
<!-- README.md is generated from README.Rmd. Please edit that file -->

# nlmixr2extra

<!-- badges: start -->

[![R-CMD-check](https://github.com/nlmixr2/nlmixr2extra/workflows/R-CMD-check/badge.svg)](https://github.com/nlmixr2/nlmixr2extra/actions)
[![Codecov test
coverage](https://codecov.io/gh/nlmixr2/nlmixr2extra/branch/main/graph/badge.svg)](https://app.codecov.io/gh/nlmixr2/nlmixr2extra?branch=main)
[![CRAN
version](http://www.r-pkg.org/badges/version/nlmixr2extra)](https://cran.r-project.org/package=nlmixr2extra)
[![CRAN total
downloads](https://cranlogs.r-pkg.org/badges/grand-total/nlmixr2extra)](https://cran.r-project.org/package=nlmixr2extra)
[![CRAN total
downloads](https://cranlogs.r-pkg.org/badges/nlmixr2extra)](https://cran.r-project.org/package=nlmixr2extra)
[![CodeFactor](https://www.codefactor.io/repository/github/nlmixr2/nlmixr2extra/badge)](https://www.codefactor.io/repository/github/nlmixr2/nlmixr2extra)
![r-universe](https://nlmixr2.r-universe.dev/badges/nlmixr2extra)
<!-- badges: end -->

The goal of nlmixr2extra is to provide the tools to help with common
pharmacometric tasks with nlmixr2 models like bootstrapping, covariate
selection etc.

## Installation

You can install the development version of nlmixr2extra from
[GitHub](https://github.com/) with:

``` r
# install.packages("remotes")
remotes::install_github("nlmixr2/nlmixr2data")
remotes::install_github("nlmixr2/lotri")
remotes::install_github("nlmixr2/rxode2")
remotes::install_github("nlmixr2/nlmixr2est")
remotes::install_github("nlmixr2/nlmixr2extra")
```

## Example of a `bootstrapFit()`

This is a basic example of bootstrapping provided by this package

``` r
library(nlmixr2est)
#> Loading required package: nlmixr2data
library(nlmixr2extra)
## basic example code
## The basic model consiss of an ini block that has initial estimates
one.compartment <- function() {
  ini({
    tka <- 0.45 # Log Ka
    tcl <- 1 # Log Cl
    tv <- 3.45    # Log V
    eta.ka ~ 0.6
    eta.cl ~ 0.3
    eta.v ~ 0.1
    add.sd <- 0.7
  })
  # and a model block with the error sppecification and model specification
  model({
    ka <- exp(tka + eta.ka)
    cl <- exp(tcl + eta.cl)
    v <- exp(tv + eta.v)
    d/dt(depot) = -ka * depot
    d/dt(center) = ka * depot - cl / v * center
    cp = center / v
    cp ~ add(add.sd)
  })
}

## The fit is performed by the function nlmixr/nlmix2 specifying the model, data and estimate
fit <- nlmixr2(one.compartment, theo_sd,  est="saem", saemControl(print=0))
#> ℹ parameter labels from comments will be replaced by 'label()'
#> → loading into symengine environment...
#> → pruning branches (`if`/`else`) of saem model...
#> ✔ done
#> → finding duplicate expressions in saem model...
#> [====|====|====|>---------------------------------]  33%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  
#> → optimizing duplicate expressions in saem model...
#> [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  
#> ✔ done
#> rxode2 2.0.9 using 4 threads (see ?getRxThreads)
#> Calculating covariance matrix
#> >-------------------------------------------------]  01%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  
#> → loading into symengine environment...
#> → pruning branches (`if`/`else`) of saem model...
#> ✔ done
#> → finding duplicate expressions in saem predOnly model 0...
#> [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  
#> → finding duplicate expressions in saem predOnly model 1...
#> [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  
#> → optimizing duplicate expressions in saem predOnly model 1...
#> [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  
#> → finding duplicate expressions in saem predOnly model 2...
#> [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  
#> ✔ done
#> → Calculating residuals/tables
#> ✔ done
#> → compress origData in nlmixr2 object, save 5952
#> → compress phiM in nlmixr2 object, save 62360
#> → compress parHist in nlmixr2 object, save 9560
#> → compress saem0 in nlmixr2 object, save 28720

fit2 <- suppressMessages(bootstrapFit(fit))
#> [====|====|====|>---------------------------------]  33%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.288803    0.978875    3.446285    0.392401    0.088720    0.016800    1.797015    
#> 002: 0.364956    1.006541    3.454819    0.372781    0.084284    0.015960    1.185648    
#> 003: 0.510180    0.904762    3.474734    0.354142    0.080070    0.015162    0.918608    
#> 004: 0.469132    0.928467    3.474083    0.336435    0.076067    0.014404    0.843936    
#> 005: 0.549086    0.944019    3.471888    0.344033    0.072263    0.013684    0.812700    
#> 006: 0.507476    0.961289    3.458957    0.341217    0.078991    0.013000    0.743293    
#> 007: 0.469826    0.948615    3.456028    0.324156    0.075041    0.012350    0.767495    
#> 008: 0.461403    0.965787    3.442739    0.396810    0.073617    0.011732    0.761684    
#> 009: 0.440973    0.936870    3.437581    0.422620    0.074051    0.011146    0.771547    
#> 010: 0.419993    0.955247    3.441024    0.414608    0.070348    0.010588    0.780521    
#> 011: 0.506499    0.966527    3.441234    0.458716    0.074833    0.010059    0.765749    
#> 012: 0.493076    0.965366    3.430157    0.435780    0.071091    0.011213    0.738729    
#> 013: 0.415532    0.966124    3.430387    0.413991    0.068155    0.013143    0.743716    
#> 014: 0.474001    0.946162    3.446693    0.426304    0.086004    0.013508    0.750853    
#> 015: 0.506237    0.954114    3.462542    0.404989    0.081704    0.012832    0.739427    
#> 016: 0.507395    0.958252    3.464558    0.447393    0.099510    0.012191    0.745778    
#> 017: 0.502623    0.959698    3.468936    0.443470    0.098485    0.011581    0.740544    
#> 018: 0.499805    0.947233    3.451106    0.421297    0.108327    0.011002    0.743342    
#> 019: 0.463627    0.950666    3.448514    0.431765    0.102910    0.010452    0.734969    
#> 020: 0.511487    0.964835    3.455564    0.442147    0.097765    0.010004    0.740815    
#> 021: 0.498569    0.943445    3.464077    0.420039    0.092877    0.009504    0.740021    
#> 022: 0.497442    0.940285    3.469202    0.463414    0.088233    0.009029    0.749821    
#> 023: 0.573617    0.947463    3.481081    0.440243    0.083821    0.008577    0.766046    
#> 024: 0.566936    0.961609    3.475120    0.435935    0.079630    0.008148    0.772363    
#> 025: 0.533325    0.936007    3.458758    0.460408    0.076570    0.008190    0.771306    
#> 026: 0.504430    0.961734    3.458389    0.437387    0.084167    0.011287    0.755922    
#> 027: 0.455874    0.987119    3.451109    0.415518    0.087975    0.012124    0.790582    
#> 028: 0.497673    0.953105    3.457788    0.394742    0.090866    0.011518    0.750350    
#> 029: 0.524332    0.947197    3.450710    0.440898    0.087640    0.010942    0.765437    
#> 030: 0.543604    0.958975    3.446713    0.418853    0.088824    0.010395    0.761807    
#> 031: 0.518314    0.936689    3.459394    0.515493    0.084383    0.009875    0.729652    
#> 032: 0.522224    0.944341    3.458723    0.583728    0.089635    0.009381    0.724806    
#> 033: 0.500102    0.955974    3.455613    0.554541    0.101250    0.008912    0.731551    
#> 034: 0.532469    0.957643    3.456762    0.526814    0.096188    0.008872    0.722828    
#> 035: 0.464806    0.938234    3.443717    0.500473    0.091378    0.008428    0.730470    
#> 036: 0.477341    0.951170    3.446830    0.475450    0.099147    0.008007    0.731938    
#> 037: 0.518269    0.958704    3.453297    0.451677    0.094190    0.007606    0.750267    
#> 038: 0.509890    0.960283    3.440294    0.429093    0.089480    0.007598    0.735975    
#> 039: 0.486821    0.955821    3.456073    0.407639    0.087368    0.007218    0.743754    
#> 040: 0.491917    0.963409    3.461726    0.387257    0.084039    0.006857    0.751194    
#> 041: 0.483130    0.946241    3.459153    0.388285    0.088669    0.006514    0.724504    
#> 042: 0.485180    0.946132    3.446349    0.368871    0.088233    0.006339    0.740779    
#> 043: 0.422046    0.973716    3.434888    0.350427    0.083821    0.006117    0.742111    
#> 044: 0.428742    0.977601    3.436592    0.335622    0.094692    0.006374    0.749974    
#> 045: 0.426329    0.979645    3.429591    0.335578    0.089957    0.006055    0.757419    
#> 046: 0.432972    0.969997    3.437091    0.318800    0.085459    0.005752    0.756750    
#> 047: 0.448389    0.964076    3.440040    0.346197    0.081186    0.005465    0.749620    
#> 048: 0.451875    0.945788    3.437565    0.396699    0.079399    0.005191    0.751811    
#> 049: 0.439602    0.942155    3.442474    0.429846    0.084800    0.005683    0.743807    
#> 050: 0.517837    0.918489    3.448426    0.448612    0.094424    0.006945    0.765733    
#> 051: 0.478900    0.924461    3.445303    0.426181    0.089703    0.006867    0.766745    
#> 052: 0.449570    0.949465    3.446793    0.404872    0.092798    0.006743    0.747830    
#> 053: 0.471306    0.952123    3.444047    0.392100    0.095943    0.006406    0.735880    
#> 054: 0.441670    0.971257    3.443328    0.376509    0.106932    0.006086    0.741067    
#> 055: 0.455486    0.959621    3.437541    0.377678    0.104389    0.005781    0.743856    
#> 056: 0.469347    0.941851    3.440332    0.417126    0.136588    0.005492    0.764651    
#> 057: 0.475796    0.931409    3.450799    0.430272    0.129759    0.006295    0.774194    
#> 058: 0.471262    0.932520    3.444068    0.408758    0.123271    0.007261    0.778025    
#> 059: 0.441325    0.915503    3.455493    0.388321    0.117108    0.009561    0.790378    
#> 060: 0.474100    0.909014    3.466437    0.368905    0.123584    0.009083    0.788505    
#> 061: 0.535053    0.937604    3.464648    0.404767    0.131965    0.008628    0.764447    
#> 062: 0.525797    0.962440    3.466482    0.418208    0.125366    0.008197    0.770208    
#> 063: 0.511458    0.922591    3.461686    0.412103    0.119098    0.009369    0.756928    
#> 064: 0.469058    0.931515    3.462516    0.391498    0.113143    0.008900    0.762781    
#> 065: 0.509476    0.941934    3.450363    0.404834    0.107486    0.008455    0.770649    
#> 066: 0.520119    0.955202    3.457171    0.434849    0.102112    0.008032    0.737724    
#> 067: 0.486520    0.944835    3.441301    0.413107    0.098765    0.007631    0.737381    
#> 068: 0.470243    0.965602    3.448452    0.441279    0.128808    0.007249    0.740466    
#> 069: 0.472063    0.946924    3.443311    0.453382    0.122368    0.006887    0.744896    
#> 070: 0.463350    0.961480    3.455510    0.430713    0.117555    0.006936    0.746043    
#> 071: 0.457413    0.964532    3.436077    0.442671    0.113715    0.006753    0.752737    
#> 072: 0.436475    0.928230    3.444981    0.422472    0.108029    0.006416    0.759115    
#> 073: 0.476644    0.954000    3.459707    0.414139    0.117840    0.006387    0.751274    
#> 074: 0.447828    0.919595    3.457887    0.405758    0.113772    0.006476    0.729825    
#> 075: 0.498616    0.921909    3.479366    0.385470    0.108083    0.006153    0.742484    
#> 076: 0.512583    0.940805    3.482913    0.379778    0.107899    0.006068    0.759221    
#> 077: 0.544691    0.915642    3.474145    0.441685    0.106063    0.005773    0.763239    
#> 078: 0.540503    0.941830    3.474269    0.489171    0.104573    0.006367    0.736902    
#> 079: 0.522371    0.950949    3.474903    0.464712    0.112726    0.007651    0.755575    
#> 080: 0.508734    0.951866    3.468378    0.441477    0.118943    0.010981    0.780721    
#> 081: 0.504811    0.937237    3.468959    0.419403    0.112996    0.012391    0.772237    
#> 082: 0.526606    0.922567    3.481072    0.432144    0.107346    0.011772    0.761130    
#> 083: 0.557222    0.969039    3.481450    0.433290    0.101979    0.011183    0.761912    
#> 084: 0.531451    0.962029    3.470704    0.436897    0.103667    0.010624    0.758900    
#> 085: 0.507147    0.961483    3.473442    0.427155    0.112207    0.010093    0.764063    
#> 086: 0.530548    0.940320    3.468151    0.479643    0.106596    0.009588    0.752891    
#> 087: 0.493182    0.941121    3.451665    0.455826    0.101267    0.009109    0.750047    
#> 088: 0.419334    0.954925    3.447406    0.433035    0.098326    0.008653    0.772469    
#> 089: 0.430799    0.978210    3.429080    0.447842    0.107078    0.008221    0.758035    
#> 090: 0.459594    0.945198    3.433787    0.425450    0.109974    0.007810    0.762033    
#> 091: 0.464047    0.942131    3.430523    0.404509    0.104475    0.007419    0.768378    
#> 092: 0.423904    0.969480    3.429625    0.393773    0.099251    0.007048    0.748858    
#> 093: 0.401111    0.976491    3.425267    0.412789    0.094289    0.006741    0.748389    
#> 094: 0.442180    0.979174    3.423586    0.451546    0.100485    0.008059    0.743660    
#> 095: 0.441106    0.985149    3.430352    0.449848    0.104361    0.007656    0.741488    
#> 096: 0.413562    0.969325    3.428369    0.444031    0.101412    0.007273    0.734259    
#> 097: 0.459272    0.985031    3.430003    0.421829    0.096342    0.006910    0.740791    
#> 098: 0.453960    0.998615    3.429766    0.454905    0.104526    0.006564    0.741354    
#> 099: 0.419222    0.954711    3.422077    0.432160    0.120947    0.006236    0.730669    
#> 100: 0.436425    0.989973    3.423301    0.410552    0.114899    0.005924    0.752592    
#> 101: 0.363424    0.966448    3.406477    0.423428    0.109154    0.005628    0.757607    
#> 102: 0.380330    0.974623    3.399920    0.443425    0.103697    0.005346    0.756598    
#> 103: 0.422332    0.981215    3.412543    0.430551    0.102869    0.005079    0.743735    
#> 104: 0.420135    0.977924    3.424860    0.437135    0.108996    0.004825    0.744525    
#> 105: 0.464498    0.963721    3.429126    0.467772    0.117760    0.004713    0.751498    
#> 106: 0.441836    0.971341    3.427214    0.444384    0.111872    0.004478    0.760660    
#> 107: 0.469697    0.966332    3.431592    0.422165    0.106349    0.004660    0.759925    
#> 108: 0.453203    0.963519    3.424006    0.401056    0.111735    0.004427    0.762516    
#> 109: 0.449129    0.965072    3.433759    0.447038    0.106149    0.004206    0.768293    
#> 110: 0.473089    0.947578    3.424740    0.424686    0.100841    0.003995    0.764174    
#> 111: 0.485182    0.963313    3.433335    0.447556    0.100716    0.003796    0.756380    
#> 112: 0.428718    0.956322    3.424501    0.448877    0.103546    0.003606    0.764068    
#> 113: 0.446540    0.978737    3.433397    0.489231    0.104708    0.003425    0.731813    
#> 114: 0.438656    0.973719    3.434709    0.464770    0.099473    0.003254    0.746007    
#> 115: 0.470419    0.938681    3.436043    0.441531    0.098791    0.003091    0.766273    
#> 116: 0.476104    0.955957    3.441140    0.419455    0.106805    0.002937    0.750867    
#> 117: 0.453670    0.959092    3.440723    0.420248    0.101465    0.002959    0.764741    
#> 118: 0.490860    0.938870    3.443741    0.454150    0.096392    0.002811    0.760336    
#> 119: 0.451697    0.956656    3.440340    0.431443    0.098932    0.003810    0.765562    
#> 120: 0.394145    0.958557    3.438028    0.409871    0.094237    0.004594    0.761570    
#> 121: 0.427551    0.986137    3.431223    0.389377    0.096651    0.004487    0.753006    
#> 122: 0.439188    0.969990    3.432917    0.447196    0.118226    0.004663    0.737358    
#> 123: 0.519760    0.989493    3.440383    0.474418    0.112315    0.005278    0.756673    
#> 124: 0.484024    1.004367    3.435405    0.450697    0.106699    0.005832    0.750003    
#> 125: 0.485707    0.987394    3.431322    0.428162    0.101364    0.006043    0.732638    
#> 126: 0.430954    0.994236    3.421378    0.406754    0.096296    0.005838    0.756869    
#> 127: 0.423875    0.994805    3.419960    0.394904    0.091481    0.005546    0.756201    
#> 128: 0.434773    0.962520    3.436852    0.408054    0.098022    0.005885    0.738128    
#> 129: 0.469388    0.966084    3.447186    0.446969    0.093121    0.005591    0.744223    
#> 130: 0.528366    0.962156    3.452884    0.459002    0.099687    0.006295    0.741606    
#> 131: 0.481980    0.948117    3.441670    0.481178    0.115363    0.006436    0.739382    
#> 132: 0.467723    0.970790    3.436009    0.457119    0.109595    0.006114    0.755441    
#> 133: 0.435932    0.944731    3.436085    0.434263    0.121056    0.006126    0.739174    
#> 134: 0.461495    0.929387    3.446464    0.430911    0.134542    0.006191    0.744995    
#> 135: 0.472340    0.957669    3.442927    0.434591    0.127815    0.005881    0.736639    
#> 136: 0.474256    0.934193    3.444043    0.441157    0.123855    0.005587    0.736324    
#> 137: 0.505845    0.922343    3.450535    0.421987    0.117663    0.005308    0.761050    
#> 138: 0.451694    0.955319    3.448829    0.400887    0.111779    0.005043    0.752507    
#> 139: 0.439039    0.961695    3.450229    0.380843    0.106190    0.004790    0.763887    
#> 140: 0.464308    0.977783    3.450012    0.363441    0.116952    0.004986    0.751776    
#> 141: 0.458861    0.939787    3.458431    0.345269    0.112632    0.004736    0.741117    
#> 142: 0.487723    0.931551    3.469847    0.346406    0.119205    0.005518    0.744071    
#> 143: 0.458718    0.946390    3.468955    0.348256    0.113245    0.005430    0.759131    
#> 144: 0.529996    0.961842    3.474024    0.363795    0.107582    0.005159    0.737832    
#> 145: 0.483242    0.970463    3.457576    0.365647    0.102203    0.004901    0.716821    
#> 146: 0.494759    0.976448    3.460801    0.347364    0.097093    0.004656    0.745750    
#> 147: 0.450969    0.942690    3.456482    0.413325    0.096508    0.004640    0.723905    
#> 148: 0.478025    0.947088    3.451994    0.413991    0.091683    0.004846    0.719231    
#> 149: 0.447375    0.957809    3.449055    0.395559    0.096620    0.004720    0.761867    
#> 150: 0.467183    0.954304    3.441026    0.375781    0.092439    0.004581    0.763224    
#> 151: 0.439408    0.979423    3.437082    0.381180    0.090979    0.004352    0.742385    
#> 152: 0.428882    0.968376    3.439029    0.421073    0.092207    0.003179    0.754409    
#> 153: 0.443055    0.981745    3.442171    0.406970    0.092866    0.002931    0.760870    
#> 154: 0.488322    0.995699    3.442702    0.452628    0.089253    0.002953    0.772505    
#> 155: 0.473431    0.962597    3.438086    0.403344    0.108593    0.003132    0.760016    
#> 156: 0.495660    0.947440    3.456187    0.416763    0.122177    0.002565    0.755968    
#> 157: 0.484785    0.931260    3.453258    0.475733    0.129758    0.003171    0.760634    
#> 158: 0.516732    0.949053    3.454186    0.423354    0.123405    0.002719    0.739213    
#> 159: 0.467722    0.951746    3.454156    0.430671    0.126974    0.002088    0.740260    
#> 160: 0.459446    0.927070    3.455133    0.398576    0.127631    0.002634    0.739849    
#> 161: 0.467911    0.947480    3.451781    0.420824    0.126574    0.002681    0.743885    
#> 162: 0.459405    0.968112    3.439447    0.426089    0.110677    0.002047    0.752310    
#> 163: 0.463123    0.962020    3.434702    0.458844    0.146922    0.002028    0.750370    
#> 164: 0.459105    0.966549    3.431019    0.449204    0.121394    0.002178    0.727098    
#> 165: 0.473393    0.958834    3.440640    0.437648    0.110515    0.002823    0.729620    
#> 166: 0.489012    0.993194    3.438564    0.411402    0.125159    0.002733    0.747717    
#> 167: 0.472154    0.980911    3.441748    0.380931    0.110477    0.002843    0.746862    
#> 168: 0.498113    0.970005    3.446624    0.359183    0.102551    0.003176    0.742132    
#> 169: 0.463266    0.983002    3.444956    0.363983    0.109333    0.002582    0.765161    
#> 170: 0.484727    0.956382    3.445273    0.434579    0.115131    0.003259    0.746367    
#> 171: 0.456108    0.949285    3.448712    0.373559    0.121753    0.003342    0.745744    
#> 172: 0.477177    0.991482    3.443321    0.437363    0.102956    0.003036    0.734714    
#> 173: 0.464353    0.976521    3.437631    0.438937    0.100818    0.003391    0.740831    
#> 174: 0.446915    0.976857    3.440733    0.338572    0.085301    0.004233    0.721075    
#> 175: 0.420167    0.989785    3.427637    0.341420    0.098488    0.003773    0.736391    
#> 176: 0.449420    0.993313    3.434901    0.423242    0.092468    0.003505    0.732045    
#> 177: 0.466618    0.961370    3.440405    0.386342    0.094418    0.003115    0.748267    
#> 178: 0.493899    0.947550    3.443843    0.425145    0.097029    0.003229    0.739673    
#> 179: 0.506294    0.968380    3.439980    0.398604    0.093805    0.003805    0.751596    
#> 180: 0.442553    0.981432    3.437645    0.493055    0.085104    0.004086    0.736739    
#> 181: 0.429998    0.991809    3.424742    0.423989    0.081626    0.004012    0.742858    
#> 182: 0.405708    0.982561    3.424090    0.370298    0.088101    0.003663    0.763971    
#> 183: 0.414927    0.995409    3.424486    0.340061    0.079909    0.003197    0.786911    
#> 184: 0.404763    0.985948    3.421457    0.397777    0.085608    0.003252    0.772746    
#> 185: 0.412959    0.988062    3.418124    0.378339    0.112376    0.002404    0.756268    
#> 186: 0.413852    0.988544    3.426744    0.339053    0.095202    0.002582    0.738944    
#> 187: 0.421847    0.966032    3.435079    0.352461    0.108327    0.002809    0.743877    
#> 188: 0.385113    0.976193    3.425364    0.370981    0.099044    0.002015    0.762471    
#> 189: 0.438061    0.997796    3.427983    0.395440    0.082898    0.002261    0.763536    
#> 190: 0.432364    0.983883    3.433558    0.386783    0.091704    0.002096    0.748394    
#> 191: 0.427803    0.976015    3.427885    0.425679    0.101425    0.002267    0.751794    
#> 192: 0.448061    0.974555    3.430797    0.460236    0.097076    0.002130    0.749212    
#> 193: 0.455619    0.988489    3.433868    0.397224    0.101441    0.001862    0.738211    
#> 194: 0.434446    0.970611    3.428784    0.404154    0.121711    0.002044    0.740942    
#> 195: 0.414566    0.956487    3.429804    0.458587    0.106098    0.002548    0.742081    
#> 196: 0.446255    0.959684    3.437557    0.421609    0.112315    0.002176    0.748796    
#> 197: 0.426148    0.969609    3.445027    0.384099    0.109645    0.002441    0.756016    
#> 198: 0.470119    0.948722    3.438140    0.438263    0.106622    0.003690    0.747920    
#> 199: 0.420581    0.953792    3.438336    0.455127    0.115806    0.003771    0.749115    
#> 200: 0.448832    0.953222    3.444956    0.381452    0.123954    0.004150    0.760650    
#> 201: 0.445597    0.952101    3.445784    0.377768    0.113816    0.005814    0.749324    
#> 202: 0.463523    0.954899    3.445861    0.409530    0.112791    0.006010    0.747730    
#> 203: 0.474453    0.958576    3.444508    0.404531    0.109405    0.006253    0.746563    
#> 204: 0.474862    0.954314    3.446486    0.410124    0.103148    0.006477    0.748830    
#> 205: 0.473134    0.959256    3.447723    0.408211    0.099814    0.006493    0.753053    
#> 206: 0.472591    0.961986    3.448561    0.415798    0.098660    0.006449    0.753038    
#> 207: 0.472908    0.960697    3.448238    0.407244    0.099952    0.006365    0.751949    
#> 208: 0.473164    0.960600    3.448398    0.405027    0.100754    0.006388    0.750095    
#> 209: 0.476017    0.959642    3.448107    0.408530    0.100135    0.006491    0.749882    
#> 210: 0.478340    0.957422    3.448597    0.403661    0.098980    0.006553    0.748658    
#> 211: 0.482571    0.956641    3.449629    0.396951    0.097621    0.006486    0.747652    
#> 212: 0.484260    0.954916    3.450463    0.392645    0.097143    0.006324    0.746281    
#> 213: 0.487760    0.952665    3.450796    0.395544    0.098035    0.006301    0.746148    
#> 214: 0.488931    0.953299    3.451170    0.394172    0.098391    0.006278    0.745632    
#> 215: 0.489238    0.954140    3.451329    0.390499    0.098164    0.006254    0.746249    
#> 216: 0.490826    0.952677    3.451736    0.392020    0.098896    0.006278    0.746925    
#> 217: 0.490611    0.952583    3.451879    0.390196    0.099121    0.006277    0.746491    
#> 218: 0.491391    0.953786    3.451658    0.391448    0.099333    0.006213    0.746290    
#> 219: 0.489916    0.953514    3.450638    0.391567    0.099321    0.006179    0.746435    
#> 220: 0.487565    0.954968    3.450235    0.393611    0.099076    0.006121    0.746174    
#> 221: 0.486153    0.954821    3.450016    0.393592    0.099541    0.006073    0.745538    
#> 222: 0.485833    0.954089    3.449703    0.393543    0.099945    0.006040    0.745790    
#> 223: 0.486649    0.953859    3.449395    0.394456    0.099386    0.006020    0.745801    
#> 224: 0.487098    0.954323    3.449642    0.394924    0.098998    0.006022    0.745431    
#> 225: 0.488271    0.951774    3.450346    0.394413    0.099054    0.006040    0.745596    
#> 226: 0.488052    0.949673    3.450657    0.393993    0.099194    0.005973    0.746219    
#> 227: 0.487874    0.949378    3.450981    0.393600    0.099215    0.005901    0.746362    
#> 228: 0.487046    0.950055    3.450770    0.393068    0.099586    0.005847    0.746074    
#> 229: 0.485658    0.950029    3.450367    0.394159    0.099709    0.005779    0.745550    
#> 230: 0.485451    0.949955    3.449995    0.394831    0.099399    0.005721    0.744981    
#> 231: 0.484383    0.950458    3.449924    0.394904    0.100038    0.005664    0.744683    
#> 232: 0.482828    0.951263    3.449684    0.396646    0.100162    0.005630    0.744234    
#> 233: 0.482093    0.950808    3.449546    0.397059    0.100038    0.005624    0.744734    
#> 234: 0.480907    0.950993    3.449467    0.396264    0.099734    0.005601    0.744730    
#> 235: 0.480246    0.951152    3.449383    0.394824    0.099246    0.005573    0.744963    
#> 236: 0.480390    0.951400    3.449193    0.396312    0.099133    0.005572    0.744945    
#> 237: 0.481428    0.951414    3.449327    0.398389    0.098920    0.005612    0.744757    
#> 238: 0.482075    0.951386    3.449387    0.399710    0.098770    0.005651    0.744821    
#> 239: 0.481109    0.952143    3.449208    0.399990    0.098945    0.005674    0.745364    
#> 240: 0.480586    0.952094    3.449051    0.398592    0.098568    0.005679    0.745240    
#> 241: 0.479765    0.951365    3.448910    0.397312    0.098290    0.005700    0.745095    
#> 242: 0.478733    0.950744    3.448703    0.396497    0.097835    0.005712    0.745727    
#> 243: 0.477111    0.951098    3.448584    0.396578    0.097271    0.005741    0.746172    
#> 244: 0.476169    0.951062    3.448496    0.398062    0.096650    0.005784    0.746383    
#> 245: 0.475610    0.950455    3.448631    0.398453    0.096390    0.005793    0.747003    
#> 246: 0.475641    0.950182    3.448722    0.398402    0.096082    0.005845    0.747046    
#> 247: 0.475596    0.949503    3.448875    0.397902    0.096018    0.005855    0.747086    
#> 248: 0.476000    0.949753    3.448903    0.398498    0.096172    0.005867    0.746797    
#> 249: 0.475607    0.950043    3.448892    0.398605    0.096176    0.005872    0.746420    
#> 250: 0.476127    0.950218    3.448878    0.398567    0.095900    0.005896    0.746441    
#> 251: 0.476103    0.951340    3.448813    0.400201    0.096189    0.005865    0.746591    
#> 252: 0.476567    0.951682    3.449044    0.400622    0.096152    0.005844    0.746631    
#> 253: 0.476752    0.952214    3.449132    0.401597    0.096344    0.005833    0.746512    
#> 254: 0.476986    0.952553    3.449246    0.401130    0.096611    0.005823    0.746524    
#> 255: 0.477328    0.952928    3.449393    0.401939    0.096421    0.005845    0.746414    
#> 256: 0.477759    0.953037    3.449379    0.402339    0.096261    0.005861    0.746146    
#> 257: 0.477144    0.953101    3.449225    0.402578    0.096354    0.005876    0.746116    
#> 258: 0.476306    0.953035    3.449126    0.401943    0.096657    0.005852    0.746227    
#> 259: 0.476213    0.953357    3.448957    0.403086    0.096826    0.005851    0.746259    
#> 260: 0.475936    0.953807    3.448939    0.403172    0.096851    0.005855    0.746224    
#> 261: 0.476170    0.953613    3.448934    0.403544    0.096855    0.005841    0.746212    
#> 262: 0.475967    0.953858    3.448904    0.402583    0.096876    0.005840    0.746223    
#> 263: 0.475385    0.954335    3.448712    0.402244    0.096782    0.005872    0.746297    
#> 264: 0.474819    0.954346    3.448553    0.402232    0.096691    0.005870    0.746593    
#> 265: 0.474649    0.954249    3.448494    0.402857    0.096332    0.005903    0.747090    
#> 266: 0.475226    0.954089    3.448540    0.403845    0.096342    0.005920    0.747212    
#> 267: 0.475337    0.953962    3.448674    0.405248    0.096440    0.005924    0.747271    
#> 268: 0.475563    0.953718    3.448586    0.405701    0.096549    0.005888    0.747200    
#> 269: 0.476555    0.953684    3.448596    0.406889    0.096911    0.005878    0.747134    
#> 270: 0.476975    0.953930    3.448477    0.407952    0.096963    0.005859    0.746846    
#> 271: 0.477264    0.954117    3.448368    0.409322    0.097052    0.005851    0.746706    
#> 272: 0.477564    0.954053    3.448327    0.409296    0.096880    0.005844    0.747198    
#> 273: 0.477809    0.954369    3.448333    0.409097    0.096681    0.005837    0.747560    
#> 274: 0.477356    0.954628    3.448399    0.408275    0.096640    0.005830    0.747708    
#> 275: 0.476947    0.954883    3.448312    0.407797    0.096462    0.005827    0.747724    
#> 276: 0.476741    0.955127    3.448473    0.407740    0.096393    0.005835    0.747818    
#> 277: 0.476761    0.955401    3.448612    0.407983    0.096533    0.005833    0.747775    
#> 278: 0.476653    0.955276    3.448676    0.407711    0.096385    0.005829    0.747978    
#> 279: 0.476110    0.955289    3.448650    0.407023    0.096544    0.005817    0.748069    
#> 280: 0.476091    0.955169    3.448760    0.406225    0.096579    0.005819    0.747987    
#> 281: 0.475623    0.955142    3.448815    0.405973    0.096330    0.005828    0.748141    
#> 282: 0.475295    0.955299    3.448940    0.405550    0.096225    0.005838    0.747995    
#> 283: 0.475357    0.955296    3.449056    0.405990    0.096212    0.005842    0.748095    
#> 284: 0.475053    0.955355    3.449014    0.405925    0.096071    0.005854    0.747748    
#> 285: 0.474639    0.955598    3.448801    0.406177    0.095995    0.005885    0.747703    
#> 286: 0.474034    0.955838    3.448529    0.406790    0.096041    0.005904    0.747588    
#> 287: 0.473161    0.956105    3.448229    0.406606    0.096040    0.005903    0.747601    
#> 288: 0.472779    0.956137    3.447940    0.405638    0.096108    0.005910    0.747925    
#> 289: 0.472881    0.956009    3.447887    0.404644    0.096195    0.005907    0.748077    
#> 290: 0.472888    0.955993    3.447810    0.404316    0.096417    0.005913    0.748028    
#> 291: 0.472870    0.956097    3.447777    0.404629    0.096528    0.005921    0.747851    
#> 292: 0.472846    0.956215    3.447670    0.405002    0.096731    0.005920    0.747942    
#> 293: 0.472747    0.956147    3.447615    0.405469    0.096715    0.005928    0.747982    
#> 294: 0.472379    0.956342    3.447538    0.405468    0.096690    0.005942    0.747932    
#> 295: 0.472209    0.956298    3.447472    0.405782    0.096765    0.005919    0.747974    
#> 296: 0.472147    0.956238    3.447444    0.405786    0.096833    0.005911    0.748228    
#> 297: 0.472183    0.956476    3.447417    0.405720    0.096863    0.005910    0.748366    
#> 298: 0.472555    0.956313    3.447408    0.406383    0.096857    0.005930    0.748328    
#> 299: 0.472844    0.956530    3.447425    0.407127    0.096923    0.005942    0.748033    
#> 300: 0.472739    0.956371    3.447502    0.407063    0.096827    0.005955    0.747788    
#> 301: 0.473072    0.956127    3.447491    0.406952    0.096604    0.005958    0.747869    
#> 302: 0.473381    0.956137    3.447517    0.406979    0.096388    0.005945    0.747861    
#> 303: 0.473658    0.956151    3.447541    0.406852    0.096368    0.005944    0.747800    
#> 304: 0.473739    0.956361    3.447488    0.407193    0.096352    0.005955    0.747950    
#> 305: 0.473469    0.956045    3.447450    0.407246    0.096375    0.005945    0.748025    
#> 306: 0.473250    0.955899    3.447316    0.407675    0.096293    0.005952    0.748113    
#> 307: 0.473320    0.955856    3.447261    0.407810    0.096293    0.005949    0.748297    
#> 308: 0.473292    0.955841    3.447225    0.409204    0.096294    0.005940    0.748475    
#> 309: 0.473633    0.955620    3.447180    0.409758    0.096223    0.005946    0.748419    
#> 310: 0.473759    0.955503    3.447111    0.409823    0.096076    0.005946    0.748311    
#> 311: 0.473591    0.955524    3.447014    0.410162    0.095938    0.005945    0.748135    
#> 312: 0.473370    0.955486    3.446878    0.410356    0.095864    0.005939    0.748267    
#> 313: 0.472808    0.955336    3.446790    0.410247    0.095864    0.005943    0.748459    
#> 314: 0.472470    0.955524    3.446689    0.410372    0.095801    0.005945    0.748429    
#> 315: 0.472197    0.955737    3.446631    0.410564    0.095899    0.005939    0.748362    
#> 316: 0.472311    0.955769    3.446652    0.410804    0.096101    0.005931    0.748542    
#> 317: 0.472642    0.955736    3.446708    0.411669    0.096255    0.005925    0.748454    
#> 318: 0.472747    0.955635    3.446708    0.411715    0.096372    0.005923    0.748340    
#> 319: 0.472856    0.955582    3.446708    0.411767    0.096437    0.005924    0.748282    
#> 320: 0.472692    0.955609    3.446596    0.411337    0.096701    0.005923    0.748320    
#> 321: 0.472335    0.955763    3.446403    0.411050    0.096867    0.005914    0.748308    
#> 322: 0.472131    0.955777    3.446157    0.411378    0.097010    0.005905    0.748363    
#> 323: 0.471379    0.955921    3.446039    0.411343    0.096983    0.005896    0.748541    
#> 324: 0.471340    0.955990    3.446013    0.411461    0.096910    0.005876    0.748436    
#> 325: 0.471517    0.956174    3.445997    0.411708    0.096875    0.005866    0.748240    
#> 326: 0.471638    0.956074    3.445913    0.411830    0.096800    0.005854    0.748214    
#> 327: 0.472067    0.956135    3.445944    0.412561    0.096762    0.005854    0.748281    
#> 328: 0.472355    0.956319    3.445929    0.413500    0.096736    0.005849    0.748264    
#> 329: 0.472587    0.956314    3.446018    0.414114    0.096790    0.005857    0.748279    
#> 330: 0.472538    0.956222    3.446016    0.414917    0.096740    0.005871    0.748305    
#> 331: 0.472437    0.956424    3.445920    0.415132    0.096683    0.005866    0.748225    
#> 332: 0.472540    0.956307    3.445914    0.415135    0.096867    0.005857    0.748249    
#> 333: 0.472155    0.956383    3.445785    0.414715    0.096773    0.005844    0.748163    
#> 334: 0.471782    0.956443    3.445570    0.415111    0.096728    0.005839    0.748092    
#> 335: 0.471371    0.956612    3.445400    0.414599    0.096590    0.005843    0.748069    
#> 336: 0.470933    0.956903    3.445301    0.414110    0.096531    0.005856    0.748006    
#> 337: 0.470534    0.957238    3.445198    0.413751    0.096412    0.005865    0.748041    
#> 338: 0.470465    0.957430    3.445161    0.413934    0.096487    0.005859    0.748098    
#> 339: 0.470221    0.957592    3.445063    0.413970    0.096586    0.005860    0.747959    
#> 340: 0.470090    0.957591    3.444986    0.413943    0.096846    0.005852    0.748018    
#> 341: 0.470148    0.957595    3.445004    0.414100    0.097144    0.005841    0.748071    
#> 342: 0.470003    0.957456    3.444987    0.414080    0.097241    0.005829    0.748089    
#> 343: 0.469533    0.957631    3.445007    0.413803    0.097293    0.005818    0.748218    
#> 344: 0.469524    0.957755    3.445014    0.413587    0.097387    0.005814    0.748380    
#> 345: 0.469572    0.957682    3.445095    0.413608    0.097648    0.005809    0.748390    
#> 346: 0.469599    0.957626    3.445095    0.414005    0.097754    0.005795    0.748303    
#> 347: 0.469728    0.957376    3.445032    0.413671    0.097933    0.005800    0.748331    
#> 348: 0.469395    0.957404    3.444971    0.413671    0.098130    0.005806    0.748384    
#> 349: 0.469307    0.957212    3.444938    0.413809    0.098147    0.005817    0.748368    
#> 350: 0.469098    0.957042    3.444878    0.413575    0.098273    0.005826    0.748308    
#> 351: 0.469158    0.957156    3.444817    0.413379    0.098327    0.005835    0.748345    
#> 352: 0.468806    0.957269    3.444772    0.413463    0.098380    0.005842    0.748464    
#> 353: 0.468687    0.957485    3.444659    0.413712    0.098319    0.005841    0.748457    
#> 354: 0.468700    0.957692    3.444485    0.413772    0.098218    0.005845    0.748385    
#> 355: 0.468885    0.957781    3.444367    0.414159    0.098230    0.005847    0.748348    
#> 356: 0.468965    0.957852    3.444376    0.414023    0.098378    0.005836    0.748470    
#> 357: 0.469033    0.957944    3.444366    0.414051    0.098488    0.005825    0.748441    
#> 358: 0.468900    0.957940    3.444374    0.414846    0.098597    0.005815    0.748295    
#> 359: 0.468475    0.958166    3.444316    0.414782    0.098649    0.005810    0.748247    
#> 360: 0.468357    0.958261    3.444202    0.414848    0.098696    0.005811    0.748105    
#> 361: 0.468055    0.958361    3.444076    0.414872    0.098668    0.005802    0.748042    
#> 362: 0.468020    0.958303    3.443994    0.415304    0.098634    0.005802    0.747907    
#> 363: 0.468018    0.958266    3.443963    0.415488    0.098615    0.005797    0.747793    
#> 364: 0.468099    0.958344    3.443919    0.415742    0.098629    0.005791    0.747756    
#> 365: 0.467883    0.958325    3.443901    0.415943    0.098709    0.005787    0.747755    
#> 366: 0.467967    0.958446    3.443880    0.416027    0.098720    0.005783    0.747695    
#> 367: 0.468249    0.958298    3.443954    0.416334    0.098644    0.005776    0.747701    
#> 368: 0.468400    0.958358    3.443961    0.416046    0.098632    0.005777    0.747628    
#> 369: 0.468406    0.958449    3.443968    0.415415    0.098576    0.005775    0.747634    
#> 370: 0.468461    0.958506    3.443984    0.415046    0.098569    0.005775    0.747653    
#> 371: 0.468369    0.958596    3.443902    0.414713    0.098536    0.005764    0.747672    
#> 372: 0.467956    0.958707    3.443850    0.414551    0.098542    0.005758    0.747732    
#> 373: 0.467434    0.958940    3.443743    0.414550    0.098503    0.005760    0.747759    
#> 374: 0.467612    0.958964    3.443686    0.414714    0.098413    0.005757    0.747746    
#> 375: 0.467469    0.958924    3.443677    0.415088    0.098369    0.005750    0.747763    
#> 376: 0.467426    0.959060    3.443663    0.415139    0.098279    0.005754    0.747680    
#> 377: 0.467293    0.959124    3.443649    0.415233    0.098242    0.005755    0.747577    
#> 378: 0.467232    0.959191    3.443607    0.415272    0.098287    0.005761    0.747545    
#> 379: 0.467047    0.959117    3.443580    0.415379    0.098243    0.005756    0.747531    
#> 380: 0.466971    0.959083    3.443564    0.415362    0.098391    0.005757    0.747460    
#> 381: 0.466783    0.959056    3.443526    0.415358    0.098376    0.005757    0.747444    
#> 382: 0.466698    0.959091    3.443511    0.415581    0.098420    0.005754    0.747306    
#> 383: 0.466936    0.958993    3.443550    0.415785    0.098400    0.005757    0.747283    
#> 384: 0.466845    0.958961    3.443557    0.416117    0.098371    0.005761    0.747186    
#> 385: 0.466965    0.958990    3.443553    0.416318    0.098394    0.005759    0.747117    
#> 386: 0.467076    0.959092    3.443615    0.416040    0.098395    0.005760    0.747230    
#> 387: 0.467125    0.959115    3.443649    0.415536    0.098366    0.005762    0.747260    
#> 388: 0.467248    0.959189    3.443645    0.415123    0.098309    0.005760    0.747339    
#> 389: 0.467242    0.959026    3.443655    0.414962    0.098314    0.005761    0.747447    
#> 390: 0.467052    0.959141    3.443585    0.414706    0.098348    0.005759    0.747433    
#> 391: 0.467115    0.959132    3.443561    0.414577    0.098289    0.005755    0.747378    
#> 392: 0.467249    0.959145    3.443569    0.414797    0.098275    0.005752    0.747377    
#> 393: 0.467312    0.959073    3.443541    0.414853    0.098262    0.005756    0.747378    
#> 394: 0.467361    0.959065    3.443510    0.414902    0.098309    0.005754    0.747312    
#> 395: 0.467672    0.959222    3.443514    0.415208    0.098294    0.005756    0.747323    
#> 396: 0.467763    0.959287    3.443529    0.415146    0.098296    0.005753    0.747308    
#> 397: 0.467707    0.959242    3.443542    0.414793    0.098234    0.005754    0.747387    
#> 398: 0.467816    0.959212    3.443527    0.414836    0.098165    0.005755    0.747494    
#> 399: 0.467877    0.959249    3.443573    0.414649    0.098163    0.005754    0.747571    
#> 400: 0.467994    0.959334    3.443617    0.414586    0.098187    0.005751    0.747620    
#> 401: 0.467904    0.959371    3.443610    0.414427    0.098265    0.005753    0.747606    
#> 402: 0.467953    0.959496    3.443587    0.414245    0.098386    0.005749    0.747622    
#> 403: 0.468174    0.959527    3.443570    0.414055    0.098530    0.005744    0.747603    
#> 404: 0.468003    0.959646    3.443470    0.414121    0.098590    0.005740    0.747579    
#> 405: 0.467758    0.959748    3.443419    0.414449    0.098561    0.005741    0.747580    
#> 406: 0.467665    0.959895    3.443376    0.414415    0.098554    0.005747    0.747622    
#> 407: 0.467703    0.959859    3.443403    0.414601    0.098633    0.005747    0.747633    
#> 408: 0.467952    0.959908    3.443393    0.414495    0.098677    0.005745    0.747620    
#> 409: 0.468038    0.959771    3.443374    0.414450    0.098653    0.005742    0.747520    
#> 410: 0.467958    0.959731    3.443340    0.414276    0.098678    0.005738    0.747507    
#> 411: 0.468108    0.959571    3.443316    0.413950    0.098585    0.005742    0.747598    
#> 412: 0.468170    0.959687    3.443281    0.413661    0.098693    0.005742    0.747595    
#> 413: 0.468125    0.959764    3.443230    0.413403    0.098698    0.005740    0.747756    
#> 414: 0.467952    0.959762    3.443222    0.413426    0.098664    0.005738    0.747717    
#> 415: 0.468030    0.959684    3.443213    0.413429    0.098680    0.005740    0.747760    
#> 416: 0.468138    0.959841    3.443208    0.413168    0.098732    0.005740    0.747792    
#> 417: 0.468035    0.959895    3.443185    0.412870    0.098751    0.005741    0.747837    
#> 418: 0.468012    0.959857    3.443181    0.412587    0.098788    0.005744    0.747845    
#> 419: 0.468153    0.959923    3.443174    0.412558    0.098793    0.005747    0.747912    
#> 420: 0.468251    0.959915    3.443179    0.412910    0.098817    0.005744    0.747848    
#> 421: 0.468232    0.959905    3.443226    0.413023    0.098854    0.005745    0.747851    
#> 422: 0.468423    0.959834    3.443236    0.412918    0.098803    0.005739    0.747939    
#> 423: 0.468559    0.959765    3.443261    0.413272    0.098839    0.005732    0.747919    
#> 424: 0.468405    0.959799    3.443219    0.413647    0.098798    0.005724    0.747896    
#> 425: 0.468302    0.959851    3.443200    0.413695    0.098655    0.005721    0.747993    
#> 426: 0.468278    0.960018    3.443167    0.413846    0.098659    0.005713    0.747999    
#> 427: 0.468067    0.959994    3.443151    0.413729    0.098621    0.005706    0.748020    
#> 428: 0.467919    0.960093    3.443098    0.413862    0.098706    0.005697    0.748011    
#> 429: 0.467915    0.960167    3.443083    0.413774    0.098779    0.005687    0.748029    
#> 430: 0.467786    0.960303    3.443018    0.413508    0.098807    0.005683    0.748065    
#> 431: 0.467817    0.960301    3.442973    0.413437    0.098764    0.005680    0.747979    
#> 432: 0.467767    0.960316    3.442966    0.413594    0.098704    0.005679    0.747851    
#> 433: 0.467804    0.960429    3.442970    0.413417    0.098628    0.005684    0.747853    
#> 434: 0.467660    0.960405    3.442982    0.413169    0.098594    0.005685    0.747852    
#> 435: 0.467742    0.960422    3.442971    0.413253    0.098545    0.005689    0.747833    
#> 436: 0.467759    0.960381    3.442963    0.413189    0.098502    0.005688    0.747904    
#> 437: 0.467910    0.960306    3.442953    0.413480    0.098498    0.005688    0.747912    
#> 438: 0.467826    0.960497    3.442937    0.413535    0.098414    0.005682    0.747845    
#> 439: 0.467802    0.960588    3.442888    0.413649    0.098313    0.005675    0.747852    
#> 440: 0.467537    0.960600    3.442893    0.413756    0.098278    0.005666    0.747897    
#> 441: 0.467482    0.960509    3.442921    0.414178    0.098290    0.005665    0.747815    
#> 442: 0.467395    0.960515    3.442947    0.414463    0.098285    0.005669    0.747751    
#> 443: 0.467402    0.960594    3.442950    0.414364    0.098225    0.005673    0.747767    
#> 444: 0.467412    0.960715    3.442906    0.414441    0.098206    0.005679    0.747712    
#> 445: 0.467335    0.960732    3.442861    0.414546    0.098219    0.005684    0.747697    
#> 446: 0.467232    0.960799    3.442817    0.414384    0.098224    0.005685    0.747647    
#> 447: 0.467361    0.960856    3.442776    0.414609    0.098204    0.005688    0.747562    
#> 448: 0.467381    0.960876    3.442766    0.414559    0.098150    0.005693    0.747493    
#> 449: 0.467514    0.960967    3.442857    0.414379    0.098163    0.005695    0.747569    
#> 450: 0.467516    0.960971    3.442916    0.414002    0.098211    0.005695    0.747609    
#> 451: 0.467513    0.961009    3.442923    0.413860    0.098311    0.005688    0.747684    
#> 452: 0.467515    0.960975    3.442908    0.413505    0.098375    0.005683    0.747726    
#> 453: 0.467415    0.961060    3.442851    0.413518    0.098363    0.005675    0.747690    
#> 454: 0.467455    0.961205    3.442808    0.413833    0.098323    0.005664    0.747735    
#> 455: 0.467591    0.961213    3.442762    0.413992    0.098349    0.005661    0.747730    
#> 456: 0.467526    0.961222    3.442750    0.414071    0.098345    0.005657    0.747705    
#> 457: 0.467508    0.961206    3.442767    0.414116    0.098342    0.005650    0.747662    
#> 458: 0.467524    0.961329    3.442773    0.414193    0.098357    0.005645    0.747621    
#> 459: 0.467510    0.961473    3.442780    0.414047    0.098445    0.005642    0.747617    
#> 460: 0.467408    0.961485    3.442766    0.413953    0.098497    0.005641    0.747633    
#> 461: 0.467450    0.961504    3.442789    0.413823    0.098498    0.005641    0.747669    
#> 462: 0.467403    0.961558    3.442822    0.413817    0.098485    0.005640    0.747720    
#> 463: 0.467492    0.961616    3.442849    0.413862    0.098487    0.005638    0.747753    
#> 464: 0.467628    0.961640    3.442869    0.414232    0.098455    0.005641    0.747714    
#> 465: 0.467820    0.961509    3.442866    0.414640    0.098448    0.005635    0.747740    
#> 466: 0.467894    0.961547    3.442853    0.414529    0.098440    0.005630    0.747724    
#> 467: 0.467821    0.961496    3.442868    0.414630    0.098443    0.005627    0.747657    
#> 468: 0.467897    0.961454    3.442901    0.414677    0.098407    0.005629    0.747687    
#> 469: 0.467966    0.961449    3.442953    0.414345    0.098336    0.005626    0.747742    
#> 470: 0.467886    0.961416    3.442935    0.414094    0.098290    0.005625    0.747743    
#> 471: 0.467801    0.961388    3.442909    0.413757    0.098269    0.005618    0.747746    
#> 472: 0.467671    0.961413    3.442906    0.413755    0.098273    0.005613    0.747744    
#> 473: 0.467594    0.961392    3.442890    0.413785    0.098300    0.005610    0.747682    
#> 474: 0.467464    0.961410    3.442849    0.413729    0.098339    0.005614    0.747706    
#> 475: 0.467429    0.961507    3.442819    0.413890    0.098267    0.005624    0.747716    
#> 476: 0.467318    0.961530    3.442762    0.414066    0.098235    0.005637    0.747760    
#> 477: 0.467250    0.961593    3.442738    0.414170    0.098168    0.005644    0.747668    
#> 478: 0.467085    0.961648    3.442715    0.414296    0.098150    0.005647    0.747601    
#> 479: 0.467050    0.961717    3.442689    0.414453    0.098098    0.005652    0.747597    
#> 480: 0.466978    0.961771    3.442706    0.414665    0.098075    0.005653    0.747701    
#> 481: 0.466942    0.961761    3.442721    0.414791    0.098095    0.005655    0.747739    
#> 482: 0.467047    0.961783    3.442726    0.414999    0.098139    0.005655    0.747822    
#> 483: 0.466909    0.961716    3.442729    0.415096    0.098172    0.005658    0.747870    
#> 484: 0.466844    0.961596    3.442746    0.415135    0.098204    0.005659    0.747877    
#> 485: 0.466924    0.961579    3.442773    0.415181    0.098196    0.005658    0.747985    
#> 486: 0.466950    0.961635    3.442754    0.415315    0.098199    0.005654    0.747973    
#> 487: 0.467184    0.961736    3.442817    0.415460    0.098189    0.005651    0.747948    
#> 488: 0.467215    0.961831    3.442870    0.415281    0.098223    0.005646    0.747977    
#> 489: 0.467294    0.961844    3.442902    0.415264    0.098304    0.005642    0.748027    
#> 490: 0.467419    0.961832    3.442951    0.415148    0.098342    0.005640    0.748087    
#> 491: 0.467493    0.961851    3.443015    0.414984    0.098314    0.005645    0.748079    
#> 492: 0.467474    0.961932    3.443048    0.414778    0.098299    0.005651    0.748107    
#> 493: 0.467419    0.961919    3.443065    0.414681    0.098244    0.005652    0.748128    
#> 494: 0.467545    0.961971    3.443054    0.414504    0.098199    0.005648    0.748098    
#> 495: 0.467560    0.961990    3.443052    0.414218    0.098217    0.005647    0.748057    
#> 496: 0.467539    0.962002    3.443030    0.413959    0.098138    0.005643    0.748109    
#> 497: 0.467412    0.962010    3.443011    0.413833    0.098175    0.005643    0.748117    
#> 498: 0.467310    0.961987    3.442986    0.413627    0.098145    0.005642    0.748102    
#> 499: 0.467312    0.961989    3.442977    0.413368    0.098210    0.005634    0.748086    
#> 500: 0.467319    0.961955    3.442982    0.413112    0.098198    0.005630    0.748038    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.276862    0.963110    3.442772    0.392401    0.082618    0.016800    1.625740    
#> 002: 0.174057    0.975732    3.480638    0.372781    0.078487    0.015960    1.025434    
#> 003: 0.198178    0.939341    3.490411    0.354142    0.082780    0.015162    0.765062    
#> 004: 0.171537    0.972482    3.481355    0.336435    0.078641    0.014404    0.669190    
#> 005: 0.219392    0.988445    3.471006    0.319613    0.074709    0.013684    0.664856    
#> 006: 0.151168    0.991140    3.462856    0.303633    0.070973    0.013000    0.613562    
#> 007: 0.105070    1.002967    3.445105    0.288451    0.067425    0.012557    0.613010    
#> 008: 0.112484    1.021849    3.437652    0.274029    0.064053    0.017968    0.596359    
#> 009: 0.110905    0.995126    3.443777    0.260327    0.060851    0.017777    0.611620    
#> 010: 0.105940    1.003418    3.437615    0.247311    0.057808    0.017403    0.616221    
#> 011: 0.134192    1.033418    3.438937    0.239450    0.062559    0.018668    0.614083    
#> 012: 0.146196    1.025657    3.439932    0.227477    0.059431    0.018895    0.606848    
#> 013: 0.101538    1.020971    3.435755    0.216103    0.056460    0.022010    0.589733    
#> 014: 0.138344    1.008866    3.447941    0.205298    0.053637    0.020910    0.593488    
#> 015: 0.127402    1.021197    3.443022    0.195033    0.059969    0.019864    0.573729    
#> 016: 0.127523    1.035848    3.447540    0.209938    0.056970    0.022412    0.578746    
#> 017: 0.127509    1.036092    3.448395    0.199441    0.056758    0.021291    0.583418    
#> 018: 0.110811    1.023053    3.433620    0.189469    0.063778    0.020227    0.587597    
#> 019: 0.074384    1.023423    3.432221    0.198764    0.060589    0.019731    0.597311    
#> 020: 0.107420    1.025891    3.447188    0.192145    0.057559    0.020824    0.601611    
#> 021: 0.105403    1.023217    3.443901    0.182537    0.054681    0.019783    0.596330    
#> 022: 0.093528    1.031057    3.452809    0.173411    0.051947    0.019828    0.589619    
#> 023: 0.174224    1.019513    3.463348    0.172872    0.049350    0.018837    0.614282    
#> 024: 0.184804    1.032817    3.465642    0.188097    0.046882    0.017895    0.604322    
#> 025: 0.164740    0.999970    3.453476    0.184618    0.044538    0.023714    0.619575    
#> 026: 0.123558    1.018584    3.442703    0.181860    0.044128    0.027765    0.609966    
#> 027: 0.090941    1.039848    3.424300    0.194204    0.041921    0.029617    0.611991    
#> 028: 0.128623    1.031234    3.444826    0.184493    0.039825    0.031518    0.589847    
#> 029: 0.119075    1.038180    3.435605    0.175269    0.045727    0.029943    0.608945    
#> 030: 0.126320    1.048379    3.423082    0.166505    0.053658    0.028445    0.601595    
#> 031: 0.107906    1.027947    3.441379    0.169474    0.051243    0.027023    0.591406    
#> 032: 0.134814    1.012309    3.459496    0.164869    0.048681    0.025672    0.591637    
#> 033: 0.124950    1.030437    3.446104    0.177984    0.046247    0.024388    0.612061    
#> 034: 0.156912    1.026494    3.457252    0.210093    0.049883    0.023169    0.606154    
#> 035: 0.122445    1.008673    3.440112    0.209530    0.047389    0.022011    0.587197    
#> 036: 0.128442    1.021564    3.440071    0.199053    0.048561    0.020910    0.599089    
#> 037: 0.115558    1.026829    3.450383    0.212235    0.046133    0.019865    0.606036    
#> 038: 0.136455    1.029273    3.438616    0.201623    0.043826    0.020307    0.614160    
#> 039: 0.122794    1.024961    3.451532    0.191542    0.043479    0.025086    0.583717    
#> 040: 0.138272    1.022269    3.466645    0.182667    0.041305    0.024466    0.606747    
#> 041: 0.107487    1.032849    3.443938    0.173534    0.045064    0.023998    0.609379    
#> 042: 0.157864    1.022053    3.451493    0.173820    0.047335    0.025634    0.586127    
#> 043: 0.103606    1.028609    3.435704    0.165129    0.044969    0.024352    0.604484    
#> 044: 0.093662    1.020747    3.445047    0.156872    0.042720    0.023135    0.601391    
#> 045: 0.109176    1.035552    3.434089    0.177080    0.045321    0.022863    0.585993    
#> 046: 0.105178    1.034279    3.438693    0.173947    0.045784    0.021720    0.592758    
#> 047: 0.098902    1.045571    3.433867    0.195962    0.043495    0.020634    0.585139    
#> 048: 0.105432    1.035761    3.432011    0.211963    0.041320    0.019602    0.589712    
#> 049: 0.108162    1.031924    3.443287    0.201364    0.046473    0.019893    0.590337    
#> 050: 0.153826    1.012300    3.459733    0.191296    0.051593    0.022288    0.592897    
#> 051: 0.158467    1.014435    3.456154    0.188686    0.049014    0.025432    0.597764    
#> 052: 0.158569    1.022518    3.450869    0.184388    0.046563    0.024160    0.589307    
#> 053: 0.128639    1.004133    3.448742    0.237435    0.044235    0.022952    0.596631    
#> 054: 0.134245    1.019406    3.449831    0.225563    0.060188    0.021804    0.599732    
#> 055: 0.127338    1.026467    3.450115    0.214285    0.057306    0.020714    0.609455    
#> 056: 0.149492    1.001354    3.452448    0.203571    0.062731    0.019679    0.595272    
#> 057: 0.152995    1.004235    3.463343    0.193392    0.059595    0.019251    0.609788    
#> 058: 0.161448    1.016687    3.450399    0.183723    0.056615    0.018289    0.608914    
#> 059: 0.128073    0.991429    3.448618    0.174537    0.053784    0.017374    0.610841    
#> 060: 0.106384    1.022344    3.441153    0.171151    0.051095    0.017130    0.614776    
#> 061: 0.164492    1.022803    3.457175    0.210041    0.059135    0.018063    0.608573    
#> 062: 0.173510    1.042124    3.465497    0.208619    0.077798    0.019993    0.612660    
#> 063: 0.168574    1.009043    3.454135    0.198709    0.073908    0.025499    0.607549    
#> 064: 0.143567    1.021045    3.460460    0.188773    0.070213    0.024224    0.618644    
#> 065: 0.137684    0.999904    3.443480    0.186399    0.066702    0.023013    0.612281    
#> 066: 0.151939    1.015803    3.455334    0.195551    0.063367    0.021941    0.589391    
#> 067: 0.147744    1.004389    3.450619    0.198729    0.060198    0.026801    0.584927    
#> 068: 0.098073    1.026711    3.449803    0.194158    0.057189    0.027099    0.590862    
#> 069: 0.129704    1.033870    3.445234    0.187574    0.054329    0.025744    0.603386    
#> 070: 0.126789    1.022904    3.450890    0.195000    0.054667    0.024457    0.610259    
#> 071: 0.122049    1.024517    3.442149    0.188792    0.059380    0.023234    0.601665    
#> 072: 0.108509    1.003036    3.460289    0.179353    0.057690    0.022072    0.605092    
#> 073: 0.169665    1.011445    3.478357    0.170385    0.054805    0.020969    0.605444    
#> 074: 0.147694    1.005078    3.456352    0.161866    0.052776    0.019920    0.596721    
#> 075: 0.162950    0.985113    3.484240    0.153772    0.053658    0.018924    0.598775    
#> 076: 0.159852    1.013479    3.474825    0.167887    0.053304    0.019675    0.591357    
#> 077: 0.197826    0.997025    3.478403    0.176955    0.050639    0.018691    0.605771    
#> 078: 0.188967    0.987844    3.479528    0.174235    0.048107    0.019322    0.587422    
#> 079: 0.161901    0.997593    3.468231    0.165524    0.045702    0.022659    0.603880    
#> 080: 0.174933    0.987626    3.475068    0.192399    0.050034    0.023814    0.610563    
#> 081: 0.158574    0.995975    3.464982    0.182779    0.047532    0.024306    0.594937    
#> 082: 0.147685    0.994954    3.467895    0.173640    0.045156    0.023090    0.601741    
#> 083: 0.163361    1.028817    3.462020    0.180532    0.046339    0.021936    0.588290    
#> 084: 0.161810    1.026841    3.455847    0.175102    0.044022    0.020839    0.598773    
#> 085: 0.134360    1.037199    3.459311    0.179221    0.047284    0.019797    0.611265    
#> 086: 0.143728    1.031764    3.455556    0.175617    0.056058    0.018807    0.575183    
#> 087: 0.128328    1.033802    3.441014    0.179702    0.063543    0.018102    0.586172    
#> 088: 0.080074    1.034618    3.438786    0.222213    0.060366    0.021446    0.593268    
#> 089: 0.082394    1.036494    3.417989    0.219452    0.059473    0.020373    0.597621    
#> 090: 0.093266    1.032683    3.419898    0.215909    0.056499    0.019563    0.601958    
#> 091: 0.057473    1.026925    3.408999    0.205113    0.053675    0.018585    0.603742    
#> 092: 0.084674    1.038165    3.413953    0.199366    0.055566    0.019400    0.620616    
#> 093: 0.031585    1.044028    3.403819    0.189397    0.063887    0.018430    0.638479    
#> 094: 0.035929    1.044442    3.407989    0.189580    0.061040    0.018301    0.630566    
#> 095: 0.058635    1.075100    3.410316    0.211058    0.061597    0.017386    0.613112    
#> 096: 0.055027    1.054590    3.417940    0.216060    0.058517    0.020389    0.611169    
#> 097: 0.102731    1.047048    3.420594    0.205257    0.055591    0.019370    0.600505    
#> 098: 0.063603    1.060328    3.424066    0.199993    0.052812    0.020664    0.605269    
#> 099: 0.062249    1.039801    3.411419    0.189994    0.050171    0.019631    0.611386    
#> 100: 0.072400    1.046359    3.416128    0.180494    0.047662    0.021651    0.594822    
#> 101: 0.076104    1.034169    3.413058    0.171469    0.060192    0.021023    0.608500    
#> 102: 0.058713    1.046437    3.409202    0.178860    0.060594    0.021927    0.600833    
#> 103: 0.069705    1.047755    3.425562    0.190227    0.057564    0.020975    0.593226    
#> 104: 0.104906    1.039353    3.439109    0.200126    0.054686    0.020246    0.599583    
#> 105: 0.150826    1.038220    3.441209    0.239991    0.064456    0.020615    0.594768    
#> 106: 0.126762    1.031240    3.436717    0.227992    0.065033    0.019584    0.590642    
#> 107: 0.138607    1.034160    3.445399    0.216592    0.061781    0.018605    0.596343    
#> 108: 0.138749    1.025227    3.451122    0.205763    0.058692    0.017912    0.611589    
#> 109: 0.131832    1.022363    3.459938    0.195475    0.055757    0.017017    0.607968    
#> 110: 0.142670    1.024129    3.444250    0.185701    0.063931    0.016166    0.604288    
#> 111: 0.143383    1.018020    3.450783    0.176416    0.061669    0.015358    0.600043    
#> 112: 0.117480    1.014724    3.438670    0.167595    0.058586    0.014590    0.616459    
#> 113: 0.109154    1.034649    3.437561    0.183271    0.060015    0.013860    0.581860    
#> 114: 0.119613    1.031050    3.443476    0.174108    0.063166    0.014547    0.595508    
#> 115: 0.133048    1.005022    3.441529    0.165402    0.060007    0.013819    0.613272    
#> 116: 0.107342    1.029169    3.434435    0.163905    0.058707    0.013128    0.617942    
#> 117: 0.109298    1.045720    3.435498    0.168967    0.071233    0.012472    0.598598    
#> 118: 0.121305    1.023396    3.443205    0.162176    0.067672    0.014240    0.594883    
#> 119: 0.107750    1.045360    3.443002    0.173199    0.064288    0.020661    0.594476    
#> 120: 0.086279    1.028982    3.442981    0.164539    0.061074    0.019628    0.587745    
#> 121: 0.097125    1.065352    3.429990    0.164089    0.058020    0.019081    0.592719    
#> 122: 0.112959    1.047729    3.433252    0.212649    0.063023    0.021034    0.574857    
#> 123: 0.121483    1.059685    3.424661    0.241440    0.059872    0.019982    0.582440    
#> 124: 0.127533    1.067299    3.431188    0.249090    0.056878    0.023839    0.594193    
#> 125: 0.112753    1.049932    3.418171    0.236636    0.054034    0.022647    0.586255    
#> 126: 0.111540    1.028787    3.424599    0.224804    0.051333    0.023764    0.603800    
#> 127: 0.120283    1.026509    3.429438    0.218907    0.048766    0.022576    0.612558    
#> 128: 0.080504    1.037721    3.443182    0.207962    0.051391    0.021447    0.611931    
#> 129: 0.125606    1.046021    3.442776    0.197564    0.061564    0.020375    0.612069    
#> 130: 0.153182    1.053429    3.445169    0.191402    0.058486    0.021184    0.584110    
#> 131: 0.121243    1.027043    3.435998    0.188946    0.055562    0.020125    0.581846    
#> 132: 0.101513    1.032368    3.424566    0.179498    0.061015    0.019118    0.592625    
#> 133: 0.105657    1.031168    3.433439    0.193043    0.057964    0.018974    0.583658    
#> 134: 0.124261    1.021238    3.442744    0.183391    0.055066    0.021365    0.596752    
#> 135: 0.092637    1.041026    3.433615    0.175997    0.052313    0.023162    0.584239    
#> 136: 0.112561    1.020020    3.443755    0.194350    0.049697    0.022003    0.583092    
#> 137: 0.141725    1.002611    3.452136    0.193804    0.047212    0.020903    0.604420    
#> 138: 0.119187    1.019056    3.445614    0.197870    0.044852    0.021538    0.591103    
#> 139: 0.128448    1.027503    3.451080    0.192968    0.042609    0.027428    0.606851    
#> 140: 0.122713    1.029583    3.449463    0.183319    0.047368    0.026056    0.618277    
#> 141: 0.114742    1.010101    3.456180    0.174153    0.046524    0.024754    0.597713    
#> 142: 0.140235    1.014383    3.466497    0.165446    0.054861    0.023516    0.600803    
#> 143: 0.130404    1.008319    3.460307    0.157173    0.052118    0.022340    0.613976    
#> 144: 0.169552    1.023030    3.468901    0.169246    0.049512    0.021223    0.592163    
#> 145: 0.137393    1.032123    3.443288    0.186516    0.047172    0.020162    0.579630    
#> 146: 0.143364    1.019175    3.457945    0.197901    0.044813    0.019478    0.599970    
#> 147: 0.109880    1.020131    3.445688    0.224383    0.046835    0.019723    0.577426    
#> 148: 0.099368    1.020417    3.453487    0.213163    0.050343    0.018889    0.581398    
#> 149: 0.123524    1.029583    3.440442    0.202505    0.070870    0.017944    0.595503    
#> 150: 0.120505    1.027537    3.428942    0.192380    0.070859    0.017047    0.591556    
#> 151: 0.083878    1.059563    3.425986    0.182761    0.067316    0.016195    0.598628    
#> 152: 0.084230    1.050303    3.424222    0.206743    0.054884    0.018592    0.588834    
#> 153: 0.101280    1.051466    3.439955    0.190974    0.052070    0.017224    0.586933    
#> 154: 0.151637    1.044455    3.440024    0.203282    0.045091    0.015668    0.603054    
#> 155: 0.119157    1.025371    3.439492    0.157911    0.057116    0.016627    0.582547    
#> 156: 0.112679    1.034561    3.443272    0.162669    0.063495    0.015887    0.606149    
#> 157: 0.100389    1.026060    3.448592    0.142282    0.057187    0.014611    0.614455    
#> 158: 0.124420    1.039142    3.445171    0.151249    0.060859    0.016611    0.587527    
#> 159: 0.094063    1.033500    3.446070    0.176566    0.053752    0.014880    0.583867    
#> 160: 0.126772    1.003028    3.456835    0.180103    0.064185    0.014891    0.602620    
#> 161: 0.134720    1.018830    3.449758    0.181509    0.056860    0.016142    0.604474    
#> 162: 0.141729    1.036199    3.447031    0.146985    0.059876    0.014010    0.607841    
#> 163: 0.143431    1.030871    3.435869    0.165245    0.052889    0.013528    0.611273    
#> 164: 0.125423    1.034391    3.440240    0.184468    0.049571    0.014914    0.609692    
#> 165: 0.163617    1.013338    3.456348    0.176806    0.047249    0.017420    0.597747    
#> 166: 0.165772    1.029115    3.461729    0.165464    0.044973    0.016999    0.598343    
#> 167: 0.174697    1.037744    3.463935    0.188807    0.045779    0.016853    0.615433    
#> 168: 0.149295    1.038393    3.456320    0.195738    0.049006    0.020246    0.595921    
#> 169: 0.140292    1.053575    3.447932    0.167910    0.056693    0.018819    0.610397    
#> 170: 0.131264    1.029831    3.450881    0.196988    0.048494    0.016484    0.591205    
#> 171: 0.132628    1.019872    3.451892    0.172584    0.053849    0.018869    0.573159    
#> 172: 0.129310    1.030909    3.448486    0.181990    0.044909    0.020536    0.580103    
#> 173: 0.130517    1.039460    3.433515    0.206074    0.050611    0.023425    0.564128    
#> 174: 0.113784    1.027765    3.445772    0.197685    0.047303    0.023800    0.580934    
#> 175: 0.120164    1.028995    3.434487    0.187185    0.043810    0.022713    0.585232    
#> 176: 0.086274    1.038540    3.437341    0.205668    0.051357    0.021743    0.588218    
#> 177: 0.106228    1.026906    3.444738    0.152969    0.046840    0.021654    0.596751    
#> 178: 0.126398    1.011981    3.452559    0.161205    0.046962    0.019625    0.594454    
#> 179: 0.142304    1.016613    3.449374    0.171852    0.055034    0.019133    0.602866    
#> 180: 0.146028    1.018224    3.455990    0.171652    0.049199    0.020404    0.603001    
#> 181: 0.143157    1.005671    3.442007    0.177962    0.052825    0.023105    0.604513    
#> 182: 0.123803    1.014747    3.434604    0.176048    0.046649    0.024015    0.617675    
#> 183: 0.116027    1.048564    3.436334    0.175548    0.048699    0.022906    0.630618    
#> 184: 0.136367    1.022398    3.444361    0.164094    0.043196    0.021846    0.610049    
#> 185: 0.118849    1.015596    3.445051    0.175137    0.039653    0.024736    0.596936    
#> 186: 0.113584    1.019879    3.451785    0.152580    0.045660    0.027708    0.588348    
#> 187: 0.123952    1.006163    3.454518    0.155152    0.042919    0.028224    0.601895    
#> 188: 0.095660    1.036325    3.449795    0.158864    0.044609    0.025130    0.616759    
#> 189: 0.148599    1.043674    3.451182    0.193759    0.041277    0.025470    0.597828    
#> 190: 0.122308    1.026047    3.453477    0.174117    0.034931    0.022755    0.594787    
#> 191: 0.122678    1.028618    3.446268    0.180394    0.039008    0.019131    0.587107    
#> 192: 0.114915    1.029738    3.446538    0.201724    0.040447    0.018402    0.589867    
#> 193: 0.125898    1.036699    3.447922    0.188204    0.055112    0.017749    0.575836    
#> 194: 0.121707    1.036957    3.432158    0.197352    0.055272    0.014479    0.598202    
#> 195: 0.094497    1.025253    3.435811    0.165890    0.047266    0.014833    0.589330    
#> 196: 0.129660    1.036811    3.440919    0.145869    0.051003    0.014437    0.609575    
#> 197: 0.101738    1.043454    3.460050    0.169830    0.047147    0.018052    0.606498    
#> 198: 0.136899    1.023855    3.449010    0.171453    0.042434    0.018712    0.582141    
#> 199: 0.143090    1.013835    3.449867    0.203124    0.056304    0.017265    0.585093    
#> 200: 0.123291    1.027339    3.444656    0.177022    0.066306    0.018699    0.594920    
#> 201: 0.111945    1.028089    3.446718    0.169100    0.057903    0.022876    0.591929    
#> 202: 0.106388    1.031730    3.444162    0.181757    0.051752    0.023264    0.589299    
#> 203: 0.117173    1.029571    3.442624    0.181512    0.049463    0.022940    0.588749    
#> 204: 0.124454    1.021801    3.447464    0.180809    0.048150    0.022871    0.591027    
#> 205: 0.126235    1.024935    3.450247    0.177670    0.047333    0.022553    0.596111    
#> 206: 0.127087    1.028759    3.450610    0.179875    0.047808    0.022540    0.596561    
#> 207: 0.123541    1.028235    3.449804    0.178281    0.047885    0.022487    0.597143    
#> 208: 0.120949    1.028877    3.448931    0.178303    0.047198    0.022521    0.596746    
#> 209: 0.122769    1.028017    3.449189    0.177731    0.047233    0.022739    0.595645    
#> 210: 0.124205    1.027550    3.449601    0.176713    0.047423    0.022648    0.594719    
#> 211: 0.126480    1.027702    3.450594    0.175527    0.047095    0.022750    0.593517    
#> 212: 0.128383    1.026534    3.451279    0.176590    0.046990    0.022728    0.593754    
#> 213: 0.129097    1.024231    3.452010    0.179200    0.046662    0.022857    0.595430    
#> 214: 0.130653    1.023135    3.452573    0.180953    0.046857    0.023057    0.594880    
#> 215: 0.131361    1.022349    3.453149    0.184034    0.046505    0.023033    0.595450    
#> 216: 0.133966    1.021213    3.453838    0.184811    0.046723    0.022746    0.596505    
#> 217: 0.134020    1.021551    3.453383    0.185967    0.047002    0.022329    0.596536    
#> 218: 0.134377    1.021933    3.453015    0.188006    0.046830    0.022067    0.596533    
#> 219: 0.132987    1.021771    3.451886    0.188468    0.046731    0.021862    0.596589    
#> 220: 0.131052    1.022253    3.451443    0.188148    0.046606    0.021815    0.596331    
#> 221: 0.129631    1.022388    3.450799    0.188207    0.046443    0.021693    0.596019    
#> 222: 0.128872    1.022647    3.450040    0.187976    0.046709    0.021449    0.595895    
#> 223: 0.128749    1.022813    3.449839    0.187643    0.046734    0.021389    0.594904    
#> 224: 0.130163    1.023498    3.449952    0.187773    0.046676    0.021489    0.594986    
#> 225: 0.130272    1.022488    3.450170    0.187382    0.046374    0.021469    0.595127    
#> 226: 0.130855    1.022080    3.450292    0.187030    0.046144    0.021397    0.594958    
#> 227: 0.130637    1.022100    3.450047    0.185583    0.046147    0.021320    0.595376    
#> 228: 0.129586    1.023733    3.449361    0.185143    0.046735    0.021322    0.595733    
#> 229: 0.128801    1.024100    3.448954    0.184660    0.046903    0.021218    0.595546    
#> 230: 0.128908    1.024306    3.448509    0.184949    0.047037    0.021117    0.595359    
#> 231: 0.128969    1.024682    3.448717    0.184970    0.047098    0.021210    0.595503    
#> 232: 0.128639    1.024630    3.448797    0.185367    0.047154    0.021225    0.595228    
#> 233: 0.128542    1.024233    3.448870    0.184920    0.047144    0.021128    0.595325    
#> 234: 0.127494    1.023729    3.448778    0.183890    0.047156    0.021200    0.595359    
#> 235: 0.127301    1.023354    3.448769    0.182455    0.046950    0.021087    0.595830    
#> 236: 0.126742    1.023778    3.448464    0.181331    0.047007    0.020960    0.596119    
#> 237: 0.126648    1.023732    3.448399    0.181127    0.047223    0.020864    0.596321    
#> 238: 0.127500    1.024056    3.448272    0.181249    0.047429    0.020782    0.596906    
#> 239: 0.126737    1.024524    3.447738    0.180771    0.047578    0.020748    0.596969    
#> 240: 0.126543    1.024335    3.447744    0.179840    0.047775    0.020789    0.597180    
#> 241: 0.126551    1.023571    3.447812    0.179125    0.047781    0.020786    0.597605    
#> 242: 0.126722    1.023195    3.447733    0.179097    0.047609    0.020773    0.598162    
#> 243: 0.126315    1.023428    3.447711    0.179250    0.047669    0.020740    0.598632    
#> 244: 0.126382    1.023270    3.447770    0.179903    0.047826    0.020669    0.598885    
#> 245: 0.127408    1.022530    3.448115    0.180494    0.048179    0.020536    0.599493    
#> 246: 0.127931    1.022417    3.448252    0.180271    0.048391    0.020429    0.599665    
#> 247: 0.128332    1.022330    3.448350    0.180074    0.048692    0.020300    0.599860    
#> 248: 0.128084    1.022576    3.448203    0.179956    0.048700    0.020249    0.599954    
#> 249: 0.127799    1.022696    3.448360    0.179445    0.048666    0.020257    0.599948    
#> 250: 0.128628    1.022677    3.448543    0.179392    0.048642    0.020319    0.599831    
#> 251: 0.128796    1.022739    3.448773    0.179386    0.048642    0.020359    0.599871    
#> 252: 0.128960    1.022688    3.449098    0.178991    0.048600    0.020396    0.599838    
#> 253: 0.129056    1.022870    3.449348    0.178864    0.048660    0.020399    0.599849    
#> 254: 0.129245    1.023214    3.449285    0.178788    0.048860    0.020397    0.599710    
#> 255: 0.128772    1.023497    3.449156    0.179117    0.048910    0.020451    0.599314    
#> 256: 0.128667    1.023628    3.448991    0.179256    0.048960    0.020431    0.599154    
#> 257: 0.128527    1.023464    3.448950    0.179073    0.048914    0.020354    0.599279    
#> 258: 0.128211    1.023313    3.448828    0.179973    0.048838    0.020304    0.599380    
#> 259: 0.127837    1.023392    3.448562    0.180395    0.048976    0.020329    0.599462    
#> 260: 0.127615    1.023583    3.448593    0.180834    0.048988    0.020341    0.599157    
#> 261: 0.127733    1.023535    3.448789    0.181190    0.049050    0.020353    0.599004    
#> 262: 0.128152    1.023691    3.449028    0.181168    0.049214    0.020339    0.599011    
#> 263: 0.128237    1.023901    3.449021    0.180913    0.049313    0.020319    0.598981    
#> 264: 0.128031    1.023963    3.448887    0.180546    0.049511    0.020303    0.599297    
#> 265: 0.128026    1.023788    3.448937    0.180603    0.049669    0.020303    0.599454    
#> 266: 0.128169    1.023846    3.449025    0.180444    0.049653    0.020283    0.599497    
#> 267: 0.128580    1.023712    3.449350    0.180360    0.049785    0.020280    0.599444    
#> 268: 0.128956    1.023105    3.449443    0.180562    0.049747    0.020275    0.599561    
#> 269: 0.129990    1.022744    3.449715    0.180516    0.049897    0.020280    0.599788    
#> 270: 0.130454    1.022604    3.449838    0.180523    0.049949    0.020228    0.599744    
#> 271: 0.130569    1.022734    3.449753    0.180513    0.049983    0.020245    0.599819    
#> 272: 0.130674    1.022694    3.449674    0.180203    0.049997    0.020231    0.600072    
#> 273: 0.130675    1.023046    3.449719    0.180143    0.050185    0.020227    0.600185    
#> 274: 0.130517    1.023302    3.449792    0.179963    0.050122    0.020212    0.600224    
#> 275: 0.130486    1.023521    3.449688    0.179774    0.050150    0.020198    0.600432    
#> 276: 0.130493    1.023671    3.449691    0.180189    0.050225    0.020232    0.600333    
#> 277: 0.130339    1.023848    3.449654    0.180279    0.050243    0.020226    0.600416    
#> 278: 0.130168    1.024085    3.449613    0.180049    0.050148    0.020216    0.600417    
#> 279: 0.129913    1.024149    3.449603    0.180182    0.050187    0.020218    0.600519    
#> 280: 0.129747    1.024334    3.449485    0.180077    0.050188    0.020177    0.600456    
#> 281: 0.129373    1.024590    3.449433    0.180083    0.050152    0.020179    0.600454    
#> 282: 0.129234    1.024750    3.449491    0.179750    0.050301    0.020110    0.600434    
#> 283: 0.129183    1.024802    3.449501    0.179721    0.050288    0.020052    0.600508    
#> 284: 0.129208    1.024712    3.449488    0.179677    0.050342    0.019986    0.600613    
#> 285: 0.128854    1.024770    3.449309    0.179192    0.050458    0.019902    0.600747    
#> 286: 0.128658    1.024748    3.449206    0.178709    0.050776    0.019818    0.600766    
#> 287: 0.128554    1.024975    3.449090    0.178209    0.051005    0.019725    0.600794    
#> 288: 0.128720    1.025015    3.449110    0.177736    0.051155    0.019676    0.601226    
#> 289: 0.128737    1.024987    3.449088    0.177347    0.051280    0.019657    0.601502    
#> 290: 0.128932    1.024939    3.449123    0.177093    0.051373    0.019610    0.601709    
#> 291: 0.129131    1.025007    3.449250    0.176958    0.051508    0.019573    0.601488    
#> 292: 0.129123    1.025178    3.449151    0.176729    0.051553    0.019534    0.601329    
#> 293: 0.128727    1.025334    3.448906    0.176727    0.051585    0.019525    0.601240    
#> 294: 0.128255    1.025599    3.448657    0.177070    0.051580    0.019518    0.601253    
#> 295: 0.127990    1.025477    3.448573    0.177169    0.051606    0.019495    0.601139    
#> 296: 0.127765    1.025407    3.448472    0.177095    0.051567    0.019490    0.601156    
#> 297: 0.127923    1.025442    3.448538    0.177181    0.051515    0.019490    0.601030    
#> 298: 0.128059    1.025251    3.448581    0.177263    0.051473    0.019474    0.600781    
#> 299: 0.128131    1.025205    3.448593    0.177203    0.051342    0.019503    0.600735    
#> 300: 0.128222    1.025020    3.448639    0.177290    0.051290    0.019509    0.600667    
#> 301: 0.128516    1.024890    3.448573    0.177582    0.051282    0.019528    0.600670    
#> 302: 0.128511    1.025029    3.448542    0.177628    0.051267    0.019537    0.600512    
#> 303: 0.128330    1.025134    3.448446    0.177521    0.051245    0.019596    0.600311    
#> 304: 0.128294    1.025397    3.448319    0.177781    0.051193    0.019646    0.600261    
#> 305: 0.128092    1.025287    3.448203    0.177758    0.051178    0.019658    0.600201    
#> 306: 0.127637    1.025138    3.448020    0.177958    0.051122    0.019662    0.600237    
#> 307: 0.127543    1.025058    3.447912    0.178221    0.051180    0.019679    0.600273    
#> 308: 0.127441    1.025039    3.447871    0.178578    0.051123    0.019665    0.600159    
#> 309: 0.127457    1.024856    3.447813    0.178944    0.051139    0.019673    0.600171    
#> 310: 0.127527    1.024782    3.447681    0.178886    0.051110    0.019653    0.600253    
#> 311: 0.127221    1.024830    3.447502    0.179189    0.051139    0.019635    0.600117    
#> 312: 0.126970    1.024793    3.447348    0.179414    0.051140    0.019648    0.600046    
#> 313: 0.126798    1.024548    3.447195    0.179757    0.051061    0.019643    0.600170    
#> 314: 0.126361    1.024647    3.447026    0.179762    0.051069    0.019637    0.600205    
#> 315: 0.125825    1.024802    3.446883    0.179760    0.051064    0.019615    0.600167    
#> 316: 0.125669    1.024984    3.446815    0.179621    0.051120    0.019602    0.600140    
#> 317: 0.125812    1.024966    3.446820    0.179820    0.051066    0.019604    0.600251    
#> 318: 0.125863    1.025086    3.446813    0.179654    0.051033    0.019600    0.600201    
#> 319: 0.125698    1.025051    3.446819    0.179467    0.051048    0.019603    0.600191    
#> 320: 0.125220    1.025102    3.446686    0.179131    0.051088    0.019599    0.600273    
#> 321: 0.125019    1.025127    3.446561    0.178740    0.051075    0.019577    0.600403    
#> 322: 0.124709    1.025343    3.446400    0.178498    0.051070    0.019547    0.600472    
#> 323: 0.124001    1.025539    3.446256    0.178480    0.051042    0.019532    0.600568    
#> 324: 0.123652    1.025640    3.446160    0.178539    0.051086    0.019508    0.600470    
#> 325: 0.123395    1.025825    3.445992    0.178436    0.051111    0.019517    0.600403    
#> 326: 0.123215    1.025731    3.445883    0.178296    0.051091    0.019529    0.600524    
#> 327: 0.123130    1.025733    3.445878    0.178120    0.051148    0.019542    0.600645    
#> 328: 0.123313    1.025758    3.445952    0.178214    0.051145    0.019529    0.600601    
#> 329: 0.123506    1.025909    3.445939    0.178213    0.051123    0.019497    0.600538    
#> 330: 0.123438    1.025940    3.446042    0.178259    0.051101    0.019516    0.600396    
#> 331: 0.123533    1.026093    3.446082    0.178146    0.051097    0.019531    0.600304    
#> 332: 0.123751    1.026094    3.446201    0.177942    0.051072    0.019534    0.600461    
#> 333: 0.123570    1.026034    3.446138    0.177796    0.051071    0.019516    0.600546    
#> 334: 0.123381    1.026007    3.446009    0.178038    0.051011    0.019527    0.600458    
#> 335: 0.123237    1.026152    3.445896    0.178129    0.050962    0.019548    0.600501    
#> 336: 0.122981    1.026301    3.445816    0.178186    0.050966    0.019572    0.600485    
#> 337: 0.122759    1.026646    3.445692    0.178148    0.051044    0.019572    0.600507    
#> 338: 0.122535    1.026811    3.445590    0.178152    0.051165    0.019534    0.600472    
#> 339: 0.122354    1.027020    3.445447    0.178255    0.051261    0.019497    0.600401    
#> 340: 0.122150    1.027028    3.445329    0.178094    0.051401    0.019442    0.600417    
#> 341: 0.122131    1.027119    3.445282    0.177874    0.051477    0.019394    0.600394    
#> 342: 0.121939    1.027056    3.445266    0.177659    0.051521    0.019343    0.600367    
#> 343: 0.121718    1.027052    3.445250    0.177573    0.051544    0.019304    0.600366    
#> 344: 0.121806    1.027070    3.445308    0.177426    0.051526    0.019277    0.600307    
#> 345: 0.121837    1.027050    3.445345    0.177217    0.051529    0.019244    0.600366    
#> 346: 0.121779    1.026992    3.445330    0.177270    0.051572    0.019208    0.600230    
#> 347: 0.121911    1.026886    3.445307    0.177382    0.051586    0.019207    0.600095    
#> 348: 0.121814    1.026890    3.445290    0.177305    0.051595    0.019183    0.600062    
#> 349: 0.121749    1.026834    3.445266    0.177327    0.051564    0.019166    0.600069    
#> 350: 0.121569    1.026797    3.445205    0.177318    0.051555    0.019149    0.600017    
#> 351: 0.121646    1.026923    3.445141    0.177133    0.051544    0.019128    0.599988    
#> 352: 0.121426    1.027044    3.445090    0.176988    0.051555    0.019122    0.600013    
#> 353: 0.121333    1.027199    3.444987    0.176994    0.051492    0.019132    0.599875    
#> 354: 0.121320    1.027256    3.444876    0.177041    0.051412    0.019140    0.599743    
#> 355: 0.121572    1.027122    3.444900    0.177139    0.051364    0.019139    0.599678    
#> 356: 0.121670    1.027022    3.444906    0.177127    0.051396    0.019130    0.599791    
#> 357: 0.121806    1.027011    3.444920    0.177020    0.051395    0.019121    0.599720    
#> 358: 0.121879    1.026996    3.445026    0.176967    0.051360    0.019140    0.599632    
#> 359: 0.121837    1.027042    3.445059    0.176986    0.051379    0.019144    0.599514    
#> 360: 0.121913    1.027017    3.445048    0.177043    0.051366    0.019155    0.599375    
#> 361: 0.121862    1.026887    3.445062    0.176971    0.051351    0.019176    0.599293    
#> 362: 0.121912    1.026799    3.445077    0.176815    0.051330    0.019215    0.599123    
#> 363: 0.121819    1.026791    3.445025    0.176923    0.051280    0.019229    0.598946    
#> 364: 0.121936    1.026828    3.444994    0.177123    0.051265    0.019263    0.598926    
#> 365: 0.121763    1.026726    3.445005    0.177133    0.051232    0.019306    0.598981    
#> 366: 0.121620    1.026684    3.444946    0.177022    0.051224    0.019323    0.598969    
#> 367: 0.121660    1.026584    3.444960    0.176913    0.051230    0.019326    0.598883    
#> 368: 0.121835    1.026589    3.444948    0.176748    0.051151    0.019345    0.598869    
#> 369: 0.121841    1.026519    3.444913    0.176692    0.051165    0.019333    0.598917    
#> 370: 0.121921    1.026408    3.444970    0.176517    0.051181    0.019350    0.598933    
#> 371: 0.121871    1.026445    3.444882    0.176297    0.051278    0.019323    0.598878    
#> 372: 0.121679    1.026538    3.444797    0.176151    0.051352    0.019295    0.598847    
#> 373: 0.121501    1.026692    3.444699    0.176249    0.051358    0.019275    0.598857    
#> 374: 0.121489    1.026766    3.444637    0.176255    0.051313    0.019271    0.598790    
#> 375: 0.121428    1.026783    3.444629    0.176369    0.051298    0.019275    0.598739    
#> 376: 0.121407    1.026815    3.444637    0.176432    0.051281    0.019278    0.598635    
#> 377: 0.121294    1.026874    3.444591    0.176498    0.051335    0.019275    0.598517    
#> 378: 0.121207    1.026859    3.444550    0.176529    0.051302    0.019281    0.598499    
#> 379: 0.120965    1.026810    3.444502    0.176623    0.051304    0.019263    0.598527    
#> 380: 0.120716    1.026820    3.444414    0.176677    0.051298    0.019264    0.598450    
#> 381: 0.120492    1.026794    3.444342    0.176757    0.051350    0.019260    0.598406    
#> 382: 0.120314    1.026840    3.444257    0.176909    0.051361    0.019238    0.598302    
#> 383: 0.120470    1.026834    3.444266    0.177155    0.051304    0.019240    0.598258    
#> 384: 0.120426    1.026821    3.444258    0.177445    0.051303    0.019264    0.598173    
#> 385: 0.120497    1.026857    3.444287    0.177437    0.051272    0.019303    0.598125    
#> 386: 0.120558    1.026942    3.444373    0.177394    0.051245    0.019329    0.598148    
#> 387: 0.120845    1.026982    3.444502    0.177230    0.051227    0.019343    0.598137    
#> 388: 0.121067    1.026932    3.444557    0.177025    0.051226    0.019352    0.598182    
#> 389: 0.121043    1.026796    3.444574    0.176846    0.051256    0.019357    0.598278    
#> 390: 0.120965    1.026814    3.444557    0.176757    0.051317    0.019316    0.598249    
#> 391: 0.121099    1.026747    3.444592    0.176834    0.051333    0.019290    0.598145    
#> 392: 0.121140    1.026698    3.444646    0.176958    0.051342    0.019270    0.598080    
#> 393: 0.121059    1.026600    3.444577    0.177020    0.051370    0.019270    0.598049    
#> 394: 0.121027    1.026617    3.444502    0.176970    0.051352    0.019267    0.598007    
#> 395: 0.121116    1.026664    3.444450    0.176856    0.051324    0.019287    0.598079    
#> 396: 0.121132    1.026713    3.444420    0.176847    0.051282    0.019310    0.598048    
#> 397: 0.121206    1.026739    3.444446    0.176850    0.051256    0.019347    0.598101    
#> 398: 0.121327    1.026699    3.444480    0.176744    0.051205    0.019367    0.598193    
#> 399: 0.121523    1.026723    3.444553    0.176574    0.051173    0.019381    0.598289    
#> 400: 0.121742    1.026777    3.444608    0.176491    0.051175    0.019390    0.598267    
#> 401: 0.121947    1.026783    3.444658    0.176526    0.051167    0.019409    0.598273    
#> 402: 0.122028    1.026853    3.444703    0.176425    0.051179    0.019416    0.598282    
#> 403: 0.122187    1.026893    3.444702    0.176343    0.051215    0.019417    0.598234    
#> 404: 0.122225    1.026938    3.444639    0.176263    0.051196    0.019416    0.598236    
#> 405: 0.122326    1.026939    3.444677    0.176263    0.051120    0.019420    0.598245    
#> 406: 0.122429    1.026979    3.444700    0.176277    0.051105    0.019442    0.598343    
#> 407: 0.122455    1.027076    3.444678    0.176310    0.051079    0.019456    0.598321    
#> 408: 0.122596    1.027201    3.444682    0.176347    0.051094    0.019461    0.598399    
#> 409: 0.122617    1.027231    3.444676    0.176487    0.051064    0.019462    0.598382    
#> 410: 0.122565    1.027281    3.444574    0.176535    0.051064    0.019447    0.598458    
#> 411: 0.122515    1.027206    3.444518    0.176566    0.051049    0.019443    0.598513    
#> 412: 0.122506    1.027269    3.444496    0.176647    0.051077    0.019438    0.598538    
#> 413: 0.122644    1.027274    3.444535    0.176754    0.051057    0.019436    0.598552    
#> 414: 0.122656    1.027250    3.444553    0.176831    0.051031    0.019441    0.598479    
#> 415: 0.122753    1.027214    3.444581    0.176825    0.050995    0.019438    0.598472    
#> 416: 0.122816    1.027281    3.444591    0.176812    0.050968    0.019433    0.598449    
#> 417: 0.122695    1.027340    3.444577    0.176831    0.050982    0.019410    0.598465    
#> 418: 0.122521    1.027335    3.444569    0.176787    0.050966    0.019393    0.598496    
#> 419: 0.122451    1.027412    3.444533    0.176814    0.050975    0.019370    0.598548    
#> 420: 0.122404    1.027501    3.444472    0.176846    0.051054    0.019336    0.598538    
#> 421: 0.122370    1.027581    3.444471    0.176804    0.051073    0.019310    0.598536    
#> 422: 0.122506    1.027533    3.444505    0.176842    0.051081    0.019281    0.598594    
#> 423: 0.122704    1.027464    3.444543    0.176975    0.051155    0.019253    0.598578    
#> 424: 0.122675    1.027414    3.444508    0.177012    0.051215    0.019234    0.598570    
#> 425: 0.122693    1.027436    3.444489    0.177124    0.051228    0.019232    0.598549    
#> 426: 0.122747    1.027512    3.444506    0.177045    0.051285    0.019210    0.598530    
#> 427: 0.122736    1.027509    3.444521    0.176994    0.051355    0.019188    0.598485    
#> 428: 0.122637    1.027539    3.444499    0.176913    0.051368    0.019185    0.598552    
#> 429: 0.122633    1.027507    3.444513    0.176785    0.051371    0.019196    0.598634    
#> 430: 0.122582    1.027541    3.444506    0.176763    0.051358    0.019208    0.598661    
#> 431: 0.122528    1.027549    3.444453    0.176760    0.051331    0.019201    0.598625    
#> 432: 0.122412    1.027610    3.444427    0.176805    0.051328    0.019202    0.598557    
#> 433: 0.122316    1.027693    3.444436    0.176774    0.051284    0.019211    0.598552    
#> 434: 0.122171    1.027624    3.444437    0.176717    0.051272    0.019208    0.598473    
#> 435: 0.122194    1.027589    3.444440    0.176767    0.051265    0.019206    0.598376    
#> 436: 0.122163    1.027544    3.444475    0.176840    0.051293    0.019202    0.598346    
#> 437: 0.122216    1.027487    3.444468    0.176821    0.051326    0.019176    0.598363    
#> 438: 0.122223    1.027596    3.444406    0.176762    0.051352    0.019151    0.598394    
#> 439: 0.122325    1.027725    3.444416    0.176671    0.051342    0.019135    0.598383    
#> 440: 0.122305    1.027797    3.444424    0.176661    0.051351    0.019140    0.598326    
#> 441: 0.122308    1.027742    3.444476    0.176681    0.051332    0.019136    0.598229    
#> 442: 0.122248    1.027766    3.444498    0.176825    0.051340    0.019131    0.598115    
#> 443: 0.122224    1.027794    3.444460    0.176828    0.051331    0.019115    0.598075    
#> 444: 0.122162    1.027823    3.444355    0.176892    0.051306    0.019105    0.598047    
#> 445: 0.122089    1.027875    3.444293    0.176830    0.051311    0.019090    0.598053    
#> 446: 0.121848    1.027996    3.444202    0.176737    0.051291    0.019080    0.598013    
#> 447: 0.121857    1.028047    3.444181    0.176797    0.051279    0.019085    0.597971    
#> 448: 0.121840    1.028073    3.444195    0.176768    0.051274    0.019105    0.597894    
#> 449: 0.121867    1.028117    3.444265    0.176758    0.051247    0.019122    0.597894    
#> 450: 0.121740    1.028133    3.444251    0.176669    0.051204    0.019130    0.597940    
#> 451: 0.121668    1.028142    3.444219    0.176627    0.051155    0.019130    0.598047    
#> 452: 0.121635    1.028143    3.444169    0.176581    0.051146    0.019131    0.598108    
#> 453: 0.121537    1.028126    3.444161    0.176642    0.051167    0.019134    0.598077    
#> 454: 0.121439    1.028277    3.444144    0.176645    0.051159    0.019133    0.598061    
#> 455: 0.121400    1.028386    3.444107    0.176658    0.051160    0.019137    0.598079    
#> 456: 0.121279    1.028388    3.444059    0.176658    0.051155    0.019144    0.598111    
#> 457: 0.121234    1.028346    3.444086    0.176591    0.051165    0.019141    0.598097    
#> 458: 0.121129    1.028475    3.444056    0.176549    0.051206    0.019124    0.598121    
#> 459: 0.120957    1.028562    3.444008    0.176498    0.051219    0.019093    0.598163    
#> 460: 0.120776    1.028649    3.443900    0.176509    0.051227    0.019083    0.598189    
#> 461: 0.120685    1.028675    3.443888    0.176483    0.051233    0.019061    0.598210    
#> 462: 0.120601    1.028753    3.443874    0.176385    0.051236    0.019037    0.598258    
#> 463: 0.120572    1.028796    3.443902    0.176291    0.051267    0.019007    0.598320    
#> 464: 0.120744    1.028783    3.443938    0.176317    0.051278    0.018996    0.598296    
#> 465: 0.120771    1.028652    3.443979    0.176289    0.051279    0.018984    0.598334    
#> 466: 0.120819    1.028654    3.443990    0.176191    0.051287    0.018972    0.598307    
#> 467: 0.120849    1.028606    3.444051    0.176107    0.051280    0.018969    0.598251    
#> 468: 0.120958    1.028608    3.444118    0.176113    0.051262    0.018973    0.598223    
#> 469: 0.121089    1.028600    3.444159    0.176149    0.051238    0.018974    0.598206    
#> 470: 0.121088    1.028586    3.444144    0.176095    0.051214    0.018969    0.598196    
#> 471: 0.121038    1.028566    3.444121    0.175967    0.051208    0.018969    0.598135    
#> 472: 0.121035    1.028541    3.444099    0.175952    0.051189    0.018974    0.598114    
#> 473: 0.120926    1.028585    3.444071    0.175866    0.051181    0.018968    0.598039    
#> 474: 0.120878    1.028609    3.444069    0.175727    0.051181    0.018967    0.598060    
#> 475: 0.120967    1.028653    3.444095    0.175655    0.051196    0.018967    0.598072    
#> 476: 0.120964    1.028670    3.444096    0.175630    0.051185    0.018968    0.598143    
#> 477: 0.120978    1.028728    3.444124    0.175604    0.051182    0.018985    0.598060    
#> 478: 0.120936    1.028752    3.444119    0.175654    0.051162    0.018992    0.598030    
#> 479: 0.121085    1.028730    3.444170    0.175722    0.051138    0.019000    0.598008    
#> 480: 0.121172    1.028722    3.444185    0.175747    0.051128    0.018994    0.597995    
#> 481: 0.121205    1.028687    3.444208    0.175742    0.051117    0.019002    0.597967    
#> 482: 0.121168    1.028651    3.444179    0.175852    0.051097    0.018996    0.598028    
#> 483: 0.121056    1.028660    3.444146    0.175954    0.051111    0.018992    0.597999    
#> 484: 0.120998    1.028579    3.444168    0.176058    0.051134    0.018986    0.598015    
#> 485: 0.121026    1.028521    3.444183    0.176066    0.051124    0.018979    0.598073    
#> 486: 0.120995    1.028507    3.444181    0.176087    0.051123    0.018960    0.598042    
#> 487: 0.121172    1.028541    3.444236    0.176278    0.051143    0.018959    0.597974    
#> 488: 0.121304    1.028534    3.444281    0.176454    0.051109    0.018953    0.597942    
#> 489: 0.121450    1.028499    3.444313    0.176616    0.051086    0.018953    0.597899    
#> 490: 0.121553    1.028518    3.444380    0.176628    0.051066    0.018968    0.597880    
#> 491: 0.121649    1.028543    3.444435    0.176687    0.051040    0.018975    0.597859    
#> 492: 0.121677    1.028575    3.444424    0.176741    0.050993    0.018985    0.597919    
#> 493: 0.121708    1.028581    3.444466    0.176845    0.050952    0.019000    0.597896    
#> 494: 0.121844    1.028540    3.444506    0.176721    0.050894    0.019015    0.597887    
#> 495: 0.121944    1.028522    3.444551    0.176662    0.050872    0.019026    0.597883    
#> 496: 0.122038    1.028531    3.444575    0.176504    0.050845    0.019030    0.597960    
#> 497: 0.122010    1.028503    3.444599    0.176346    0.050855    0.019026    0.598026    
#> 498: 0.122028    1.028506    3.444589    0.176301    0.050856    0.019023    0.598010    
#> 499: 0.122000    1.028553    3.444553    0.176310    0.050876    0.019019    0.597960    
#> 500: 0.121978    1.028501    3.444529    0.176315    0.050905    0.019010    0.597927    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.264298    0.987488    3.449494    0.392401    0.085846    0.016800    1.614386    
#> 002: 0.225841    1.088359    3.499667    0.372781    0.081554    0.015960    1.067967    
#> 003: 0.377509    1.101516    3.522684    0.354142    0.077476    0.015162    0.751035    
#> 004: 0.365263    1.138871    3.522908    0.348502    0.073602    0.014404    0.669017    
#> 005: 0.425377    1.143001    3.510348    0.371393    0.069922    0.013684    0.619016    
#> 006: 0.402004    1.149988    3.513463    0.389036    0.066426    0.013000    0.591955    
#> 007: 0.403224    1.165763    3.519168    0.372127    0.063105    0.012350    0.591965    
#> 008: 0.372004    1.161113    3.505388    0.412339    0.059949    0.012833    0.577063    
#> 009: 0.346067    1.143020    3.504066    0.391722    0.056952    0.012804    0.588107    
#> 010: 0.418701    1.142449    3.512619    0.504841    0.054104    0.016370    0.582473    
#> 011: 0.434897    1.171425    3.516762    0.556550    0.051399    0.017642    0.562629    
#> 012: 0.444349    1.149548    3.519632    0.528723    0.048829    0.016760    0.571436    
#> 013: 0.422508    1.136719    3.522562    0.507560    0.046388    0.016401    0.579177    
#> 014: 0.469984    1.127652    3.537180    0.482182    0.044068    0.015581    0.580301    
#> 015: 0.466606    1.135647    3.534125    0.458073    0.041865    0.014802    0.567459    
#> 016: 0.458560    1.152671    3.528984    0.460220    0.039772    0.014062    0.582954    
#> 017: 0.392592    1.160623    3.523088    0.437209    0.037783    0.013358    0.571095    
#> 018: 0.441867    1.164540    3.516139    0.447513    0.035894    0.015702    0.576188    
#> 019: 0.412574    1.154753    3.523364    0.425137    0.034099    0.014917    0.562038    
#> 020: 0.452193    1.151146    3.521319    0.438060    0.032394    0.014370    0.564873    
#> 021: 0.448355    1.139191    3.542216    0.416157    0.030775    0.015704    0.558984    
#> 022: 0.455179    1.139725    3.533312    0.422501    0.029236    0.015082    0.562662    
#> 023: 0.531837    1.135578    3.550646    0.534802    0.027774    0.018540    0.576217    
#> 024: 0.516023    1.157191    3.555801    0.522816    0.026385    0.017613    0.560332    
#> 025: 0.495778    1.147717    3.540535    0.527162    0.025066    0.016733    0.566537    
#> 026: 0.471702    1.162266    3.537385    0.500804    0.023813    0.015896    0.577833    
#> 027: 0.455951    1.166954    3.534754    0.475764    0.026457    0.015101    0.567678    
#> 028: 0.464221    1.158816    3.529864    0.544382    0.025134    0.015140    0.549773    
#> 029: 0.471908    1.156183    3.523531    0.600095    0.023878    0.015592    0.563027    
#> 030: 0.502378    1.163734    3.530547    0.653440    0.022684    0.014963    0.572758    
#> 031: 0.479503    1.150881    3.542763    0.620768    0.021550    0.015522    0.563626    
#> 032: 0.453658    1.141973    3.542186    0.589729    0.020472    0.014746    0.562132    
#> 033: 0.437823    1.148159    3.529159    0.560243    0.019449    0.014009    0.563888    
#> 034: 0.480633    1.143184    3.535376    0.532231    0.018476    0.013308    0.575865    
#> 035: 0.457330    1.132083    3.524463    0.505619    0.017552    0.012643    0.568746    
#> 036: 0.443032    1.139445    3.526864    0.480338    0.018934    0.012011    0.581007    
#> 037: 0.457015    1.132971    3.534795    0.456321    0.017987    0.013727    0.589033    
#> 038: 0.441107    1.137937    3.524416    0.436445    0.017476    0.015201    0.585604    
#> 039: 0.452398    1.135266    3.536364    0.454468    0.017909    0.015908    0.567719    
#> 040: 0.454421    1.133552    3.541737    0.458484    0.021428    0.015699    0.563725    
#> 041: 0.444443    1.131675    3.530840    0.483393    0.020357    0.014914    0.566876    
#> 042: 0.498123    1.116855    3.532681    0.560359    0.019339    0.014169    0.565265    
#> 043: 0.460472    1.129623    3.521140    0.579199    0.018372    0.015209    0.555621    
#> 044: 0.431097    1.127737    3.525904    0.550239    0.017453    0.016009    0.559229    
#> 045: 0.410299    1.135868    3.520133    0.522727    0.018372    0.016351    0.556559    
#> 046: 0.426820    1.135611    3.524358    0.512961    0.017453    0.015690    0.565961    
#> 047: 0.438613    1.136635    3.517361    0.487575    0.017587    0.016294    0.567682    
#> 048: 0.419137    1.135254    3.520742    0.463197    0.022160    0.015479    0.577435    
#> 049: 0.410167    1.153695    3.519580    0.440037    0.021052    0.015263    0.578907    
#> 050: 0.467191    1.132171    3.528896    0.532676    0.025686    0.015377    0.566468    
#> 051: 0.450320    1.151338    3.524641    0.506042    0.024401    0.016144    0.564523    
#> 052: 0.460122    1.148668    3.532932    0.480740    0.023181    0.015337    0.564792    
#> 053: 0.450978    1.125830    3.533082    0.520275    0.022022    0.018008    0.561442    
#> 054: 0.419491    1.142835    3.528484    0.494261    0.022727    0.017108    0.578992    
#> 055: 0.422128    1.139162    3.525142    0.469548    0.021590    0.016252    0.581061    
#> 056: 0.450379    1.136535    3.530811    0.490451    0.022476    0.015545    0.594551    
#> 057: 0.415436    1.142683    3.528416    0.465928    0.021353    0.015520    0.598788    
#> 058: 0.458490    1.158208    3.512263    0.453013    0.022772    0.014744    0.583831    
#> 059: 0.377185    1.126646    3.512082    0.471412    0.021886    0.016530    0.593914    
#> 060: 0.380214    1.130266    3.520667    0.447842    0.020792    0.016956    0.613849    
#> 061: 0.455990    1.126212    3.532927    0.472345    0.019868    0.016108    0.592609    
#> 062: 0.420399    1.138291    3.530867    0.448754    0.018875    0.016724    0.619411    
#> 063: 0.461717    1.129034    3.539718    0.486641    0.017931    0.017210    0.610212    
#> 064: 0.497392    1.130530    3.556505    0.462309    0.018577    0.017463    0.602442    
#> 065: 0.508290    1.130336    3.532636    0.439193    0.020130    0.018287    0.589476    
#> 066: 0.497620    1.125870    3.543118    0.489580    0.019124    0.017373    0.577796    
#> 067: 0.479693    1.127616    3.534795    0.535479    0.020190    0.016504    0.573811    
#> 068: 0.463577    1.141756    3.545267    0.508705    0.023070    0.015679    0.567600    
#> 069: 0.476195    1.160294    3.525046    0.620457    0.021916    0.019331    0.569393    
#> 070: 0.422656    1.157157    3.529334    0.589434    0.020821    0.019409    0.571299    
#> 071: 0.436489    1.181802    3.505054    0.559962    0.019780    0.019575    0.571112    
#> 072: 0.413855    1.165867    3.500612    0.584135    0.018791    0.018639    0.568304    
#> 073: 0.442695    1.170137    3.516411    0.576099    0.017851    0.017707    0.574049    
#> 074: 0.398827    1.159422    3.507939    0.547294    0.017000    0.016822    0.572785    
#> 075: 0.398201    1.167126    3.522038    0.520853    0.016150    0.019267    0.568079    
#> 076: 0.451159    1.158683    3.530245    0.518174    0.017238    0.018776    0.588823    
#> 077: 0.467053    1.148376    3.526762    0.522404    0.016376    0.020994    0.583924    
#> 078: 0.474526    1.144623    3.532264    0.568006    0.015557    0.020160    0.572490    
#> 079: 0.479100    1.150086    3.532473    0.559267    0.014779    0.020025    0.589609    
#> 080: 0.509303    1.146231    3.540056    0.566786    0.014603    0.020486    0.608396    
#> 081: 0.524870    1.146683    3.538006    0.562517    0.014194    0.021029    0.591733    
#> 082: 0.465962    1.136272    3.541684    0.534391    0.013485    0.024442    0.596922    
#> 083: 0.457454    1.143275    3.535244    0.508746    0.013843    0.023220    0.590439    
#> 084: 0.461519    1.159594    3.527481    0.630079    0.015950    0.023035    0.575842    
#> 085: 0.475665    1.151229    3.542343    0.598575    0.017517    0.023409    0.585039    
#> 086: 0.475150    1.139611    3.535631    0.568647    0.016641    0.022239    0.574332    
#> 087: 0.445165    1.138750    3.534273    0.540214    0.016675    0.021127    0.575714    
#> 088: 0.406545    1.138227    3.539697    0.513204    0.015841    0.020071    0.582775    
#> 089: 0.415548    1.153275    3.510499    0.487543    0.015049    0.019067    0.589839    
#> 090: 0.406012    1.163097    3.506592    0.487844    0.014297    0.018114    0.578347    
#> 091: 0.410783    1.159327    3.503111    0.537460    0.013582    0.017509    0.574149    
#> 092: 0.413894    1.175314    3.505128    0.510587    0.014586    0.018155    0.572476    
#> 093: 0.379663    1.156926    3.510891    0.485058    0.014105    0.019594    0.579041    
#> 094: 0.399736    1.163271    3.500152    0.460805    0.015369    0.018614    0.578991    
#> 095: 0.409482    1.158156    3.520372    0.437764    0.016211    0.017982    0.567313    
#> 096: 0.388474    1.161390    3.509854    0.522728    0.015401    0.019484    0.569145    
#> 097: 0.437399    1.172485    3.511052    0.506629    0.015462    0.019569    0.575400    
#> 098: 0.438939    1.168127    3.519816    0.481297    0.017619    0.018590    0.566164    
#> 099: 0.444099    1.152528    3.515157    0.457232    0.016738    0.017661    0.569044    
#> 100: 0.428408    1.161196    3.522292    0.434371    0.017435    0.016778    0.565562    
#> 101: 0.417018    1.150973    3.517701    0.436870    0.016563    0.015939    0.566612    
#> 102: 0.420067    1.136044    3.507106    0.451272    0.015735    0.016353    0.568782    
#> 103: 0.430822    1.146523    3.517343    0.485579    0.014949    0.015535    0.571036    
#> 104: 0.450581    1.144799    3.535349    0.498951    0.014201    0.017792    0.582325    
#> 105: 0.471962    1.144327    3.525860    0.538126    0.013491    0.018584    0.576818    
#> 106: 0.446330    1.146023    3.523073    0.534528    0.014479    0.017654    0.581934    
#> 107: 0.455733    1.150546    3.523430    0.507802    0.017292    0.016772    0.569650    
#> 108: 0.410687    1.150967    3.519793    0.482412    0.021000    0.017485    0.574101    
#> 109: 0.451971    1.138431    3.543199    0.458291    0.019950    0.016611    0.572342    
#> 110: 0.435140    1.144087    3.527622    0.436975    0.018952    0.015780    0.581385    
#> 111: 0.466250    1.149605    3.531078    0.462873    0.018202    0.015008    0.562137    
#> 112: 0.422419    1.136038    3.522068    0.445478    0.019525    0.014257    0.583233    
#> 113: 0.438638    1.149417    3.528988    0.489796    0.019035    0.013723    0.564801    
#> 114: 0.473883    1.146662    3.533007    0.524814    0.021335    0.015047    0.573993    
#> 115: 0.474177    1.126653    3.527545    0.536684    0.022459    0.016164    0.578425    
#> 116: 0.480444    1.139509    3.527759    0.549615    0.021336    0.017306    0.583381    
#> 117: 0.428947    1.158107    3.537877    0.522134    0.020603    0.019531    0.591414    
#> 118: 0.438292    1.155721    3.539016    0.496027    0.022517    0.018554    0.584262    
#> 119: 0.473528    1.149559    3.528740    0.471226    0.021391    0.020717    0.584125    
#> 120: 0.431964    1.146079    3.532820    0.471836    0.020321    0.019681    0.588501    
#> 121: 0.466255    1.149991    3.532894    0.479941    0.022906    0.018697    0.583765    
#> 122: 0.457848    1.134096    3.535504    0.514402    0.021760    0.021388    0.573286    
#> 123: 0.486029    1.155585    3.531482    0.501794    0.020672    0.020425    0.568381    
#> 124: 0.433330    1.173513    3.528197    0.496975    0.019977    0.021274    0.575992    
#> 125: 0.430502    1.187806    3.516061    0.502571    0.021751    0.020210    0.567964    
#> 126: 0.397881    1.200609    3.499825    0.477443    0.024381    0.019199    0.574768    
#> 127: 0.419520    1.179882    3.495512    0.454111    0.023162    0.018239    0.579786    
#> 128: 0.401443    1.164215    3.521902    0.465020    0.022004    0.017327    0.575964    
#> 129: 0.432471    1.164554    3.525496    0.459471    0.024196    0.016461    0.583909    
#> 130: 0.457883    1.172413    3.524637    0.491919    0.022986    0.015638    0.578179    
#> 131: 0.436189    1.157674    3.508842    0.467323    0.021837    0.018518    0.554213    
#> 132: 0.378545    1.166918    3.494508    0.443957    0.020745    0.017592    0.576026    
#> 133: 0.373832    1.163928    3.502459    0.482876    0.019708    0.016819    0.579252    
#> 134: 0.396003    1.152400    3.517471    0.521507    0.018722    0.015986    0.576108    
#> 135: 0.428762    1.137812    3.526801    0.495431    0.017786    0.019333    0.572206    
#> 136: 0.446572    1.139794    3.529072    0.505726    0.016987    0.018783    0.563321    
#> 137: 0.483396    1.130474    3.529205    0.586144    0.016138    0.018702    0.577420    
#> 138: 0.468300    1.128532    3.539047    0.556837    0.015331    0.017767    0.586567    
#> 139: 0.445901    1.130808    3.539290    0.528995    0.014565    0.018022    0.585631    
#> 140: 0.462016    1.143816    3.542473    0.502844    0.013836    0.018081    0.585778    
#> 141: 0.450356    1.129344    3.541677    0.477702    0.013145    0.017470    0.599125    
#> 142: 0.462787    1.113625    3.553151    0.453817    0.014229    0.016596    0.598732    
#> 143: 0.434597    1.123578    3.544021    0.431126    0.016837    0.015766    0.582066    
#> 144: 0.492271    1.115176    3.558593    0.460199    0.015995    0.016919    0.577353    
#> 145: 0.454069    1.126784    3.537153    0.454456    0.015195    0.016073    0.569369    
#> 146: 0.454709    1.130749    3.550393    0.500304    0.014436    0.018470    0.579293    
#> 147: 0.413684    1.137567    3.516226    0.533725    0.016135    0.017930    0.574375    
#> 148: 0.403759    1.141708    3.533905    0.535466    0.015328    0.018082    0.569017    
#> 149: 0.417975    1.141539    3.525994    0.508692    0.014562    0.017487    0.584383    
#> 150: 0.454272    1.138975    3.516220    0.498171    0.014896    0.016613    0.590942    
#> 151: 0.410774    1.159895    3.523022    0.473263    0.017991    0.016852    0.569665    
#> 152: 0.412664    1.153581    3.530042    0.464938    0.020028    0.015593    0.571460    
#> 153: 0.425309    1.161695    3.540253    0.429817    0.021704    0.017066    0.577794    
#> 154: 0.461413    1.158869    3.538366    0.447180    0.019855    0.019834    0.586409    
#> 155: 0.482390    1.149915    3.534014    0.496344    0.012126    0.022662    0.578756    
#> 156: 0.482232    1.151433    3.534198    0.491253    0.013160    0.024242    0.575551    
#> 157: 0.475161    1.140670    3.531968    0.511175    0.009696    0.022757    0.566755    
#> 158: 0.461267    1.151619    3.532497    0.474492    0.010133    0.021075    0.558557    
#> 159: 0.435862    1.153798    3.537943    0.527877    0.011317    0.018779    0.568471    
#> 160: 0.458068    1.139640    3.537649    0.459280    0.013925    0.016702    0.571157    
#> 161: 0.482272    1.140876    3.541420    0.509171    0.015006    0.020607    0.567353    
#> 162: 0.490076    1.156339    3.538780    0.480961    0.011610    0.020077    0.582067    
#> 163: 0.478365    1.139875    3.533731    0.489783    0.012042    0.019267    0.574302    
#> 164: 0.459353    1.153413    3.527069    0.469741    0.013780    0.017386    0.579382    
#> 165: 0.463336    1.159583    3.531311    0.496126    0.013873    0.014680    0.593908    
#> 166: 0.465653    1.174426    3.529556    0.445204    0.015416    0.011623    0.593755    
#> 167: 0.424589    1.190363    3.526249    0.460800    0.020375    0.012718    0.583041    
#> 168: 0.446693    1.189057    3.528699    0.530624    0.018504    0.015072    0.571301    
#> 169: 0.458500    1.186041    3.515141    0.524113    0.019641    0.011000    0.587317    
#> 170: 0.477881    1.157715    3.529480    0.575918    0.019612    0.012914    0.569907    
#> 171: 0.459860    1.156524    3.525632    0.490575    0.020280    0.009519    0.568401    
#> 172: 0.412088    1.171498    3.524206    0.412801    0.019013    0.010254    0.576354    
#> 173: 0.399827    1.182364    3.508685    0.401507    0.018651    0.013211    0.587859    
#> 174: 0.407020    1.184912    3.511077    0.442270    0.018178    0.013857    0.579272    
#> 175: 0.418557    1.185204    3.509474    0.471513    0.018846    0.015077    0.580127    
#> 176: 0.449475    1.185718    3.519655    0.506856    0.020383    0.015821    0.565787    
#> 177: 0.437639    1.169126    3.530458    0.471634    0.022312    0.013455    0.568963    
#> 178: 0.437228    1.155474    3.531681    0.460021    0.022323    0.014065    0.579482    
#> 179: 0.448945    1.160710    3.523997    0.457395    0.020239    0.016442    0.573416    
#> 180: 0.456320    1.151539    3.526495    0.521504    0.020515    0.018926    0.576673    
#> 181: 0.436812    1.127781    3.515648    0.472573    0.015198    0.015371    0.580530    
#> 182: 0.402018    1.143803    3.507705    0.460377    0.018886    0.013234    0.580286    
#> 183: 0.455725    1.163818    3.518862    0.457375    0.017512    0.016084    0.580816    
#> 184: 0.446118    1.144647    3.529011    0.430450    0.016654    0.015280    0.571622    
#> 185: 0.429575    1.168352    3.518117    0.480861    0.016576    0.014916    0.578266    
#> 186: 0.409108    1.177342    3.516789    0.459596    0.018590    0.015115    0.583990    
#> 187: 0.452654    1.159579    3.529855    0.543802    0.012757    0.019981    0.571271    
#> 188: 0.411588    1.178546    3.521992    0.492319    0.010582    0.019035    0.591313    
#> 189: 0.465468    1.188398    3.532168    0.595708    0.012885    0.025169    0.585025    
#> 190: 0.488437    1.182285    3.529334    0.699264    0.012588    0.022485    0.564341    
#> 191: 0.425410    1.191007    3.510975    0.566516    0.013320    0.018885    0.558281    
#> 192: 0.421043    1.184424    3.506100    0.590934    0.015219    0.016706    0.572594    
#> 193: 0.448708    1.180674    3.519216    0.539788    0.016376    0.015137    0.568203    
#> 194: 0.405193    1.161912    3.497362    0.488672    0.016613    0.017102    0.585980    
#> 195: 0.348954    1.167950    3.496906    0.495883    0.014675    0.016923    0.581683    
#> 196: 0.384896    1.175123    3.505253    0.469609    0.017618    0.018423    0.569984    
#> 197: 0.375072    1.188483    3.517605    0.387311    0.016207    0.020594    0.591554    
#> 198: 0.426786    1.164777    3.513673    0.410284    0.014357    0.018388    0.573847    
#> 199: 0.425649    1.159751    3.516854    0.489389    0.012970    0.019409    0.567184    
#> 200: 0.400603    1.155010    3.517000    0.526487    0.010875    0.017115    0.582615    
#> 201: 0.398347    1.147202    3.517231    0.480590    0.011834    0.015213    0.582565    
#> 202: 0.404844    1.147661    3.520956    0.475691    0.012935    0.014260    0.582895    
#> 203: 0.425541    1.147071    3.523493    0.468553    0.013910    0.014717    0.581522    
#> 204: 0.437342    1.143892    3.525753    0.472411    0.014675    0.014688    0.583692    
#> 205: 0.441311    1.144359    3.526825    0.472610    0.015916    0.014868    0.582446    
#> 206: 0.442464    1.146843    3.527550    0.478543    0.015509    0.014593    0.583821    
#> 207: 0.444855    1.147748    3.526902    0.479324    0.015413    0.014419    0.583297    
#> 208: 0.445754    1.148427    3.526880    0.486072    0.015317    0.014732    0.581369    
#> 209: 0.445962    1.147716    3.526485    0.489599    0.014917    0.015336    0.580156    
#> 210: 0.447234    1.147523    3.526973    0.494020    0.014871    0.015572    0.578835    
#> 211: 0.447904    1.148354    3.527706    0.489720    0.014880    0.015603    0.578496    
#> 212: 0.449448    1.148863    3.528480    0.486366    0.014792    0.015742    0.578840    
#> 213: 0.452576    1.147036    3.529472    0.491165    0.014890    0.015924    0.579332    
#> 214: 0.455931    1.146063    3.529624    0.495685    0.014986    0.016320    0.578939    
#> 215: 0.456723    1.145267    3.530054    0.502716    0.014947    0.016708    0.578942    
#> 216: 0.460119    1.143014    3.530835    0.503340    0.014771    0.017155    0.579605    
#> 217: 0.456939    1.142051    3.531228    0.498488    0.014507    0.017363    0.580113    
#> 218: 0.456447    1.141600    3.530538    0.496660    0.014538    0.017505    0.580114    
#> 219: 0.454828    1.141337    3.529901    0.495419    0.014418    0.017497    0.579409    
#> 220: 0.451899    1.142023    3.529341    0.498154    0.014474    0.017493    0.579087    
#> 221: 0.451313    1.142244    3.528609    0.500333    0.014488    0.017570    0.578173    
#> 222: 0.450766    1.142441    3.528025    0.503815    0.014351    0.017664    0.578065    
#> 223: 0.452421    1.142033    3.528261    0.507219    0.014270    0.017863    0.577597    
#> 224: 0.454108    1.142005    3.528906    0.506554    0.014310    0.017926    0.577587    
#> 225: 0.453456    1.141508    3.529649    0.504200    0.014457    0.017946    0.577495    
#> 226: 0.452714    1.141059    3.529465    0.501124    0.014485    0.017863    0.577708    
#> 227: 0.453307    1.141009    3.529496    0.497548    0.014578    0.017665    0.577489    
#> 228: 0.452743    1.141687    3.529405    0.494743    0.014636    0.017525    0.577920    
#> 229: 0.451043    1.141843    3.529008    0.493028    0.014587    0.017437    0.577606    
#> 230: 0.451205    1.141834    3.529132    0.489884    0.014568    0.017453    0.577758    
#> 231: 0.450904    1.142347    3.529135    0.489582    0.014589    0.017386    0.577505    
#> 232: 0.450349    1.142386    3.529255    0.489701    0.014573    0.017358    0.577590    
#> 233: 0.449716    1.141641    3.529279    0.489105    0.014558    0.017431    0.578054    
#> 234: 0.450311    1.141600    3.529391    0.490912    0.014588    0.017498    0.578301    
#> 235: 0.451189    1.141613    3.529484    0.492307    0.014606    0.017442    0.578319    
#> 236: 0.451227    1.141841    3.529247    0.491649    0.014611    0.017414    0.578222    
#> 237: 0.451600    1.142012    3.529244    0.490130    0.014623    0.017433    0.578264    
#> 238: 0.452244    1.142273    3.529444    0.489935    0.014646    0.017523    0.578601    
#> 239: 0.452590    1.142739    3.529641    0.488929    0.014592    0.017635    0.578309    
#> 240: 0.452141    1.142880    3.529804    0.487306    0.014571    0.017682    0.577935    
#> 241: 0.452185    1.142716    3.529944    0.486646    0.014576    0.017715    0.577786    
#> 242: 0.452173    1.142491    3.529846    0.486957    0.014622    0.017742    0.577987    
#> 243: 0.451859    1.142786    3.529616    0.486710    0.014686    0.017770    0.578152    
#> 244: 0.451614    1.142574    3.529725    0.486533    0.014676    0.017820    0.578203    
#> 245: 0.451442    1.142316    3.529793    0.485789    0.014687    0.017760    0.578582    
#> 246: 0.451324    1.142161    3.529815    0.485132    0.014636    0.017793    0.578781    
#> 247: 0.451179    1.141958    3.530008    0.483936    0.014627    0.017831    0.578676    
#> 248: 0.451168    1.142030    3.530079    0.483672    0.014698    0.017807    0.578290    
#> 249: 0.451036    1.141954    3.530216    0.484351    0.014669    0.017793    0.578366    
#> 250: 0.451539    1.141972    3.530278    0.483846    0.014627    0.017771    0.578359    
#> 251: 0.451474    1.142229    3.530455    0.482227    0.014582    0.017725    0.578486    
#> 252: 0.451866    1.142528    3.530765    0.482624    0.014576    0.017729    0.578464    
#> 253: 0.452453    1.142629    3.530957    0.483816    0.014563    0.017750    0.578599    
#> 254: 0.453226    1.142959    3.531169    0.484911    0.014513    0.017750    0.578644    
#> 255: 0.453805    1.142957    3.531371    0.486010    0.014548    0.017726    0.578778    
#> 256: 0.454738    1.142855    3.531516    0.486120    0.014583    0.017677    0.578619    
#> 257: 0.455215    1.142709    3.531543    0.485807    0.014572    0.017647    0.578358    
#> 258: 0.455400    1.142296    3.531727    0.485099    0.014581    0.017600    0.578396    
#> 259: 0.455715    1.141945    3.531903    0.485608    0.014585    0.017548    0.578240    
#> 260: 0.455934    1.141817    3.531977    0.485691    0.014610    0.017554    0.578192    
#> 261: 0.456281    1.141653    3.532075    0.486131    0.014620    0.017562    0.578307    
#> 262: 0.456115    1.141639    3.532098    0.484963    0.014619    0.017582    0.578340    
#> 263: 0.455834    1.141856    3.532096    0.485284    0.014620    0.017585    0.578474    
#> 264: 0.455098    1.141932    3.531874    0.485375    0.014674    0.017550    0.578575    
#> 265: 0.454919    1.142060    3.531863    0.485188    0.014731    0.017528    0.578838    
#> 266: 0.455813    1.142315    3.532068    0.484518    0.014679    0.017544    0.579177    
#> 267: 0.455933    1.142334    3.532239    0.485058    0.014647    0.017528    0.579239    
#> 268: 0.455862    1.142327    3.532266    0.485254    0.014667    0.017519    0.579392    
#> 269: 0.456050    1.142178    3.532290    0.485038    0.014707    0.017479    0.579306    
#> 270: 0.455848    1.142175    3.532120    0.484740    0.014695    0.017410    0.579301    
#> 271: 0.455676    1.142125    3.531918    0.484788    0.014691    0.017351    0.579370    
#> 272: 0.455472    1.142097    3.531830    0.484663    0.014698    0.017305    0.579464    
#> 273: 0.454966    1.142286    3.531726    0.484813    0.014744    0.017278    0.579412    
#> 274: 0.454648    1.142475    3.531663    0.485149    0.014790    0.017274    0.579149    
#> 275: 0.454099    1.142612    3.531327    0.485046    0.014841    0.017224    0.578968    
#> 276: 0.453986    1.142685    3.531257    0.485428    0.014856    0.017169    0.578816    
#> 277: 0.453588    1.142780    3.531230    0.485678    0.014836    0.017161    0.578943    
#> 278: 0.453556    1.142853    3.531255    0.486354    0.014830    0.017145    0.579032    
#> 279: 0.453530    1.142869    3.531236    0.486986    0.014789    0.017174    0.579189    
#> 280: 0.453273    1.143096    3.531159    0.487226    0.014781    0.017223    0.579279    
#> 281: 0.453105    1.143424    3.531047    0.486821    0.014774    0.017244    0.579336    
#> 282: 0.453051    1.143690    3.530993    0.486602    0.014774    0.017280    0.579280    
#> 283: 0.453006    1.143864    3.530976    0.487105    0.014790    0.017336    0.579323    
#> 284: 0.452823    1.144015    3.530909    0.487481    0.014820    0.017366    0.579232    
#> 285: 0.452674    1.144065    3.530719    0.487102    0.014856    0.017407    0.579242    
#> 286: 0.452548    1.144077    3.530605    0.486895    0.014894    0.017412    0.579465    
#> 287: 0.452633    1.144119    3.530511    0.486341    0.014914    0.017434    0.579882    
#> 288: 0.453063    1.144156    3.530572    0.486704    0.014885    0.017461    0.579949    
#> 289: 0.453680    1.144114    3.530686    0.486913    0.014879    0.017474    0.580052    
#> 290: 0.453809    1.144034    3.530753    0.486457    0.014919    0.017486    0.579913    
#> 291: 0.453557    1.144260    3.530698    0.486060    0.014940    0.017488    0.579791    
#> 292: 0.453159    1.144402    3.530596    0.485618    0.014938    0.017483    0.579832    
#> 293: 0.452663    1.144677    3.530393    0.485036    0.014934    0.017490    0.579766    
#> 294: 0.452182    1.144937    3.530117    0.484919    0.014939    0.017497    0.579831    
#> 295: 0.451293    1.145048    3.529820    0.484572    0.014965    0.017508    0.579728    
#> 296: 0.450934    1.145121    3.529597    0.484860    0.014974    0.017503    0.579911    
#> 297: 0.450460    1.145313    3.529289    0.485537    0.014998    0.017502    0.579972    
#> 298: 0.449869    1.145424    3.529070    0.485856    0.015006    0.017476    0.579857    
#> 299: 0.449179    1.145626    3.528805    0.485918    0.015017    0.017462    0.579725    
#> 300: 0.448776    1.145768    3.528725    0.486575    0.014996    0.017492    0.579651    
#> 301: 0.448724    1.145707    3.528669    0.486221    0.014972    0.017495    0.579753    
#> 302: 0.448878    1.145759    3.528655    0.485952    0.014954    0.017500    0.579695    
#> 303: 0.448820    1.145894    3.528643    0.485415    0.014948    0.017485    0.579570    
#> 304: 0.448599    1.146102    3.528547    0.484922    0.014954    0.017444    0.579594    
#> 305: 0.448221    1.146024    3.528500    0.484338    0.014948    0.017409    0.579677    
#> 306: 0.447751    1.145988    3.528421    0.484004    0.014943    0.017366    0.579730    
#> 307: 0.447536    1.145857    3.528344    0.483873    0.014937    0.017346    0.579814    
#> 308: 0.446972    1.145770    3.528248    0.483623    0.014938    0.017338    0.579817    
#> 309: 0.446849    1.145489    3.528280    0.483747    0.014945    0.017342    0.579888    
#> 310: 0.446827    1.145504    3.528225    0.483485    0.014965    0.017335    0.579940    
#> 311: 0.446643    1.145562    3.528210    0.483277    0.014969    0.017337    0.580051    
#> 312: 0.446307    1.145545    3.528095    0.482351    0.014975    0.017351    0.580247    
#> 313: 0.446071    1.145367    3.527980    0.481841    0.014978    0.017391    0.580250    
#> 314: 0.445480    1.145390    3.527775    0.481928    0.014970    0.017435    0.580296    
#> 315: 0.445014    1.145384    3.527640    0.481471    0.014953    0.017466    0.580315    
#> 316: 0.445098    1.145334    3.527605    0.481353    0.014954    0.017482    0.580288    
#> 317: 0.444989    1.145266    3.527645    0.481721    0.014984    0.017514    0.580323    
#> 318: 0.444931    1.145350    3.527610    0.481566    0.015020    0.017529    0.580204    
#> 319: 0.444909    1.145370    3.527624    0.481897    0.015033    0.017548    0.580251    
#> 320: 0.444361    1.145449    3.527479    0.481612    0.015034    0.017560    0.580427    
#> 321: 0.444359    1.145478    3.527410    0.481645    0.015022    0.017588    0.580515    
#> 322: 0.444360    1.145490    3.527308    0.481419    0.015004    0.017606    0.580542    
#> 323: 0.443983    1.145495    3.527272    0.480948    0.014972    0.017614    0.580494    
#> 324: 0.444011    1.145583    3.527310    0.481262    0.014960    0.017634    0.580373    
#> 325: 0.443847    1.145750    3.527235    0.480925    0.014944    0.017650    0.580339    
#> 326: 0.443772    1.145651    3.527221    0.480846    0.014911    0.017659    0.580345    
#> 327: 0.443878    1.145660    3.527279    0.480605    0.014872    0.017687    0.580356    
#> 328: 0.443903    1.145752    3.527268    0.480860    0.014857    0.017695    0.580357    
#> 329: 0.443963    1.145792    3.527290    0.480716    0.014873    0.017685    0.580226    
#> 330: 0.443934    1.145862    3.527292    0.480503    0.014896    0.017656    0.580209    
#> 331: 0.444416    1.145876    3.527390    0.481323    0.014909    0.017616    0.580168    
#> 332: 0.444598    1.145769    3.527518    0.481657    0.014934    0.017580    0.580235    
#> 333: 0.444547    1.145743    3.527458    0.481647    0.014964    0.017544    0.580290    
#> 334: 0.444210    1.145716    3.527363    0.481791    0.014961    0.017552    0.580240    
#> 335: 0.444025    1.145727    3.527260    0.481578    0.014958    0.017536    0.580219    
#> 336: 0.443791    1.145846    3.527161    0.481442    0.014944    0.017561    0.580189    
#> 337: 0.443322    1.146085    3.526925    0.481943    0.014952    0.017569    0.580099    
#> 338: 0.442887    1.146244    3.526835    0.481727    0.014966    0.017580    0.580086    
#> 339: 0.442758    1.146349    3.526805    0.481833    0.014972    0.017602    0.580023    
#> 340: 0.442802    1.146305    3.526804    0.481788    0.014979    0.017608    0.579992    
#> 341: 0.442993    1.146276    3.526874    0.481987    0.014976    0.017605    0.579975    
#> 342: 0.442947    1.146124    3.526914    0.482050    0.014960    0.017613    0.579911    
#> 343: 0.442898    1.146087    3.526989    0.481778    0.014916    0.017620    0.579940    
#> 344: 0.443088    1.146035    3.527104    0.481832    0.014895    0.017638    0.579981    
#> 345: 0.443104    1.146035    3.527153    0.481655    0.014898    0.017651    0.579964    
#> 346: 0.443065    1.146159    3.527062    0.481740    0.014875    0.017673    0.579964    
#> 347: 0.443263    1.146058    3.527006    0.481873    0.014871    0.017703    0.580047    
#> 348: 0.442896    1.146142    3.526899    0.481431    0.014852    0.017725    0.580099    
#> 349: 0.442898    1.146228    3.526899    0.481487    0.014837    0.017740    0.580051    
#> 350: 0.442598    1.146279    3.526849    0.481708    0.014835    0.017736    0.579989    
#> 351: 0.442573    1.146473    3.526793    0.481946    0.014855    0.017721    0.579929    
#> 352: 0.442336    1.146656    3.526696    0.481753    0.014874    0.017730    0.580008    
#> 353: 0.442519    1.146837    3.526640    0.481747    0.014904    0.017703    0.580057    
#> 354: 0.442462    1.147004    3.526494    0.481913    0.014926    0.017721    0.580030    
#> 355: 0.442602    1.147030    3.526439    0.482209    0.014945    0.017722    0.579953    
#> 356: 0.442568    1.146994    3.526430    0.482582    0.014964    0.017713    0.580049    
#> 357: 0.442735    1.146924    3.526447    0.483029    0.014951    0.017710    0.580124    
#> 358: 0.442897    1.146931    3.526530    0.483684    0.014910    0.017740    0.580145    
#> 359: 0.442924    1.146999    3.526533    0.484148    0.014888    0.017780    0.580074    
#> 360: 0.442914    1.147041    3.526478    0.484008    0.014861    0.017830    0.579948    
#> 361: 0.442917    1.147137    3.526414    0.484128    0.014845    0.017859    0.579832    
#> 362: 0.442868    1.147189    3.526358    0.484247    0.014835    0.017867    0.579674    
#> 363: 0.442807    1.147160    3.526335    0.484187    0.014818    0.017889    0.579576    
#> 364: 0.442788    1.147124    3.526315    0.483759    0.014784    0.017926    0.579560    
#> 365: 0.442691    1.147097    3.526285    0.483931    0.014794    0.017990    0.579579    
#> 366: 0.442728    1.147072    3.526201    0.483738    0.014779    0.018026    0.579521    
#> 367: 0.442754    1.147058    3.526165    0.483950    0.014767    0.018027    0.579463    
#> 368: 0.442964    1.147104    3.526062    0.485063    0.014762    0.018020    0.579404    
#> 369: 0.443108    1.147091    3.526034    0.485455    0.014749    0.018017    0.579460    
#> 370: 0.442873    1.147156    3.525971    0.485134    0.014739    0.018012    0.579469    
#> 371: 0.442896    1.147177    3.525914    0.485094    0.014718    0.018019    0.579448    
#> 372: 0.442706    1.147202    3.525873    0.485411    0.014713    0.018031    0.579483    
#> 373: 0.442530    1.147351    3.525790    0.485801    0.014735    0.018034    0.579431    
#> 374: 0.442574    1.147444    3.525734    0.486121    0.014754    0.018040    0.579384    
#> 375: 0.442490    1.147518    3.525664    0.486507    0.014741    0.018035    0.579395    
#> 376: 0.442418    1.147550    3.525598    0.486411    0.014731    0.018045    0.579362    
#> 377: 0.442368    1.147623    3.525610    0.486388    0.014746    0.018024    0.579339    
#> 378: 0.442170    1.147638    3.525520    0.486294    0.014754    0.018004    0.579405    
#> 379: 0.442079    1.147524    3.525518    0.486399    0.014763    0.017998    0.579412    
#> 380: 0.441921    1.147472    3.525539    0.486226    0.014800    0.017991    0.579378    
#> 381: 0.441820    1.147401    3.525536    0.486300    0.014824    0.017973    0.579336    
#> 382: 0.441827    1.147357    3.525534    0.486934    0.014841    0.017979    0.579254    
#> 383: 0.441760    1.147332    3.525492    0.487121    0.014851    0.017993    0.579202    
#> 384: 0.441680    1.147368    3.525471    0.486862    0.014855    0.017983    0.579240    
#> 385: 0.441789    1.147435    3.525497    0.486531    0.014861    0.017955    0.579245    
#> 386: 0.442000    1.147550    3.525558    0.486236    0.014882    0.017940    0.579220    
#> 387: 0.442137    1.147532    3.525639    0.485827    0.014889    0.017938    0.579221    
#> 388: 0.442246    1.147507    3.525743    0.485505    0.014909    0.017914    0.579201    
#> 389: 0.442411    1.147344    3.525816    0.485374    0.014905    0.017889    0.579233    
#> 390: 0.442434    1.147296    3.525821    0.485396    0.014897    0.017878    0.579281    
#> 391: 0.442740    1.147241    3.525850    0.485383    0.014887    0.017914    0.579289    
#> 392: 0.442973    1.147189    3.525926    0.485748    0.014882    0.017934    0.579309    
#> 393: 0.443056    1.147120    3.525981    0.485815    0.014878    0.017934    0.579262    
#> 394: 0.443399    1.147051    3.526049    0.486373    0.014868    0.017949    0.579230    
#> 395: 0.443925    1.147028    3.526163    0.486956    0.014860    0.017953    0.579254    
#> 396: 0.444236    1.147059    3.526255    0.487432    0.014862    0.017969    0.579279    
#> 397: 0.444413    1.147026    3.526372    0.487356    0.014869    0.017979    0.579324    
#> 398: 0.444588    1.146920    3.526459    0.487277    0.014879    0.017975    0.579363    
#> 399: 0.444868    1.146847    3.526602    0.487265    0.014890    0.017970    0.579330    
#> 400: 0.445060    1.146868    3.526680    0.487199    0.014894    0.017965    0.579313    
#> 401: 0.445206    1.146930    3.526690    0.487302    0.014899    0.017946    0.579333    
#> 402: 0.445255    1.146975    3.526689    0.487051    0.014907    0.017930    0.579352    
#> 403: 0.445344    1.146994    3.526660    0.486874    0.014916    0.017913    0.579332    
#> 404: 0.445268    1.147019    3.526575    0.486939    0.014942    0.017900    0.579208    
#> 405: 0.445189    1.147083    3.526565    0.487104    0.014966    0.017887    0.579204    
#> 406: 0.445186    1.147078    3.526555    0.487219    0.014985    0.017894    0.579225    
#> 407: 0.445244    1.147117    3.526576    0.487182    0.014987    0.017892    0.579233    
#> 408: 0.445328    1.147184    3.526616    0.486770    0.014984    0.017881    0.579321    
#> 409: 0.445350    1.147192    3.526583    0.486560    0.014979    0.017857    0.579333    
#> 410: 0.445111    1.147229    3.526522    0.486355    0.014989    0.017854    0.579293    
#> 411: 0.444980    1.147154    3.526475    0.486235    0.014995    0.017841    0.579263    
#> 412: 0.444895    1.147199    3.526410    0.486167    0.015003    0.017829    0.579193    
#> 413: 0.444875    1.147234    3.526366    0.486369    0.015000    0.017818    0.579140    
#> 414: 0.444629    1.147209    3.526327    0.486015    0.014996    0.017850    0.579125    
#> 415: 0.444906    1.147177    3.526325    0.486199    0.014989    0.017863    0.579146    
#> 416: 0.445135    1.147154    3.526368    0.486757    0.014985    0.017860    0.579132    
#> 417: 0.445241    1.147114    3.526367    0.487030    0.015000    0.017855    0.579089    
#> 418: 0.445163    1.147129    3.526360    0.487113    0.014998    0.017857    0.579029    
#> 419: 0.445277    1.147172    3.526354    0.487252    0.014979    0.017851    0.578996    
#> 420: 0.445247    1.147221    3.526340    0.487040    0.014944    0.017851    0.578943    
#> 421: 0.445059    1.147286    3.526334    0.486676    0.014933    0.017862    0.578898    
#> 422: 0.445172    1.147275    3.526373    0.486366    0.014925    0.017870    0.578905    
#> 423: 0.445355    1.147196    3.526419    0.486550    0.014932    0.017871    0.578851    
#> 424: 0.445361    1.147146    3.526359    0.486722    0.014936    0.017889    0.578836    
#> 425: 0.445351    1.147164    3.526297    0.487509    0.014942    0.017915    0.578866    
#> 426: 0.445503    1.147230    3.526298    0.487890    0.014929    0.017927    0.578866    
#> 427: 0.445406    1.147303    3.526266    0.487933    0.014919    0.017946    0.578813    
#> 428: 0.445363    1.147347    3.526270    0.487970    0.014916    0.017946    0.578832    
#> 429: 0.445331    1.147323    3.526281    0.487898    0.014910    0.017941    0.578864    
#> 430: 0.445255    1.147299    3.526325    0.487737    0.014915    0.017950    0.578832    
#> 431: 0.445262    1.147318    3.526321    0.487606    0.014902    0.017952    0.578774    
#> 432: 0.445381    1.147387    3.526330    0.487984    0.014897    0.017964    0.578734    
#> 433: 0.445447    1.147516    3.526347    0.488205    0.014905    0.017974    0.578708    
#> 434: 0.445161    1.147566    3.526251    0.488153    0.014907    0.017980    0.578616    
#> 435: 0.445023    1.147634    3.526188    0.488121    0.014910    0.017987    0.578537    
#> 436: 0.445030    1.147680    3.526193    0.488172    0.014893    0.017978    0.578498    
#> 437: 0.444952    1.147747    3.526185    0.487767    0.014881    0.017978    0.578500    
#> 438: 0.445102    1.147877    3.526211    0.487588    0.014881    0.017963    0.578530    
#> 439: 0.445071    1.147939    3.526198    0.487413    0.014866    0.017961    0.578557    
#> 440: 0.445136    1.147972    3.526202    0.487283    0.014851    0.017958    0.578583    
#> 441: 0.445288    1.147952    3.526197    0.487198    0.014849    0.017954    0.578558    
#> 442: 0.445178    1.147961    3.526251    0.487019    0.014838    0.017948    0.578544    
#> 443: 0.445139    1.147967    3.526229    0.486888    0.014832    0.017948    0.578531    
#> 444: 0.445015    1.147988    3.526180    0.486779    0.014827    0.017950    0.578473    
#> 445: 0.444966    1.148024    3.526154    0.486838    0.014857    0.017943    0.578448    
#> 446: 0.444819    1.148089    3.526097    0.486915    0.014861    0.017942    0.578438    
#> 447: 0.444899    1.148108    3.526074    0.487085    0.014862    0.017940    0.578420    
#> 448: 0.444816    1.148140    3.526034    0.487086    0.014857    0.017947    0.578399    
#> 449: 0.444767    1.148213    3.526075    0.487109    0.014855    0.017955    0.578443    
#> 450: 0.444939    1.148207    3.526079    0.487449    0.014850    0.017950    0.578443    
#> 451: 0.445065    1.148245    3.526077    0.487683    0.014848    0.017950    0.578455    
#> 452: 0.444889    1.148341    3.526033    0.487771    0.014842    0.017954    0.578371    
#> 453: 0.444647    1.148400    3.525989    0.487694    0.014851    0.017947    0.578336    
#> 454: 0.444706    1.148506    3.525966    0.488211    0.014850    0.017940    0.578310    
#> 455: 0.444775    1.148540    3.525928    0.488864    0.014854    0.017933    0.578284    
#> 456: 0.444694    1.148554    3.525902    0.488993    0.014850    0.017938    0.578274    
#> 457: 0.444612    1.148569    3.525915    0.488841    0.014836    0.017932    0.578219    
#> 458: 0.444536    1.148646    3.525953    0.488712    0.014824    0.017939    0.578189    
#> 459: 0.444261    1.148730    3.525928    0.488589    0.014832    0.017953    0.578156    
#> 460: 0.444134    1.148788    3.525882    0.488685    0.014821    0.017974    0.578117    
#> 461: 0.443924    1.148850    3.525841    0.488500    0.014817    0.017986    0.578093    
#> 462: 0.443736    1.148916    3.525822    0.488503    0.014806    0.017984    0.578085    
#> 463: 0.443647    1.148953    3.525800    0.488394    0.014790    0.017980    0.578103    
#> 464: 0.443775    1.149009    3.525800    0.488322    0.014782    0.017972    0.578055    
#> 465: 0.443847    1.148970    3.525820    0.488244    0.014769    0.017979    0.577958    
#> 466: 0.444015    1.148985    3.525802    0.488577    0.014749    0.017988    0.577900    
#> 467: 0.443938    1.148966    3.525810    0.488883    0.014736    0.017995    0.577869    
#> 468: 0.444093    1.148969    3.525821    0.489457    0.014730    0.018002    0.577868    
#> 469: 0.444147    1.149026    3.525826    0.489606    0.014720    0.018018    0.577942    
#> 470: 0.444177    1.149021    3.525807    0.489976    0.014699    0.018038    0.577962    
#> 471: 0.444141    1.149015    3.525764    0.490095    0.014689    0.018040    0.577975    
#> 472: 0.444057    1.149020    3.525735    0.490195    0.014665    0.018045    0.577962    
#> 473: 0.443974    1.149079    3.525681    0.490391    0.014652    0.018055    0.577938    
#> 474: 0.443883    1.149080    3.525625    0.490469    0.014653    0.018063    0.577929    
#> 475: 0.443976    1.149128    3.525615    0.490405    0.014645    0.018063    0.577959    
#> 476: 0.443787    1.149116    3.525565    0.490210    0.014639    0.018058    0.578028    
#> 477: 0.443624    1.149126    3.525561    0.490129    0.014626    0.018049    0.578003    
#> 478: 0.443493    1.149111    3.525550    0.490194    0.014631    0.018039    0.578054    
#> 479: 0.443391    1.149148    3.525537    0.490146    0.014627    0.018030    0.578039    
#> 480: 0.443352    1.149169    3.525489    0.490519    0.014619    0.018024    0.578065    
#> 481: 0.443213    1.149199    3.525414    0.490645    0.014612    0.018024    0.578047    
#> 482: 0.443175    1.149233    3.525325    0.491053    0.014608    0.018034    0.578068    
#> 483: 0.443051    1.149262    3.525286    0.491043    0.014588    0.018040    0.578102    
#> 484: 0.443048    1.149210    3.525296    0.491090    0.014574    0.018050    0.578088    
#> 485: 0.443037    1.149221    3.525297    0.491282    0.014585    0.018059    0.578090    
#> 486: 0.442965    1.149288    3.525305    0.491366    0.014588    0.018063    0.578092    
#> 487: 0.442953    1.149377    3.525319    0.491468    0.014590    0.018077    0.578073    
#> 488: 0.442921    1.149349    3.525331    0.491638    0.014581    0.018097    0.578042    
#> 489: 0.442983    1.149308    3.525353    0.491560    0.014580    0.018115    0.578072    
#> 490: 0.443095    1.149340    3.525398    0.491471    0.014569    0.018135    0.578097    
#> 491: 0.443190    1.149406    3.525447    0.491561    0.014565    0.018152    0.578122    
#> 492: 0.443144    1.149462    3.525450    0.491422    0.014567    0.018170    0.578176    
#> 493: 0.443084    1.149482    3.525454    0.491506    0.014574    0.018188    0.578220    
#> 494: 0.443128    1.149552    3.525439    0.491571    0.014566    0.018190    0.578192    
#> 495: 0.443170    1.149586    3.525479    0.491439    0.014564    0.018200    0.578141    
#> 496: 0.443334    1.149644    3.525495    0.491537    0.014563    0.018205    0.578121    
#> 497: 0.443405    1.149654    3.525518    0.491613    0.014571    0.018199    0.578098    
#> 498: 0.443414    1.149671    3.525509    0.491523    0.014566    0.018190    0.578076    
#> 499: 0.443403    1.149693    3.525487    0.491627    0.014580    0.018186    0.578042    
#> 500: 0.443409    1.149689    3.525456    0.491844    0.014588    0.018182    0.578040    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.285703    0.977533    3.437770    0.392401    0.073420    0.016800    1.752371    
#> 002: 0.251485    0.987421    3.473279    0.372781    0.070373    0.017127    1.241543    
#> 003: 0.370588    0.938761    3.468346    0.354142    0.066854    0.016271    0.964191    
#> 004: 0.294877    0.942215    3.476637    0.336435    0.063511    0.018901    0.861213    
#> 005: 0.360402    0.957368    3.474270    0.319613    0.074906    0.018120    0.791706    
#> 006: 0.336868    0.983111    3.469746    0.303633    0.081784    0.017214    0.751446    
#> 007: 0.286458    0.987992    3.457578    0.288451    0.090282    0.016353    0.758156    
#> 008: 0.320017    0.975105    3.456555    0.274029    0.085768    0.016646    0.750979    
#> 009: 0.292689    0.953067    3.457493    0.260327    0.081479    0.015813    0.744001    
#> 010: 0.287474    0.960488    3.454180    0.247311    0.077405    0.015023    0.755524    
#> 011: 0.344369    0.978682    3.462126    0.234945    0.081012    0.014803    0.773311    
#> 012: 0.342161    0.985384    3.454780    0.223198    0.081132    0.014063    0.755161    
#> 013: 0.280916    0.959230    3.456295    0.212038    0.077076    0.014893    0.765322    
#> 014: 0.344496    0.962023    3.470364    0.201436    0.073222    0.018877    0.776317    
#> 015: 0.352556    0.958923    3.478139    0.191364    0.090894    0.017934    0.735124    
#> 016: 0.340930    0.973705    3.487117    0.181796    0.105496    0.017037    0.743923    
#> 017: 0.357880    0.970374    3.488769    0.172706    0.106998    0.016185    0.731702    
#> 018: 0.371839    0.950730    3.486488    0.164071    0.101648    0.015376    0.750333    
#> 019: 0.337605    0.955369    3.480118    0.155867    0.099883    0.014725    0.743344    
#> 020: 0.354416    0.944042    3.485487    0.169644    0.110535    0.015342    0.737034    
#> 021: 0.338584    0.942103    3.487205    0.161162    0.122801    0.015065    0.723702    
#> 022: 0.369768    0.954254    3.500321    0.153104    0.116661    0.014617    0.735557    
#> 023: 0.435612    0.944162    3.510004    0.157243    0.110828    0.013890    0.753740    
#> 024: 0.435498    0.950872    3.514449    0.149381    0.108249    0.013195    0.769585    
#> 025: 0.402279    0.914109    3.507325    0.141912    0.102836    0.012535    0.758803    
#> 026: 0.380140    0.960830    3.493419    0.134816    0.097695    0.011909    0.763206    
#> 027: 0.345943    0.991285    3.476475    0.128984    0.096527    0.011313    0.767778    
#> 028: 0.370110    0.961834    3.483939    0.156493    0.111684    0.010748    0.737333    
#> 029: 0.352456    0.980805    3.472289    0.163557    0.114096    0.014056    0.749675    
#> 030: 0.372927    0.976088    3.470662    0.155380    0.108391    0.013353    0.741287    
#> 031: 0.352995    0.963051    3.485760    0.173748    0.102972    0.012685    0.728110    
#> 032: 0.343946    0.961333    3.480941    0.175902    0.100909    0.012051    0.723113    
#> 033: 0.351368    0.971717    3.473956    0.167107    0.104669    0.011449    0.738807    
#> 034: 0.368619    0.978366    3.480464    0.158752    0.099436    0.010876    0.735510    
#> 035: 0.339426    0.961355    3.471307    0.161852    0.094464    0.010332    0.734978    
#> 036: 0.310139    0.999939    3.460878    0.170345    0.101854    0.009816    0.758495    
#> 037: 0.299317    0.981836    3.461774    0.161827    0.112896    0.009325    0.752080    
#> 038: 0.341219    0.989776    3.452109    0.153736    0.113903    0.009265    0.759112    
#> 039: 0.342135    0.991559    3.460113    0.163314    0.108208    0.008802    0.755064    
#> 040: 0.294817    0.988652    3.466232    0.155148    0.115414    0.008496    0.752039    
#> 041: 0.280569    0.977644    3.463753    0.172567    0.110312    0.008071    0.743822    
#> 042: 0.341966    0.969119    3.466162    0.163939    0.105807    0.007667    0.741326    
#> 043: 0.309070    0.987439    3.457023    0.158189    0.105218    0.007542    0.729701    
#> 044: 0.269880    1.002954    3.454531    0.175294    0.111017    0.007796    0.749993    
#> 045: 0.288720    1.015485    3.442753    0.166530    0.108506    0.007407    0.765625    
#> 046: 0.314918    0.988681    3.450440    0.176689    0.104704    0.007036    0.751677    
#> 047: 0.336900    0.990518    3.444908    0.175214    0.118914    0.008358    0.733608    
#> 048: 0.337373    0.976649    3.448102    0.175344    0.112968    0.007940    0.747971    
#> 049: 0.313796    0.990643    3.450329    0.211287    0.107319    0.007543    0.741079    
#> 050: 0.352376    0.955256    3.456588    0.200723    0.115002    0.009902    0.766319    
#> 051: 0.353456    0.986472    3.453780    0.190686    0.115454    0.010587    0.777560    
#> 052: 0.346719    0.998997    3.461061    0.181152    0.110021    0.010058    0.730820    
#> 053: 0.342845    0.990099    3.462636    0.172094    0.115816    0.009984    0.767889    
#> 054: 0.273990    0.990432    3.458702    0.163490    0.112204    0.012176    0.761971    
#> 055: 0.291931    0.983087    3.456092    0.186500    0.125594    0.011568    0.761182    
#> 056: 0.300706    0.957021    3.466100    0.189873    0.128790    0.010989    0.779394    
#> 057: 0.310279    0.935492    3.484204    0.180379    0.127182    0.010440    0.785129    
#> 058: 0.349043    0.939942    3.470290    0.184289    0.121420    0.009918    0.777280    
#> 059: 0.340560    0.913494    3.477712    0.175075    0.121409    0.009422    0.770547    
#> 060: 0.341793    0.928220    3.481271    0.166321    0.119828    0.011937    0.765794    
#> 061: 0.381562    0.940488    3.488033    0.158005    0.113837    0.014851    0.768680    
#> 062: 0.361317    0.949741    3.491996    0.150105    0.110597    0.017002    0.776195    
#> 063: 0.382989    0.937472    3.486983    0.142599    0.105067    0.016152    0.786655    
#> 064: 0.377524    0.956262    3.488225    0.144910    0.109172    0.015344    0.748138    
#> 065: 0.380455    0.930162    3.483723    0.149359    0.106757    0.014577    0.753875    
#> 066: 0.395271    0.950741    3.487531    0.162921    0.101419    0.014691    0.749158    
#> 067: 0.350659    0.949121    3.481319    0.154775    0.101190    0.013956    0.754511    
#> 068: 0.313681    0.954607    3.480644    0.149228    0.096131    0.013259    0.777211    
#> 069: 0.340530    0.948181    3.472619    0.162400    0.098379    0.012596    0.771011    
#> 070: 0.356118    0.955681    3.487786    0.154280    0.131302    0.011966    0.757143    
#> 071: 0.334019    0.970082    3.468288    0.146566    0.124737    0.011368    0.756105    
#> 072: 0.274179    0.964331    3.457117    0.162534    0.118500    0.010799    0.755091    
#> 073: 0.333344    0.968187    3.475501    0.154407    0.112575    0.010259    0.742712    
#> 074: 0.311631    0.962943    3.474800    0.155113    0.112375    0.009746    0.739083    
#> 075: 0.328714    0.949271    3.485011    0.152901    0.110952    0.009444    0.726512    
#> 076: 0.377646    0.967742    3.501164    0.184279    0.108899    0.008972    0.734746    
#> 077: 0.379376    0.931999    3.487968    0.176905    0.117449    0.008523    0.732765    
#> 078: 0.379521    0.977264    3.490799    0.168060    0.117424    0.010282    0.729878    
#> 079: 0.376173    0.976187    3.498977    0.159657    0.136833    0.014173    0.754758    
#> 080: 0.368643    0.959763    3.487002    0.151674    0.129991    0.013465    0.792402    
#> 081: 0.368601    0.979690    3.475445    0.146817    0.123492    0.012791    0.767999    
#> 082: 0.368112    0.959660    3.483747    0.151442    0.117317    0.012152    0.760819    
#> 083: 0.367664    1.001591    3.486095    0.148085    0.111451    0.011544    0.735796    
#> 084: 0.367708    0.991281    3.477393    0.140681    0.116001    0.010967    0.733979    
#> 085: 0.343801    0.981317    3.486815    0.138090    0.112983    0.010661    0.752907    
#> 086: 0.343763    0.980159    3.474513    0.145479    0.107334    0.011380    0.738933    
#> 087: 0.320235    0.985615    3.459962    0.162680    0.101967    0.010811    0.726852    
#> 088: 0.255417    0.967711    3.457429    0.165402    0.096869    0.013222    0.761546    
#> 089: 0.304233    0.986868    3.450905    0.170037    0.092025    0.014177    0.743665    
#> 090: 0.293873    0.986232    3.449935    0.161535    0.103920    0.013468    0.754274    
#> 091: 0.276872    0.987200    3.436653    0.153459    0.107934    0.012795    0.768540    
#> 092: 0.274356    1.011064    3.433172    0.157593    0.123338    0.012155    0.763542    
#> 093: 0.268397    1.000306    3.434977    0.175280    0.117171    0.011547    0.747810    
#> 094: 0.249326    1.008422    3.436290    0.196195    0.111599    0.010970    0.757699    
#> 095: 0.285923    1.002991    3.452749    0.186385    0.109510    0.010421    0.757246    
#> 096: 0.280465    0.981337    3.454764    0.177066    0.104034    0.011709    0.759351    
#> 097: 0.319649    1.007947    3.453413    0.191704    0.105990    0.011124    0.732524    
#> 098: 0.313330    0.994487    3.461110    0.212866    0.103844    0.010568    0.752942    
#> 099: 0.313077    0.972962    3.449567    0.202222    0.110730    0.010039    0.762283    
#> 100: 0.297735    0.972175    3.458473    0.192111    0.105193    0.010066    0.737448    
#> 101: 0.260247    0.975246    3.443597    0.182506    0.099934    0.010141    0.741399    
#> 102: 0.268104    0.994636    3.437741    0.174067    0.097368    0.011028    0.740318    
#> 103: 0.319974    1.004773    3.457027    0.187613    0.119891    0.010477    0.717166    
#> 104: 0.296148    0.999044    3.461352    0.178232    0.127764    0.009953    0.751616    
#> 105: 0.305714    0.991276    3.452658    0.169321    0.130727    0.009455    0.741524    
#> 106: 0.325520    0.988883    3.447812    0.160854    0.124191    0.008982    0.734888    
#> 107: 0.338664    0.996497    3.454195    0.152812    0.117981    0.008533    0.755455    
#> 108: 0.300787    0.981500    3.444175    0.145171    0.112082    0.008107    0.761314    
#> 109: 0.264940    1.004239    3.453276    0.148021    0.106478    0.007701    0.749998    
#> 110: 0.284513    0.990081    3.436151    0.184528    0.127587    0.007316    0.736610    
#> 111: 0.274267    0.982369    3.444115    0.177654    0.121207    0.006950    0.741532    
#> 112: 0.279929    0.962405    3.448562    0.175163    0.131960    0.006603    0.747082    
#> 113: 0.295681    0.986314    3.448911    0.210497    0.143196    0.006273    0.737536    
#> 114: 0.302566    0.965919    3.455750    0.207775    0.154988    0.005959    0.743695    
#> 115: 0.346799    0.954779    3.458859    0.220794    0.147238    0.005661    0.754241    
#> 116: 0.345254    1.002724    3.463008    0.209754    0.139876    0.006111    0.752778    
#> 117: 0.334522    0.969886    3.470579    0.199266    0.132883    0.007336    0.744835    
#> 118: 0.320645    0.950529    3.471920    0.189303    0.127433    0.006969    0.753151    
#> 119: 0.335622    0.950730    3.470496    0.179838    0.121061    0.007428    0.754963    
#> 120: 0.327816    0.952915    3.471613    0.170846    0.115008    0.008586    0.746797    
#> 121: 0.333923    0.983784    3.469890    0.162304    0.109258    0.008157    0.763977    
#> 122: 0.331690    0.952639    3.472934    0.154188    0.103795    0.007749    0.755904    
#> 123: 0.380659    0.983169    3.471374    0.156447    0.098605    0.008306    0.739674    
#> 124: 0.375405    1.004332    3.468752    0.148624    0.095360    0.009136    0.754422    
#> 125: 0.374698    1.018049    3.456216    0.141193    0.105336    0.010114    0.756536    
#> 126: 0.318342    1.006843    3.444139    0.134133    0.100069    0.010922    0.756256    
#> 127: 0.319000    0.990213    3.441438    0.138825    0.095975    0.010988    0.763563    
#> 128: 0.297730    0.983977    3.464489    0.139583    0.125530    0.011856    0.751669    
#> 129: 0.314641    0.997953    3.460348    0.138795    0.121998    0.011263    0.761260    
#> 130: 0.332500    0.998818    3.458120    0.131855    0.124652    0.011588    0.727488    
#> 131: 0.329414    0.959995    3.454671    0.145181    0.118420    0.013154    0.757457    
#> 132: 0.290496    0.995206    3.436844    0.140475    0.112499    0.012497    0.769078    
#> 133: 0.302047    1.001060    3.444051    0.149520    0.106874    0.011872    0.754289    
#> 134: 0.323337    0.973735    3.461113    0.165828    0.104322    0.011278    0.749786    
#> 135: 0.316132    0.962438    3.462944    0.163850    0.142155    0.010714    0.743812    
#> 136: 0.330600    0.950304    3.467516    0.157149    0.135048    0.010179    0.734946    
#> 137: 0.356689    0.959489    3.469835    0.182660    0.128295    0.009670    0.735110    
#> 138: 0.340239    0.982173    3.467612    0.177827    0.124103    0.009186    0.742716    
#> 139: 0.372199    0.965688    3.483518    0.168936    0.117898    0.009327    0.751913    
#> 140: 0.353124    0.972462    3.483141    0.161248    0.138115    0.008861    0.757886    
#> 141: 0.323467    0.949067    3.477702    0.153186    0.149984    0.008418    0.746798    
#> 142: 0.349510    0.946089    3.482242    0.160933    0.142485    0.007997    0.750941    
#> 143: 0.327715    0.969999    3.480179    0.152887    0.135360    0.008474    0.748992    
#> 144: 0.405543    0.956999    3.502744    0.168361    0.128592    0.008233    0.739223    
#> 145: 0.391672    0.965477    3.484244    0.163763    0.122163    0.008878    0.743576    
#> 146: 0.345666    0.960622    3.475872    0.155575    0.118156    0.008434    0.753888    
#> 147: 0.315491    0.941998    3.469241    0.152170    0.112248    0.008636    0.737614    
#> 148: 0.331789    0.965973    3.478179    0.158771    0.116676    0.009256    0.736278    
#> 149: 0.342226    0.968492    3.476704    0.172590    0.110842    0.008793    0.749708    
#> 150: 0.342058    0.969634    3.462395    0.188981    0.116455    0.008353    0.739681    
#> 151: 0.306768    0.986081    3.461212    0.179532    0.114559    0.007935    0.742857    
#> 152: 0.302447    0.973049    3.468967    0.166293    0.114605    0.007080    0.745171    
#> 153: 0.275406    0.966450    3.467464    0.176449    0.124013    0.008259    0.762823    
#> 154: 0.346722    0.978265    3.473040    0.161452    0.117799    0.008627    0.748848    
#> 155: 0.328024    0.969848    3.471776    0.164444    0.137290    0.008085    0.747675    
#> 156: 0.326070    0.952958    3.487683    0.209524    0.144324    0.007865    0.746242    
#> 157: 0.364962    0.934664    3.488353    0.167914    0.138898    0.006346    0.758724    
#> 158: 0.395727    0.971774    3.488022    0.149503    0.108067    0.007472    0.740917    
#> 159: 0.346737    0.964706    3.489747    0.139731    0.119915    0.007065    0.742616    
#> 160: 0.376433    0.928869    3.495068    0.143277    0.098974    0.007859    0.755509    
#> 161: 0.372647    0.951010    3.490462    0.158690    0.114956    0.007931    0.748858    
#> 162: 0.358083    0.964713    3.471052    0.181844    0.113281    0.008627    0.729852    
#> 163: 0.367556    0.971731    3.467201    0.167801    0.114244    0.009842    0.742506    
#> 164: 0.330431    0.973833    3.468864    0.156509    0.118747    0.011576    0.742360    
#> 165: 0.367987    0.944031    3.481676    0.185125    0.115934    0.011343    0.750037    
#> 166: 0.387067    0.996216    3.483751    0.154473    0.108995    0.006518    0.746917    
#> 167: 0.362016    1.003169    3.478239    0.151900    0.120812    0.007504    0.748394    
#> 168: 0.369896    0.969699    3.479759    0.175211    0.129902    0.007886    0.757543    
#> 169: 0.342548    1.022983    3.473686    0.187688    0.136838    0.008104    0.769390    
#> 170: 0.321686    1.005603    3.456538    0.185152    0.127334    0.008182    0.745360    
#> 171: 0.285976    0.997992    3.455568    0.187990    0.110971    0.008268    0.734950    
#> 172: 0.287932    1.002960    3.447217    0.187796    0.099917    0.006688    0.729937    
#> 173: 0.298994    1.003839    3.441279    0.138025    0.106324    0.008378    0.752469    
#> 174: 0.290779    1.007463    3.443468    0.194894    0.111121    0.008249    0.740346    
#> 175: 0.268619    1.022125    3.431917    0.183476    0.112073    0.009123    0.750116    
#> 176: 0.299030    1.015211    3.451067    0.182576    0.100150    0.010396    0.757393    
#> 177: 0.322984    0.980834    3.467252    0.148484    0.100458    0.013122    0.717782    
#> 178: 0.346859    0.966482    3.467227    0.168704    0.111768    0.009644    0.739589    
#> 179: 0.362990    0.988107    3.461864    0.163609    0.116646    0.009151    0.751681    
#> 180: 0.315622    0.997137    3.458458    0.214558    0.112773    0.008446    0.751074    
#> 181: 0.301839    1.006821    3.437416    0.188869    0.114120    0.007110    0.733943    
#> 182: 0.253527    1.010412    3.427261    0.224600    0.120941    0.006695    0.744244    
#> 183: 0.292003    1.028879    3.426884    0.227689    0.112469    0.007350    0.741534    
#> 184: 0.293260    1.010258    3.429706    0.233463    0.124658    0.006439    0.734472    
#> 185: 0.272338    1.024996    3.430626    0.205958    0.136665    0.005972    0.745856    
#> 186: 0.290624    1.025062    3.436168    0.181778    0.109890    0.005940    0.755710    
#> 187: 0.290390    0.992977    3.443728    0.162831    0.111968    0.006667    0.742590    
#> 188: 0.266345    1.001809    3.438815    0.168924    0.124964    0.007035    0.768909    
#> 189: 0.293317    1.010249    3.442835    0.157062    0.109652    0.007950    0.758581    
#> 190: 0.282991    1.007108    3.447552    0.199057    0.122798    0.007230    0.731900    
#> 191: 0.259096    0.996676    3.441718    0.150463    0.115783    0.006990    0.752628    
#> 192: 0.286461    1.013445    3.452796    0.142725    0.130342    0.006103    0.736423    
#> 193: 0.302777    1.005741    3.451344    0.130180    0.117507    0.006596    0.728569    
#> 194: 0.302853    0.987416    3.444304    0.121330    0.098020    0.008396    0.750682    
#> 195: 0.283720    0.980243    3.450511    0.136981    0.114899    0.008555    0.731727    
#> 196: 0.292907    0.978208    3.461650    0.154251    0.132112    0.006914    0.745082    
#> 197: 0.284139    0.969642    3.473724    0.162594    0.116520    0.006590    0.765632    
#> 198: 0.344514    0.963557    3.467880    0.117598    0.128898    0.006388    0.742862    
#> 199: 0.317642    0.976782    3.466714    0.132825    0.101848    0.008325    0.748552    
#> 200: 0.321937    0.984284    3.465853    0.132931    0.113315    0.007140    0.765072    
#> 201: 0.321506    0.975686    3.465683    0.139913    0.113032    0.007104    0.759407    
#> 202: 0.320035    0.977871    3.465594    0.134386    0.111469    0.007846    0.753291    
#> 203: 0.326821    0.978147    3.463408    0.135284    0.107163    0.008278    0.752747    
#> 204: 0.333176    0.972494    3.464319    0.137969    0.107281    0.008461    0.752934    
#> 205: 0.329595    0.980121    3.464068    0.143863    0.105932    0.008828    0.753706    
#> 206: 0.327189    0.984667    3.462601    0.148055    0.106042    0.008821    0.757053    
#> 207: 0.323138    0.982269    3.461253    0.150097    0.107517    0.008707    0.756921    
#> 208: 0.322344    0.983621    3.460685    0.157038    0.108155    0.008551    0.754704    
#> 209: 0.323460    0.981529    3.460043    0.160139    0.109793    0.008671    0.753571    
#> 210: 0.323812    0.979245    3.459781    0.160513    0.109705    0.008753    0.751847    
#> 211: 0.323342    0.980482    3.459493    0.160257    0.110579    0.008755    0.750521    
#> 212: 0.324947    0.979056    3.460257    0.160559    0.110851    0.008764    0.748913    
#> 213: 0.327625    0.975417    3.461391    0.165956    0.109812    0.008770    0.748612    
#> 214: 0.329246    0.974435    3.461801    0.166029    0.108821    0.008815    0.748931    
#> 215: 0.329114    0.974939    3.461973    0.165881    0.108684    0.008862    0.748336    
#> 216: 0.330131    0.973880    3.461708    0.164903    0.109308    0.008854    0.748739    
#> 217: 0.330633    0.975064    3.461446    0.163430    0.110204    0.008960    0.748237    
#> 218: 0.329605    0.976202    3.460718    0.163828    0.110489    0.008981    0.747169    
#> 219: 0.328230    0.975715    3.459783    0.164944    0.109983    0.008906    0.746970    
#> 220: 0.326652    0.976261    3.459681    0.165690    0.109863    0.008749    0.746918    
#> 221: 0.325581    0.976991    3.459637    0.165569    0.110784    0.008618    0.746987    
#> 222: 0.325087    0.977057    3.459368    0.165936    0.111871    0.008505    0.748393    
#> 223: 0.326393    0.977634    3.459049    0.166700    0.112430    0.008441    0.747924    
#> 224: 0.327920    0.978954    3.459248    0.165979    0.113400    0.008431    0.747849    
#> 225: 0.327440    0.978042    3.459511    0.165614    0.113787    0.008458    0.747485    
#> 226: 0.327118    0.977580    3.459288    0.164731    0.113487    0.008445    0.747431    
#> 227: 0.326057    0.977892    3.459380    0.165114    0.113709    0.008363    0.747595    
#> 228: 0.324996    0.978793    3.459043    0.165086    0.113706    0.008310    0.747970    
#> 229: 0.324119    0.979055    3.458802    0.165622    0.113375    0.008270    0.747417    
#> 230: 0.323461    0.978835    3.458586    0.166161    0.113190    0.008257    0.746950    
#> 231: 0.323658    0.979413    3.458974    0.167219    0.113796    0.008255    0.746843    
#> 232: 0.321917    0.979894    3.459086    0.167280    0.113838    0.008268    0.747264    
#> 233: 0.321670    0.979434    3.459067    0.166181    0.114234    0.008286    0.747175    
#> 234: 0.320947    0.978687    3.459113    0.165548    0.114215    0.008312    0.747361    
#> 235: 0.321371    0.979103    3.458741    0.165528    0.114694    0.008271    0.747712    
#> 236: 0.322154    0.979537    3.458715    0.166337    0.115143    0.008353    0.748293    
#> 237: 0.323353    0.979677    3.458913    0.167929    0.114908    0.008444    0.748650    
#> 238: 0.323840    0.979530    3.458934    0.168386    0.114767    0.008455    0.748936    
#> 239: 0.323484    0.979826    3.458958    0.168544    0.114504    0.008507    0.748798    
#> 240: 0.323647    0.979549    3.459131    0.167681    0.114132    0.008527    0.748728    
#> 241: 0.324385    0.978566    3.459666    0.166510    0.113916    0.008558    0.748746    
#> 242: 0.324321    0.977912    3.459782    0.166493    0.114137    0.008595    0.749104    
#> 243: 0.323968    0.978669    3.459893    0.165756    0.114126    0.008636    0.749544    
#> 244: 0.323851    0.978372    3.460101    0.165591    0.114152    0.008674    0.749719    
#> 245: 0.323423    0.977752    3.460281    0.165858    0.113931    0.008683    0.749912    
#> 246: 0.323546    0.977235    3.460588    0.165557    0.113779    0.008736    0.750198    
#> 247: 0.323009    0.976927    3.460906    0.165882    0.114158    0.008755    0.749970    
#> 248: 0.322664    0.977015    3.460918    0.165847    0.114606    0.008767    0.750052    
#> 249: 0.321896    0.977409    3.460838    0.166353    0.115270    0.008722    0.749848    
#> 250: 0.322446    0.977573    3.460946    0.166708    0.115379    0.008712    0.750018    
#> 251: 0.322716    0.978052    3.461217    0.167556    0.115818    0.008708    0.750221    
#> 252: 0.323121    0.978151    3.461533    0.168089    0.116161    0.008739    0.750431    
#> 253: 0.323481    0.978054    3.461856    0.168392    0.115918    0.008777    0.750114    
#> 254: 0.323085    0.978504    3.462081    0.168004    0.115765    0.008782    0.749763    
#> 255: 0.322902    0.979000    3.462307    0.167848    0.115671    0.008781    0.749560    
#> 256: 0.323023    0.978941    3.462175    0.167564    0.115615    0.008799    0.749490    
#> 257: 0.322446    0.979029    3.462003    0.167500    0.115633    0.008817    0.749587    
#> 258: 0.322221    0.978755    3.461973    0.167342    0.115429    0.008838    0.749652    
#> 259: 0.322243    0.978969    3.461888    0.167303    0.115181    0.008839    0.749686    
#> 260: 0.322245    0.979697    3.461991    0.167165    0.115185    0.008844    0.749642    
#> 261: 0.322305    0.979855    3.462023    0.167281    0.115228    0.008875    0.749428    
#> 262: 0.322662    0.980109    3.462084    0.166990    0.115073    0.008911    0.749590    
#> 263: 0.322453    0.980366    3.462131    0.166723    0.115302    0.008973    0.749634    
#> 264: 0.321861    0.980584    3.461975    0.166326    0.115153    0.008963    0.750253    
#> 265: 0.321593    0.980710    3.461818    0.165755    0.115244    0.008998    0.750405    
#> 266: 0.322033    0.980991    3.461772    0.165504    0.115184    0.009020    0.750498    
#> 267: 0.322237    0.980904    3.461793    0.165298    0.115105    0.009038    0.750553    
#> 268: 0.322312    0.980416    3.461606    0.165234    0.114919    0.009027    0.750753    
#> 269: 0.322684    0.980330    3.461560    0.165285    0.114921    0.009014    0.751018    
#> 270: 0.323168    0.980264    3.461463    0.165306    0.114997    0.008973    0.750700    
#> 271: 0.323201    0.980119    3.461306    0.165587    0.114801    0.008975    0.750875    
#> 272: 0.322886    0.980029    3.461117    0.166238    0.114572    0.008973    0.751040    
#> 273: 0.322865    0.980157    3.461102    0.166220    0.114498    0.008955    0.751344    
#> 274: 0.322558    0.980010    3.461253    0.166384    0.114916    0.008971    0.751372    
#> 275: 0.322342    0.980256    3.461135    0.166661    0.114852    0.008977    0.751313    
#> 276: 0.322113    0.980205    3.461275    0.166572    0.114813    0.008993    0.751154    
#> 277: 0.322025    0.980310    3.461371    0.166644    0.114910    0.009009    0.750868    
#> 278: 0.321995    0.980381    3.461509    0.166416    0.115005    0.009009    0.750786    
#> 279: 0.321844    0.980085    3.461692    0.166110    0.114996    0.008997    0.750916    
#> 280: 0.321834    0.980263    3.461758    0.165754    0.114867    0.009012    0.750659    
#> 281: 0.321740    0.980183    3.461910    0.165554    0.114598    0.009030    0.750517    
#> 282: 0.321699    0.980258    3.461965    0.165392    0.114374    0.009040    0.750339    
#> 283: 0.321881    0.980162    3.462007    0.165401    0.114235    0.009049    0.750562    
#> 284: 0.321678    0.980160    3.462031    0.165057    0.114215    0.009052    0.750446    
#> 285: 0.321996    0.980215    3.462027    0.165253    0.114212    0.009056    0.750577    
#> 286: 0.321999    0.980427    3.461974    0.165504    0.114190    0.009050    0.750757    
#> 287: 0.321990    0.980620    3.461887    0.165695    0.114115    0.009048    0.750983    
#> 288: 0.322413    0.980686    3.461858    0.165950    0.114320    0.009057    0.750941    
#> 289: 0.322787    0.980701    3.461895    0.166333    0.114230    0.009061    0.750879    
#> 290: 0.322982    0.980552    3.461929    0.166458    0.114081    0.009079    0.750917    
#> 291: 0.323358    0.980748    3.462149    0.166266    0.114052    0.009129    0.750695    
#> 292: 0.323393    0.980380    3.462354    0.166165    0.113973    0.009147    0.750772    
#> 293: 0.323288    0.980140    3.462358    0.166207    0.113973    0.009144    0.750703    
#> 294: 0.323126    0.980067    3.462332    0.166229    0.113955    0.009143    0.750539    
#> 295: 0.323089    0.979636    3.462358    0.166369    0.114010    0.009150    0.750552    
#> 296: 0.323285    0.979421    3.462458    0.166200    0.113842    0.009191    0.750687    
#> 297: 0.323707    0.979234    3.462562    0.166333    0.113670    0.009239    0.750728    
#> 298: 0.323808    0.979055    3.462513    0.166150    0.113445    0.009268    0.750686    
#> 299: 0.324005    0.979000    3.462549    0.166254    0.113458    0.009269    0.750665    
#> 300: 0.324258    0.978798    3.462718    0.166130    0.113440    0.009301    0.750491    
#> 301: 0.324481    0.978680    3.462701    0.165775    0.113601    0.009317    0.750571    
#> 302: 0.324344    0.978843    3.462617    0.165676    0.113621    0.009321    0.750423    
#> 303: 0.324290    0.978957    3.462603    0.165650    0.113696    0.009299    0.750200    
#> 304: 0.324363    0.979294    3.462444    0.165434    0.113717    0.009292    0.750163    
#> 305: 0.324039    0.979003    3.462401    0.165368    0.113658    0.009287    0.750221    
#> 306: 0.323599    0.979054    3.462251    0.165516    0.113575    0.009279    0.750235    
#> 307: 0.323762    0.979056    3.462171    0.165601    0.113468    0.009272    0.750197    
#> 308: 0.323564    0.979018    3.462080    0.165773    0.113560    0.009267    0.750102    
#> 309: 0.323361    0.978823    3.461979    0.165815    0.113578    0.009288    0.750269    
#> 310: 0.323306    0.978760    3.461808    0.166087    0.113615    0.009275    0.750128    
#> 311: 0.322926    0.978835    3.461677    0.166121    0.113569    0.009272    0.749963    
#> 312: 0.322685    0.978917    3.461548    0.166123    0.113622    0.009295    0.749919    
#> 313: 0.322360    0.978700    3.461393    0.166373    0.113858    0.009322    0.750054    
#> 314: 0.321844    0.978740    3.461309    0.166006    0.113956    0.009331    0.750138    
#> 315: 0.321272    0.978976    3.461192    0.165907    0.114014    0.009349    0.750187    
#> 316: 0.321261    0.979032    3.461060    0.165741    0.113916    0.009361    0.750224    
#> 317: 0.321234    0.978992    3.461081    0.165689    0.113754    0.009356    0.750162    
#> 318: 0.321094    0.979129    3.460976    0.165830    0.113687    0.009338    0.749945    
#> 319: 0.321090    0.979217    3.460940    0.165894    0.113618    0.009343    0.749850    
#> 320: 0.321011    0.979301    3.460872    0.165981    0.113523    0.009353    0.749867    
#> 321: 0.320870    0.979340    3.460740    0.166313    0.113407    0.009360    0.749969    
#> 322: 0.320804    0.979440    3.460644    0.166138    0.113324    0.009348    0.750050    
#> 323: 0.320290    0.979605    3.460508    0.165986    0.113198    0.009333    0.750097    
#> 324: 0.320174    0.979872    3.460456    0.165604    0.113260    0.009340    0.750005    
#> 325: 0.319806    0.980119    3.460300    0.165440    0.113171    0.009350    0.749866    
#> 326: 0.319725    0.979913    3.460239    0.165244    0.113148    0.009358    0.749844    
#> 327: 0.319920    0.980016    3.460282    0.165049    0.113250    0.009379    0.749867    
#> 328: 0.320047    0.980284    3.460342    0.164801    0.113257    0.009382    0.749836    
#> 329: 0.320349    0.980330    3.460439    0.164786    0.113306    0.009399    0.749794    
#> 330: 0.320515    0.980263    3.460520    0.164847    0.113281    0.009409    0.749790    
#> 331: 0.320748    0.980266    3.460601    0.164844    0.113282    0.009407    0.749682    
#> 332: 0.320832    0.980176    3.460642    0.164646    0.113233    0.009399    0.749660    
#> 333: 0.320896    0.980192    3.460663    0.164732    0.113303    0.009392    0.749591    
#> 334: 0.320813    0.980043    3.460617    0.164794    0.113451    0.009373    0.749385    
#> 335: 0.320617    0.980156    3.460514    0.164637    0.113677    0.009367    0.749355    
#> 336: 0.320236    0.980282    3.460416    0.164575    0.113875    0.009370    0.749539    
#> 337: 0.320275    0.980452    3.460296    0.164670    0.113925    0.009361    0.749590    
#> 338: 0.320377    0.980369    3.460316    0.164657    0.113935    0.009364    0.749559    
#> 339: 0.320291    0.980352    3.460333    0.164621    0.113972    0.009380    0.749580    
#> 340: 0.320285    0.980072    3.460459    0.164581    0.114011    0.009377    0.749481    
#> 341: 0.320589    0.980065    3.460527    0.164581    0.114088    0.009371    0.749551    
#> 342: 0.320431    0.979874    3.460552    0.164465    0.114126    0.009374    0.749437    
#> 343: 0.320402    0.979860    3.460627    0.164623    0.114028    0.009367    0.749422    
#> 344: 0.320542    0.979668    3.460672    0.164755    0.114075    0.009387    0.749411    
#> 345: 0.320703    0.979614    3.460711    0.164861    0.113975    0.009409    0.749317    
#> 346: 0.320745    0.979660    3.460669    0.165014    0.113893    0.009418    0.749115    
#> 347: 0.320716    0.979730    3.460574    0.164836    0.113852    0.009425    0.749185    
#> 348: 0.320575    0.979833    3.460537    0.164830    0.113798    0.009437    0.749208    
#> 349: 0.320592    0.979797    3.460515    0.164917    0.113739    0.009454    0.749159    
#> 350: 0.320454    0.979667    3.460462    0.164760    0.113625    0.009448    0.749207    
#> 351: 0.320433    0.979912    3.460402    0.164775    0.113489    0.009438    0.749331    
#> 352: 0.320032    0.980141    3.460366    0.164931    0.113415    0.009439    0.749376    
#> 353: 0.320006    0.980335    3.460308    0.165130    0.113375    0.009431    0.749261    
#> 354: 0.319910    0.980467    3.460179    0.165279    0.113365    0.009442    0.749128    
#> 355: 0.320120    0.980464    3.460106    0.165417    0.113446    0.009449    0.749140    
#> 356: 0.320066    0.980427    3.460159    0.165519    0.113437    0.009457    0.749292    
#> 357: 0.320144    0.980555    3.460173    0.165512    0.113489    0.009456    0.749255    
#> 358: 0.320211    0.980617    3.460239    0.165481    0.113666    0.009446    0.749141    
#> 359: 0.320322    0.980691    3.460275    0.165486    0.113641    0.009457    0.749107    
#> 360: 0.320298    0.980629    3.460235    0.165451    0.113554    0.009478    0.749051    
#> 361: 0.320112    0.980684    3.460168    0.165572    0.113519    0.009477    0.749062    
#> 362: 0.320151    0.980572    3.460137    0.165610    0.113506    0.009470    0.748956    
#> 363: 0.320199    0.980570    3.460106    0.165506    0.113568    0.009471    0.748849    
#> 364: 0.320225    0.980592    3.460064    0.165477    0.113664    0.009473    0.748800    
#> 365: 0.320280    0.980546    3.460098    0.165473    0.113700    0.009476    0.748851    
#> 366: 0.320364    0.980597    3.460054    0.165674    0.113606    0.009468    0.748920    
#> 367: 0.320375    0.980624    3.460078    0.165708    0.113553    0.009466    0.748961    
#> 368: 0.320464    0.980750    3.460033    0.165878    0.113485    0.009472    0.748838    
#> 369: 0.320447    0.980733    3.459973    0.165883    0.113530    0.009471    0.748890    
#> 370: 0.320221    0.980774    3.459910    0.165779    0.113595    0.009478    0.748950    
#> 371: 0.320176    0.980895    3.459801    0.165579    0.113615    0.009472    0.749055    
#> 372: 0.320094    0.981054    3.459740    0.165383    0.113676    0.009462    0.749173    
#> 373: 0.319885    0.981293    3.459688    0.165305    0.113715    0.009454    0.749242    
#> 374: 0.319888    0.981416    3.459658    0.165333    0.113739    0.009441    0.749190    
#> 375: 0.319736    0.981483    3.459629    0.165406    0.113762    0.009425    0.749255    
#> 376: 0.319548    0.981521    3.459632    0.165249    0.113765    0.009420    0.749339    
#> 377: 0.319432    0.981509    3.459631    0.165197    0.113701    0.009408    0.749233    
#> 378: 0.319347    0.981519    3.459595    0.165078    0.113713    0.009401    0.749235    
#> 379: 0.319246    0.981403    3.459584    0.164879    0.113707    0.009395    0.749292    
#> 380: 0.319093    0.981408    3.459556    0.164835    0.113675    0.009394    0.749209    
#> 381: 0.319045    0.981383    3.459592    0.164876    0.113617    0.009396    0.749105    
#> 382: 0.319147    0.981314    3.459614    0.164904    0.113547    0.009405    0.748950    
#> 383: 0.319295    0.981402    3.459590    0.164851    0.113617    0.009408    0.748912    
#> 384: 0.319157    0.981386    3.459606    0.164963    0.113539    0.009412    0.748954    
#> 385: 0.319211    0.981391    3.459631    0.164862    0.113468    0.009410    0.749024    
#> 386: 0.319244    0.981569    3.459656    0.164739    0.113432    0.009407    0.749115    
#> 387: 0.319448    0.981669    3.459749    0.164788    0.113355    0.009420    0.749082    
#> 388: 0.319642    0.981665    3.459829    0.164765    0.113327    0.009428    0.749015    
#> 389: 0.319720    0.981539    3.459871    0.164753    0.113344    0.009434    0.748988    
#> 390: 0.319600    0.981644    3.459850    0.164872    0.113347    0.009450    0.748932    
#> 391: 0.319600    0.981620    3.459854    0.164911    0.113289    0.009466    0.748926    
#> 392: 0.319483    0.981593    3.459858    0.164890    0.113245    0.009477    0.748977    
#> 393: 0.319470    0.981518    3.459816    0.164795    0.113259    0.009489    0.748912    
#> 394: 0.319344    0.981489    3.459771    0.164844    0.113272    0.009488    0.748922    
#> 395: 0.319492    0.981554    3.459749    0.164895    0.113244    0.009482    0.748951    
#> 396: 0.319597    0.981659    3.459759    0.164825    0.113248    0.009475    0.748920    
#> 397: 0.319567    0.981704    3.459761    0.164808    0.113181    0.009478    0.748938    
#> 398: 0.319549    0.981665    3.459751    0.164946    0.113219    0.009474    0.748970    
#> 399: 0.319584    0.981708    3.459792    0.164896    0.113158    0.009468    0.748919    
#> 400: 0.319688    0.981731    3.459804    0.164843    0.113159    0.009471    0.748897    
#> 401: 0.319712    0.981758    3.459826    0.164711    0.113198    0.009469    0.748843    
#> 402: 0.319745    0.981953    3.459825    0.164565    0.113093    0.009459    0.748897    
#> 403: 0.319897    0.981857    3.459818    0.164477    0.113142    0.009442    0.749005    
#> 404: 0.320022    0.981833    3.459795    0.164441    0.113098    0.009427    0.748953    
#> 405: 0.320099    0.981910    3.459861    0.164534    0.113139    0.009421    0.748879    
#> 406: 0.320186    0.981901    3.459912    0.164481    0.113088    0.009420    0.748959    
#> 407: 0.320241    0.981993    3.459971    0.164419    0.113055    0.009428    0.748937    
#> 408: 0.320234    0.982041    3.459997    0.164394    0.113025    0.009427    0.748962    
#> 409: 0.320173    0.981952    3.460011    0.164311    0.113059    0.009423    0.748879    
#> 410: 0.320190    0.981955    3.459969    0.164172    0.113052    0.009412    0.748908    
#> 411: 0.320309    0.981774    3.459971    0.163950    0.113131    0.009408    0.749076    
#> 412: 0.320190    0.981778    3.459922    0.163843    0.113178    0.009395    0.749084    
#> 413: 0.320101    0.981771    3.459858    0.163965    0.113183    0.009384    0.749013    
#> 414: 0.319909    0.981814    3.459832    0.163915    0.113110    0.009382    0.748992    
#> 415: 0.319999    0.981763    3.459822    0.163868    0.113040    0.009380    0.748950    
#> 416: 0.320114    0.981832    3.459837    0.163867    0.113085    0.009374    0.748897    
#> 417: 0.320213    0.981761    3.459860    0.163937    0.113077    0.009369    0.748866    
#> 418: 0.320091    0.981800    3.459873    0.164020    0.113109    0.009366    0.748805    
#> 419: 0.320209    0.981892    3.459889    0.163988    0.113051    0.009374    0.748786    
#> 420: 0.320350    0.981951    3.459925    0.164018    0.113106    0.009372    0.748687    
#> 421: 0.320411    0.981957    3.459964    0.164044    0.113142    0.009373    0.748590    
#> 422: 0.320705    0.981802    3.460024    0.163991    0.113185    0.009370    0.748660    
#> 423: 0.320968    0.981698    3.460115    0.164047    0.113122    0.009380    0.748752    
#> 424: 0.321122    0.981663    3.460148    0.164136    0.113070    0.009388    0.748748    
#> 425: 0.321344    0.981773    3.460177    0.164302    0.113080    0.009386    0.748859    
#> 426: 0.321401    0.981876    3.460185    0.164555    0.113075    0.009376    0.748858    
#> 427: 0.321301    0.981850    3.460156    0.164720    0.112999    0.009374    0.748828    
#> 428: 0.321041    0.981928    3.460120    0.164783    0.112930    0.009367    0.748858    
#> 429: 0.320872    0.981979    3.460088    0.164856    0.112957    0.009352    0.748846    
#> 430: 0.320786    0.982095    3.460068    0.165042    0.112938    0.009354    0.748775    
#> 431: 0.320581    0.982076    3.460015    0.165143    0.112881    0.009360    0.748754    
#> 432: 0.320527    0.982186    3.459977    0.165303    0.112867    0.009368    0.748718    
#> 433: 0.320539    0.982210    3.459989    0.165383    0.112836    0.009371    0.748683    
#> 434: 0.320412    0.982230    3.459941    0.165368    0.112807    0.009364    0.748616    
#> 435: 0.320380    0.982275    3.459897    0.165393    0.112788    0.009359    0.748542    
#> 436: 0.320302    0.982171    3.459904    0.165380    0.112869    0.009352    0.748605    
#> 437: 0.320242    0.981999    3.459932    0.165451    0.112800    0.009352    0.748589    
#> 438: 0.320167    0.982102    3.459951    0.165644    0.112782    0.009346    0.748505    
#> 439: 0.320230    0.982175    3.459968    0.165709    0.112802    0.009343    0.748457    
#> 440: 0.320149    0.982219    3.459989    0.165729    0.112778    0.009338    0.748408    
#> 441: 0.320148    0.982216    3.460003    0.165637    0.112792    0.009332    0.748361    
#> 442: 0.320128    0.982295    3.459993    0.165517    0.112742    0.009331    0.748282    
#> 443: 0.319980    0.982371    3.459933    0.165471    0.112807    0.009324    0.748283    
#> 444: 0.319983    0.982444    3.459876    0.165398    0.112951    0.009318    0.748275    
#> 445: 0.319916    0.982541    3.459811    0.165221    0.112976    0.009325    0.748253    
#> 446: 0.319681    0.982657    3.459710    0.165098    0.113040    0.009323    0.748226    
#> 447: 0.319597    0.982707    3.459659    0.165007    0.113106    0.009323    0.748229    
#> 448: 0.319432    0.982769    3.459652    0.164942    0.113118    0.009313    0.748205    
#> 449: 0.319324    0.982833    3.459712    0.164911    0.113175    0.009306    0.748191    
#> 450: 0.319371    0.982852    3.459729    0.164863    0.113150    0.009300    0.748178    
#> 451: 0.319488    0.982825    3.459744    0.164804    0.113182    0.009298    0.748219    
#> 452: 0.319312    0.982924    3.459675    0.164769    0.113195    0.009295    0.748291    
#> 453: 0.319042    0.983002    3.459580    0.164806    0.113198    0.009292    0.748216    
#> 454: 0.318905    0.983174    3.459510    0.164903    0.113205    0.009283    0.748193    
#> 455: 0.318809    0.983274    3.459440    0.164962    0.113228    0.009277    0.748250    
#> 456: 0.318687    0.983308    3.459378    0.165055    0.113193    0.009264    0.748259    
#> 457: 0.318570    0.983277    3.459344    0.165161    0.113129    0.009254    0.748217    
#> 458: 0.318504    0.983364    3.459396    0.165296    0.113163    0.009260    0.748162    
#> 459: 0.318407    0.983442    3.459400    0.165299    0.113223    0.009276    0.748142    
#> 460: 0.318370    0.983324    3.459386    0.165307    0.113184    0.009283    0.748116    
#> 461: 0.318249    0.983304    3.459407    0.165352    0.113211    0.009283    0.748080    
#> 462: 0.318214    0.983322    3.459451    0.165427    0.113219    0.009281    0.748068    
#> 463: 0.318209    0.983368    3.459476    0.165560    0.113197    0.009273    0.747999    
#> 464: 0.318319    0.983320    3.459491    0.165607    0.113224    0.009257    0.747935    
#> 465: 0.318292    0.983145    3.459513    0.165716    0.113258    0.009247    0.747952    
#> 466: 0.318436    0.983173    3.459504    0.165778    0.113288    0.009236    0.747962    
#> 467: 0.318441    0.983129    3.459513    0.165875    0.113263    0.009222    0.747918    
#> 468: 0.318580    0.983119    3.459536    0.165969    0.113249    0.009211    0.747955    
#> 469: 0.318621    0.983220    3.459543    0.165908    0.113241    0.009201    0.748047    
#> 470: 0.318652    0.983211    3.459581    0.165841    0.113286    0.009192    0.748020    
#> 471: 0.318656    0.983126    3.459627    0.165789    0.113305    0.009190    0.748032    
#> 472: 0.318673    0.983044    3.459696    0.165752    0.113320    0.009194    0.747978    
#> 473: 0.318698    0.982955    3.459751    0.165726    0.113313    0.009198    0.748042    
#> 474: 0.318758    0.982784    3.459773    0.165693    0.113267    0.009199    0.748177    
#> 475: 0.318877    0.982747    3.459787    0.165648    0.113239    0.009190    0.748152    
#> 476: 0.319032    0.982686    3.459807    0.165620    0.113276    0.009182    0.748186    
#> 477: 0.318998    0.982634    3.459854    0.165606    0.113352    0.009174    0.748117    
#> 478: 0.318939    0.982613    3.459854    0.165554    0.113382    0.009168    0.748131    
#> 479: 0.318996    0.982623    3.459852    0.165485    0.113504    0.009160    0.748137    
#> 480: 0.319089    0.982526    3.459895    0.165538    0.113508    0.009147    0.748204    
#> 481: 0.319136    0.982569    3.459919    0.165488    0.113537    0.009137    0.748218    
#> 482: 0.319309    0.982588    3.459935    0.165403    0.113582    0.009127    0.748242    
#> 483: 0.319347    0.982588    3.459936    0.165287    0.113592    0.009116    0.748248    
#> 484: 0.319353    0.982515    3.459946    0.165211    0.113597    0.009108    0.748340    
#> 485: 0.319415    0.982518    3.459936    0.165129    0.113594    0.009104    0.748423    
#> 486: 0.319462    0.982542    3.459965    0.165065    0.113582    0.009102    0.748404    
#> 487: 0.319698    0.982520    3.460052    0.165056    0.113564    0.009101    0.748363    
#> 488: 0.319858    0.982565    3.460122    0.164940    0.113623    0.009098    0.748352    
#> 489: 0.319998    0.982521    3.460177    0.164873    0.113640    0.009104    0.748362    
#> 490: 0.320095    0.982529    3.460224    0.164854    0.113671    0.009105    0.748345    
#> 491: 0.320153    0.982589    3.460280    0.164808    0.113666    0.009106    0.748361    
#> 492: 0.320148    0.982655    3.460310    0.164673    0.113666    0.009109    0.748489    
#> 493: 0.320080    0.982662    3.460334    0.164670    0.113723    0.009106    0.748590    
#> 494: 0.320131    0.982690    3.460328    0.164622    0.113644    0.009099    0.748607    
#> 495: 0.320267    0.982617    3.460372    0.164641    0.113614    0.009094    0.748625    
#> 496: 0.320419    0.982623    3.460369    0.164777    0.113614    0.009088    0.748639    
#> 497: 0.320300    0.982635    3.460366    0.164741    0.113539    0.009088    0.748712    
#> 498: 0.320350    0.982595    3.460374    0.164777    0.113580    0.009076    0.748677    
#> 499: 0.320414    0.982547    3.460349    0.164756    0.113645    0.009069    0.748657    
#> 500: 0.320415    0.982526    3.460333    0.164729    0.113669    0.009062    0.748617    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.239263    0.965823    3.447834    0.392401    0.080836    0.016800    1.729700    
#> 002: 0.215852    1.060072    3.479413    0.372781    0.076795    0.015960    1.103679    
#> 003: 0.335298    1.043900    3.515980    0.354142    0.072955    0.015162    0.846487    
#> 004: 0.303474    1.074896    3.519251    0.336435    0.076039    0.014404    0.767727    
#> 005: 0.319838    1.096924    3.499673    0.319613    0.073924    0.013684    0.713149    
#> 006: 0.310673    1.109767    3.494590    0.303633    0.091568    0.013000    0.680211    
#> 007: 0.294424    1.136370    3.490190    0.288451    0.097008    0.012350    0.675690    
#> 008: 0.288254    1.100875    3.484809    0.274029    0.099901    0.011732    0.682310    
#> 009: 0.262387    1.069820    3.494661    0.260327    0.100562    0.011919    0.691440    
#> 010: 0.301960    1.072290    3.495552    0.252366    0.098256    0.013146    0.694571    
#> 011: 0.344277    1.089358    3.511343    0.239748    0.093343    0.012498    0.699547    
#> 012: 0.319822    1.077080    3.501856    0.250175    0.088676    0.016384    0.674423    
#> 013: 0.282440    1.072748    3.494411    0.237666    0.085058    0.020752    0.675545    
#> 014: 0.340685    1.067582    3.509584    0.234457    0.090647    0.019714    0.691400    
#> 015: 0.356440    1.074286    3.522613    0.222734    0.086115    0.019321    0.655536    
#> 016: 0.347586    1.102811    3.528767    0.211597    0.091242    0.018355    0.672269    
#> 017: 0.322350    1.110310    3.516406    0.201018    0.091816    0.018442    0.656699    
#> 018: 0.350716    1.104008    3.506481    0.190967    0.087225    0.017520    0.668624    
#> 019: 0.322464    1.099524    3.509597    0.205977    0.082864    0.017613    0.664345    
#> 020: 0.322767    1.109589    3.504543    0.195678    0.082773    0.021959    0.681318    
#> 021: 0.336035    1.091565    3.515686    0.185894    0.078634    0.023449    0.662446    
#> 022: 0.341900    1.095974    3.528171    0.203993    0.074703    0.022277    0.666139    
#> 023: 0.399977    1.093112    3.535656    0.196708    0.081908    0.021163    0.673300    
#> 024: 0.414118    1.116520    3.525973    0.196946    0.077813    0.020105    0.684015    
#> 025: 0.375598    1.093468    3.525116    0.195131    0.085987    0.019099    0.660920    
#> 026: 0.352150    1.103746    3.516622    0.185374    0.081996    0.020247    0.676108    
#> 027: 0.295059    1.109484    3.511492    0.188427    0.080964    0.019234    0.684567    
#> 028: 0.357186    1.099319    3.514288    0.179005    0.076916    0.018403    0.666620    
#> 029: 0.373882    1.085997    3.516000    0.193420    0.073070    0.019646    0.693253    
#> 030: 0.354120    1.114033    3.514582    0.226171    0.069417    0.023336    0.666871    
#> 031: 0.328561    1.095281    3.520631    0.214863    0.066634    0.022169    0.665910    
#> 032: 0.343896    1.078006    3.531602    0.204120    0.068041    0.021475    0.664093    
#> 033: 0.349871    1.100065    3.523374    0.212174    0.071979    0.021084    0.661873    
#> 034: 0.366170    1.106679    3.524850    0.219980    0.068380    0.022510    0.669000    
#> 035: 0.323034    1.080276    3.517090    0.211253    0.078674    0.021384    0.647961    
#> 036: 0.350052    1.095685    3.520227    0.200691    0.081864    0.020315    0.658419    
#> 037: 0.332352    1.105369    3.511296    0.190656    0.090148    0.019299    0.682359    
#> 038: 0.368963    1.086927    3.514821    0.209181    0.085640    0.018334    0.690595    
#> 039: 0.371657    1.085876    3.532343    0.198722    0.094389    0.017418    0.661848    
#> 040: 0.357231    1.086046    3.526509    0.205452    0.092637    0.016547    0.673733    
#> 041: 0.334907    1.072983    3.523159    0.212771    0.088005    0.015719    0.661568    
#> 042: 0.368327    1.080161    3.525309    0.202132    0.084432    0.016185    0.654629    
#> 043: 0.329319    1.104778    3.511554    0.192026    0.088811    0.015376    0.663488    
#> 044: 0.292772    1.093717    3.508311    0.185088    0.086951    0.014607    0.666215    
#> 045: 0.275149    1.130161    3.490070    0.190799    0.094399    0.013877    0.669115    
#> 046: 0.303733    1.101476    3.508084    0.181259    0.094912    0.013183    0.672426    
#> 047: 0.336850    1.116795    3.497036    0.184454    0.090167    0.012524    0.653256    
#> 048: 0.331488    1.082300    3.505690    0.175232    0.091162    0.016904    0.674596    
#> 049: 0.313543    1.088729    3.515928    0.166470    0.086604    0.016746    0.699366    
#> 050: 0.382627    1.058806    3.521681    0.198043    0.086004    0.016398    0.711849    
#> 051: 0.348572    1.070422    3.526214    0.188141    0.109550    0.018683    0.694148    
#> 052: 0.335191    1.102959    3.522042    0.195121    0.104072    0.017749    0.670736    
#> 053: 0.345279    1.062674    3.525041    0.185365    0.110062    0.016861    0.694411    
#> 054: 0.307717    1.084941    3.521183    0.176096    0.104559    0.016586    0.707342    
#> 055: 0.310796    1.087101    3.510020    0.190705    0.099331    0.018294    0.707576    
#> 056: 0.323676    1.068790    3.511058    0.213357    0.095021    0.017379    0.686064    
#> 057: 0.341078    1.053595    3.526541    0.221000    0.097662    0.016510    0.686221    
#> 058: 0.319237    1.071359    3.510228    0.209950    0.092779    0.017910    0.685706    
#> 059: 0.328907    1.044572    3.518511    0.199452    0.091649    0.020645    0.689903    
#> 060: 0.339366    1.065570    3.521075    0.189479    0.105808    0.020400    0.699398    
#> 061: 0.367886    1.079360    3.527792    0.226294    0.106294    0.019380    0.700271    
#> 062: 0.338310    1.097528    3.536668    0.214979    0.115006    0.018411    0.715734    
#> 063: 0.385426    1.053112    3.534773    0.204230    0.109256    0.017490    0.720410    
#> 064: 0.377292    1.069688    3.538906    0.194019    0.103793    0.021135    0.696577    
#> 065: 0.371973    1.052351    3.526492    0.184318    0.101208    0.020079    0.691353    
#> 066: 0.371873    1.096685    3.525512    0.175102    0.096147    0.019075    0.669359    
#> 067: 0.333636    1.082958    3.509946    0.218057    0.091340    0.020505    0.664919    
#> 068: 0.325129    1.077112    3.525310    0.212841    0.105078    0.021304    0.692271    
#> 069: 0.299133    1.096937    3.508916    0.258150    0.099843    0.020239    0.683107    
#> 070: 0.343176    1.092906    3.525132    0.245243    0.117160    0.019227    0.672996    
#> 071: 0.300204    1.116326    3.491254    0.232981    0.122617    0.018266    0.670171    
#> 072: 0.281621    1.095825    3.490139    0.221332    0.116486    0.017352    0.662500    
#> 073: 0.319141    1.107485    3.505269    0.228353    0.110662    0.016656    0.653843    
#> 074: 0.291152    1.080098    3.504250    0.228772    0.105129    0.015824    0.667594    
#> 075: 0.332717    1.060230    3.530767    0.217333    0.099872    0.015032    0.672354    
#> 076: 0.360593    1.095885    3.539958    0.206466    0.103411    0.014370    0.677047    
#> 077: 0.403296    1.066099    3.537397    0.196143    0.098241    0.014628    0.669519    
#> 078: 0.397098    1.075045    3.537299    0.218068    0.093329    0.016522    0.657847    
#> 079: 0.364777    1.102714    3.518344    0.234620    0.103092    0.015696    0.679836    
#> 080: 0.354588    1.073729    3.525050    0.245119    0.097938    0.016557    0.692015    
#> 081: 0.357067    1.095523    3.516943    0.232863    0.093041    0.015729    0.678409    
#> 082: 0.355226    1.085702    3.527113    0.221220    0.088389    0.016936    0.670652    
#> 083: 0.362211    1.104638    3.528563    0.221160    0.083969    0.017683    0.658703    
#> 084: 0.344544    1.094878    3.527097    0.210102    0.086235    0.016799    0.659537    
#> 085: 0.356895    1.111034    3.529714    0.199597    0.097031    0.016690    0.663040    
#> 086: 0.343415    1.098432    3.512711    0.189617    0.092179    0.015855    0.659315    
#> 087: 0.315948    1.112311    3.500050    0.194093    0.087570    0.016092    0.666701    
#> 088: 0.292751    1.110763    3.503373    0.224312    0.087379    0.016400    0.703183    
#> 089: 0.292094    1.124202    3.488579    0.213097    0.111132    0.015580    0.689361    
#> 090: 0.302266    1.098559    3.495599    0.214465    0.105576    0.014801    0.681658    
#> 091: 0.281835    1.088159    3.481516    0.246589    0.100297    0.015031    0.682524    
#> 092: 0.281522    1.110611    3.477272    0.235985    0.095282    0.015026    0.686754    
#> 093: 0.250420    1.106244    3.486076    0.224186    0.090518    0.017019    0.689959    
#> 094: 0.282722    1.123439    3.482884    0.212976    0.086726    0.020449    0.669733    
#> 095: 0.286382    1.125690    3.498633    0.202328    0.095970    0.020758    0.679037    
#> 096: 0.268553    1.112012    3.492258    0.206241    0.100481    0.019720    0.681720    
#> 097: 0.329728    1.115985    3.500368    0.195929    0.095457    0.018734    0.678160    
#> 098: 0.318719    1.145166    3.516481    0.202385    0.096208    0.017798    0.688628    
#> 099: 0.291306    1.103905    3.491194    0.195592    0.114969    0.016908    0.654112    
#> 100: 0.312756    1.117246    3.496655    0.185812    0.109221    0.016062    0.658729    
#> 101: 0.287749    1.101089    3.486727    0.176522    0.103760    0.015259    0.667175    
#> 102: 0.282540    1.094486    3.483180    0.167696    0.098572    0.014496    0.673340    
#> 103: 0.315014    1.101007    3.497165    0.176015    0.093643    0.013771    0.659164    
#> 104: 0.301747    1.089015    3.512527    0.184183    0.107198    0.013083    0.673622    
#> 105: 0.358705    1.080196    3.523349    0.188790    0.101838    0.012429    0.683951    
#> 106: 0.381375    1.069728    3.527688    0.191515    0.100756    0.011837    0.672371    
#> 107: 0.390449    1.086748    3.523679    0.196655    0.097530    0.014457    0.686289    
#> 108: 0.350477    1.067494    3.524602    0.190696    0.102800    0.013735    0.693935    
#> 109: 0.310302    1.096363    3.527226    0.199926    0.097660    0.013048    0.692421    
#> 110: 0.332498    1.104728    3.496249    0.189930    0.092777    0.012395    0.691010    
#> 111: 0.305298    1.102457    3.497116    0.180433    0.088138    0.011776    0.678763    
#> 112: 0.296900    1.100595    3.489681    0.189395    0.083731    0.013297    0.673752    
#> 113: 0.318946    1.128920    3.499266    0.179925    0.086402    0.013366    0.655282    
#> 114: 0.322702    1.111157    3.505900    0.174724    0.082082    0.014023    0.669241    
#> 115: 0.369633    1.083159    3.514516    0.178614    0.080993    0.013322    0.710213    
#> 116: 0.337560    1.118464    3.516866    0.178968    0.083553    0.017261    0.700874    
#> 117: 0.307898    1.126996    3.513253    0.171697    0.079375    0.017215    0.710018    
#> 118: 0.327664    1.117799    3.514442    0.199415    0.078867    0.016930    0.692407    
#> 119: 0.331204    1.116211    3.503765    0.239935    0.086431    0.016084    0.688990    
#> 120: 0.320738    1.108632    3.508114    0.227938    0.088951    0.015280    0.666566    
#> 121: 0.330270    1.133597    3.501922    0.216541    0.103844    0.014516    0.685314    
#> 122: 0.336055    1.121643    3.507461    0.205714    0.101018    0.013790    0.655516    
#> 123: 0.356843    1.126604    3.504511    0.196113    0.099330    0.013100    0.666774    
#> 124: 0.350567    1.134007    3.508183    0.190017    0.103239    0.012445    0.667520    
#> 125: 0.367316    1.133937    3.508564    0.180516    0.098077    0.013578    0.675754    
#> 126: 0.295152    1.116805    3.495890    0.171490    0.093174    0.013812    0.685870    
#> 127: 0.307042    1.116413    3.488302    0.162916    0.088569    0.016694    0.690360    
#> 128: 0.306645    1.097501    3.508716    0.155239    0.094870    0.015913    0.687912    
#> 129: 0.333331    1.126820    3.508242    0.191517    0.096994    0.021189    0.697533    
#> 130: 0.355631    1.124869    3.507740    0.203682    0.096101    0.020238    0.663815    
#> 131: 0.334301    1.096315    3.508670    0.199447    0.098725    0.019226    0.673841    
#> 132: 0.287124    1.099887    3.487013    0.206313    0.093789    0.018265    0.673168    
#> 133: 0.278261    1.089827    3.492391    0.195998    0.098621    0.017351    0.702789    
#> 134: 0.354010    1.063549    3.521021    0.217981    0.093690    0.016484    0.676853    
#> 135: 0.332703    1.073521    3.520422    0.214763    0.095990    0.015660    0.671776    
#> 136: 0.320761    1.090965    3.515685    0.204025    0.117347    0.014877    0.656636    
#> 137: 0.384359    1.072592    3.523673    0.199104    0.111480    0.015710    0.661644    
#> 138: 0.342579    1.099345    3.508944    0.196950    0.105906    0.016680    0.652405    
#> 139: 0.359524    1.102656    3.528834    0.187102    0.100611    0.015846    0.668465    
#> 140: 0.369857    1.109376    3.525641    0.202448    0.096667    0.020485    0.676837    
#> 141: 0.348947    1.067773    3.525462    0.192936    0.099505    0.019461    0.659703    
#> 142: 0.357299    1.070904    3.536054    0.183289    0.094530    0.018487    0.673253    
#> 143: 0.325977    1.098416    3.523737    0.204033    0.089803    0.026204    0.677228    
#> 144: 0.359646    1.081483    3.530397    0.193832    0.085313    0.024894    0.646577    
#> 145: 0.334576    1.092815    3.508411    0.189123    0.082016    0.023649    0.652144    
#> 146: 0.320723    1.102294    3.513755    0.179689    0.077915    0.022467    0.662166    
#> 147: 0.307848    1.092027    3.510176    0.197947    0.081774    0.021683    0.642788    
#> 148: 0.316039    1.099576    3.518101    0.197966    0.084581    0.023797    0.659109    
#> 149: 0.329208    1.088550    3.514582    0.188068    0.082916    0.022607    0.690742    
#> 150: 0.342771    1.071349    3.511291    0.180477    0.078770    0.021477    0.689809    
#> 151: 0.307686    1.115880    3.497327    0.173511    0.088027    0.020403    0.688273    
#> 152: 0.294699    1.100536    3.507885    0.192346    0.073071    0.016167    0.659189    
#> 153: 0.297219    1.120586    3.515700    0.194718    0.085352    0.016589    0.681493    
#> 154: 0.369841    1.095360    3.524895    0.194612    0.082496    0.014314    0.701684    
#> 155: 0.334243    1.063793    3.519982    0.197610    0.083207    0.013210    0.694147    
#> 156: 0.358616    1.070761    3.520229    0.194920    0.119687    0.011012    0.697026    
#> 157: 0.372719    1.065663    3.535534    0.205385    0.131255    0.008679    0.677880    
#> 158: 0.391962    1.092792    3.527173    0.194802    0.103452    0.007983    0.681356    
#> 159: 0.328023    1.079678    3.526151    0.188211    0.090783    0.011124    0.684150    
#> 160: 0.365087    1.060510    3.539845    0.188426    0.099210    0.013037    0.686372    
#> 161: 0.350418    1.082110    3.529160    0.210706    0.101061    0.012823    0.677967    
#> 162: 0.325209    1.082338    3.507557    0.207823    0.109269    0.011367    0.697284    
#> 163: 0.334331    1.081982    3.508376    0.246028    0.124771    0.011881    0.668627    
#> 164: 0.337277    1.083284    3.516996    0.192287    0.101174    0.011493    0.691090    
#> 165: 0.386536    1.065694    3.532192    0.203210    0.094965    0.016124    0.680854    
#> 166: 0.381154    1.095967    3.539347    0.150424    0.099810    0.016342    0.673166    
#> 167: 0.381818    1.086058    3.535405    0.140016    0.095165    0.016278    0.684328    
#> 168: 0.353428    1.095238    3.526361    0.181278    0.105163    0.012650    0.682719    
#> 169: 0.335055    1.133649    3.510832    0.196154    0.101800    0.009683    0.708478    
#> 170: 0.339149    1.103259    3.509227    0.188176    0.115166    0.008004    0.682968    
#> 171: 0.303138    1.103394    3.504118    0.161983    0.097622    0.008173    0.666744    
#> 172: 0.312126    1.114483    3.502948    0.169281    0.108868    0.009231    0.672669    
#> 173: 0.297305    1.102799    3.496781    0.156317    0.108929    0.009469    0.675525    
#> 174: 0.309920    1.100816    3.504955    0.147818    0.102634    0.010164    0.681606    
#> 175: 0.296006    1.107124    3.492141    0.189163    0.112413    0.009802    0.683385    
#> 176: 0.302238    1.117944    3.501763    0.184931    0.087045    0.008080    0.687109    
#> 177: 0.309876    1.105879    3.510100    0.162669    0.098367    0.009963    0.680750    
#> 178: 0.340738    1.082095    3.513506    0.139852    0.107743    0.010539    0.679890    
#> 179: 0.343149    1.132516    3.505178    0.156187    0.102674    0.010990    0.675138    
#> 180: 0.311219    1.108503    3.510119    0.141000    0.091819    0.011690    0.682861    
#> 181: 0.315003    1.111548    3.497122    0.132970    0.088446    0.013306    0.669884    
#> 182: 0.281705    1.122396    3.490455    0.122931    0.103605    0.015716    0.693775    
#> 183: 0.304877    1.125525    3.493478    0.096833    0.095067    0.016118    0.691410    
#> 184: 0.295456    1.126807    3.500407    0.112322    0.094276    0.016048    0.691812    
#> 185: 0.266724    1.130017    3.489565    0.118592    0.087387    0.013745    0.712856    
#> 186: 0.285197    1.139626    3.493698    0.110697    0.084563    0.018977    0.701814    
#> 187: 0.303683    1.117151    3.508707    0.128580    0.095441    0.014411    0.692610    
#> 188: 0.269277    1.134255    3.491335    0.156893    0.105373    0.010867    0.701493    
#> 189: 0.312191    1.128881    3.498351    0.159611    0.111403    0.009887    0.707302    
#> 190: 0.301849    1.112158    3.504788    0.137157    0.103934    0.011886    0.696534    
#> 191: 0.275244    1.111990    3.494132    0.142374    0.121285    0.011540    0.708913    
#> 192: 0.314971    1.124358    3.508706    0.175630    0.101428    0.011220    0.684295    
#> 193: 0.363709    1.106171    3.512721    0.195794    0.089673    0.012393    0.665840    
#> 194: 0.329157    1.097741    3.503794    0.199686    0.109028    0.012934    0.684814    
#> 195: 0.304017    1.090980    3.503050    0.180124    0.121610    0.014351    0.683341    
#> 196: 0.304208    1.102571    3.510934    0.154118    0.111824    0.012489    0.690135    
#> 197: 0.293069    1.099973    3.532890    0.119192    0.115632    0.012546    0.703249    
#> 198: 0.364455    1.087987    3.521166    0.129714    0.100829    0.014308    0.682861    
#> 199: 0.319787    1.082677    3.515737    0.154210    0.092980    0.015247    0.687043    
#> 200: 0.326970    1.096207    3.514566    0.145705    0.106301    0.013774    0.697055    
#> 201: 0.324267    1.079168    3.522869    0.159800    0.095662    0.016956    0.691954    
#> 202: 0.330726    1.077194    3.519658    0.177181    0.093962    0.016208    0.680289    
#> 203: 0.344676    1.076279    3.516930    0.186935    0.091083    0.016359    0.679350    
#> 204: 0.348164    1.072565    3.518329    0.186772    0.090658    0.016951    0.680184    
#> 205: 0.347347    1.076177    3.519161    0.190619    0.088593    0.017555    0.682497    
#> 206: 0.343972    1.083083    3.518744    0.187275    0.088533    0.017699    0.684588    
#> 207: 0.337983    1.084969    3.516567    0.188248    0.089359    0.017956    0.684308    
#> 208: 0.335685    1.086091    3.515978    0.188914    0.089860    0.017821    0.684146    
#> 209: 0.337844    1.085310    3.515479    0.195575    0.090163    0.017724    0.682029    
#> 210: 0.340205    1.085882    3.515135    0.197184    0.088722    0.017663    0.680588    
#> 211: 0.340718    1.086728    3.515796    0.195512    0.088295    0.017670    0.679178    
#> 212: 0.341800    1.087337    3.515282    0.193075    0.088431    0.017450    0.678977    
#> 213: 0.342390    1.087358    3.515133    0.193316    0.089181    0.017208    0.679661    
#> 214: 0.344059    1.087407    3.515377    0.192498    0.089578    0.016963    0.679849    
#> 215: 0.342816    1.087522    3.515732    0.191484    0.090096    0.016805    0.679701    
#> 216: 0.344357    1.086200    3.515986    0.191936    0.092015    0.016704    0.680457    
#> 217: 0.344441    1.086887    3.516441    0.190863    0.094214    0.016515    0.679104    
#> 218: 0.343015    1.087733    3.516195    0.191704    0.095558    0.016337    0.678452    
#> 219: 0.340735    1.087410    3.515262    0.192380    0.095661    0.016075    0.678367    
#> 220: 0.339207    1.088341    3.514701    0.193892    0.095992    0.015917    0.677610    
#> 221: 0.338222    1.089038    3.514151    0.194145    0.096010    0.015728    0.676377    
#> 222: 0.338282    1.088731    3.513526    0.194731    0.096574    0.015551    0.676524    
#> 223: 0.339800    1.088275    3.513387    0.194931    0.096760    0.015314    0.676391    
#> 224: 0.341534    1.088356    3.513559    0.195726    0.096888    0.015182    0.676146    
#> 225: 0.341613    1.086695    3.513947    0.195693    0.096833    0.015120    0.676254    
#> 226: 0.341572    1.085517    3.513869    0.195171    0.096958    0.015023    0.676380    
#> 227: 0.341558    1.085291    3.513987    0.195564    0.096462    0.015040    0.675879    
#> 228: 0.339837    1.086549    3.513053    0.196227    0.097434    0.014990    0.675926    
#> 229: 0.338271    1.086625    3.512689    0.196233    0.097629    0.014983    0.675452    
#> 230: 0.338085    1.086492    3.512531    0.195888    0.098102    0.015011    0.675192    
#> 231: 0.337512    1.087631    3.512664    0.195523    0.098861    0.015032    0.675344    
#> 232: 0.336676    1.087851    3.512900    0.195724    0.099136    0.015039    0.675221    
#> 233: 0.337185    1.086376    3.513391    0.196539    0.099183    0.015067    0.675481    
#> 234: 0.337973    1.085897    3.513963    0.197325    0.099323    0.015100    0.675181    
#> 235: 0.338218    1.085572    3.514043    0.197724    0.099366    0.015100    0.674724    
#> 236: 0.338447    1.085900    3.513894    0.197863    0.099390    0.015069    0.674576    
#> 237: 0.339310    1.086077    3.514037    0.198601    0.099438    0.015076    0.674848    
#> 238: 0.340048    1.086163    3.514302    0.199543    0.099476    0.015127    0.675120    
#> 239: 0.339816    1.086402    3.514299    0.199010    0.099616    0.015123    0.675143    
#> 240: 0.340335    1.085914    3.514553    0.197961    0.099343    0.015171    0.675004    
#> 241: 0.340566    1.084794    3.514931    0.197509    0.099159    0.015149    0.675243    
#> 242: 0.340556    1.084176    3.514888    0.197601    0.098921    0.015187    0.675343    
#> 243: 0.339626    1.084781    3.514760    0.198104    0.098803    0.015198    0.675718    
#> 244: 0.338835    1.084900    3.514752    0.198786    0.098586    0.015301    0.675570    
#> 245: 0.338778    1.084591    3.514807    0.198280    0.098303    0.015295    0.675642    
#> 246: 0.338263    1.084529    3.514665    0.198270    0.098180    0.015308    0.675257    
#> 247: 0.337597    1.084751    3.514830    0.197955    0.098303    0.015268    0.675316    
#> 248: 0.337038    1.085488    3.514784    0.198153    0.097940    0.015316    0.675185    
#> 249: 0.337195    1.085637    3.514900    0.198465    0.097763    0.015424    0.675046    
#> 250: 0.337729    1.085966    3.515050    0.198812    0.097621    0.015598    0.674848    
#> 251: 0.337920    1.086591    3.515296    0.199196    0.097456    0.015719    0.674658    
#> 252: 0.338833    1.086807    3.515635    0.200439    0.097104    0.015780    0.674588    
#> 253: 0.338769    1.086999    3.515787    0.201077    0.096578    0.015868    0.674544    
#> 254: 0.338785    1.087466    3.515926    0.201805    0.096415    0.015898    0.674312    
#> 255: 0.338797    1.087931    3.516080    0.202610    0.096131    0.015960    0.674351    
#> 256: 0.338942    1.088221    3.515847    0.202674    0.096077    0.016013    0.674245    
#> 257: 0.338639    1.088409    3.515611    0.202875    0.096157    0.016028    0.673933    
#> 258: 0.337794    1.088626    3.515314    0.203447    0.096204    0.015990    0.673912    
#> 259: 0.336715    1.089207    3.515002    0.203949    0.096135    0.015979    0.674020    
#> 260: 0.335798    1.089829    3.514767    0.203541    0.096124    0.015961    0.673955    
#> 261: 0.334985    1.090413    3.514548    0.203555    0.096221    0.015914    0.674202    
#> 262: 0.334782    1.091010    3.514276    0.203105    0.095980    0.015907    0.674752    
#> 263: 0.334517    1.091397    3.514072    0.203160    0.095832    0.015891    0.675186    
#> 264: 0.334212    1.091564    3.513871    0.203556    0.095683    0.015852    0.675369    
#> 265: 0.334199    1.091789    3.513907    0.203671    0.095322    0.015854    0.675403    
#> 266: 0.334887    1.091820    3.513930    0.203663    0.095339    0.015852    0.675427    
#> 267: 0.335299    1.091838    3.514194    0.204520    0.095468    0.015873    0.675230    
#> 268: 0.335489    1.091580    3.514292    0.204508    0.095549    0.015892    0.675341    
#> 269: 0.336134    1.091363    3.514500    0.204202    0.095612    0.015926    0.675403    
#> 270: 0.336280    1.091638    3.514378    0.204190    0.095603    0.015924    0.675276    
#> 271: 0.335965    1.091873    3.514221    0.204194    0.095458    0.015922    0.675319    
#> 272: 0.335895    1.091739    3.514207    0.203844    0.095356    0.015913    0.675425    
#> 273: 0.335685    1.092057    3.514252    0.203881    0.095333    0.015907    0.675282    
#> 274: 0.335216    1.092157    3.514275    0.203625    0.095302    0.015864    0.675301    
#> 275: 0.335213    1.092029    3.514286    0.203339    0.095250    0.015842    0.675175    
#> 276: 0.335171    1.092133    3.514413    0.203330    0.095256    0.015801    0.675106    
#> 277: 0.334986    1.092279    3.514470    0.203192    0.095253    0.015782    0.674924    
#> 278: 0.335112    1.092187    3.514708    0.203265    0.095249    0.015759    0.674871    
#> 279: 0.335060    1.091864    3.514891    0.203572    0.095271    0.015723    0.675096    
#> 280: 0.335044    1.091769    3.514934    0.203233    0.095267    0.015697    0.674895    
#> 281: 0.334786    1.091813    3.514988    0.202980    0.095191    0.015695    0.674848    
#> 282: 0.334838    1.091916    3.514969    0.203126    0.095072    0.015709    0.675041    
#> 283: 0.334905    1.091891    3.515024    0.203538    0.095217    0.015772    0.675131    
#> 284: 0.334661    1.091821    3.514985    0.203639    0.095286    0.015803    0.675075    
#> 285: 0.334662    1.091907    3.514893    0.204091    0.095247    0.015847    0.675038    
#> 286: 0.334484    1.092164    3.514733    0.204317    0.095426    0.015850    0.674960    
#> 287: 0.334235    1.092311    3.514578    0.203901    0.095459    0.015858    0.675157    
#> 288: 0.334403    1.092255    3.514611    0.203670    0.095592    0.015894    0.675240    
#> 289: 0.334670    1.092236    3.514640    0.203033    0.095574    0.015927    0.675285    
#> 290: 0.334873    1.092020    3.514717    0.202819    0.095558    0.015933    0.675467    
#> 291: 0.334989    1.092036    3.514872    0.202723    0.095534    0.015957    0.675283    
#> 292: 0.334694    1.091922    3.514864    0.202572    0.095621    0.015938    0.675329    
#> 293: 0.334682    1.091945    3.514721    0.202587    0.095528    0.015918    0.675220    
#> 294: 0.334570    1.091991    3.514652    0.202822    0.095449    0.015899    0.675127    
#> 295: 0.334607    1.091666    3.514611    0.202904    0.095259    0.015877    0.675061    
#> 296: 0.334353    1.091768    3.514532    0.203145    0.095284    0.015860    0.675103    
#> 297: 0.334263    1.092081    3.514457    0.203233    0.095310    0.015818    0.675107    
#> 298: 0.334301    1.092123    3.514422    0.203480    0.095197    0.015834    0.675050    
#> 299: 0.334608    1.092206    3.514393    0.203690    0.095045    0.015841    0.674929    
#> 300: 0.335053    1.092255    3.514607    0.203756    0.094990    0.015836    0.674767    
#> 301: 0.335406    1.092166    3.514678    0.203781    0.094891    0.015818    0.674819    
#> 302: 0.335460    1.092306    3.514654    0.204055    0.094776    0.015807    0.674737    
#> 303: 0.335258    1.092524    3.514506    0.204189    0.094668    0.015794    0.674596    
#> 304: 0.335172    1.092829    3.514405    0.204313    0.094570    0.015788    0.674490    
#> 305: 0.335077    1.092630    3.514372    0.204428    0.094532    0.015811    0.674392    
#> 306: 0.334530    1.092619    3.514215    0.204112    0.094456    0.015836    0.674393    
#> 307: 0.334338    1.092658    3.514052    0.204091    0.094345    0.015830    0.674587    
#> 308: 0.334080    1.092499    3.513993    0.204268    0.094324    0.015816    0.674809    
#> 309: 0.334149    1.092213    3.513962    0.204506    0.094250    0.015816    0.674938    
#> 310: 0.334362    1.092049    3.513878    0.204861    0.094163    0.015801    0.674932    
#> 311: 0.334364    1.091958    3.513978    0.204794    0.094118    0.015803    0.674875    
#> 312: 0.334416    1.091802    3.513974    0.204582    0.094100    0.015796    0.674769    
#> 313: 0.334330    1.091552    3.513930    0.204342    0.094099    0.015783    0.674756    
#> 314: 0.334067    1.091661    3.513803    0.204314    0.094073    0.015757    0.674584    
#> 315: 0.333611    1.091826    3.513687    0.204382    0.094020    0.015738    0.674552    
#> 316: 0.333660    1.091924    3.513620    0.204214    0.094077    0.015732    0.674654    
#> 317: 0.333679    1.091956    3.513628    0.204170    0.094174    0.015731    0.674722    
#> 318: 0.333590    1.092220    3.513532    0.204097    0.094155    0.015748    0.674705    
#> 319: 0.333525    1.092281    3.513486    0.204004    0.094089    0.015770    0.674771    
#> 320: 0.333182    1.092267    3.513394    0.203776    0.094207    0.015804    0.674744    
#> 321: 0.333052    1.092299    3.513332    0.203636    0.094295    0.015828    0.674796    
#> 322: 0.332976    1.092191    3.513296    0.203757    0.094339    0.015808    0.674870    
#> 323: 0.332648    1.092148    3.513297    0.203975    0.094395    0.015805    0.674900    
#> 324: 0.332530    1.092452    3.513232    0.204369    0.094407    0.015787    0.674797    
#> 325: 0.332365    1.092591    3.513152    0.204377    0.094402    0.015773    0.674704    
#> 326: 0.332311    1.092476    3.513054    0.204189    0.094392    0.015755    0.674716    
#> 327: 0.332306    1.092506    3.513022    0.204114    0.094372    0.015758    0.674584    
#> 328: 0.332197    1.092631    3.512949    0.204215    0.094345    0.015754    0.674383    
#> 329: 0.332094    1.092678    3.512926    0.204181    0.094373    0.015772    0.674212    
#> 330: 0.332024    1.092834    3.512867    0.204163    0.094293    0.015789    0.674112    
#> 331: 0.332380    1.092903    3.512945    0.204073    0.094227    0.015813    0.674060    
#> 332: 0.332618    1.092734    3.513127    0.204134    0.094068    0.015861    0.674025    
#> 333: 0.332732    1.092699    3.513147    0.204218    0.093914    0.015884    0.673978    
#> 334: 0.332676    1.092766    3.513034    0.204184    0.093842    0.015876    0.673895    
#> 335: 0.332560    1.092730    3.512943    0.204165    0.093625    0.015885    0.673873    
#> 336: 0.332279    1.092806    3.512893    0.204143    0.093421    0.015925    0.673867    
#> 337: 0.332281    1.093120    3.512777    0.204122    0.093289    0.015961    0.673894    
#> 338: 0.332367    1.093123    3.512843    0.203974    0.093190    0.015987    0.673836    
#> 339: 0.332341    1.093190    3.512834    0.203869    0.093147    0.016015    0.673825    
#> 340: 0.332410    1.093009    3.512919    0.203790    0.093193    0.016037    0.673835    
#> 341: 0.332674    1.093016    3.512990    0.203731    0.093263    0.016055    0.673815    
#> 342: 0.332632    1.092806    3.513075    0.203466    0.093302    0.016074    0.673783    
#> 343: 0.332624    1.092737    3.513118    0.203316    0.093281    0.016067    0.673743    
#> 344: 0.332832    1.092641    3.513240    0.203090    0.093281    0.016071    0.673799    
#> 345: 0.333027    1.092576    3.513311    0.203019    0.093288    0.016083    0.673734    
#> 346: 0.332987    1.092576    3.513230    0.203013    0.093238    0.016083    0.673682    
#> 347: 0.333003    1.092572    3.513180    0.203262    0.093201    0.016103    0.673808    
#> 348: 0.332820    1.092649    3.513124    0.203057    0.093270    0.016128    0.673737    
#> 349: 0.332669    1.092610    3.513111    0.202946    0.093277    0.016165    0.673717    
#> 350: 0.332281    1.092586    3.513004    0.203150    0.093269    0.016183    0.673695    
#> 351: 0.332078    1.092831    3.512865    0.203357    0.093220    0.016211    0.673667    
#> 352: 0.331592    1.093094    3.512710    0.203673    0.093142    0.016234    0.673791    
#> 353: 0.331269    1.093423    3.512591    0.203984    0.093115    0.016255    0.673708    
#> 354: 0.331228    1.093543    3.512447    0.204063    0.093010    0.016270    0.673602    
#> 355: 0.331338    1.093611    3.512406    0.204234    0.092974    0.016284    0.673607    
#> 356: 0.331319    1.093571    3.512388    0.204135    0.092983    0.016293    0.673666    
#> 357: 0.331279    1.093747    3.512386    0.203929    0.092893    0.016307    0.673646    
#> 358: 0.331030    1.093867    3.512344    0.203927    0.092830    0.016309    0.673535    
#> 359: 0.330945    1.094002    3.512306    0.203925    0.092809    0.016285    0.673474    
#> 360: 0.330832    1.094129    3.512167    0.203928    0.092810    0.016261    0.673383    
#> 361: 0.330642    1.094207    3.512069    0.203834    0.092786    0.016229    0.673383    
#> 362: 0.330637    1.094150    3.512061    0.203819    0.092754    0.016212    0.673212    
#> 363: 0.330687    1.094083    3.512037    0.203822    0.092703    0.016212    0.673072    
#> 364: 0.330812    1.094198    3.512007    0.204071    0.092801    0.016187    0.673072    
#> 365: 0.330727    1.094195    3.511994    0.204102    0.092843    0.016190    0.673032    
#> 366: 0.330473    1.094462    3.511859    0.203907    0.092813    0.016196    0.673148    
#> 367: 0.330400    1.094473    3.511817    0.203834    0.092716    0.016201    0.673136    
#> 368: 0.330677    1.094431    3.511852    0.203822    0.092665    0.016207    0.673091    
#> 369: 0.330704    1.094299    3.511859    0.203781    0.092751    0.016183    0.673149    
#> 370: 0.330766    1.094254    3.511867    0.203532    0.092833    0.016172    0.673206    
#> 371: 0.330643    1.094332    3.511773    0.203352    0.092835    0.016151    0.673250    
#> 372: 0.330491    1.094373    3.511715    0.203375    0.092856    0.016140    0.673214    
#> 373: 0.330206    1.094515    3.511609    0.203361    0.092877    0.016134    0.673173    
#> 374: 0.330112    1.094624    3.511525    0.203318    0.092822    0.016126    0.673113    
#> 375: 0.329921    1.094666    3.511502    0.203364    0.092739    0.016111    0.673191    
#> 376: 0.329835    1.094755    3.511476    0.203281    0.092686    0.016103    0.673166    
#> 377: 0.329518    1.094842    3.511410    0.203207    0.092656    0.016103    0.673081    
#> 378: 0.329235    1.094857    3.511341    0.203241    0.092650    0.016103    0.673137    
#> 379: 0.329153    1.094797    3.511344    0.203276    0.092637    0.016096    0.673120    
#> 380: 0.329113    1.094769    3.511337    0.203413    0.092676    0.016076    0.673145    
#> 381: 0.329035    1.094783    3.511338    0.203506    0.092682    0.016067    0.673177    
#> 382: 0.329054    1.094804    3.511362    0.203495    0.092674    0.016062    0.673117    
#> 383: 0.329174    1.094813    3.511375    0.203334    0.092714    0.016047    0.673066    
#> 384: 0.329064    1.094756    3.511406    0.203199    0.092664    0.016038    0.673088    
#> 385: 0.329068    1.094760    3.511430    0.203268    0.092613    0.016051    0.673043    
#> 386: 0.329172    1.094866    3.511476    0.203221    0.092589    0.016070    0.673027    
#> 387: 0.329418    1.094975    3.511601    0.203030    0.092575    0.016080    0.673014    
#> 388: 0.329476    1.095011    3.511653    0.202906    0.092502    0.016091    0.672964    
#> 389: 0.329566    1.094841    3.511677    0.202966    0.092450    0.016099    0.672976    
#> 390: 0.329548    1.094841    3.511687    0.202810    0.092427    0.016125    0.672984    
#> 391: 0.329696    1.094744    3.511773    0.202825    0.092373    0.016132    0.672952    
#> 392: 0.329862    1.094700    3.511886    0.203038    0.092380    0.016144    0.672899    
#> 393: 0.329951    1.094691    3.511871    0.203059    0.092365    0.016147    0.672865    
#> 394: 0.330026    1.094731    3.511848    0.203080    0.092366    0.016140    0.672833    
#> 395: 0.330241    1.094752    3.511872    0.202944    0.092381    0.016134    0.672859    
#> 396: 0.330327    1.094754    3.511903    0.203050    0.092392    0.016116    0.672740    
#> 397: 0.330523    1.094692    3.511967    0.202938    0.092413    0.016101    0.672696    
#> 398: 0.330662    1.094558    3.512050    0.202797    0.092437    0.016100    0.672742    
#> 399: 0.330814    1.094551    3.512132    0.202688    0.092505    0.016105    0.672652    
#> 400: 0.330883    1.094545    3.512208    0.202484    0.092520    0.016109    0.672586    
#> 401: 0.330874    1.094609    3.512204    0.202418    0.092597    0.016117    0.672594    
#> 402: 0.330865    1.094839    3.512221    0.202254    0.092630    0.016122    0.672596    
#> 403: 0.331122    1.094871    3.512244    0.202231    0.092621    0.016139    0.672564    
#> 404: 0.331209    1.094828    3.512274    0.202023    0.092604    0.016143    0.672535    
#> 405: 0.331321    1.094844    3.512293    0.201925    0.092535    0.016150    0.672583    
#> 406: 0.331420    1.094853    3.512314    0.201850    0.092549    0.016165    0.672612    
#> 407: 0.331574    1.094755    3.512472    0.201842    0.092607    0.016176    0.672560    
#> 408: 0.331689    1.094701    3.512531    0.201709    0.092652    0.016185    0.672620    
#> 409: 0.331684    1.094634    3.512517    0.201572    0.092580    0.016184    0.672543    
#> 410: 0.331492    1.094696    3.512387    0.201450    0.092628    0.016155    0.672646    
#> 411: 0.331509    1.094547    3.512298    0.201497    0.092649    0.016151    0.672722    
#> 412: 0.331549    1.094689    3.512230    0.201379    0.092674    0.016140    0.672743    
#> 413: 0.331507    1.094757    3.512210    0.201172    0.092672    0.016131    0.672806    
#> 414: 0.331454    1.094705    3.512209    0.201112    0.092612    0.016128    0.672805    
#> 415: 0.331492    1.094782    3.512199    0.201175    0.092600    0.016123    0.672720    
#> 416: 0.331442    1.094905    3.512198    0.201183    0.092575    0.016116    0.672686    
#> 417: 0.331377    1.094904    3.512157    0.201225    0.092550    0.016104    0.672650    
#> 418: 0.331214    1.095044    3.512136    0.201164    0.092557    0.016102    0.672580    
#> 419: 0.331081    1.095188    3.512095    0.201174    0.092540    0.016103    0.672552    
#> 420: 0.330955    1.095255    3.512028    0.201031    0.092510    0.016101    0.672577    
#> 421: 0.330730    1.095319    3.511975    0.200876    0.092449    0.016100    0.672619    
#> 422: 0.330887    1.095279    3.511956    0.200900    0.092506    0.016092    0.672655    
#> 423: 0.330927    1.095159    3.511934    0.200822    0.092648    0.016085    0.672685    
#> 424: 0.330924    1.095154    3.511911    0.200734    0.092741    0.016076    0.672649    
#> 425: 0.331128    1.095264    3.511926    0.200725    0.092793    0.016066    0.672721    
#> 426: 0.331277    1.095369    3.511892    0.200778    0.092789    0.016064    0.672657    
#> 427: 0.331231    1.095384    3.511856    0.200853    0.092712    0.016064    0.672572    
#> 428: 0.331143    1.095462    3.511861    0.201012    0.092655    0.016066    0.672590    
#> 429: 0.331088    1.095523    3.511843    0.201036    0.092651    0.016062    0.672581    
#> 430: 0.331042    1.095614    3.511820    0.200882    0.092657    0.016066    0.672627    
#> 431: 0.330940    1.095610    3.511790    0.200790    0.092632    0.016061    0.672569    
#> 432: 0.330905    1.095685    3.511808    0.200777    0.092636    0.016065    0.672528    
#> 433: 0.330946    1.095780    3.511850    0.200704    0.092541    0.016083    0.672512    
#> 434: 0.330882    1.095808    3.511830    0.200648    0.092528    0.016090    0.672474    
#> 435: 0.330870    1.095826    3.511822    0.200690    0.092572    0.016070    0.672448    
#> 436: 0.330844    1.095816    3.511842    0.200700    0.092666    0.016047    0.672557    
#> 437: 0.330851    1.095818    3.511835    0.200642    0.092678    0.016036    0.672478    
#> 438: 0.330890    1.095943    3.511802    0.200627    0.092648    0.016026    0.672446    
#> 439: 0.330821    1.096032    3.511768    0.200666    0.092629    0.016012    0.672393    
#> 440: 0.330729    1.096086    3.511791    0.200717    0.092652    0.015992    0.672345    
#> 441: 0.330681    1.096109    3.511813    0.200853    0.092688    0.015986    0.672300    
#> 442: 0.330621    1.096195    3.511822    0.200803    0.092681    0.015971    0.672318    
#> 443: 0.330431    1.096226    3.511753    0.200817    0.092604    0.015960    0.672390    
#> 444: 0.330435    1.096307    3.511711    0.200827    0.092559    0.015969    0.672387    
#> 445: 0.330361    1.096424    3.511664    0.200952    0.092508    0.015992    0.672383    
#> 446: 0.330113    1.096535    3.511560    0.201099    0.092497    0.015996    0.672379    
#> 447: 0.330108    1.096585    3.511504    0.201116    0.092519    0.016004    0.672394    
#> 448: 0.330053    1.096611    3.511515    0.201067    0.092521    0.016007    0.672317    
#> 449: 0.330242    1.096653    3.511633    0.200968    0.092559    0.016009    0.672305    
#> 450: 0.330238    1.096621    3.511682    0.200887    0.092547    0.016021    0.672292    
#> 451: 0.330453    1.096565    3.511702    0.200814    0.092569    0.016025    0.672330    
#> 452: 0.330592    1.096564    3.511730    0.200657    0.092536    0.016010    0.672372    
#> 453: 0.330501    1.096540    3.511717    0.200540    0.092533    0.016000    0.672332    
#> 454: 0.330489    1.096677    3.511719    0.200473    0.092506    0.015993    0.672272    
#> 455: 0.330541    1.096751    3.511726    0.200464    0.092481    0.015985    0.672219    
#> 456: 0.330575    1.096711    3.511731    0.200414    0.092464    0.015981    0.672175    
#> 457: 0.330578    1.096681    3.511784    0.200361    0.092496    0.015973    0.672115    
#> 458: 0.330565    1.096825    3.511838    0.200308    0.092561    0.015954    0.672193    
#> 459: 0.330434    1.096967    3.511819    0.200251    0.092585    0.015941    0.672304    
#> 460: 0.330230    1.096978    3.511748    0.200213    0.092670    0.015929    0.672391    
#> 461: 0.329994    1.097044    3.511705    0.200227    0.092773    0.015930    0.672451    
#> 462: 0.329717    1.097086    3.511673    0.200189    0.092770    0.015943    0.672472    
#> 463: 0.329715    1.097127    3.511706    0.200061    0.092798    0.015945    0.672473    
#> 464: 0.329840    1.097104    3.511739    0.199968    0.092758    0.015941    0.672403    
#> 465: 0.329880    1.096962    3.511743    0.199914    0.092716    0.015940    0.672441    
#> 466: 0.329870    1.097038    3.511686    0.199821    0.092704    0.015937    0.672450    
#> 467: 0.329779    1.097017    3.511669    0.199919    0.092710    0.015937    0.672370    
#> 468: 0.329951    1.097044    3.511718    0.199942    0.092719    0.015926    0.672411    
#> 469: 0.330081    1.097184    3.511743    0.199943    0.092678    0.015923    0.672517    
#> 470: 0.330051    1.097231    3.511729    0.199980    0.092621    0.015923    0.672546    
#> 471: 0.329987    1.097202    3.511709    0.199921    0.092570    0.015917    0.672529    
#> 472: 0.330030    1.097157    3.511720    0.199786    0.092534    0.015908    0.672547    
#> 473: 0.329980    1.097131    3.511738    0.199783    0.092557    0.015901    0.672501    
#> 474: 0.330039    1.097024    3.511792    0.199805    0.092539    0.015899    0.672502    
#> 475: 0.330181    1.097034    3.511842    0.199775    0.092529    0.015901    0.672475    
#> 476: 0.330298    1.096947    3.511871    0.199755    0.092549    0.015893    0.672504    
#> 477: 0.330369    1.096905    3.511952    0.199692    0.092531    0.015893    0.672473    
#> 478: 0.330302    1.096880    3.512001    0.199600    0.092504    0.015894    0.672466    
#> 479: 0.330387    1.096891    3.512033    0.199570    0.092554    0.015893    0.672447    
#> 480: 0.330484    1.096865    3.512057    0.199648    0.092619    0.015895    0.672417    
#> 481: 0.330495    1.096794    3.512062    0.199649    0.092689    0.015882    0.672402    
#> 482: 0.330673    1.096754    3.512062    0.199777    0.092740    0.015860    0.672459    
#> 483: 0.330744    1.096720    3.512081    0.199872    0.092794    0.015847    0.672402    
#> 484: 0.330811    1.096618    3.512091    0.200112    0.092801    0.015836    0.672456    
#> 485: 0.330948    1.096582    3.512135    0.200207    0.092755    0.015841    0.672487    
#> 486: 0.331023    1.096621    3.512153    0.200348    0.092742    0.015837    0.672440    
#> 487: 0.331259    1.096588    3.512234    0.200615    0.092749    0.015829    0.672385    
#> 488: 0.331291    1.096559    3.512265    0.200684    0.092772    0.015812    0.672360    
#> 489: 0.331308    1.096521    3.512259    0.200789    0.092775    0.015801    0.672345    
#> 490: 0.331351    1.096523    3.512324    0.200776    0.092764    0.015789    0.672344    
#> 491: 0.331345    1.096562    3.512388    0.200691    0.092705    0.015798    0.672302    
#> 492: 0.331284    1.096581    3.512408    0.200602    0.092697    0.015806    0.672332    
#> 493: 0.331108    1.096608    3.512384    0.200415    0.092708    0.015803    0.672399    
#> 494: 0.331117    1.096711    3.512342    0.200258    0.092758    0.015792    0.672389    
#> 495: 0.331091    1.096756    3.512293    0.200242    0.092809    0.015792    0.672356    
#> 496: 0.331129    1.096841    3.512239    0.200153    0.092763    0.015796    0.672438    
#> 497: 0.331009    1.096866    3.512208    0.200125    0.092771    0.015806    0.672445    
#> 498: 0.331003    1.096880    3.512181    0.199974    0.092766    0.015806    0.672429    
#> 499: 0.330933    1.096915    3.512147    0.199931    0.092766    0.015809    0.672393    
#> 500: 0.330957    1.096838    3.512146    0.199836    0.092756    0.015818    0.672423    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.295977    0.979353    3.441212    0.392401    0.078575    0.016800    1.617246    
#> 002: 0.327385    0.988221    3.474111    0.372781    0.074646    0.016383    1.042192    
#> 003: 0.387091    0.950326    3.470951    0.354142    0.070914    0.015677    0.881254    
#> 004: 0.317648    0.951122    3.463282    0.336435    0.071158    0.014893    0.791885    
#> 005: 0.350152    0.961683    3.450722    0.319613    0.079435    0.014148    0.732200    
#> 006: 0.328955    0.974117    3.452293    0.303633    0.104941    0.013441    0.692369    
#> 007: 0.302851    0.967263    3.445029    0.288451    0.108275    0.012769    0.705526    
#> 008: 0.288828    0.950357    3.438183    0.290781    0.124960    0.012130    0.702092    
#> 009: 0.280618    0.942429    3.431140    0.296191    0.118712    0.011524    0.706846    
#> 010: 0.321270    0.938709    3.433151    0.411892    0.112776    0.012434    0.711109    
#> 011: 0.369639    0.944385    3.448656    0.391297    0.107137    0.015028    0.712035    
#> 012: 0.360723    0.929043    3.443881    0.420393    0.115628    0.014276    0.698145    
#> 013: 0.325883    0.936056    3.436852    0.399374    0.109847    0.013563    0.704819    
#> 014: 0.338648    0.943606    3.437594    0.379405    0.104355    0.012884    0.703096    
#> 015: 0.356091    0.938888    3.456344    0.360435    0.099137    0.013322    0.689159    
#> 016: 0.369630    0.950703    3.464313    0.342413    0.094180    0.012664    0.700122    
#> 017: 0.345842    0.970377    3.460949    0.340569    0.090352    0.012258    0.686857    
#> 018: 0.365483    0.962383    3.447275    0.327689    0.086528    0.013655    0.695927    
#> 019: 0.358712    0.959287    3.452258    0.354251    0.082201    0.013520    0.676120    
#> 020: 0.369489    0.963832    3.461948    0.336539    0.087776    0.013128    0.677847    
#> 021: 0.363448    0.949513    3.467114    0.319712    0.083388    0.013660    0.679638    
#> 022: 0.363353    0.938163    3.471913    0.303726    0.079218    0.013333    0.686375    
#> 023: 0.400413    0.946364    3.473060    0.356184    0.104617    0.013728    0.692310    
#> 024: 0.439763    0.959571    3.473113    0.385967    0.099386    0.014430    0.671212    
#> 025: 0.397921    0.941273    3.467160    0.428505    0.094417    0.013708    0.682710    
#> 026: 0.377630    0.969728    3.449329    0.407080    0.097988    0.013287    0.684568    
#> 027: 0.323948    0.968071    3.448219    0.386726    0.096825    0.013668    0.704306    
#> 028: 0.356280    0.956296    3.457558    0.382990    0.091984    0.014189    0.673860    
#> 029: 0.380839    0.958714    3.458842    0.363841    0.087924    0.014577    0.698251    
#> 030: 0.392475    0.973393    3.451558    0.368892    0.083528    0.014605    0.699997    
#> 031: 0.369201    0.936382    3.460699    0.384131    0.080854    0.015137    0.689543    
#> 032: 0.352673    0.931526    3.463520    0.364924    0.077488    0.017880    0.684953    
#> 033: 0.327835    0.957092    3.458122    0.346678    0.091027    0.018011    0.687681    
#> 034: 0.364824    0.970342    3.455531    0.334978    0.086475    0.017238    0.698189    
#> 035: 0.346356    0.944179    3.451443    0.318229    0.096605    0.016376    0.678416    
#> 036: 0.333128    0.960692    3.448950    0.321486    0.091774    0.016174    0.685580    
#> 037: 0.308269    0.958549    3.438142    0.305411    0.087186    0.015365    0.705302    
#> 038: 0.338992    0.956705    3.435412    0.373686    0.093249    0.014597    0.685272    
#> 039: 0.346925    0.947267    3.444686    0.355001    0.099267    0.013867    0.669350    
#> 040: 0.328807    0.956351    3.451615    0.388961    0.099903    0.013174    0.675160    
#> 041: 0.351449    0.961507    3.450087    0.480025    0.101004    0.012515    0.670669    
#> 042: 0.371807    0.954724    3.448435    0.456024    0.102564    0.011889    0.676196    
#> 043: 0.344029    0.960224    3.441357    0.433223    0.103208    0.011295    0.668626    
#> 044: 0.358038    0.949671    3.442731    0.411562    0.106442    0.010730    0.686695    
#> 045: 0.351142    0.976578    3.436968    0.401778    0.114149    0.010194    0.676938    
#> 046: 0.305561    0.972278    3.428846    0.381689    0.108441    0.009684    0.679874    
#> 047: 0.316294    0.983713    3.422523    0.371463    0.113720    0.009200    0.670393    
#> 048: 0.311633    0.964730    3.424163    0.352889    0.115709    0.008740    0.670924    
#> 049: 0.306136    0.975706    3.428562    0.335245    0.109924    0.008303    0.696923    
#> 050: 0.357095    0.925735    3.442017    0.373060    0.104428    0.007888    0.723830    
#> 051: 0.305694    0.948135    3.439632    0.354407    0.109539    0.007691    0.712561    
#> 052: 0.325732    0.955651    3.445581    0.336687    0.106406    0.007306    0.703076    
#> 053: 0.302036    0.952080    3.439783    0.319852    0.126672    0.007153    0.699116    
#> 054: 0.288834    0.946879    3.445487    0.303860    0.120338    0.009534    0.718505    
#> 055: 0.294447    0.961979    3.444667    0.288667    0.114321    0.013846    0.704457    
#> 056: 0.335631    0.943849    3.457733    0.274233    0.108605    0.013153    0.706157    
#> 057: 0.394370    0.925702    3.476464    0.260522    0.104389    0.012496    0.711404    
#> 058: 0.351069    0.933524    3.466878    0.265783    0.099170    0.011871    0.704792    
#> 059: 0.341690    0.891091    3.471246    0.282837    0.098403    0.013090    0.716338    
#> 060: 0.344376    0.904371    3.477666    0.268695    0.095175    0.012436    0.748326    
#> 061: 0.376205    0.921318    3.464302    0.276841    0.099727    0.011814    0.761527    
#> 062: 0.345873    0.947444    3.464983    0.339734    0.100094    0.011338    0.750716    
#> 063: 0.386698    0.902336    3.468645    0.322747    0.095089    0.010771    0.738065    
#> 064: 0.372753    0.943882    3.466910    0.361156    0.090335    0.010355    0.710849    
#> 065: 0.386371    0.923939    3.458305    0.343098    0.094418    0.010880    0.727106    
#> 066: 0.367694    0.947263    3.457093    0.333246    0.089698    0.010336    0.704051    
#> 067: 0.377019    0.929967    3.449515    0.338727    0.089844    0.012937    0.691195    
#> 068: 0.335118    0.946169    3.450582    0.347158    0.118299    0.012290    0.709762    
#> 069: 0.339223    0.938015    3.443112    0.329800    0.117399    0.011892    0.696636    
#> 070: 0.324235    0.958615    3.455959    0.335822    0.111529    0.014779    0.674315    
#> 071: 0.323069    0.965430    3.445600    0.319031    0.105953    0.014040    0.686126    
#> 072: 0.341644    0.922831    3.455999    0.303079    0.100655    0.013338    0.682476    
#> 073: 0.357624    0.944685    3.469627    0.398517    0.110939    0.013188    0.666408    
#> 074: 0.359734    0.909226    3.466858    0.378591    0.105393    0.012703    0.676601    
#> 075: 0.361972    0.909528    3.476322    0.375160    0.105497    0.012068    0.685619    
#> 076: 0.364906    0.919004    3.485201    0.356402    0.100222    0.011465    0.694291    
#> 077: 0.431460    0.912104    3.470533    0.357005    0.097610    0.010950    0.680144    
#> 078: 0.393033    0.942792    3.468381    0.374745    0.098366    0.010403    0.696800    
#> 079: 0.371733    0.968897    3.466229    0.363131    0.111513    0.009883    0.712986    
#> 080: 0.396055    0.952442    3.466704    0.344975    0.105937    0.011018    0.700223    
#> 081: 0.394064    0.965258    3.457646    0.327726    0.100640    0.011201    0.686562    
#> 082: 0.384349    0.934042    3.478774    0.316067    0.095608    0.010641    0.709570    
#> 083: 0.372315    0.927097    3.464878    0.333555    0.090828    0.010109    0.719281    
#> 084: 0.370594    0.940420    3.460012    0.316877    0.102502    0.009604    0.699579    
#> 085: 0.357130    0.949355    3.460485    0.301034    0.114116    0.009124    0.691645    
#> 086: 0.338169    0.968706    3.454196    0.296490    0.108411    0.008667    0.710998    
#> 087: 0.321125    0.978981    3.438983    0.317276    0.102990    0.010337    0.688275    
#> 088: 0.274255    0.966181    3.436801    0.368075    0.097841    0.009820    0.711377    
#> 089: 0.303796    0.966311    3.432405    0.349672    0.112858    0.009329    0.707131    
#> 090: 0.289919    0.962883    3.427729    0.334893    0.107215    0.008862    0.706726    
#> 091: 0.288395    0.981054    3.418055    0.318149    0.101855    0.008419    0.702736    
#> 092: 0.267753    0.998634    3.413616    0.349591    0.107949    0.009225    0.703659    
#> 093: 0.264035    0.982028    3.417217    0.332111    0.102551    0.011037    0.685287    
#> 094: 0.306813    0.973191    3.417730    0.368569    0.097424    0.010779    0.670338    
#> 095: 0.302162    1.005221    3.431164    0.350140    0.092552    0.012809    0.665235    
#> 096: 0.247269    0.992625    3.427265    0.332633    0.105365    0.012168    0.666589    
#> 097: 0.322577    0.992011    3.425931    0.316001    0.107784    0.011560    0.675562    
#> 098: 0.328545    0.987349    3.440955    0.326210    0.102708    0.011691    0.684700    
#> 099: 0.302922    0.953133    3.425219    0.335989    0.106592    0.011106    0.677794    
#> 100: 0.291014    0.960099    3.431956    0.319190    0.101262    0.010551    0.682282    
#> 101: 0.263873    0.958839    3.409871    0.328364    0.096199    0.010023    0.681239    
#> 102: 0.283522    0.973937    3.406273    0.311946    0.091389    0.009522    0.704683    
#> 103: 0.274211    0.970224    3.419156    0.300389    0.100591    0.009046    0.704949    
#> 104: 0.301739    0.967277    3.432990    0.319531    0.108496    0.008879    0.692155    
#> 105: 0.276220    0.968119    3.430290    0.303554    0.103071    0.008435    0.700833    
#> 106: 0.319034    0.952573    3.435341    0.325163    0.097918    0.008955    0.690067    
#> 107: 0.367995    0.953315    3.439893    0.422139    0.123070    0.008507    0.700859    
#> 108: 0.361992    0.943592    3.439530    0.401032    0.119147    0.008082    0.703305    
#> 109: 0.341970    0.949293    3.457492    0.380980    0.147602    0.007678    0.711430    
#> 110: 0.355522    0.957774    3.437860    0.373691    0.140221    0.007294    0.689555    
#> 111: 0.327470    0.957267    3.438450    0.355006    0.133210    0.006929    0.684329    
#> 112: 0.300579    0.954631    3.428816    0.337256    0.126550    0.006583    0.701028    
#> 113: 0.307311    0.990180    3.429988    0.328951    0.120222    0.006254    0.685438    
#> 114: 0.318375    0.969039    3.434830    0.387675    0.114211    0.005941    0.687979    
#> 115: 0.337898    0.948024    3.437186    0.421758    0.113050    0.005644    0.699623    
#> 116: 0.336661    0.975204    3.441813    0.400670    0.109391    0.005437    0.702441    
#> 117: 0.299546    0.985796    3.438511    0.380636    0.103921    0.005174    0.696397    
#> 118: 0.321977    0.962156    3.439616    0.361604    0.111949    0.004915    0.685261    
#> 119: 0.313434    0.978154    3.438626    0.343524    0.118364    0.004830    0.702097    
#> 120: 0.274576    0.970366    3.433384    0.326877    0.114701    0.004589    0.712963    
#> 121: 0.303506    0.996520    3.430171    0.310533    0.113171    0.004930    0.720790    
#> 122: 0.315013    0.949625    3.438663    0.295006    0.107512    0.004683    0.738491    
#> 123: 0.340544    0.991633    3.436194    0.303737    0.102137    0.004449    0.725676    
#> 124: 0.321338    1.000386    3.423891    0.328265    0.101520    0.004227    0.713506    
#> 125: 0.291832    0.990859    3.417601    0.333125    0.112089    0.004015    0.714789    
#> 126: 0.275394    1.000206    3.411098    0.316469    0.116951    0.003814    0.706616    
#> 127: 0.282422    0.971230    3.412888    0.317808    0.127926    0.003764    0.710859    
#> 128: 0.258332    0.991325    3.422064    0.301918    0.121530    0.003575    0.723010    
#> 129: 0.329472    0.984894    3.431313    0.317364    0.115453    0.004382    0.715098    
#> 130: 0.339308    0.985288    3.438713    0.316460    0.121753    0.004830    0.688339    
#> 131: 0.323163    0.963356    3.428512    0.338567    0.119904    0.004588    0.686941    
#> 132: 0.309257    0.959025    3.419000    0.396475    0.124664    0.004915    0.701377    
#> 133: 0.290978    0.953673    3.422917    0.376651    0.136928    0.005378    0.690583    
#> 134: 0.301356    0.941523    3.425850    0.385017    0.130082    0.007642    0.688939    
#> 135: 0.320852    0.947664    3.431722    0.402280    0.123578    0.007259    0.686839    
#> 136: 0.318022    0.941198    3.433590    0.382166    0.124010    0.006896    0.673840    
#> 137: 0.396094    0.968449    3.439848    0.428373    0.117809    0.006552    0.689593    
#> 138: 0.330459    0.955536    3.434269    0.413795    0.115809    0.006224    0.695829    
#> 139: 0.308134    0.969908    3.432239    0.393105    0.110018    0.005913    0.689060    
#> 140: 0.318877    0.971337    3.442912    0.373450    0.109444    0.007455    0.683131    
#> 141: 0.306644    0.941084    3.450137    0.354777    0.105111    0.008135    0.695214    
#> 142: 0.380928    0.947486    3.459292    0.380654    0.106118    0.007729    0.701537    
#> 143: 0.367016    0.963012    3.464927    0.395879    0.116022    0.008489    0.691909    
#> 144: 0.368064    0.962661    3.459886    0.376085    0.120757    0.008064    0.691668    
#> 145: 0.335828    0.960680    3.452588    0.357281    0.114719    0.007661    0.679971    
#> 146: 0.320798    0.964524    3.462607    0.385667    0.109635    0.007278    0.692646    
#> 147: 0.324606    0.946556    3.458098    0.366384    0.104153    0.009206    0.668839    
#> 148: 0.324589    0.964701    3.464443    0.348065    0.101259    0.010024    0.673335    
#> 149: 0.343290    0.948005    3.459835    0.330662    0.096196    0.011645    0.679387    
#> 150: 0.349677    0.927387    3.453099    0.314128    0.091386    0.011063    0.692348    
#> 151: 0.312752    0.970304    3.449924    0.298641    0.095214    0.010510    0.684982    
#> 152: 0.323951    0.964568    3.449685    0.332403    0.102573    0.006270    0.686221    
#> 153: 0.307251    0.961378    3.450561    0.306530    0.104923    0.007331    0.688321    
#> 154: 0.373684    0.975379    3.458834    0.283196    0.120629    0.008426    0.701157    
#> 155: 0.317829    0.949998    3.442733    0.268756    0.112938    0.006998    0.688415    
#> 156: 0.337827    0.927531    3.454748    0.287107    0.100383    0.006751    0.698207    
#> 157: 0.339674    0.932768    3.464557    0.337315    0.120319    0.008107    0.697424    
#> 158: 0.388322    0.966421    3.461884    0.325517    0.110484    0.007268    0.696749    
#> 159: 0.340777    0.982323    3.452727    0.313978    0.092131    0.007339    0.696225    
#> 160: 0.342608    0.944948    3.456891    0.299880    0.088457    0.006797    0.695958    
#> 161: 0.367373    0.966481    3.450451    0.333206    0.084602    0.007369    0.689902    
#> 162: 0.348406    0.965267    3.447886    0.330862    0.102980    0.005689    0.720320    
#> 163: 0.356398    0.964333    3.435335    0.362740    0.125633    0.005961    0.690285    
#> 164: 0.334395    0.967445    3.436222    0.337679    0.097346    0.004211    0.697983    
#> 165: 0.328315    0.940323    3.441270    0.367145    0.110587    0.003920    0.693935    
#> 166: 0.326105    0.978826    3.442509    0.322525    0.129342    0.003703    0.688868    
#> 167: 0.318901    0.965856    3.447487    0.329045    0.127316    0.003511    0.694733    
#> 168: 0.354465    0.974235    3.446781    0.388799    0.130074    0.003618    0.692698    
#> 169: 0.335342    0.981292    3.438019    0.343648    0.114649    0.004275    0.705305    
#> 170: 0.344459    0.975671    3.438042    0.390360    0.117344    0.004658    0.701267    
#> 171: 0.288456    0.971792    3.437602    0.312902    0.111041    0.004398    0.686685    
#> 172: 0.280096    0.972343    3.436578    0.272059    0.138975    0.004238    0.696273    
#> 173: 0.307472    0.950568    3.438832    0.345027    0.117321    0.003687    0.702754    
#> 174: 0.324425    0.954575    3.443615    0.365866    0.130200    0.003395    0.692382    
#> 175: 0.329285    0.945626    3.438744    0.367922    0.134975    0.002852    0.696926    
#> 176: 0.344587    0.954934    3.441322    0.379901    0.125512    0.002720    0.701399    
#> 177: 0.337252    0.941472    3.445978    0.369857    0.136192    0.002047    0.716179    
#> 178: 0.348032    0.933510    3.446190    0.316250    0.141182    0.002040    0.704457    
#> 179: 0.368905    0.969642    3.446339    0.301198    0.109782    0.002872    0.708812    
#> 180: 0.328430    0.982372    3.446424    0.286479    0.124224    0.003275    0.707773    
#> 181: 0.307016    0.963574    3.426702    0.290912    0.095577    0.002889    0.700853    
#> 182: 0.277870    0.979520    3.421017    0.329459    0.126333    0.002932    0.694308    
#> 183: 0.293368    1.003598    3.418691    0.299435    0.127866    0.002881    0.694938    
#> 184: 0.277006    0.988361    3.418228    0.286771    0.112820    0.003052    0.696521    
#> 185: 0.277912    0.992783    3.408261    0.314174    0.119188    0.002907    0.720732    
#> 186: 0.246278    0.991196    3.414621    0.290707    0.125427    0.003116    0.704314    
#> 187: 0.295242    0.986245    3.419513    0.345858    0.118541    0.002537    0.702185    
#> 188: 0.267706    1.000426    3.412282    0.308642    0.126679    0.002496    0.723560    
#> 189: 0.310763    1.001117    3.419490    0.311388    0.113715    0.002802    0.721574    
#> 190: 0.304700    0.982403    3.428400    0.316794    0.104526    0.002465    0.689867    
#> 191: 0.289507    0.986442    3.422638    0.277095    0.117619    0.002321    0.688730    
#> 192: 0.272168    0.998696    3.422906    0.383171    0.107007    0.003241    0.694102    
#> 193: 0.333030    0.987813    3.426134    0.392984    0.085546    0.002824    0.687581    
#> 194: 0.302285    0.978434    3.422081    0.381665    0.110355    0.003583    0.692803    
#> 195: 0.245531    0.983699    3.414091    0.347208    0.123576    0.003469    0.701206    
#> 196: 0.267846    0.974530    3.421803    0.319030    0.132763    0.002846    0.722154    
#> 197: 0.265496    0.970133    3.430536    0.347110    0.124833    0.002611    0.729582    
#> 198: 0.331854    0.943879    3.424252    0.347280    0.123771    0.002601    0.707889    
#> 199: 0.281374    0.967475    3.425891    0.362270    0.127177    0.002604    0.705822    
#> 200: 0.275383    0.974487    3.428171    0.412116    0.110598    0.002547    0.711074    
#> 201: 0.297875    0.967801    3.430297    0.442994    0.106739    0.002966    0.706849    
#> 202: 0.309667    0.970041    3.430621    0.469308    0.112744    0.002831    0.707378    
#> 203: 0.323865    0.968356    3.430703    0.487443    0.114513    0.002729    0.707786    
#> 204: 0.334959    0.961650    3.432319    0.478821    0.118906    0.002741    0.706985    
#> 205: 0.339274    0.965684    3.433074    0.474597    0.120857    0.002709    0.707520    
#> 206: 0.337149    0.970171    3.433487    0.463181    0.125169    0.002751    0.707546    
#> 207: 0.338321    0.970981    3.433208    0.464297    0.127588    0.002677    0.706728    
#> 208: 0.337945    0.969915    3.432717    0.461096    0.128445    0.002595    0.705311    
#> 209: 0.344893    0.967116    3.433044    0.461951    0.127988    0.002607    0.706202    
#> 210: 0.344633    0.963347    3.433351    0.458321    0.127957    0.002571    0.705712    
#> 211: 0.345341    0.963722    3.433862    0.451998    0.128166    0.002496    0.704588    
#> 212: 0.345807    0.962792    3.434306    0.440340    0.128798    0.002451    0.705107    
#> 213: 0.347083    0.960962    3.434440    0.433695    0.130690    0.002431    0.706682    
#> 214: 0.346502    0.961282    3.434033    0.429249    0.130985    0.002392    0.705773    
#> 215: 0.344672    0.962719    3.433561    0.424535    0.131115    0.002356    0.705724    
#> 216: 0.344389    0.962953    3.433469    0.421022    0.131580    0.002334    0.707234    
#> 217: 0.340367    0.963889    3.433135    0.418751    0.132014    0.002347    0.707739    
#> 218: 0.339492    0.965229    3.432700    0.415278    0.132754    0.002310    0.707608    
#> 219: 0.336703    0.966426    3.431660    0.413066    0.132134    0.002322    0.707147    
#> 220: 0.333847    0.967773    3.431211    0.414619    0.131363    0.002319    0.706896    
#> 221: 0.332281    0.967928    3.430622    0.414318    0.130997    0.002311    0.706754    
#> 222: 0.330975    0.967661    3.430226    0.411831    0.130513    0.002338    0.706950    
#> 223: 0.329996    0.967911    3.430068    0.409318    0.131002    0.002348    0.707133    
#> 224: 0.329720    0.967095    3.430174    0.409589    0.131399    0.002352    0.706354    
#> 225: 0.328560    0.965191    3.430512    0.408599    0.131836    0.002374    0.706305    
#> 226: 0.328351    0.964427    3.430464    0.406770    0.132384    0.002394    0.706691    
#> 227: 0.327180    0.964175    3.430595    0.404201    0.132384    0.002410    0.707603    
#> 228: 0.325673    0.964484    3.430267    0.402541    0.132927    0.002410    0.707711    
#> 229: 0.324445    0.964204    3.429877    0.400740    0.133695    0.002400    0.707693    
#> 230: 0.324077    0.964504    3.429468    0.400057    0.133559    0.002388    0.707443    
#> 231: 0.322869    0.965034    3.429305    0.399663    0.133643    0.002389    0.707231    
#> 232: 0.321619    0.965754    3.429366    0.396924    0.133452    0.002387    0.707262    
#> 233: 0.320327    0.965526    3.429336    0.397377    0.133082    0.002399    0.707698    
#> 234: 0.318725    0.966057    3.429254    0.396718    0.132625    0.002401    0.707458    
#> 235: 0.318194    0.966373    3.429028    0.394135    0.132814    0.002411    0.707510    
#> 236: 0.317210    0.966348    3.428856    0.393415    0.132569    0.002424    0.707283    
#> 237: 0.316865    0.966679    3.428698    0.391967    0.131747    0.002445    0.707611    
#> 238: 0.316579    0.966889    3.428422    0.392426    0.131682    0.002484    0.707579    
#> 239: 0.315980    0.967610    3.428205    0.392231    0.131492    0.002491    0.707534    
#> 240: 0.315746    0.967562    3.428123    0.391871    0.131153    0.002482    0.707136    
#> 241: 0.315833    0.967023    3.428070    0.392199    0.130562    0.002477    0.707098    
#> 242: 0.314841    0.966519    3.427924    0.392325    0.130632    0.002489    0.707147    
#> 243: 0.314270    0.967054    3.427735    0.392230    0.130866    0.002508    0.707250    
#> 244: 0.313973    0.967159    3.427671    0.392292    0.130682    0.002541    0.706867    
#> 245: 0.314211    0.966887    3.427641    0.391377    0.130236    0.002557    0.706963    
#> 246: 0.314820    0.966884    3.427703    0.390154    0.129757    0.002591    0.706868    
#> 247: 0.314853    0.966686    3.427953    0.387605    0.129155    0.002612    0.707106    
#> 248: 0.314449    0.966801    3.428049    0.386182    0.128506    0.002621    0.707129    
#> 249: 0.314034    0.966747    3.428020    0.384726    0.128190    0.002628    0.706922    
#> 250: 0.314964    0.967259    3.428065    0.384537    0.127939    0.002649    0.706804    
#> 251: 0.315410    0.967945    3.428082    0.383962    0.127360    0.002649    0.706959    
#> 252: 0.315477    0.968559    3.428121    0.384626    0.127103    0.002644    0.706859    
#> 253: 0.315273    0.968814    3.428119    0.385432    0.126425    0.002658    0.706719    
#> 254: 0.315456    0.968975    3.428191    0.386778    0.126216    0.002667    0.706647    
#> 255: 0.316179    0.969561    3.428325    0.387818    0.125932    0.002691    0.706844    
#> 256: 0.316097    0.969672    3.428404    0.386520    0.125913    0.002709    0.706889    
#> 257: 0.315868    0.969334    3.428349    0.386042    0.126005    0.002723    0.706836    
#> 258: 0.315660    0.969206    3.428266    0.384863    0.126351    0.002721    0.707017    
#> 259: 0.315291    0.969047    3.428225    0.384004    0.126293    0.002715    0.706876    
#> 260: 0.314958    0.969354    3.428293    0.384101    0.126252    0.002707    0.706686    
#> 261: 0.315394    0.969184    3.428377    0.384871    0.125958    0.002703    0.706743    
#> 262: 0.315500    0.969254    3.428481    0.384174    0.125721    0.002700    0.706645    
#> 263: 0.315192    0.969262    3.428555    0.383452    0.125507    0.002707    0.706666    
#> 264: 0.314812    0.969173    3.428578    0.383464    0.125518    0.002708    0.706930    
#> 265: 0.314189    0.969317    3.428589    0.384289    0.125284    0.002713    0.706901    
#> 266: 0.314650    0.969420    3.428535    0.385276    0.125272    0.002716    0.706946    
#> 267: 0.315215    0.969577    3.428585    0.386728    0.125230    0.002713    0.706792    
#> 268: 0.315453    0.969315    3.428558    0.386314    0.125280    0.002709    0.706713    
#> 269: 0.315940    0.969206    3.428552    0.385893    0.125042    0.002711    0.706568    
#> 270: 0.316056    0.969658    3.428421    0.386538    0.124837    0.002710    0.706208    
#> 271: 0.315686    0.970116    3.428185    0.386903    0.124507    0.002716    0.706204    
#> 272: 0.315414    0.970178    3.427986    0.385890    0.124475    0.002713    0.706385    
#> 273: 0.314779    0.970526    3.427805    0.385353    0.124371    0.002717    0.706580    
#> 274: 0.314080    0.971152    3.427647    0.385178    0.124208    0.002709    0.706763    
#> 275: 0.313849    0.971318    3.427458    0.383867    0.124117    0.002709    0.706947    
#> 276: 0.313619    0.971522    3.427542    0.383836    0.123978    0.002732    0.706939    
#> 277: 0.313686    0.971788    3.427710    0.383846    0.123944    0.002759    0.706686    
#> 278: 0.313814    0.971869    3.427810    0.384103    0.123840    0.002774    0.706539    
#> 279: 0.313704    0.971785    3.427856    0.383768    0.123750    0.002792    0.706622    
#> 280: 0.313384    0.971788    3.427938    0.382998    0.123631    0.002793    0.706573    
#> 281: 0.312759    0.971669    3.427990    0.381631    0.123322    0.002786    0.706742    
#> 282: 0.312562    0.971857    3.427988    0.381028    0.123092    0.002798    0.706784    
#> 283: 0.312404    0.972067    3.428032    0.380609    0.123220    0.002812    0.707065    
#> 284: 0.312178    0.972105    3.428024    0.379773    0.123095    0.002821    0.706983    
#> 285: 0.312461    0.972313    3.427971    0.379362    0.122934    0.002830    0.706837    
#> 286: 0.312650    0.972391    3.427901    0.379192    0.122747    0.002838    0.706723    
#> 287: 0.312212    0.972673    3.427798    0.378626    0.122583    0.002841    0.706385    
#> 288: 0.312331    0.972667    3.427719    0.378148    0.122329    0.002840    0.706252    
#> 289: 0.312543    0.972878    3.427668    0.377985    0.122350    0.002837    0.706112    
#> 290: 0.312399    0.972959    3.427642    0.377767    0.122515    0.002835    0.706152    
#> 291: 0.312501    0.973038    3.427686    0.376780    0.122621    0.002833    0.706207    
#> 292: 0.312502    0.972825    3.427727    0.376153    0.122607    0.002829    0.706278    
#> 293: 0.312344    0.972759    3.427713    0.375543    0.122559    0.002825    0.706152    
#> 294: 0.312161    0.972763    3.427707    0.374984    0.122411    0.002821    0.706166    
#> 295: 0.312256    0.972361    3.427703    0.375157    0.122312    0.002816    0.706052    
#> 296: 0.312436    0.972317    3.427779    0.375898    0.122217    0.002822    0.705981    
#> 297: 0.312597    0.972436    3.427836    0.375874    0.122307    0.002829    0.705878    
#> 298: 0.312776    0.972481    3.427943    0.376287    0.122353    0.002836    0.705766    
#> 299: 0.313061    0.972421    3.428027    0.376434    0.122349    0.002834    0.705652    
#> 300: 0.313112    0.972228    3.428097    0.376089    0.122190    0.002825    0.705569    
#> 301: 0.313351    0.971864    3.428131    0.375782    0.122013    0.002818    0.705708    
#> 302: 0.313500    0.971866    3.428176    0.375298    0.121858    0.002816    0.705725    
#> 303: 0.313390    0.971890    3.428168    0.374851    0.121603    0.002816    0.705612    
#> 304: 0.313489    0.972202    3.428118    0.375021    0.121454    0.002821    0.705546    
#> 305: 0.313349    0.971997    3.428097    0.374907    0.121314    0.002832    0.705552    
#> 306: 0.313207    0.971959    3.428057    0.374609    0.121180    0.002838    0.705568    
#> 307: 0.313096    0.971799    3.428015    0.374050    0.121074    0.002835    0.705530    
#> 308: 0.312744    0.971697    3.427942    0.374227    0.121149    0.002833    0.705569    
#> 309: 0.312611    0.971454    3.427892    0.373957    0.121183    0.002826    0.705640    
#> 310: 0.312750    0.971429    3.427807    0.373622    0.121049    0.002824    0.705707    
#> 311: 0.312746    0.971408    3.427778    0.373441    0.120862    0.002832    0.705699    
#> 312: 0.312235    0.971290    3.427716    0.372804    0.120859    0.002831    0.705772    
#> 313: 0.311927    0.971065    3.427624    0.372147    0.120967    0.002828    0.705940    
#> 314: 0.311662    0.971241    3.427525    0.372067    0.121015    0.002825    0.705918    
#> 315: 0.311563    0.971498    3.427501    0.371493    0.121181    0.002832    0.705903    
#> 316: 0.311360    0.971642    3.427473    0.370959    0.121148    0.002837    0.706031    
#> 317: 0.311206    0.971677    3.427492    0.370345    0.121171    0.002836    0.706273    
#> 318: 0.311226    0.971715    3.427447    0.370051    0.121316    0.002835    0.706330    
#> 319: 0.311117    0.971772    3.427443    0.370152    0.121484    0.002834    0.706311    
#> 320: 0.310866    0.971794    3.427395    0.370372    0.121572    0.002834    0.706367    
#> 321: 0.310658    0.972003    3.427307    0.369949    0.121653    0.002837    0.706448    
#> 322: 0.310519    0.971962    3.427195    0.369492    0.121536    0.002838    0.706381    
#> 323: 0.310045    0.971823    3.427147    0.369577    0.121377    0.002842    0.706287    
#> 324: 0.309988    0.971910    3.427185    0.369554    0.121328    0.002847    0.706184    
#> 325: 0.310102    0.971865    3.427150    0.369154    0.121310    0.002846    0.706092    
#> 326: 0.310144    0.971633    3.427094    0.368644    0.121403    0.002842    0.705999    
#> 327: 0.310285    0.971740    3.427101    0.368197    0.121287    0.002839    0.705996    
#> 328: 0.310338    0.971883    3.427070    0.368033    0.121233    0.002835    0.705907    
#> 329: 0.310218    0.971906    3.427053    0.367589    0.121202    0.002833    0.705985    
#> 330: 0.309999    0.971961    3.427039    0.367038    0.121087    0.002832    0.706036    
#> 331: 0.310094    0.972134    3.427047    0.366731    0.120997    0.002831    0.706046    
#> 332: 0.310005    0.972173    3.427048    0.366453    0.120988    0.002833    0.705998    
#> 333: 0.309782    0.972309    3.426988    0.366072    0.121003    0.002839    0.705938    
#> 334: 0.309686    0.972239    3.426868    0.366068    0.120882    0.002843    0.705933    
#> 335: 0.309251    0.972429    3.426724    0.366031    0.120815    0.002848    0.705883    
#> 336: 0.308687    0.972651    3.426613    0.366225    0.120659    0.002856    0.705919    
#> 337: 0.308422    0.973007    3.426470    0.366604    0.120522    0.002859    0.706010    
#> 338: 0.308069    0.973086    3.426398    0.366581    0.120406    0.002853    0.706077    
#> 339: 0.307808    0.973253    3.426341    0.366412    0.120367    0.002850    0.706087    
#> 340: 0.307816    0.973109    3.426345    0.366196    0.120310    0.002855    0.706099    
#> 341: 0.307924    0.973094    3.426357    0.365706    0.120249    0.002858    0.706193    
#> 342: 0.307640    0.972971    3.426316    0.365487    0.120229    0.002856    0.706085    
#> 343: 0.307262    0.972977    3.426306    0.365141    0.120201    0.002852    0.706052    
#> 344: 0.307248    0.973013    3.426351    0.364594    0.120283    0.002852    0.706073    
#> 345: 0.307261    0.972888    3.426408    0.363910    0.120344    0.002853    0.706135    
#> 346: 0.307156    0.972870    3.426416    0.363078    0.120303    0.002846    0.706096    
#> 347: 0.307334    0.972797    3.426362    0.363570    0.120260    0.002842    0.706024    
#> 348: 0.307085    0.972827    3.426272    0.363725    0.120288    0.002846    0.706056    
#> 349: 0.306767    0.972787    3.426186    0.363723    0.120384    0.002850    0.706122    
#> 350: 0.306473    0.972740    3.426130    0.363777    0.120441    0.002853    0.706066    
#> 351: 0.306463    0.973042    3.426065    0.363966    0.120535    0.002858    0.706036    
#> 352: 0.306231    0.973231    3.426037    0.364161    0.120588    0.002860    0.706066    
#> 353: 0.306262    0.973430    3.426005    0.363881    0.120543    0.002857    0.705988    
#> 354: 0.306334    0.973464    3.425932    0.363677    0.120585    0.002854    0.705990    
#> 355: 0.306584    0.973264    3.425880    0.363742    0.120623    0.002858    0.706036    
#> 356: 0.306529    0.973243    3.425877    0.363972    0.120585    0.002854    0.706150    
#> 357: 0.306788    0.973338    3.425861    0.364052    0.120564    0.002849    0.706203    
#> 358: 0.306766    0.973295    3.425883    0.364058    0.120474    0.002848    0.706025    
#> 359: 0.306743    0.973328    3.425880    0.364274    0.120456    0.002848    0.705863    
#> 360: 0.306778    0.973244    3.425834    0.364376    0.120409    0.002846    0.705736    
#> 361: 0.306599    0.973119    3.425798    0.364414    0.120301    0.002844    0.705681    
#> 362: 0.306613    0.973061    3.425756    0.364258    0.120303    0.002842    0.705486    
#> 363: 0.306577    0.973037    3.425720    0.364182    0.120305    0.002841    0.705327    
#> 364: 0.306705    0.973009    3.425691    0.364173    0.120281    0.002843    0.705291    
#> 365: 0.306752    0.972933    3.425712    0.363980    0.120336    0.002845    0.705329    
#> 366: 0.306858    0.972989    3.425703    0.363589    0.120308    0.002848    0.705381    
#> 367: 0.306993    0.972945    3.425714    0.363628    0.120306    0.002844    0.705308    
#> 368: 0.307014    0.972945    3.425688    0.363495    0.120328    0.002840    0.705264    
#> 369: 0.306886    0.972892    3.425714    0.363129    0.120404    0.002841    0.705256    
#> 370: 0.306814    0.973048    3.425718    0.362703    0.120486    0.002839    0.705305    
#> 371: 0.306718    0.973087    3.425659    0.362546    0.120478    0.002835    0.705354    
#> 372: 0.306312    0.973179    3.425573    0.362773    0.120452    0.002833    0.705373    
#> 373: 0.306072    0.973157    3.425484    0.362997    0.120526    0.002831    0.705456    
#> 374: 0.306076    0.973169    3.425395    0.362985    0.120593    0.002828    0.705461    
#> 375: 0.305943    0.973231    3.425328    0.363145    0.120716    0.002825    0.705475    
#> 376: 0.305901    0.973307    3.425271    0.363391    0.120657    0.002821    0.705449    
#> 377: 0.305911    0.973349    3.425239    0.363562    0.120574    0.002818    0.705471    
#> 378: 0.305830    0.973335    3.425195    0.363546    0.120489    0.002818    0.705493    
#> 379: 0.305510    0.973259    3.425170    0.363247    0.120411    0.002819    0.705413    
#> 380: 0.305397    0.973164    3.425161    0.363294    0.120427    0.002815    0.705405    
#> 381: 0.305126    0.973076    3.425128    0.363042    0.120412    0.002811    0.705528    
#> 382: 0.305078    0.973120    3.425107    0.362766    0.120378    0.002807    0.705432    
#> 383: 0.305007    0.973109    3.425097    0.362456    0.120390    0.002801    0.705457    
#> 384: 0.304887    0.973090    3.425102    0.362456    0.120415    0.002796    0.705463    
#> 385: 0.305070    0.972986    3.425151    0.362786    0.120377    0.002801    0.705460    
#> 386: 0.305277    0.973084    3.425205    0.363106    0.120372    0.002804    0.705497    
#> 387: 0.305391    0.973272    3.425226    0.362750    0.120298    0.002806    0.705593    
#> 388: 0.305390    0.973220    3.425248    0.362416    0.120347    0.002806    0.705688    
#> 389: 0.305366    0.973120    3.425221    0.362114    0.120268    0.002801    0.705803    
#> 390: 0.305303    0.973103    3.425190    0.362046    0.120251    0.002796    0.705840    
#> 391: 0.305485    0.973092    3.425170    0.362061    0.120295    0.002791    0.705853    
#> 392: 0.305582    0.973119    3.425192    0.362400    0.120305    0.002786    0.705767    
#> 393: 0.305496    0.973093    3.425158    0.362566    0.120325    0.002784    0.705665    
#> 394: 0.305516    0.973144    3.425121    0.362658    0.120371    0.002782    0.705604    
#> 395: 0.305608    0.973281    3.425103    0.362545    0.120404    0.002779    0.705634    
#> 396: 0.305758    0.973383    3.425100    0.362597    0.120425    0.002777    0.705584    
#> 397: 0.305756    0.973322    3.425104    0.362789    0.120447    0.002774    0.705596    
#> 398: 0.305827    0.973249    3.425121    0.362837    0.120521    0.002777    0.705625    
#> 399: 0.305807    0.973205    3.425177    0.362932    0.120506    0.002780    0.705583    
#> 400: 0.305898    0.973119    3.425209    0.362829    0.120574    0.002780    0.705604    
#> 401: 0.306030    0.973117    3.425231    0.362659    0.120532    0.002784    0.705577    
#> 402: 0.306034    0.973312    3.425245    0.362473    0.120514    0.002790    0.705565    
#> 403: 0.306184    0.973339    3.425259    0.362378    0.120396    0.002799    0.705479    
#> 404: 0.306064    0.973450    3.425224    0.361990    0.120407    0.002803    0.705422    
#> 405: 0.305997    0.973520    3.425220    0.361780    0.120397    0.002806    0.705495    
#> 406: 0.306016    0.973550    3.425202    0.362134    0.120442    0.002810    0.705429    
#> 407: 0.305941    0.973588    3.425216    0.362317    0.120418    0.002810    0.705446    
#> 408: 0.306043    0.973648    3.425209    0.362287    0.120436    0.002811    0.705446    
#> 409: 0.305885    0.973579    3.425195    0.362437    0.120399    0.002809    0.705384    
#> 410: 0.305767    0.973567    3.425135    0.362266    0.120446    0.002806    0.705358    
#> 411: 0.305703    0.973438    3.425103    0.362370    0.120464    0.002805    0.705335    
#> 412: 0.305556    0.973604    3.425051    0.362533    0.120454    0.002807    0.705385    
#> 413: 0.305484    0.973685    3.425003    0.362630    0.120452    0.002804    0.705460    
#> 414: 0.305410    0.973654    3.424976    0.362569    0.120443    0.002802    0.705433    
#> 415: 0.305375    0.973688    3.424920    0.362546    0.120521    0.002797    0.705527    
#> 416: 0.305228    0.973806    3.424864    0.362618    0.120571    0.002794    0.705499    
#> 417: 0.305016    0.973871    3.424777    0.362878    0.120524    0.002792    0.705501    
#> 418: 0.304765    0.973993    3.424699    0.362887    0.120610    0.002789    0.705499    
#> 419: 0.304681    0.974029    3.424642    0.363156    0.120605    0.002790    0.705460    
#> 420: 0.304670    0.974021    3.424596    0.363053    0.120554    0.002790    0.705480    
#> 421: 0.304592    0.974031    3.424592    0.363175    0.120531    0.002791    0.705414    
#> 422: 0.304591    0.973998    3.424593    0.363227    0.120582    0.002794    0.705339    
#> 423: 0.304774    0.973975    3.424611    0.363031    0.120561    0.002797    0.705332    
#> 424: 0.304814    0.973857    3.424614    0.362842    0.120548    0.002793    0.705344    
#> 425: 0.304754    0.973868    3.424620    0.362863    0.120563    0.002790    0.705303    
#> 426: 0.304817    0.973983    3.424634    0.362843    0.120506    0.002788    0.705263    
#> 427: 0.304725    0.973932    3.424676    0.362763    0.120488    0.002787    0.705203    
#> 428: 0.304699    0.973978    3.424671    0.362668    0.120445    0.002786    0.705214    
#> 429: 0.304585    0.974055    3.424668    0.362393    0.120463    0.002786    0.705171    
#> 430: 0.304503    0.974125    3.424662    0.362376    0.120467    0.002786    0.705216    
#> 431: 0.304304    0.974139    3.424595    0.362222    0.120486    0.002787    0.705151    
#> 432: 0.304064    0.974236    3.424555    0.361876    0.120461    0.002789    0.705160    
#> 433: 0.304005    0.974387    3.424535    0.361565    0.120465    0.002789    0.705185    
#> 434: 0.303768    0.974387    3.424518    0.361518    0.120494    0.002791    0.705142    
#> 435: 0.303763    0.974346    3.424508    0.361296    0.120571    0.002788    0.705138    
#> 436: 0.303717    0.974268    3.424523    0.361047    0.120558    0.002785    0.705148    
#> 437: 0.303717    0.974178    3.424520    0.360793    0.120479    0.002786    0.705108    
#> 438: 0.303835    0.974235    3.424540    0.360673    0.120384    0.002785    0.705087    
#> 439: 0.303938    0.974241    3.424560    0.360611    0.120348    0.002779    0.705060    
#> 440: 0.303934    0.974234    3.424615    0.360521    0.120357    0.002778    0.705129    
#> 441: 0.304015    0.974204    3.424652    0.360631    0.120347    0.002777    0.705123    
#> 442: 0.303793    0.974256    3.424666    0.360513    0.120315    0.002774    0.705059    
#> 443: 0.303744    0.974316    3.424652    0.360409    0.120248    0.002777    0.704987    
#> 444: 0.303587    0.974383    3.424626    0.360447    0.120154    0.002783    0.704933    
#> 445: 0.303495    0.974429    3.424586    0.360352    0.120044    0.002788    0.704957    
#> 446: 0.303277    0.974495    3.424543    0.360230    0.119966    0.002794    0.704930    
#> 447: 0.303310    0.974516    3.424540    0.360119    0.119965    0.002801    0.704859    
#> 448: 0.303174    0.974578    3.424543    0.360102    0.119934    0.002809    0.704762    
#> 449: 0.303136    0.974686    3.424604    0.360071    0.120000    0.002814    0.704698    
#> 450: 0.303240    0.974612    3.424649    0.360139    0.120018    0.002821    0.704669    
#> 451: 0.303396    0.974529    3.424672    0.360355    0.120053    0.002827    0.704679    
#> 452: 0.303423    0.974544    3.424656    0.360621    0.120052    0.002827    0.704654    
#> 453: 0.303500    0.974564    3.424641    0.360884    0.120013    0.002823    0.704653    
#> 454: 0.303575    0.974685    3.424619    0.360960    0.120000    0.002822    0.704661    
#> 455: 0.303607    0.974714    3.424586    0.360863    0.119933    0.002820    0.704638    
#> 456: 0.303581    0.974679    3.424576    0.360728    0.119993    0.002822    0.704662    
#> 457: 0.303474    0.974619    3.424584    0.360862    0.120084    0.002821    0.704625    
#> 458: 0.303433    0.974690    3.424612    0.360670    0.120168    0.002818    0.704579    
#> 459: 0.303259    0.974759    3.424617    0.360496    0.120209    0.002814    0.704638    
#> 460: 0.303066    0.974752    3.424601    0.360433    0.120326    0.002810    0.704706    
#> 461: 0.302964    0.974770    3.424600    0.360366    0.120338    0.002810    0.704760    
#> 462: 0.302830    0.974804    3.424613    0.360264    0.120291    0.002811    0.704691    
#> 463: 0.302771    0.974878    3.424605    0.360050    0.120324    0.002813    0.704640    
#> 464: 0.302732    0.974940    3.424590    0.360059    0.120298    0.002816    0.704541    
#> 465: 0.302766    0.974845    3.424582    0.360123    0.120284    0.002815    0.704537    
#> 466: 0.302837    0.974883    3.424554    0.360109    0.120233    0.002814    0.704550    
#> 467: 0.302802    0.974855    3.424528    0.360315    0.120243    0.002816    0.704416    
#> 468: 0.302937    0.974852    3.424513    0.360338    0.120245    0.002816    0.704506    
#> 469: 0.302945    0.974938    3.424503    0.360255    0.120257    0.002819    0.704557    
#> 470: 0.302900    0.974958    3.424487    0.360435    0.120328    0.002821    0.704497    
#> 471: 0.302833    0.974914    3.424480    0.360559    0.120318    0.002821    0.704501    
#> 472: 0.302934    0.974870    3.424509    0.360803    0.120356    0.002821    0.704480    
#> 473: 0.302933    0.974815    3.424524    0.360896    0.120397    0.002823    0.704414    
#> 474: 0.302920    0.974847    3.424536    0.360929    0.120443    0.002827    0.704433    
#> 475: 0.303040    0.974867    3.424539    0.360937    0.120415    0.002831    0.704378    
#> 476: 0.303024    0.974850    3.424524    0.360750    0.120397    0.002833    0.704404    
#> 477: 0.303006    0.974836    3.424534    0.360626    0.120382    0.002836    0.704377    
#> 478: 0.302886    0.974812    3.424546    0.360575    0.120414    0.002838    0.704382    
#> 479: 0.302882    0.974882    3.424559    0.360757    0.120436    0.002838    0.704404    
#> 480: 0.302890    0.974829    3.424577    0.360911    0.120490    0.002841    0.704388    
#> 481: 0.302877    0.974785    3.424556    0.361214    0.120547    0.002843    0.704397    
#> 482: 0.302920    0.974795    3.424529    0.361580    0.120605    0.002842    0.704380    
#> 483: 0.302823    0.974792    3.424506    0.361616    0.120601    0.002842    0.704370    
#> 484: 0.302855    0.974694    3.424495    0.362113    0.120586    0.002842    0.704396    
#> 485: 0.302801    0.974678    3.424489    0.362225    0.120561    0.002841    0.704439    
#> 486: 0.302858    0.974680    3.424487    0.362444    0.120467    0.002839    0.704449    
#> 487: 0.303018    0.974737    3.424505    0.362748    0.120403    0.002837    0.704410    
#> 488: 0.303053    0.974734    3.424529    0.362868    0.120414    0.002836    0.704395    
#> 489: 0.303201    0.974745    3.424538    0.363086    0.120416    0.002838    0.704394    
#> 490: 0.303351    0.974732    3.424556    0.363204    0.120412    0.002838    0.704438    
#> 491: 0.303483    0.974745    3.424585    0.363346    0.120392    0.002839    0.704375    
#> 492: 0.303507    0.974784    3.424586    0.363462    0.120437    0.002839    0.704412    
#> 493: 0.303461    0.974744    3.424600    0.363276    0.120524    0.002841    0.704404    
#> 494: 0.303584    0.974774    3.424598    0.363142    0.120587    0.002840    0.704368    
#> 495: 0.303692    0.974789    3.424620    0.363031    0.120595    0.002842    0.704355    
#> 496: 0.303854    0.974822    3.424633    0.362969    0.120657    0.002842    0.704369    
#> 497: 0.303898    0.974802    3.424647    0.362945    0.120641    0.002841    0.704392    
#> 498: 0.303963    0.974742    3.424660    0.362948    0.120582    0.002840    0.704334    
#> 499: 0.304025    0.974669    3.424652    0.362957    0.120525    0.002839    0.704318    
#> 500: 0.304048    0.974574    3.424659    0.362716    0.120521    0.002837    0.704275    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.293896    0.965977    3.438175    0.392401    0.070359    0.016800    1.704848    
#> 002: 0.166280    0.934117    3.456379    0.372781    0.066841    0.015960    1.160224    
#> 003: 0.207576    0.829577    3.457981    0.354142    0.063499    0.015162    0.910142    
#> 004: 0.156608    0.868808    3.434042    0.336435    0.060324    0.014404    0.784342    
#> 005: 0.166324    0.869347    3.408560    0.319613    0.057308    0.013684    0.729848    
#> 006: 0.104472    0.887285    3.393649    0.303633    0.054443    0.013000    0.681599    
#> 007: 0.055487    0.916480    3.375085    0.330285    0.066492    0.012727    0.677588    
#> 008: 0.022057    0.929588    3.365587    0.321933    0.063167    0.013351    0.663471    
#> 009: -0.004834   0.926174    3.344418    0.342673    0.060009    0.012683    0.652992    
#> 010: 0.010544    0.921504    3.351760    0.332108    0.057008    0.012049    0.684735    
#> 011: 0.054097    0.938364    3.357923    0.365064    0.064901    0.011657    0.684693    
#> 012: 0.059756    0.950559    3.358984    0.378750    0.061656    0.011376    0.661777    
#> 013: 0.029937    0.947256    3.350364    0.376494    0.060569    0.012361    0.656930    
#> 014: 0.051460    0.921312    3.354535    0.441280    0.057541    0.011743    0.669003    
#> 015: 0.045068    0.927870    3.368705    0.419216    0.062667    0.011156    0.662197    
#> 016: 0.069514    0.931448    3.369612    0.398255    0.060382    0.012968    0.659871    
#> 017: 0.053491    0.936291    3.368108    0.378342    0.059563    0.012417    0.651721    
#> 018: 0.068028    0.940082    3.362446    0.367117    0.056585    0.011796    0.654536    
#> 019: 0.047373    0.939477    3.359924    0.348761    0.060347    0.011206    0.641671    
#> 020: 0.084427    0.944204    3.366793    0.388417    0.057330    0.012217    0.658873    
#> 021: 0.078918    0.923574    3.378900    0.394584    0.054464    0.012146    0.648691    
#> 022: 0.077865    0.922540    3.384650    0.393255    0.051740    0.013736    0.643146    
#> 023: 0.143273    0.912707    3.396430    0.431502    0.049153    0.016844    0.663729    
#> 024: 0.118841    0.937167    3.382323    0.412351    0.055109    0.016002    0.658026    
#> 025: 0.101861    0.921482    3.378581    0.465083    0.054816    0.015202    0.655445    
#> 026: 0.068713    0.949655    3.356781    0.441829    0.053644    0.014442    0.666152    
#> 027: 0.038508    0.963129    3.347736    0.419738    0.054136    0.013720    0.662944    
#> 028: 0.054279    0.952466    3.349374    0.398751    0.057703    0.013034    0.649086    
#> 029: 0.056928    0.944884    3.345223    0.388101    0.054818    0.012382    0.662266    
#> 030: 0.049928    0.946891    3.355373    0.384815    0.053375    0.011763    0.658401    
#> 031: 0.032912    0.937832    3.361610    0.380410    0.056695    0.011175    0.657106    
#> 032: 0.053429    0.927353    3.362097    0.400962    0.053860    0.010616    0.657652    
#> 033: 0.041570    0.939273    3.359185    0.402190    0.051167    0.010085    0.658702    
#> 034: 0.073269    0.938152    3.362226    0.411047    0.048609    0.012218    0.649001    
#> 035: 0.052625    0.941108    3.348487    0.417317    0.056893    0.011607    0.642085    
#> 036: 0.040506    0.954246    3.339559    0.448138    0.054049    0.012320    0.648839    
#> 037: 0.032467    0.952950    3.343608    0.425731    0.051346    0.011704    0.671571    
#> 038: 0.025971    0.941860    3.340286    0.404444    0.049251    0.011119    0.675564    
#> 039: 0.043556    0.946208    3.347816    0.430756    0.046788    0.013857    0.664799    
#> 040: 0.055446    0.949708    3.354924    0.437140    0.044449    0.013505    0.670683    
#> 041: 0.001843    0.936625    3.354404    0.415283    0.051032    0.012830    0.647186    
#> 042: 0.047196    0.943824    3.350579    0.394519    0.049563    0.012189    0.642087    
#> 043: 0.028050    0.964710    3.333470    0.405633    0.051217    0.011579    0.667060    
#> 044: 0.004836    0.969710    3.326239    0.406190    0.051260    0.011000    0.663314    
#> 045: -0.015634   0.973011    3.320423    0.391374    0.054830    0.010450    0.652996    
#> 046: 0.019145    0.955755    3.336686    0.371805    0.052089    0.009928    0.657838    
#> 047: 0.012096    0.957761    3.333666    0.398224    0.049484    0.009800    0.647957    
#> 048: 0.015498    0.962459    3.334945    0.378313    0.047158    0.010792    0.660978    
#> 049: 0.024793    0.963368    3.332072    0.441850    0.052818    0.011364    0.662912    
#> 050: 0.042444    0.933897    3.347593    0.426491    0.055960    0.013079    0.674088    
#> 051: 0.019463    0.951143    3.340479    0.405166    0.053162    0.014739    0.672876    
#> 052: 0.051555    0.961737    3.349212    0.404372    0.050504    0.014002    0.667660    
#> 053: 0.038152    0.961172    3.349086    0.411006    0.048174    0.013478    0.663380    
#> 054: 0.021059    0.949228    3.354144    0.406733    0.056174    0.012804    0.671371    
#> 055: 0.044028    0.953055    3.352105    0.462176    0.061535    0.013250    0.653234    
#> 056: 0.077741    0.927475    3.352968    0.533163    0.058458    0.012815    0.667457    
#> 057: 0.069177    0.928537    3.352127    0.506504    0.064344    0.013195    0.662671    
#> 058: 0.098850    0.933747    3.354150    0.481179    0.061126    0.012535    0.668053    
#> 059: 0.098210    0.897867    3.362910    0.497825    0.058070    0.015459    0.686949    
#> 060: 0.136380    0.897598    3.384477    0.508169    0.055167    0.016525    0.693398    
#> 061: 0.138941    0.896915    3.396689    0.482760    0.052408    0.020364    0.690962    
#> 062: 0.123545    0.923687    3.384542    0.548666    0.053522    0.019346    0.696381    
#> 063: 0.141550    0.911531    3.378769    0.640486    0.050846    0.018379    0.694727    
#> 064: 0.088249    0.915320    3.383388    0.608462    0.048303    0.017460    0.692094    
#> 065: 0.066489    0.914257    3.355796    0.578039    0.054584    0.016587    0.683288    
#> 066: 0.083114    0.937808    3.361907    0.553199    0.051855    0.017044    0.658297    
#> 067: 0.054865    0.934732    3.354382    0.546410    0.049262    0.020014    0.650080    
#> 068: 0.010473    0.961734    3.346416    0.519090    0.047455    0.019013    0.656124    
#> 069: 0.029509    0.955600    3.328629    0.545155    0.045082    0.018062    0.663761    
#> 070: 0.007505    0.951248    3.336029    0.533076    0.046430    0.017159    0.653465    
#> 071: -0.002474   0.976550    3.312732    0.506423    0.046906    0.016301    0.671646    
#> 072: -0.032322   0.948411    3.320381    0.481101    0.044561    0.016732    0.656944    
#> 073: 0.022538    0.959074    3.350368    0.457046    0.042333    0.018140    0.666873    
#> 074: 0.014342    0.933305    3.341472    0.434194    0.041266    0.017233    0.662353    
#> 075: 0.033856    0.931738    3.358060    0.481055    0.041867    0.016372    0.665899    
#> 076: 0.076054    0.932399    3.365991    0.507091    0.039773    0.015627    0.676031    
#> 077: 0.107653    0.922770    3.362149    0.503427    0.040136    0.018580    0.672903    
#> 078: 0.087279    0.924478    3.377476    0.569137    0.040581    0.017851    0.649236    
#> 079: 0.095196    0.943748    3.370236    0.540680    0.038552    0.019186    0.667459    
#> 080: 0.098688    0.930296    3.361378    0.513646    0.036713    0.018227    0.670665    
#> 081: 0.068538    0.939439    3.359656    0.487964    0.038475    0.017316    0.671113    
#> 082: 0.051324    0.937024    3.360629    0.463565    0.044436    0.016450    0.689928    
#> 083: 0.062106    0.957818    3.360182    0.440387    0.044042    0.015627    0.671551    
#> 084: 0.081147    0.951982    3.350319    0.435306    0.049624    0.014846    0.656162    
#> 085: 0.068843    0.952068    3.368442    0.473737    0.053309    0.015631    0.656987    
#> 086: 0.065101    0.948265    3.356947    0.450050    0.050644    0.014849    0.645288    
#> 087: 0.040862    0.937027    3.352545    0.427548    0.048112    0.016620    0.642263    
#> 088: 0.009178    0.938271    3.354816    0.406170    0.046754    0.015789    0.653230    
#> 089: 0.021606    0.956300    3.341866    0.446004    0.044416    0.016864    0.649841    
#> 090: 0.001358    0.954695    3.330913    0.441049    0.044859    0.018262    0.668353    
#> 091: -0.020974   0.950857    3.324053    0.418996    0.042616    0.017440    0.684600    
#> 092: 0.008273    0.970757    3.326124    0.478987    0.040485    0.018947    0.662052    
#> 093: -0.020175   0.969650    3.320530    0.455037    0.040203    0.018000    0.663407    
#> 094: -0.004218   0.985053    3.319320    0.445519    0.044254    0.018290    0.672652    
#> 095: -0.010739   0.984806    3.326676    0.434611    0.043439    0.017376    0.665730    
#> 096: -0.032342   0.968517    3.318669    0.412880    0.041267    0.016507    0.667888    
#> 097: -0.013990   0.984338    3.323365    0.410046    0.039203    0.015682    0.645907    
#> 098: 0.012360    0.978068    3.339850    0.389544    0.040987    0.014898    0.662869    
#> 099: -0.014272   0.952314    3.327259    0.449709    0.044163    0.014153    0.659922    
#> 100: 0.012741    0.959492    3.329969    0.431402    0.055216    0.013445    0.650283    
#> 101: -0.012171   0.962715    3.315945    0.409832    0.052455    0.012773    0.650062    
#> 102: -0.013970   0.967072    3.314135    0.389341    0.049832    0.012134    0.656533    
#> 103: 0.003026    0.974164    3.324770    0.438044    0.053284    0.011527    0.645008    
#> 104: -0.018897   0.962986    3.342952    0.416142    0.050620    0.010951    0.677974    
#> 105: 0.001335    0.960044    3.336266    0.414837    0.059305    0.010403    0.680381    
#> 106: 0.048754    0.963187    3.338483    0.472777    0.056340    0.010747    0.671805    
#> 107: 0.020765    0.976058    3.337065    0.474982    0.058848    0.012104    0.663482    
#> 108: 0.014119    0.956090    3.333887    0.492830    0.058667    0.011499    0.657112    
#> 109: 0.008187    0.958273    3.345482    0.468188    0.055733    0.012588    0.650980    
#> 110: 0.061229    0.937064    3.333921    0.563674    0.054703    0.011959    0.642855    
#> 111: 0.047137    0.953792    3.336750    0.535491    0.054868    0.011361    0.636766    
#> 112: 0.033696    0.936179    3.336593    0.508716    0.058724    0.010793    0.653609    
#> 113: 0.010357    0.966733    3.338882    0.485886    0.055788    0.010253    0.654380    
#> 114: 0.017911    0.979598    3.335621    0.480841    0.061956    0.009740    0.655495    
#> 115: 0.005544    0.954584    3.321954    0.489447    0.067937    0.009253    0.664273    
#> 116: 0.023867    0.962687    3.333787    0.464975    0.064541    0.008791    0.666376    
#> 117: 0.032410    0.969196    3.342321    0.441726    0.061314    0.008661    0.672323    
#> 118: 0.041861    0.949451    3.345301    0.419640    0.058739    0.008580    0.662856    
#> 119: 0.044567    0.967091    3.347722    0.421842    0.055802    0.009688    0.679689    
#> 120: -0.025193   0.954203    3.333439    0.400750    0.053012    0.010541    0.669557    
#> 121: 0.022730    0.983717    3.337016    0.382763    0.052220    0.011377    0.668699    
#> 122: 0.029352    0.943741    3.348322    0.363624    0.049609    0.012692    0.664460    
#> 123: 0.064918    0.974938    3.346777    0.357984    0.053780    0.013109    0.647319    
#> 124: 0.061440    0.984242    3.339201    0.360828    0.055061    0.013978    0.668295    
#> 125: 0.054115    0.962171    3.338561    0.419977    0.052308    0.014491    0.661402    
#> 126: 0.017809    0.967684    3.330849    0.398978    0.049692    0.014157    0.674914    
#> 127: 0.034836    0.965708    3.330093    0.429339    0.051682    0.016610    0.669952    
#> 128: 0.041326    0.961419    3.349245    0.448575    0.049097    0.017906    0.673238    
#> 129: 0.052854    0.958336    3.353530    0.487178    0.046643    0.018584    0.675170    
#> 130: 0.078154    0.956325    3.355448    0.462819    0.044310    0.023310    0.669471    
#> 131: 0.078626    0.927176    3.353226    0.456567    0.042095    0.023847    0.656890    
#> 132: 0.009537    0.950660    3.333669    0.433739    0.046596    0.022655    0.644059    
#> 133: 0.054222    0.942333    3.336770    0.605534    0.044266    0.021522    0.651095    
#> 134: 0.043488    0.932943    3.347155    0.579550    0.042053    0.021671    0.657010    
#> 135: 0.056223    0.937628    3.346441    0.550572    0.039950    0.020587    0.653745    
#> 136: 0.063739    0.925281    3.351693    0.536521    0.037953    0.019558    0.648118    
#> 137: 0.091305    0.911561    3.365934    0.509695    0.036055    0.022419    0.670214    
#> 138: 0.072158    0.927832    3.364752    0.484210    0.037300    0.021298    0.655435    
#> 139: 0.039128    0.938944    3.369077    0.460000    0.036974    0.020233    0.671700    
#> 140: 0.096798    0.949335    3.375114    0.463180    0.035125    0.019221    0.679624    
#> 141: 0.059778    0.916588    3.373067    0.456795    0.033618    0.018260    0.686632    
#> 142: 0.107845    0.903443    3.382150    0.524744    0.033413    0.017347    0.677171    
#> 143: 0.090615    0.910887    3.376005    0.516544    0.037549    0.018708    0.673542    
#> 144: 0.123760    0.915874    3.390308    0.490717    0.036856    0.017772    0.654328    
#> 145: 0.087414    0.937071    3.362383    0.466181    0.039908    0.016890    0.664235    
#> 146: 0.051371    0.943072    3.373081    0.442872    0.039103    0.018134    0.660062    
#> 147: 0.028336    0.926059    3.351986    0.420728    0.039009    0.017227    0.650270    
#> 148: 0.015086    0.941976    3.352356    0.468915    0.048389    0.016366    0.664481    
#> 149: 0.031870    0.929478    3.358965    0.445469    0.045970    0.015679    0.659679    
#> 150: 0.046284    0.945958    3.346410    0.423196    0.052439    0.014895    0.674357    
#> 151: -0.002267   0.967496    3.336881    0.402036    0.049817    0.014150    0.666263    
#> 152: 0.005107    0.964023    3.344443    0.454180    0.042943    0.015953    0.655247    
#> 153: 0.008439    0.961349    3.349995    0.422041    0.060372    0.014285    0.654968    
#> 154: 0.045290    0.958932    3.351319    0.379749    0.050845    0.014058    0.662633    
#> 155: 0.017159    0.953991    3.346990    0.330043    0.051024    0.012161    0.661475    
#> 156: 0.034753    0.942590    3.355808    0.322652    0.045342    0.013194    0.676997    
#> 157: 0.017948    0.943452    3.350604    0.423552    0.061894    0.009634    0.675112    
#> 158: 0.062081    0.948400    3.351694    0.437951    0.061995    0.010151    0.654325    
#> 159: 0.009924    0.938670    3.349606    0.439307    0.050699    0.012417    0.661117    
#> 160: 0.049874    0.929128    3.358436    0.458539    0.055572    0.012169    0.665606    
#> 161: 0.051073    0.941074    3.355451    0.396739    0.049137    0.012609    0.658143    
#> 162: 0.045759    0.947344    3.347513    0.399747    0.049656    0.013895    0.674288    
#> 163: 0.046191    0.952473    3.341230    0.441912    0.042032    0.010459    0.668139    
#> 164: 0.055494    0.960071    3.342262    0.516660    0.048763    0.009106    0.653664    
#> 165: 0.038341    0.952519    3.351579    0.423604    0.056805    0.010322    0.648759    
#> 166: 0.058478    0.963536    3.345754    0.389262    0.063495    0.009555    0.668638    
#> 167: 0.039390    0.990075    3.340433    0.477216    0.053540    0.008740    0.668630    
#> 168: 0.017365    0.988272    3.339759    0.432669    0.055511    0.009098    0.658822    
#> 169: 0.034452    0.990994    3.326991    0.405477    0.059641    0.011237    0.664447    
#> 170: 0.039751    0.967968    3.336015    0.456628    0.054041    0.010782    0.663543    
#> 171: 0.040284    0.965489    3.340305    0.418183    0.058842    0.009691    0.653758    
#> 172: 0.018233    0.977310    3.339522    0.403721    0.051247    0.009754    0.652806    
#> 173: 0.014179    0.972080    3.328190    0.369374    0.056417    0.010047    0.661128    
#> 174: 0.032968    0.953085    3.344785    0.376482    0.060295    0.010325    0.648920    
#> 175: 0.018584    0.954405    3.335194    0.383720    0.066325    0.009749    0.661969    
#> 176: 0.007392    0.956336    3.349265    0.273585    0.059322    0.008296    0.666973    
#> 177: 0.015122    0.961202    3.351518    0.325155    0.058242    0.007344    0.667063    
#> 178: 0.052317    0.949997    3.353211    0.358628    0.055053    0.009175    0.650231    
#> 179: 0.058283    0.975053    3.348830    0.312085    0.055667    0.008546    0.672759    
#> 180: 0.036114    0.960961    3.351455    0.350091    0.055346    0.008388    0.658215    
#> 181: 0.040715    0.946979    3.342043    0.350956    0.055580    0.009561    0.644970    
#> 182: 0.031226    0.946976    3.331679    0.388581    0.058465    0.008841    0.672605    
#> 183: 0.043378    0.963838    3.339679    0.371008    0.065392    0.009499    0.672881    
#> 184: 0.034110    0.941591    3.337244    0.420007    0.054627    0.009296    0.678385    
#> 185: 0.037500    0.957420    3.341155    0.424793    0.048823    0.009376    0.670525    
#> 186: 0.053453    0.975835    3.342514    0.432166    0.061423    0.010235    0.670461    
#> 187: 0.033336    0.948879    3.348969    0.446598    0.064178    0.008628    0.647032    
#> 188: 0.013365    0.960299    3.341521    0.400510    0.062137    0.009603    0.645291    
#> 189: -0.001409   0.968770    3.346204    0.377514    0.063784    0.007576    0.660353    
#> 190: 0.024357    0.967291    3.350200    0.394183    0.052859    0.006964    0.656409    
#> 191: 0.008149    0.968834    3.342688    0.353068    0.054499    0.007441    0.644862    
#> 192: 0.010683    0.969214    3.342915    0.409485    0.054046    0.008997    0.643075    
#> 193: 0.038386    0.974245    3.347799    0.401887    0.036025    0.009454    0.666180    
#> 194: 0.021945    0.952222    3.341052    0.401090    0.058662    0.009407    0.669733    
#> 195: 0.002344    0.943149    3.331229    0.429197    0.054748    0.007155    0.680407    
#> 196: 0.031379    0.948146    3.347481    0.416314    0.065102    0.007095    0.682319    
#> 197: 0.022631    0.943233    3.359694    0.346715    0.053378    0.009209    0.698988    
#> 198: 0.053907    0.945633    3.355945    0.357790    0.051362    0.008343    0.680318    
#> 199: 0.052011    0.936408    3.362412    0.344750    0.054525    0.007356    0.671553    
#> 200: 0.061235    0.935106    3.360288    0.436458    0.073095    0.007355    0.688976    
#> 201: 0.058221    0.921576    3.363150    0.418329    0.064022    0.008447    0.690039    
#> 202: 0.050254    0.924938    3.358219    0.399096    0.064154    0.008696    0.692500    
#> 203: 0.051603    0.924262    3.355675    0.399625    0.062492    0.008564    0.692835    
#> 204: 0.048381    0.923231    3.354528    0.406020    0.062301    0.008673    0.694832    
#> 205: 0.045674    0.932217    3.354495    0.405273    0.061562    0.009057    0.695081    
#> 206: 0.041887    0.936214    3.354366    0.396973    0.061322    0.009176    0.694510    
#> 207: 0.038487    0.937028    3.352984    0.405819    0.060907    0.009297    0.692223    
#> 208: 0.035518    0.938095    3.351934    0.399268    0.058963    0.009294    0.689962    
#> 209: 0.034125    0.937551    3.351302    0.395731    0.058241    0.009279    0.688865    
#> 210: 0.033721    0.936843    3.351287    0.393527    0.057131    0.009144    0.687489    
#> 211: 0.034241    0.938007    3.351871    0.389570    0.056574    0.009090    0.685811    
#> 212: 0.036863    0.938955    3.352438    0.390002    0.056310    0.009219    0.683034    
#> 213: 0.038681    0.939303    3.352460    0.389911    0.055681    0.009563    0.684482    
#> 214: 0.040308    0.939451    3.352678    0.387992    0.054734    0.009775    0.683218    
#> 215: 0.040681    0.940256    3.353031    0.387174    0.054021    0.009848    0.682533    
#> 216: 0.044115    0.939296    3.353499    0.385337    0.054369    0.009837    0.682013    
#> 217: 0.044080    0.940084    3.353805    0.382482    0.054278    0.009841    0.681149    
#> 218: 0.045830    0.940602    3.353886    0.385881    0.054202    0.009937    0.680708    
#> 219: 0.045072    0.940090    3.353295    0.387367    0.053951    0.009994    0.680866    
#> 220: 0.042706    0.940482    3.353002    0.389106    0.053679    0.010016    0.680501    
#> 221: 0.042251    0.941529    3.352689    0.389833    0.053226    0.009934    0.679560    
#> 222: 0.042122    0.941531    3.352565    0.389749    0.053090    0.009876    0.678741    
#> 223: 0.043084    0.941504    3.352721    0.387999    0.052883    0.009915    0.677877    
#> 224: 0.043762    0.942650    3.353098    0.386755    0.053333    0.009903    0.677122    
#> 225: 0.043793    0.941558    3.353669    0.386921    0.053090    0.009881    0.676717    
#> 226: 0.043866    0.940155    3.353949    0.387013    0.053106    0.009835    0.676536    
#> 227: 0.044408    0.939748    3.354356    0.388570    0.053577    0.009774    0.676871    
#> 228: 0.044455    0.940040    3.354221    0.387893    0.054216    0.009775    0.676704    
#> 229: 0.042942    0.939959    3.353632    0.387470    0.054698    0.009673    0.676446    
#> 230: 0.042809    0.939783    3.353256    0.386648    0.054819    0.009549    0.676497    
#> 231: 0.042528    0.940766    3.352975    0.388254    0.055118    0.009450    0.676710    
#> 232: 0.040798    0.940803    3.352884    0.387837    0.055128    0.009428    0.676880    
#> 233: 0.040040    0.940104    3.352935    0.387345    0.055266    0.009435    0.677071    
#> 234: 0.039937    0.939863    3.353101    0.387726    0.055360    0.009404    0.676748    
#> 235: 0.039954    0.939495    3.353098    0.387411    0.055476    0.009321    0.676718    
#> 236: 0.040060    0.939781    3.352990    0.388099    0.055581    0.009282    0.676227    
#> 237: 0.040627    0.939829    3.352975    0.387288    0.055989    0.009238    0.676037    
#> 238: 0.041098    0.939610    3.353153    0.384946    0.056362    0.009221    0.676226    
#> 239: 0.041359    0.939862    3.353355    0.383843    0.056715    0.009256    0.675883    
#> 240: 0.041849    0.939814    3.353543    0.384627    0.056897    0.009286    0.675482    
#> 241: 0.041985    0.939449    3.353791    0.384130    0.056756    0.009287    0.675381    
#> 242: 0.041854    0.939231    3.353846    0.383386    0.056997    0.009335    0.675601    
#> 243: 0.042008    0.939820    3.353903    0.383192    0.057251    0.009376    0.675446    
#> 244: 0.041746    0.940461    3.353891    0.383508    0.057325    0.009416    0.675032    
#> 245: 0.041872    0.940412    3.353858    0.384117    0.057451    0.009391    0.675172    
#> 246: 0.042588    0.940388    3.354074    0.384603    0.057395    0.009409    0.675238    
#> 247: 0.043334    0.939848    3.354406    0.384996    0.057510    0.009441    0.674918    
#> 248: 0.043270    0.940077    3.354487    0.384244    0.057349    0.009444    0.674504    
#> 249: 0.043376    0.940430    3.354623    0.385924    0.057402    0.009425    0.674093    
#> 250: 0.043751    0.940490    3.354781    0.385962    0.057536    0.009422    0.673771    
#> 251: 0.044042    0.940888    3.355038    0.386465    0.057681    0.009428    0.673630    
#> 252: 0.043835    0.940872    3.355200    0.386032    0.057868    0.009442    0.673599    
#> 253: 0.044370    0.940691    3.355455    0.386702    0.057922    0.009480    0.673362    
#> 254: 0.044526    0.941139    3.355599    0.386682    0.057983    0.009537    0.673103    
#> 255: 0.044437    0.941612    3.355525    0.387092    0.058040    0.009596    0.672891    
#> 256: 0.044428    0.941724    3.355241    0.388166    0.058175    0.009600    0.672728    
#> 257: 0.044885    0.941674    3.355135    0.390006    0.058222    0.009571    0.672934    
#> 258: 0.044756    0.941494    3.355020    0.389868    0.058281    0.009520    0.673236    
#> 259: 0.045294    0.941494    3.354856    0.391443    0.058326    0.009494    0.673601    
#> 260: 0.045434    0.941806    3.354744    0.391936    0.058323    0.009467    0.673716    
#> 261: 0.044938    0.941788    3.354716    0.390894    0.058675    0.009462    0.674132    
#> 262: 0.044736    0.942050    3.354657    0.389874    0.058887    0.009433    0.674417    
#> 263: 0.044293    0.942373    3.354387    0.390142    0.058907    0.009455    0.674505    
#> 264: 0.043736    0.942391    3.354248    0.391035    0.058923    0.009448    0.674630    
#> 265: 0.043263    0.942585    3.354090    0.390792    0.059095    0.009434    0.674822    
#> 266: 0.042908    0.942916    3.353885    0.390728    0.059160    0.009418    0.674990    
#> 267: 0.041927    0.943193    3.353708    0.390772    0.059148    0.009436    0.675039    
#> 268: 0.041582    0.943023    3.353465    0.391485    0.059144    0.009434    0.674872    
#> 269: 0.041878    0.942805    3.353394    0.392834    0.059059    0.009440    0.674680    
#> 270: 0.042106    0.942909    3.353280    0.393430    0.058946    0.009430    0.674420    
#> 271: 0.041646    0.943193    3.353002    0.394313    0.058855    0.009440    0.674362    
#> 272: 0.041592    0.943116    3.352828    0.394701    0.058717    0.009419    0.674458    
#> 273: 0.040961    0.943469    3.352676    0.394213    0.058736    0.009402    0.674552    
#> 274: 0.040708    0.944004    3.352657    0.393616    0.058574    0.009383    0.674555    
#> 275: 0.040419    0.944464    3.352447    0.393197    0.058529    0.009373    0.674390    
#> 276: 0.040171    0.944847    3.352436    0.393244    0.058429    0.009385    0.674315    
#> 277: 0.040026    0.944996    3.352559    0.394000    0.058375    0.009401    0.674164    
#> 278: 0.039823    0.944870    3.352601    0.394148    0.058365    0.009395    0.674039    
#> 279: 0.039634    0.944642    3.352565    0.393720    0.058444    0.009396    0.673951    
#> 280: 0.039385    0.944698    3.352576    0.392914    0.058371    0.009401    0.674006    
#> 281: 0.039147    0.944797    3.352590    0.391962    0.058298    0.009410    0.674079    
#> 282: 0.038788    0.944945    3.352550    0.391887    0.058284    0.009404    0.674024    
#> 283: 0.038621    0.945147    3.352484    0.392175    0.058194    0.009410    0.674022    
#> 284: 0.038534    0.945119    3.352404    0.392958    0.058183    0.009417    0.673917    
#> 285: 0.038227    0.945280    3.352222    0.393575    0.058172    0.009391    0.673767    
#> 286: 0.037943    0.945591    3.352034    0.393919    0.058170    0.009359    0.673730    
#> 287: 0.037483    0.945889    3.351760    0.395202    0.058165    0.009346    0.673531    
#> 288: 0.037464    0.946045    3.351542    0.395198    0.058277    0.009324    0.673701    
#> 289: 0.037548    0.946093    3.351409    0.395434    0.058259    0.009314    0.673799    
#> 290: 0.037551    0.945979    3.351317    0.394867    0.058220    0.009311    0.674094    
#> 291: 0.037587    0.946079    3.351312    0.394320    0.058275    0.009290    0.674022    
#> 292: 0.037449    0.946230    3.351177    0.394808    0.058262    0.009285    0.673924    
#> 293: 0.037400    0.946432    3.350997    0.395548    0.058296    0.009292    0.673891    
#> 294: 0.037148    0.946616    3.350824    0.395891    0.058204    0.009294    0.673949    
#> 295: 0.037103    0.946407    3.350673    0.396616    0.058192    0.009292    0.673790    
#> 296: 0.037198    0.946243    3.350635    0.396875    0.058123    0.009324    0.673801    
#> 297: 0.037110    0.946309    3.350551    0.397281    0.057974    0.009364    0.673840    
#> 298: 0.037174    0.946275    3.350442    0.398517    0.057897    0.009387    0.673787    
#> 299: 0.036884    0.946296    3.350332    0.398992    0.057822    0.009394    0.673673    
#> 300: 0.037026    0.946141    3.350368    0.399249    0.057911    0.009371    0.673636    
#> 301: 0.037018    0.945958    3.350331    0.398752    0.057904    0.009365    0.673663    
#> 302: 0.037081    0.946108    3.350263    0.398902    0.057958    0.009367    0.673407    
#> 303: 0.036759    0.946507    3.350083    0.398651    0.057972    0.009392    0.673173    
#> 304: 0.036675    0.946822    3.349843    0.398832    0.057881    0.009420    0.672897    
#> 305: 0.036445    0.946856    3.349704    0.399594    0.057775    0.009471    0.672624    
#> 306: 0.036215    0.946886    3.349546    0.399768    0.057820    0.009501    0.672602    
#> 307: 0.035989    0.946928    3.349403    0.399839    0.057874    0.009510    0.672634    
#> 308: 0.035756    0.946784    3.349317    0.400121    0.057947    0.009546    0.672692    
#> 309: 0.035598    0.946647    3.349260    0.400166    0.058047    0.009568    0.672989    
#> 310: 0.035603    0.946723    3.349139    0.400370    0.058095    0.009559    0.673008    
#> 311: 0.035498    0.946770    3.349099    0.400894    0.058174    0.009554    0.672938    
#> 312: 0.035108    0.946693    3.348965    0.400586    0.058194    0.009545    0.673184    
#> 313: 0.034702    0.946588    3.348858    0.399939    0.058200    0.009537    0.673445    
#> 314: 0.034394    0.946860    3.348643    0.399806    0.058247    0.009529    0.673413    
#> 315: 0.034103    0.947070    3.348515    0.399799    0.058256    0.009525    0.673400    
#> 316: 0.034011    0.947214    3.348363    0.400223    0.058281    0.009511    0.673379    
#> 317: 0.034102    0.947179    3.348352    0.400368    0.058279    0.009500    0.673420    
#> 318: 0.034366    0.947144    3.348357    0.400205    0.058319    0.009491    0.673365    
#> 319: 0.034353    0.947050    3.348356    0.400419    0.058365    0.009467    0.673476    
#> 320: 0.034095    0.947097    3.348264    0.400425    0.058391    0.009465    0.673478    
#> 321: 0.033633    0.947271    3.348035    0.399972    0.058375    0.009442    0.673653    
#> 322: 0.033503    0.947356    3.347904    0.399472    0.058415    0.009440    0.673793    
#> 323: 0.033320    0.947411    3.347825    0.399142    0.058487    0.009428    0.673815    
#> 324: 0.033066    0.947533    3.347825    0.398504    0.058554    0.009405    0.673765    
#> 325: 0.032998    0.947710    3.347774    0.398268    0.058520    0.009400    0.673724    
#> 326: 0.032891    0.947551    3.347684    0.398489    0.058517    0.009388    0.673679    
#> 327: 0.032915    0.947603    3.347696    0.398630    0.058580    0.009381    0.673642    
#> 328: 0.032980    0.947612    3.347677    0.398955    0.058557    0.009381    0.673551    
#> 329: 0.033091    0.947644    3.347694    0.399419    0.058634    0.009381    0.673481    
#> 330: 0.032802    0.947638    3.347672    0.399098    0.058701    0.009365    0.673439    
#> 331: 0.032683    0.947811    3.347584    0.399148    0.058727    0.009355    0.673395    
#> 332: 0.032636    0.947754    3.347562    0.399319    0.058754    0.009337    0.673476    
#> 333: 0.032534    0.947792    3.347485    0.399446    0.058752    0.009328    0.673407    
#> 334: 0.032324    0.947796    3.347348    0.399181    0.058720    0.009306    0.673299    
#> 335: 0.031907    0.947913    3.347167    0.398774    0.058738    0.009294    0.673280    
#> 336: 0.031383    0.948188    3.346988    0.398312    0.058762    0.009281    0.673301    
#> 337: 0.030930    0.948568    3.346794    0.398698    0.058778    0.009272    0.673315    
#> 338: 0.030669    0.948741    3.346710    0.398596    0.058774    0.009253    0.673426    
#> 339: 0.030446    0.948950    3.346638    0.398425    0.058742    0.009267    0.673363    
#> 340: 0.030511    0.948692    3.346705    0.398336    0.058801    0.009277    0.673318    
#> 341: 0.030780    0.948573    3.346807    0.398561    0.058773    0.009281    0.673228    
#> 342: 0.030754    0.948453    3.346860    0.398386    0.058854    0.009265    0.673158    
#> 343: 0.030696    0.948531    3.346901    0.398544    0.058919    0.009272    0.673070    
#> 344: 0.030838    0.948505    3.346906    0.398719    0.058881    0.009282    0.673141    
#> 345: 0.031039    0.948485    3.346958    0.398697    0.058804    0.009287    0.673138    
#> 346: 0.031176    0.948541    3.346962    0.398668    0.058682    0.009291    0.673076    
#> 347: 0.031311    0.948469    3.346925    0.398192    0.058525    0.009325    0.673118    
#> 348: 0.031344    0.948602    3.346918    0.398356    0.058456    0.009363    0.673074    
#> 349: 0.031331    0.948588    3.346890    0.398244    0.058329    0.009388    0.672920    
#> 350: 0.031083    0.948524    3.346827    0.398108    0.058184    0.009422    0.672964    
#> 351: 0.030887    0.948603    3.346727    0.398111    0.058149    0.009441    0.672925    
#> 352: 0.030692    0.948721    3.346715    0.398231    0.058140    0.009473    0.672823    
#> 353: 0.030655    0.948868    3.346689    0.398182    0.058065    0.009488    0.672769    
#> 354: 0.030639    0.948908    3.346646    0.398058    0.057982    0.009507    0.672609    
#> 355: 0.030967    0.948830    3.346701    0.397991    0.057875    0.009531    0.672561    
#> 356: 0.031078    0.948744    3.346744    0.397856    0.057839    0.009541    0.672572    
#> 357: 0.031461    0.948785    3.346820    0.398545    0.057799    0.009558    0.672447    
#> 358: 0.031450    0.948787    3.346887    0.398348    0.057717    0.009575    0.672279    
#> 359: 0.031473    0.948842    3.346943    0.397851    0.057735    0.009587    0.672173    
#> 360: 0.031494    0.948839    3.346897    0.397461    0.057679    0.009584    0.672108    
#> 361: 0.031448    0.948846    3.346847    0.397569    0.057578    0.009586    0.672012    
#> 362: 0.031475    0.948866    3.346806    0.397672    0.057512    0.009593    0.671798    
#> 363: 0.031459    0.948890    3.346760    0.397448    0.057466    0.009596    0.671631    
#> 364: 0.031399    0.948954    3.346731    0.397009    0.057423    0.009596    0.671606    
#> 365: 0.031319    0.948942    3.346734    0.396569    0.057416    0.009604    0.671615    
#> 366: 0.031255    0.949000    3.346684    0.395975    0.057410    0.009606    0.671704    
#> 367: 0.031197    0.949059    3.346687    0.395615    0.057449    0.009585    0.671687    
#> 368: 0.031364    0.949116    3.346696    0.395426    0.057347    0.009576    0.671737    
#> 369: 0.031278    0.949178    3.346685    0.395159    0.057351    0.009563    0.671897    
#> 370: 0.031190    0.949291    3.346664    0.395051    0.057390    0.009555    0.671855    
#> 371: 0.031058    0.949345    3.346586    0.394891    0.057398    0.009549    0.671818    
#> 372: 0.030827    0.949410    3.346521    0.394536    0.057391    0.009546    0.671833    
#> 373: 0.030546    0.949652    3.346395    0.394677    0.057414    0.009543    0.671835    
#> 374: 0.030344    0.949667    3.346289    0.394685    0.057386    0.009549    0.671711    
#> 375: 0.030097    0.949704    3.346203    0.394978    0.057375    0.009553    0.671615    
#> 376: 0.029958    0.949882    3.346123    0.394959    0.057404    0.009551    0.671607    
#> 377: 0.029962    0.949980    3.346086    0.395355    0.057426    0.009553    0.671478    
#> 378: 0.029876    0.949972    3.346012    0.395853    0.057444    0.009553    0.671428    
#> 379: 0.029817    0.949881    3.345969    0.395982    0.057435    0.009563    0.671298    
#> 380: 0.029617    0.949858    3.345915    0.395775    0.057453    0.009561    0.671301    
#> 381: 0.029375    0.949926    3.345807    0.396010    0.057495    0.009545    0.671290    
#> 382: 0.029176    0.950021    3.345785    0.395764    0.057446    0.009543    0.671303    
#> 383: 0.029278    0.950036    3.345790    0.395701    0.057442    0.009545    0.671268    
#> 384: 0.029279    0.950005    3.345866    0.395365    0.057418    0.009555    0.671224    
#> 385: 0.029399    0.949968    3.345927    0.395399    0.057357    0.009583    0.671126    
#> 386: 0.029551    0.950103    3.345985    0.395443    0.057307    0.009600    0.671165    
#> 387: 0.029693    0.950157    3.346069    0.395714    0.057225    0.009632    0.671141    
#> 388: 0.029777    0.950152    3.346142    0.395541    0.057165    0.009652    0.671073    
#> 389: 0.029815    0.950018    3.346147    0.395231    0.057092    0.009668    0.671143    
#> 390: 0.029780    0.949973    3.346166    0.395213    0.057041    0.009682    0.671081    
#> 391: 0.030083    0.949916    3.346201    0.395244    0.057001    0.009678    0.671042    
#> 392: 0.029918    0.949928    3.346237    0.394850    0.057005    0.009675    0.671112    
#> 393: 0.029882    0.949860    3.346246    0.394687    0.056966    0.009681    0.671088    
#> 394: 0.029868    0.949913    3.346221    0.394881    0.056983    0.009684    0.670979    
#> 395: 0.029945    0.950030    3.346183    0.394933    0.057000    0.009683    0.670991    
#> 396: 0.029854    0.950136    3.346154    0.394813    0.057008    0.009676    0.670968    
#> 397: 0.029770    0.950139    3.346154    0.394883    0.056970    0.009678    0.670967    
#> 398: 0.029932    0.950116    3.346154    0.395099    0.056939    0.009672    0.670990    
#> 399: 0.030013    0.950158    3.346192    0.395402    0.056917    0.009668    0.670972    
#> 400: 0.030202    0.950220    3.346214    0.395658    0.056936    0.009664    0.670944    
#> 401: 0.030347    0.950233    3.346201    0.395912    0.056982    0.009658    0.670991    
#> 402: 0.030270    0.950264    3.346176    0.395746    0.056952    0.009668    0.671008    
#> 403: 0.030359    0.950281    3.346169    0.395998    0.056938    0.009672    0.670912    
#> 404: 0.030342    0.950269    3.346078    0.396430    0.056888    0.009677    0.670886    
#> 405: 0.030152    0.950233    3.346030    0.396761    0.056835    0.009679    0.670886    
#> 406: 0.029960    0.950297    3.345972    0.397145    0.056749    0.009688    0.670826    
#> 407: 0.029973    0.950362    3.345971    0.397297    0.056660    0.009687    0.670797    
#> 408: 0.029988    0.950416    3.345913    0.397274    0.056614    0.009686    0.670802    
#> 409: 0.029979    0.950370    3.345868    0.397439    0.056588    0.009692    0.670706    
#> 410: 0.029844    0.950362    3.345793    0.397590    0.056553    0.009695    0.670708    
#> 411: 0.029725    0.950166    3.345774    0.397364    0.056564    0.009692    0.670728    
#> 412: 0.029805    0.950129    3.345767    0.397427    0.056563    0.009692    0.670675    
#> 413: 0.029741    0.950115    3.345694    0.397350    0.056573    0.009700    0.670626    
#> 414: 0.029670    0.950131    3.345651    0.397507    0.056527    0.009700    0.670580    
#> 415: 0.029705    0.950222    3.345649    0.397422    0.056492    0.009716    0.670481    
#> 416: 0.029699    0.950285    3.345668    0.397514    0.056468    0.009730    0.670415    
#> 417: 0.029781    0.950212    3.345664    0.397142    0.056450    0.009730    0.670417    
#> 418: 0.029738    0.950245    3.345691    0.397170    0.056479    0.009716    0.670394    
#> 419: 0.029721    0.950325    3.345711    0.396860    0.056494    0.009707    0.670352    
#> 420: 0.029717    0.950333    3.345720    0.396654    0.056515    0.009691    0.670288    
#> 421: 0.029688    0.950323    3.345756    0.396309    0.056519    0.009676    0.670234    
#> 422: 0.029760    0.950258    3.345755    0.396186    0.056509    0.009669    0.670213    
#> 423: 0.029823    0.950171    3.345741    0.396054    0.056511    0.009661    0.670261    
#> 424: 0.029747    0.950097    3.345734    0.395903    0.056519    0.009663    0.670237    
#> 425: 0.029707    0.950098    3.345740    0.395781    0.056495    0.009673    0.670263    
#> 426: 0.029832    0.950145    3.345748    0.395813    0.056483    0.009672    0.670226    
#> 427: 0.029880    0.950085    3.345822    0.395656    0.056467    0.009696    0.670168    
#> 428: 0.029911    0.950052    3.345855    0.395674    0.056430    0.009703    0.670074    
#> 429: 0.030048    0.950011    3.345891    0.395520    0.056423    0.009712    0.670049    
#> 430: 0.030163    0.949987    3.345918    0.395552    0.056368    0.009731    0.670064    
#> 431: 0.030242    0.949941    3.345903    0.395541    0.056315    0.009731    0.669979    
#> 432: 0.030174    0.950043    3.345887    0.395541    0.056297    0.009744    0.669897    
#> 433: 0.030127    0.950144    3.345890    0.395302    0.056257    0.009751    0.669879    
#> 434: 0.030030    0.950097    3.345862    0.395385    0.056202    0.009754    0.669786    
#> 435: 0.030023    0.950127    3.345814    0.395158    0.056218    0.009752    0.669708    
#> 436: 0.030055    0.950066    3.345827    0.394848    0.056213    0.009743    0.669690    
#> 437: 0.030239    0.950004    3.345843    0.395011    0.056174    0.009741    0.669699    
#> 438: 0.030283    0.950125    3.345832    0.395359    0.056205    0.009728    0.669594    
#> 439: 0.030308    0.950224    3.345833    0.395300    0.056205    0.009721    0.669507    
#> 440: 0.030229    0.950311    3.345842    0.395199    0.056204    0.009708    0.669444    
#> 441: 0.030269    0.950265    3.345899    0.395160    0.056210    0.009711    0.669394    
#> 442: 0.030246    0.950274    3.345932    0.395205    0.056210    0.009708    0.669380    
#> 443: 0.030271    0.950318    3.345898    0.395182    0.056236    0.009703    0.669380    
#> 444: 0.030148    0.950377    3.345841    0.395049    0.056287    0.009702    0.669361    
#> 445: 0.029902    0.950494    3.345746    0.395103    0.056333    0.009702    0.669387    
#> 446: 0.029663    0.950569    3.345679    0.395149    0.056339    0.009691    0.669453    
#> 447: 0.029639    0.950624    3.345648    0.395312    0.056341    0.009691    0.669442    
#> 448: 0.029542    0.950628    3.345620    0.395448    0.056338    0.009696    0.669353    
#> 449: 0.029561    0.950692    3.345646    0.395492    0.056378    0.009695    0.669343    
#> 450: 0.029532    0.950712    3.345639    0.395611    0.056395    0.009701    0.669324    
#> 451: 0.029510    0.950815    3.345574    0.395903    0.056449    0.009703    0.669279    
#> 452: 0.029448    0.950884    3.345524    0.396209    0.056467    0.009702    0.669274    
#> 453: 0.029315    0.950935    3.345451    0.395950    0.056489    0.009699    0.669233    
#> 454: 0.029276    0.951055    3.345406    0.396022    0.056499    0.009698    0.669144    
#> 455: 0.029247    0.951107    3.345381    0.395934    0.056467    0.009702    0.669117    
#> 456: 0.029254    0.951136    3.345359    0.396040    0.056432    0.009710    0.669118    
#> 457: 0.029201    0.951158    3.345339    0.396266    0.056436    0.009715    0.669038    
#> 458: 0.029275    0.951255    3.345405    0.396356    0.056468    0.009717    0.669020    
#> 459: 0.029161    0.951337    3.345410    0.396211    0.056479    0.009717    0.669083    
#> 460: 0.029085    0.951367    3.345398    0.396051    0.056471    0.009728    0.669049    
#> 461: 0.029007    0.951388    3.345408    0.395818    0.056494    0.009741    0.669078    
#> 462: 0.028967    0.951409    3.345422    0.395756    0.056469    0.009753    0.669047    
#> 463: 0.029029    0.951464    3.345441    0.395872    0.056455    0.009754    0.669022    
#> 464: 0.029130    0.951473    3.345424    0.396033    0.056439    0.009752    0.668962    
#> 465: 0.029212    0.951347    3.345434    0.396295    0.056429    0.009746    0.668980    
#> 466: 0.029335    0.951366    3.345433    0.396626    0.056398    0.009738    0.668990    
#> 467: 0.029358    0.951271    3.345479    0.396997    0.056402    0.009733    0.668917    
#> 468: 0.029538    0.951255    3.345537    0.397393    0.056371    0.009735    0.668902    
#> 469: 0.029672    0.951351    3.345598    0.397552    0.056334    0.009743    0.668986    
#> 470: 0.029503    0.951385    3.345586    0.397444    0.056334    0.009757    0.669028    
#> 471: 0.029400    0.951411    3.345558    0.397408    0.056281    0.009758    0.669039    
#> 472: 0.029309    0.951450    3.345565    0.397469    0.056268    0.009757    0.669025    
#> 473: 0.029287    0.951461    3.345561    0.397313    0.056220    0.009759    0.669031    
#> 474: 0.029345    0.951472    3.345553    0.397238    0.056208    0.009760    0.669069    
#> 475: 0.029357    0.951570    3.345538    0.397147    0.056220    0.009760    0.669037    
#> 476: 0.029221    0.951624    3.345505    0.397107    0.056251    0.009754    0.669051    
#> 477: 0.029116    0.951651    3.345487    0.397319    0.056257    0.009748    0.668969    
#> 478: 0.029114    0.951694    3.345489    0.397290    0.056236    0.009746    0.668976    
#> 479: 0.029076    0.951785    3.345489    0.397213    0.056242    0.009741    0.668958    
#> 480: 0.029038    0.951811    3.345468    0.397054    0.056257    0.009744    0.668941    
#> 481: 0.028924    0.951834    3.345419    0.396887    0.056255    0.009751    0.668930    
#> 482: 0.029021    0.951850    3.345385    0.397011    0.056228    0.009758    0.669024    
#> 483: 0.028951    0.951807    3.345364    0.396831    0.056241    0.009757    0.669078    
#> 484: 0.028899    0.951688    3.345369    0.396606    0.056208    0.009754    0.669148    
#> 485: 0.028852    0.951648    3.345377    0.396543    0.056171    0.009763    0.669214    
#> 486: 0.028932    0.951614    3.345429    0.396444    0.056181    0.009760    0.669222    
#> 487: 0.029039    0.951606    3.345507    0.396228    0.056220    0.009756    0.669208    
#> 488: 0.029165    0.951590    3.345572    0.396096    0.056225    0.009752    0.669226    
#> 489: 0.029339    0.951506    3.345613    0.395993    0.056258    0.009752    0.669297    
#> 490: 0.029412    0.951493    3.345649    0.395992    0.056310    0.009749    0.669326    
#> 491: 0.029504    0.951547    3.345699    0.396102    0.056362    0.009745    0.669371    
#> 492: 0.029454    0.951555    3.345719    0.396015    0.056384    0.009733    0.669549    
#> 493: 0.029414    0.951516    3.345715    0.395953    0.056445    0.009744    0.669569    
#> 494: 0.029450    0.951563    3.345679    0.395830    0.056493    0.009748    0.669540    
#> 495: 0.029461    0.951611    3.345674    0.395639    0.056517    0.009744    0.669530    
#> 496: 0.029622    0.951646    3.345658    0.395647    0.056528    0.009735    0.669557    
#> 497: 0.029548    0.951620    3.345636    0.395728    0.056545    0.009730    0.669544    
#> 498: 0.029517    0.951632    3.345604    0.395993    0.056548    0.009723    0.669471    
#> 499: 0.029481    0.951713    3.345554    0.396142    0.056568    0.009718    0.669428    
#> 500: 0.029440    0.951659    3.345537    0.396129    0.056565    0.009719    0.669372    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.325347    0.986689    3.439233    0.392401    0.073871    0.016800    1.811729    
#> 002: 0.257754    1.043928    3.466642    0.372781    0.070177    0.015960    1.149826    
#> 003: 0.391262    1.028652    3.466536    0.354142    0.066668    0.015162    0.883152    
#> 004: 0.338914    1.062755    3.473730    0.336435    0.063335    0.014404    0.807295    
#> 005: 0.383072    1.084681    3.452094    0.319613    0.060168    0.013684    0.745935    
#> 006: 0.368807    1.099472    3.449461    0.418967    0.057160    0.013000    0.691863    
#> 007: 0.307700    1.105879    3.443772    0.398019    0.054302    0.013716    0.686892    
#> 008: 0.321449    1.104058    3.444611    0.395141    0.056545    0.013884    0.680521    
#> 009: 0.313693    1.091005    3.445197    0.480469    0.053718    0.019155    0.680037    
#> 010: 0.306636    1.087391    3.448121    0.456446    0.051032    0.019871    0.673072    
#> 011: 0.427350    1.082266    3.464887    0.508151    0.051517    0.020206    0.683172    
#> 012: 0.437214    1.078015    3.475718    0.482744    0.048941    0.019196    0.660338    
#> 013: 0.389903    1.075882    3.468710    0.489445    0.046494    0.022881    0.659077    
#> 014: 0.446684    1.077219    3.482984    0.514021    0.044170    0.025284    0.657801    
#> 015: 0.466802    1.070239    3.495902    0.531160    0.041961    0.024020    0.660695    
#> 016: 0.455814    1.078655    3.488092    0.504602    0.039863    0.022819    0.656100    
#> 017: 0.430271    1.076615    3.484724    0.516652    0.037870    0.023285    0.635273    
#> 018: 0.449473    1.078985    3.481066    0.507197    0.035976    0.022121    0.646438    
#> 019: 0.399194    1.082696    3.477917    0.521189    0.034178    0.022635    0.646429    
#> 020: 0.388407    1.089127    3.477698    0.495130    0.036149    0.021503    0.646807    
#> 021: 0.403269    1.088879    3.481466    0.508934    0.034342    0.020428    0.645554    
#> 022: 0.387374    1.084028    3.489242    0.556219    0.033787    0.019491    0.649375    
#> 023: 0.501391    1.095087    3.503457    0.528408    0.035286    0.018862    0.676128    
#> 024: 0.474431    1.106269    3.496345    0.513078    0.033522    0.021303    0.657492    
#> 025: 0.418539    1.102299    3.479346    0.528064    0.031846    0.023824    0.646593    
#> 026: 0.377925    1.125524    3.454908    0.519052    0.032099    0.022633    0.647095    
#> 027: 0.366950    1.137459    3.445754    0.510262    0.035530    0.021502    0.648906    
#> 028: 0.403601    1.112277    3.454011    0.523579    0.033754    0.020426    0.629321    
#> 029: 0.386192    1.113791    3.447629    0.497400    0.032597    0.025356    0.645391    
#> 030: 0.363366    1.135787    3.443797    0.472530    0.030967    0.026300    0.632335    
#> 031: 0.336208    1.119843    3.453644    0.448903    0.029796    0.024985    0.635263    
#> 032: 0.358318    1.109803    3.464846    0.484197    0.035078    0.024752    0.634931    
#> 033: 0.379136    1.124602    3.449862    0.573035    0.033324    0.023515    0.655112    
#> 034: 0.415719    1.108826    3.453800    0.544383    0.032361    0.022339    0.658833    
#> 035: 0.385242    1.096123    3.455982    0.517164    0.030743    0.021222    0.643830    
#> 036: 0.362393    1.093832    3.448205    0.491306    0.031806    0.020609    0.639743    
#> 037: 0.370690    1.108481    3.461332    0.489392    0.036958    0.025328    0.638720    
#> 038: 0.427219    1.117238    3.455772    0.567717    0.035110    0.024062    0.655680    
#> 039: 0.389599    1.111091    3.470261    0.539331    0.033355    0.026268    0.627593    
#> 040: 0.405065    1.104685    3.480084    0.512364    0.031687    0.024955    0.645342    
#> 041: 0.400542    1.096707    3.469474    0.486746    0.030103    0.023707    0.642736    
#> 042: 0.427352    1.106612    3.464563    0.570063    0.028598    0.026140    0.642602    
#> 043: 0.369179    1.117656    3.454827    0.541560    0.027168    0.026900    0.643376    
#> 044: 0.371052    1.119194    3.460537    0.546420    0.025809    0.029549    0.637432    
#> 045: 0.356248    1.121219    3.453442    0.519099    0.024519    0.031503    0.631305    
#> 046: 0.393333    1.110163    3.457056    0.507698    0.028537    0.029928    0.641111    
#> 047: 0.398874    1.097042    3.473255    0.491143    0.027792    0.028997    0.634597    
#> 048: 0.406055    1.087687    3.467050    0.593454    0.027659    0.031443    0.639096    
#> 049: 0.422483    1.096684    3.467011    0.563782    0.030699    0.029871    0.664428    
#> 050: 0.434478    1.078097    3.481823    0.535593    0.029164    0.029037    0.662857    
#> 051: 0.395914    1.090076    3.469002    0.559719    0.029708    0.027585    0.650523    
#> 052: 0.418191    1.105532    3.479205    0.561591    0.029323    0.027374    0.646126    
#> 053: 0.414090    1.100586    3.470033    0.545093    0.027857    0.031104    0.657526    
#> 054: 0.385579    1.114771    3.463628    0.583637    0.026464    0.031510    0.647360    
#> 055: 0.409014    1.120571    3.468896    0.554455    0.029762    0.029934    0.663450    
#> 056: 0.392127    1.112075    3.466944    0.526732    0.031826    0.028438    0.651160    
#> 057: 0.413125    1.117000    3.465540    0.519909    0.032916    0.027016    0.654666    
#> 058: 0.397751    1.099022    3.465670    0.493914    0.031271    0.025761    0.651036    
#> 059: 0.375298    1.065136    3.468955    0.527519    0.035318    0.024473    0.656787    
#> 060: 0.393506    1.076081    3.471014    0.611045    0.033552    0.032058    0.673593    
#> 061: 0.445185    1.082400    3.472255    0.706407    0.031874    0.031183    0.657622    
#> 062: 0.406724    1.089112    3.476078    0.671087    0.032051    0.033099    0.663199    
#> 063: 0.449083    1.079498    3.474198    0.637533    0.031283    0.031444    0.677995    
#> 064: 0.422681    1.082879    3.475286    0.605656    0.030217    0.030820    0.673352    
#> 065: 0.429338    1.070789    3.468468    0.575373    0.028706    0.031909    0.657415    
#> 066: 0.412870    1.082635    3.475312    0.546605    0.027386    0.030313    0.638212    
#> 067: 0.404161    1.080810    3.481965    0.519274    0.026016    0.028798    0.636934    
#> 068: 0.365809    1.102382    3.468095    0.493311    0.026926    0.027358    0.652658    
#> 069: 0.377161    1.100361    3.473825    0.468645    0.032939    0.025990    0.653915    
#> 070: 0.397393    1.091013    3.478865    0.445213    0.031292    0.024690    0.647470    
#> 071: 0.386591    1.114662    3.455810    0.422952    0.029727    0.024325    0.669568    
#> 072: 0.379325    1.080961    3.471772    0.416735    0.034783    0.030127    0.664020    
#> 073: 0.378016    1.087229    3.488146    0.423099    0.042243    0.028621    0.673861    
#> 074: 0.382952    1.071634    3.479058    0.426527    0.040131    0.027190    0.665749    
#> 075: 0.422272    1.085161    3.504789    0.466402    0.038124    0.026219    0.653162    
#> 076: 0.457121    1.082396    3.512726    0.443082    0.036218    0.024908    0.675451    
#> 077: 0.465224    1.073958    3.495762    0.485147    0.036940    0.023663    0.677086    
#> 078: 0.382939    1.095236    3.482211    0.507198    0.035298    0.022480    0.650623    
#> 079: 0.415913    1.099954    3.474279    0.524407    0.037627    0.021356    0.656243    
#> 080: 0.429784    1.096208    3.472724    0.520322    0.038344    0.020288    0.657363    
#> 081: 0.397655    1.105522    3.469290    0.526742    0.036427    0.022470    0.641252    
#> 082: 0.394806    1.087765    3.476304    0.500405    0.034606    0.024348    0.648701    
#> 083: 0.389416    1.101597    3.474934    0.524498    0.032876    0.025960    0.642240    
#> 084: 0.390362    1.102922    3.470545    0.498273    0.035062    0.025763    0.641843    
#> 085: 0.400232    1.106851    3.483992    0.485646    0.033309    0.024475    0.649141    
#> 086: 0.427505    1.102697    3.479215    0.476884    0.031643    0.027815    0.634232    
#> 087: 0.415202    1.099429    3.471545    0.453040    0.030061    0.026424    0.658367    
#> 088: 0.338767    1.091138    3.470458    0.430388    0.031155    0.025103    0.651035    
#> 089: 0.374412    1.110435    3.465572    0.408869    0.029597    0.025520    0.647558    
#> 090: 0.384057    1.107120    3.466290    0.443532    0.039218    0.024244    0.651067    
#> 091: 0.386281    1.103038    3.458020    0.483923    0.041355    0.023032    0.648945    
#> 092: 0.389715    1.109493    3.455129    0.471542    0.040039    0.021880    0.643511    
#> 093: 0.349501    1.098062    3.449426    0.531164    0.038049    0.022062    0.640550    
#> 094: 0.379119    1.120459    3.453701    0.504606    0.036147    0.020959    0.651354    
#> 095: 0.407404    1.111924    3.471851    0.606355    0.034339    0.020079    0.638701    
#> 096: 0.360332    1.106181    3.458002    0.589755    0.032622    0.022775    0.650663    
#> 097: 0.394578    1.120500    3.461120    0.560267    0.031742    0.024843    0.639686    
#> 098: 0.404852    1.115526    3.463326    0.581611    0.030155    0.023601    0.643764    
#> 099: 0.400811    1.104193    3.453612    0.625695    0.028647    0.025596    0.634704    
#> 100: 0.390741    1.113046    3.449540    0.649184    0.027215    0.024536    0.637362    
#> 101: 0.341883    1.093157    3.428000    0.616725    0.025854    0.023644    0.637357    
#> 102: 0.347916    1.091575    3.441821    0.585889    0.024561    0.026100    0.647355    
#> 103: 0.386899    1.092097    3.456159    0.556595    0.026099    0.025895    0.642594    
#> 104: 0.389800    1.104158    3.473563    0.552261    0.031392    0.024601    0.653591    
#> 105: 0.400979    1.114290    3.463194    0.530208    0.031159    0.023371    0.650200    
#> 106: 0.397880    1.100812    3.458315    0.580370    0.029733    0.026798    0.644928    
#> 107: 0.434574    1.108534    3.471193    0.551351    0.029242    0.025667    0.656251    
#> 108: 0.428922    1.103392    3.470266    0.523784    0.027780    0.028749    0.664857    
#> 109: 0.415034    1.083557    3.488003    0.497595    0.036034    0.030068    0.647265    
#> 110: 0.450197    1.097152    3.473677    0.472715    0.034232    0.029801    0.650643    
#> 111: 0.429497    1.108827    3.477580    0.471014    0.033457    0.028311    0.645983    
#> 112: 0.428735    1.092911    3.474321    0.511363    0.036780    0.026896    0.649893    
#> 113: 0.403173    1.106041    3.469635    0.499158    0.042214    0.025551    0.628307    
#> 114: 0.383197    1.118601    3.460784    0.474200    0.044259    0.024273    0.642762    
#> 115: 0.379093    1.094691    3.450227    0.482303    0.042046    0.027753    0.665743    
#> 116: 0.408698    1.114188    3.452641    0.533252    0.039944    0.028225    0.652601    
#> 117: 0.382421    1.119440    3.462807    0.506589    0.037946    0.026814    0.654897    
#> 118: 0.402560    1.108116    3.470354    0.481260    0.036843    0.025473    0.660696    
#> 119: 0.409874    1.103869    3.468439    0.478649    0.039002    0.027969    0.664685    
#> 120: 0.370962    1.102600    3.463677    0.488828    0.037052    0.027313    0.650838    
#> 121: 0.371479    1.113628    3.465452    0.481425    0.035200    0.025948    0.649194    
#> 122: 0.398546    1.091048    3.464315    0.530489    0.033440    0.024650    0.639072    
#> 123: 0.402440    1.123875    3.460706    0.557161    0.031768    0.024676    0.634940    
#> 124: 0.416563    1.140991    3.456321    0.535313    0.030179    0.025452    0.652603    
#> 125: 0.396981    1.132043    3.453295    0.526951    0.034420    0.024909    0.631595    
#> 126: 0.392223    1.128260    3.453052    0.529710    0.039670    0.026696    0.635126    
#> 127: 0.407669    1.110746    3.459202    0.526186    0.039486    0.026971    0.639881    
#> 128: 0.405327    1.113518    3.464801    0.585090    0.044431    0.028982    0.662848    
#> 129: 0.428073    1.099612    3.479563    0.555835    0.047426    0.027533    0.657494    
#> 130: 0.411849    1.114178    3.472625    0.528044    0.045054    0.026157    0.643966    
#> 131: 0.412168    1.085281    3.460933    0.501641    0.042802    0.024849    0.661672    
#> 132: 0.383028    1.102753    3.446737    0.505117    0.040662    0.023606    0.654814    
#> 133: 0.359181    1.098501    3.452644    0.479862    0.038739    0.022426    0.658976    
#> 134: 0.379627    1.085144    3.479864    0.455869    0.036947    0.022819    0.666093    
#> 135: 0.381920    1.088356    3.475944    0.433075    0.035100    0.021778    0.660485    
#> 136: 0.411803    1.077611    3.478046    0.411421    0.033345    0.023901    0.659193    
#> 137: 0.424298    1.079041    3.488844    0.411590    0.031677    0.023281    0.675804    
#> 138: 0.402750    1.092849    3.475623    0.399769    0.030319    0.022117    0.664561    
#> 139: 0.383372    1.086571    3.486830    0.437051    0.033673    0.022433    0.682620    
#> 140: 0.426921    1.102370    3.483651    0.507013    0.039840    0.021312    0.685682    
#> 141: 0.395960    1.090293    3.479340    0.488166    0.038741    0.021615    0.648743    
#> 142: 0.417333    1.074042    3.483499    0.508339    0.036804    0.023333    0.655831    
#> 143: 0.417393    1.089099    3.487266    0.490683    0.034964    0.024495    0.647198    
#> 144: 0.444079    1.091473    3.483507    0.556815    0.033216    0.023270    0.649714    
#> 145: 0.418585    1.095333    3.473678    0.528975    0.031884    0.025613    0.636919    
#> 146: 0.397777    1.095971    3.480883    0.502526    0.030290    0.024914    0.650088    
#> 147: 0.354029    1.095186    3.462368    0.477400    0.028775    0.023668    0.644699    
#> 148: 0.375104    1.106738    3.473639    0.478404    0.031346    0.022485    0.645441    
#> 149: 0.382343    1.099427    3.459586    0.459294    0.031651    0.024866    0.653327    
#> 150: 0.448722    1.094495    3.457366    0.542249    0.034836    0.024391    0.669780    
#> 151: 0.388579    1.124747    3.458165    0.542637    0.033105    0.024656    0.655182    
#> 152: 0.381941    1.111790    3.466334    0.488822    0.030980    0.026678    0.640220    
#> 153: 0.369530    1.119545    3.474453    0.481612    0.023730    0.032805    0.654474    
#> 154: 0.400692    1.133580    3.469835    0.452115    0.028429    0.031917    0.645871    
#> 155: 0.396768    1.103991    3.471818    0.482934    0.022678    0.036162    0.643054    
#> 156: 0.409805    1.118122    3.465679    0.484598    0.027037    0.042509    0.647134    
#> 157: 0.397953    1.109039    3.469018    0.494655    0.018431    0.039795    0.644802    
#> 158: 0.433511    1.111876    3.474366    0.498262    0.014229    0.032828    0.650594    
#> 159: 0.379754    1.114629    3.478782    0.472832    0.015772    0.035668    0.654386    
#> 160: 0.447552    1.090456    3.488186    0.591101    0.021795    0.033755    0.657367    
#> 161: 0.386185    1.090793    3.482035    0.450727    0.022135    0.036190    0.659636    
#> 162: 0.412907    1.110935    3.471909    0.462887    0.019866    0.039326    0.652270    
#> 163: 0.416997    1.090451    3.469493    0.536128    0.016813    0.035884    0.652832    
#> 164: 0.421053    1.095659    3.469085    0.528996    0.017458    0.036091    0.649478    
#> 165: 0.384332    1.092887    3.468724    0.494053    0.015993    0.031571    0.650484    
#> 166: 0.418336    1.122226    3.471318    0.449736    0.015248    0.032854    0.674056    
#> 167: 0.409756    1.134588    3.480807    0.484064    0.017004    0.033775    0.663876    
#> 168: 0.395421    1.132458    3.473443    0.483333    0.017673    0.032863    0.651209    
#> 169: 0.396355    1.134477    3.468257    0.459730    0.020027    0.029010    0.661106    
#> 170: 0.386751    1.113418    3.469677    0.408869    0.023447    0.030854    0.650584    
#> 171: 0.354617    1.131025    3.449290    0.428970    0.017569    0.030850    0.655119    
#> 172: 0.341697    1.144967    3.448466    0.429257    0.017030    0.032032    0.653460    
#> 173: 0.371195    1.139966    3.450020    0.488898    0.020673    0.032328    0.644083    
#> 174: 0.390295    1.141703    3.462621    0.498472    0.024541    0.034469    0.655618    
#> 175: 0.387649    1.144027    3.450157    0.525229    0.027039    0.036073    0.643723    
#> 176: 0.346983    1.139648    3.455218    0.512565    0.023702    0.031942    0.632855    
#> 177: 0.402611    1.124269    3.461196    0.594600    0.025997    0.037069    0.624990    
#> 178: 0.417336    1.111330    3.478647    0.569687    0.035560    0.032841    0.633342    
#> 179: 0.493005    1.110658    3.477046    0.588662    0.032333    0.025918    0.644518    
#> 180: 0.426966    1.112842    3.474375    0.488436    0.032465    0.023949    0.650570    
#> 181: 0.423980    1.095114    3.460280    0.499709    0.031167    0.026195    0.665258    
#> 182: 0.370665    1.102622    3.450571    0.431425    0.036708    0.021815    0.663407    
#> 183: 0.354015    1.113396    3.452089    0.382149    0.030422    0.021628    0.660176    
#> 184: 0.359109    1.105806    3.452374    0.458620    0.029540    0.021888    0.657246    
#> 185: 0.363357    1.126841    3.455091    0.419192    0.032365    0.024002    0.655868    
#> 186: 0.343176    1.151928    3.451134    0.441092    0.039490    0.030568    0.655717    
#> 187: 0.382704    1.119687    3.457850    0.454081    0.031832    0.029353    0.672626    
#> 188: 0.339349    1.131275    3.452438    0.521255    0.033897    0.024135    0.676843    
#> 189: 0.385390    1.143810    3.464815    0.536668    0.031273    0.024585    0.663629    
#> 190: 0.365244    1.118902    3.458028    0.458910    0.030118    0.026253    0.651427    
#> 191: 0.344599    1.122746    3.453421    0.504046    0.028086    0.027865    0.641918    
#> 192: 0.350769    1.127999    3.439199    0.487486    0.026078    0.027480    0.645698    
#> 193: 0.417032    1.127412    3.467612    0.490876    0.026395    0.029396    0.648938    
#> 194: 0.413911    1.116799    3.462086    0.467565    0.020085    0.023883    0.653683    
#> 195: 0.400099    1.104000    3.467419    0.499364    0.019642    0.026341    0.656573    
#> 196: 0.415031    1.105358    3.472961    0.559408    0.025637    0.033009    0.643746    
#> 197: 0.367502    1.099099    3.482477    0.495335    0.020465    0.035962    0.658452    
#> 198: 0.475882    1.087094    3.482280    0.553802    0.020471    0.031316    0.644457    
#> 199: 0.411676    1.074172    3.472328    0.464882    0.024501    0.029157    0.644646    
#> 200: 0.412362    1.083695    3.486431    0.443715    0.020679    0.030985    0.663613    
#> 201: 0.397111    1.077269    3.490270    0.409776    0.020725    0.031022    0.673386    
#> 202: 0.390567    1.077296    3.488988    0.412907    0.020761    0.031871    0.673644    
#> 203: 0.405450    1.075158    3.485674    0.434450    0.021205    0.033186    0.672232    
#> 204: 0.412096    1.069499    3.487990    0.453036    0.021479    0.032743    0.667187    
#> 205: 0.413746    1.071656    3.487571    0.453842    0.021542    0.033902    0.666893    
#> 206: 0.410669    1.077225    3.484796    0.468217    0.022083    0.033639    0.666024    
#> 207: 0.405857    1.079980    3.480915    0.458794    0.021772    0.033448    0.664460    
#> 208: 0.402307    1.082758    3.479407    0.455456    0.021948    0.033769    0.662844    
#> 209: 0.402689    1.083349    3.478602    0.458865    0.022072    0.033675    0.660063    
#> 210: 0.404994    1.083254    3.479417    0.462555    0.021920    0.033237    0.658461    
#> 211: 0.406521    1.084344    3.479606    0.466008    0.022249    0.032537    0.657188    
#> 212: 0.406947    1.085176    3.479587    0.467113    0.022300    0.032102    0.656067    
#> 213: 0.408652    1.083053    3.479950    0.466858    0.022726    0.031390    0.656182    
#> 214: 0.411696    1.082059    3.480706    0.469432    0.023142    0.031067    0.656659    
#> 215: 0.411909    1.082394    3.480931    0.473044    0.023360    0.031237    0.656144    
#> 216: 0.416621    1.080911    3.481841    0.483955    0.023421    0.031376    0.656972    
#> 217: 0.420017    1.080836    3.482456    0.493115    0.023159    0.031471    0.656317    
#> 218: 0.421566    1.080980    3.482347    0.502243    0.022821    0.031623    0.655742    
#> 219: 0.422619    1.080804    3.481274    0.508202    0.022606    0.031895    0.655261    
#> 220: 0.420506    1.081500    3.480810    0.507231    0.022361    0.032095    0.655244    
#> 221: 0.418369    1.082205    3.480465    0.503959    0.022143    0.032241    0.655257    
#> 222: 0.417215    1.083130    3.479579    0.505820    0.022143    0.032169    0.654904    
#> 223: 0.417733    1.084043    3.479225    0.506996    0.022201    0.032056    0.654539    
#> 224: 0.419440    1.084967    3.479230    0.508959    0.022313    0.032152    0.654084    
#> 225: 0.419879    1.084555    3.479698    0.512833    0.022591    0.032350    0.653987    
#> 226: 0.418622    1.084273    3.479243    0.516283    0.022728    0.032516    0.653471    
#> 227: 0.417281    1.084589    3.478644    0.516605    0.022816    0.032637    0.652942    
#> 228: 0.415545    1.085681    3.477990    0.515367    0.022747    0.032714    0.653141    
#> 229: 0.415429    1.086156    3.477618    0.516302    0.022630    0.032865    0.652628    
#> 230: 0.415178    1.086446    3.477113    0.517001    0.022724    0.032982    0.652489    
#> 231: 0.414098    1.086880    3.477021    0.514614    0.022820    0.033089    0.651857    
#> 232: 0.413883    1.086850    3.477006    0.515208    0.022957    0.033006    0.651101    
#> 233: 0.413273    1.086243    3.477127    0.518328    0.022911    0.032884    0.650959    
#> 234: 0.412622    1.085879    3.477216    0.516637    0.022724    0.032881    0.651576    
#> 235: 0.413582    1.085566    3.477312    0.518216    0.022780    0.032942    0.651138    
#> 236: 0.413194    1.085720    3.477055    0.516748    0.022893    0.032943    0.651093    
#> 237: 0.413627    1.085680    3.476979    0.516954    0.022919    0.033031    0.651133    
#> 238: 0.414108    1.085992    3.477004    0.516916    0.022899    0.032977    0.651497    
#> 239: 0.414395    1.086618    3.476694    0.517191    0.022954    0.032830    0.651623    
#> 240: 0.413975    1.086435    3.476916    0.515327    0.023015    0.032679    0.651653    
#> 241: 0.414808    1.085953    3.476961    0.515858    0.023232    0.032530    0.651798    
#> 242: 0.414650    1.085348    3.477003    0.514503    0.023483    0.032324    0.652172    
#> 243: 0.415018    1.084907    3.477343    0.512726    0.023774    0.032164    0.652453    
#> 244: 0.415383    1.083997    3.477978    0.508989    0.023856    0.032034    0.653011    
#> 245: 0.416197    1.083230    3.478647    0.507244    0.023927    0.031996    0.653657    
#> 246: 0.417315    1.082739    3.479162    0.506134    0.023930    0.032055    0.654185    
#> 247: 0.418083    1.082530    3.479341    0.506534    0.024006    0.032002    0.654033    
#> 248: 0.418503    1.082560    3.479501    0.506644    0.023986    0.031884    0.653768    
#> 249: 0.418320    1.082267    3.479525    0.506598    0.023988    0.031775    0.653567    
#> 250: 0.418950    1.082513    3.479634    0.507863    0.024010    0.031717    0.653593    
#> 251: 0.419468    1.082806    3.480024    0.509082    0.024094    0.031672    0.653516    
#> 252: 0.420183    1.083027    3.480404    0.510905    0.024133    0.031677    0.653302    
#> 253: 0.420694    1.083038    3.480801    0.510696    0.024096    0.031616    0.653474    
#> 254: 0.421261    1.083477    3.481061    0.509601    0.024071    0.031498    0.653918    
#> 255: 0.421037    1.083671    3.481115    0.508743    0.024008    0.031439    0.653884    
#> 256: 0.421679    1.083566    3.481055    0.510866    0.023925    0.031488    0.653796    
#> 257: 0.421163    1.083316    3.480864    0.511521    0.023781    0.031417    0.653729    
#> 258: 0.420790    1.082992    3.480685    0.512817    0.023754    0.031433    0.653844    
#> 259: 0.420317    1.083018    3.480522    0.513104    0.023776    0.031453    0.654045    
#> 260: 0.420206    1.083165    3.480559    0.512834    0.023798    0.031520    0.654125    
#> 261: 0.420366    1.083054    3.480599    0.512544    0.023824    0.031663    0.654383    
#> 262: 0.420288    1.083228    3.480339    0.513744    0.023853    0.031697    0.654397    
#> 263: 0.420079    1.083351    3.480201    0.514773    0.023811    0.031679    0.654329    
#> 264: 0.419808    1.083519    3.479977    0.516024    0.023798    0.031672    0.654503    
#> 265: 0.419522    1.083631    3.479883    0.516275    0.023847    0.031638    0.654819    
#> 266: 0.419337    1.084034    3.479705    0.517691    0.023838    0.031675    0.654630    
#> 267: 0.419380    1.084242    3.479755    0.519399    0.023788    0.031617    0.654741    
#> 268: 0.419213    1.084356    3.479606    0.519842    0.023760    0.031592    0.654836    
#> 269: 0.419228    1.084377    3.479463    0.519530    0.023796    0.031563    0.654654    
#> 270: 0.419638    1.084628    3.479384    0.519559    0.023842    0.031499    0.654280    
#> 271: 0.420075    1.084827    3.479271    0.519523    0.023773    0.031423    0.654101    
#> 272: 0.420195    1.084837    3.479103    0.518858    0.023733    0.031459    0.654057    
#> 273: 0.419811    1.085140    3.479031    0.518076    0.023739    0.031463    0.653974    
#> 274: 0.419833    1.085234    3.478984    0.517968    0.023758    0.031455    0.653705    
#> 275: 0.419531    1.085406    3.478706    0.517769    0.023787    0.031412    0.653495    
#> 276: 0.419205    1.085567    3.478564    0.517768    0.023759    0.031350    0.653595    
#> 277: 0.418972    1.085779    3.478685    0.516689    0.023724    0.031314    0.653908    
#> 278: 0.418667    1.085945    3.478674    0.516387    0.023747    0.031248    0.653828    
#> 279: 0.419044    1.085902    3.478807    0.516431    0.023758    0.031270    0.653941    
#> 280: 0.418806    1.086050    3.478856    0.516280    0.023839    0.031294    0.653846    
#> 281: 0.418185    1.086241    3.478804    0.516679    0.023871    0.031286    0.653732    
#> 282: 0.418253    1.086430    3.478756    0.518310    0.023923    0.031242    0.653663    
#> 283: 0.418199    1.086562    3.478758    0.519721    0.023963    0.031203    0.653985    
#> 284: 0.417873    1.086595    3.478664    0.520170    0.024048    0.031131    0.653959    
#> 285: 0.417674    1.086616    3.478484    0.520850    0.024170    0.031124    0.654068    
#> 286: 0.417101    1.086834    3.478222    0.522070    0.024324    0.031110    0.654246    
#> 287: 0.416610    1.087216    3.477845    0.523041    0.024415    0.031113    0.654341    
#> 288: 0.416512    1.087303    3.477705    0.522344    0.024446    0.031086    0.654764    
#> 289: 0.416037    1.087519    3.477416    0.521955    0.024467    0.031091    0.654736    
#> 290: 0.416179    1.087747    3.477249    0.522974    0.024480    0.031117    0.654936    
#> 291: 0.416078    1.088017    3.477111    0.523496    0.024484    0.031166    0.655060    
#> 292: 0.415389    1.088309    3.476792    0.522813    0.024488    0.031190    0.655119    
#> 293: 0.415132    1.088531    3.476595    0.521930    0.024457    0.031218    0.655267    
#> 294: 0.414336    1.088824    3.476260    0.522539    0.024458    0.031249    0.655359    
#> 295: 0.413843    1.088705    3.476046    0.522775    0.024444    0.031354    0.655425    
#> 296: 0.413380    1.088784    3.475866    0.522331    0.024436    0.031464    0.655610    
#> 297: 0.413137    1.088989    3.475790    0.522851    0.024486    0.031524    0.655718    
#> 298: 0.413148    1.089000    3.475684    0.522720    0.024486    0.031475    0.655713    
#> 299: 0.413198    1.089096    3.475544    0.522264    0.024495    0.031397    0.655623    
#> 300: 0.413506    1.089141    3.475586    0.522858    0.024468    0.031389    0.655520    
#> 301: 0.413920    1.088974    3.475655    0.522410    0.024461    0.031368    0.655662    
#> 302: 0.414129    1.088926    3.475732    0.521702    0.024434    0.031383    0.655494    
#> 303: 0.414222    1.089037    3.475765    0.521736    0.024439    0.031380    0.655342    
#> 304: 0.414399    1.089244    3.475718    0.522213    0.024419    0.031381    0.655371    
#> 305: 0.414436    1.089205    3.475641    0.522086    0.024438    0.031358    0.655305    
#> 306: 0.414290    1.089161    3.475554    0.521474    0.024459    0.031287    0.655276    
#> 307: 0.413558    1.089070    3.475259    0.521200    0.024515    0.031220    0.655323    
#> 308: 0.412845    1.089102    3.475064    0.521376    0.024581    0.031169    0.655286    
#> 309: 0.412359    1.089046    3.474996    0.521461    0.024579    0.031106    0.655516    
#> 310: 0.412047    1.089250    3.474732    0.521781    0.024651    0.031116    0.655407    
#> 311: 0.412049    1.089342    3.474626    0.522287    0.024661    0.031102    0.655271    
#> 312: 0.411592    1.089321    3.474472    0.523132    0.024707    0.031100    0.655256    
#> 313: 0.411189    1.089206    3.474269    0.523598    0.024750    0.031074    0.655341    
#> 314: 0.410601    1.089309    3.474146    0.523474    0.024729    0.031067    0.655444    
#> 315: 0.410203    1.089491    3.474029    0.523192    0.024710    0.031009    0.655575    
#> 316: 0.409665    1.089808    3.473819    0.522733    0.024711    0.031000    0.655642    
#> 317: 0.409377    1.090007    3.473789    0.521905    0.024752    0.031026    0.655863    
#> 318: 0.409190    1.090208    3.473670    0.521602    0.024726    0.031008    0.655848    
#> 319: 0.408955    1.090349    3.473597    0.521383    0.024730    0.031017    0.655827    
#> 320: 0.408615    1.090500    3.473468    0.521733    0.024692    0.031000    0.655927    
#> 321: 0.408421    1.090711    3.473258    0.522632    0.024685    0.031011    0.655932    
#> 322: 0.408135    1.090883    3.473083    0.522656    0.024667    0.031014    0.655895    
#> 323: 0.407714    1.090945    3.472925    0.522363    0.024686    0.031067    0.655849    
#> 324: 0.407274    1.091153    3.472721    0.522534    0.024745    0.031065    0.655753    
#> 325: 0.406804    1.091508    3.472493    0.522457    0.024768    0.031076    0.655681    
#> 326: 0.406393    1.091638    3.472322    0.522058    0.024763    0.031083    0.655648    
#> 327: 0.406284    1.091777    3.472298    0.522239    0.024796    0.031094    0.655631    
#> 328: 0.406275    1.091825    3.472303    0.521987    0.024783    0.031077    0.655682    
#> 329: 0.406411    1.091870    3.472311    0.521991    0.024768    0.031064    0.655764    
#> 330: 0.405937    1.091880    3.472264    0.521664    0.024734    0.031018    0.655998    
#> 331: 0.405774    1.092071    3.472229    0.521471    0.024789    0.030985    0.655988    
#> 332: 0.405671    1.092127    3.472297    0.521045    0.024812    0.030947    0.656119    
#> 333: 0.405425    1.092138    3.472202    0.520756    0.024875    0.030908    0.656174    
#> 334: 0.405323    1.092049    3.472131    0.520297    0.024927    0.030892    0.656040    
#> 335: 0.405186    1.092116    3.471986    0.520359    0.024970    0.030888    0.655913    
#> 336: 0.404772    1.092321    3.471880    0.520101    0.025023    0.030883    0.655793    
#> 337: 0.404514    1.092702    3.471649    0.520386    0.025089    0.030879    0.655730    
#> 338: 0.404377    1.092949    3.471499    0.520718    0.025146    0.030887    0.655649    
#> 339: 0.403940    1.093125    3.471291    0.520508    0.025166    0.030923    0.655650    
#> 340: 0.403747    1.093170    3.471152    0.520805    0.025169    0.030954    0.655579    
#> 341: 0.403860    1.093152    3.471128    0.521332    0.025187    0.030999    0.655501    
#> 342: 0.403901    1.092975    3.471155    0.521491    0.025151    0.031055    0.655514    
#> 343: 0.403684    1.092920    3.471185    0.521344    0.025136    0.031076    0.655546    
#> 344: 0.403877    1.092830    3.471252    0.521748    0.025096    0.031114    0.655685    
#> 345: 0.403945    1.092855    3.471318    0.521616    0.025038    0.031183    0.655722    
#> 346: 0.403638    1.093023    3.471190    0.521639    0.025010    0.031185    0.655761    
#> 347: 0.403482    1.092989    3.471126    0.521632    0.025039    0.031162    0.655800    
#> 348: 0.403440    1.093089    3.471010    0.521700    0.025029    0.031179    0.655913    
#> 349: 0.403066    1.093124    3.470913    0.522099    0.025015    0.031208    0.655875    
#> 350: 0.402628    1.093144    3.470762    0.522174    0.025012    0.031223    0.655790    
#> 351: 0.402475    1.093361    3.470626    0.522411    0.025000    0.031219    0.655755    
#> 352: 0.402231    1.093507    3.470565    0.522382    0.024964    0.031238    0.655976    
#> 353: 0.402449    1.093598    3.470520    0.522588    0.024950    0.031228    0.656007    
#> 354: 0.402444    1.093712    3.470486    0.522583    0.024972    0.031192    0.655964    
#> 355: 0.402736    1.093734    3.470447    0.522953    0.024973    0.031173    0.655873    
#> 356: 0.402699    1.093715    3.470495    0.522753    0.024967    0.031157    0.655929    
#> 357: 0.402736    1.093809    3.470543    0.522868    0.024949    0.031102    0.655947    
#> 358: 0.402596    1.093908    3.470579    0.522836    0.024956    0.031062    0.655917    
#> 359: 0.402296    1.094090    3.470461    0.522465    0.024913    0.031021    0.655995    
#> 360: 0.402112    1.094233    3.470317    0.522628    0.024883    0.030992    0.655936    
#> 361: 0.401974    1.094404    3.470232    0.522314    0.024880    0.030973    0.655815    
#> 362: 0.401974    1.094406    3.470183    0.522212    0.024896    0.030923    0.655639    
#> 363: 0.401983    1.094394    3.470211    0.522258    0.024909    0.030866    0.655536    
#> 364: 0.402299    1.094434    3.470214    0.522677    0.024912    0.030839    0.655542    
#> 365: 0.402058    1.094412    3.470140    0.522404    0.024932    0.030835    0.655624    
#> 366: 0.402134    1.094420    3.470116    0.522052    0.024933    0.030809    0.655737    
#> 367: 0.402239    1.094481    3.470070    0.522145    0.024930    0.030773    0.655750    
#> 368: 0.402465    1.094587    3.470028    0.522602    0.024922    0.030749    0.655664    
#> 369: 0.402605    1.094625    3.469952    0.523331    0.024922    0.030737    0.655603    
#> 370: 0.402570    1.094745    3.469863    0.523513    0.024926    0.030760    0.655587    
#> 371: 0.402360    1.094854    3.469786    0.523324    0.024917    0.030775    0.655501    
#> 372: 0.402066    1.094933    3.469670    0.523539    0.024888    0.030798    0.655457    
#> 373: 0.401628    1.095096    3.469478    0.523686    0.024857    0.030798    0.655403    
#> 374: 0.401731    1.095111    3.469440    0.523959    0.024814    0.030807    0.655281    
#> 375: 0.401696    1.095103    3.469436    0.524173    0.024812    0.030800    0.655216    
#> 376: 0.401783    1.095150    3.469411    0.524500    0.024799    0.030804    0.655050    
#> 377: 0.401726    1.095239    3.469369    0.524613    0.024792    0.030785    0.654986    
#> 378: 0.401663    1.095246    3.469331    0.524449    0.024770    0.030768    0.655040    
#> 379: 0.401580    1.095125    3.469286    0.524555    0.024776    0.030756    0.655065    
#> 380: 0.401508    1.095176    3.469195    0.524634    0.024792    0.030734    0.655114    
#> 381: 0.401549    1.095214    3.469144    0.525325    0.024770    0.030729    0.655080    
#> 382: 0.401312    1.095266    3.469036    0.525652    0.024787    0.030718    0.654967    
#> 383: 0.401114    1.095291    3.468928    0.525701    0.024780    0.030701    0.654877    
#> 384: 0.400838    1.095431    3.468835    0.525576    0.024760    0.030694    0.654825    
#> 385: 0.400759    1.095485    3.468800    0.525582    0.024784    0.030675    0.654777    
#> 386: 0.400858    1.095639    3.468766    0.525815    0.024842    0.030652    0.654742    
#> 387: 0.400930    1.095726    3.468842    0.525587    0.024901    0.030639    0.654725    
#> 388: 0.400987    1.095755    3.468897    0.525262    0.024900    0.030622    0.654699    
#> 389: 0.400959    1.095665    3.468895    0.525379    0.024897    0.030603    0.654737    
#> 390: 0.400946    1.095716    3.468896    0.525334    0.024871    0.030598    0.654694    
#> 391: 0.401079    1.095699    3.468956    0.525218    0.024856    0.030589    0.654647    
#> 392: 0.401134    1.095681    3.469033    0.525256    0.024838    0.030576    0.654701    
#> 393: 0.401153    1.095608    3.469036    0.525506    0.024861    0.030565    0.654753    
#> 394: 0.401256    1.095641    3.468981    0.525423    0.024856    0.030567    0.654837    
#> 395: 0.401206    1.095797    3.468953    0.525184    0.024850    0.030593    0.654898    
#> 396: 0.401183    1.095862    3.468951    0.524966    0.024869    0.030588    0.654908    
#> 397: 0.401207    1.095789    3.468967    0.524965    0.024868    0.030595    0.655025    
#> 398: 0.401302    1.095705    3.469028    0.524655    0.024889    0.030609    0.655027    
#> 399: 0.401411    1.095757    3.469038    0.524681    0.024918    0.030612    0.655059    
#> 400: 0.401465    1.095877    3.469016    0.524900    0.024928    0.030600    0.655027    
#> 401: 0.401406    1.096049    3.468957    0.524980    0.024951    0.030605    0.655039    
#> 402: 0.401502    1.096069    3.468983    0.524979    0.024941    0.030599    0.655089    
#> 403: 0.401940    1.096092    3.469030    0.525021    0.024934    0.030562    0.655129    
#> 404: 0.402077    1.096160    3.469033    0.524975    0.024937    0.030536    0.655052    
#> 405: 0.402098    1.096195    3.469042    0.525319    0.024954    0.030498    0.654968    
#> 406: 0.402257    1.096220    3.469052    0.525248    0.024960    0.030482    0.654968    
#> 407: 0.402317    1.096273    3.469094    0.525283    0.025004    0.030477    0.654937    
#> 408: 0.402604    1.096401    3.469121    0.525395    0.025078    0.030452    0.654881    
#> 409: 0.402535    1.096447    3.469055    0.525313    0.025097    0.030413    0.654879    
#> 410: 0.402299    1.096507    3.468950    0.525350    0.025127    0.030406    0.654842    
#> 411: 0.402288    1.096399    3.468930    0.525507    0.025165    0.030387    0.654884    
#> 412: 0.402212    1.096414    3.468936    0.525232    0.025195    0.030354    0.654876    
#> 413: 0.402153    1.096428    3.468967    0.524621    0.025191    0.030339    0.654880    
#> 414: 0.401964    1.096394    3.468986    0.524567    0.025197    0.030338    0.654904    
#> 415: 0.402186    1.096388    3.469019    0.524644    0.025186    0.030325    0.654891    
#> 416: 0.402345    1.096430    3.469098    0.524299    0.025190    0.030298    0.654911    
#> 417: 0.402624    1.096399    3.469177    0.524691    0.025203    0.030291    0.654883    
#> 418: 0.402698    1.096376    3.469247    0.524697    0.025221    0.030291    0.654833    
#> 419: 0.402840    1.096418    3.469288    0.524789    0.025234    0.030311    0.654749    
#> 420: 0.403063    1.096399    3.469368    0.524754    0.025233    0.030292    0.654638    
#> 421: 0.403141    1.096379    3.469440    0.524660    0.025221    0.030271    0.654581    
#> 422: 0.403399    1.096326    3.469518    0.524559    0.025224    0.030253    0.654517    
#> 423: 0.403569    1.096237    3.469602    0.524474    0.025215    0.030260    0.654425    
#> 424: 0.403621    1.096177    3.469570    0.524666    0.025210    0.030241    0.654370    
#> 425: 0.403649    1.096187    3.469524    0.525024    0.025217    0.030244    0.654375    
#> 426: 0.403803    1.096234    3.469492    0.525223    0.025226    0.030243    0.654346    
#> 427: 0.403706    1.096180    3.469496    0.525274    0.025228    0.030240    0.654246    
#> 428: 0.403571    1.096199    3.469509    0.525097    0.025222    0.030256    0.654135    
#> 429: 0.403537    1.096237    3.469527    0.525037    0.025211    0.030272    0.654084    
#> 430: 0.403524    1.096295    3.469472    0.524939    0.025208    0.030272    0.654104    
#> 431: 0.403404    1.096314    3.469399    0.524908    0.025209    0.030283    0.654048    
#> 432: 0.403201    1.096400    3.469316    0.524977    0.025199    0.030302    0.654059    
#> 433: 0.403189    1.096515    3.469297    0.525089    0.025190    0.030291    0.654084    
#> 434: 0.403083    1.096516    3.469254    0.524875    0.025185    0.030292    0.654045    
#> 435: 0.403108    1.096559    3.469234    0.524633    0.025173    0.030274    0.654023    
#> 436: 0.403160    1.096541    3.469281    0.524577    0.025184    0.030261    0.654004    
#> 437: 0.403116    1.096525    3.469289    0.524408    0.025195    0.030238    0.654019    
#> 438: 0.402954    1.096675    3.469283    0.524220    0.025214    0.030217    0.654031    
#> 439: 0.402893    1.096775    3.469257    0.524174    0.025226    0.030200    0.653928    
#> 440: 0.402848    1.096822    3.469239    0.523724    0.025228    0.030192    0.653937    
#> 441: 0.402929    1.096804    3.469240    0.523367    0.025222    0.030171    0.653878    
#> 442: 0.402875    1.096778    3.469276    0.523426    0.025212    0.030176    0.653778    
#> 443: 0.402892    1.096815    3.469262    0.523298    0.025228    0.030158    0.653683    
#> 444: 0.402798    1.096871    3.469183    0.523087    0.025243    0.030137    0.653666    
#> 445: 0.402751    1.096940    3.469168    0.522951    0.025261    0.030148    0.653669    
#> 446: 0.402617    1.096985    3.469155    0.523040    0.025277    0.030151    0.653642    
#> 447: 0.402771    1.096995    3.469177    0.523294    0.025296    0.030152    0.653653    
#> 448: 0.402818    1.097029    3.469201    0.523162    0.025289    0.030131    0.653668    
#> 449: 0.402837    1.097106    3.469286    0.522860    0.025307    0.030123    0.653677    
#> 450: 0.402859    1.097107    3.469337    0.522601    0.025317    0.030107    0.653650    
#> 451: 0.402847    1.097180    3.469346    0.522301    0.025324    0.030134    0.653622    
#> 452: 0.402786    1.097229    3.469337    0.522075    0.025332    0.030129    0.653567    
#> 453: 0.402745    1.097276    3.469305    0.522037    0.025327    0.030129    0.653523    
#> 454: 0.402577    1.097318    3.469259    0.521928    0.025341    0.030123    0.653469    
#> 455: 0.402562    1.097274    3.469220    0.522107    0.025317    0.030122    0.653421    
#> 456: 0.402517    1.097244    3.469205    0.522118    0.025320    0.030101    0.653400    
#> 457: 0.402553    1.097247    3.469234    0.522093    0.025312    0.030078    0.653373    
#> 458: 0.402579    1.097323    3.469243    0.522238    0.025306    0.030064    0.653377    
#> 459: 0.402328    1.097445    3.469191    0.522353    0.025301    0.030076    0.653374    
#> 460: 0.402100    1.097475    3.469099    0.522137    0.025291    0.030084    0.653361    
#> 461: 0.402046    1.097503    3.469093    0.521854    0.025282    0.030079    0.653348    
#> 462: 0.401907    1.097536    3.469095    0.521438    0.025283    0.030075    0.653322    
#> 463: 0.401813    1.097584    3.469082    0.521122    0.025269    0.030091    0.653274    
#> 464: 0.401737    1.097630    3.469031    0.520962    0.025265    0.030089    0.653236    
#> 465: 0.401694    1.097562    3.469026    0.520838    0.025262    0.030083    0.653181    
#> 466: 0.401704    1.097565    3.468995    0.520605    0.025247    0.030085    0.653122    
#> 467: 0.401512    1.097594    3.469004    0.520298    0.025263    0.030063    0.653084    
#> 468: 0.401585    1.097603    3.469048    0.520378    0.025276    0.030050    0.653035    
#> 469: 0.401762    1.097679    3.469100    0.520520    0.025304    0.030029    0.653019    
#> 470: 0.401876    1.097707    3.469129    0.520755    0.025335    0.030011    0.653046    
#> 471: 0.401983    1.097686    3.469160    0.520846    0.025348    0.029994    0.653090    
#> 472: 0.402204    1.097619    3.469222    0.520941    0.025370    0.029960    0.653142    
#> 473: 0.402239    1.097636    3.469217    0.520570    0.025381    0.029948    0.653122    
#> 474: 0.402264    1.097634    3.469227    0.520504    0.025369    0.029953    0.653157    
#> 475: 0.402353    1.097663    3.469244    0.520622    0.025361    0.029958    0.653168    
#> 476: 0.402517    1.097624    3.469276    0.521232    0.025348    0.029955    0.653209    
#> 477: 0.402577    1.097603    3.469325    0.521245    0.025337    0.029948    0.653169    
#> 478: 0.402504    1.097565    3.469366    0.521117    0.025354    0.029947    0.653160    
#> 479: 0.402544    1.097589    3.469400    0.520661    0.025388    0.029943    0.653153    
#> 480: 0.402514    1.097625    3.469432    0.520303    0.025420    0.029932    0.653177    
#> 481: 0.402425    1.097670    3.469430    0.519928    0.025419    0.029934    0.653160    
#> 482: 0.402491    1.097670    3.469419    0.519957    0.025428    0.029933    0.653163    
#> 483: 0.402521    1.097665    3.469449    0.520030    0.025434    0.029929    0.653156    
#> 484: 0.402492    1.097575    3.469471    0.519832    0.025430    0.029930    0.653176    
#> 485: 0.402525    1.097609    3.469502    0.519666    0.025427    0.029940    0.653206    
#> 486: 0.402601    1.097696    3.469578    0.519343    0.025435    0.029933    0.653234    
#> 487: 0.402889    1.097783    3.469690    0.519370    0.025442    0.029926    0.653233    
#> 488: 0.402997    1.097730    3.469761    0.519404    0.025455    0.029930    0.653208    
#> 489: 0.403208    1.097683    3.469797    0.519600    0.025455    0.029951    0.653228    
#> 490: 0.403300    1.097752    3.469810    0.520163    0.025471    0.029965    0.653165    
#> 491: 0.403311    1.097834    3.469809    0.520177    0.025490    0.029970    0.653108    
#> 492: 0.403271    1.097926    3.469753    0.520211    0.025507    0.029986    0.653097    
#> 493: 0.403132    1.097974    3.469716    0.520195    0.025510    0.029994    0.653137    
#> 494: 0.403168    1.098029    3.469673    0.520016    0.025512    0.029999    0.653152    
#> 495: 0.403198    1.098092    3.469688    0.519937    0.025502    0.029989    0.653139    
#> 496: 0.403300    1.098157    3.469671    0.520043    0.025523    0.029996    0.653089    
#> 497: 0.403300    1.098143    3.469668    0.520198    0.025524    0.029999    0.653128    
#> 498: 0.403318    1.098141    3.469659    0.520249    0.025523    0.029998    0.653128    
#> 499: 0.403291    1.098217    3.469606    0.520187    0.025541    0.029988    0.653087    
#> 500: 0.403278    1.098233    3.469553    0.520373    0.025529    0.029988    0.653029    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.282846    0.992756    3.449632    0.392401    0.085936    0.016800    1.685169    
#> 002: 0.349988    1.004434    3.486268    0.372781    0.081639    0.016517    1.109585    
#> 003: 0.424115    1.002946    3.491761    0.354142    0.092498    0.015691    0.915694    
#> 004: 0.351560    1.013391    3.482236    0.336435    0.096500    0.015506    0.817481    
#> 005: 0.378164    1.027073    3.469598    0.319613    0.109289    0.014731    0.751494    
#> 006: 0.390916    1.045008    3.460584    0.303666    0.103824    0.014573    0.690806    
#> 007: 0.372798    1.047506    3.456006    0.317673    0.102727    0.016757    0.680046    
#> 008: 0.347569    1.043131    3.450385    0.332746    0.097591    0.015919    0.679885    
#> 009: 0.326456    1.037047    3.442301    0.316108    0.092711    0.017628    0.657956    
#> 010: 0.337312    1.036470    3.447408    0.356554    0.088076    0.020929    0.671407    
#> 011: 0.398063    1.040418    3.457403    0.355088    0.083672    0.021625    0.671579    
#> 012: 0.384385    1.048782    3.458040    0.337334    0.102688    0.020742    0.643757    
#> 013: 0.345320    1.052194    3.445360    0.320467    0.097554    0.021553    0.662339    
#> 014: 0.372420    1.057246    3.462253    0.331911    0.103692    0.027011    0.664203    
#> 015: 0.396492    1.064483    3.461591    0.315315    0.098507    0.025661    0.651483    
#> 016: 0.394783    1.064939    3.469645    0.340300    0.093582    0.024378    0.649193    
#> 017: 0.382005    1.068753    3.463914    0.325954    0.088903    0.025854    0.641230    
#> 018: 0.403945    1.064331    3.454572    0.377825    0.084458    0.028640    0.628837    
#> 019: 0.385387    1.051815    3.456938    0.358934    0.080235    0.027208    0.639557    
#> 020: 0.393355    1.050717    3.457364    0.375530    0.076223    0.028122    0.640398    
#> 021: 0.387840    1.052836    3.456088    0.384469    0.072412    0.026716    0.631413    
#> 022: 0.403367    1.039526    3.476328    0.406510    0.075687    0.029534    0.626247    
#> 023: 0.500403    1.042362    3.480831    0.432402    0.082155    0.028667    0.646093    
#> 024: 0.465926    1.049711    3.487175    0.410782    0.083373    0.027234    0.634104    
#> 025: 0.423804    1.038303    3.482112    0.390243    0.079204    0.025872    0.637724    
#> 026: 0.393618    1.050493    3.462251    0.370731    0.088163    0.024578    0.642465    
#> 027: 0.365502    1.062576    3.454729    0.352194    0.088729    0.023349    0.666573    
#> 028: 0.435533    1.037446    3.472362    0.367778    0.084292    0.025812    0.654520    
#> 029: 0.429659    1.052244    3.456140    0.439424    0.098323    0.028696    0.664838    
#> 030: 0.431135    1.044186    3.459212    0.417453    0.093406    0.027536    0.658948    
#> 031: 0.369387    1.033450    3.464586    0.396580    0.088736    0.026159    0.666683    
#> 032: 0.389605    1.028484    3.472275    0.376751    0.102132    0.024851    0.660247    
#> 033: 0.411796    1.041637    3.474927    0.357913    0.102602    0.023608    0.669822    
#> 034: 0.413061    1.045063    3.479808    0.369036    0.097472    0.022428    0.655423    
#> 035: 0.412871    1.034178    3.468409    0.389375    0.092598    0.021529    0.636728    
#> 036: 0.409863    1.043238    3.470504    0.369906    0.087968    0.024283    0.651825    
#> 037: 0.412224    1.050379    3.466774    0.401820    0.083681    0.025593    0.672394    
#> 038: 0.471475    1.035881    3.477499    0.424830    0.079497    0.026997    0.653802    
#> 039: 0.454718    1.026990    3.477576    0.411081    0.084653    0.025647    0.642276    
#> 040: 0.448622    1.034695    3.483215    0.418016    0.086509    0.024365    0.644741    
#> 041: 0.412630    1.032802    3.475693    0.397115    0.082183    0.026386    0.648792    
#> 042: 0.430783    1.033460    3.464683    0.377259    0.078074    0.030300    0.647390    
#> 043: 0.393636    1.068210    3.451819    0.358396    0.087148    0.031968    0.653383    
#> 044: 0.349554    1.076068    3.450172    0.340477    0.088785    0.030370    0.654820    
#> 045: 0.369872    1.078771    3.448230    0.367591    0.084346    0.028851    0.646061    
#> 046: 0.373941    1.055497    3.453048    0.391602    0.080128    0.028020    0.639505    
#> 047: 0.346746    1.072233    3.447666    0.372022    0.086604    0.026619    0.641030    
#> 048: 0.381966    1.049264    3.461919    0.353421    0.088419    0.027180    0.658240    
#> 049: 0.384216    1.053121    3.463081    0.335750    0.091868    0.025821    0.662939    
#> 050: 0.426093    1.022310    3.478478    0.366873    0.093152    0.027369    0.676072    
#> 051: 0.440538    1.027129    3.463642    0.396261    0.088494    0.026000    0.685664    
#> 052: 0.445495    1.049950    3.483327    0.411166    0.090362    0.024700    0.660292    
#> 053: 0.456031    1.034188    3.468072    0.428162    0.095335    0.024876    0.650309    
#> 054: 0.384639    1.048682    3.478200    0.406754    0.090569    0.033973    0.678346    
#> 055: 0.413099    1.045379    3.464534    0.413772    0.093208    0.032275    0.672057    
#> 056: 0.397169    1.046640    3.463260    0.393084    0.103285    0.030661    0.682948    
#> 057: 0.396103    1.051253    3.472727    0.373429    0.098121    0.029128    0.675881    
#> 058: 0.381591    1.059724    3.454827    0.384731    0.104983    0.027672    0.670452    
#> 059: 0.393070    1.033151    3.466651    0.390429    0.099734    0.026288    0.672730    
#> 060: 0.418911    1.015642    3.475266    0.431120    0.094747    0.029395    0.656742    
#> 061: 0.462165    1.045607    3.473832    0.440471    0.090010    0.034348    0.666829    
#> 062: 0.406349    1.054018    3.476590    0.418447    0.085509    0.038687    0.689631    
#> 063: 0.479167    1.022003    3.484376    0.397525    0.081234    0.036752    0.659684    
#> 064: 0.450894    1.036842    3.490601    0.377649    0.086463    0.034915    0.661076    
#> 065: 0.442592    1.016662    3.478423    0.358766    0.082140    0.037123    0.661706    
#> 066: 0.462783    1.045476    3.483100    0.340828    0.078033    0.036237    0.655130    
#> 067: 0.410541    1.033404    3.469696    0.365625    0.074131    0.034425    0.647702    
#> 068: 0.398429    1.046382    3.471604    0.375517    0.080984    0.032704    0.661781    
#> 069: 0.398135    1.031730    3.458921    0.418142    0.078168    0.031434    0.653249    
#> 070: 0.374676    1.041735    3.457432    0.411007    0.075500    0.032280    0.646326    
#> 071: 0.326762    1.064562    3.424276    0.390456    0.071725    0.030666    0.675192    
#> 072: 0.361047    1.022792    3.449972    0.370934    0.069264    0.037668    0.657748    
#> 073: 0.379412    1.061188    3.466577    0.385480    0.069209    0.035785    0.657768    
#> 074: 0.362906    1.057088    3.465686    0.368048    0.073737    0.033996    0.647901    
#> 075: 0.424961    1.035425    3.479061    0.376775    0.081528    0.032296    0.637456    
#> 076: 0.430146    1.042788    3.484868    0.420303    0.077452    0.035874    0.650271    
#> 077: 0.470228    1.029064    3.484373    0.399288    0.075787    0.034080    0.655071    
#> 078: 0.437468    1.034108    3.487429    0.379323    0.076645    0.032376    0.651118    
#> 079: 0.404368    1.043728    3.472589    0.384017    0.072813    0.032065    0.647697    
#> 080: 0.441720    1.052424    3.476491    0.455222    0.071735    0.032801    0.635698    
#> 081: 0.427875    1.047725    3.477481    0.432461    0.071929    0.031161    0.638332    
#> 082: 0.420255    1.036167    3.479321    0.410838    0.074626    0.029603    0.660848    
#> 083: 0.416362    1.051886    3.482781    0.390296    0.074722    0.028122    0.668449    
#> 084: 0.413957    1.063398    3.470133    0.370781    0.095295    0.026716    0.645431    
#> 085: 0.397184    1.056154    3.474451    0.382130    0.090530    0.025381    0.650746    
#> 086: 0.387697    1.046219    3.466053    0.363023    0.086004    0.027924    0.654407    
#> 087: 0.402138    1.038057    3.460488    0.344872    0.081704    0.026527    0.653567    
#> 088: 0.355901    1.034120    3.467966    0.384629    0.077619    0.026905    0.669141    
#> 089: 0.402250    1.055101    3.460285    0.425335    0.073738    0.031731    0.641690    
#> 090: 0.407157    1.049797    3.452497    0.448578    0.074625    0.031892    0.644369    
#> 091: 0.393704    1.028759    3.455187    0.426149    0.078159    0.030297    0.658304    
#> 092: 0.399966    1.060423    3.451330    0.414488    0.080886    0.028782    0.641747    
#> 093: 0.378201    1.054707    3.460284    0.393764    0.091424    0.027343    0.661599    
#> 094: 0.365579    1.069795    3.445168    0.397002    0.090124    0.025976    0.675688    
#> 095: 0.401182    1.051600    3.469343    0.405186    0.085618    0.026694    0.659511    
#> 096: 0.362267    1.042879    3.469418    0.384927    0.081337    0.027552    0.658486    
#> 097: 0.382123    1.076228    3.457405    0.382403    0.087683    0.028904    0.642313    
#> 098: 0.364608    1.074446    3.464849    0.363283    0.083727    0.027459    0.654017    
#> 099: 0.370344    1.034581    3.452671    0.365407    0.079540    0.027998    0.652571    
#> 100: 0.375578    1.052195    3.460976    0.347136    0.075563    0.026598    0.643017    
#> 101: 0.363643    1.034337    3.440774    0.343996    0.071785    0.025268    0.644139    
#> 102: 0.374980    1.053459    3.444752    0.327360    0.074713    0.024005    0.642053    
#> 103: 0.405603    1.043029    3.463512    0.389109    0.084974    0.025785    0.638176    
#> 104: 0.378992    1.041154    3.468325    0.377417    0.083702    0.028975    0.650962    
#> 105: 0.388414    1.050529    3.467858    0.375008    0.087664    0.027526    0.650646    
#> 106: 0.402645    1.045448    3.473322    0.356258    0.085482    0.026150    0.648250    
#> 107: 0.441760    1.045551    3.470895    0.371604    0.097539    0.025773    0.638527    
#> 108: 0.419225    1.046929    3.471293    0.367535    0.101319    0.025845    0.660018    
#> 109: 0.405696    1.039543    3.476814    0.381609    0.096253    0.028961    0.640638    
#> 110: 0.406956    1.039058    3.463100    0.379422    0.091441    0.027513    0.641360    
#> 111: 0.399967    1.035586    3.461454    0.360451    0.092630    0.026137    0.627206    
#> 112: 0.414136    1.036001    3.458216    0.369382    0.087998    0.024830    0.650070    
#> 113: 0.395115    1.056109    3.469831    0.355009    0.083598    0.028565    0.637269    
#> 114: 0.414229    1.054286    3.466896    0.347201    0.088411    0.031604    0.630774    
#> 115: 0.409820    1.038574    3.469875    0.330095    0.102473    0.034568    0.665145    
#> 116: 0.395533    1.047648    3.456604    0.358473    0.097350    0.032839    0.653203    
#> 117: 0.380718    1.050012    3.473944    0.340550    0.092482    0.031197    0.669718    
#> 118: 0.401301    1.030116    3.469535    0.323522    0.087858    0.029637    0.662081    
#> 119: 0.414334    1.034430    3.478076    0.320357    0.083465    0.031187    0.662130    
#> 120: 0.382231    1.027684    3.469445    0.342108    0.079292    0.032674    0.658969    
#> 121: 0.374773    1.076371    3.462909    0.325002    0.075327    0.031272    0.676585    
#> 122: 0.402555    1.032468    3.478204    0.317496    0.074010    0.029804    0.655681    
#> 123: 0.387272    1.064586    3.453473    0.366246    0.070310    0.029607    0.664935    
#> 124: 0.424160    1.075319    3.460985    0.423194    0.072454    0.032962    0.661358    
#> 125: 0.383790    1.080900    3.443886    0.402034    0.082569    0.031314    0.658325    
#> 126: 0.368786    1.110894    3.421804    0.445358    0.092890    0.029748    0.669823    
#> 127: 0.367382    1.081773    3.430729    0.423090    0.088245    0.028261    0.660593    
#> 128: 0.350150    1.069724    3.454973    0.401935    0.090093    0.026848    0.659190    
#> 129: 0.363094    1.071918    3.441494    0.418013    0.090135    0.025505    0.660190    
#> 130: 0.411617    1.069031    3.456164    0.417662    0.086296    0.029237    0.659121    
#> 131: 0.443701    1.035384    3.457943    0.404796    0.081981    0.029472    0.678771    
#> 132: 0.381355    1.068920    3.445893    0.427097    0.088458    0.027998    0.653659    
#> 133: 0.383420    1.047887    3.448898    0.422566    0.084035    0.030086    0.646459    
#> 134: 0.403009    1.024761    3.469349    0.412421    0.082347    0.036782    0.638856    
#> 135: 0.408923    1.013332    3.471347    0.405835    0.079288    0.036067    0.643085    
#> 136: 0.436396    1.018916    3.476039    0.411435    0.075323    0.040193    0.632384    
#> 137: 0.460713    1.021479    3.489969    0.404925    0.071557    0.038183    0.653364    
#> 138: 0.435389    1.041436    3.475489    0.388744    0.068765    0.036274    0.653675    
#> 139: 0.413290    1.039925    3.485859    0.395323    0.067793    0.035355    0.662166    
#> 140: 0.433465    1.041248    3.477199    0.397125    0.064404    0.039235    0.659535    
#> 141: 0.392247    1.012313    3.474319    0.377269    0.064250    0.037273    0.670287    
#> 142: 0.409848    1.004396    3.488704    0.358405    0.067378    0.035409    0.679122    
#> 143: 0.393321    1.040550    3.484975    0.366105    0.087211    0.033639    0.657743    
#> 144: 0.451548    1.029108    3.489781    0.347800    0.082850    0.031957    0.661348    
#> 145: 0.402481    1.051413    3.463551    0.382161    0.089211    0.030359    0.651245    
#> 146: 0.371796    1.051267    3.472280    0.363053    0.084750    0.028841    0.660006    
#> 147: 0.373636    1.045838    3.460181    0.344901    0.080513    0.027399    0.660377    
#> 148: 0.375131    1.040518    3.479290    0.327656    0.085642    0.026029    0.648831    
#> 149: 0.382702    1.048070    3.471266    0.346704    0.085852    0.028130    0.647998    
#> 150: 0.400661    1.058443    3.446862    0.358048    0.088941    0.026724    0.651884    
#> 151: 0.323042    1.085166    3.442237    0.340146    0.097218    0.025388    0.643204    
#> 152: 0.381834    1.075014    3.449498    0.441393    0.092199    0.026445    0.625755    
#> 153: 0.381971    1.065203    3.460087    0.422105    0.091501    0.030999    0.647478    
#> 154: 0.416305    1.064135    3.469172    0.415078    0.074935    0.037123    0.653082    
#> 155: 0.403127    1.044707    3.467256    0.441789    0.069411    0.033000    0.636787    
#> 156: 0.420227    1.035921    3.462965    0.413245    0.074384    0.030165    0.651585    
#> 157: 0.423529    1.033465    3.473710    0.389338    0.077761    0.033039    0.647378    
#> 158: 0.415911    1.047254    3.458502    0.419288    0.080524    0.030695    0.631754    
#> 159: 0.375909    1.049832    3.466326    0.392905    0.092544    0.028022    0.641667    
#> 160: 0.435021    1.022743    3.476826    0.467155    0.084727    0.030605    0.645108    
#> 161: 0.430084    1.044403    3.465865    0.434292    0.078692    0.034264    0.640275    
#> 162: 0.428305    1.060531    3.453696    0.583495    0.075540    0.034068    0.652567    
#> 163: 0.412052    1.048117    3.457015    0.550205    0.084356    0.033586    0.632220    
#> 164: 0.405330    1.057766    3.458376    0.434099    0.082800    0.032199    0.636129    
#> 165: 0.409389    1.057314    3.466261    0.448111    0.094995    0.026628    0.649112    
#> 166: 0.456421    1.065730    3.463654    0.486432    0.090403    0.027757    0.649228    
#> 167: 0.456124    1.064321    3.480199    0.479334    0.092465    0.031345    0.648601    
#> 168: 0.435927    1.043821    3.485443    0.439885    0.085181    0.028749    0.635027    
#> 169: 0.431534    1.067761    3.468560    0.398981    0.094334    0.026215    0.643765    
#> 170: 0.423737    1.050348    3.479480    0.411673    0.084900    0.027806    0.625663    
#> 171: 0.417218    1.053461    3.464048    0.461667    0.105565    0.024095    0.631520    
#> 172: 0.404006    1.074479    3.458050    0.470989    0.090247    0.027609    0.631512    
#> 173: 0.402322    1.054472    3.445776    0.404400    0.075331    0.025975    0.625620    
#> 174: 0.414415    1.050239    3.468216    0.380687    0.086591    0.026467    0.630336    
#> 175: 0.414959    1.051109    3.462473    0.409083    0.077664    0.030816    0.639072    
#> 176: 0.419487    1.057412    3.475779    0.394852    0.071331    0.033479    0.626189    
#> 177: 0.442697    1.054373    3.476074    0.411796    0.084174    0.035505    0.631703    
#> 178: 0.437113    1.034779    3.471452    0.419352    0.080998    0.028748    0.640742    
#> 179: 0.443964    1.054441    3.475917    0.368391    0.064149    0.028265    0.671861    
#> 180: 0.382723    1.031577    3.469283    0.329143    0.068624    0.027290    0.670645    
#> 181: 0.380037    1.044480    3.445598    0.336541    0.052986    0.022835    0.677526    
#> 182: 0.315586    1.065218    3.435000    0.320354    0.062805    0.022035    0.695636    
#> 183: 0.361546    1.079993    3.443324    0.356034    0.075812    0.019778    0.679922    
#> 184: 0.377082    1.047901    3.450769    0.429027    0.082213    0.022490    0.664771    
#> 185: 0.348804    1.056636    3.445512    0.358939    0.089370    0.019175    0.652799    
#> 186: 0.360309    1.078240    3.449440    0.327111    0.088370    0.021779    0.663173    
#> 187: 0.384037    1.053377    3.459845    0.345706    0.077897    0.025315    0.652246    
#> 188: 0.404464    1.078943    3.455376    0.410599    0.076171    0.028927    0.657565    
#> 189: 0.394097    1.064077    3.462718    0.381902    0.070440    0.028617    0.659098    
#> 190: 0.390193    1.071641    3.466323    0.392218    0.071442    0.025714    0.647981    
#> 191: 0.382534    1.059414    3.458558    0.331045    0.067320    0.026593    0.646368    
#> 192: 0.385164    1.065736    3.473618    0.303543    0.073396    0.029360    0.648189    
#> 193: 0.397439    1.071280    3.460320    0.377268    0.073947    0.031241    0.637076    
#> 194: 0.384309    1.080705    3.448064    0.410570    0.069733    0.031006    0.644436    
#> 195: 0.354407    1.065365    3.450050    0.395515    0.061360    0.031165    0.643623    
#> 196: 0.354620    1.060441    3.455905    0.416675    0.065173    0.034830    0.646729    
#> 197: 0.358118    1.051638    3.462889    0.415747    0.066078    0.037619    0.658506    
#> 198: 0.413369    1.063593    3.456557    0.413465    0.070692    0.036096    0.635617    
#> 199: 0.405720    1.051503    3.455119    0.447290    0.069970    0.034747    0.647582    
#> 200: 0.385421    1.048465    3.465246    0.400814    0.073779    0.025317    0.664664    
#> 201: 0.378803    1.041837    3.462049    0.394971    0.073675    0.026115    0.660966    
#> 202: 0.384732    1.045675    3.464197    0.399771    0.073717    0.027358    0.660389    
#> 203: 0.392140    1.042541    3.462203    0.390016    0.075017    0.027154    0.659356    
#> 204: 0.392302    1.040616    3.464304    0.392160    0.076026    0.026642    0.657298    
#> 205: 0.394656    1.046096    3.465099    0.389613    0.077069    0.026664    0.659993    
#> 206: 0.399138    1.049957    3.467211    0.395293    0.077980    0.026412    0.660543    
#> 207: 0.402693    1.050687    3.467840    0.396502    0.080165    0.026153    0.657692    
#> 208: 0.405617    1.050917    3.467180    0.396200    0.079877    0.026190    0.654893    
#> 209: 0.409969    1.047165    3.467184    0.396806    0.079050    0.026043    0.653887    
#> 210: 0.411478    1.043770    3.468882    0.389754    0.079181    0.026167    0.653514    
#> 211: 0.414641    1.043845    3.470302    0.386880    0.078797    0.026192    0.653271    
#> 212: 0.418538    1.041881    3.471688    0.386469    0.078594    0.026291    0.652974    
#> 213: 0.421719    1.039775    3.473394    0.384473    0.079152    0.026274    0.652376    
#> 214: 0.425791    1.038100    3.475040    0.390025    0.079642    0.026347    0.652179    
#> 215: 0.427263    1.036638    3.476208    0.388894    0.080336    0.026342    0.652359    
#> 216: 0.429675    1.035706    3.476850    0.389107    0.080436    0.026204    0.653477    
#> 217: 0.429517    1.035907    3.477063    0.388986    0.079815    0.026243    0.652407    
#> 218: 0.430614    1.035360    3.476984    0.390641    0.080009    0.026498    0.651922    
#> 219: 0.429770    1.035136    3.476765    0.387112    0.080545    0.026676    0.651994    
#> 220: 0.428307    1.035632    3.476494    0.385615    0.080670    0.026826    0.652821    
#> 221: 0.427214    1.036256    3.476297    0.384314    0.080691    0.026795    0.652863    
#> 222: 0.428103    1.036667    3.475969    0.386281    0.080475    0.026801    0.652916    
#> 223: 0.429477    1.036659    3.475814    0.387023    0.080355    0.026807    0.652535    
#> 224: 0.431941    1.037105    3.476206    0.389308    0.080039    0.026984    0.652181    
#> 225: 0.432232    1.035965    3.476686    0.387316    0.079700    0.027456    0.652011    
#> 226: 0.432498    1.035003    3.476720    0.387242    0.079180    0.027695    0.651481    
#> 227: 0.431670    1.034432    3.476810    0.385047    0.078996    0.027784    0.650838    
#> 228: 0.430061    1.034420    3.476369    0.382505    0.078607    0.027896    0.650555    
#> 229: 0.429787    1.034060    3.476094    0.381416    0.078290    0.027892    0.650242    
#> 230: 0.429753    1.033691    3.476057    0.379981    0.077980    0.027859    0.650524    
#> 231: 0.430407    1.034375    3.476019    0.380126    0.077978    0.027768    0.650395    
#> 232: 0.429250    1.035176    3.475843    0.378879    0.077806    0.027782    0.650317    
#> 233: 0.428066    1.035033    3.475760    0.378761    0.078033    0.027841    0.650015    
#> 234: 0.426364    1.035075    3.475710    0.377659    0.077899    0.027899    0.650416    
#> 235: 0.425574    1.035494    3.475372    0.376862    0.078046    0.027750    0.650583    
#> 236: 0.424668    1.036276    3.475013    0.375483    0.078389    0.027700    0.650816    
#> 237: 0.423813    1.036447    3.474907    0.374889    0.078436    0.027794    0.651359    
#> 238: 0.423343    1.036423    3.474750    0.373650    0.078529    0.027846    0.652233    
#> 239: 0.422508    1.037345    3.474345    0.372611    0.078717    0.027860    0.652220    
#> 240: 0.421688    1.037404    3.474309    0.371554    0.078910    0.027731    0.652023    
#> 241: 0.421710    1.036650    3.474370    0.370764    0.079112    0.027660    0.651974    
#> 242: 0.421692    1.035931    3.474460    0.371231    0.079472    0.027570    0.652284    
#> 243: 0.421612    1.036267    3.474404    0.370850    0.079767    0.027547    0.652553    
#> 244: 0.421448    1.036829    3.474488    0.370639    0.079964    0.027552    0.652757    
#> 245: 0.421184    1.036638    3.474530    0.371110    0.080104    0.027618    0.653123    
#> 246: 0.421805    1.036539    3.474376    0.371441    0.079781    0.027661    0.653201    
#> 247: 0.421368    1.036707    3.474221    0.371477    0.079768    0.027714    0.653303    
#> 248: 0.421335    1.037201    3.474174    0.371704    0.080002    0.027666    0.653121    
#> 249: 0.420747    1.037275    3.474116    0.371149    0.080033    0.027688    0.652855    
#> 250: 0.421276    1.037537    3.474195    0.371906    0.079759    0.027657    0.652595    
#> 251: 0.422196    1.037734    3.474471    0.372739    0.079614    0.027660    0.652575    
#> 252: 0.423234    1.037389    3.475005    0.372737    0.079592    0.027731    0.652656    
#> 253: 0.423598    1.037372    3.475061    0.373024    0.079644    0.027741    0.652751    
#> 254: 0.424289    1.037516    3.475235    0.374297    0.079524    0.027795    0.652973    
#> 255: 0.424922    1.037805    3.475286    0.375949    0.079598    0.027840    0.652676    
#> 256: 0.425371    1.037982    3.475169    0.376658    0.079631    0.027905    0.652641    
#> 257: 0.425137    1.037706    3.475023    0.376892    0.079334    0.027977    0.652631    
#> 258: 0.424499    1.037200    3.474978    0.377181    0.079230    0.027998    0.652535    
#> 259: 0.423981    1.037034    3.474819    0.377008    0.079069    0.028075    0.652447    
#> 260: 0.423577    1.037134    3.474751    0.376851    0.078902    0.028131    0.652217    
#> 261: 0.423510    1.037038    3.474960    0.376968    0.078796    0.028217    0.652045    
#> 262: 0.423456    1.037473    3.474973    0.376407    0.078741    0.028280    0.652016    
#> 263: 0.423541    1.037839    3.474980    0.376034    0.078946    0.028268    0.651908    
#> 264: 0.423730    1.038132    3.475009    0.376557    0.079121    0.028213    0.651997    
#> 265: 0.424003    1.038650    3.474915    0.377213    0.079328    0.028150    0.652255    
#> 266: 0.423917    1.038967    3.474691    0.377858    0.079130    0.028134    0.652139    
#> 267: 0.424234    1.038716    3.474787    0.378529    0.078979    0.028155    0.652287    
#> 268: 0.424422    1.038432    3.474697    0.379785    0.079074    0.028101    0.652213    
#> 269: 0.425257    1.038235    3.474803    0.380770    0.079107    0.028053    0.652330    
#> 270: 0.425481    1.038371    3.474778    0.382135    0.079208    0.027960    0.652069    
#> 271: 0.425354    1.038302    3.474646    0.382223    0.079328    0.027851    0.652227    
#> 272: 0.425179    1.038100    3.474564    0.382875    0.079387    0.027880    0.652479    
#> 273: 0.424572    1.038270    3.474493    0.382781    0.079445    0.027861    0.652670    
#> 274: 0.424350    1.038620    3.474533    0.381502    0.079577    0.027852    0.652739    
#> 275: 0.424250    1.038960    3.474383    0.381212    0.079448    0.027881    0.652734    
#> 276: 0.423753    1.039222    3.474434    0.380173    0.079323    0.027983    0.652710    
#> 277: 0.423078    1.039483    3.474365    0.379554    0.079257    0.028073    0.652663    
#> 278: 0.422514    1.039810    3.474315    0.379248    0.079374    0.028077    0.652783    
#> 279: 0.422303    1.039792    3.474203    0.379772    0.079357    0.028130    0.652926    
#> 280: 0.421886    1.040109    3.474198    0.379683    0.079270    0.028172    0.652865    
#> 281: 0.421374    1.040211    3.474088    0.379853    0.079106    0.028223    0.652815    
#> 282: 0.421069    1.040482    3.474028    0.380777    0.078893    0.028235    0.653023    
#> 283: 0.420863    1.040777    3.473929    0.381021    0.078776    0.028266    0.653194    
#> 284: 0.420321    1.040804    3.473817    0.381137    0.078764    0.028279    0.653152    
#> 285: 0.419952    1.041183    3.473509    0.381131    0.078853    0.028312    0.653296    
#> 286: 0.419467    1.041513    3.473194    0.381191    0.078586    0.028320    0.653472    
#> 287: 0.419183    1.041914    3.473026    0.380858    0.078673    0.028334    0.653456    
#> 288: 0.419120    1.041966    3.473022    0.380743    0.078754    0.028318    0.653754    
#> 289: 0.419225    1.042033    3.472966    0.380107    0.078716    0.028278    0.654068    
#> 290: 0.419820    1.041907    3.473055    0.379984    0.078847    0.028291    0.654159    
#> 291: 0.420040    1.041853    3.473183    0.380092    0.078759    0.028298    0.654212    
#> 292: 0.419837    1.041803    3.473328    0.380245    0.078663    0.028327    0.654354    
#> 293: 0.419854    1.041772    3.473373    0.380128    0.078632    0.028352    0.654374    
#> 294: 0.420004    1.041804    3.473336    0.379925    0.078593    0.028342    0.654206    
#> 295: 0.420428    1.041569    3.473373    0.379998    0.078571    0.028343    0.654107    
#> 296: 0.420485    1.041364    3.473413    0.379557    0.078549    0.028379    0.654207    
#> 297: 0.420423    1.041367    3.473390    0.379527    0.078548    0.028400    0.654172    
#> 298: 0.420143    1.041286    3.473240    0.379299    0.078636    0.028385    0.654030    
#> 299: 0.419946    1.041426    3.473070    0.379654    0.078611    0.028384    0.653854    
#> 300: 0.420100    1.041392    3.473051    0.379934    0.078522    0.028397    0.653725    
#> 301: 0.420075    1.041399    3.472903    0.379787    0.078436    0.028378    0.653794    
#> 302: 0.420197    1.041482    3.472871    0.379546    0.078447    0.028339    0.653590    
#> 303: 0.419722    1.041655    3.472662    0.379379    0.078578    0.028298    0.653417    
#> 304: 0.419377    1.041945    3.472394    0.379742    0.078731    0.028248    0.653434    
#> 305: 0.419066    1.041983    3.472116    0.380428    0.078704    0.028237    0.653492    
#> 306: 0.418361    1.042052    3.471817    0.380734    0.078742    0.028201    0.653373    
#> 307: 0.417670    1.042167    3.471584    0.380560    0.078751    0.028156    0.653434    
#> 308: 0.417192    1.042225    3.471421    0.380877    0.078841    0.028118    0.653492    
#> 309: 0.416808    1.042021    3.471330    0.381003    0.078894    0.028124    0.653626    
#> 310: 0.416794    1.042005    3.471184    0.381037    0.078770    0.028131    0.653694    
#> 311: 0.416867    1.042057    3.471179    0.380954    0.078654    0.028108    0.653690    
#> 312: 0.416903    1.042062    3.471120    0.381695    0.078569    0.028091    0.653879    
#> 313: 0.416857    1.041941    3.471100    0.381722    0.078575    0.028117    0.653933    
#> 314: 0.416491    1.042134    3.470906    0.382121    0.078557    0.028156    0.653862    
#> 315: 0.415993    1.042411    3.470687    0.382305    0.078610    0.028163    0.653744    
#> 316: 0.415629    1.042648    3.470408    0.383902    0.078549    0.028186    0.653591    
#> 317: 0.415619    1.042801    3.470276    0.384805    0.078523    0.028222    0.653490    
#> 318: 0.415399    1.042903    3.470076    0.384820    0.078523    0.028196    0.653288    
#> 319: 0.415271    1.043053    3.469962    0.384693    0.078471    0.028153    0.653277    
#> 320: 0.414688    1.043179    3.469767    0.384542    0.078442    0.028111    0.653280    
#> 321: 0.414240    1.043208    3.469570    0.384285    0.078443    0.028080    0.653301    
#> 322: 0.414097    1.043237    3.469455    0.384662    0.078447    0.028084    0.653210    
#> 323: 0.413780    1.043190    3.469429    0.385094    0.078371    0.028084    0.653184    
#> 324: 0.413804    1.043286    3.469469    0.385576    0.078400    0.028106    0.653040    
#> 325: 0.413798    1.043414    3.469305    0.386285    0.078336    0.028084    0.653010    
#> 326: 0.413567    1.043362    3.469214    0.386384    0.078282    0.028058    0.652873    
#> 327: 0.413571    1.043434    3.469211    0.386873    0.078184    0.028006    0.652848    
#> 328: 0.414054    1.043488    3.469253    0.387124    0.078200    0.027980    0.652787    
#> 329: 0.414354    1.043446    3.469363    0.387198    0.078240    0.027969    0.652853    
#> 330: 0.414127    1.043350    3.469423    0.387383    0.078204    0.027937    0.652820    
#> 331: 0.414163    1.043519    3.469412    0.387345    0.078227    0.027925    0.652807    
#> 332: 0.414000    1.043501    3.469417    0.387470    0.078392    0.027895    0.652754    
#> 333: 0.413742    1.043585    3.469254    0.387555    0.078491    0.027875    0.652706    
#> 334: 0.413461    1.043572    3.469046    0.387614    0.078657    0.027869    0.652748    
#> 335: 0.413125    1.043716    3.468809    0.387974    0.078780    0.027837    0.652771    
#> 336: 0.412822    1.043956    3.468680    0.388375    0.078903    0.027799    0.652797    
#> 337: 0.412638    1.044319    3.468481    0.389026    0.078949    0.027774    0.652839    
#> 338: 0.412447    1.044445    3.468351    0.389663    0.078947    0.027769    0.652860    
#> 339: 0.412252    1.044520    3.468244    0.390210    0.078991    0.027774    0.652812    
#> 340: 0.412320    1.044187    3.468251    0.390754    0.078876    0.027786    0.652824    
#> 341: 0.412382    1.044175    3.468274    0.390935    0.078838    0.027813    0.652681    
#> 342: 0.412419    1.044080    3.468311    0.390982    0.078824    0.027808    0.652640    
#> 343: 0.412338    1.044127    3.468245    0.391290    0.078802    0.027832    0.652622    
#> 344: 0.412454    1.044036    3.468260    0.392208    0.078739    0.027879    0.652631    
#> 345: 0.412516    1.043965    3.468242    0.392403    0.078690    0.027930    0.652678    
#> 346: 0.412574    1.043914    3.468193    0.392710    0.078654    0.027941    0.652597    
#> 347: 0.412585    1.043886    3.468112    0.392880    0.078702    0.027953    0.652697    
#> 348: 0.412112    1.043996    3.467907    0.392806    0.078657    0.027964    0.652724    
#> 349: 0.411876    1.043873    3.467798    0.393156    0.078608    0.027959    0.652744    
#> 350: 0.411633    1.043831    3.467686    0.393131    0.078659    0.027938    0.652756    
#> 351: 0.411458    1.044081    3.467556    0.393143    0.078630    0.027930    0.652865    
#> 352: 0.410975    1.044200    3.467429    0.393266    0.078602    0.028016    0.652940    
#> 353: 0.410905    1.044472    3.467283    0.393832    0.078614    0.028076    0.653016    
#> 354: 0.410608    1.044581    3.467112    0.393912    0.078676    0.028131    0.653097    
#> 355: 0.410732    1.044496    3.467005    0.393849    0.078755    0.028183    0.653110    
#> 356: 0.410483    1.044440    3.466955    0.393528    0.078759    0.028183    0.653268    
#> 357: 0.410559    1.044453    3.467000    0.393641    0.078713    0.028174    0.653225    
#> 358: 0.410539    1.044386    3.467013    0.393407    0.078754    0.028187    0.653197    
#> 359: 0.410469    1.044449    3.466980    0.393278    0.078725    0.028239    0.653077    
#> 360: 0.410229    1.044467    3.466918    0.392841    0.078653    0.028261    0.653014    
#> 361: 0.410045    1.044465    3.466920    0.392692    0.078577    0.028277    0.652964    
#> 362: 0.410118    1.044509    3.466876    0.392740    0.078561    0.028267    0.652871    
#> 363: 0.410028    1.044535    3.466830    0.392997    0.078619    0.028236    0.652716    
#> 364: 0.409993    1.044606    3.466770    0.393157    0.078731    0.028212    0.652702    
#> 365: 0.409794    1.044608    3.466694    0.393286    0.078859    0.028195    0.652677    
#> 366: 0.409449    1.044752    3.466503    0.392953    0.078884    0.028175    0.652737    
#> 367: 0.409241    1.044962    3.466349    0.392516    0.078917    0.028144    0.652764    
#> 368: 0.409256    1.045046    3.466287    0.392282    0.078884    0.028119    0.652719    
#> 369: 0.409204    1.045098    3.466248    0.392242    0.078819    0.028142    0.652661    
#> 370: 0.409031    1.045252    3.466181    0.392053    0.078779    0.028151    0.652601    
#> 371: 0.408801    1.045302    3.466149    0.391545    0.078722    0.028123    0.652528    
#> 372: 0.408651    1.045435    3.466111    0.391228    0.078724    0.028101    0.652484    
#> 373: 0.408289    1.045626    3.465951    0.390950    0.078764    0.028120    0.652459    
#> 374: 0.408310    1.045728    3.465913    0.390721    0.078741    0.028133    0.652453    
#> 375: 0.408360    1.045865    3.465873    0.390688    0.078709    0.028140    0.652445    
#> 376: 0.408363    1.045893    3.465870    0.390376    0.078696    0.028136    0.652422    
#> 377: 0.408235    1.046011    3.465880    0.390047    0.078674    0.028096    0.652438    
#> 378: 0.408089    1.045931    3.465934    0.389975    0.078634    0.028088    0.652455    
#> 379: 0.408012    1.045698    3.465988    0.389825    0.078588    0.028087    0.652481    
#> 380: 0.407763    1.045605    3.466053    0.389714    0.078604    0.028098    0.652522    
#> 381: 0.407343    1.045624    3.465949    0.389595    0.078627    0.028121    0.652543    
#> 382: 0.407097    1.045662    3.465871    0.389492    0.078596    0.028110    0.652478    
#> 383: 0.406957    1.045752    3.465807    0.389729    0.078602    0.028093    0.652320    
#> 384: 0.406743    1.045754    3.465792    0.389492    0.078624    0.028098    0.652246    
#> 385: 0.406814    1.045760    3.465795    0.389685    0.078653    0.028079    0.652133    
#> 386: 0.406907    1.045863    3.465830    0.389629    0.078721    0.028068    0.652131    
#> 387: 0.406842    1.045976    3.465874    0.389609    0.078682    0.028067    0.652128    
#> 388: 0.406640    1.046044    3.465870    0.389516    0.078767    0.028030    0.652128    
#> 389: 0.406455    1.045964    3.465812    0.389245    0.078809    0.028001    0.652174    
#> 390: 0.406222    1.046031    3.465785    0.388911    0.078773    0.027986    0.652133    
#> 391: 0.406375    1.046044    3.465754    0.388785    0.078743    0.027979    0.652052    
#> 392: 0.406601    1.046037    3.465832    0.388869    0.078736    0.027967    0.651999    
#> 393: 0.406623    1.045965    3.465824    0.388810    0.078802    0.027942    0.651962    
#> 394: 0.406721    1.045958    3.465814    0.388756    0.078871    0.027900    0.651954    
#> 395: 0.406736    1.046013    3.465790    0.388748    0.078954    0.027874    0.651971    
#> 396: 0.406858    1.046042    3.465811    0.389195    0.079033    0.027846    0.651872    
#> 397: 0.406837    1.046028    3.465805    0.389245    0.079064    0.027819    0.651830    
#> 398: 0.406775    1.045941    3.465808    0.388944    0.079101    0.027796    0.651848    
#> 399: 0.406909    1.045932    3.465872    0.388827    0.079122    0.027767    0.651800    
#> 400: 0.407125    1.045946    3.465907    0.388841    0.079165    0.027735    0.651754    
#> 401: 0.407232    1.045998    3.465896    0.388573    0.079245    0.027688    0.651837    
#> 402: 0.407223    1.046074    3.465897    0.388283    0.079354    0.027641    0.651917    
#> 403: 0.407364    1.046115    3.465923    0.388261    0.079385    0.027599    0.651914    
#> 404: 0.407396    1.046109    3.465910    0.388135    0.079439    0.027568    0.651936    
#> 405: 0.407414    1.046043    3.465948    0.387783    0.079527    0.027547    0.652025    
#> 406: 0.407373    1.046005    3.465942    0.387437    0.079565    0.027548    0.652136    
#> 407: 0.407329    1.046018    3.465996    0.387277    0.079639    0.027543    0.652208    
#> 408: 0.407331    1.046075    3.465997    0.386895    0.079743    0.027520    0.652300    
#> 409: 0.407157    1.046005    3.465946    0.386504    0.079758    0.027524    0.652327    
#> 410: 0.407015    1.045976    3.465894    0.386335    0.079731    0.027548    0.652307    
#> 411: 0.407067    1.045823    3.465900    0.386459    0.079645    0.027561    0.652387    
#> 412: 0.407020    1.045913    3.465880    0.386023    0.079665    0.027563    0.652377    
#> 413: 0.406899    1.046019    3.465845    0.385815    0.079676    0.027569    0.652477    
#> 414: 0.406750    1.046162    3.465845    0.385919    0.079732    0.027569    0.652488    
#> 415: 0.407066    1.046214    3.465846    0.386216    0.079778    0.027565    0.652571    
#> 416: 0.407188    1.046242    3.465873    0.386149    0.079852    0.027552    0.652653    
#> 417: 0.407340    1.046230    3.465885    0.386461    0.079859    0.027544    0.652599    
#> 418: 0.407167    1.046174    3.465920    0.386262    0.079840    0.027546    0.652513    
#> 419: 0.407166    1.046238    3.465952    0.386068    0.079834    0.027553    0.652418    
#> 420: 0.407208    1.046207    3.465979    0.386092    0.079810    0.027559    0.652279    
#> 421: 0.407206    1.046171    3.466004    0.385970    0.079802    0.027558    0.652229    
#> 422: 0.407269    1.046118    3.465992    0.386135    0.079778    0.027538    0.652225    
#> 423: 0.407345    1.046045    3.466022    0.385916    0.079759    0.027542    0.652227    
#> 424: 0.407313    1.046023    3.466013    0.385655    0.079690    0.027531    0.652252    
#> 425: 0.407317    1.046076    3.466011    0.385501    0.079674    0.027526    0.652290    
#> 426: 0.407396    1.046124    3.466026    0.385553    0.079688    0.027515    0.652220    
#> 427: 0.407384    1.046078    3.466059    0.385823    0.079684    0.027521    0.652175    
#> 428: 0.407215    1.046164    3.466033    0.385537    0.079726    0.027506    0.652159    
#> 429: 0.407155    1.046229    3.466023    0.385365    0.079679    0.027499    0.652124    
#> 430: 0.407085    1.046240    3.465991    0.385374    0.079688    0.027505    0.652124    
#> 431: 0.406993    1.046307    3.465917    0.385426    0.079669    0.027516    0.652075    
#> 432: 0.406690    1.046405    3.465858    0.385438    0.079649    0.027537    0.652066    
#> 433: 0.406483    1.046552    3.465797    0.385265    0.079685    0.027531    0.652068    
#> 434: 0.406388    1.046462    3.465770    0.385100    0.079686    0.027551    0.652011    
#> 435: 0.406405    1.046468    3.465755    0.384942    0.079631    0.027565    0.651987    
#> 436: 0.406493    1.046392    3.465833    0.384973    0.079548    0.027575    0.651986    
#> 437: 0.406614    1.046306    3.465861    0.384990    0.079507    0.027585    0.651902    
#> 438: 0.406522    1.046384    3.465862    0.384932    0.079480    0.027592    0.651821    
#> 439: 0.406379    1.046439    3.465833    0.384796    0.079471    0.027618    0.651719    
#> 440: 0.406349    1.046474    3.465857    0.384613    0.079399    0.027644    0.651786    
#> 441: 0.406533    1.046409    3.465885    0.384858    0.079372    0.027673    0.651681    
#> 442: 0.406577    1.046394    3.465924    0.384982    0.079338    0.027726    0.651573    
#> 443: 0.406470    1.046468    3.465848    0.385134    0.079331    0.027744    0.651532    
#> 444: 0.406204    1.046579    3.465722    0.385147    0.079323    0.027759    0.651475    
#> 445: 0.406000    1.046681    3.465622    0.385499    0.079296    0.027771    0.651477    
#> 446: 0.405834    1.046806    3.465537    0.385724    0.079274    0.027771    0.651464    
#> 447: 0.405988    1.046923    3.465532    0.385875    0.079262    0.027766    0.651432    
#> 448: 0.405927    1.046941    3.465508    0.385675    0.079243    0.027745    0.651432    
#> 449: 0.406049    1.047057    3.465587    0.385486    0.079294    0.027722    0.651478    
#> 450: 0.406006    1.047094    3.465585    0.385345    0.079361    0.027698    0.651550    
#> 451: 0.405948    1.047101    3.465547    0.385306    0.079466    0.027690    0.651603    
#> 452: 0.405850    1.047129    3.465504    0.385111    0.079519    0.027664    0.651624    
#> 453: 0.405675    1.047147    3.465461    0.384771    0.079483    0.027666    0.651617    
#> 454: 0.405429    1.047332    3.465381    0.384642    0.079461    0.027658    0.651595    
#> 455: 0.405404    1.047459    3.465312    0.384863    0.079473    0.027660    0.651553    
#> 456: 0.405224    1.047483    3.465225    0.385276    0.079502    0.027656    0.651588    
#> 457: 0.405216    1.047489    3.465177    0.385741    0.079500    0.027664    0.651577    
#> 458: 0.405105    1.047656    3.465145    0.386008    0.079501    0.027684    0.651580    
#> 459: 0.404859    1.047822    3.465119    0.385975    0.079586    0.027700    0.651632    
#> 460: 0.404689    1.047945    3.465021    0.386050    0.079581    0.027734    0.651595    
#> 461: 0.404551    1.048053    3.464976    0.386018    0.079573    0.027738    0.651525    
#> 462: 0.404309    1.048137    3.464928    0.385955    0.079567    0.027740    0.651477    
#> 463: 0.404342    1.048195    3.464950    0.385917    0.079523    0.027738    0.651464    
#> 464: 0.404417    1.048275    3.464949    0.385709    0.079554    0.027727    0.651389    
#> 465: 0.404439    1.048185    3.464958    0.385559    0.079609    0.027707    0.651330    
#> 466: 0.404332    1.048238    3.464877    0.385371    0.079590    0.027703    0.651302    
#> 467: 0.404036    1.048229    3.464819    0.385413    0.079570    0.027693    0.651235    
#> 468: 0.404093    1.048287    3.464824    0.385570    0.079592    0.027698    0.651125    
#> 469: 0.404128    1.048427    3.464807    0.385789    0.079640    0.027690    0.651085    
#> 470: 0.404030    1.048504    3.464770    0.385823    0.079651    0.027670    0.651084    
#> 471: 0.403912    1.048476    3.464750    0.385837    0.079669    0.027645    0.651060    
#> 472: 0.403921    1.048492    3.464726    0.385913    0.079676    0.027633    0.651105    
#> 473: 0.403786    1.048489    3.464689    0.385817    0.079683    0.027618    0.651094    
#> 474: 0.403626    1.048438    3.464644    0.385578    0.079690    0.027625    0.651148    
#> 475: 0.403655    1.048482    3.464639    0.385326    0.079685    0.027642    0.651108    
#> 476: 0.403659    1.048501    3.464597    0.385231    0.079704    0.027662    0.651123    
#> 477: 0.403594    1.048527    3.464597    0.385213    0.079695    0.027686    0.651063    
#> 478: 0.403535    1.048522    3.464608    0.385247    0.079748    0.027701    0.651098    
#> 479: 0.403692    1.048597    3.464606    0.385646    0.079756    0.027714    0.651106    
#> 480: 0.403718    1.048628    3.464593    0.385830    0.079744    0.027734    0.651095    
#> 481: 0.403737    1.048586    3.464559    0.385951    0.079717    0.027756    0.651040    
#> 482: 0.403795    1.048597    3.464517    0.386077    0.079738    0.027780    0.651041    
#> 483: 0.403654    1.048607    3.464489    0.386089    0.079724    0.027802    0.651010    
#> 484: 0.403598    1.048499    3.464480    0.386213    0.079690    0.027828    0.651008    
#> 485: 0.403475    1.048569    3.464435    0.386429    0.079704    0.027854    0.651061    
#> 486: 0.403386    1.048624    3.464424    0.386602    0.079665    0.027873    0.650993    
#> 487: 0.403541    1.048685    3.464440    0.386848    0.079630    0.027886    0.650971    
#> 488: 0.403484    1.048727    3.464428    0.387085    0.079635    0.027904    0.650890    
#> 489: 0.403668    1.048772    3.464384    0.387440    0.079684    0.027932    0.650877    
#> 490: 0.403704    1.048785    3.464394    0.387523    0.079676    0.027942    0.650846    
#> 491: 0.403677    1.048802    3.464413    0.387327    0.079655    0.027946    0.650789    
#> 492: 0.403661    1.048848    3.464401    0.387136    0.079647    0.027948    0.650861    
#> 493: 0.403603    1.048905    3.464440    0.386817    0.079649    0.027967    0.650943    
#> 494: 0.403662    1.048903    3.464440    0.386591    0.079597    0.027977    0.650945    
#> 495: 0.403735    1.048915    3.464416    0.386870    0.079560    0.027985    0.650933    
#> 496: 0.403791    1.048981    3.464378    0.386877    0.079555    0.027993    0.650948    
#> 497: 0.403948    1.048968    3.464410    0.386950    0.079554    0.027988    0.651020    
#> 498: 0.403981    1.048943    3.464407    0.386928    0.079552    0.028000    0.651025    
#> 499: 0.404032    1.048966    3.464380    0.386988    0.079580    0.028003    0.650954    
#> 500: 0.404091    1.048940    3.464356    0.387205    0.079551    0.028003    0.650911    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.275091    0.969915    3.445814    0.392401    0.075363    0.016800    1.480434    
#> 002: 0.259159    0.984807    3.471664    0.372781    0.071595    0.015960    0.922085    
#> 003: 0.385651    0.943064    3.486683    0.354142    0.070912    0.015162    0.718339    
#> 004: 0.337815    0.954659    3.476391    0.336435    0.074633    0.014404    0.602210    
#> 005: 0.341461    0.961674    3.471336    0.319613    0.073469    0.013684    0.543858    
#> 006: 0.321872    0.968317    3.457272    0.303633    0.071191    0.013000    0.516287    
#> 007: 0.278478    0.972321    3.453355    0.288451    0.067631    0.012350    0.517084    
#> 008: 0.273059    0.972454    3.448448    0.274029    0.067271    0.011830    0.512715    
#> 009: 0.269358    0.966184    3.451756    0.260327    0.063908    0.014542    0.509554    
#> 010: 0.268282    0.981846    3.444442    0.247311    0.060713    0.014630    0.506675    
#> 011: 0.326877    0.980650    3.455037    0.249979    0.060123    0.017123    0.506276    
#> 012: 0.311190    0.974611    3.455448    0.260100    0.057906    0.016267    0.489641    
#> 013: 0.295999    0.974380    3.452335    0.247095    0.057398    0.015454    0.495175    
#> 014: 0.318921    0.980059    3.459633    0.268292    0.054529    0.018206    0.488786    
#> 015: 0.332856    0.981690    3.453369    0.278432    0.051802    0.017296    0.479989    
#> 016: 0.301610    0.998986    3.448184    0.268210    0.049212    0.016750    0.486597    
#> 017: 0.300686    1.000010    3.455122    0.254799    0.046751    0.018638    0.481284    
#> 018: 0.308885    0.997007    3.447534    0.242351    0.044414    0.019572    0.486493    
#> 019: 0.277839    1.000398    3.445679    0.257628    0.042193    0.018594    0.477489    
#> 020: 0.303536    0.997677    3.446855    0.254676    0.050069    0.017664    0.479308    
#> 021: 0.309072    0.989916    3.459577    0.241942    0.049548    0.016781    0.477378    
#> 022: 0.284994    0.979977    3.457414    0.261624    0.047325    0.017343    0.476711    
#> 023: 0.354918    0.984503    3.468320    0.290191    0.044959    0.018005    0.491027    
#> 024: 0.330350    0.992394    3.464545    0.282562    0.042711    0.017105    0.480371    
#> 025: 0.321754    0.981387    3.457304    0.273800    0.040576    0.018103    0.486254    
#> 026: 0.319439    0.997923    3.453563    0.273378    0.038915    0.017198    0.484027    
#> 027: 0.308482    0.996256    3.449329    0.259709    0.044452    0.017884    0.497530    
#> 028: 0.334922    0.980797    3.463900    0.253952    0.042229    0.019247    0.472775    
#> 029: 0.336316    0.982882    3.458347    0.243700    0.041984    0.018284    0.477532    
#> 030: 0.343178    0.987318    3.459132    0.253003    0.041910    0.017370    0.472784    
#> 031: 0.315809    0.973386    3.461257    0.240353    0.049467    0.016502    0.470681    
#> 032: 0.303088    0.974155    3.465484    0.228335    0.046993    0.015677    0.476754    
#> 033: 0.282158    0.978979    3.455199    0.255081    0.046547    0.015856    0.487037    
#> 034: 0.298815    0.991868    3.450123    0.286975    0.052735    0.015063    0.480176    
#> 035: 0.293395    0.977589    3.451277    0.272626    0.050099    0.015748    0.468519    
#> 036: 0.299446    0.984412    3.456489    0.258995    0.047594    0.018386    0.466770    
#> 037: 0.314179    0.984805    3.457104    0.264783    0.053084    0.018880    0.480575    
#> 038: 0.298714    0.986145    3.450922    0.263591    0.053078    0.019340    0.475383    
#> 039: 0.312225    0.988069    3.454015    0.283591    0.050424    0.019941    0.461344    
#> 040: 0.308138    0.981433    3.462406    0.271506    0.047903    0.020552    0.478778    
#> 041: 0.293833    0.969935    3.455023    0.257930    0.045508    0.025934    0.484562    
#> 042: 0.295800    0.977259    3.451402    0.245034    0.043232    0.024637    0.469553    
#> 043: 0.286108    1.001451    3.442982    0.252428    0.041553    0.023406    0.471966    
#> 044: 0.272427    1.002026    3.439693    0.245741    0.044116    0.022235    0.489167    
#> 045: 0.292787    1.010099    3.434128    0.296656    0.041910    0.021944    0.473947    
#> 046: 0.285743    1.003225    3.436350    0.306030    0.048652    0.022635    0.472002    
#> 047: 0.280676    0.997771    3.446006    0.290729    0.046220    0.021504    0.468660    
#> 048: 0.324186    0.991995    3.453462    0.331527    0.043909    0.023998    0.478135    
#> 049: 0.324610    0.991184    3.454917    0.314951    0.050262    0.022799    0.469799    
#> 050: 0.321160    0.969092    3.457050    0.301061    0.047749    0.021659    0.477143    
#> 051: 0.311270    0.973300    3.452240    0.286008    0.054652    0.020576    0.488961    
#> 052: 0.322155    0.965963    3.465430    0.271707    0.051919    0.019547    0.487091    
#> 053: 0.313902    0.964167    3.453033    0.276977    0.049323    0.018570    0.483609    
#> 054: 0.271526    0.980571    3.448312    0.263128    0.046857    0.018866    0.492248    
#> 055: 0.274700    0.983329    3.449518    0.249972    0.044514    0.018516    0.485209    
#> 056: 0.303989    0.979765    3.449443    0.266314    0.042288    0.019608    0.488746    
#> 057: 0.290707    0.977494    3.454714    0.266603    0.040264    0.019283    0.477869    
#> 058: 0.288063    0.986297    3.439058    0.284650    0.050363    0.018319    0.479786    
#> 059: 0.260434    0.986168    3.435477    0.270417    0.047844    0.018142    0.494415    
#> 060: 0.277729    0.974665    3.450337    0.271460    0.045452    0.017422    0.486132    
#> 061: 0.320308    0.982757    3.458269    0.291425    0.043180    0.019157    0.491554    
#> 062: 0.321298    0.980687    3.466095    0.278071    0.048520    0.021874    0.496719    
#> 063: 0.332558    0.962903    3.461886    0.287519    0.058127    0.020780    0.498217    
#> 064: 0.335040    0.961641    3.460377    0.273143    0.055221    0.019741    0.488823    
#> 065: 0.335047    0.981541    3.458806    0.263767    0.052459    0.018754    0.472730    
#> 066: 0.322527    0.988561    3.464164    0.250579    0.053214    0.017816    0.469772    
#> 067: 0.314643    0.971423    3.464049    0.238050    0.050553    0.018331    0.473155    
#> 068: 0.305036    0.970616    3.467357    0.226147    0.048025    0.017975    0.483194    
#> 069: 0.318502    0.969498    3.468929    0.223153    0.045624    0.021507    0.488061    
#> 070: 0.337938    0.976622    3.471519    0.236334    0.043343    0.020432    0.488102    
#> 071: 0.303398    0.977824    3.455056    0.233196    0.041984    0.021323    0.494015    
#> 072: 0.289795    0.972878    3.452652    0.245063    0.041758    0.025338    0.481541    
#> 073: 0.277950    0.979142    3.458995    0.244485    0.043349    0.024072    0.474817    
#> 074: 0.298470    0.975206    3.449107    0.232261    0.041181    0.022868    0.478732    
#> 075: 0.304966    0.983886    3.461221    0.258030    0.049853    0.023059    0.483707    
#> 076: 0.326901    1.002492    3.462906    0.281807    0.047361    0.024287    0.480217    
#> 077: 0.344115    0.980727    3.465105    0.281941    0.044993    0.023137    0.479713    
#> 078: 0.318621    0.978216    3.462366    0.285103    0.042743    0.021980    0.470113    
#> 079: 0.311428    0.980548    3.447979    0.308025    0.040606    0.020881    0.483432    
#> 080: 0.308660    0.988758    3.455470    0.294068    0.039042    0.022681    0.486053    
#> 081: 0.293751    0.987300    3.448569    0.306569    0.037760    0.023528    0.474054    
#> 082: 0.283099    0.985246    3.444740    0.291241    0.036100    0.024584    0.480491    
#> 083: 0.294593    1.002290    3.442582    0.303318    0.037120    0.023355    0.471807    
#> 084: 0.290200    1.002546    3.442707    0.288152    0.035896    0.023387    0.477879    
#> 085: 0.277950    0.989246    3.452997    0.273744    0.034836    0.022218    0.480956    
#> 086: 0.289238    1.004766    3.443602    0.262598    0.042109    0.021670    0.473967    
#> 087: 0.272830    1.004351    3.440605    0.249796    0.045997    0.020587    0.482331    
#> 088: 0.230739    1.008736    3.433493    0.271071    0.045425    0.019829    0.484278    
#> 089: 0.251623    1.015543    3.427050    0.257517    0.043583    0.020205    0.481667    
#> 090: 0.275866    1.004999    3.444875    0.278684    0.045374    0.021273    0.485683    
#> 091: 0.296840    0.990373    3.444630    0.300362    0.043195    0.021242    0.494726    
#> 092: 0.294439    0.989069    3.436253    0.285344    0.041036    0.021155    0.492475    
#> 093: 0.260005    0.990166    3.439390    0.271076    0.041015    0.020735    0.499557    
#> 094: 0.292703    1.000961    3.444306    0.259071    0.048814    0.019698    0.503183    
#> 095: 0.304929    0.998196    3.458213    0.263118    0.046374    0.018713    0.496245    
#> 096: 0.274214    0.984001    3.450471    0.289819    0.044055    0.018712    0.490345    
#> 097: 0.280812    1.010724    3.435254    0.275328    0.046501    0.018379    0.475553    
#> 098: 0.284277    1.014765    3.444282    0.261562    0.045037    0.019559    0.478623    
#> 099: 0.267655    0.987279    3.435019    0.248484    0.042785    0.020660    0.485252    
#> 100: 0.281977    0.999380    3.442106    0.244890    0.040645    0.020962    0.470994    
#> 101: 0.268943    0.990354    3.437840    0.234543    0.039662    0.020393    0.473094    
#> 102: 0.272731    0.993845    3.433665    0.243851    0.038441    0.020986    0.484694    
#> 103: 0.285071    0.989754    3.444892    0.247639    0.036943    0.022100    0.478736    
#> 104: 0.279761    0.990509    3.454715    0.245736    0.045134    0.020995    0.496793    
#> 105: 0.317864    0.980459    3.454699    0.236572    0.042877    0.019946    0.491210    
#> 106: 0.332717    0.976535    3.462567    0.268078    0.040734    0.019720    0.476402    
#> 107: 0.341035    0.977089    3.460116    0.261213    0.038697    0.019463    0.489182    
#> 108: 0.309207    0.996586    3.458496    0.248152    0.043029    0.019298    0.489118    
#> 109: 0.320278    0.984608    3.473691    0.275754    0.046279    0.020797    0.488631    
#> 110: 0.352225    0.961158    3.467968    0.262964    0.043965    0.023316    0.475131    
#> 111: 0.342069    0.967068    3.469147    0.251433    0.042408    0.022150    0.467443    
#> 112: 0.312731    0.967925    3.456491    0.238861    0.044837    0.021042    0.483517    
#> 113: 0.290619    0.983835    3.458469    0.229746    0.042595    0.019990    0.476083    
#> 114: 0.300654    0.984715    3.450871    0.245451    0.047728    0.020119    0.479261    
#> 115: 0.310539    0.970572    3.450758    0.269706    0.045342    0.023280    0.483528    
#> 116: 0.323504    0.979758    3.449982    0.289353    0.043075    0.022116    0.482967    
#> 117: 0.294096    0.976910    3.454974    0.274885    0.041326    0.021011    0.491774    
#> 118: 0.327615    0.964241    3.461005    0.261141    0.039259    0.019960    0.482737    
#> 119: 0.306598    0.978526    3.457472    0.252329    0.037296    0.020839    0.486184    
#> 120: 0.289914    0.969572    3.455947    0.258301    0.039140    0.021182    0.477321    
#> 121: 0.323524    0.995156    3.460420    0.245386    0.040491    0.020682    0.488012    
#> 122: 0.311032    0.981807    3.461139    0.243091    0.043802    0.019648    0.479438    
#> 123: 0.345663    1.000139    3.459246    0.280039    0.046354    0.018666    0.471259    
#> 124: 0.320898    1.012129    3.456668    0.276128    0.044036    0.019483    0.485850    
#> 125: 0.347584    0.994763    3.452390    0.270293    0.053873    0.018509    0.481329    
#> 126: 0.317973    1.000069    3.451023    0.276939    0.051180    0.018269    0.480875    
#> 127: 0.317889    0.989366    3.449208    0.300367    0.049496    0.017356    0.488804    
#> 128: 0.301650    0.998333    3.459234    0.285349    0.047532    0.018485    0.494297    
#> 129: 0.313001    0.987552    3.459689    0.271082    0.045250    0.017561    0.487953    
#> 130: 0.338683    0.992490    3.450107    0.274564    0.051136    0.016683    0.475396    
#> 131: 0.304376    0.984268    3.443463    0.275065    0.049657    0.018285    0.467464    
#> 132: 0.261181    1.002525    3.425238    0.261312    0.051915    0.017561    0.473854    
#> 133: 0.267433    1.011900    3.430058    0.264263    0.049319    0.017965    0.475375    
#> 134: 0.288951    0.986395    3.447818    0.251050    0.046853    0.021822    0.474975    
#> 135: 0.286983    0.978410    3.448819    0.238497    0.044510    0.021777    0.483975    
#> 136: 0.306401    0.959019    3.462610    0.238974    0.042285    0.024458    0.477226    
#> 137: 0.334793    0.958042    3.465211    0.247984    0.047455    0.023235    0.488162    
#> 138: 0.319642    0.971558    3.461899    0.260995    0.050564    0.022073    0.486562    
#> 139: 0.318245    0.980777    3.473409    0.286071    0.048035    0.024615    0.481401    
#> 140: 0.348138    0.965845    3.471121    0.293738    0.046878    0.024036    0.489593    
#> 141: 0.341719    0.957706    3.477005    0.279051    0.044534    0.023638    0.483530    
#> 142: 0.325933    0.951207    3.472900    0.265098    0.042308    0.024186    0.496341    
#> 143: 0.319241    0.971031    3.461546    0.257437    0.042623    0.022976    0.498594    
#> 144: 0.327760    0.980241    3.463132    0.260367    0.040492    0.021827    0.471621    
#> 145: 0.299611    0.982140    3.456212    0.252191    0.038468    0.020736    0.481813    
#> 146: 0.269098    0.994651    3.449923    0.263709    0.043058    0.020594    0.488915    
#> 147: 0.272133    0.990486    3.440106    0.253987    0.044990    0.020023    0.479619    
#> 148: 0.253118    1.006506    3.447122    0.256705    0.042740    0.019639    0.477746    
#> 149: 0.269153    0.994559    3.439466    0.268606    0.045549    0.018657    0.481405    
#> 150: 0.304142    0.989186    3.436603    0.306555    0.044840    0.017942    0.479765    
#> 151: 0.260541    1.001099    3.440336    0.291227    0.042598    0.019338    0.475149    
#> 152: 0.282942    1.012658    3.440550    0.269086    0.037174    0.022029    0.468197    
#> 153: 0.283758    1.009677    3.445116    0.261025    0.037560    0.024927    0.478782    
#> 154: 0.285354    1.000396    3.442830    0.272997    0.036552    0.021891    0.478168    
#> 155: 0.260519    0.987609    3.439504    0.251071    0.036411    0.022930    0.472497    
#> 156: 0.282144    0.985785    3.443793    0.260166    0.035328    0.024296    0.488126    
#> 157: 0.285306    0.977002    3.447654    0.247002    0.033250    0.023050    0.489652    
#> 158: 0.307816    0.997562    3.449146    0.255717    0.033025    0.023882    0.483023    
#> 159: 0.273340    1.000967    3.445992    0.270134    0.039279    0.025169    0.475386    
#> 160: 0.298726    0.980902    3.448823    0.284232    0.041582    0.026079    0.470274    
#> 161: 0.299253    0.980649    3.453477    0.270674    0.029469    0.030804    0.479984    
#> 162: 0.283946    0.988001    3.454510    0.290592    0.029282    0.033955    0.483990    
#> 163: 0.287052    0.986042    3.448442    0.279108    0.029655    0.029972    0.482896    
#> 164: 0.309921    0.995774    3.446977    0.312251    0.025203    0.034942    0.474854    
#> 165: 0.305624    0.984913    3.448521    0.297293    0.027103    0.031502    0.468428    
#> 166: 0.321759    0.996881    3.453914    0.273501    0.026230    0.028645    0.474522    
#> 167: 0.315294    1.002872    3.457410    0.268451    0.033585    0.030520    0.476184    
#> 168: 0.300017    1.003536    3.445712    0.287645    0.031737    0.027839    0.467294    
#> 169: 0.311885    1.025573    3.444292    0.282571    0.034270    0.029123    0.486429    
#> 170: 0.287306    1.015772    3.444832    0.259754    0.034504    0.027336    0.476062    
#> 171: 0.269795    1.009422    3.439691    0.263400    0.030274    0.025103    0.461602    
#> 172: 0.272097    1.009508    3.439269    0.274375    0.038344    0.023077    0.457850    
#> 173: 0.291285    1.014782    3.437289    0.296577    0.034305    0.025200    0.462519    
#> 174: 0.293339    1.010480    3.439352    0.300271    0.032489    0.023044    0.468542    
#> 175: 0.285112    1.000917    3.436429    0.285008    0.033718    0.024694    0.467438    
#> 176: 0.297563    1.010958    3.448727    0.288421    0.035209    0.021382    0.473728    
#> 177: 0.316221    0.993419    3.455951    0.281894    0.032334    0.024909    0.483951    
#> 178: 0.311193    0.991790    3.459772    0.279958    0.045571    0.024344    0.471033    
#> 179: 0.324367    1.012927    3.446652    0.298978    0.050919    0.018694    0.470660    
#> 180: 0.298138    0.993325    3.450090    0.290415    0.044383    0.018197    0.470058    
#> 181: 0.283888    0.988998    3.440586    0.285441    0.044372    0.017555    0.481871    
#> 182: 0.268436    0.996061    3.433200    0.266288    0.040333    0.018299    0.491721    
#> 183: 0.284042    1.013464    3.437952    0.276101    0.050369    0.019179    0.496218    
#> 184: 0.273097    0.997438    3.447496    0.262719    0.042771    0.021505    0.491655    
#> 185: 0.284140    1.008135    3.442654    0.281541    0.041747    0.026598    0.481155    
#> 186: 0.282219    1.010218    3.437154    0.292697    0.049258    0.024226    0.476787    
#> 187: 0.308513    0.998551    3.444085    0.263571    0.038072    0.023759    0.479091    
#> 188: 0.296515    0.997459    3.453344    0.274318    0.039709    0.023644    0.478819    
#> 189: 0.302201    1.003410    3.452372    0.263496    0.044392    0.021197    0.488890    
#> 190: 0.300548    1.006571    3.442294    0.266834    0.045677    0.020391    0.481128    
#> 191: 0.292874    1.009316    3.438722    0.291624    0.042205    0.018477    0.465582    
#> 192: 0.280430    1.013618    3.441323    0.251673    0.045311    0.016726    0.469829    
#> 193: 0.304686    1.009248    3.447771    0.259119    0.045151    0.017735    0.472570    
#> 194: 0.290284    0.989594    3.441217    0.256557    0.042606    0.016515    0.488338    
#> 195: 0.288508    0.999438    3.441993    0.283613    0.037378    0.020080    0.485681    
#> 196: 0.293241    0.989071    3.449179    0.271909    0.042761    0.024089    0.480530    
#> 197: 0.274696    0.997042    3.455890    0.243227    0.041224    0.025207    0.499204    
#> 198: 0.314821    0.981028    3.455216    0.253495    0.038258    0.024789    0.474779    
#> 199: 0.302558    0.980726    3.444142    0.279223    0.039099    0.021546    0.479872    
#> 200: 0.303923    0.981152    3.450186    0.257190    0.035156    0.021507    0.478573    
#> 201: 0.311755    0.982992    3.454746    0.257133    0.036442    0.022820    0.474172    
#> 202: 0.305099    0.986910    3.453099    0.267733    0.035720    0.023247    0.473342    
#> 203: 0.311970    0.985694    3.451686    0.277861    0.035625    0.023069    0.474023    
#> 204: 0.310856    0.983833    3.453559    0.273546    0.036422    0.023134    0.476950    
#> 205: 0.312882    0.985212    3.455538    0.269359    0.037315    0.023178    0.481181    
#> 206: 0.311809    0.989887    3.455688    0.265366    0.038369    0.023155    0.482678    
#> 207: 0.308872    0.990886    3.454101    0.263367    0.038110    0.023392    0.483384    
#> 208: 0.308443    0.990918    3.453240    0.262748    0.037954    0.023481    0.483303    
#> 209: 0.308720    0.989387    3.452623    0.261605    0.038052    0.023312    0.483659    
#> 210: 0.310687    0.988943    3.453132    0.261619    0.038360    0.023050    0.482488    
#> 211: 0.312638    0.988739    3.453850    0.262045    0.039175    0.022858    0.481338    
#> 212: 0.316159    0.986840    3.455227    0.265074    0.038853    0.022547    0.481332    
#> 213: 0.318655    0.984853    3.456276    0.267703    0.038474    0.022458    0.481370    
#> 214: 0.319900    0.983892    3.456706    0.267572    0.038582    0.022126    0.480929    
#> 215: 0.319819    0.983669    3.457546    0.267088    0.038906    0.022010    0.480424    
#> 216: 0.322915    0.982367    3.458567    0.267089    0.039068    0.021959    0.481297    
#> 217: 0.324007    0.982053    3.459392    0.266806    0.039287    0.021702    0.481875    
#> 218: 0.325191    0.981634    3.459743    0.264558    0.039466    0.021649    0.481801    
#> 219: 0.323796    0.981104    3.459346    0.262341    0.039168    0.021640    0.482132    
#> 220: 0.322290    0.980844    3.459118    0.261025    0.038863    0.021911    0.482520    
#> 221: 0.322420    0.981383    3.459064    0.259919    0.038870    0.022076    0.482516    
#> 222: 0.322259    0.981202    3.458897    0.259459    0.039006    0.022369    0.482336    
#> 223: 0.322799    0.981096    3.458759    0.260377    0.038929    0.022611    0.482238    
#> 224: 0.323892    0.981542    3.458665    0.260816    0.038706    0.022768    0.482385    
#> 225: 0.323271    0.980695    3.458608    0.261230    0.038431    0.023037    0.483087    
#> 226: 0.323141    0.979886    3.458669    0.261070    0.038416    0.023268    0.483326    
#> 227: 0.322908    0.979808    3.458674    0.260768    0.038355    0.023471    0.483752    
#> 228: 0.321925    0.980469    3.458344    0.260273    0.038142    0.023603    0.484140    
#> 229: 0.321459    0.980334    3.458133    0.260020    0.037889    0.023717    0.483857    
#> 230: 0.322186    0.980033    3.458272    0.260921    0.037747    0.023748    0.483994    
#> 231: 0.322428    0.980027    3.458438    0.260682    0.037607    0.023739    0.483756    
#> 232: 0.321769    0.980073    3.458481    0.260684    0.037524    0.023681    0.483304    
#> 233: 0.320954    0.979521    3.458480    0.260557    0.037405    0.023580    0.483307    
#> 234: 0.320930    0.979282    3.458572    0.259569    0.037411    0.023553    0.483437    
#> 235: 0.321104    0.979270    3.458733    0.258637    0.037323    0.023505    0.483272    
#> 236: 0.320753    0.979555    3.458646    0.258001    0.037429    0.023370    0.483380    
#> 237: 0.320511    0.979423    3.458698    0.257935    0.037514    0.023241    0.483875    
#> 238: 0.320529    0.979582    3.458819    0.257870    0.037532    0.023145    0.484267    
#> 239: 0.320324    0.979942    3.458687    0.258148    0.037631    0.023087    0.484155    
#> 240: 0.320010    0.979839    3.458690    0.258414    0.037701    0.023048    0.484058    
#> 241: 0.319773    0.979420    3.458681    0.258242    0.037882    0.022986    0.484060    
#> 242: 0.319639    0.979259    3.458490    0.258494    0.038011    0.022849    0.484225    
#> 243: 0.319227    0.979597    3.458350    0.258145    0.038122    0.022800    0.484478    
#> 244: 0.318610    0.979752    3.458503    0.257253    0.038147    0.022694    0.484467    
#> 245: 0.318656    0.979703    3.458825    0.257139    0.038337    0.022698    0.484694    
#> 246: 0.319256    0.979689    3.458836    0.256528    0.038376    0.022615    0.484878    
#> 247: 0.319190    0.979643    3.458896    0.256127    0.038457    0.022560    0.485037    
#> 248: 0.319102    0.979843    3.458737    0.255792    0.038428    0.022457    0.485139    
#> 249: 0.318762    0.979786    3.458816    0.255185    0.038477    0.022398    0.485369    
#> 250: 0.318465    0.979885    3.458848    0.255150    0.038679    0.022301    0.485602    
#> 251: 0.318589    0.979963    3.459021    0.255193    0.038782    0.022223    0.485717    
#> 252: 0.319277    0.980228    3.459242    0.255367    0.038867    0.022146    0.485687    
#> 253: 0.319340    0.980400    3.459252    0.254946    0.039011    0.022057    0.485529    
#> 254: 0.319113    0.980789    3.459107    0.254957    0.039087    0.021949    0.485328    
#> 255: 0.319350    0.981036    3.459220    0.254603    0.039115    0.021852    0.485391    
#> 256: 0.319327    0.980819    3.459230    0.254261    0.039202    0.021731    0.485586    
#> 257: 0.318861    0.980563    3.459232    0.253219    0.039239    0.021622    0.485845    
#> 258: 0.318491    0.980088    3.459278    0.252731    0.039292    0.021596    0.485945    
#> 259: 0.318314    0.979845    3.459312    0.252226    0.039318    0.021605    0.486006    
#> 260: 0.318418    0.979797    3.459418    0.252322    0.039340    0.021626    0.486062    
#> 261: 0.318723    0.979526    3.459681    0.252550    0.039319    0.021622    0.486305    
#> 262: 0.318848    0.979460    3.459734    0.252817    0.039360    0.021599    0.486145    
#> 263: 0.319070    0.979500    3.459773    0.253119    0.039454    0.021587    0.486120    
#> 264: 0.319096    0.979822    3.459703    0.252903    0.039621    0.021508    0.486028    
#> 265: 0.318945    0.980033    3.459675    0.252692    0.039855    0.021448    0.486156    
#> 266: 0.318514    0.980207    3.459548    0.252745    0.039935    0.021378    0.486071    
#> 267: 0.318151    0.980252    3.459629    0.252693    0.039947    0.021322    0.486102    
#> 268: 0.318370    0.980055    3.459626    0.252846    0.039913    0.021245    0.486061    
#> 269: 0.318728    0.979943    3.459643    0.252864    0.039903    0.021190    0.486008    
#> 270: 0.318791    0.980010    3.459580    0.252418    0.039926    0.021120    0.485958    
#> 271: 0.318646    0.979961    3.459543    0.252566    0.040012    0.021050    0.486012    
#> 272: 0.318848    0.979730    3.459527    0.252096    0.040185    0.021019    0.486319    
#> 273: 0.318711    0.979853    3.459502    0.252172    0.040349    0.020994    0.486336    
#> 274: 0.319060    0.980165    3.459553    0.252156    0.040511    0.020958    0.486390    
#> 275: 0.319183    0.980268    3.459541    0.251971    0.040590    0.020925    0.486283    
#> 276: 0.318966    0.980485    3.459493    0.251810    0.040701    0.020905    0.486106    
#> 277: 0.318664    0.980638    3.459507    0.251461    0.040703    0.020911    0.486285    
#> 278: 0.318725    0.980629    3.459620    0.251505    0.040703    0.020869    0.486340    
#> 279: 0.318580    0.980436    3.459642    0.252104    0.040713    0.020849    0.486582    
#> 280: 0.318278    0.980589    3.459543    0.252499    0.040730    0.020855    0.486587    
#> 281: 0.317988    0.980941    3.459447    0.253022    0.040835    0.020842    0.486355    
#> 282: 0.317759    0.981210    3.459435    0.253312    0.040989    0.020810    0.486407    
#> 283: 0.317677    0.981213    3.459407    0.253521    0.041090    0.020745    0.486599    
#> 284: 0.317533    0.981159    3.459361    0.253326    0.041098    0.020673    0.486636    
#> 285: 0.317177    0.981186    3.459202    0.252869    0.041244    0.020588    0.486759    
#> 286: 0.316735    0.981418    3.458949    0.252711    0.041372    0.020541    0.486728    
#> 287: 0.316050    0.981683    3.458617    0.252461    0.041497    0.020522    0.486722    
#> 288: 0.316130    0.981851    3.458511    0.252848    0.041633    0.020511    0.486833    
#> 289: 0.316097    0.981916    3.458458    0.253267    0.041694    0.020530    0.486800    
#> 290: 0.316101    0.982040    3.458380    0.253300    0.041678    0.020505    0.486920    
#> 291: 0.315863    0.982224    3.458372    0.253351    0.041608    0.020480    0.486769    
#> 292: 0.315671    0.982296    3.458306    0.253293    0.041549    0.020456    0.486747    
#> 293: 0.315441    0.982330    3.458181    0.253248    0.041568    0.020455    0.486670    
#> 294: 0.315043    0.982450    3.457959    0.253587    0.041609    0.020450    0.486612    
#> 295: 0.314635    0.982348    3.457805    0.253838    0.041569    0.020497    0.486525    
#> 296: 0.314326    0.982455    3.457661    0.254167    0.041494    0.020573    0.486408    
#> 297: 0.314138    0.982685    3.457569    0.254460    0.041418    0.020630    0.486376    
#> 298: 0.314013    0.982768    3.457398    0.254743    0.041370    0.020649    0.486265    
#> 299: 0.313938    0.982948    3.457233    0.255024    0.041360    0.020641    0.486156    
#> 300: 0.314013    0.982901    3.457210    0.255277    0.041346    0.020653    0.486204    
#> 301: 0.313848    0.982748    3.457072    0.255515    0.041373    0.020670    0.486270    
#> 302: 0.313766    0.982784    3.456950    0.255756    0.041406    0.020685    0.486192    
#> 303: 0.313427    0.982897    3.456834    0.255911    0.041458    0.020693    0.486114    
#> 304: 0.313106    0.983076    3.456714    0.256150    0.041454    0.020717    0.486176    
#> 305: 0.313081    0.983024    3.456624    0.256203    0.041501    0.020736    0.486121    
#> 306: 0.312649    0.983109    3.456428    0.256190    0.041522    0.020718    0.486003    
#> 307: 0.312131    0.983249    3.456244    0.256223    0.041570    0.020680    0.485983    
#> 308: 0.311624    0.983310    3.456106    0.256303    0.041623    0.020683    0.485967    
#> 309: 0.311440    0.983144    3.456061    0.256558    0.041657    0.020689    0.486148    
#> 310: 0.311475    0.983088    3.455996    0.256851    0.041666    0.020714    0.486330    
#> 311: 0.311185    0.983117    3.455902    0.257589    0.041684    0.020715    0.486275    
#> 312: 0.310875    0.983181    3.455750    0.258222    0.041734    0.020698    0.486337    
#> 313: 0.310594    0.983059    3.455592    0.258503    0.041746    0.020687    0.486363    
#> 314: 0.310239    0.983028    3.455484    0.258905    0.041798    0.020694    0.486287    
#> 315: 0.310099    0.983139    3.455353    0.259369    0.041872    0.020704    0.486220    
#> 316: 0.310076    0.983369    3.455241    0.259938    0.041861    0.020726    0.486185    
#> 317: 0.310274    0.983372    3.455285    0.260041    0.041821    0.020724    0.486305    
#> 318: 0.310239    0.983374    3.455242    0.260136    0.041784    0.020719    0.486250    
#> 319: 0.310151    0.983337    3.455230    0.260070    0.041752    0.020709    0.486297    
#> 320: 0.309954    0.983330    3.455177    0.260145    0.041692    0.020682    0.486326    
#> 321: 0.309832    0.983262    3.455143    0.259930    0.041675    0.020651    0.486286    
#> 322: 0.309832    0.983209    3.455117    0.259833    0.041668    0.020640    0.486210    
#> 323: 0.309665    0.983195    3.455106    0.259728    0.041699    0.020621    0.486086    
#> 324: 0.309608    0.983303    3.455083    0.259658    0.041770    0.020600    0.485963    
#> 325: 0.309464    0.983530    3.454944    0.259757    0.041821    0.020579    0.485907    
#> 326: 0.309256    0.983541    3.454823    0.259699    0.041863    0.020567    0.485883    
#> 327: 0.309182    0.983538    3.454788    0.259379    0.041924    0.020540    0.485954    
#> 328: 0.309063    0.983644    3.454712    0.259152    0.041906    0.020521    0.485931    
#> 329: 0.309099    0.983727    3.454782    0.258975    0.041871    0.020485    0.485922    
#> 330: 0.308993    0.983699    3.454817    0.258844    0.041817    0.020442    0.485937    
#> 331: 0.309047    0.983741    3.454936    0.258578    0.041837    0.020426    0.485937    
#> 332: 0.309258    0.983593    3.455094    0.258473    0.041826    0.020412    0.486063    
#> 333: 0.309315    0.983507    3.455098    0.258302    0.041821    0.020405    0.486090    
#> 334: 0.309307    0.983367    3.455068    0.258246    0.041848    0.020383    0.486217    
#> 335: 0.309185    0.983251    3.455060    0.258151    0.041860    0.020350    0.486243    
#> 336: 0.308988    0.983329    3.455037    0.258091    0.041939    0.020324    0.486236    
#> 337: 0.308816    0.983542    3.454937    0.257902    0.042024    0.020294    0.486291    
#> 338: 0.308660    0.983664    3.454861    0.257807    0.042092    0.020258    0.486289    
#> 339: 0.308466    0.983760    3.454789    0.257515    0.042127    0.020236    0.486313    
#> 340: 0.308467    0.983606    3.454785    0.257477    0.042152    0.020223    0.486299    
#> 341: 0.308430    0.983587    3.454803    0.257413    0.042171    0.020208    0.486216    
#> 342: 0.308329    0.983455    3.454821    0.257379    0.042213    0.020202    0.486107    
#> 343: 0.308174    0.983454    3.454822    0.257362    0.042233    0.020196    0.486004    
#> 344: 0.308345    0.983462    3.454864    0.257546    0.042228    0.020185    0.485970    
#> 345: 0.308406    0.983513    3.454869    0.257421    0.042179    0.020174    0.485924    
#> 346: 0.308289    0.983602    3.454792    0.257369    0.042164    0.020135    0.485864    
#> 347: 0.308264    0.983566    3.454764    0.257446    0.042182    0.020117    0.485822    
#> 348: 0.308101    0.983606    3.454707    0.257555    0.042216    0.020093    0.485839    
#> 349: 0.307820    0.983658    3.454613    0.257646    0.042237    0.020076    0.485764    
#> 350: 0.307689    0.983725    3.454551    0.257660    0.042246    0.020063    0.485711    
#> 351: 0.307820    0.983881    3.454513    0.257704    0.042226    0.020047    0.485797    
#> 352: 0.307581    0.984056    3.454482    0.257540    0.042230    0.020051    0.486012    
#> 353: 0.307488    0.984278    3.454416    0.257405    0.042221    0.020046    0.486116    
#> 354: 0.307374    0.984358    3.454338    0.257237    0.042191    0.020037    0.486102    
#> 355: 0.307441    0.984319    3.454279    0.257266    0.042206    0.020038    0.486115    
#> 356: 0.307409    0.984301    3.454250    0.257158    0.042195    0.020046    0.486181    
#> 357: 0.307324    0.984351    3.454260    0.256973    0.042190    0.020054    0.486135    
#> 358: 0.307114    0.984424    3.454218    0.256751    0.042190    0.020036    0.486061    
#> 359: 0.306838    0.984645    3.454076    0.256579    0.042164    0.020017    0.486081    
#> 360: 0.306655    0.984762    3.453946    0.256489    0.042137    0.020005    0.486024    
#> 361: 0.306445    0.984854    3.453869    0.256245    0.042185    0.019984    0.485954    
#> 362: 0.306302    0.984873    3.453825    0.256005    0.042191    0.019972    0.485829    
#> 363: 0.306275    0.984886    3.453814    0.256088    0.042177    0.019950    0.485711    
#> 364: 0.306369    0.984889    3.453793    0.256212    0.042177    0.019945    0.485703    
#> 365: 0.306129    0.984912    3.453726    0.256278    0.042153    0.019940    0.485698    
#> 366: 0.305970    0.985009    3.453632    0.256207    0.042145    0.019939    0.485686    
#> 367: 0.305905    0.985131    3.453574    0.256104    0.042154    0.019943    0.485629    
#> 368: 0.306020    0.985227    3.453525    0.256140    0.042133    0.019953    0.485603    
#> 369: 0.306068    0.985246    3.453518    0.256367    0.042098    0.019965    0.485655    
#> 370: 0.305990    0.985353    3.453494    0.256334    0.042044    0.019990    0.485643    
#> 371: 0.305895    0.985483    3.453435    0.256243    0.042031    0.019996    0.485573    
#> 372: 0.305845    0.985533    3.453411    0.256134    0.042020    0.020002    0.485527    
#> 373: 0.305664    0.985585    3.453378    0.256126    0.041969    0.019998    0.485557    
#> 374: 0.305703    0.985625    3.453312    0.256226    0.041942    0.020005    0.485559    
#> 375: 0.305650    0.985698    3.453290    0.256472    0.041912    0.020034    0.485561    
#> 376: 0.305627    0.985799    3.453239    0.256608    0.041893    0.020057    0.485491    
#> 377: 0.305634    0.985847    3.453245    0.256567    0.041845    0.020059    0.485516    
#> 378: 0.305601    0.985861    3.453235    0.256369    0.041778    0.020068    0.485552    
#> 379: 0.305658    0.985776    3.453289    0.256249    0.041759    0.020071    0.485451    
#> 380: 0.305634    0.985683    3.453284    0.256096    0.041714    0.020071    0.485465    
#> 381: 0.305495    0.985635    3.453262    0.256033    0.041692    0.020076    0.485466    
#> 382: 0.305426    0.985653    3.453239    0.256022    0.041652    0.020074    0.485410    
#> 383: 0.305349    0.985706    3.453180    0.256122    0.041643    0.020079    0.485329    
#> 384: 0.305216    0.985691    3.453203    0.256129    0.041608    0.020085    0.485262    
#> 385: 0.305291    0.985683    3.453217    0.256036    0.041597    0.020098    0.485159    
#> 386: 0.305372    0.985836    3.453195    0.256115    0.041580    0.020115    0.485147    
#> 387: 0.305451    0.985919    3.453248    0.256155    0.041560    0.020133    0.485130    
#> 388: 0.305549    0.985912    3.453312    0.256346    0.041536    0.020155    0.485070    
#> 389: 0.305535    0.985820    3.453317    0.256462    0.041508    0.020180    0.485128    
#> 390: 0.305424    0.985887    3.453260    0.256625    0.041494    0.020176    0.485108    
#> 391: 0.305535    0.985897    3.453229    0.256683    0.041471    0.020172    0.485065    
#> 392: 0.305577    0.985875    3.453245    0.256860    0.041410    0.020169    0.485078    
#> 393: 0.305533    0.985795    3.453212    0.257049    0.041370    0.020182    0.485019    
#> 394: 0.305403    0.985819    3.453187    0.257188    0.041324    0.020200    0.485031    
#> 395: 0.305477    0.985862    3.453168    0.257262    0.041319    0.020236    0.485008    
#> 396: 0.305443    0.985879    3.453140    0.257369    0.041305    0.020248    0.484930    
#> 397: 0.305312    0.985876    3.453093    0.257431    0.041265    0.020254    0.484922    
#> 398: 0.305346    0.985867    3.453089    0.257422    0.041256    0.020263    0.484858    
#> 399: 0.305437    0.985878    3.453149    0.257515    0.041241    0.020270    0.484838    
#> 400: 0.305528    0.985911    3.453163    0.257750    0.041228    0.020266    0.484765    
#> 401: 0.305511    0.985998    3.453127    0.257838    0.041207    0.020254    0.484786    
#> 402: 0.305403    0.986081    3.453094    0.257904    0.041194    0.020248    0.484814    
#> 403: 0.305543    0.986132    3.453113    0.257947    0.041185    0.020244    0.484744    
#> 404: 0.305582    0.986171    3.453067    0.258005    0.041185    0.020235    0.484655    
#> 405: 0.305470    0.986235    3.453043    0.257906    0.041192    0.020232    0.484611    
#> 406: 0.305331    0.986286    3.453001    0.257916    0.041170    0.020228    0.484639    
#> 407: 0.305250    0.986346    3.452963    0.257963    0.041182    0.020224    0.484669    
#> 408: 0.305339    0.986427    3.452934    0.258085    0.041214    0.020214    0.484699    
#> 409: 0.305297    0.986400    3.452929    0.258190    0.041204    0.020215    0.484678    
#> 410: 0.305227    0.986442    3.452892    0.258385    0.041176    0.020234    0.484630    
#> 411: 0.305275    0.986379    3.452916    0.258558    0.041190    0.020242    0.484625    
#> 412: 0.305290    0.986412    3.452910    0.258740    0.041166    0.020255    0.484600    
#> 413: 0.305437    0.986398    3.452941    0.258914    0.041130    0.020274    0.484586    
#> 414: 0.305365    0.986392    3.452953    0.259052    0.041108    0.020284    0.484571    
#> 415: 0.305513    0.986352    3.452959    0.259320    0.041090    0.020302    0.484498    
#> 416: 0.305587    0.986390    3.452993    0.259502    0.041085    0.020311    0.484473    
#> 417: 0.305578    0.986335    3.453008    0.259631    0.041089    0.020327    0.484436    
#> 418: 0.305481    0.986290    3.453048    0.259597    0.041101    0.020326    0.484409    
#> 419: 0.305583    0.986293    3.453076    0.259630    0.041131    0.020333    0.484350    
#> 420: 0.305708    0.986284    3.453131    0.259583    0.041171    0.020332    0.484276    
#> 421: 0.305749    0.986273    3.453209    0.259464    0.041184    0.020341    0.484236    
#> 422: 0.305959    0.986219    3.453281    0.259443    0.041184    0.020350    0.484204    
#> 423: 0.306081    0.986119    3.453326    0.259400    0.041174    0.020359    0.484235    
#> 424: 0.306126    0.986045    3.453324    0.259264    0.041180    0.020344    0.484205    
#> 425: 0.306045    0.986091    3.453291    0.259214    0.041223    0.020337    0.484288    
#> 426: 0.305927    0.986233    3.453215    0.259267    0.041257    0.020336    0.484253    
#> 427: 0.305729    0.986295    3.453177    0.259283    0.041285    0.020325    0.484223    
#> 428: 0.305566    0.986408    3.453140    0.259218    0.041314    0.020314    0.484201    
#> 429: 0.305540    0.986474    3.453155    0.259236    0.041322    0.020316    0.484178    
#> 430: 0.305580    0.986483    3.453147    0.259241    0.041323    0.020318    0.484186    
#> 431: 0.305649    0.986480    3.453153    0.259379    0.041349    0.020309    0.484094    
#> 432: 0.305664    0.986509    3.453163    0.259423    0.041396    0.020298    0.484031    
#> 433: 0.305615    0.986567    3.453149    0.259510    0.041438    0.020281    0.484057    
#> 434: 0.305561    0.986505    3.453153    0.259453    0.041444    0.020279    0.484068    
#> 435: 0.305563    0.986463    3.453148    0.259463    0.041430    0.020278    0.483999    
#> 436: 0.305702    0.986433    3.453232    0.259488    0.041460    0.020287    0.483988    
#> 437: 0.305878    0.986401    3.453276    0.259387    0.041473    0.020277    0.483977    
#> 438: 0.305911    0.986471    3.453280    0.259195    0.041483    0.020285    0.483910    
#> 439: 0.305937    0.986490    3.453311    0.259000    0.041515    0.020280    0.483828    
#> 440: 0.306010    0.986490    3.453381    0.258846    0.041512    0.020284    0.483802    
#> 441: 0.306077    0.986461    3.453413    0.258814    0.041504    0.020294    0.483775    
#> 442: 0.306046    0.986457    3.453409    0.258789    0.041511    0.020298    0.483743    
#> 443: 0.306019    0.986533    3.453362    0.258813    0.041513    0.020309    0.483748    
#> 444: 0.305900    0.986621    3.453279    0.258924    0.041548    0.020307    0.483790    
#> 445: 0.305734    0.986713    3.453211    0.258963    0.041552    0.020304    0.483816    
#> 446: 0.305576    0.986799    3.453144    0.258916    0.041554    0.020309    0.483795    
#> 447: 0.305532    0.986870    3.453098    0.259007    0.041556    0.020323    0.483799    
#> 448: 0.305502    0.986872    3.453060    0.259058    0.041550    0.020341    0.483731    
#> 449: 0.305584    0.986924    3.453112    0.259055    0.041538    0.020364    0.483739    
#> 450: 0.305601    0.986915    3.453113    0.259146    0.041529    0.020390    0.483736    
#> 451: 0.305481    0.986927    3.453076    0.259174    0.041511    0.020415    0.483782    
#> 452: 0.305383    0.986953    3.453048    0.259279    0.041494    0.020431    0.483786    
#> 453: 0.305180    0.987008    3.452988    0.259206    0.041473    0.020434    0.483744    
#> 454: 0.305090    0.987124    3.452952    0.259277    0.041473    0.020442    0.483705    
#> 455: 0.305002    0.987224    3.452894    0.259311    0.041451    0.020440    0.483664    
#> 456: 0.304855    0.987246    3.452857    0.259322    0.041445    0.020445    0.483667    
#> 457: 0.304778    0.987266    3.452865    0.259322    0.041440    0.020456    0.483612    
#> 458: 0.304711    0.987376    3.452840    0.259314    0.041426    0.020462    0.483585    
#> 459: 0.304602    0.987492    3.452816    0.259424    0.041391    0.020482    0.483602    
#> 460: 0.304454    0.987544    3.452740    0.259550    0.041358    0.020504    0.483591    
#> 461: 0.304366    0.987587    3.452697    0.259582    0.041330    0.020519    0.483555    
#> 462: 0.304239    0.987629    3.452678    0.259496    0.041307    0.020538    0.483480    
#> 463: 0.304228    0.987635    3.452708    0.259367    0.041294    0.020554    0.483468    
#> 464: 0.304238    0.987649    3.452698    0.259243    0.041285    0.020564    0.483443    
#> 465: 0.304233    0.987574    3.452715    0.259187    0.041266    0.020567    0.483415    
#> 466: 0.304260    0.987583    3.452718    0.259176    0.041247    0.020580    0.483348    
#> 467: 0.304236    0.987525    3.452752    0.259144    0.041226    0.020595    0.483271    
#> 468: 0.304364    0.987532    3.452804    0.259270    0.041199    0.020624    0.483217    
#> 469: 0.304544    0.987611    3.452828    0.259374    0.041214    0.020637    0.483248    
#> 470: 0.304411    0.987676    3.452780    0.259417    0.041211    0.020644    0.483205    
#> 471: 0.304305    0.987683    3.452757    0.259418    0.041216    0.020636    0.483206    
#> 472: 0.304219    0.987694    3.452721    0.259440    0.041241    0.020626    0.483192    
#> 473: 0.304114    0.987710    3.452707    0.259397    0.041231    0.020630    0.483176    
#> 474: 0.304071    0.987741    3.452675    0.259295    0.041214    0.020637    0.483242    
#> 475: 0.304031    0.987797    3.452657    0.259280    0.041197    0.020637    0.483216    
#> 476: 0.303957    0.987804    3.452634    0.259416    0.041180    0.020641    0.483166    
#> 477: 0.303885    0.987841    3.452636    0.259520    0.041165    0.020642    0.483119    
#> 478: 0.303780    0.987817    3.452642    0.259596    0.041141    0.020644    0.483117    
#> 479: 0.303819    0.987852    3.452625    0.259767    0.041126    0.020648    0.483124    
#> 480: 0.303770    0.987874    3.452618    0.259804    0.041136    0.020637    0.483182    
#> 481: 0.303729    0.987893    3.452589    0.259802    0.041135    0.020634    0.483173    
#> 482: 0.303709    0.987903    3.452540    0.259855    0.041139    0.020642    0.483162    
#> 483: 0.303587    0.987893    3.452513    0.259931    0.041156    0.020635    0.483129    
#> 484: 0.303586    0.987830    3.452517    0.260034    0.041142    0.020644    0.483093    
#> 485: 0.303541    0.987851    3.452515    0.260084    0.041142    0.020655    0.483141    
#> 486: 0.303504    0.987907    3.452522    0.260063    0.041141    0.020663    0.483138    
#> 487: 0.303571    0.987930    3.452555    0.260165    0.041161    0.020662    0.483157    
#> 488: 0.303643    0.987903    3.452589    0.260269    0.041171    0.020661    0.483102    
#> 489: 0.303771    0.987840    3.452604    0.260306    0.041165    0.020662    0.483068    
#> 490: 0.303830    0.987870    3.452631    0.260298    0.041176    0.020664    0.483034    
#> 491: 0.303860    0.987904    3.452662    0.260249    0.041187    0.020663    0.482985    
#> 492: 0.303909    0.987949    3.452661    0.260182    0.041199    0.020659    0.483002    
#> 493: 0.303869    0.987992    3.452659    0.260163    0.041200    0.020674    0.482978    
#> 494: 0.303917    0.988030    3.452653    0.260232    0.041203    0.020678    0.482928    
#> 495: 0.303927    0.988040    3.452620    0.260271    0.041196    0.020670    0.482863    
#> 496: 0.303949    0.988114    3.452605    0.260212    0.041188    0.020674    0.482814    
#> 497: 0.303992    0.988110    3.452618    0.260227    0.041152    0.020675    0.482867    
#> 498: 0.303946    0.988103    3.452595    0.260219    0.041141    0.020679    0.482831    
#> 499: 0.303923    0.988102    3.452566    0.260226    0.041135    0.020677    0.482773    
#> 500: 0.303961    0.988039    3.452572    0.260379    0.041117    0.020678    0.482768    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.308815    0.949402    3.443836    0.392401    0.089004    0.016800    1.708241    
#> 002: 0.332597    0.860670    3.464899    0.372781    0.084553    0.016700    1.066632    
#> 003: 0.347775    0.832892    3.465574    0.354142    0.080326    0.015865    0.895650    
#> 004: 0.291879    0.854988    3.440033    0.336435    0.076310    0.015072    0.825350    
#> 005: 0.310746    0.862287    3.437609    0.319613    0.072494    0.014318    0.792627    
#> 006: 0.294521    0.834829    3.406598    0.303633    0.072438    0.014779    0.720285    
#> 007: 0.234573    0.842986    3.403402    0.288451    0.068816    0.015307    0.715406    
#> 008: 0.224932    0.875330    3.386736    0.339184    0.065376    0.017382    0.683747    
#> 009: 0.185961    0.877687    3.370594    0.361582    0.065028    0.018304    0.657047    
#> 010: 0.168657    0.895193    3.367149    0.345371    0.061777    0.017389    0.672286    
#> 011: 0.227301    0.903980    3.371239    0.384254    0.068282    0.016519    0.669193    
#> 012: 0.207768    0.906947    3.358914    0.371282    0.064868    0.016855    0.646798    
#> 013: 0.158443    0.911776    3.352421    0.352718    0.071546    0.018192    0.667988    
#> 014: 0.227156    0.897515    3.369997    0.340756    0.090867    0.017283    0.673669    
#> 015: 0.240734    0.895015    3.383605    0.347954    0.086324    0.016418    0.652830    
#> 016: 0.235641    0.889584    3.380512    0.343929    0.083529    0.020042    0.654374    
#> 017: 0.227256    0.909466    3.371749    0.371884    0.086466    0.019040    0.642144    
#> 018: 0.197469    0.917725    3.366419    0.365939    0.086692    0.018088    0.643443    
#> 019: 0.149347    0.929266    3.351979    0.347642    0.082357    0.017184    0.639226    
#> 020: 0.193227    0.930404    3.362840    0.330260    0.078239    0.016990    0.649959    
#> 021: 0.208370    0.907869    3.366204    0.334877    0.074327    0.016141    0.639326    
#> 022: 0.222177    0.900692    3.386592    0.339507    0.070611    0.018399    0.641699    
#> 023: 0.308336    0.911635    3.393086    0.375109    0.072862    0.018400    0.667477    
#> 024: 0.277985    0.916997    3.390242    0.410794    0.069219    0.018984    0.654833    
#> 025: 0.277822    0.896436    3.386100    0.390254    0.065758    0.019800    0.643238    
#> 026: 0.207368    0.921223    3.364088    0.370741    0.062470    0.022462    0.656431    
#> 027: 0.237715    0.927684    3.361622    0.387482    0.061986    0.021339    0.664534    
#> 028: 0.236221    0.933028    3.372629    0.368108    0.058952    0.025176    0.648646    
#> 029: 0.236283    0.934752    3.362552    0.474388    0.065816    0.024830    0.637162    
#> 030: 0.199655    0.925177    3.359283    0.450668    0.062526    0.024855    0.640344    
#> 031: 0.177525    0.913962    3.360111    0.489603    0.064897    0.024939    0.652615    
#> 032: 0.157025    0.915270    3.365930    0.465123    0.061652    0.025947    0.655613    
#> 033: 0.160286    0.938215    3.354183    0.441867    0.058569    0.031415    0.628030    
#> 034: 0.177948    0.939061    3.360342    0.419773    0.055641    0.029844    0.643090    
#> 035: 0.196782    0.920103    3.361141    0.398785    0.052901    0.028352    0.631650    
#> 036: 0.194997    0.931484    3.355439    0.429447    0.061967    0.027820    0.624405    
#> 037: 0.198054    0.937916    3.357056    0.409439    0.058868    0.026429    0.650812    
#> 038: 0.205034    0.933148    3.350025    0.455381    0.055925    0.026140    0.645540    
#> 039: 0.175917    0.927560    3.347478    0.478876    0.063323    0.025096    0.644078    
#> 040: 0.192055    0.941553    3.349054    0.454932    0.061116    0.023841    0.656831    
#> 041: 0.190491    0.907508    3.355446    0.438717    0.066147    0.022833    0.649474    
#> 042: 0.205822    0.922137    3.355204    0.416781    0.062914    0.022208    0.639364    
#> 043: 0.181594    0.917712    3.346722    0.395942    0.059769    0.021695    0.636419    
#> 044: 0.166043    0.918402    3.356371    0.376145    0.063766    0.020610    0.637780    
#> 045: 0.176875    0.932636    3.351839    0.369463    0.060577    0.020439    0.645567    
#> 046: 0.189745    0.897530    3.359988    0.404063    0.057548    0.023044    0.648177    
#> 047: 0.170181    0.901423    3.354281    0.383860    0.054671    0.027517    0.643771    
#> 048: 0.184027    0.913325    3.356779    0.378651    0.052387    0.026142    0.645471    
#> 049: 0.170882    0.910401    3.360780    0.381192    0.061937    0.025432    0.646986    
#> 050: 0.214033    0.900246    3.367232    0.362132    0.059226    0.024160    0.667755    
#> 051: 0.199449    0.916848    3.368610    0.354616    0.061546    0.023899    0.650920    
#> 052: 0.216622    0.908294    3.372276    0.433905    0.058468    0.024479    0.633350    
#> 053: 0.214894    0.897413    3.367888    0.437633    0.068725    0.023255    0.634167    
#> 054: 0.203542    0.901849    3.368446    0.415751    0.065948    0.023726    0.663936    
#> 055: 0.224327    0.886283    3.384441    0.394964    0.062651    0.022539    0.667622    
#> 056: 0.238375    0.877577    3.385671    0.387820    0.059522    0.021412    0.660005    
#> 057: 0.208753    0.897246    3.381051    0.390079    0.056546    0.023084    0.670258    
#> 058: 0.214317    0.907915    3.374634    0.370575    0.063174    0.022992    0.666788    
#> 059: 0.220750    0.870268    3.380715    0.406912    0.060015    0.025622    0.669784    
#> 060: 0.196881    0.869414    3.378992    0.386566    0.057015    0.024341    0.658645    
#> 061: 0.231825    0.899671    3.378570    0.395343    0.055799    0.023124    0.674893    
#> 062: 0.221174    0.919215    3.376270    0.375576    0.055130    0.023700    0.688598    
#> 063: 0.275295    0.892824    3.381906    0.410118    0.055231    0.026441    0.676491    
#> 064: 0.244003    0.889287    3.390817    0.389612    0.055917    0.025119    0.684633    
#> 065: 0.250319    0.884592    3.366503    0.370132    0.053121    0.023863    0.664183    
#> 066: 0.220336    0.909608    3.367096    0.387767    0.050465    0.026231    0.640583    
#> 067: 0.210462    0.918028    3.363551    0.411721    0.058497    0.024919    0.625165    
#> 068: 0.181879    0.906640    3.374325    0.391135    0.057987    0.029860    0.646638    
#> 069: 0.193194    0.905257    3.368459    0.371578    0.055087    0.028367    0.655900    
#> 070: 0.192438    0.903302    3.372174    0.377420    0.052333    0.031639    0.647182    
#> 071: 0.174496    0.947724    3.346153    0.458277    0.056102    0.030057    0.641006    
#> 072: 0.179521    0.922884    3.348535    0.531577    0.053297    0.028554    0.631883    
#> 073: 0.213257    0.916973    3.369759    0.531931    0.050632    0.030340    0.640479    
#> 074: 0.202887    0.910569    3.370555    0.505334    0.050360    0.028823    0.639246    
#> 075: 0.212645    0.900838    3.384807    0.480067    0.047842    0.027381    0.644555    
#> 076: 0.253120    0.913953    3.387401    0.456064    0.045450    0.031679    0.660892    
#> 077: 0.286864    0.902283    3.395939    0.446782    0.043177    0.030182    0.652717    
#> 078: 0.217533    0.901477    3.384987    0.424443    0.041019    0.029128    0.640769    
#> 079: 0.208995    0.910144    3.379302    0.403221    0.044859    0.027672    0.667729    
#> 080: 0.250566    0.896315    3.382387    0.434294    0.052457    0.032829    0.641262    
#> 081: 0.236794    0.902024    3.379118    0.412579    0.049834    0.035227    0.634389    
#> 082: 0.223246    0.891202    3.380025    0.391950    0.052789    0.033465    0.639762    
#> 083: 0.221661    0.913841    3.377598    0.372353    0.050149    0.031792    0.654262    
#> 084: 0.212042    0.922146    3.369762    0.357904    0.056519    0.030203    0.639903    
#> 085: 0.228386    0.916200    3.391452    0.371078    0.053693    0.028692    0.639456    
#> 086: 0.233296    0.914019    3.381393    0.362789    0.054049    0.027258    0.640981    
#> 087: 0.202453    0.902532    3.368851    0.353237    0.054346    0.025895    0.632190    
#> 088: 0.152864    0.885982    3.366456    0.335575    0.054098    0.024600    0.673051    
#> 089: 0.202745    0.928418    3.360342    0.404426    0.068731    0.023370    0.640145    
#> 090: 0.191597    0.919341    3.359146    0.384205    0.069049    0.022202    0.646284    
#> 091: 0.164871    0.913708    3.343608    0.364995    0.068996    0.022960    0.647830    
#> 092: 0.155370    0.931873    3.337374    0.349203    0.065547    0.025744    0.660128    
#> 093: 0.149307    0.923988    3.348152    0.373522    0.062269    0.024457    0.680999    
#> 094: 0.169742    0.935573    3.349656    0.397995    0.070179    0.023234    0.669708    
#> 095: 0.177018    0.915590    3.363529    0.395285    0.066670    0.024506    0.657008    
#> 096: 0.137223    0.925123    3.344828    0.375521    0.067802    0.023281    0.636122    
#> 097: 0.192223    0.940290    3.346512    0.450903    0.071130    0.022117    0.626725    
#> 098: 0.210634    0.935214    3.353243    0.479589    0.077072    0.023367    0.646494    
#> 099: 0.177822    0.914634    3.347950    0.455610    0.078404    0.022198    0.642849    
#> 100: 0.203085    0.933044    3.361669    0.432829    0.074541    0.021088    0.631694    
#> 101: 0.155513    0.925302    3.341594    0.411188    0.076879    0.020034    0.643793    
#> 102: 0.190010    0.934695    3.335996    0.390628    0.073035    0.019032    0.661014    
#> 103: 0.201298    0.914442    3.361618    0.472733    0.069383    0.018081    0.647318    
#> 104: 0.199263    0.910494    3.372008    0.495073    0.065914    0.017955    0.653082    
#> 105: 0.196531    0.909498    3.366985    0.470319    0.074458    0.017057    0.659877    
#> 106: 0.192656    0.916309    3.358340    0.446803    0.071734    0.016430    0.643468    
#> 107: 0.184760    0.931222    3.359711    0.424463    0.069941    0.020618    0.635741    
#> 108: 0.171827    0.920649    3.364365    0.403240    0.076809    0.019982    0.644206    
#> 109: 0.202160    0.925001    3.371581    0.383078    0.072969    0.018983    0.653195    
#> 110: 0.214194    0.900452    3.362367    0.421380    0.069320    0.018034    0.650138    
#> 111: 0.202875    0.912171    3.366688    0.401981    0.068304    0.018411    0.639096    
#> 112: 0.161795    0.906745    3.346736    0.381882    0.064889    0.018832    0.655356    
#> 113: 0.170294    0.933665    3.348818    0.424354    0.061644    0.019333    0.645342    
#> 114: 0.189466    0.923227    3.359058    0.403136    0.058562    0.018898    0.657608    
#> 115: 0.204189    0.905856    3.363267    0.402517    0.058567    0.019685    0.654609    
#> 116: 0.199298    0.918712    3.359088    0.426320    0.064550    0.019166    0.637138    
#> 117: 0.182545    0.927592    3.363335    0.425285    0.070309    0.018208    0.654633    
#> 118: 0.206543    0.914768    3.362597    0.470243    0.066793    0.017298    0.656040    
#> 119: 0.184234    0.932013    3.355859    0.446731    0.068185    0.016433    0.665578    
#> 120: 0.157719    0.915689    3.349897    0.424395    0.064776    0.015708    0.664719    
#> 121: 0.186683    0.938521    3.351687    0.473428    0.072864    0.018256    0.662060    
#> 122: 0.192371    0.923309    3.370466    0.449757    0.078708    0.017343    0.668679    
#> 123: 0.191094    0.952353    3.353785    0.427269    0.074773    0.016476    0.676828    
#> 124: 0.170375    0.960807    3.348753    0.405906    0.071034    0.016157    0.661773    
#> 125: 0.212798    0.946177    3.359102    0.385610    0.067483    0.019079    0.670395    
#> 126: 0.195979    0.940073    3.348704    0.383734    0.064963    0.018126    0.671280    
#> 127: 0.209527    0.947716    3.338315    0.431666    0.061715    0.017219    0.673013    
#> 128: 0.182020    0.929038    3.352664    0.410082    0.064139    0.020091    0.670907    
#> 129: 0.176608    0.936659    3.363530    0.389578    0.069937    0.020528    0.678277    
#> 130: 0.213411    0.934975    3.366540    0.370099    0.067561    0.020777    0.657401    
#> 131: 0.162467    0.920562    3.345439    0.376138    0.074027    0.020662    0.653367    
#> 132: 0.132968    0.940064    3.334074    0.357331    0.070326    0.025116    0.648198    
#> 133: 0.171883    0.925497    3.346434    0.439796    0.066809    0.028845    0.624227    
#> 134: 0.203239    0.905002    3.364549    0.431595    0.063469    0.030867    0.636728    
#> 135: 0.224691    0.898679    3.373700    0.410015    0.060295    0.029323    0.643765    
#> 136: 0.250652    0.891640    3.374738    0.474291    0.060763    0.027857    0.631953    
#> 137: 0.273905    0.895475    3.383582    0.484989    0.057725    0.027365    0.643604    
#> 138: 0.250202    0.901072    3.380052    0.460739    0.054839    0.026985    0.638401    
#> 139: 0.216755    0.910549    3.375820    0.437702    0.053271    0.025635    0.645077    
#> 140: 0.205663    0.916226    3.377082    0.415817    0.054839    0.025839    0.666228    
#> 141: 0.213468    0.893874    3.375280    0.395026    0.052097    0.025454    0.645503    
#> 142: 0.221997    0.893063    3.386239    0.375275    0.057909    0.025535    0.649763    
#> 143: 0.207808    0.912390    3.375457    0.356511    0.072856    0.024258    0.663484    
#> 144: 0.255969    0.907065    3.397142    0.376961    0.069213    0.023045    0.636313    
#> 145: 0.229484    0.918197    3.371557    0.358113    0.065753    0.021893    0.650053    
#> 146: 0.182059    0.914150    3.370275    0.344380    0.065140    0.020798    0.649812    
#> 147: 0.168282    0.907884    3.357748    0.335274    0.061883    0.021294    0.649053    
#> 148: 0.190622    0.920681    3.366999    0.352027    0.058789    0.022097    0.650579    
#> 149: 0.195239    0.912172    3.373914    0.452966    0.055850    0.021202    0.654009    
#> 150: 0.219066    0.908129    3.359997    0.430318    0.055602    0.026350    0.657226    
#> 151: 0.183878    0.925486    3.369954    0.408802    0.052822    0.025032    0.653831    
#> 152: 0.200834    0.920190    3.361343    0.404246    0.045856    0.023082    0.655228    
#> 153: 0.198498    0.916895    3.377087    0.369215    0.056494    0.025239    0.660083    
#> 154: 0.236272    0.906459    3.381488    0.418322    0.041238    0.026999    0.654307    
#> 155: 0.214268    0.904600    3.371727    0.397143    0.052692    0.022357    0.649464    
#> 156: 0.217442    0.910401    3.375882    0.404364    0.050758    0.020776    0.655423    
#> 157: 0.263639    0.901074    3.385095    0.459607    0.057393    0.017555    0.654774    
#> 158: 0.242143    0.911678    3.379563    0.387636    0.061439    0.019976    0.650605    
#> 159: 0.232794    0.903835    3.384251    0.406545    0.076468    0.021027    0.664557    
#> 160: 0.255318    0.871870    3.399804    0.371931    0.070178    0.024776    0.657913    
#> 161: 0.250989    0.883197    3.390097    0.388017    0.061610    0.025901    0.651777    
#> 162: 0.248535    0.895040    3.392619    0.429176    0.054336    0.022119    0.651796    
#> 163: 0.278919    0.890992    3.382984    0.409612    0.063580    0.023942    0.639586    
#> 164: 0.266462    0.894504    3.376072    0.462846    0.056882    0.020187    0.638458    
#> 165: 0.254114    0.886219    3.384939    0.446984    0.056118    0.025771    0.643286    
#> 166: 0.277547    0.917039    3.378487    0.627338    0.060727    0.026909    0.646208    
#> 167: 0.252233    0.930173    3.391675    0.471075    0.071512    0.021996    0.651914    
#> 168: 0.272677    0.917399    3.383415    0.482217    0.061215    0.019775    0.634668    
#> 169: 0.281642    0.941792    3.374304    0.521105    0.068996    0.021298    0.657975    
#> 170: 0.280765    0.925995    3.379373    0.586823    0.074193    0.022951    0.652970    
#> 171: 0.263204    0.904595    3.374019    0.561285    0.081505    0.017923    0.627507    
#> 172: 0.205710    0.931967    3.365898    0.409150    0.073372    0.016950    0.629492    
#> 173: 0.207684    0.934545    3.353536    0.438056    0.060504    0.012228    0.644529    
#> 174: 0.224075    0.922264    3.362055    0.440088    0.053259    0.013074    0.662631    
#> 175: 0.215706    0.936261    3.354417    0.403376    0.050530    0.014981    0.652303    
#> 176: 0.223996    0.945142    3.367823    0.394612    0.062204    0.020093    0.634245    
#> 177: 0.240648    0.914336    3.379425    0.373526    0.047565    0.015091    0.660925    
#> 178: 0.231615    0.902548    3.373820    0.401237    0.049617    0.017729    0.655140    
#> 179: 0.252353    0.914469    3.367060    0.463463    0.059417    0.020998    0.644616    
#> 180: 0.239299    0.920549    3.370164    0.502250    0.050920    0.021428    0.643857    
#> 181: 0.233664    0.915623    3.353176    0.450862    0.049199    0.020634    0.648772    
#> 182: 0.186938    0.915071    3.347673    0.450737    0.051849    0.022456    0.662348    
#> 183: 0.195604    0.933513    3.353071    0.460262    0.055133    0.026722    0.640110    
#> 184: 0.203319    0.918802    3.355740    0.480443    0.055301    0.027512    0.630672    
#> 185: 0.152125    0.938671    3.345964    0.424923    0.070961    0.026176    0.631468    
#> 186: 0.159350    0.958811    3.339524    0.402116    0.063800    0.023681    0.635499    
#> 187: 0.188016    0.930473    3.347502    0.493242    0.053081    0.021410    0.633021    
#> 188: 0.168159    0.936066    3.351516    0.451495    0.056884    0.024150    0.641438    
#> 189: 0.166025    0.943049    3.353646    0.428608    0.054951    0.024390    0.648016    
#> 190: 0.199222    0.936102    3.354586    0.473533    0.044725    0.021706    0.642703    
#> 191: 0.183519    0.925965    3.354128    0.422850    0.039656    0.023447    0.637338    
#> 192: 0.162185    0.922722    3.352518    0.400671    0.045587    0.025856    0.633518    
#> 193: 0.186275    0.934878    3.354941    0.400984    0.057243    0.023044    0.644788    
#> 194: 0.191662    0.934201    3.352873    0.442181    0.061642    0.023607    0.647928    
#> 195: 0.160193    0.943361    3.345839    0.434824    0.047049    0.026790    0.636897    
#> 196: 0.138783    0.937098    3.352829    0.398682    0.046874    0.024661    0.651830    
#> 197: 0.138633    0.929951    3.366297    0.382311    0.046207    0.022390    0.651192    
#> 198: 0.202497    0.909843    3.366393    0.342217    0.055815    0.023601    0.640110    
#> 199: 0.197893    0.903242    3.367619    0.413310    0.059911    0.027594    0.632090    
#> 200: 0.196626    0.902703    3.365471    0.443599    0.060390    0.025628    0.636711    
#> 201: 0.198489    0.901522    3.369225    0.432795    0.058286    0.026875    0.633575    
#> 202: 0.201395    0.908811    3.369364    0.427352    0.058415    0.026366    0.633287    
#> 203: 0.204379    0.911347    3.367217    0.406261    0.059371    0.025654    0.635611    
#> 204: 0.199899    0.911588    3.365393    0.404390    0.061012    0.026209    0.636223    
#> 205: 0.202017    0.916852    3.363195    0.407308    0.060280    0.026382    0.640180    
#> 206: 0.198191    0.922619    3.361513    0.415801    0.058725    0.027005    0.642054    
#> 207: 0.193712    0.923988    3.358800    0.409070    0.059836    0.026978    0.641900    
#> 208: 0.194080    0.924743    3.357323    0.410901    0.060035    0.026903    0.640855    
#> 209: 0.192993    0.923353    3.355948    0.412304    0.058276    0.026765    0.643833    
#> 210: 0.193334    0.923488    3.356482    0.411955    0.057658    0.026765    0.644492    
#> 211: 0.195123    0.924702    3.357047    0.404341    0.057345    0.026474    0.644762    
#> 212: 0.198145    0.924091    3.358461    0.400486    0.057148    0.026338    0.644468    
#> 213: 0.200977    0.922602    3.360042    0.400766    0.057198    0.026592    0.644667    
#> 214: 0.204717    0.921893    3.361785    0.402203    0.057040    0.026738    0.644734    
#> 215: 0.207809    0.921102    3.363682    0.402862    0.056755    0.026865    0.645289    
#> 216: 0.210228    0.919530    3.364738    0.403465    0.056700    0.026791    0.646488    
#> 217: 0.209234    0.920483    3.364931    0.401655    0.056291    0.026368    0.646505    
#> 218: 0.210097    0.920177    3.364784    0.404083    0.056765    0.026026    0.646128    
#> 219: 0.210045    0.919779    3.364410    0.407372    0.056412    0.025769    0.645970    
#> 220: 0.209245    0.919634    3.364263    0.408073    0.056300    0.025905    0.646014    
#> 221: 0.209944    0.919402    3.364444    0.410558    0.056157    0.025807    0.645606    
#> 222: 0.210990    0.918647    3.364422    0.414849    0.055473    0.025911    0.645361    
#> 223: 0.210943    0.917704    3.364594    0.413338    0.054787    0.026057    0.645098    
#> 224: 0.211273    0.917737    3.364915    0.411313    0.054417    0.025910    0.645219    
#> 225: 0.210846    0.916739    3.365533    0.411487    0.054107    0.025794    0.645981    
#> 226: 0.211540    0.915830    3.365570    0.411914    0.053929    0.025527    0.646904    
#> 227: 0.210319    0.916244    3.365069    0.411398    0.054296    0.025451    0.647572    
#> 228: 0.209790    0.917087    3.364662    0.410234    0.054462    0.025416    0.647934    
#> 229: 0.208552    0.916649    3.364443    0.409346    0.054757    0.025378    0.647994    
#> 230: 0.208676    0.916064    3.364387    0.408760    0.054500    0.025258    0.648688    
#> 231: 0.208720    0.916055    3.364532    0.408604    0.054417    0.025185    0.648611    
#> 232: 0.208068    0.915678    3.364638    0.407283    0.054248    0.025215    0.648990    
#> 233: 0.206953    0.914915    3.364468    0.406215    0.054274    0.025240    0.649433    
#> 234: 0.206850    0.915018    3.364472    0.406420    0.054521    0.025225    0.649994    
#> 235: 0.206753    0.915092    3.364484    0.405673    0.054452    0.025099    0.650321    
#> 236: 0.205901    0.915349    3.364294    0.403946    0.054469    0.024999    0.650365    
#> 237: 0.206345    0.915125    3.364541    0.403305    0.054558    0.024873    0.651192    
#> 238: 0.206617    0.915114    3.364828    0.402875    0.054691    0.024918    0.651711    
#> 239: 0.206939    0.915020    3.364949    0.402426    0.054737    0.024771    0.651578    
#> 240: 0.206781    0.914912    3.365328    0.400929    0.054796    0.024637    0.651197    
#> 241: 0.207359    0.913848    3.365778    0.399913    0.054864    0.024580    0.651071    
#> 242: 0.207972    0.912784    3.365969    0.398549    0.054699    0.024537    0.651242    
#> 243: 0.207651    0.912972    3.365921    0.396721    0.054688    0.024491    0.651022    
#> 244: 0.207883    0.912606    3.366267    0.397169    0.054550    0.024576    0.650742    
#> 245: 0.208942    0.912026    3.366537    0.397666    0.054615    0.024660    0.651070    
#> 246: 0.209597    0.911560    3.366570    0.399050    0.054573    0.024685    0.651328    
#> 247: 0.209500    0.910947    3.366817    0.398570    0.054589    0.024698    0.651557    
#> 248: 0.209555    0.910969    3.367027    0.398265    0.054680    0.024584    0.651333    
#> 249: 0.209777    0.910735    3.367288    0.397927    0.054803    0.024426    0.651298    
#> 250: 0.210211    0.910824    3.367561    0.396785    0.054848    0.024347    0.651552    
#> 251: 0.211291    0.910922    3.367917    0.397198    0.054674    0.024291    0.651600    
#> 252: 0.212208    0.911231    3.368335    0.396308    0.054724    0.024152    0.652094    
#> 253: 0.212291    0.911647    3.368543    0.395988    0.054761    0.024129    0.652651    
#> 254: 0.212898    0.911870    3.368771    0.395928    0.054754    0.024140    0.652917    
#> 255: 0.212923    0.911787    3.368873    0.395190    0.054678    0.024080    0.653197    
#> 256: 0.212797    0.911700    3.368842    0.393984    0.054658    0.023989    0.653248    
#> 257: 0.212481    0.911570    3.368772    0.394128    0.054918    0.023961    0.653377    
#> 258: 0.211716    0.911305    3.368588    0.392641    0.055054    0.023835    0.653577    
#> 259: 0.211745    0.911051    3.368584    0.392380    0.055123    0.023764    0.653942    
#> 260: 0.211506    0.911095    3.368612    0.393209    0.055279    0.023722    0.653845    
#> 261: 0.211694    0.910848    3.368764    0.393986    0.055333    0.023619    0.653865    
#> 262: 0.211266    0.910854    3.368890    0.393836    0.055189    0.023605    0.653902    
#> 263: 0.210962    0.911130    3.368816    0.393490    0.055246    0.023561    0.654258    
#> 264: 0.210895    0.911281    3.368784    0.392779    0.055289    0.023548    0.654478    
#> 265: 0.210627    0.911375    3.368795    0.391996    0.055257    0.023597    0.654609    
#> 266: 0.210607    0.911656    3.368868    0.391551    0.055158    0.023574    0.654763    
#> 267: 0.210786    0.911601    3.369033    0.391309    0.055132    0.023654    0.654809    
#> 268: 0.211131    0.911363    3.369037    0.392131    0.055173    0.023689    0.654803    
#> 269: 0.211169    0.911537    3.368893    0.392723    0.055248    0.023681    0.654756    
#> 270: 0.210967    0.911523    3.368782    0.391787    0.055198    0.023685    0.654737    
#> 271: 0.210844    0.911623    3.368591    0.392422    0.055044    0.023695    0.654840    
#> 272: 0.210686    0.911642    3.368382    0.393114    0.054887    0.023733    0.654944    
#> 273: 0.210385    0.911794    3.368340    0.393154    0.054830    0.023734    0.654947    
#> 274: 0.209980    0.912082    3.368357    0.392945    0.054750    0.023713    0.654835    
#> 275: 0.209896    0.912244    3.368253    0.392460    0.054658    0.023675    0.654860    
#> 276: 0.209713    0.912411    3.368293    0.392232    0.054456    0.023784    0.654741    
#> 277: 0.209405    0.912544    3.368346    0.392322    0.054327    0.023877    0.654755    
#> 278: 0.209112    0.912582    3.368358    0.391855    0.054204    0.023965    0.654733    
#> 279: 0.208984    0.912325    3.368392    0.391370    0.054112    0.024042    0.654818    
#> 280: 0.208969    0.912453    3.368389    0.390635    0.054059    0.024074    0.654608    
#> 281: 0.208532    0.912623    3.368301    0.390102    0.054065    0.024010    0.654496    
#> 282: 0.208366    0.912762    3.368324    0.389299    0.054152    0.024005    0.654490    
#> 283: 0.208439    0.912861    3.368473    0.388959    0.054312    0.024033    0.654876    
#> 284: 0.208726    0.912672    3.368568    0.388478    0.054311    0.024041    0.654726    
#> 285: 0.208528    0.912700    3.368474    0.388305    0.054358    0.024031    0.654668    
#> 286: 0.208217    0.912714    3.368333    0.387828    0.054448    0.024045    0.654701    
#> 287: 0.207758    0.913008    3.368099    0.387703    0.054354    0.024122    0.654765    
#> 288: 0.207582    0.913092    3.367944    0.387840    0.054460    0.024150    0.654851    
#> 289: 0.207770    0.913027    3.367871    0.387730    0.054527    0.024140    0.654878    
#> 290: 0.207923    0.912876    3.367961    0.387853    0.054775    0.024154    0.654934    
#> 291: 0.207872    0.912921    3.367950    0.388010    0.054836    0.024147    0.654906    
#> 292: 0.207562    0.912945    3.367824    0.387934    0.054868    0.024141    0.654872    
#> 293: 0.206984    0.912960    3.367538    0.387855    0.054825    0.024169    0.654837    
#> 294: 0.206767    0.913078    3.367317    0.387572    0.054832    0.024161    0.654900    
#> 295: 0.206495    0.912964    3.367203    0.387475    0.054876    0.024127    0.654798    
#> 296: 0.206342    0.912902    3.367144    0.387579    0.054785    0.024112    0.654827    
#> 297: 0.206174    0.912964    3.367077    0.387290    0.054735    0.024074    0.654947    
#> 298: 0.205868    0.912942    3.366984    0.387535    0.054840    0.024073    0.654825    
#> 299: 0.205578    0.913064    3.366881    0.387560    0.054782    0.024103    0.654571    
#> 300: 0.205575    0.912964    3.366809    0.387589    0.054719    0.024086    0.654531    
#> 301: 0.205401    0.912877    3.366691    0.387564    0.054610    0.024081    0.654563    
#> 302: 0.205415    0.912838    3.366606    0.387739    0.054582    0.024034    0.654542    
#> 303: 0.205075    0.913039    3.366480    0.387450    0.054553    0.023983    0.654405    
#> 304: 0.204868    0.913431    3.366322    0.387162    0.054603    0.023928    0.654430    
#> 305: 0.204602    0.913482    3.366159    0.387033    0.054635    0.023886    0.654365    
#> 306: 0.204265    0.913406    3.366148    0.386690    0.054563    0.023848    0.654314    
#> 307: 0.204231    0.913423    3.366108    0.386655    0.054509    0.023847    0.654315    
#> 308: 0.203896    0.913402    3.365986    0.386738    0.054508    0.023828    0.654298    
#> 309: 0.203766    0.913242    3.365954    0.386805    0.054468    0.023818    0.654535    
#> 310: 0.203942    0.913171    3.365906    0.387308    0.054414    0.023819    0.654437    
#> 311: 0.203968    0.913138    3.365970    0.387217    0.054408    0.023806    0.654256    
#> 312: 0.203923    0.913130    3.365914    0.387276    0.054361    0.023793    0.654226    
#> 313: 0.203815    0.912920    3.365763    0.387352    0.054343    0.023806    0.654352    
#> 314: 0.203484    0.912996    3.365643    0.387226    0.054317    0.023797    0.654375    
#> 315: 0.203277    0.913237    3.365461    0.387765    0.054389    0.023807    0.654255    
#> 316: 0.203089    0.913297    3.365339    0.387427    0.054506    0.023803    0.654029    
#> 317: 0.203036    0.913356    3.365336    0.387472    0.054608    0.023749    0.654107    
#> 318: 0.202972    0.913537    3.365221    0.387655    0.054703    0.023715    0.654072    
#> 319: 0.202792    0.913524    3.365193    0.387629    0.054702    0.023692    0.654141    
#> 320: 0.202299    0.913466    3.365116    0.387472    0.054766    0.023670    0.654237    
#> 321: 0.201939    0.913594    3.364958    0.387278    0.054842    0.023614    0.654341    
#> 322: 0.201611    0.913775    3.364683    0.387595    0.054971    0.023566    0.654402    
#> 323: 0.200960    0.913981    3.364418    0.387550    0.055017    0.023521    0.654494    
#> 324: 0.200642    0.914109    3.364311    0.387648    0.055076    0.023459    0.654569    
#> 325: 0.200315    0.914302    3.364159    0.387488    0.055058    0.023392    0.654604    
#> 326: 0.200036    0.914361    3.364064    0.387630    0.055126    0.023343    0.654583    
#> 327: 0.199935    0.914357    3.364039    0.387642    0.055091    0.023278    0.654642    
#> 328: 0.199865    0.914461    3.363985    0.387396    0.055132    0.023248    0.654552    
#> 329: 0.200091    0.914538    3.364019    0.387768    0.055222    0.023218    0.654440    
#> 330: 0.199932    0.914577    3.363977    0.387661    0.055294    0.023159    0.654399    
#> 331: 0.200086    0.914637    3.364107    0.387350    0.055282    0.023149    0.654429    
#> 332: 0.200201    0.914503    3.364267    0.387061    0.055230    0.023169    0.654586    
#> 333: 0.200199    0.914442    3.364268    0.386708    0.055179    0.023170    0.654663    
#> 334: 0.200094    0.914377    3.364164    0.386689    0.055167    0.023132    0.654707    
#> 335: 0.199861    0.914415    3.364098    0.386344    0.055139    0.023121    0.654764    
#> 336: 0.199569    0.914465    3.364068    0.385868    0.055190    0.023100    0.654864    
#> 337: 0.199329    0.914698    3.363971    0.385414    0.055211    0.023099    0.654899    
#> 338: 0.199267    0.914746    3.363926    0.385141    0.055237    0.023051    0.654845    
#> 339: 0.199100    0.914948    3.363799    0.385274    0.055239    0.023003    0.654724    
#> 340: 0.198852    0.914864    3.363716    0.385259    0.055216    0.022980    0.654686    
#> 341: 0.198761    0.914814    3.363668    0.385438    0.055245    0.022956    0.654681    
#> 342: 0.198504    0.914664    3.363623    0.385182    0.055170    0.022941    0.654650    
#> 343: 0.198224    0.914635    3.363592    0.385153    0.055183    0.022939    0.654591    
#> 344: 0.198125    0.914650    3.363563    0.385085    0.055209    0.022968    0.654601    
#> 345: 0.198094    0.914657    3.363609    0.385089    0.055278    0.022951    0.654574    
#> 346: 0.198077    0.914671    3.363587    0.384955    0.055324    0.022930    0.654603    
#> 347: 0.198119    0.914572    3.363551    0.385034    0.055359    0.022917    0.654801    
#> 348: 0.198096    0.914642    3.363520    0.385491    0.055384    0.022906    0.654903    
#> 349: 0.198148    0.914602    3.363539    0.385718    0.055463    0.022887    0.654957    
#> 350: 0.198150    0.914472    3.363568    0.385871    0.055625    0.022867    0.655046    
#> 351: 0.198336    0.914507    3.363574    0.385862    0.055758    0.022846    0.655079    
#> 352: 0.198153    0.914552    3.363552    0.385798    0.055892    0.022850    0.655204    
#> 353: 0.198330    0.914688    3.363559    0.385691    0.056041    0.022821    0.655163    
#> 354: 0.198250    0.914746    3.363546    0.385421    0.056163    0.022782    0.655149    
#> 355: 0.198643    0.914676    3.363585    0.385509    0.056236    0.022779    0.655177    
#> 356: 0.198639    0.914602    3.363593    0.385371    0.056361    0.022760    0.655315    
#> 357: 0.198593    0.914645    3.363605    0.385212    0.056384    0.022784    0.655298    
#> 358: 0.198657    0.914663    3.363587    0.385416    0.056396    0.022780    0.655260    
#> 359: 0.198608    0.914718    3.363516    0.385566    0.056472    0.022764    0.655231    
#> 360: 0.198336    0.914724    3.363364    0.385353    0.056539    0.022734    0.655258    
#> 361: 0.198168    0.914796    3.363267    0.385383    0.056626    0.022701    0.655203    
#> 362: 0.198197    0.914802    3.363228    0.385452    0.056661    0.022662    0.655067    
#> 363: 0.198151    0.914826    3.363243    0.385207    0.056674    0.022629    0.654981    
#> 364: 0.198131    0.914910    3.363227    0.385191    0.056731    0.022590    0.654946    
#> 365: 0.198004    0.914931    3.363230    0.385326    0.056916    0.022546    0.654810    
#> 366: 0.197957    0.915000    3.363133    0.385856    0.057042    0.022517    0.654669    
#> 367: 0.198168    0.915047    3.363091    0.386425    0.057110    0.022481    0.654566    
#> 368: 0.198288    0.915104    3.363073    0.386352    0.057146    0.022460    0.654500    
#> 369: 0.198162    0.915074    3.363086    0.386323    0.057138    0.022435    0.654525    
#> 370: 0.198076    0.915082    3.363122    0.386224    0.057169    0.022400    0.654466    
#> 371: 0.197944    0.915103    3.363121    0.386095    0.057146    0.022344    0.654524    
#> 372: 0.197917    0.915097    3.363120    0.386149    0.057197    0.022311    0.654471    
#> 373: 0.197747    0.915204    3.363052    0.386133    0.057249    0.022286    0.654464    
#> 374: 0.197720    0.915286    3.362976    0.386423    0.057243    0.022295    0.654370    
#> 375: 0.197539    0.915350    3.362921    0.386691    0.057260    0.022313    0.654330    
#> 376: 0.197563    0.915430    3.362868    0.386707    0.057337    0.022300    0.654225    
#> 377: 0.197609    0.915484    3.362860    0.386596    0.057423    0.022278    0.654183    
#> 378: 0.197475    0.915534    3.362843    0.386573    0.057436    0.022302    0.654128    
#> 379: 0.197370    0.915440    3.362829    0.386558    0.057388    0.022311    0.654129    
#> 380: 0.197192    0.915385    3.362829    0.386229    0.057389    0.022302    0.654182    
#> 381: 0.197065    0.915401    3.362786    0.385977    0.057364    0.022298    0.654200    
#> 382: 0.197000    0.915384    3.362763    0.386143    0.057331    0.022310    0.654078    
#> 383: 0.196881    0.915351    3.362685    0.386153    0.057347    0.022295    0.653932    
#> 384: 0.196705    0.915364    3.362644    0.386224    0.057377    0.022283    0.653858    
#> 385: 0.196621    0.915425    3.362598    0.385854    0.057432    0.022265    0.653772    
#> 386: 0.196603    0.915509    3.362602    0.385513    0.057463    0.022244    0.653747    
#> 387: 0.196654    0.915612    3.362671    0.385587    0.057422    0.022236    0.653692    
#> 388: 0.196702    0.915560    3.362709    0.385423    0.057454    0.022212    0.653653    
#> 389: 0.196659    0.915392    3.362702    0.385397    0.057454    0.022185    0.653788    
#> 390: 0.196603    0.915467    3.362681    0.385365    0.057461    0.022165    0.653766    
#> 391: 0.196826    0.915426    3.362684    0.385524    0.057436    0.022176    0.653750    
#> 392: 0.196958    0.915423    3.362759    0.385672    0.057452    0.022203    0.653770    
#> 393: 0.197054    0.915386    3.362766    0.385672    0.057434    0.022230    0.653752    
#> 394: 0.197296    0.915337    3.362822    0.385706    0.057437    0.022231    0.653795    
#> 395: 0.197469    0.915409    3.362854    0.385752    0.057426    0.022240    0.653797    
#> 396: 0.197594    0.915422    3.362872    0.385661    0.057390    0.022252    0.653733    
#> 397: 0.197611    0.915344    3.362944    0.385364    0.057388    0.022274    0.653758    
#> 398: 0.197687    0.915270    3.362970    0.385040    0.057329    0.022302    0.653796    
#> 399: 0.197766    0.915247    3.363004    0.384996    0.057283    0.022308    0.653743    
#> 400: 0.197871    0.915231    3.363040    0.384702    0.057274    0.022304    0.653665    
#> 401: 0.197979    0.915236    3.363037    0.384747    0.057296    0.022294    0.653623    
#> 402: 0.198016    0.915288    3.363056    0.384786    0.057374    0.022270    0.653595    
#> 403: 0.198254    0.915275    3.363089    0.384851    0.057433    0.022258    0.653533    
#> 404: 0.198253    0.915285    3.363011    0.385176    0.057475    0.022247    0.653465    
#> 405: 0.198251    0.915338    3.363001    0.385649    0.057530    0.022233    0.653492    
#> 406: 0.198210    0.915397    3.362929    0.385871    0.057635    0.022231    0.653528    
#> 407: 0.198171    0.915481    3.362935    0.385932    0.057723    0.022222    0.653554    
#> 408: 0.198212    0.915587    3.362898    0.385754    0.057743    0.022215    0.653591    
#> 409: 0.198154    0.915513    3.362881    0.385566    0.057726    0.022200    0.653557    
#> 410: 0.198094    0.915505    3.362835    0.385502    0.057747    0.022190    0.653575    
#> 411: 0.197999    0.915350    3.362843    0.385119    0.057729    0.022162    0.653720    
#> 412: 0.198165    0.915357    3.362903    0.385096    0.057724    0.022159    0.653800    
#> 413: 0.198402    0.915389    3.362948    0.385474    0.057737    0.022157    0.653795    
#> 414: 0.198361    0.915457    3.362970    0.385654    0.057787    0.022149    0.653851    
#> 415: 0.198469    0.915491    3.362975    0.386073    0.057866    0.022148    0.653809    
#> 416: 0.198621    0.915510    3.362992    0.386190    0.057906    0.022165    0.653771    
#> 417: 0.198726    0.915469    3.363029    0.386169    0.057909    0.022183    0.653716    
#> 418: 0.198640    0.915392    3.363069    0.386028    0.057917    0.022202    0.653706    
#> 419: 0.198669    0.915430    3.363059    0.386106    0.057943    0.022209    0.653669    
#> 420: 0.198642    0.915479    3.363015    0.386036    0.058011    0.022211    0.653600    
#> 421: 0.198574    0.915513    3.363015    0.385999    0.058113    0.022208    0.653578    
#> 422: 0.198653    0.915452    3.363012    0.385711    0.058227    0.022199    0.653572    
#> 423: 0.198723    0.915367    3.363027    0.385692    0.058284    0.022193    0.653553    
#> 424: 0.198643    0.915377    3.362975    0.385638    0.058338    0.022181    0.653509    
#> 425: 0.198643    0.915438    3.362925    0.385721    0.058373    0.022161    0.653559    
#> 426: 0.198499    0.915548    3.362880    0.385807    0.058414    0.022147    0.653567    
#> 427: 0.198333    0.915589    3.362848    0.385854    0.058392    0.022137    0.653541    
#> 428: 0.198177    0.915666    3.362832    0.385711    0.058405    0.022139    0.653526    
#> 429: 0.198128    0.915716    3.362830    0.385640    0.058422    0.022152    0.653464    
#> 430: 0.198178    0.915749    3.362805    0.386105    0.058435    0.022166    0.653452    
#> 431: 0.198183    0.915772    3.362766    0.386344    0.058418    0.022161    0.653411    
#> 432: 0.198025    0.915847    3.362733    0.386296    0.058423    0.022159    0.653308    
#> 433: 0.198038    0.915908    3.362734    0.386501    0.058455    0.022138    0.653303    
#> 434: 0.197957    0.915809    3.362714    0.386419    0.058453    0.022131    0.653336    
#> 435: 0.198027    0.915794    3.362690    0.386611    0.058421    0.022154    0.653288    
#> 436: 0.198006    0.915809    3.362687    0.386527    0.058364    0.022161    0.653294    
#> 437: 0.197993    0.915815    3.362679    0.386498    0.058328    0.022167    0.653292    
#> 438: 0.197936    0.915917    3.362655    0.386474    0.058265    0.022162    0.653247    
#> 439: 0.197924    0.915970    3.362651    0.386428    0.058223    0.022158    0.653174    
#> 440: 0.198045    0.915998    3.362641    0.386416    0.058225    0.022148    0.653084    
#> 441: 0.198065    0.915973    3.362654    0.386220    0.058290    0.022134    0.653001    
#> 442: 0.197898    0.916036    3.362658    0.386075    0.058348    0.022110    0.652950    
#> 443: 0.197812    0.916100    3.362605    0.386202    0.058322    0.022111    0.652883    
#> 444: 0.197540    0.916230    3.362483    0.386257    0.058311    0.022120    0.652838    
#> 445: 0.197297    0.916392    3.362372    0.386275    0.058280    0.022121    0.652893    
#> 446: 0.197110    0.916528    3.362296    0.386253    0.058244    0.022118    0.652907    
#> 447: 0.197132    0.916586    3.362298    0.386309    0.058206    0.022135    0.652888    
#> 448: 0.197149    0.916599    3.362328    0.386334    0.058174    0.022148    0.652819    
#> 449: 0.197369    0.916570    3.362442    0.386534    0.058167    0.022157    0.652826    
#> 450: 0.197495    0.916477    3.362477    0.386713    0.058147    0.022167    0.652827    
#> 451: 0.197631    0.916416    3.362513    0.386801    0.058149    0.022188    0.652872    
#> 452: 0.197620    0.916407    3.362496    0.386718    0.058144    0.022190    0.652851    
#> 453: 0.197605    0.916414    3.362482    0.386692    0.058147    0.022192    0.652772    
#> 454: 0.197535    0.916577    3.362444    0.386533    0.058175    0.022183    0.652713    
#> 455: 0.197574    0.916670    3.362444    0.386439    0.058232    0.022178    0.652667    
#> 456: 0.197525    0.916660    3.362454    0.386353    0.058274    0.022178    0.652629    
#> 457: 0.197440    0.916686    3.362453    0.386248    0.058320    0.022177    0.652554    
#> 458: 0.197385    0.916801    3.362452    0.386212    0.058340    0.022179    0.652522    
#> 459: 0.197170    0.916965    3.362411    0.386423    0.058357    0.022179    0.652570    
#> 460: 0.196945    0.917084    3.362307    0.386591    0.058391    0.022176    0.652564    
#> 461: 0.196762    0.917178    3.362269    0.386518    0.058447    0.022169    0.652548    
#> 462: 0.196716    0.917170    3.362249    0.386769    0.058443    0.022147    0.652568    
#> 463: 0.196744    0.917180    3.362256    0.387108    0.058445    0.022131    0.652583    
#> 464: 0.196812    0.917195    3.362258    0.387261    0.058435    0.022128    0.652506    
#> 465: 0.196951    0.917050    3.362279    0.387508    0.058430    0.022117    0.652508    
#> 466: 0.197067    0.917051    3.362283    0.387964    0.058430    0.022115    0.652465    
#> 467: 0.197150    0.917025    3.362294    0.388235    0.058422    0.022124    0.652379    
#> 468: 0.197335    0.917025    3.362306    0.388588    0.058386    0.022154    0.652323    
#> 469: 0.197322    0.917129    3.362305    0.388670    0.058366    0.022180    0.652387    
#> 470: 0.197138    0.917188    3.362249    0.388538    0.058317    0.022207    0.652424    
#> 471: 0.196919    0.917188    3.362196    0.388299    0.058309    0.022219    0.652425    
#> 472: 0.196719    0.917235    3.362137    0.388121    0.058292    0.022240    0.652407    
#> 473: 0.196569    0.917264    3.362111    0.388134    0.058270    0.022249    0.652332    
#> 474: 0.196431    0.917273    3.362090    0.388222    0.058292    0.022248    0.652350    
#> 475: 0.196406    0.917401    3.362056    0.388292    0.058304    0.022258    0.652302    
#> 476: 0.196392    0.917394    3.362062    0.388430    0.058319    0.022273    0.652304    
#> 477: 0.196349    0.917423    3.362094    0.388420    0.058297    0.022279    0.652225    
#> 478: 0.196296    0.917409    3.362090    0.388477    0.058283    0.022279    0.652292    
#> 479: 0.196399    0.917396    3.362098    0.388573    0.058278    0.022269    0.652337    
#> 480: 0.196469    0.917377    3.362075    0.388543    0.058252    0.022271    0.652451    
#> 481: 0.196346    0.917437    3.362059    0.388524    0.058270    0.022264    0.652531    
#> 482: 0.196317    0.917496    3.362017    0.388591    0.058288    0.022272    0.652521    
#> 483: 0.196216    0.917495    3.361982    0.388588    0.058295    0.022267    0.652526    
#> 484: 0.196122    0.917380    3.361988    0.388476    0.058312    0.022257    0.652558    
#> 485: 0.196015    0.917378    3.361966    0.388428    0.058367    0.022238    0.652545    
#> 486: 0.196095    0.917404    3.362007    0.388571    0.058387    0.022224    0.652502    
#> 487: 0.196163    0.917423    3.362032    0.388588    0.058393    0.022211    0.652502    
#> 488: 0.196211    0.917394    3.362039    0.388590    0.058427    0.022189    0.652498    
#> 489: 0.196364    0.917381    3.362034    0.388641    0.058500    0.022171    0.652521    
#> 490: 0.196416    0.917424    3.362017    0.388747    0.058516    0.022165    0.652475    
#> 491: 0.196359    0.917496    3.361966    0.388885    0.058521    0.022152    0.652450    
#> 492: 0.196211    0.917568    3.361889    0.388913    0.058506    0.022127    0.652484    
#> 493: 0.196091    0.917630    3.361862    0.389060    0.058510    0.022117    0.652481    
#> 494: 0.196198    0.917682    3.361858    0.389196    0.058527    0.022118    0.652438    
#> 495: 0.196275    0.917719    3.361845    0.389164    0.058535    0.022107    0.652415    
#> 496: 0.196309    0.917771    3.361786    0.389307    0.058509    0.022097    0.652459    
#> 497: 0.196295    0.917761    3.361730    0.389448    0.058543    0.022077    0.652547    
#> 498: 0.196285    0.917760    3.361689    0.389717    0.058544    0.022065    0.652514    
#> 499: 0.196357    0.917786    3.361671    0.389787    0.058549    0.022051    0.652480    
#> 500: 0.196402    0.917747    3.361671    0.389863    0.058528    0.022047    0.652449    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.307688    0.961768    3.436703    0.392401    0.078700    0.016800    1.859964    
#> 002: 0.365439    0.914304    3.438026    0.375040    0.074765    0.015960    1.180578    
#> 003: 0.529011    0.817650    3.436416    0.437323    0.076283    0.015162    0.839675    
#> 004: 0.469170    0.811923    3.424230    0.613146    0.072469    0.014404    0.670135    
#> 005: 0.510348    0.800512    3.408193    0.671672    0.072632    0.013684    0.615784    
#> 006: 0.550992    0.812891    3.400149    0.838114    0.070295    0.013000    0.544539    
#> 007: 0.519369    0.838985    3.385290    0.934592    0.066780    0.012350    0.553346    
#> 008: 0.500456    0.832587    3.384544    0.887862    0.063441    0.014113    0.541030    
#> 009: 0.474731    0.823241    3.372672    0.962897    0.060269    0.013408    0.535034    
#> 010: 0.473263    0.819628    3.373192    1.019820    0.057256    0.012737    0.543114    
#> 011: 0.490827    0.830987    3.378860    0.968829    0.054393    0.012100    0.542792    
#> 012: 0.492356    0.831092    3.371195    0.986704    0.056848    0.012060    0.527708    
#> 013: 0.481087    0.833748    3.374389    0.937369    0.057248    0.011465    0.535607    
#> 014: 0.531997    0.830488    3.380762    0.991948    0.060380    0.011850    0.539552    
#> 015: 0.525919    0.839798    3.389264    0.945203    0.062624    0.011258    0.514674    
#> 016: 0.507289    0.845868    3.387703    0.897943    0.059493    0.011069    0.533351    
#> 017: 0.519809    0.852518    3.387203    0.957291    0.058986    0.011915    0.507680    
#> 018: 0.532084    0.850629    3.377147    0.981462    0.056406    0.011375    0.511151    
#> 019: 0.520487    0.843237    3.380240    1.032457    0.058996    0.011044    0.506745    
#> 020: 0.543270    0.842071    3.381173    1.173932    0.056046    0.013996    0.530365    
#> 021: 0.535562    0.826014    3.381933    1.115235    0.054471    0.013736    0.514771    
#> 022: 0.540138    0.854522    3.391354    1.059474    0.058429    0.013049    0.508866    
#> 023: 0.587191    0.852934    3.390511    1.112370    0.055507    0.012397    0.524117    
#> 024: 0.524196    0.863734    3.385367    1.056752    0.052732    0.012966    0.518327    
#> 025: 0.546534    0.842690    3.378849    1.136671    0.050095    0.014885    0.523602    
#> 026: 0.604042    0.854948    3.379554    1.362577    0.048178    0.016421    0.530420    
#> 027: 0.556387    0.853847    3.378473    1.294448    0.045769    0.016196    0.541674    
#> 028: 0.600472    0.857918    3.382466    1.405731    0.046511    0.016220    0.528194    
#> 029: 0.594565    0.860553    3.371298    1.442368    0.048587    0.016596    0.520520    
#> 030: 0.609603    0.862250    3.364035    1.470393    0.046158    0.015766    0.508776    
#> 031: 0.552063    0.849953    3.372858    1.396873    0.043850    0.014978    0.513710    
#> 032: 0.540256    0.843780    3.377658    1.327030    0.045022    0.014229    0.519816    
#> 033: 0.550521    0.844356    3.375582    1.260678    0.045454    0.013518    0.529058    
#> 034: 0.621063    0.844682    3.379621    1.438711    0.052398    0.012842    0.511416    
#> 035: 0.541892    0.838135    3.370832    1.366775    0.052121    0.013337    0.513408    
#> 036: 0.569310    0.846682    3.377096    1.298437    0.049515    0.014020    0.535720    
#> 037: 0.577890    0.841834    3.378243    1.253735    0.047039    0.013881    0.538597    
#> 038: 0.584069    0.834138    3.380478    1.300925    0.044687    0.015629    0.531350    
#> 039: 0.575399    0.819756    3.389421    1.235879    0.042453    0.014848    0.538254    
#> 040: 0.555988    0.826830    3.392086    1.189129    0.048145    0.015825    0.510417    
#> 041: 0.490584    0.835200    3.384819    1.129673    0.048336    0.016740    0.512592    
#> 042: 0.492014    0.833935    3.378264    1.073189    0.050951    0.015903    0.516709    
#> 043: 0.476847    0.841386    3.368882    1.019530    0.050219    0.015108    0.525689    
#> 044: 0.463306    0.845623    3.367232    0.968553    0.047708    0.014532    0.523768    
#> 045: 0.511158    0.837254    3.373941    1.143438    0.045323    0.013806    0.525157    
#> 046: 0.553507    0.830374    3.380916    1.273970    0.043057    0.015143    0.518508    
#> 047: 0.593861    0.833233    3.385232    1.220603    0.052637    0.014826    0.526229    
#> 048: 0.547118    0.843189    3.373166    1.159572    0.057977    0.014085    0.533417    
#> 049: 0.514813    0.829416    3.381871    1.101594    0.055078    0.013381    0.530236    
#> 050: 0.539505    0.811379    3.379978    1.106404    0.052908    0.013038    0.548899    
#> 051: 0.571144    0.834492    3.374844    1.325474    0.054275    0.017215    0.545327    
#> 052: 0.603307    0.831180    3.386808    1.436325    0.051561    0.018004    0.540889    
#> 053: 0.604980    0.827250    3.380353    1.364509    0.058786    0.017554    0.524313    
#> 054: 0.558453    0.847171    3.383694    1.296283    0.056593    0.017559    0.536868    
#> 055: 0.521365    0.843341    3.382373    1.231469    0.057670    0.016994    0.527328    
#> 056: 0.552415    0.843224    3.377770    1.169896    0.056738    0.016145    0.532177    
#> 057: 0.532965    0.846459    3.383949    1.111401    0.053901    0.016438    0.526938    
#> 058: 0.548019    0.838798    3.372072    1.163441    0.054189    0.015616    0.521916    
#> 059: 0.594673    0.823347    3.381538    1.294921    0.051480    0.015953    0.533143    
#> 060: 0.558388    0.817826    3.383986    1.230175    0.057478    0.015340    0.532712    
#> 061: 0.616233    0.832504    3.385792    1.287622    0.054605    0.016705    0.524635    
#> 062: 0.542562    0.839950    3.388390    1.223241    0.051874    0.016688    0.535736    
#> 063: 0.596958    0.816560    3.385901    1.249337    0.049281    0.015854    0.531658    
#> 064: 0.576447    0.826795    3.391305    1.186870    0.053300    0.015846    0.535550    
#> 065: 0.540328    0.830196    3.383318    1.127527    0.051574    0.015054    0.519394    
#> 066: 0.526003    0.845134    3.377199    1.093994    0.048995    0.014301    0.525532    
#> 067: 0.513187    0.837682    3.377434    1.039294    0.047586    0.013586    0.516407    
#> 068: 0.497915    0.834159    3.379400    0.987329    0.045207    0.014902    0.530032    
#> 069: 0.539194    0.827061    3.380124    1.053776    0.044394    0.014157    0.526273    
#> 070: 0.565353    0.830129    3.381822    1.246211    0.045277    0.015576    0.523494    
#> 071: 0.535323    0.851244    3.371692    1.183901    0.049987    0.014797    0.530801    
#> 072: 0.520187    0.828921    3.380062    1.124706    0.047487    0.014057    0.510279    
#> 073: 0.519605    0.834693    3.389692    1.068470    0.048943    0.015511    0.519284    
#> 074: 0.519871    0.824132    3.384250    1.077254    0.046533    0.016576    0.511574    
#> 075: 0.592887    0.826924    3.389091    1.272470    0.044206    0.016081    0.517538    
#> 076: 0.617771    0.841040    3.398176    1.227179    0.041996    0.015277    0.523073    
#> 077: 0.577859    0.834847    3.393557    1.165820    0.051568    0.015072    0.519999    
#> 078: 0.551715    0.835933    3.395291    1.109821    0.048989    0.015445    0.522672    
#> 079: 0.576943    0.833040    3.388196    1.239405    0.057127    0.014673    0.522534    
#> 080: 0.592678    0.840756    3.388624    1.288776    0.054270    0.013939    0.524726    
#> 081: 0.558500    0.844368    3.387612    1.224337    0.054673    0.013242    0.525165    
#> 082: 0.576500    0.829794    3.389212    1.234817    0.061694    0.012580    0.534631    
#> 083: 0.560549    0.844887    3.389817    1.173076    0.058609    0.011951    0.539545    
#> 084: 0.561408    0.842919    3.389561    1.117564    0.058670    0.013711    0.526829    
#> 085: 0.581383    0.832760    3.391470    1.335632    0.057117    0.015033    0.532611    
#> 086: 0.555735    0.823822    3.386283    1.268851    0.054261    0.015014    0.522474    
#> 087: 0.575630    0.827867    3.382972    1.205408    0.051548    0.016568    0.522310    
#> 088: 0.538694    0.829554    3.390360    1.145138    0.048971    0.015740    0.517805    
#> 089: 0.545018    0.832052    3.385379    1.087881    0.055178    0.014953    0.520956    
#> 090: 0.542477    0.835510    3.380084    1.056163    0.053583    0.014205    0.517133    
#> 091: 0.533124    0.838756    3.376239    1.059391    0.060909    0.015341    0.525403    
#> 092: 0.518819    0.837543    3.366344    1.184704    0.057864    0.017405    0.539245    
#> 093: 0.477063    0.835956    3.369256    1.125469    0.054970    0.016535    0.544694    
#> 094: 0.517137    0.848743    3.375083    1.069196    0.052222    0.020739    0.529320    
#> 095: 0.582628    0.847007    3.376978    1.331834    0.049611    0.021799    0.520872    
#> 096: 0.573507    0.853648    3.367077    1.292765    0.048391    0.020709    0.524456    
#> 097: 0.544731    0.865282    3.364588    1.228127    0.054369    0.019674    0.527681    
#> 098: 0.560019    0.862828    3.370015    1.166720    0.051650    0.019638    0.516297    
#> 099: 0.550517    0.842848    3.368932    1.159812    0.049068    0.018656    0.515155    
#> 100: 0.525996    0.856940    3.373552    1.155843    0.050079    0.017723    0.513014    
#> 101: 0.488873    0.842269    3.358068    1.098051    0.049844    0.016837    0.511975    
#> 102: 0.472160    0.852247    3.356122    1.043148    0.047352    0.015995    0.524456    
#> 103: 0.520185    0.851208    3.365851    1.146542    0.053055    0.015196    0.515364    
#> 104: 0.505387    0.850241    3.376905    1.101013    0.050597    0.014436    0.531093    
#> 105: 0.552065    0.828441    3.375824    1.192816    0.056731    0.013714    0.533059    
#> 106: 0.533956    0.836447    3.378528    1.148573    0.053894    0.013028    0.517126    
#> 107: 0.581448    0.835983    3.380678    1.322590    0.051199    0.012446    0.529074    
#> 108: 0.540276    0.837500    3.382046    1.256460    0.057211    0.013263    0.536216    
#> 109: 0.566187    0.845043    3.392792    1.193637    0.055833    0.014046    0.538786    
#> 110: 0.596333    0.823904    3.377569    1.153576    0.059124    0.013518    0.524979    
#> 111: 0.586327    0.817088    3.384544    1.147212    0.057659    0.012842    0.516227    
#> 112: 0.565314    0.829895    3.377631    1.116543    0.062277    0.013558    0.513999    
#> 113: 0.535476    0.860147    3.376789    1.140778    0.059163    0.013687    0.508577    
#> 114: 0.550534    0.853551    3.370936    1.135398    0.056804    0.013728    0.515804    
#> 115: 0.540331    0.834335    3.372714    1.128756    0.057693    0.015216    0.527668    
#> 116: 0.639143    0.839568    3.371261    1.520651    0.054808    0.015236    0.520203    
#> 117: 0.583891    0.852028    3.378319    1.444618    0.054906    0.014833    0.521522    
#> 118: 0.590392    0.839741    3.377531    1.521718    0.053832    0.015376    0.528138    
#> 119: 0.595085    0.848375    3.371028    1.490900    0.054939    0.014607    0.542266    
#> 120: 0.564659    0.821886    3.379404    1.416355    0.052192    0.013877    0.525233    
#> 121: 0.550179    0.859921    3.372595    1.345538    0.057628    0.013183    0.528344    
#> 122: 0.471669    0.839949    3.375308    1.278261    0.054747    0.012524    0.530644    
#> 123: 0.549677    0.854346    3.374974    1.214348    0.052009    0.011897    0.541224    
#> 124: 0.546885    0.863646    3.376935    1.184773    0.049409    0.011303    0.540520    
#> 125: 0.558662    0.861219    3.369899    1.274697    0.051071    0.012210    0.531330    
#> 126: 0.618598    0.866724    3.360600    1.624337    0.048580    0.011600    0.534532    
#> 127: 0.568919    0.837744    3.361884    1.543121    0.046151    0.011135    0.528165    
#> 128: 0.575737    0.840981    3.373929    1.465965    0.046431    0.011460    0.526234    
#> 129: 0.580470    0.842424    3.381937    1.392666    0.053951    0.013266    0.519717    
#> 130: 0.580295    0.846665    3.372936    1.323151    0.058649    0.012602    0.512091    
#> 131: 0.526438    0.842458    3.360165    1.256993    0.055717    0.011972    0.524740    
#> 132: 0.501244    0.862670    3.363462    1.194144    0.052931    0.012350    0.529120    
#> 133: 0.524573    0.833613    3.372416    1.142231    0.050284    0.011732    0.520799    
#> 134: 0.482306    0.824036    3.380252    1.085119    0.047770    0.012028    0.529843    
#> 135: 0.505385    0.837753    3.382710    1.030863    0.054220    0.011569    0.528349    
#> 136: 0.516199    0.824253    3.381654    0.979320    0.052289    0.011049    0.520452    
#> 137: 0.526226    0.828996    3.386869    0.990230    0.049675    0.014852    0.520204    
#> 138: 0.547198    0.831933    3.379898    1.030234    0.052726    0.014109    0.521087    
#> 139: 0.504278    0.841655    3.384143    1.046785    0.056988    0.013404    0.524051    
#> 140: 0.539712    0.846108    3.386496    1.219479    0.054139    0.012733    0.536342    
#> 141: 0.602951    0.821321    3.382907    1.440374    0.057981    0.012097    0.525435    
#> 142: 0.572872    0.830970    3.392179    1.368356    0.060995    0.011492    0.529394    
#> 143: 0.545427    0.834946    3.381136    1.299938    0.057945    0.012145    0.539032    
#> 144: 0.527388    0.841475    3.386464    1.234941    0.055048    0.014078    0.528029    
#> 145: 0.503153    0.840092    3.369198    1.173194    0.053690    0.013374    0.526378    
#> 146: 0.527264    0.855369    3.370849    1.114534    0.062620    0.012705    0.519121    
#> 147: 0.481101    0.847773    3.370499    1.058808    0.059489    0.013753    0.517034    
#> 148: 0.469216    0.852205    3.381912    1.005867    0.056515    0.013066    0.516655    
#> 149: 0.489283    0.828956    3.387069    0.955574    0.053689    0.013463    0.517853    
#> 150: 0.501956    0.833959    3.374983    0.944268    0.060905    0.014120    0.525010    
#> 151: 0.478496    0.855951    3.374349    0.954980    0.057859    0.013414    0.509986    
#> 152: 0.500336    0.856410    3.371937    1.014309    0.054991    0.011710    0.509320    
#> 153: 0.495812    0.856689    3.376604    1.067009    0.054673    0.010879    0.521775    
#> 154: 0.513142    0.865794    3.378369    1.055509    0.056470    0.011731    0.522264    
#> 155: 0.535212    0.844187    3.374640    1.150954    0.054309    0.010660    0.518109    
#> 156: 0.544246    0.845876    3.385223    1.069107    0.051544    0.013363    0.532734    
#> 157: 0.520664    0.828186    3.385632    1.058282    0.062668    0.015330    0.524923    
#> 158: 0.530759    0.840965    3.378858    1.039019    0.062280    0.012666    0.524137    
#> 159: 0.538649    0.840270    3.383920    1.060782    0.060768    0.015154    0.528411    
#> 160: 0.579200    0.813676    3.389395    1.308755    0.059138    0.017092    0.527545    
#> 161: 0.577733    0.831150    3.384988    1.257118    0.069086    0.015798    0.533406    
#> 162: 0.598766    0.839080    3.373250    1.402001    0.070467    0.013628    0.537606    
#> 163: 0.602375    0.840223    3.373043    1.469362    0.067509    0.014212    0.529024    
#> 164: 0.593418    0.864364    3.369377    1.363603    0.062814    0.012204    0.520991    
#> 165: 0.578195    0.850965    3.374142    1.307823    0.064098    0.012292    0.521336    
#> 166: 0.638874    0.866425    3.373525    1.484470    0.060909    0.012028    0.527527    
#> 167: 0.596045    0.864665    3.372180    1.341942    0.059339    0.010766    0.531233    
#> 168: 0.538022    0.858909    3.375997    1.153309    0.063331    0.010820    0.524258    
#> 169: 0.566716    0.880265    3.374812    1.142972    0.063589    0.011262    0.539710    
#> 170: 0.520787    0.859243    3.378110    1.042700    0.057824    0.012950    0.530038    
#> 171: 0.496420    0.853740    3.369056    1.058787    0.068858    0.010799    0.535649    
#> 172: 0.497445    0.851365    3.367933    1.007421    0.071130    0.009422    0.526641    
#> 173: 0.504006    0.864370    3.361803    1.037669    0.069196    0.011362    0.521715    
#> 174: 0.533232    0.833818    3.376410    1.104375    0.060718    0.010784    0.514303    
#> 175: 0.479255    0.836058    3.362124    1.024355    0.057742    0.011578    0.531478    
#> 176: 0.534096    0.852883    3.379573    1.131397    0.059221    0.011613    0.513598    
#> 177: 0.544374    0.842207    3.374388    1.165519    0.052204    0.010799    0.529095    
#> 178: 0.499227    0.853985    3.369275    1.006261    0.052340    0.009995    0.536787    
#> 179: 0.515645    0.868995    3.368986    0.968979    0.050422    0.011833    0.529584    
#> 180: 0.472034    0.861509    3.374349    0.888158    0.052720    0.011731    0.530311    
#> 181: 0.522887    0.854713    3.360948    1.081780    0.052471    0.012876    0.522149    
#> 182: 0.445317    0.842249    3.360269    0.899937    0.055436    0.012118    0.533026    
#> 183: 0.518968    0.865268    3.354138    1.126628    0.048467    0.014251    0.522570    
#> 184: 0.522960    0.860837    3.367536    1.116283    0.054576    0.014637    0.508507    
#> 185: 0.508932    0.874514    3.363514    1.143469    0.057779    0.015798    0.524013    
#> 186: 0.481188    0.870322    3.361702    1.057831    0.056790    0.015399    0.547158    
#> 187: 0.554517    0.844602    3.378242    1.209533    0.046541    0.013272    0.537071    
#> 188: 0.530533    0.855386    3.376389    1.190530    0.048211    0.013646    0.539422    
#> 189: 0.536463    0.862918    3.378601    1.117939    0.051282    0.011275    0.537443    
#> 190: 0.483957    0.863189    3.370970    1.023183    0.050186    0.011443    0.533387    
#> 191: 0.560417    0.855972    3.374357    1.194725    0.047986    0.012717    0.515548    
#> 192: 0.532960    0.856971    3.373427    1.115412    0.044775    0.012897    0.522526    
#> 193: 0.568442    0.860832    3.375435    1.267410    0.048251    0.013645    0.519664    
#> 194: 0.560775    0.860349    3.368365    1.229383    0.055259    0.015125    0.520676    
#> 195: 0.483197    0.851367    3.367136    1.016945    0.053526    0.014902    0.522282    
#> 196: 0.514699    0.843993    3.370359    1.118577    0.052678    0.013570    0.512438    
#> 197: 0.492289    0.847103    3.379423    1.051559    0.056772    0.012776    0.516882    
#> 198: 0.544142    0.836275    3.375011    1.162676    0.067557    0.011667    0.516267    
#> 199: 0.512869    0.837665    3.371913    1.160775    0.060210    0.011875    0.519754    
#> 200: 0.501521    0.845365    3.368581    1.043770    0.065083    0.010710    0.530114    
#> 201: 0.487286    0.851896    3.371905    0.974320    0.064159    0.010729    0.527463    
#> 202: 0.490790    0.856692    3.371472    0.984599    0.062554    0.011317    0.529126    
#> 203: 0.507117    0.858014    3.370042    1.025399    0.062397    0.010875    0.527065    
#> 204: 0.510681    0.854156    3.369833    1.049719    0.062873    0.011038    0.527718    
#> 205: 0.517332    0.856800    3.369177    1.081855    0.064163    0.011150    0.530060    
#> 206: 0.524300    0.858488    3.369183    1.119316    0.064026    0.011200    0.531102    
#> 207: 0.524418    0.858097    3.368521    1.146913    0.063364    0.011175    0.531478    
#> 208: 0.524823    0.859059    3.367807    1.155540    0.063225    0.010968    0.530711    
#> 209: 0.527755    0.857575    3.367039    1.178847    0.062273    0.010861    0.531269    
#> 210: 0.527034    0.855525    3.367733    1.166250    0.062246    0.010863    0.531785    
#> 211: 0.528436    0.856041    3.368193    1.165469    0.061225    0.010934    0.531102    
#> 212: 0.531600    0.856318    3.368554    1.169728    0.059805    0.011191    0.531408    
#> 213: 0.533003    0.854450    3.369390    1.166656    0.059212    0.011457    0.531741    
#> 214: 0.538777    0.853113    3.369919    1.178904    0.058209    0.011512    0.531968    
#> 215: 0.540911    0.851888    3.370935    1.176562    0.057938    0.011525    0.531398    
#> 216: 0.545804    0.849766    3.371849    1.188602    0.057741    0.011522    0.531406    
#> 217: 0.548851    0.849314    3.372468    1.196265    0.057415    0.011605    0.530382    
#> 218: 0.548794    0.849231    3.372589    1.195872    0.057461    0.011658    0.529864    
#> 219: 0.548046    0.848950    3.371980    1.192105    0.057626    0.011607    0.529544    
#> 220: 0.543418    0.849919    3.371646    1.179615    0.057851    0.011600    0.529383    
#> 221: 0.539378    0.850474    3.371147    1.170766    0.057948    0.011620    0.529560    
#> 222: 0.540418    0.850650    3.370511    1.178982    0.058081    0.011716    0.529152    
#> 223: 0.541821    0.851237    3.370199    1.185739    0.058347    0.011791    0.528823    
#> 224: 0.543737    0.851487    3.370218    1.190631    0.058285    0.011834    0.528581    
#> 225: 0.543910    0.850471    3.370768    1.187499    0.058515    0.011756    0.528709    
#> 226: 0.545711    0.848940    3.370908    1.191153    0.058229    0.011750    0.528593    
#> 227: 0.544619    0.848892    3.370835    1.187537    0.058613    0.011700    0.527947    
#> 228: 0.542491    0.849316    3.370593    1.180050    0.058693    0.011676    0.527615    
#> 229: 0.541171    0.849309    3.370556    1.174590    0.058680    0.011687    0.527094    
#> 230: 0.539626    0.848833    3.370572    1.166908    0.058391    0.011667    0.527151    
#> 231: 0.538286    0.848922    3.370843    1.159666    0.058269    0.011653    0.526671    
#> 232: 0.537774    0.848946    3.371281    1.155630    0.058009    0.011659    0.526063    
#> 233: 0.539515    0.848492    3.371519    1.162728    0.058081    0.011647    0.525801    
#> 234: 0.539906    0.848443    3.371702    1.163439    0.058314    0.011647    0.525472    
#> 235: 0.540563    0.848145    3.371729    1.163376    0.058241    0.011617    0.525330    
#> 236: 0.540307    0.848448    3.371636    1.161739    0.058001    0.011595    0.525227    
#> 237: 0.539831    0.848350    3.371548    1.158655    0.057885    0.011565    0.525423    
#> 238: 0.539558    0.848073    3.371671    1.157062    0.057956    0.011560    0.525883    
#> 239: 0.539456    0.848169    3.371637    1.156060    0.057860    0.011544    0.526144    
#> 240: 0.538558    0.847929    3.371767    1.153548    0.057968    0.011527    0.525876    
#> 241: 0.538615    0.847317    3.371942    1.151785    0.057973    0.011527    0.525490    
#> 242: 0.538762    0.846788    3.372013    1.151128    0.058080    0.011519    0.525693    
#> 243: 0.538622    0.847141    3.372099    1.148810    0.058199    0.011518    0.525871    
#> 244: 0.537863    0.846850    3.372297    1.143711    0.057957    0.011549    0.526172    
#> 245: 0.537894    0.846583    3.372398    1.141510    0.057591    0.011546    0.526825    
#> 246: 0.538592    0.846359    3.372518    1.142358    0.057328    0.011587    0.526854    
#> 247: 0.538741    0.846051    3.372808    1.142321    0.057167    0.011633    0.526732    
#> 248: 0.538563    0.846319    3.372824    1.141225    0.057233    0.011626    0.526450    
#> 249: 0.537769    0.846447    3.372823    1.138500    0.057206    0.011627    0.526563    
#> 250: 0.537829    0.846640    3.372810    1.137890    0.057117    0.011638    0.526664    
#> 251: 0.538615    0.846803    3.372951    1.140760    0.057193    0.011624    0.526594    
#> 252: 0.539011    0.846944    3.373266    1.141302    0.057194    0.011599    0.526722    
#> 253: 0.539321    0.846841    3.373443    1.140979    0.057216    0.011614    0.526808    
#> 254: 0.540107    0.847054    3.373693    1.142394    0.057258    0.011648    0.526780    
#> 255: 0.540453    0.847002    3.373872    1.143157    0.057281    0.011686    0.526828    
#> 256: 0.540003    0.846766    3.373959    1.140203    0.057380    0.011663    0.526892    
#> 257: 0.538948    0.846361    3.374110    1.135429    0.057392    0.011627    0.526997    
#> 258: 0.538902    0.845940    3.374318    1.133932    0.057323    0.011656    0.526883    
#> 259: 0.539183    0.845707    3.374474    1.133230    0.057256    0.011661    0.526925    
#> 260: 0.539191    0.845707    3.374677    1.130184    0.057298    0.011657    0.526912    
#> 261: 0.539167    0.845610    3.374949    1.127339    0.057189    0.011685    0.526757    
#> 262: 0.539755    0.845662    3.375188    1.128621    0.057245    0.011698    0.526678    
#> 263: 0.539629    0.845586    3.375369    1.126757    0.057385    0.011712    0.526767    
#> 264: 0.539734    0.845636    3.375516    1.125763    0.057441    0.011740    0.526886    
#> 265: 0.540774    0.845531    3.375689    1.127954    0.057358    0.011756    0.527149    
#> 266: 0.541780    0.845597    3.375817    1.130726    0.057294    0.011736    0.527364    
#> 267: 0.543145    0.845351    3.375968    1.135213    0.057387    0.011738    0.527429    
#> 268: 0.543978    0.844873    3.376071    1.136387    0.057372    0.011741    0.527417    
#> 269: 0.544840    0.844545    3.376222    1.137723    0.057345    0.011760    0.527540    
#> 270: 0.546155    0.844458    3.376288    1.141661    0.057321    0.011780    0.527445    
#> 271: 0.546434    0.844354    3.376311    1.143791    0.057321    0.011823    0.527646    
#> 272: 0.547129    0.844116    3.376338    1.145654    0.057241    0.011850    0.527779    
#> 273: 0.547697    0.844109    3.376374    1.149761    0.057099    0.011888    0.527909    
#> 274: 0.547824    0.844180    3.376448    1.150321    0.057234    0.011889    0.527961    
#> 275: 0.547142    0.844285    3.376382    1.148032    0.057312    0.011874    0.527836    
#> 276: 0.547438    0.844534    3.376436    1.149917    0.057302    0.011892    0.527853    
#> 277: 0.547170    0.844619    3.376560    1.149421    0.057216    0.011914    0.527809    
#> 278: 0.546530    0.844580    3.376732    1.146815    0.057231    0.011924    0.527810    
#> 279: 0.546409    0.844408    3.376862    1.146107    0.057209    0.011927    0.528057    
#> 280: 0.546175    0.844414    3.376940    1.145156    0.057074    0.011936    0.528015    
#> 281: 0.545994    0.844346    3.377076    1.143951    0.057004    0.011933    0.527862    
#> 282: 0.546465    0.844390    3.377185    1.145418    0.056953    0.011960    0.527751    
#> 283: 0.546460    0.844440    3.377213    1.145234    0.056899    0.011997    0.527718    
#> 284: 0.546675    0.844289    3.377291    1.145757    0.056874    0.012038    0.527554    
#> 285: 0.546596    0.844179    3.377309    1.144880    0.056772    0.012075    0.527556    
#> 286: 0.546367    0.844228    3.377276    1.143173    0.056637    0.012089    0.527411    
#> 287: 0.546178    0.844238    3.377266    1.141807    0.056446    0.012099    0.527516    
#> 288: 0.546313    0.844144    3.377349    1.141035    0.056401    0.012117    0.527694    
#> 289: 0.546498    0.844001    3.377416    1.141054    0.056277    0.012136    0.527657    
#> 290: 0.546926    0.843877    3.377544    1.141977    0.056196    0.012187    0.527665    
#> 291: 0.547844    0.844017    3.377715    1.144799    0.056107    0.012224    0.527616    
#> 292: 0.548076    0.843962    3.377769    1.145364    0.056016    0.012223    0.527636    
#> 293: 0.548279    0.844038    3.377770    1.146508    0.055963    0.012222    0.527640    
#> 294: 0.548492    0.844074    3.377714    1.147135    0.055879    0.012220    0.527598    
#> 295: 0.548658    0.843962    3.377687    1.148653    0.055892    0.012208    0.527620    
#> 296: 0.548106    0.843960    3.377636    1.147192    0.055878    0.012215    0.527716    
#> 297: 0.547472    0.843981    3.377577    1.145568    0.055843    0.012215    0.527710    
#> 298: 0.546999    0.844051    3.377480    1.144506    0.055813    0.012229    0.527629    
#> 299: 0.546604    0.844198    3.377330    1.144799    0.055766    0.012212    0.527631    
#> 300: 0.546182    0.844206    3.377243    1.144415    0.055678    0.012216    0.527750    
#> 301: 0.545841    0.844163    3.377117    1.144360    0.055613    0.012233    0.527860    
#> 302: 0.545508    0.844342    3.376924    1.143407    0.055622    0.012253    0.527921    
#> 303: 0.544945    0.844529    3.376815    1.141616    0.055511    0.012279    0.527747    
#> 304: 0.545132    0.844833    3.376743    1.142262    0.055496    0.012286    0.527807    
#> 305: 0.545156    0.844720    3.376728    1.142233    0.055465    0.012300    0.527907    
#> 306: 0.544677    0.844521    3.376674    1.141631    0.055402    0.012308    0.527871    
#> 307: 0.544123    0.844409    3.376668    1.141258    0.055280    0.012319    0.527886    
#> 308: 0.543849    0.844334    3.376611    1.141625    0.055226    0.012327    0.527836    
#> 309: 0.544000    0.844118    3.376626    1.142445    0.055089    0.012352    0.528038    
#> 310: 0.543802    0.844080    3.376580    1.141903    0.055037    0.012354    0.528065    
#> 311: 0.543799    0.844115    3.376577    1.142036    0.054910    0.012381    0.528126    
#> 312: 0.544534    0.844080    3.376581    1.145359    0.054736    0.012398    0.528193    
#> 313: 0.544855    0.843937    3.376594    1.146333    0.054672    0.012421    0.528208    
#> 314: 0.544638    0.843961    3.376607    1.145284    0.054613    0.012438    0.528233    
#> 315: 0.544741    0.844002    3.376635    1.145509    0.054587    0.012487    0.528152    
#> 316: 0.545437    0.844131    3.376654    1.147866    0.054507    0.012512    0.528072    
#> 317: 0.545432    0.844113    3.376653    1.148236    0.054439    0.012535    0.528093    
#> 318: 0.545254    0.844079    3.376586    1.147930    0.054389    0.012558    0.528058    
#> 319: 0.545233    0.844067    3.376561    1.147537    0.054376    0.012573    0.528081    
#> 320: 0.544908    0.844130    3.376508    1.147154    0.054315    0.012579    0.528072    
#> 321: 0.545045    0.844334    3.376464    1.147789    0.054269    0.012569    0.528122    
#> 322: 0.545038    0.844463    3.376405    1.148535    0.054264    0.012558    0.527990    
#> 323: 0.544742    0.844490    3.376377    1.148088    0.054212    0.012558    0.527966    
#> 324: 0.544504    0.844509    3.376404    1.147586    0.054237    0.012553    0.527837    
#> 325: 0.544638    0.844539    3.376397    1.148304    0.054249    0.012549    0.527674    
#> 326: 0.544739    0.844367    3.376389    1.148775    0.054287    0.012551    0.527608    
#> 327: 0.545025    0.844275    3.376410    1.150011    0.054305    0.012553    0.527545    
#> 328: 0.545235    0.844347    3.376448    1.150630    0.054340    0.012548    0.527484    
#> 329: 0.545359    0.844309    3.376494    1.151184    0.054383    0.012547    0.527476    
#> 330: 0.545446    0.844252    3.376552    1.151497    0.054435    0.012559    0.527394    
#> 331: 0.545614    0.844388    3.376662    1.152026    0.054454    0.012559    0.527286    
#> 332: 0.546382    0.844350    3.376725    1.153957    0.054412    0.012582    0.527143    
#> 333: 0.546433    0.844300    3.376717    1.154372    0.054413    0.012583    0.527063    
#> 334: 0.545987    0.844135    3.376666    1.153819    0.054400    0.012574    0.527116    
#> 335: 0.546004    0.844129    3.376548    1.154966    0.054377    0.012575    0.527171    
#> 336: 0.545658    0.844276    3.376415    1.155254    0.054359    0.012582    0.527189    
#> 337: 0.545449    0.844551    3.376295    1.155502    0.054390    0.012589    0.527188    
#> 338: 0.545290    0.844615    3.376232    1.156005    0.054391    0.012599    0.527142    
#> 339: 0.545013    0.844688    3.376184    1.155994    0.054386    0.012629    0.527068    
#> 340: 0.544706    0.844554    3.376153    1.155943    0.054427    0.012649    0.527042    
#> 341: 0.544543    0.844498    3.376163    1.155252    0.054432    0.012661    0.527025    
#> 342: 0.544056    0.844403    3.376139    1.153620    0.054412    0.012673    0.527033    
#> 343: 0.543778    0.844307    3.376157    1.152425    0.054347    0.012694    0.526949    
#> 344: 0.544350    0.844318    3.376222    1.154831    0.054405    0.012711    0.526813    
#> 345: 0.544505    0.844262    3.376252    1.155298    0.054420    0.012731    0.526781    
#> 346: 0.544645    0.844188    3.376204    1.154983    0.054395    0.012741    0.526827    
#> 347: 0.544506    0.844153    3.376123    1.154717    0.054353    0.012748    0.526852    
#> 348: 0.543971    0.844182    3.376020    1.153954    0.054345    0.012768    0.526802    
#> 349: 0.543730    0.844139    3.375957    1.154445    0.054427    0.012778    0.526724    
#> 350: 0.543222    0.844008    3.375881    1.153399    0.054447    0.012793    0.526729    
#> 351: 0.542797    0.843979    3.375814    1.152563    0.054396    0.012802    0.526752    
#> 352: 0.542266    0.844013    3.375786    1.151325    0.054363    0.012821    0.526839    
#> 353: 0.542446    0.844044    3.375805    1.151443    0.054369    0.012821    0.526827    
#> 354: 0.542336    0.844015    3.375728    1.151478    0.054331    0.012821    0.526821    
#> 355: 0.542598    0.843877    3.375696    1.152356    0.054332    0.012830    0.526804    
#> 356: 0.542790    0.843785    3.375741    1.151903    0.054351    0.012853    0.526848    
#> 357: 0.542992    0.843824    3.375781    1.152105    0.054360    0.012860    0.526754    
#> 358: 0.543043    0.843859    3.375826    1.151636    0.054374    0.012866    0.526659    
#> 359: 0.542929    0.843955    3.375804    1.150708    0.054406    0.012871    0.526566    
#> 360: 0.542790    0.843981    3.375730    1.150153    0.054414    0.012867    0.526512    
#> 361: 0.542603    0.844009    3.375683    1.149323    0.054429    0.012857    0.526402    
#> 362: 0.542538    0.844012    3.375649    1.148929    0.054432    0.012842    0.526267    
#> 363: 0.542711    0.843915    3.375688    1.149063    0.054431    0.012842    0.526151    
#> 364: 0.542628    0.843881    3.375678    1.148170    0.054480    0.012840    0.526127    
#> 365: 0.542447    0.843841    3.375703    1.147258    0.054484    0.012835    0.526091    
#> 366: 0.542258    0.843802    3.375670    1.146575    0.054462    0.012834    0.526085    
#> 367: 0.542144    0.843785    3.375637    1.145940    0.054480    0.012827    0.526049    
#> 368: 0.541957    0.843883    3.375568    1.145114    0.054494    0.012826    0.525998    
#> 369: 0.541831    0.843943    3.375502    1.145240    0.054468    0.012822    0.526016    
#> 370: 0.541687    0.843974    3.375462    1.145065    0.054474    0.012809    0.525995    
#> 371: 0.541666    0.843988    3.375422    1.145455    0.054443    0.012805    0.525934    
#> 372: 0.541543    0.843964    3.375435    1.145061    0.054450    0.012793    0.525875    
#> 373: 0.541079    0.844008    3.375407    1.143720    0.054491    0.012783    0.525810    
#> 374: 0.540919    0.844037    3.375384    1.143129    0.054495    0.012785    0.525681    
#> 375: 0.540826    0.844142    3.375389    1.142216    0.054544    0.012786    0.525623    
#> 376: 0.540671    0.844206    3.375413    1.141169    0.054588    0.012774    0.525622    
#> 377: 0.540494    0.844288    3.375374    1.140189    0.054604    0.012782    0.525564    
#> 378: 0.540270    0.844318    3.375334    1.139929    0.054569    0.012795    0.525515    
#> 379: 0.540076    0.844232    3.375305    1.139699    0.054558    0.012816    0.525493    
#> 380: 0.539830    0.844199    3.375289    1.139287    0.054554    0.012825    0.525447    
#> 381: 0.539552    0.844207    3.375284    1.138471    0.054534    0.012818    0.525475    
#> 382: 0.539557    0.844167    3.375305    1.137859    0.054521    0.012815    0.525349    
#> 383: 0.539676    0.844196    3.375283    1.137837    0.054528    0.012819    0.525273    
#> 384: 0.539354    0.844233    3.375262    1.137301    0.054525    0.012814    0.525282    
#> 385: 0.539282    0.844277    3.375244    1.137203    0.054506    0.012831    0.525229    
#> 386: 0.539384    0.844390    3.375236    1.137512    0.054473    0.012835    0.525258    
#> 387: 0.539330    0.844507    3.375237    1.137428    0.054444    0.012851    0.525259    
#> 388: 0.539409    0.844567    3.375237    1.137703    0.054426    0.012869    0.525279    
#> 389: 0.539184    0.844511    3.375176    1.137720    0.054429    0.012887    0.525406    
#> 390: 0.538894    0.844597    3.375082    1.137019    0.054400    0.012894    0.525411    
#> 391: 0.538651    0.844593    3.375000    1.136634    0.054377    0.012901    0.525374    
#> 392: 0.538784    0.844637    3.374970    1.137065    0.054365    0.012917    0.525279    
#> 393: 0.539023    0.844630    3.374925    1.138462    0.054370    0.012916    0.525226    
#> 394: 0.539294    0.844699    3.374905    1.139853    0.054347    0.012915    0.525240    
#> 395: 0.539470    0.844813    3.374879    1.141453    0.054347    0.012918    0.525297    
#> 396: 0.539558    0.844942    3.374874    1.142439    0.054306    0.012922    0.525324    
#> 397: 0.539362    0.844954    3.374847    1.142719    0.054274    0.012934    0.525354    
#> 398: 0.539395    0.844930    3.374889    1.142989    0.054229    0.012955    0.525419    
#> 399: 0.539707    0.844905    3.374945    1.143794    0.054179    0.012963    0.525388    
#> 400: 0.539667    0.844962    3.374965    1.143448    0.054200    0.012961    0.525367    
#> 401: 0.539511    0.845038    3.374963    1.142686    0.054187    0.012964    0.525414    
#> 402: 0.539332    0.845068    3.374944    1.142109    0.054157    0.012974    0.525402    
#> 403: 0.539400    0.845103    3.374942    1.142312    0.054147    0.012983    0.525387    
#> 404: 0.539505    0.845132    3.374949    1.142180    0.054150    0.012979    0.525349    
#> 405: 0.539418    0.845143    3.374973    1.141856    0.054157    0.012979    0.525330    
#> 406: 0.539087    0.845237    3.374922    1.141054    0.054184    0.012973    0.525259    
#> 407: 0.538913    0.845256    3.374922    1.140693    0.054177    0.012971    0.525180    
#> 408: 0.538889    0.845289    3.374905    1.140071    0.054150    0.012969    0.525161    
#> 409: 0.538640    0.845222    3.374880    1.139178    0.054158    0.012969    0.525136    
#> 410: 0.538473    0.845228    3.374887    1.138443    0.054178    0.012962    0.525139    
#> 411: 0.538623    0.845146    3.374863    1.139093    0.054160    0.012954    0.525186    
#> 412: 0.538401    0.845183    3.374850    1.138498    0.054126    0.012955    0.525244    
#> 413: 0.538358    0.845253    3.374826    1.138222    0.054142    0.012959    0.525248    
#> 414: 0.538498    0.845294    3.374849    1.139334    0.054144    0.012963    0.525253    
#> 415: 0.538480    0.845255    3.374830    1.139370    0.054123    0.012956    0.525248    
#> 416: 0.538344    0.845278    3.374858    1.138590    0.054134    0.012955    0.525269    
#> 417: 0.538580    0.845267    3.374884    1.139408    0.054143    0.012953    0.525193    
#> 418: 0.538546    0.845202    3.374895    1.139492    0.054155    0.012962    0.525163    
#> 419: 0.538862    0.845163    3.374903    1.140701    0.054156    0.012974    0.525105    
#> 420: 0.539093    0.845165    3.374900    1.141515    0.054140    0.012980    0.525053    
#> 421: 0.539014    0.845220    3.374886    1.141666    0.054201    0.012987    0.524999    
#> 422: 0.539022    0.845223    3.374828    1.142106    0.054233    0.012993    0.524953    
#> 423: 0.538801    0.845212    3.374787    1.141522    0.054226    0.012996    0.524905    
#> 424: 0.538492    0.845222    3.374732    1.140747    0.054228    0.013001    0.524838    
#> 425: 0.538331    0.845358    3.374671    1.140531    0.054229    0.013002    0.524889    
#> 426: 0.538159    0.845427    3.374628    1.140771    0.054229    0.012995    0.524866    
#> 427: 0.538089    0.845388    3.374620    1.141177    0.054189    0.013009    0.524832    
#> 428: 0.537849    0.845442    3.374597    1.140973    0.054142    0.013019    0.524835    
#> 429: 0.537656    0.845498    3.374560    1.140754    0.054101    0.013030    0.524830    
#> 430: 0.537460    0.845536    3.374493    1.140750    0.054115    0.013047    0.524822    
#> 431: 0.537385    0.845573    3.374436    1.141258    0.054071    0.013047    0.524753    
#> 432: 0.537423    0.845675    3.374391    1.142188    0.054049    0.013048    0.524724    
#> 433: 0.537407    0.845816    3.374342    1.142598    0.054043    0.013056    0.524736    
#> 434: 0.537196    0.845798    3.374288    1.142321    0.053998    0.013071    0.524745    
#> 435: 0.537258    0.845794    3.374265    1.142633    0.053937    0.013088    0.524754    
#> 436: 0.537415    0.845774    3.374268    1.143366    0.053885    0.013100    0.524829    
#> 437: 0.537522    0.845721    3.374285    1.143584    0.053846    0.013115    0.524936    
#> 438: 0.537428    0.845781    3.374285    1.143161    0.053822    0.013123    0.524943    
#> 439: 0.537572    0.845849    3.374290    1.143410    0.053815    0.013125    0.524874    
#> 440: 0.537592    0.845859    3.374320    1.142957    0.053767    0.013128    0.524817    
#> 441: 0.537892    0.845798    3.374384    1.143266    0.053756    0.013133    0.524782    
#> 442: 0.537929    0.845825    3.374409    1.143306    0.053755    0.013138    0.524762    
#> 443: 0.538058    0.845878    3.374399    1.143672    0.053752    0.013154    0.524761    
#> 444: 0.538030    0.845979    3.374362    1.143832    0.053755    0.013168    0.524735    
#> 445: 0.537970    0.846035    3.374302    1.144139    0.053705    0.013193    0.524718    
#> 446: 0.537809    0.846074    3.374250    1.144154    0.053644    0.013205    0.524675    
#> 447: 0.537725    0.846142    3.374201    1.144242    0.053592    0.013217    0.524691    
#> 448: 0.537544    0.846196    3.374190    1.144073    0.053559    0.013228    0.524648    
#> 449: 0.537565    0.846265    3.374244    1.143985    0.053531    0.013241    0.524634    
#> 450: 0.537476    0.846271    3.374269    1.143339    0.053481    0.013248    0.524656    
#> 451: 0.537534    0.846258    3.374287    1.143587    0.053472    0.013255    0.524629    
#> 452: 0.537574    0.846297    3.374253    1.143814    0.053450    0.013259    0.524583    
#> 453: 0.537651    0.846306    3.374243    1.144192    0.053456    0.013270    0.524522    
#> 454: 0.537530    0.846371    3.374212    1.143859    0.053444    0.013275    0.524488    
#> 455: 0.537528    0.846370    3.374191    1.143843    0.053445    0.013272    0.524430    
#> 456: 0.537305    0.846354    3.374154    1.143647    0.053475    0.013267    0.524405    
#> 457: 0.537228    0.846318    3.374131    1.143931    0.053471    0.013272    0.524352    
#> 458: 0.537208    0.846393    3.374124    1.144389    0.053449    0.013285    0.524262    
#> 459: 0.537129    0.846472    3.374071    1.144696    0.053459    0.013293    0.524179    
#> 460: 0.536863    0.846469    3.373978    1.144480    0.053478    0.013291    0.524179    
#> 461: 0.536555    0.846482    3.373929    1.143774    0.053508    0.013284    0.524199    
#> 462: 0.536446    0.846508    3.373927    1.143546    0.053510    0.013284    0.524221    
#> 463: 0.536458    0.846530    3.373951    1.143328    0.053518    0.013287    0.524212    
#> 464: 0.536442    0.846554    3.373936    1.142824    0.053537    0.013283    0.524222    
#> 465: 0.536353    0.846489    3.373925    1.142167    0.053557    0.013278    0.524217    
#> 466: 0.536198    0.846511    3.373898    1.141217    0.053556    0.013265    0.524226    
#> 467: 0.536085    0.846474    3.373930    1.140748    0.053534    0.013266    0.524184    
#> 468: 0.536241    0.846478    3.373938    1.141063    0.053552    0.013266    0.524142    
#> 469: 0.536553    0.846497    3.373959    1.141664    0.053537    0.013259    0.524114    
#> 470: 0.536587    0.846490    3.373962    1.141973    0.053510    0.013267    0.524072    
#> 471: 0.536590    0.846474    3.373978    1.141796    0.053491    0.013271    0.524112    
#> 472: 0.536529    0.846423    3.374014    1.141507    0.053475    0.013277    0.524168    
#> 473: 0.536412    0.846353    3.374026    1.140953    0.053444    0.013276    0.524144    
#> 474: 0.536311    0.846358    3.374042    1.140500    0.053471    0.013265    0.524184    
#> 475: 0.536316    0.846344    3.374061    1.140304    0.053452    0.013263    0.524201    
#> 476: 0.536414    0.846313    3.374075    1.140486    0.053483    0.013262    0.524206    
#> 477: 0.536449    0.846282    3.374132    1.140395    0.053500    0.013262    0.524174    
#> 478: 0.536307    0.846268    3.374181    1.139752    0.053483    0.013257    0.524262    
#> 479: 0.536369    0.846262    3.374229    1.139904    0.053488    0.013256    0.524303    
#> 480: 0.536204    0.846284    3.374218    1.139398    0.053460    0.013262    0.524461    
#> 481: 0.536108    0.846322    3.374200    1.139387    0.053477    0.013260    0.524549    
#> 482: 0.536095    0.846382    3.374123    1.139814    0.053487    0.013269    0.524625    
#> 483: 0.536108    0.846406    3.374070    1.140766    0.053479    0.013276    0.524740    
#> 484: 0.536163    0.846333    3.374029    1.141713    0.053486    0.013289    0.524829    
#> 485: 0.536231    0.846364    3.373984    1.142914    0.053532    0.013304    0.524870    
#> 486: 0.536153    0.846380    3.373976    1.143122    0.053511    0.013317    0.524917    
#> 487: 0.536237    0.846367    3.373996    1.143262    0.053490    0.013322    0.524915    
#> 488: 0.536375    0.846360    3.374010    1.143579    0.053464    0.013322    0.524926    
#> 489: 0.536462    0.846349    3.373992    1.143786    0.053464    0.013318    0.524906    
#> 490: 0.536620    0.846365    3.374005    1.144288    0.053449    0.013313    0.524884    
#> 491: 0.536558    0.846442    3.374019    1.144104    0.053443    0.013312    0.524838    
#> 492: 0.536601    0.846518    3.374013    1.143984    0.053424    0.013305    0.524893    
#> 493: 0.536587    0.846542    3.374036    1.143749    0.053406    0.013307    0.524883    
#> 494: 0.536550    0.846564    3.374051    1.143651    0.053383    0.013306    0.524865    
#> 495: 0.536730    0.846586    3.374058    1.144361    0.053347    0.013308    0.524823    
#> 496: 0.536886    0.846637    3.374058    1.144593    0.053330    0.013310    0.524847    
#> 497: 0.537139    0.846633    3.374087    1.145418    0.053331    0.013311    0.524851    
#> 498: 0.537280    0.846603    3.374082    1.145871    0.053350    0.013303    0.524838    
#> 499: 0.537326    0.846571    3.374081    1.145852    0.053359    0.013300    0.524820    
#> 500: 0.537568    0.846553    3.374079    1.146410    0.053377    0.013297    0.524806    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.300722    0.966231    3.449219    0.392401    0.077086    0.016800    1.674400    
#> 002: 0.320726    1.011906    3.467853    0.372781    0.073232    0.016620    1.110443    
#> 003: 0.402562    0.916312    3.478587    0.354142    0.069570    0.015789    0.842467    
#> 004: 0.366787    0.908268    3.471623    0.336435    0.066092    0.014999    0.746414    
#> 005: 0.386746    0.938959    3.457407    0.319613    0.062787    0.014249    0.706308    
#> 006: 0.347968    0.928193    3.442754    0.303633    0.059648    0.013537    0.662091    
#> 007: 0.298640    0.938821    3.430205    0.288451    0.061382    0.014457    0.671553    
#> 008: 0.309842    0.938741    3.430263    0.274029    0.076908    0.013734    0.674261    
#> 009: 0.290885    0.924673    3.430795    0.260327    0.074625    0.013047    0.669802    
#> 010: 0.294850    0.930789    3.428338    0.247311    0.073951    0.012395    0.676105    
#> 011: 0.338716    0.927991    3.432525    0.234945    0.095645    0.011775    0.673623    
#> 012: 0.354531    0.940295    3.424391    0.223198    0.090863    0.011186    0.675773    
#> 013: 0.291937    0.938019    3.422559    0.212038    0.092592    0.010988    0.671438    
#> 014: 0.328663    0.932490    3.435067    0.215983    0.087962    0.010712    0.692451    
#> 015: 0.343994    0.933300    3.444470    0.205184    0.083564    0.010177    0.666779    
#> 016: 0.326283    0.944647    3.440578    0.197234    0.079386    0.009668    0.667233    
#> 017: 0.338012    0.952081    3.434802    0.205080    0.075416    0.010087    0.672676    
#> 018: 0.307014    0.944334    3.423832    0.194826    0.079236    0.010987    0.677917    
#> 019: 0.286734    0.955744    3.423533    0.185085    0.085914    0.010437    0.660911    
#> 020: 0.313108    0.956759    3.428171    0.207384    0.081618    0.009915    0.675195    
#> 021: 0.336127    0.937685    3.443975    0.201380    0.077537    0.009420    0.686493    
#> 022: 0.323405    0.928605    3.445651    0.197566    0.073660    0.009594    0.672043    
#> 023: 0.367165    0.928984    3.453261    0.187688    0.071339    0.009125    0.706479    
#> 024: 0.361372    0.951417    3.452806    0.203028    0.075666    0.008669    0.689283    
#> 025: 0.343362    0.934153    3.439467    0.192877    0.084757    0.008236    0.680560    
#> 026: 0.354018    0.956267    3.438543    0.211734    0.083553    0.007968    0.665886    
#> 027: 0.316209    0.980121    3.428147    0.201147    0.079375    0.009560    0.672750    
#> 028: 0.326918    0.948008    3.430020    0.218591    0.075460    0.009082    0.669121    
#> 029: 0.335918    0.958069    3.424813    0.207661    0.096557    0.008628    0.699211    
#> 030: 0.316452    0.964107    3.424352    0.200404    0.091729    0.008196    0.670538    
#> 031: 0.293795    0.945021    3.430518    0.190384    0.087629    0.007787    0.673544    
#> 032: 0.297849    0.933525    3.433680    0.222642    0.083248    0.007830    0.683104    
#> 033: 0.302096    0.945797    3.424987    0.224072    0.079085    0.007536    0.686390    
#> 034: 0.314160    0.960268    3.425197    0.212869    0.077557    0.007209    0.677334    
#> 035: 0.287021    0.943173    3.422968    0.202225    0.093874    0.006849    0.678534    
#> 036: 0.299417    0.959670    3.420044    0.192114    0.089180    0.007109    0.683343    
#> 037: 0.287132    0.976756    3.423828    0.182508    0.084721    0.006927    0.694247    
#> 038: 0.298075    0.961520    3.413731    0.173383    0.096143    0.006581    0.712628    
#> 039: 0.330598    0.933783    3.436115    0.164714    0.099864    0.006872    0.688778    
#> 040: 0.292493    0.948846    3.436985    0.168978    0.094871    0.007652    0.677165    
#> 041: 0.291992    0.932008    3.434366    0.160529    0.098884    0.007541    0.688599    
#> 042: 0.297430    0.940305    3.426436    0.167544    0.093940    0.007164    0.666314    
#> 043: 0.271795    0.947341    3.413550    0.159284    0.089243    0.007402    0.670698    
#> 044: 0.262613    0.960145    3.415137    0.174031    0.084781    0.007032    0.672461    
#> 045: 0.259974    0.980477    3.413838    0.165330    0.080542    0.006680    0.688390    
#> 046: 0.294034    0.968251    3.417410    0.164997    0.076515    0.006346    0.691418    
#> 047: 0.319919    0.948639    3.428774    0.172727    0.077219    0.006409    0.676157    
#> 048: 0.309746    0.947072    3.432789    0.164262    0.076513    0.008820    0.677508    
#> 049: 0.295877    0.954064    3.437198    0.156049    0.081032    0.008837    0.669569    
#> 050: 0.367294    0.920105    3.438292    0.159934    0.086879    0.008395    0.697692    
#> 051: 0.329802    0.919499    3.437993    0.154161    0.082535    0.009925    0.685415    
#> 052: 0.350661    0.941479    3.450735    0.148462    0.078408    0.009429    0.661081    
#> 053: 0.369634    0.928745    3.442876    0.193581    0.074488    0.008958    0.672793    
#> 054: 0.319198    0.922834    3.446380    0.196189    0.079848    0.008510    0.681051    
#> 055: 0.333196    0.924508    3.445262    0.186380    0.086854    0.008084    0.666832    
#> 056: 0.363992    0.927110    3.448564    0.211141    0.099035    0.009084    0.679974    
#> 057: 0.369547    0.920492    3.458967    0.217556    0.102150    0.008630    0.701209    
#> 058: 0.375286    0.917783    3.442822    0.206678    0.097043    0.008198    0.705846    
#> 059: 0.372782    0.892239    3.452158    0.203009    0.108236    0.007788    0.693319    
#> 060: 0.362011    0.878411    3.461159    0.210534    0.102825    0.010355    0.705445    
#> 061: 0.398465    0.895829    3.464539    0.200007    0.097683    0.012261    0.714846    
#> 062: 0.373599    0.917363    3.464491    0.192035    0.107081    0.011648    0.710545    
#> 063: 0.380683    0.883931    3.457771    0.200934    0.101727    0.011074    0.702181    
#> 064: 0.351854    0.913222    3.463012    0.190887    0.096641    0.010520    0.713404    
#> 065: 0.359030    0.888641    3.456283    0.181343    0.091809    0.009994    0.705609    
#> 066: 0.350247    0.925327    3.458736    0.172276    0.099638    0.009494    0.671900    
#> 067: 0.330083    0.903920    3.443520    0.170452    0.094656    0.009051    0.684330    
#> 068: 0.311185    0.937154    3.442147    0.164351    0.099770    0.008598    0.681487    
#> 069: 0.337156    0.930148    3.442392    0.177585    0.094781    0.008168    0.693095    
#> 070: 0.342731    0.930297    3.450256    0.168706    0.090042    0.007760    0.694413    
#> 071: 0.327780    0.959023    3.424988    0.162729    0.085540    0.008128    0.698571    
#> 072: 0.288965    0.936831    3.427803    0.154593    0.089312    0.010161    0.675145    
#> 073: 0.338015    0.930034    3.453873    0.146863    0.084846    0.010244    0.684793    
#> 074: 0.329500    0.917524    3.448911    0.150542    0.080604    0.010113    0.688201    
#> 075: 0.343186    0.908726    3.466087    0.153264    0.097943    0.009607    0.685869    
#> 076: 0.355331    0.918298    3.470037    0.145600    0.093046    0.009127    0.685532    
#> 077: 0.386103    0.911932    3.453252    0.145946    0.088393    0.008670    0.686824    
#> 078: 0.381931    0.925594    3.458207    0.163709    0.083974    0.008237    0.678187    
#> 079: 0.403640    0.919356    3.462706    0.183904    0.080349    0.007911    0.684859    
#> 080: 0.373072    0.918860    3.452859    0.177444    0.094554    0.008644    0.707851    
#> 081: 0.330172    0.922619    3.447548    0.168572    0.089827    0.008880    0.702301    
#> 082: 0.351242    0.902954    3.458152    0.168637    0.085335    0.008436    0.705258    
#> 083: 0.361312    0.929827    3.459085    0.160205    0.082647    0.008014    0.696555    
#> 084: 0.377519    0.910263    3.460499    0.193102    0.081997    0.009266    0.669016    
#> 085: 0.353265    0.927738    3.463436    0.183447    0.079475    0.009761    0.679716    
#> 086: 0.346814    0.938478    3.455149    0.174274    0.084760    0.010621    0.668189    
#> 087: 0.340997    0.925580    3.445154    0.177268    0.080522    0.010090    0.667046    
#> 088: 0.312109    0.935321    3.436850    0.173956    0.076496    0.009585    0.676239    
#> 089: 0.340089    0.937031    3.439254    0.165258    0.086200    0.009656    0.672725    
#> 090: 0.314396    0.937286    3.440777    0.162750    0.081890    0.009173    0.666663    
#> 091: 0.291683    0.913763    3.429215    0.160441    0.077796    0.008715    0.679656    
#> 092: 0.267654    0.946560    3.421015    0.181959    0.076740    0.009256    0.677938    
#> 093: 0.275359    0.947265    3.415484    0.225779    0.083451    0.008793    0.681688    
#> 094: 0.269676    0.967710    3.405517    0.214490    0.097062    0.008353    0.683262    
#> 095: 0.281081    0.977045    3.414439    0.214020    0.092209    0.007936    0.673889    
#> 096: 0.256855    0.968397    3.417584    0.203319    0.087598    0.007539    0.681579    
#> 097: 0.312980    0.973774    3.417176    0.197393    0.083218    0.007842    0.672101    
#> 098: 0.265290    0.988562    3.410171    0.190437    0.080932    0.008320    0.685429    
#> 099: 0.242113    0.961901    3.396593    0.183256    0.081253    0.009758    0.670034    
#> 100: 0.247544    0.981335    3.397618    0.195798    0.084067    0.009270    0.670370    
#> 101: 0.254070    0.946721    3.391846    0.190141    0.081950    0.008807    0.674393    
#> 102: 0.262667    0.969864    3.389453    0.185443    0.079726    0.008366    0.674859    
#> 103: 0.292395    0.955816    3.409276    0.176171    0.075740    0.008476    0.670367    
#> 104: 0.274723    0.955099    3.417973    0.167363    0.073965    0.008052    0.687604    
#> 105: 0.291898    0.971044    3.419737    0.170858    0.081704    0.007650    0.676461    
#> 106: 0.317075    0.951908    3.420409    0.189258    0.094543    0.007267    0.679233    
#> 107: 0.352625    0.961559    3.430900    0.199437    0.096848    0.006974    0.672934    
#> 108: 0.336323    0.935389    3.428828    0.189465    0.092006    0.006625    0.688937    
#> 109: 0.293218    0.961184    3.432602    0.179992    0.099718    0.006294    0.687107    
#> 110: 0.320921    0.932891    3.425293    0.191420    0.094732    0.005979    0.680430    
#> 111: 0.306042    0.933762    3.427415    0.187369    0.095065    0.005680    0.674424    
#> 112: 0.283693    0.923435    3.421426    0.178001    0.097443    0.005396    0.708563    
#> 113: 0.298669    0.961034    3.421243    0.169101    0.092571    0.005126    0.680419    
#> 114: 0.309827    0.953115    3.426872    0.160646    0.088942    0.004870    0.672962    
#> 115: 0.334335    0.930673    3.430259    0.153016    0.096371    0.004626    0.681528    
#> 116: 0.306263    0.940574    3.439771    0.145365    0.091553    0.004878    0.671032    
#> 117: 0.304464    0.944560    3.437426    0.143530    0.086975    0.004634    0.700032    
#> 118: 0.324366    0.926155    3.437787    0.148719    0.082626    0.004936    0.700053    
#> 119: 0.313242    0.932142    3.438492    0.158774    0.093477    0.004931    0.675957    
#> 120: 0.314315    0.922819    3.433326    0.150835    0.091326    0.005733    0.684772    
#> 121: 0.326591    0.961164    3.431496    0.152870    0.086759    0.005980    0.682657    
#> 122: 0.315261    0.946770    3.438123    0.162274    0.085292    0.005790    0.678702    
#> 123: 0.333996    0.954873    3.438325    0.156553    0.087968    0.006533    0.692321    
#> 124: 0.320255    0.972960    3.431091    0.169906    0.083569    0.006206    0.678632    
#> 125: 0.334125    0.971480    3.421512    0.177456    0.092271    0.005896    0.675078    
#> 126: 0.279761    0.982469    3.407941    0.168583    0.087658    0.006349    0.681144    
#> 127: 0.293023    0.949418    3.413249    0.160154    0.086355    0.007156    0.689622    
#> 128: 0.300066    0.936796    3.435343    0.188614    0.084091    0.009232    0.680865    
#> 129: 0.336035    0.955803    3.439649    0.181143    0.087596    0.009906    0.677101    
#> 130: 0.354805    0.948555    3.436598    0.188543    0.083216    0.011779    0.660030    
#> 131: 0.307695    0.942254    3.423362    0.180559    0.098586    0.011190    0.671679    
#> 132: 0.278260    0.956186    3.411181    0.171531    0.101693    0.010631    0.697905    
#> 133: 0.291854    0.935014    3.412689    0.162954    0.106040    0.010650    0.692314    
#> 134: 0.308781    0.944032    3.430802    0.154807    0.100738    0.014299    0.685088    
#> 135: 0.279322    0.958526    3.423923    0.162799    0.095701    0.013584    0.688591    
#> 136: 0.319089    0.929547    3.433134    0.154659    0.090916    0.012904    0.665247    
#> 137: 0.348262    0.934466    3.442944    0.165780    0.086370    0.012259    0.675463    
#> 138: 0.342024    0.944695    3.443432    0.157491    0.082052    0.011646    0.673296    
#> 139: 0.314140    0.924928    3.448283    0.149617    0.087133    0.014142    0.680403    
#> 140: 0.354552    0.933503    3.451166    0.181376    0.082776    0.013435    0.684212    
#> 141: 0.338477    0.921711    3.452960    0.172307    0.083011    0.013029    0.677601    
#> 142: 0.378366    0.908811    3.462434    0.190773    0.080065    0.012378    0.681734    
#> 143: 0.349787    0.926576    3.458411    0.198352    0.093839    0.011759    0.682982    
#> 144: 0.388061    0.921374    3.470290    0.188434    0.089147    0.011171    0.692041    
#> 145: 0.370035    0.931539    3.444863    0.194193    0.086746    0.010613    0.678918    
#> 146: 0.343113    0.931714    3.451629    0.191401    0.082409    0.011755    0.677344    
#> 147: 0.300074    0.924420    3.438341    0.181831    0.078289    0.011168    0.663498    
#> 148: 0.316407    0.942440    3.444516    0.208629    0.074374    0.010609    0.669414    
#> 149: 0.319059    0.924572    3.436894    0.198198    0.085131    0.010079    0.692863    
#> 150: 0.322459    0.955286    3.432731    0.188288    0.080874    0.009575    0.718773    
#> 151: 0.290523    0.972145    3.430735    0.178874    0.078206    0.009120    0.685732    
#> 152: 0.295300    0.961522    3.437663    0.173468    0.077166    0.009477    0.680386    
#> 153: 0.320853    0.939579    3.442561    0.164453    0.090209    0.011333    0.690697    
#> 154: 0.348196    0.924812    3.453352    0.163973    0.084412    0.012407    0.690342    
#> 155: 0.328130    0.914698    3.447001    0.173930    0.074293    0.010038    0.700574    
#> 156: 0.350745    0.927914    3.455842    0.147471    0.081228    0.010244    0.704007    
#> 157: 0.332397    0.911220    3.461303    0.148592    0.082696    0.009924    0.695505    
#> 158: 0.374909    0.923883    3.452351    0.171099    0.086926    0.009561    0.669522    
#> 159: 0.332082    0.938592    3.448499    0.168629    0.085903    0.008528    0.679850    
#> 160: 0.344159    0.917865    3.446820    0.172820    0.111381    0.008192    0.683942    
#> 161: 0.356820    0.927535    3.449511    0.188198    0.073676    0.010413    0.677466    
#> 162: 0.309979    0.947620    3.432030    0.188233    0.075170    0.010366    0.664887    
#> 163: 0.320966    0.923963    3.424278    0.166091    0.071697    0.008764    0.670802    
#> 164: 0.330141    0.936653    3.432902    0.180899    0.062563    0.010507    0.686758    
#> 165: 0.364971    0.933844    3.442471    0.181267    0.080691    0.010003    0.664062    
#> 166: 0.346613    0.948618    3.441243    0.179946    0.082016    0.009571    0.661259    
#> 167: 0.366022    0.970193    3.449105    0.206340    0.076056    0.009107    0.673192    
#> 168: 0.393563    0.943356    3.458770    0.182470    0.077098    0.008925    0.680633    
#> 169: 0.383022    0.973228    3.449918    0.162904    0.077746    0.008256    0.706250    
#> 170: 0.378515    0.925995    3.447130    0.157851    0.071942    0.007924    0.685699    
#> 171: 0.311374    0.941004    3.439042    0.168924    0.075535    0.007893    0.660179    
#> 172: 0.314038    0.967730    3.437661    0.169821    0.071623    0.008607    0.663725    
#> 173: 0.318610    0.961226    3.427018    0.145023    0.069608    0.010255    0.676455    
#> 174: 0.318314    0.949452    3.435775    0.125524    0.074592    0.007939    0.680879    
#> 175: 0.324541    0.960273    3.436915    0.141248    0.085424    0.008474    0.679700    
#> 176: 0.328831    0.952442    3.448946    0.119486    0.088932    0.006677    0.684143    
#> 177: 0.340668    0.934059    3.449022    0.136357    0.095592    0.007791    0.673545    
#> 178: 0.337438    0.902522    3.455205    0.149698    0.089449    0.009997    0.658190    
#> 179: 0.374286    0.929573    3.455849    0.157071    0.081402    0.008204    0.675019    
#> 180: 0.380390    0.924823    3.458417    0.138394    0.076140    0.009394    0.690987    
#> 181: 0.361424    0.913918    3.443958    0.163007    0.066550    0.009616    0.684561    
#> 182: 0.318182    0.929243    3.430719    0.207139    0.084136    0.009403    0.669622    
#> 183: 0.319526    0.953510    3.434861    0.163067    0.072744    0.009266    0.670508    
#> 184: 0.311801    0.915163    3.435026    0.163084    0.062404    0.008426    0.685068    
#> 185: 0.311948    0.936888    3.442151    0.178736    0.061249    0.008660    0.677410    
#> 186: 0.310904    0.965698    3.433283    0.194029    0.074455    0.011439    0.662771    
#> 187: 0.334224    0.942636    3.443836    0.169027    0.064128    0.013843    0.679616    
#> 188: 0.307047    0.952561    3.435809    0.162379    0.082615    0.009715    0.695962    
#> 189: 0.321107    0.962651    3.437315    0.167062    0.089431    0.009826    0.695315    
#> 190: 0.339397    0.944301    3.443014    0.172427    0.087148    0.009018    0.670777    
#> 191: 0.301711    0.936309    3.437870    0.162730    0.086584    0.006907    0.662533    
#> 192: 0.316314    0.948114    3.437559    0.158095    0.075295    0.007484    0.670825    
#> 193: 0.321401    0.960827    3.435100    0.151183    0.077395    0.006754    0.665450    
#> 194: 0.306545    0.945070    3.426498    0.133646    0.099220    0.003558    0.684824    
#> 195: 0.285282    0.942451    3.420037    0.139562    0.075446    0.003650    0.707969    
#> 196: 0.296599    0.943069    3.431227    0.143662    0.093210    0.004211    0.704570    
#> 197: 0.288071    0.938103    3.446617    0.122494    0.085168    0.004897    0.709903    
#> 198: 0.350402    0.932469    3.444662    0.150201    0.067109    0.004926    0.694229    
#> 199: 0.334512    0.908652    3.444065    0.144070    0.101476    0.002787    0.700210    
#> 200: 0.337137    0.913270    3.443507    0.116863    0.105442    0.002796    0.719507    
#> 201: 0.335962    0.912040    3.444838    0.118399    0.097808    0.003249    0.709820    
#> 202: 0.337423    0.921153    3.443124    0.120640    0.096069    0.003282    0.709165    
#> 203: 0.339381    0.928426    3.441935    0.131394    0.095969    0.003293    0.709834    
#> 204: 0.342839    0.926112    3.442397    0.139481    0.096268    0.003257    0.712974    
#> 205: 0.342690    0.928405    3.441759    0.141857    0.097508    0.003318    0.710597    
#> 206: 0.344653    0.932433    3.442791    0.141088    0.098828    0.003247    0.710792    
#> 207: 0.340197    0.931284    3.441837    0.144451    0.098371    0.003191    0.711335    
#> 208: 0.338874    0.931529    3.442154    0.141272    0.097499    0.003187    0.710705    
#> 209: 0.340320    0.928150    3.442413    0.137906    0.097009    0.003283    0.712358    
#> 210: 0.341136    0.925139    3.442924    0.136980    0.097649    0.003304    0.712949    
#> 211: 0.342017    0.925143    3.444033    0.138106    0.097588    0.003267    0.711443    
#> 212: 0.341822    0.923506    3.444611    0.137892    0.097202    0.003228    0.711148    
#> 213: 0.342835    0.923086    3.444646    0.138792    0.097205    0.003277    0.710242    
#> 214: 0.343665    0.922356    3.444628    0.138855    0.098446    0.003363    0.708955    
#> 215: 0.343178    0.922292    3.445012    0.138188    0.098331    0.003496    0.707296    
#> 216: 0.344487    0.922109    3.444974    0.138943    0.098538    0.003560    0.707394    
#> 217: 0.343887    0.923468    3.444681    0.138959    0.097785    0.003564    0.706907    
#> 218: 0.342865    0.924396    3.443968    0.138225    0.097561    0.003612    0.706432    
#> 219: 0.341030    0.924063    3.443063    0.136762    0.096628    0.003691    0.705455    
#> 220: 0.339542    0.923938    3.442819    0.136605    0.095788    0.003705    0.704887    
#> 221: 0.338803    0.924579    3.442728    0.136150    0.094973    0.003719    0.704738    
#> 222: 0.338837    0.924685    3.442612    0.136273    0.094750    0.003792    0.704519    
#> 223: 0.340468    0.924460    3.442726    0.135927    0.095101    0.003836    0.703715    
#> 224: 0.341904    0.925020    3.443352    0.135897    0.095492    0.003841    0.703622    
#> 225: 0.342911    0.923099    3.443867    0.135701    0.095141    0.003876    0.704335    
#> 226: 0.343525    0.921685    3.444055    0.135304    0.095509    0.003909    0.704029    
#> 227: 0.342794    0.921744    3.444307    0.135318    0.095195    0.003974    0.703535    
#> 228: 0.341858    0.922569    3.444244    0.135109    0.095309    0.004059    0.702966    
#> 229: 0.340683    0.921986    3.444208    0.134293    0.095363    0.004118    0.702391    
#> 230: 0.340771    0.921657    3.444114    0.133404    0.095404    0.004151    0.701934    
#> 231: 0.340317    0.922077    3.444288    0.132687    0.095111    0.004210    0.701572    
#> 232: 0.339286    0.921646    3.444657    0.132719    0.094937    0.004260    0.701437    
#> 233: 0.339427    0.921066    3.444791    0.132180    0.094347    0.004333    0.701852    
#> 234: 0.339114    0.921652    3.444880    0.132469    0.094284    0.004407    0.701490    
#> 235: 0.338538    0.921753    3.444640    0.132106    0.094099    0.004399    0.701736    
#> 236: 0.337889    0.922717    3.444256    0.132105    0.094335    0.004429    0.702153    
#> 237: 0.338695    0.922886    3.444249    0.131967    0.094357    0.004477    0.702258    
#> 238: 0.338758    0.922672    3.444346    0.132158    0.094465    0.004485    0.702851    
#> 239: 0.338667    0.923155    3.444325    0.132220    0.094736    0.004530    0.702482    
#> 240: 0.339266    0.922647    3.444361    0.133222    0.094900    0.004563    0.701710    
#> 241: 0.339472    0.921993    3.444453    0.133406    0.094916    0.004545    0.701474    
#> 242: 0.339197    0.922199    3.444288    0.133219    0.094937    0.004538    0.701753    
#> 243: 0.338126    0.922520    3.444277    0.133232    0.094815    0.004555    0.701678    
#> 244: 0.336918    0.922349    3.444272    0.133095    0.095015    0.004551    0.702031    
#> 245: 0.336442    0.922044    3.444300    0.133499    0.095185    0.004565    0.702198    
#> 246: 0.336585    0.922104    3.444547    0.133518    0.094947    0.004599    0.702311    
#> 247: 0.336414    0.921930    3.444914    0.134115    0.094679    0.004605    0.702423    
#> 248: 0.336321    0.922447    3.444877    0.134373    0.094593    0.004601    0.702841    
#> 249: 0.335924    0.923085    3.444653    0.135660    0.094403    0.004587    0.702611    
#> 250: 0.336355    0.923470    3.444709    0.135777    0.094333    0.004604    0.702270    
#> 251: 0.336896    0.924289    3.444822    0.135893    0.094268    0.004609    0.702237    
#> 252: 0.336966    0.924826    3.444939    0.136044    0.094491    0.004603    0.701972    
#> 253: 0.336591    0.925276    3.444912    0.136293    0.094698    0.004630    0.701580    
#> 254: 0.336184    0.925826    3.444890    0.136496    0.094716    0.004641    0.701211    
#> 255: 0.335811    0.926371    3.444883    0.136317    0.094410    0.004644    0.701310    
#> 256: 0.335696    0.926573    3.444786    0.136203    0.094153    0.004639    0.701418    
#> 257: 0.335499    0.926797    3.444586    0.136370    0.093786    0.004626    0.701779    
#> 258: 0.334766    0.926754    3.444485    0.136545    0.093806    0.004630    0.702007    
#> 259: 0.334027    0.926667    3.444425    0.136424    0.093959    0.004638    0.701763    
#> 260: 0.333523    0.926487    3.444606    0.136222    0.093683    0.004647    0.701664    
#> 261: 0.333381    0.926350    3.444781    0.135572    0.093732    0.004658    0.701572    
#> 262: 0.333882    0.926521    3.444856    0.136082    0.093863    0.004657    0.701397    
#> 263: 0.333698    0.926727    3.444883    0.136295    0.093769    0.004664    0.701121    
#> 264: 0.333411    0.927019    3.444708    0.136294    0.093617    0.004656    0.701290    
#> 265: 0.333557    0.927320    3.444614    0.136298    0.093692    0.004641    0.701360    
#> 266: 0.333635    0.928032    3.444426    0.136481    0.093684    0.004637    0.701396    
#> 267: 0.333478    0.928423    3.444255    0.136905    0.093580    0.004638    0.701524    
#> 268: 0.332796    0.928560    3.443930    0.137192    0.093427    0.004637    0.701568    
#> 269: 0.332816    0.928682    3.443731    0.137702    0.093419    0.004654    0.701327    
#> 270: 0.333132    0.928953    3.443606    0.137836    0.093424    0.004649    0.700983    
#> 271: 0.332933    0.929114    3.443405    0.137633    0.093382    0.004644    0.701156    
#> 272: 0.332914    0.928923    3.443254    0.138240    0.093532    0.004644    0.701224    
#> 273: 0.332684    0.929510    3.443102    0.138296    0.093908    0.004642    0.701197    
#> 274: 0.331953    0.929639    3.442922    0.138083    0.093757    0.004641    0.701197    
#> 275: 0.331372    0.929713    3.442726    0.138114    0.093930    0.004633    0.701164    
#> 276: 0.331345    0.929692    3.442849    0.138200    0.094030    0.004645    0.701112    
#> 277: 0.331215    0.929941    3.442924    0.138167    0.093941    0.004651    0.700820    
#> 278: 0.331193    0.929842    3.443029    0.138098    0.093907    0.004654    0.700727    
#> 279: 0.331135    0.929720    3.443055    0.138277    0.093901    0.004672    0.700635    
#> 280: 0.331187    0.930034    3.443083    0.138256    0.093908    0.004669    0.700314    
#> 281: 0.330792    0.930277    3.443093    0.138093    0.093720    0.004673    0.700284    
#> 282: 0.330615    0.930393    3.443154    0.137985    0.093572    0.004677    0.700249    
#> 283: 0.330581    0.930605    3.443090    0.138083    0.093443    0.004672    0.700398    
#> 284: 0.330399    0.930645    3.442994    0.138223    0.093151    0.004671    0.700478    
#> 285: 0.330351    0.930892    3.442874    0.138568    0.093092    0.004672    0.700391    
#> 286: 0.330264    0.931128    3.442751    0.139024    0.093268    0.004671    0.700258    
#> 287: 0.330092    0.931206    3.442647    0.139424    0.093483    0.004676    0.700123    
#> 288: 0.330397    0.931125    3.442573    0.139478    0.093540    0.004664    0.700074    
#> 289: 0.330801    0.931110    3.442580    0.139872    0.093627    0.004667    0.700057    
#> 290: 0.330738    0.931163    3.442482    0.139897    0.093679    0.004671    0.700066    
#> 291: 0.330826    0.931447    3.442518    0.140081    0.093714    0.004674    0.699837    
#> 292: 0.330796    0.931723    3.442442    0.140307    0.093755    0.004666    0.699906    
#> 293: 0.330699    0.931848    3.442345    0.140504    0.093788    0.004659    0.699869    
#> 294: 0.330459    0.932040    3.442253    0.140693    0.093691    0.004663    0.699749    
#> 295: 0.330462    0.931805    3.442229    0.140920    0.093632    0.004679    0.699505    
#> 296: 0.330522    0.931819    3.442253    0.140723    0.093576    0.004697    0.699455    
#> 297: 0.330661    0.932091    3.442229    0.140791    0.093543    0.004724    0.699303    
#> 298: 0.330790    0.932126    3.442163    0.141125    0.093583    0.004725    0.699243    
#> 299: 0.330795    0.932308    3.442051    0.141497    0.093500    0.004721    0.699157    
#> 300: 0.330693    0.932355    3.442049    0.141612    0.093600    0.004705    0.698933    
#> 301: 0.330879    0.932407    3.441984    0.141586    0.093619    0.004697    0.698917    
#> 302: 0.330788    0.932685    3.441816    0.141665    0.093613    0.004690    0.698915    
#> 303: 0.330416    0.933087    3.441716    0.141823    0.093642    0.004695    0.698656    
#> 304: 0.330081    0.933424    3.441556    0.142065    0.093562    0.004707    0.698577    
#> 305: 0.329779    0.933258    3.441443    0.142250    0.093625    0.004724    0.698489    
#> 306: 0.329274    0.933397    3.441242    0.142402    0.093712    0.004733    0.698413    
#> 307: 0.328939    0.933514    3.441078    0.142321    0.093958    0.004717    0.698486    
#> 308: 0.328524    0.933520    3.440998    0.142202    0.094103    0.004715    0.698560    
#> 309: 0.328438    0.933393    3.440905    0.142210    0.094006    0.004718    0.698562    
#> 310: 0.328539    0.933364    3.440788    0.142272    0.093970    0.004720    0.698492    
#> 311: 0.328552    0.933462    3.440690    0.142308    0.094033    0.004728    0.698410    
#> 312: 0.328496    0.933538    3.440581    0.142358    0.094099    0.004730    0.698326    
#> 313: 0.328075    0.933403    3.440491    0.142347    0.094046    0.004734    0.698495    
#> 314: 0.327856    0.933389    3.440393    0.142546    0.094115    0.004736    0.698607    
#> 315: 0.327582    0.933586    3.440263    0.142777    0.094178    0.004735    0.698855    
#> 316: 0.327563    0.933534    3.440227    0.142909    0.094202    0.004728    0.699050    
#> 317: 0.327484    0.933462    3.440270    0.142925    0.094197    0.004722    0.699123    
#> 318: 0.327602    0.933545    3.440198    0.142896    0.094072    0.004722    0.699015    
#> 319: 0.327387    0.933519    3.440155    0.142830    0.094162    0.004719    0.698951    
#> 320: 0.327000    0.933654    3.440013    0.142795    0.094118    0.004721    0.698981    
#> 321: 0.326470    0.933806    3.439783    0.142854    0.094127    0.004714    0.699006    
#> 322: 0.326309    0.934006    3.439638    0.142702    0.094060    0.004713    0.698963    
#> 323: 0.325724    0.934011    3.439501    0.142615    0.093988    0.004711    0.698943    
#> 324: 0.325421    0.934225    3.439410    0.142563    0.093925    0.004706    0.698760    
#> 325: 0.325222    0.934471    3.439271    0.142494    0.093898    0.004701    0.698637    
#> 326: 0.325012    0.934403    3.439140    0.142796    0.093940    0.004694    0.698437    
#> 327: 0.325036    0.934448    3.439078    0.142976    0.093928    0.004699    0.698403    
#> 328: 0.325036    0.934484    3.439001    0.143246    0.093922    0.004701    0.698169    
#> 329: 0.325151    0.934502    3.439001    0.143438    0.093976    0.004701    0.698169    
#> 330: 0.325145    0.934437    3.438994    0.143638    0.093846    0.004706    0.698145    
#> 331: 0.325290    0.934554    3.439019    0.143907    0.093714    0.004706    0.697995    
#> 332: 0.325392    0.934517    3.439017    0.144168    0.093539    0.004707    0.698149    
#> 333: 0.325257    0.934639    3.438892    0.144564    0.093465    0.004728    0.698000    
#> 334: 0.324989    0.934510    3.438741    0.144663    0.093400    0.004748    0.697878    
#> 335: 0.324553    0.934690    3.438553    0.144834    0.093396    0.004751    0.697757    
#> 336: 0.324085    0.934845    3.438446    0.144875    0.093436    0.004753    0.697767    
#> 337: 0.324009    0.935186    3.438352    0.145084    0.093483    0.004755    0.697798    
#> 338: 0.324169    0.935161    3.438378    0.145281    0.093535    0.004760    0.697686    
#> 339: 0.324049    0.935229    3.438372    0.145295    0.093463    0.004765    0.697598    
#> 340: 0.323955    0.935153    3.438367    0.145328    0.093462    0.004771    0.697514    
#> 341: 0.324148    0.935234    3.438441    0.145472    0.093501    0.004780    0.697497    
#> 342: 0.323915    0.935137    3.438456    0.145645    0.093490    0.004785    0.697348    
#> 343: 0.323667    0.935180    3.438528    0.145609    0.093580    0.004779    0.697263    
#> 344: 0.323714    0.935112    3.438574    0.145634    0.093414    0.004779    0.697353    
#> 345: 0.323704    0.935127    3.438613    0.145577    0.093349    0.004782    0.697440    
#> 346: 0.323664    0.935097    3.438572    0.145540    0.093269    0.004785    0.697393    
#> 347: 0.323693    0.935091    3.438474    0.145468    0.093254    0.004808    0.697454    
#> 348: 0.323411    0.935169    3.438376    0.145578    0.093296    0.004824    0.697458    
#> 349: 0.323338    0.935160    3.438280    0.145737    0.093216    0.004832    0.697513    
#> 350: 0.322999    0.935001    3.438199    0.145701    0.093234    0.004839    0.697601    
#> 351: 0.322795    0.935163    3.438108    0.145779    0.093238    0.004839    0.697604    
#> 352: 0.322456    0.935240    3.438072    0.146004    0.093279    0.004848    0.697692    
#> 353: 0.322306    0.935338    3.438015    0.146069    0.093150    0.004856    0.697608    
#> 354: 0.322436    0.935284    3.437971    0.146310    0.093099    0.004866    0.697473    
#> 355: 0.322680    0.935081    3.437975    0.146308    0.093054    0.004875    0.697328    
#> 356: 0.322614    0.935010    3.437984    0.146423    0.093059    0.004873    0.697299    
#> 357: 0.322887    0.935008    3.438013    0.146582    0.093009    0.004883    0.697252    
#> 358: 0.323105    0.935088    3.438095    0.146576    0.092890    0.004888    0.697119    
#> 359: 0.323075    0.935094    3.438134    0.146492    0.092867    0.004890    0.697147    
#> 360: 0.322825    0.935040    3.438083    0.146399    0.092847    0.004887    0.697060    
#> 361: 0.322606    0.934989    3.438002    0.146420    0.092753    0.004896    0.697041    
#> 362: 0.322537    0.934909    3.437956    0.146496    0.092654    0.004910    0.696819    
#> 363: 0.322476    0.934951    3.437885    0.146595    0.092604    0.004909    0.696673    
#> 364: 0.322601    0.934964    3.437880    0.146710    0.092546    0.004911    0.696643    
#> 365: 0.322570    0.934773    3.437928    0.146728    0.092492    0.004917    0.696736    
#> 366: 0.322553    0.934736    3.437868    0.146694    0.092611    0.004924    0.696695    
#> 367: 0.322663    0.934761    3.437861    0.146601    0.092731    0.004930    0.696685    
#> 368: 0.322726    0.934825    3.437810    0.146603    0.092683    0.004934    0.696611    
#> 369: 0.322601    0.934913    3.437739    0.146632    0.092721    0.004943    0.696575    
#> 370: 0.322446    0.934967    3.437665    0.146575    0.092629    0.004962    0.696522    
#> 371: 0.322291    0.935054    3.437551    0.146614    0.092558    0.004972    0.696416    
#> 372: 0.322265    0.935169    3.437503    0.146693    0.092534    0.004978    0.696341    
#> 373: 0.322099    0.935335    3.437454    0.146708    0.092483    0.004978    0.696311    
#> 374: 0.322053    0.935450    3.437373    0.146501    0.092426    0.004977    0.696321    
#> 375: 0.321778    0.935538    3.437276    0.146378    0.092415    0.004979    0.696310    
#> 376: 0.321586    0.935685    3.437188    0.146158    0.092474    0.004990    0.696268    
#> 377: 0.321346    0.935770    3.437160    0.146019    0.092460    0.004986    0.696175    
#> 378: 0.321034    0.935813    3.437088    0.146130    0.092411    0.004985    0.696224    
#> 379: 0.320906    0.935725    3.437094    0.146216    0.092418    0.004991    0.696190    
#> 380: 0.320741    0.935754    3.437055    0.146167    0.092455    0.004992    0.696141    
#> 381: 0.320570    0.935762    3.437006    0.146088    0.092456    0.004991    0.696113    
#> 382: 0.320548    0.935729    3.436975    0.145978    0.092476    0.004989    0.696037    
#> 383: 0.320731    0.935708    3.436995    0.146117    0.092364    0.004990    0.695998    
#> 384: 0.320692    0.935623    3.437036    0.146189    0.092353    0.004998    0.695938    
#> 385: 0.320722    0.935622    3.437067    0.146293    0.092421    0.005012    0.695834    
#> 386: 0.320847    0.935833    3.437080    0.146391    0.092451    0.005020    0.695785    
#> 387: 0.320927    0.936001    3.437083    0.146449    0.092425    0.005034    0.695730    
#> 388: 0.320943    0.936081    3.437069    0.146582    0.092389    0.005043    0.695680    
#> 389: 0.320980    0.935934    3.437076    0.146700    0.092309    0.005056    0.695700    
#> 390: 0.320721    0.936019    3.437030    0.146656    0.092225    0.005064    0.695728    
#> 391: 0.320663    0.935918    3.436983    0.146574    0.092172    0.005068    0.695762    
#> 392: 0.320732    0.935900    3.437020    0.146533    0.092067    0.005071    0.695946    
#> 393: 0.320691    0.935814    3.436999    0.146586    0.092029    0.005075    0.695992    
#> 394: 0.320726    0.935706    3.436979    0.146591    0.091986    0.005088    0.695953    
#> 395: 0.320943    0.935809    3.436963    0.146603    0.091887    0.005100    0.695958    
#> 396: 0.321021    0.935881    3.436937    0.146603    0.091842    0.005107    0.695923    
#> 397: 0.321053    0.935863    3.436917    0.146769    0.091819    0.005115    0.695855    
#> 398: 0.321135    0.935832    3.436940    0.147019    0.091871    0.005116    0.695817    
#> 399: 0.321261    0.935898    3.436980    0.147132    0.091868    0.005116    0.695775    
#> 400: 0.321361    0.936006    3.437001    0.147286    0.091853    0.005115    0.695709    
#> 401: 0.321328    0.936124    3.436985    0.147384    0.091882    0.005119    0.695777    
#> 402: 0.321218    0.936299    3.436904    0.147446    0.091788    0.005125    0.695829    
#> 403: 0.321341    0.936340    3.436856    0.147633    0.091767    0.005124    0.695765    
#> 404: 0.321498    0.936393    3.436825    0.147688    0.091686    0.005120    0.695697    
#> 405: 0.321386    0.936429    3.436831    0.147688    0.091609    0.005121    0.695676    
#> 406: 0.321524    0.936421    3.436845    0.147830    0.091551    0.005129    0.695711    
#> 407: 0.321590    0.936531    3.436869    0.148043    0.091572    0.005133    0.695670    
#> 408: 0.321641    0.936610    3.436837    0.148153    0.091611    0.005130    0.695619    
#> 409: 0.321483    0.936548    3.436793    0.148161    0.091576    0.005130    0.695519    
#> 410: 0.321355    0.936628    3.436706    0.148066    0.091580    0.005134    0.695427    
#> 411: 0.321278    0.936522    3.436658    0.148069    0.091592    0.005134    0.695503    
#> 412: 0.321231    0.936624    3.436608    0.147976    0.091541    0.005135    0.695480    
#> 413: 0.321192    0.936711    3.436547    0.147968    0.091501    0.005133    0.695524    
#> 414: 0.321229    0.936701    3.436577    0.147921    0.091470    0.005128    0.695512    
#> 415: 0.321385    0.936553    3.436623    0.147909    0.091445    0.005133    0.695424    
#> 416: 0.321513    0.936480    3.436659    0.147853    0.091430    0.005138    0.695327    
#> 417: 0.321584    0.936458    3.436654    0.147720    0.091434    0.005140    0.695311    
#> 418: 0.321288    0.936557    3.436614    0.147735    0.091424    0.005137    0.695317    
#> 419: 0.321176    0.936726    3.436544    0.147653    0.091445    0.005138    0.695309    
#> 420: 0.321213    0.936781    3.436537    0.147580    0.091439    0.005141    0.695247    
#> 421: 0.321078    0.936837    3.436561    0.147529    0.091441    0.005140    0.695259    
#> 422: 0.321238    0.936780    3.436581    0.147649    0.091488    0.005139    0.695234    
#> 423: 0.321389    0.936717    3.436585    0.147661    0.091549    0.005138    0.695294    
#> 424: 0.321347    0.936622    3.436568    0.147649    0.091585    0.005134    0.695343    
#> 425: 0.321461    0.936632    3.436564    0.147494    0.091543    0.005127    0.695402    
#> 426: 0.321605    0.936706    3.436571    0.147444    0.091547    0.005121    0.695430    
#> 427: 0.321477    0.936686    3.436569    0.147423    0.091566    0.005122    0.695340    
#> 428: 0.321322    0.936748    3.436538    0.147534    0.091575    0.005126    0.695254    
#> 429: 0.321304    0.936765    3.436515    0.147575    0.091530    0.005133    0.695186    
#> 430: 0.321222    0.936879    3.436467    0.147576    0.091505    0.005143    0.695085    
#> 431: 0.321139    0.936949    3.436408    0.147563    0.091482    0.005149    0.695000    
#> 432: 0.321172    0.937049    3.436423    0.147653    0.091429    0.005158    0.694942    
#> 433: 0.321215    0.937151    3.436467    0.147765    0.091337    0.005166    0.694873    
#> 434: 0.321235    0.937008    3.436548    0.147823    0.091355    0.005182    0.694810    
#> 435: 0.321394    0.936955    3.436593    0.147811    0.091343    0.005186    0.694789    
#> 436: 0.321427    0.936887    3.436636    0.147792    0.091283    0.005187    0.694813    
#> 437: 0.321417    0.936738    3.436638    0.147831    0.091317    0.005187    0.694747    
#> 438: 0.321418    0.936818    3.436656    0.147810    0.091325    0.005188    0.694673    
#> 439: 0.321463    0.936912    3.436647    0.147763    0.091302    0.005186    0.694611    
#> 440: 0.321350    0.936900    3.436667    0.147713    0.091310    0.005187    0.694549    
#> 441: 0.321395    0.936882    3.436712    0.147627    0.091323    0.005188    0.694494    
#> 442: 0.321390    0.936976    3.436718    0.147641    0.091386    0.005186    0.694401    
#> 443: 0.321330    0.937079    3.436707    0.147681    0.091428    0.005184    0.694405    
#> 444: 0.321253    0.937203    3.436658    0.147612    0.091430    0.005179    0.694401    
#> 445: 0.321150    0.937257    3.436594    0.147669    0.091482    0.005173    0.694360    
#> 446: 0.320931    0.937320    3.436519    0.147725    0.091462    0.005165    0.694336    
#> 447: 0.320962    0.937391    3.436486    0.147722    0.091446    0.005167    0.694269    
#> 448: 0.320902    0.937407    3.436483    0.147724    0.091403    0.005171    0.694201    
#> 449: 0.320959    0.937506    3.436540    0.147728    0.091368    0.005176    0.694201    
#> 450: 0.321029    0.937524    3.436550    0.147771    0.091329    0.005185    0.694108    
#> 451: 0.321082    0.937524    3.436519    0.147965    0.091303    0.005194    0.694052    
#> 452: 0.321067    0.937591    3.436478    0.148116    0.091262    0.005196    0.694002    
#> 453: 0.320997    0.937652    3.436438    0.148151    0.091210    0.005192    0.693999    
#> 454: 0.320933    0.937765    3.436411    0.148182    0.091235    0.005190    0.693915    
#> 455: 0.321028    0.937826    3.436377    0.148278    0.091220    0.005187    0.693899    
#> 456: 0.320907    0.937860    3.436341    0.148390    0.091219    0.005188    0.693863    
#> 457: 0.320845    0.937854    3.436334    0.148464    0.091212    0.005191    0.693793    
#> 458: 0.320745    0.937987    3.436318    0.148551    0.091207    0.005189    0.693760    
#> 459: 0.320635    0.938210    3.436281    0.148477    0.091163    0.005189    0.693865    
#> 460: 0.320507    0.938226    3.436244    0.148405    0.091095    0.005193    0.693808    
#> 461: 0.320336    0.938267    3.436232    0.148514    0.091019    0.005201    0.693806    
#> 462: 0.320280    0.938408    3.436235    0.148557    0.090986    0.005206    0.693779    
#> 463: 0.320318    0.938470    3.436223    0.148625    0.090963    0.005208    0.693733    
#> 464: 0.320349    0.938493    3.436213    0.148658    0.090961    0.005208    0.693627    
#> 465: 0.320351    0.938376    3.436210    0.148682    0.090929    0.005204    0.693614    
#> 466: 0.320358    0.938434    3.436168    0.148701    0.090882    0.005203    0.693579    
#> 467: 0.320248    0.938416    3.436142    0.148744    0.090899    0.005202    0.693489    
#> 468: 0.320282    0.938475    3.436115    0.148863    0.090903    0.005208    0.693473    
#> 469: 0.320248    0.938585    3.436097    0.148935    0.090899    0.005214    0.693438    
#> 470: 0.320101    0.938650    3.436060    0.148986    0.090935    0.005221    0.693416    
#> 471: 0.320001    0.938594    3.436049    0.148985    0.090949    0.005221    0.693386    
#> 472: 0.320003    0.938576    3.436087    0.148966    0.090943    0.005225    0.693390    
#> 473: 0.319855    0.938569    3.436099    0.148883    0.090970    0.005228    0.693371    
#> 474: 0.319719    0.938523    3.436074    0.148896    0.090981    0.005240    0.693381    
#> 475: 0.319592    0.938539    3.436053    0.148878    0.090967    0.005248    0.693330    
#> 476: 0.319595    0.938563    3.436003    0.148972    0.090948    0.005255    0.693313    
#> 477: 0.319563    0.938565    3.436002    0.148965    0.090938    0.005260    0.693222    
#> 478: 0.319483    0.938586    3.435981    0.148965    0.090965    0.005262    0.693116    
#> 479: 0.319462    0.938602    3.436005    0.148972    0.090972    0.005264    0.693088    
#> 480: 0.319519    0.938534    3.436043    0.148906    0.090986    0.005265    0.693173    
#> 481: 0.319456    0.938564    3.436026    0.148812    0.090980    0.005264    0.693219    
#> 482: 0.319583    0.938664    3.436004    0.148920    0.090983    0.005264    0.693223    
#> 483: 0.319469    0.938766    3.435943    0.149014    0.090974    0.005265    0.693154    
#> 484: 0.319326    0.938687    3.435901    0.149066    0.090948    0.005268    0.693140    
#> 485: 0.319234    0.938684    3.435851    0.149154    0.090914    0.005275    0.693095    
#> 486: 0.319165    0.938690    3.435821    0.149147    0.090879    0.005278    0.693065    
#> 487: 0.319201    0.938776    3.435822    0.149176    0.090839    0.005281    0.692996    
#> 488: 0.319150    0.938821    3.435833    0.149163    0.090824    0.005284    0.692990    
#> 489: 0.319215    0.938826    3.435840    0.149115    0.090761    0.005288    0.693039    
#> 490: 0.319331    0.938768    3.435893    0.149100    0.090749    0.005292    0.693095    
#> 491: 0.319370    0.938787    3.435939    0.149127    0.090762    0.005292    0.693094    
#> 492: 0.319397    0.938759    3.435950    0.149198    0.090790    0.005288    0.693185    
#> 493: 0.319403    0.938743    3.435965    0.149228    0.090758    0.005293    0.693181    
#> 494: 0.319507    0.938690    3.435985    0.149230    0.090756    0.005291    0.693129    
#> 495: 0.319621    0.938668    3.436026    0.149328    0.090732    0.005290    0.693063    
#> 496: 0.319739    0.938657    3.436038    0.149361    0.090727    0.005290    0.693053    
#> 497: 0.319785    0.938632    3.436054    0.149331    0.090752    0.005292    0.693065    
#> 498: 0.319791    0.938627    3.436025    0.149349    0.090732    0.005292    0.692988    
#> 499: 0.319777    0.938665    3.435989    0.149333    0.090783    0.005293    0.692932    
#> 500: 0.319778    0.938724    3.435969    0.149368    0.090746    0.005294    0.692815    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.346897    0.981633    3.451995    0.392401    0.078006    0.016800    1.704214    
#> 002: 0.480519    1.093896    3.476087    0.372781    0.074106    0.015960    1.099623    
#> 003: 0.748482    1.065340    3.514296    0.374080    0.070400    0.015162    0.743538    
#> 004: 0.749106    1.130604    3.512098    0.404584    0.066880    0.014404    0.650344    
#> 005: 0.817556    1.136390    3.517923    0.540077    0.063536    0.013684    0.580705    
#> 006: 0.848977    1.145012    3.523006    0.565394    0.060360    0.013000    0.519926    
#> 007: 0.838423    1.165947    3.520675    0.573583    0.057342    0.012350    0.519273    
#> 008: 0.812841    1.149767    3.520138    0.581834    0.054474    0.011732    0.525720    
#> 009: 0.783738    1.139139    3.517826    0.552742    0.051751    0.011146    0.527935    
#> 010: 0.813573    1.134500    3.520840    0.654859    0.049163    0.010588    0.530873    
#> 011: 0.884895    1.137444    3.518789    0.697829    0.046705    0.010116    0.521671    
#> 012: 0.946702    1.131088    3.530557    0.753675    0.044370    0.009610    0.514269    
#> 013: 0.863832    1.136530    3.529390    0.715991    0.042151    0.009130    0.522420    
#> 014: 0.935204    1.138702    3.536840    0.750698    0.040044    0.008673    0.515957    
#> 015: 0.957396    1.135945    3.551604    0.780097    0.038042    0.008286    0.496840    
#> 016: 0.950442    1.143158    3.551898    0.741092    0.036139    0.008626    0.507442    
#> 017: 0.932444    1.142232    3.552220    0.704038    0.034333    0.008194    0.502335    
#> 018: 0.931271    1.151509    3.538893    0.668836    0.032616    0.007785    0.507997    
#> 019: 0.885049    1.146465    3.531785    0.660212    0.030985    0.007395    0.487156    
#> 020: 0.909102    1.146799    3.537482    0.627201    0.036253    0.007458    0.491680    
#> 021: 0.900937    1.132484    3.549094    0.624700    0.034441    0.008574    0.494057    
#> 022: 0.903791    1.132519    3.547482    0.656369    0.037800    0.008387    0.496759    
#> 023: 0.964338    1.144695    3.550276    0.680134    0.035910    0.007968    0.521472    
#> 024: 0.979036    1.157034    3.547369    0.783630    0.034115    0.007918    0.496428    
#> 025: 0.987488    1.135233    3.550533    0.837446    0.032409    0.008673    0.503089    
#> 026: 0.976500    1.155026    3.542122    0.819813    0.030789    0.009265    0.528267    
#> 027: 0.936500    1.158384    3.543453    0.778822    0.029249    0.008802    0.514229    
#> 028: 0.906480    1.142928    3.544519    0.739881    0.027787    0.009421    0.498870    
#> 029: 0.924380    1.136571    3.542140    0.702887    0.028602    0.009495    0.504169    
#> 030: 0.944769    1.146388    3.541930    0.762585    0.028839    0.011580    0.505802    
#> 031: 0.876074    1.134469    3.538533    0.724456    0.029862    0.011001    0.501470    
#> 032: 0.804875    1.123402    3.532689    0.688233    0.028369    0.010451    0.505761    
#> 033: 0.878968    1.139295    3.533582    0.676242    0.026950    0.009929    0.498976    
#> 034: 0.931615    1.146135    3.542436    0.720869    0.028606    0.009432    0.493994    
#> 035: 0.881499    1.128919    3.534962    0.684826    0.028406    0.008961    0.488027    
#> 036: 0.905213    1.131580    3.540345    0.684978    0.026986    0.010170    0.499123    
#> 037: 0.891296    1.154772    3.535955    0.664649    0.030380    0.009724    0.507485    
#> 038: 0.891550    1.144098    3.532258    0.696654    0.030803    0.009688    0.514298    
#> 039: 0.929292    1.140129    3.544320    0.688371    0.030103    0.010136    0.504585    
#> 040: 0.921015    1.147802    3.545040    0.697915    0.028598    0.010412    0.513403    
#> 041: 0.943060    1.129048    3.538898    0.820143    0.029610    0.009891    0.500824    
#> 042: 0.930000    1.137420    3.532660    0.830712    0.028130    0.009397    0.503804    
#> 043: 0.864594    1.157194    3.522936    0.789176    0.026723    0.008927    0.505993    
#> 044: 0.889414    1.173524    3.523267    0.749717    0.025875    0.008481    0.504496    
#> 045: 0.898829    1.162876    3.517581    0.760732    0.024581    0.008057    0.504053    
#> 046: 0.924946    1.150270    3.531416    0.738871    0.028887    0.008763    0.489925    
#> 047: 0.937239    1.148440    3.535457    0.763967    0.027443    0.009530    0.499140    
#> 048: 0.914764    1.149360    3.529224    0.791370    0.028590    0.009823    0.492055    
#> 049: 0.907915    1.139353    3.539637    0.751801    0.031170    0.010158    0.499388    
#> 050: 0.977415    1.124591    3.548189    0.917848    0.029611    0.009650    0.527069    
#> 051: 0.919470    1.135270    3.531828    0.871956    0.030928    0.009167    0.515947    
#> 052: 0.934355    1.131821    3.543000    0.828358    0.029381    0.008733    0.513348    
#> 053: 0.944135    1.132870    3.546186    0.786940    0.027912    0.010258    0.501064    
#> 054: 0.945297    1.138464    3.548684    0.752134    0.026517    0.012535    0.508852    
#> 055: 0.925444    1.141316    3.548719    0.714528    0.025191    0.011908    0.517672    
#> 056: 0.924040    1.136412    3.555405    0.678801    0.027602    0.011313    0.518646    
#> 057: 0.926672    1.144089    3.549693    0.653129    0.030245    0.010747    0.524361    
#> 058: 0.914417    1.146574    3.537643    0.637730    0.030478    0.010210    0.523442    
#> 059: 0.886751    1.115728    3.543332    0.679452    0.028954    0.012420    0.518279    
#> 060: 0.920244    1.114735    3.547730    0.722792    0.029156    0.011799    0.525739    
#> 061: 0.963364    1.122747    3.545327    0.874652    0.027699    0.012060    0.521453    
#> 062: 0.938632    1.123630    3.547084    0.830920    0.026314    0.013460    0.546524    
#> 063: 0.956960    1.115998    3.549464    0.789374    0.026908    0.012787    0.536490    
#> 064: 0.930918    1.129259    3.541417    0.749905    0.025563    0.012147    0.521258    
#> 065: 0.976554    1.122481    3.527635    0.857232    0.024284    0.011795    0.522115    
#> 066: 0.950859    1.138659    3.539519    0.834382    0.023255    0.011205    0.494360    
#> 067: 0.949467    1.138598    3.539910    0.795380    0.026557    0.010645    0.505719    
#> 068: 0.931129    1.145983    3.547141    0.816612    0.025229    0.010113    0.511268    
#> 069: 0.920893    1.146058    3.539878    0.775782    0.023967    0.009607    0.515169    
#> 070: 0.895067    1.142272    3.551163    0.736993    0.022769    0.010886    0.511103    
#> 071: 0.874584    1.165775    3.532841    0.700143    0.021631    0.010342    0.513130    
#> 072: 0.862362    1.145869    3.534445    0.665136    0.020549    0.010248    0.507557    
#> 073: 0.940981    1.148531    3.544768    0.767279    0.020897    0.009735    0.500832    
#> 074: 0.888483    1.142621    3.539883    0.728916    0.025060    0.009980    0.500340    
#> 075: 0.934798    1.134146    3.555770    0.743026    0.031448    0.011548    0.505175    
#> 076: 0.905021    1.144576    3.560006    0.705875    0.029967    0.011873    0.530173    
#> 077: 0.978203    1.122928    3.550401    0.670581    0.030974    0.011952    0.524761    
#> 078: 0.937889    1.121711    3.553260    0.671634    0.029425    0.011354    0.526412    
#> 079: 0.971039    1.135201    3.548470    0.814337    0.027954    0.010787    0.523685    
#> 080: 0.971983    1.128628    3.549261    0.773620    0.026556    0.010247    0.521797    
#> 081: 0.929078    1.126799    3.546825    0.798833    0.026442    0.009735    0.512220    
#> 082: 0.938775    1.128725    3.553758    0.758891    0.030099    0.009421    0.520161    
#> 083: 0.936512    1.139290    3.553634    0.750507    0.030384    0.008950    0.518420    
#> 084: 0.910453    1.137549    3.550108    0.712982    0.030455    0.010387    0.509251    
#> 085: 0.904586    1.136858    3.558124    0.677332    0.029292    0.011879    0.497233    
#> 086: 0.923557    1.143855    3.551096    0.680487    0.029133    0.011285    0.494950    
#> 087: 0.893327    1.132576    3.542360    0.646462    0.030756    0.010720    0.493006    
#> 088: 0.917337    1.118633    3.543706    0.809911    0.031007    0.010184    0.499177    
#> 089: 0.904196    1.142237    3.545647    0.769416    0.031922    0.011027    0.495643    
#> 090: 0.912027    1.141778    3.548396    0.730945    0.034696    0.010476    0.503244    
#> 091: 0.913849    1.140372    3.536158    0.694398    0.032961    0.010459    0.509748    
#> 092: 0.876601    1.132821    3.534516    0.724889    0.031313    0.010079    0.512640    
#> 093: 0.844273    1.142689    3.525763    0.693344    0.033620    0.009575    0.520692    
#> 094: 0.893253    1.129802    3.530285    0.658677    0.032037    0.009352    0.516835    
#> 095: 0.913196    1.141249    3.541949    0.724491    0.030435    0.010478    0.499506    
#> 096: 0.876853    1.149980    3.536320    0.688267    0.029636    0.009954    0.499411    
#> 097: 0.905538    1.157621    3.539900    0.653853    0.028752    0.010300    0.490706    
#> 098: 0.926300    1.153810    3.545510    0.642152    0.028993    0.010698    0.488005    
#> 099: 0.918042    1.127589    3.546697    0.647622    0.027543    0.010410    0.494606    
#> 100: 0.923110    1.132761    3.546909    0.723820    0.026478    0.011349    0.491359    
#> 101: 0.867837    1.133191    3.532288    0.687629    0.027299    0.010782    0.493405    
#> 102: 0.866423    1.133210    3.525578    0.674569    0.028255    0.010242    0.491162    
#> 103: 0.865019    1.150140    3.536735    0.640840    0.030718    0.009730    0.483759    
#> 104: 0.891236    1.146069    3.543802    0.661741    0.029582    0.009629    0.501014    
#> 105: 0.940878    1.129873    3.538444    0.781667    0.030504    0.009147    0.519712    
#> 106: 0.963949    1.137739    3.546140    0.818887    0.028979    0.010629    0.494238    
#> 107: 0.967434    1.146837    3.546234    0.812822    0.027530    0.010097    0.501297    
#> 108: 0.939487    1.146831    3.547241    0.772181    0.028791    0.009593    0.496320    
#> 109: 0.916252    1.145645    3.547039    0.733572    0.027351    0.009113    0.495075    
#> 110: 0.911088    1.134252    3.545095    0.696893    0.026553    0.009786    0.501127    
#> 111: 0.926998    1.139240    3.551288    0.662049    0.025226    0.009437    0.496776    
#> 112: 0.913746    1.118668    3.543922    0.670024    0.025523    0.009100    0.519176    
#> 113: 0.897306    1.133625    3.544707    0.636523    0.024247    0.008645    0.516040    
#> 114: 0.909740    1.143542    3.547880    0.608153    0.024577    0.009159    0.517452    
#> 115: 0.957636    1.122367    3.545668    0.705838    0.023348    0.011072    0.514493    
#> 116: 0.941913    1.135933    3.542345    0.670546    0.025401    0.010568    0.497177    
#> 117: 0.884155    1.152528    3.542866    0.637019    0.024131    0.010040    0.503728    
#> 118: 0.908932    1.154761    3.541975    0.628603    0.027864    0.009538    0.506466    
#> 119: 0.916978    1.154562    3.542676    0.674335    0.026471    0.009061    0.514591    
#> 120: 0.866030    1.143713    3.541124    0.643078    0.025148    0.008854    0.504806    
#> 121: 0.891264    1.155419    3.533521    0.613284    0.026707    0.008411    0.504973    
#> 122: 0.877551    1.138043    3.535167    0.620490    0.026060    0.007990    0.508103    
#> 123: 0.864227    1.166412    3.530460    0.589465    0.025777    0.008503    0.510104    
#> 124: 0.919659    1.176402    3.530940    0.715729    0.024716    0.008476    0.508435    
#> 125: 0.922176    1.164441    3.526611    0.679943    0.031708    0.008817    0.505876    
#> 126: 0.891059    1.167737    3.520640    0.645946    0.032743    0.008770    0.514793    
#> 127: 0.912305    1.147456    3.526998    0.690215    0.031484    0.008332    0.517660    
#> 128: 0.912430    1.149361    3.534598    0.713039    0.031713    0.007915    0.511677    
#> 129: 0.925868    1.147999    3.544872    0.679304    0.030128    0.008160    0.521868    
#> 130: 0.928202    1.155641    3.537549    0.691521    0.028621    0.007843    0.514609    
#> 131: 0.906850    1.139474    3.533355    0.656945    0.030267    0.007451    0.511162    
#> 132: 0.901307    1.138791    3.528455    0.700922    0.032159    0.008694    0.505663    
#> 133: 0.857180    1.129944    3.533677    0.665876    0.030551    0.008611    0.514845    
#> 134: 0.903216    1.124341    3.542782    0.688280    0.029024    0.009614    0.508354    
#> 135: 0.931930    1.121893    3.548173    0.653866    0.027573    0.009133    0.502042    
#> 136: 0.930701    1.123078    3.547451    0.621173    0.026194    0.009268    0.498710    
#> 137: 0.968905    1.129880    3.560043    0.625751    0.029374    0.009931    0.520402    
#> 138: 0.942826    1.139121    3.558729    0.613789    0.029774    0.011016    0.514162    
#> 139: 0.905157    1.119416    3.560672    0.643903    0.028285    0.010465    0.514069    
#> 140: 0.913824    1.126648    3.554847    0.611708    0.026871    0.010367    0.511641    
#> 141: 0.884818    1.119995    3.559203    0.581122    0.025527    0.011307    0.517236    
#> 142: 0.934389    1.107907    3.562461    0.618894    0.024251    0.011799    0.525351    
#> 143: 0.923234    1.118863    3.552450    0.683168    0.023330    0.011209    0.519530    
#> 144: 0.978115    1.131104    3.560565    0.779866    0.022163    0.012084    0.508360    
#> 145: 0.950273    1.143266    3.541508    0.852589    0.021055    0.011480    0.513880    
#> 146: 0.930923    1.150747    3.551337    0.809959    0.020002    0.011191    0.504131    
#> 147: 0.882920    1.140813    3.535751    0.769462    0.021705    0.012785    0.499913    
#> 148: 0.890024    1.146460    3.541120    0.730988    0.026532    0.012145    0.498600    
#> 149: 0.902126    1.122696    3.544054    0.694439    0.025206    0.012024    0.505071    
#> 150: 0.916528    1.122099    3.536263    0.709680    0.027765    0.011423    0.506240    
#> 151: 0.867938    1.160511    3.530665    0.674196    0.026376    0.010851    0.506640    
#> 152: 0.832041    1.156854    3.531568    0.649433    0.016855    0.013030    0.524933    
#> 153: 0.865480    1.169799    3.534255    0.589602    0.019130    0.012763    0.524158    
#> 154: 0.894409    1.175006    3.540738    0.635357    0.020212    0.013104    0.522916    
#> 155: 0.856881    1.152085    3.532067    0.595002    0.021604    0.014491    0.505092    
#> 156: 0.891656    1.154373    3.536142    0.587645    0.020501    0.014979    0.514567    
#> 157: 0.875060    1.143111    3.540413    0.609772    0.019846    0.014387    0.511212    
#> 158: 0.917774    1.147445    3.540247    0.627914    0.018641    0.013637    0.513916    
#> 159: 0.870137    1.162208    3.549986    0.550906    0.021467    0.011807    0.502858    
#> 160: 0.924927    1.131867    3.560545    0.563612    0.020147    0.014650    0.509300    
#> 161: 0.937157    1.135822    3.556144    0.551117    0.018765    0.016457    0.523419    
#> 162: 0.908453    1.143098    3.548572    0.522758    0.019155    0.013151    0.526301    
#> 163: 0.914024    1.127623    3.546080    0.557741    0.022171    0.012769    0.513156    
#> 164: 0.912556    1.138295    3.545461    0.584644    0.020266    0.013109    0.511221    
#> 165: 0.942738    1.139940    3.550035    0.640550    0.026044    0.012912    0.516910    
#> 166: 0.960490    1.153156    3.550862    0.592012    0.022641    0.013926    0.529427    
#> 167: 0.972382    1.161296    3.558088    0.674461    0.024944    0.012870    0.515933    
#> 168: 0.973569    1.160310    3.557918    0.703502    0.025169    0.009754    0.503580    
#> 169: 0.932636    1.166806    3.542346    0.561617    0.023687    0.010939    0.514507    
#> 170: 0.935342    1.143784    3.551616    0.563051    0.029013    0.011415    0.508861    
#> 171: 0.868358    1.137273    3.544630    0.522159    0.022771    0.010008    0.515519    
#> 172: 0.885966    1.145655    3.547660    0.541962    0.029912    0.009282    0.501011    
#> 173: 0.927475    1.153886    3.531871    0.698086    0.025344    0.007993    0.499477    
#> 174: 0.936269    1.158976    3.543753    0.642875    0.028017    0.008204    0.507314    
#> 175: 0.926916    1.152836    3.537943    0.680760    0.020630    0.008263    0.513821    
#> 176: 0.935129    1.164554    3.544311    0.659252    0.028351    0.007294    0.510670    
#> 177: 0.908647    1.150882    3.549112    0.612226    0.023673    0.007361    0.514069    
#> 178: 0.908524    1.137168    3.544833    0.641434    0.029468    0.007666    0.508609    
#> 179: 0.939737    1.155975    3.540183    0.631866    0.034089    0.008735    0.510342    
#> 180: 0.902048    1.162832    3.539479    0.599737    0.029623    0.008155    0.508853    
#> 181: 0.894445    1.130951    3.532755    0.571387    0.022940    0.009024    0.511822    
#> 182: 0.850805    1.143170    3.527115    0.576689    0.022124    0.010073    0.526959    
#> 183: 0.854805    1.149926    3.527507    0.524028    0.026502    0.011395    0.511259    
#> 184: 0.865140    1.131096    3.537073    0.506829    0.033775    0.008975    0.511188    
#> 185: 0.849479    1.151280    3.527690    0.541829    0.030754    0.008169    0.512474    
#> 186: 0.872861    1.168392    3.531854    0.639877    0.037807    0.008162    0.506141    
#> 187: 0.893332    1.147942    3.541686    0.633453    0.034205    0.009511    0.511671    
#> 188: 0.868671    1.157290    3.533486    0.655364    0.033520    0.010002    0.520827    
#> 189: 0.907180    1.154973    3.541413    0.684639    0.030570    0.011954    0.498898    
#> 190: 0.893709    1.145055    3.540589    0.651837    0.026243    0.010615    0.496622    
#> 191: 0.865332    1.148092    3.534448    0.614569    0.022147    0.011573    0.491407    
#> 192: 0.876590    1.153069    3.530784    0.669670    0.021849    0.011050    0.492052    
#> 193: 0.916108    1.157825    3.540598    0.674916    0.023282    0.010805    0.503416    
#> 194: 0.886691    1.146427    3.532872    0.622049    0.024976    0.010629    0.497376    
#> 195: 0.856814    1.151510    3.524904    0.671644    0.021851    0.011063    0.497405    
#> 196: 0.886565    1.147820    3.534222    0.593530    0.019990    0.012716    0.515912    
#> 197: 0.857052    1.151662    3.545191    0.595734    0.021536    0.012552    0.525993    
#> 198: 0.928773    1.140507    3.535323    0.677793    0.017596    0.013742    0.512234    
#> 199: 0.902027    1.133856    3.540286    0.713970    0.015699    0.013941    0.505325    
#> 200: 0.872189    1.123660    3.538136    0.706452    0.014993    0.013876    0.510528    
#> 201: 0.887632    1.126411    3.541756    0.710887    0.016615    0.013756    0.507224    
#> 202: 0.897968    1.129375    3.542970    0.709736    0.016869    0.013583    0.507415    
#> 203: 0.912180    1.130591    3.542668    0.714933    0.017438    0.013114    0.506405    
#> 204: 0.926380    1.129276    3.544122    0.726926    0.019533    0.012303    0.506352    
#> 205: 0.929397    1.134168    3.544039    0.714787    0.020560    0.011752    0.507335    
#> 206: 0.924655    1.138672    3.545138    0.693193    0.020866    0.011824    0.508299    
#> 207: 0.924961    1.139002    3.544415    0.684690    0.020837    0.011607    0.508265    
#> 208: 0.925860    1.138961    3.544553    0.686462    0.020568    0.011482    0.507275    
#> 209: 0.927736    1.136989    3.544879    0.681007    0.020519    0.011441    0.508207    
#> 210: 0.927342    1.135577    3.545718    0.675715    0.020465    0.011458    0.507401    
#> 211: 0.926338    1.134754    3.546245    0.670707    0.020942    0.011378    0.505493    
#> 212: 0.926935    1.134530    3.546752    0.668284    0.021071    0.011380    0.505118    
#> 213: 0.928944    1.133411    3.547471    0.663743    0.021214    0.011472    0.505900    
#> 214: 0.929541    1.132520    3.547939    0.659090    0.021436    0.011473    0.506302    
#> 215: 0.930492    1.132253    3.548672    0.657461    0.021539    0.011517    0.505694    
#> 216: 0.935277    1.130702    3.549656    0.660234    0.021471    0.011729    0.505482    
#> 217: 0.936740    1.130721    3.550163    0.660583    0.021366    0.011874    0.505168    
#> 218: 0.935403    1.131527    3.549912    0.656613    0.021466    0.012006    0.504498    
#> 219: 0.932860    1.131742    3.549211    0.653265    0.021326    0.012102    0.504152    
#> 220: 0.929500    1.131808    3.548644    0.653451    0.021140    0.012180    0.504212    
#> 221: 0.927740    1.132319    3.547957    0.653269    0.021150    0.012156    0.504081    
#> 222: 0.925651    1.132497    3.547711    0.648872    0.021241    0.012205    0.503939    
#> 223: 0.925935    1.132989    3.547783    0.647815    0.021267    0.012165    0.504089    
#> 224: 0.927597    1.133418    3.548012    0.647411    0.021117    0.012043    0.503910    
#> 225: 0.928201    1.132855    3.548462    0.645967    0.021101    0.012026    0.503717    
#> 226: 0.927767    1.132153    3.548464    0.643680    0.021120    0.011966    0.503720    
#> 227: 0.927967    1.132116    3.548533    0.643224    0.021156    0.012005    0.503397    
#> 228: 0.927912    1.132348    3.548266    0.642967    0.021007    0.012007    0.503580    
#> 229: 0.926825    1.132121    3.548066    0.641500    0.020761    0.012002    0.503671    
#> 230: 0.927518    1.131732    3.548026    0.642518    0.020557    0.011977    0.503858    
#> 231: 0.927359    1.131893    3.548278    0.641050    0.020467    0.011978    0.503955    
#> 232: 0.927139    1.131930    3.548520    0.640020    0.020371    0.011931    0.503885    
#> 233: 0.926992    1.131560    3.548786    0.641519    0.020379    0.011912    0.503999    
#> 234: 0.927375    1.131338    3.548889    0.641227    0.020504    0.011899    0.504011    
#> 235: 0.928311    1.130722    3.548917    0.640907    0.020706    0.011897    0.503859    
#> 236: 0.928643    1.130901    3.548822    0.643227    0.020848    0.011870    0.503853    
#> 237: 0.929524    1.130764    3.548945    0.645229    0.020832    0.011823    0.503858    
#> 238: 0.930420    1.130765    3.549001    0.648874    0.020837    0.011791    0.504172    
#> 239: 0.929575    1.130969    3.548884    0.647582    0.020885    0.011773    0.504385    
#> 240: 0.929786    1.131025    3.549006    0.647717    0.020964    0.011719    0.504242    
#> 241: 0.930033    1.130788    3.549092    0.646559    0.021113    0.011689    0.504263    
#> 242: 0.929851    1.130343    3.549117    0.645854    0.021261    0.011644    0.504507    
#> 243: 0.929742    1.130461    3.549097    0.645852    0.021449    0.011625    0.504440    
#> 244: 0.929443    1.130223    3.549194    0.645844    0.021471    0.011632    0.504441    
#> 245: 0.929633    1.130020    3.549258    0.644651    0.021679    0.011620    0.504625    
#> 246: 0.929656    1.130088    3.549295    0.643843    0.021692    0.011586    0.504656    
#> 247: 0.928676    1.130029    3.549293    0.642129    0.021700    0.011570    0.504546    
#> 248: 0.928345    1.130418    3.549094    0.641347    0.021686    0.011506    0.504545    
#> 249: 0.927773    1.130558    3.549085    0.640774    0.021766    0.011448    0.504543    
#> 250: 0.928369    1.130724    3.549204    0.639675    0.021850    0.011416    0.504667    
#> 251: 0.928524    1.130795    3.549427    0.639277    0.021908    0.011401    0.504782    
#> 252: 0.929986    1.130754    3.549730    0.641232    0.022011    0.011380    0.505044    
#> 253: 0.930698    1.130724    3.549842    0.644782    0.022121    0.011333    0.505300    
#> 254: 0.930417    1.131091    3.549848    0.644166    0.022177    0.011290    0.505501    
#> 255: 0.930409    1.131292    3.549851    0.643764    0.022185    0.011287    0.505783    
#> 256: 0.930645    1.131219    3.549845    0.643924    0.022202    0.011217    0.506201    
#> 257: 0.930608    1.130787    3.549852    0.643313    0.022353    0.011172    0.506225    
#> 258: 0.930504    1.130314    3.549884    0.644148    0.022408    0.011191    0.506256    
#> 259: 0.930318    1.130230    3.549817    0.643780    0.022338    0.011219    0.506309    
#> 260: 0.930056    1.130493    3.549742    0.644056    0.022341    0.011223    0.506370    
#> 261: 0.930184    1.130511    3.549599    0.645427    0.022333    0.011219    0.506537    
#> 262: 0.929623    1.130774    3.549528    0.644828    0.022352    0.011214    0.506580    
#> 263: 0.929104    1.131016    3.549484    0.644457    0.022440    0.011206    0.506682    
#> 264: 0.928466    1.131100    3.549446    0.644525    0.022607    0.011193    0.506584    
#> 265: 0.928417    1.131279    3.549339    0.645135    0.022785    0.011188    0.506452    
#> 266: 0.928946    1.131604    3.549268    0.646030    0.022889    0.011171    0.506458    
#> 267: 0.929238    1.131702    3.549355    0.648286    0.022922    0.011180    0.506530    
#> 268: 0.928985    1.131703    3.549303    0.647640    0.022883    0.011184    0.506511    
#> 269: 0.929324    1.131426    3.549351    0.647976    0.022803    0.011213    0.506562    
#> 270: 0.929414    1.131386    3.549207    0.647270    0.022684    0.011259    0.506599    
#> 271: 0.929435    1.131348    3.549123    0.647129    0.022583    0.011297    0.506654    
#> 272: 0.929136    1.131283    3.549095    0.645010    0.022521    0.011333    0.506913    
#> 273: 0.928982    1.131374    3.549073    0.645498    0.022502    0.011354    0.507093    
#> 274: 0.928740    1.131455    3.549066    0.645886    0.022478    0.011385    0.506889    
#> 275: 0.928594    1.131595    3.548951    0.645512    0.022471    0.011364    0.506842    
#> 276: 0.928476    1.131738    3.549065    0.645627    0.022483    0.011372    0.506790    
#> 277: 0.928305    1.131939    3.549204    0.645713    0.022484    0.011403    0.506931    
#> 278: 0.928213    1.131962    3.549281    0.646076    0.022550    0.011408    0.506823    
#> 279: 0.928056    1.131844    3.549279    0.646016    0.022549    0.011397    0.506929    
#> 280: 0.927904    1.131955    3.549237    0.645588    0.022523    0.011386    0.506980    
#> 281: 0.927242    1.132122    3.549181    0.644582    0.022570    0.011359    0.506901    
#> 282: 0.926889    1.132372    3.549141    0.644305    0.022623    0.011354    0.506810    
#> 283: 0.926898    1.132573    3.549182    0.645007    0.022683    0.011353    0.506807    
#> 284: 0.926652    1.132520    3.549093    0.645243    0.022693    0.011350    0.506702    
#> 285: 0.926501    1.132626    3.548875    0.646069    0.022721    0.011346    0.506745    
#> 286: 0.925946    1.132905    3.548602    0.645597    0.022768    0.011352    0.506777    
#> 287: 0.925291    1.133217    3.548377    0.645511    0.022759    0.011377    0.506929    
#> 288: 0.924791    1.133383    3.548180    0.644739    0.022793    0.011389    0.506970    
#> 289: 0.924618    1.133552    3.548029    0.645300    0.022848    0.011387    0.506965    
#> 290: 0.924586    1.133623    3.547945    0.645932    0.022847    0.011394    0.507049    
#> 291: 0.924584    1.133761    3.547875    0.646157    0.022799    0.011387    0.506990    
#> 292: 0.924439    1.133834    3.547790    0.646028    0.022746    0.011377    0.506975    
#> 293: 0.924113    1.133941    3.547657    0.646015    0.022710    0.011378    0.506946    
#> 294: 0.923723    1.134070    3.547524    0.646339    0.022725    0.011366    0.506875    
#> 295: 0.923657    1.133965    3.547504    0.646355    0.022703    0.011367    0.506799    
#> 296: 0.923651    1.133907    3.547423    0.646674    0.022699    0.011378    0.506841    
#> 297: 0.923635    1.133944    3.547432    0.646865    0.022634    0.011385    0.507085    
#> 298: 0.923925    1.133856    3.547405    0.647615    0.022603    0.011378    0.506947    
#> 299: 0.923935    1.133864    3.547298    0.648180    0.022572    0.011378    0.506877    
#> 300: 0.924373    1.133774    3.547374    0.649557    0.022555    0.011397    0.506812    
#> 301: 0.924632    1.133729    3.547306    0.650552    0.022555    0.011402    0.506788    
#> 302: 0.924605    1.133773    3.547199    0.650493    0.022592    0.011413    0.506652    
#> 303: 0.924335    1.133938    3.547113    0.650183    0.022608    0.011411    0.506474    
#> 304: 0.924089    1.134225    3.546914    0.650070    0.022641    0.011394    0.506390    
#> 305: 0.923879    1.134254    3.546827    0.650075    0.022649    0.011384    0.506329    
#> 306: 0.923051    1.134273    3.546665    0.649245    0.022697    0.011357    0.506208    
#> 307: 0.922949    1.134261    3.546603    0.650088    0.022737    0.011341    0.506198    
#> 308: 0.922592    1.134240    3.546545    0.650428    0.022783    0.011324    0.506215    
#> 309: 0.922650    1.134124    3.546501    0.650990    0.022831    0.011295    0.506216    
#> 310: 0.923154    1.134114    3.546352    0.652844    0.022890    0.011277    0.506179    
#> 311: 0.923135    1.134152    3.546255    0.653960    0.022939    0.011265    0.506145    
#> 312: 0.922854    1.134077    3.546133    0.654238    0.022951    0.011241    0.506203    
#> 313: 0.922433    1.134004    3.545996    0.654497    0.022956    0.011232    0.506273    
#> 314: 0.921817    1.133948    3.545897    0.654517    0.022948    0.011211    0.506320    
#> 315: 0.921426    1.134045    3.545813    0.654468    0.022976    0.011198    0.506357    
#> 316: 0.920971    1.134158    3.545688    0.654040    0.022996    0.011192    0.506360    
#> 317: 0.921016    1.134230    3.545608    0.654456    0.023045    0.011174    0.506558    
#> 318: 0.921247    1.134292    3.545528    0.655044    0.023071    0.011170    0.506572    
#> 319: 0.921353    1.134304    3.545530    0.655785    0.023074    0.011162    0.506718    
#> 320: 0.920869    1.134353    3.545437    0.656044    0.023077    0.011137    0.506871    
#> 321: 0.920588    1.134489    3.545303    0.656057    0.023126    0.011102    0.507005    
#> 322: 0.920315    1.134539    3.545192    0.656082    0.023180    0.011102    0.506943    
#> 323: 0.919874    1.134568    3.545079    0.656309    0.023216    0.011115    0.506888    
#> 324: 0.919946    1.134719    3.545017    0.657178    0.023234    0.011121    0.506878    
#> 325: 0.919731    1.134867    3.544892    0.657249    0.023213    0.011115    0.506931    
#> 326: 0.919499    1.134792    3.544845    0.656853    0.023200    0.011122    0.506944    
#> 327: 0.919296    1.134777    3.544800    0.656602    0.023172    0.011109    0.506930    
#> 328: 0.919082    1.134910    3.544755    0.656498    0.023168    0.011098    0.506922    
#> 329: 0.918998    1.134993    3.544708    0.656848    0.023122    0.011087    0.506813    
#> 330: 0.918521    1.135098    3.544623    0.656137    0.023097    0.011071    0.506764    
#> 331: 0.918450    1.135370    3.544554    0.656032    0.023097    0.011060    0.506646    
#> 332: 0.918262    1.135412    3.544570    0.655925    0.023096    0.011097    0.506581    
#> 333: 0.918187    1.135473    3.544558    0.655677    0.023087    0.011120    0.506522    
#> 334: 0.918034    1.135505    3.544491    0.656048    0.023080    0.011124    0.506420    
#> 335: 0.918089    1.135603    3.544386    0.656627    0.023077    0.011122    0.506477    
#> 336: 0.917975    1.135820    3.544271    0.657183    0.023092    0.011120    0.506523    
#> 337: 0.917731    1.136069    3.544112    0.658067    0.023131    0.011121    0.506563    
#> 338: 0.917596    1.136150    3.544024    0.658376    0.023150    0.011120    0.506606    
#> 339: 0.917377    1.136229    3.543986    0.658417    0.023135    0.011121    0.506580    
#> 340: 0.917312    1.136186    3.543957    0.658746    0.023131    0.011118    0.506596    
#> 341: 0.917635    1.136131    3.543993    0.659491    0.023109    0.011112    0.506572    
#> 342: 0.917341    1.136138    3.544010    0.659440    0.023120    0.011110    0.506585    
#> 343: 0.917086    1.136235    3.544085    0.658576    0.023146    0.011111    0.506566    
#> 344: 0.917229    1.136235    3.544135    0.658035    0.023166    0.011107    0.506557    
#> 345: 0.917082    1.136176    3.544157    0.657726    0.023146    0.011098    0.506497    
#> 346: 0.916994    1.136225    3.544139    0.657593    0.023111    0.011099    0.506436    
#> 347: 0.917128    1.136104    3.544111    0.658152    0.023115    0.011093    0.506448    
#> 348: 0.916850    1.136124    3.544105    0.657182    0.023118    0.011074    0.506519    
#> 349: 0.916691    1.136104    3.544103    0.656685    0.023132    0.011067    0.506438    
#> 350: 0.916532    1.136164    3.544116    0.656704    0.023132    0.011063    0.506450    
#> 351: 0.916541    1.136326    3.544108    0.656725    0.023132    0.011057    0.506500    
#> 352: 0.916552    1.136422    3.544119    0.656655    0.023111    0.011067    0.506620    
#> 353: 0.916926    1.136516    3.544142    0.657367    0.023083    0.011074    0.506594    
#> 354: 0.917214    1.136588    3.544125    0.658184    0.023067    0.011071    0.506559    
#> 355: 0.917620    1.136529    3.544105    0.659270    0.023022    0.011073    0.506598    
#> 356: 0.917812    1.136480    3.544150    0.660046    0.022993    0.011081    0.506643    
#> 357: 0.918119    1.136505    3.544172    0.660169    0.022966    0.011100    0.506624    
#> 358: 0.918030    1.136545    3.544210    0.660124    0.022946    0.011099    0.506648    
#> 359: 0.917815    1.136614    3.544216    0.659714    0.022912    0.011107    0.506671    
#> 360: 0.917804    1.136622    3.544204    0.659722    0.022879    0.011102    0.506608    
#> 361: 0.917579    1.136711    3.544169    0.659723    0.022896    0.011092    0.506500    
#> 362: 0.917557    1.136773    3.544119    0.659677    0.022914    0.011076    0.506344    
#> 363: 0.917578    1.136752    3.544150    0.659900    0.022919    0.011065    0.506285    
#> 364: 0.917716    1.136807    3.544134    0.660064    0.022918    0.011063    0.506253    
#> 365: 0.917883    1.136856    3.544118    0.660906    0.022943    0.011057    0.506278    
#> 366: 0.917990    1.136907    3.544060    0.661637    0.022948    0.011052    0.506426    
#> 367: 0.918006    1.136958    3.544017    0.662222    0.022977    0.011042    0.506496    
#> 368: 0.918241    1.136970    3.543985    0.662780    0.023016    0.011029    0.506455    
#> 369: 0.918105    1.136970    3.543963    0.662684    0.023028    0.011035    0.506541    
#> 370: 0.917792    1.137034    3.543872    0.662523    0.023065    0.011031    0.506565    
#> 371: 0.917752    1.137052    3.543809    0.662521    0.023077    0.011026    0.506537    
#> 372: 0.917356    1.137108    3.543713    0.662803    0.023106    0.011015    0.506558    
#> 373: 0.917214    1.137257    3.543620    0.663874    0.023116    0.011011    0.506593    
#> 374: 0.917129    1.137314    3.543560    0.664214    0.023105    0.011011    0.506614    
#> 375: 0.916894    1.137395    3.543525    0.664398    0.023136    0.011012    0.506681    
#> 376: 0.916828    1.137431    3.543484    0.665242    0.023164    0.011024    0.506598    
#> 377: 0.916772    1.137520    3.543417    0.665829    0.023138    0.011024    0.506598    
#> 378: 0.916502    1.137561    3.543342    0.665533    0.023111    0.011037    0.506631    
#> 379: 0.916294    1.137457    3.543306    0.665839    0.023095    0.011051    0.506557    
#> 380: 0.916104    1.137435    3.543266    0.665615    0.023061    0.011057    0.506522    
#> 381: 0.915823    1.137419    3.543202    0.665577    0.023055    0.011067    0.506475    
#> 382: 0.915637    1.137410    3.543170    0.665766    0.023011    0.011084    0.506413    
#> 383: 0.915648    1.137439    3.543131    0.666216    0.022992    0.011092    0.506320    
#> 384: 0.915519    1.137409    3.543109    0.666598    0.022957    0.011100    0.506337    
#> 385: 0.915757    1.137412    3.543081    0.667595    0.022938    0.011113    0.506337    
#> 386: 0.916155    1.137492    3.543103    0.668670    0.022948    0.011126    0.506362    
#> 387: 0.916281    1.137595    3.543133    0.668631    0.022967    0.011137    0.506401    
#> 388: 0.916328    1.137649    3.543140    0.668736    0.022998    0.011150    0.506373    
#> 389: 0.916252    1.137556    3.543117    0.668963    0.023020    0.011149    0.506439    
#> 390: 0.916183    1.137579    3.543077    0.669153    0.023028    0.011145    0.506455    
#> 391: 0.916270    1.137560    3.543036    0.669270    0.023027    0.011151    0.506407    
#> 392: 0.916533    1.137542    3.543061    0.669923    0.023037    0.011160    0.506378    
#> 393: 0.916642    1.137490    3.543063    0.670639    0.023053    0.011169    0.506330    
#> 394: 0.916480    1.137468    3.543027    0.670506    0.023057    0.011168    0.506301    
#> 395: 0.916404    1.137520    3.543027    0.670307    0.023069    0.011165    0.506265    
#> 396: 0.916314    1.137544    3.543015    0.670295    0.023064    0.011168    0.506182    
#> 397: 0.916272    1.137481    3.543018    0.670351    0.023057    0.011167    0.506190    
#> 398: 0.916367    1.137358    3.543052    0.670401    0.023036    0.011174    0.506182    
#> 399: 0.916387    1.137334    3.543094    0.670102    0.023040    0.011175    0.506156    
#> 400: 0.916392    1.137343    3.543132    0.670032    0.023048    0.011169    0.506118    
#> 401: 0.916317    1.137346    3.543127    0.669683    0.023043    0.011155    0.506162    
#> 402: 0.916416    1.137361    3.543094    0.669542    0.023050    0.011148    0.506216    
#> 403: 0.916536    1.137357    3.543074    0.669386    0.023039    0.011144    0.506260    
#> 404: 0.916424    1.137338    3.543011    0.669200    0.023063    0.011124    0.506266    
#> 405: 0.916267    1.137323    3.542979    0.669569    0.023107    0.011107    0.506225    
#> 406: 0.916243    1.137320    3.542927    0.670238    0.023160    0.011094    0.506213    
#> 407: 0.916333    1.137396    3.542933    0.670410    0.023201    0.011082    0.506240    
#> 408: 0.916561    1.137482    3.542922    0.670460    0.023237    0.011072    0.506259    
#> 409: 0.916629    1.137484    3.542914    0.670282    0.023237    0.011061    0.506240    
#> 410: 0.916502    1.137504    3.542889    0.669821    0.023241    0.011060    0.506272    
#> 411: 0.916436    1.137408    3.542870    0.669357    0.023262    0.011058    0.506391    
#> 412: 0.916387    1.137396    3.542856    0.669051    0.023270    0.011052    0.506455    
#> 413: 0.916214    1.137437    3.542786    0.668779    0.023273    0.011049    0.506463    
#> 414: 0.915885    1.137533    3.542752    0.668466    0.023283    0.011042    0.506464    
#> 415: 0.915762    1.137560    3.542712    0.668426    0.023284    0.011034    0.506435    
#> 416: 0.915852    1.137622    3.542716    0.668895    0.023286    0.011032    0.506350    
#> 417: 0.915900    1.137617    3.542708    0.669495    0.023284    0.011027    0.506273    
#> 418: 0.915864    1.137638    3.542719    0.669606    0.023286    0.011022    0.506219    
#> 419: 0.915979    1.137709    3.542738    0.669734    0.023293    0.011027    0.506190    
#> 420: 0.916016    1.137745    3.542741    0.669787    0.023287    0.011036    0.506144    
#> 421: 0.915849    1.137716    3.542738    0.669577    0.023281    0.011040    0.506055    
#> 422: 0.915896    1.137665    3.542752    0.669644    0.023255    0.011048    0.506030    
#> 423: 0.916045    1.137600    3.542778    0.669562    0.023235    0.011053    0.506040    
#> 424: 0.915937    1.137533    3.542720    0.669395    0.023221    0.011047    0.506107    
#> 425: 0.916087    1.137580    3.542691    0.669913    0.023252    0.011048    0.506174    
#> 426: 0.916078    1.137629    3.542654    0.670306    0.023256    0.011042    0.506223    
#> 427: 0.915876    1.137644    3.542658    0.670114    0.023241    0.011037    0.506250    
#> 428: 0.915930    1.137650    3.542687    0.670327    0.023244    0.011029    0.506291    
#> 429: 0.916052    1.137681    3.542726    0.670395    0.023235    0.011024    0.506287    
#> 430: 0.916173    1.137677    3.542739    0.670611    0.023239    0.011013    0.506318    
#> 431: 0.916041    1.137675    3.542764    0.670374    0.023240    0.011002    0.506268    
#> 432: 0.915915    1.137734    3.542745    0.670264    0.023265    0.010988    0.506235    
#> 433: 0.915894    1.137827    3.542756    0.670392    0.023277    0.010977    0.506235    
#> 434: 0.915932    1.137798    3.542762    0.670385    0.023250    0.010976    0.506263    
#> 435: 0.916020    1.137800    3.542745    0.670631    0.023231    0.010983    0.506248    
#> 436: 0.915939    1.137807    3.542746    0.670670    0.023247    0.010989    0.506231    
#> 437: 0.916021    1.137812    3.542738    0.670812    0.023258    0.010989    0.506205    
#> 438: 0.915916    1.137864    3.542714    0.670538    0.023265    0.010992    0.506186    
#> 439: 0.915846    1.137934    3.542711    0.670207    0.023269    0.010992    0.506105    
#> 440: 0.915838    1.138000    3.542725    0.669940    0.023271    0.010992    0.506037    
#> 441: 0.915872    1.137979    3.542748    0.669740    0.023288    0.010995    0.505968    
#> 442: 0.915809    1.138029    3.542775    0.669508    0.023305    0.010987    0.505915    
#> 443: 0.915815    1.138086    3.542755    0.669037    0.023314    0.010988    0.505900    
#> 444: 0.915719    1.138135    3.542707    0.669217    0.023329    0.010996    0.505891    
#> 445: 0.915539    1.138141    3.542657    0.669480    0.023326    0.011008    0.506007    
#> 446: 0.915368    1.138200    3.542629    0.669046    0.023301    0.011009    0.506052    
#> 447: 0.915296    1.138268    3.542604    0.668758    0.023292    0.011014    0.506111    
#> 448: 0.915089    1.138290    3.542610    0.668178    0.023305    0.011011    0.506136    
#> 449: 0.915053    1.138361    3.542667    0.667832    0.023330    0.011010    0.506194    
#> 450: 0.915058    1.138366    3.542679    0.667481    0.023351    0.011013    0.506198    
#> 451: 0.915007    1.138429    3.542678    0.667396    0.023368    0.011016    0.506205    
#> 452: 0.914895    1.138481    3.542658    0.667092    0.023381    0.011011    0.506162    
#> 453: 0.914850    1.138526    3.542631    0.666785    0.023379    0.011007    0.506117    
#> 454: 0.914666    1.138616    3.542589    0.666554    0.023393    0.011002    0.506084    
#> 455: 0.914652    1.138633    3.542576    0.666611    0.023383    0.010996    0.506096    
#> 456: 0.914544    1.138607    3.542554    0.666579    0.023395    0.010995    0.506114    
#> 457: 0.914524    1.138609    3.542567    0.666575    0.023399    0.011000    0.506090    
#> 458: 0.914553    1.138669    3.542597    0.666448    0.023402    0.011004    0.506051    
#> 459: 0.914469    1.138759    3.542601    0.666421    0.023403    0.011006    0.506038    
#> 460: 0.914262    1.138802    3.542569    0.666083    0.023405    0.011012    0.506016    
#> 461: 0.914083    1.138843    3.542584    0.665987    0.023410    0.011019    0.506005    
#> 462: 0.913969    1.138879    3.542592    0.665717    0.023397    0.011027    0.505959    
#> 463: 0.914037    1.138910    3.542634    0.665481    0.023380    0.011036    0.505904    
#> 464: 0.914118    1.138953    3.542621    0.665344    0.023372    0.011037    0.505846    
#> 465: 0.914035    1.138880    3.542613    0.665066    0.023363    0.011039    0.505805    
#> 466: 0.913953    1.138882    3.542576    0.664995    0.023345    0.011043    0.505773    
#> 467: 0.913814    1.138897    3.542612    0.664677    0.023328    0.011047    0.505728    
#> 468: 0.913938    1.138893    3.542668    0.664690    0.023330    0.011054    0.505746    
#> 469: 0.914032    1.138986    3.542703    0.664707    0.023362    0.011050    0.505739    
#> 470: 0.914018    1.139047    3.542681    0.664793    0.023372    0.011056    0.505759    
#> 471: 0.913968    1.139077    3.542662    0.664833    0.023365    0.011055    0.505774    
#> 472: 0.913901    1.139109    3.542650    0.664804    0.023386    0.011047    0.505700    
#> 473: 0.913705    1.139158    3.542619    0.664543    0.023382    0.011042    0.505673    
#> 474: 0.913597    1.139188    3.542590    0.664388    0.023383    0.011041    0.505734    
#> 475: 0.913589    1.139269    3.542560    0.664407    0.023395    0.011039    0.505732    
#> 476: 0.913487    1.139287    3.542510    0.664678    0.023409    0.011038    0.505724    
#> 477: 0.913410    1.139321    3.542495    0.664613    0.023399    0.011042    0.505682    
#> 478: 0.913269    1.139311    3.542486    0.664378    0.023385    0.011044    0.505675    
#> 479: 0.913320    1.139325    3.542485    0.664526    0.023387    0.011042    0.505642    
#> 480: 0.913205    1.139328    3.542464    0.664600    0.023389    0.011042    0.505682    
#> 481: 0.913182    1.139343    3.542417    0.664977    0.023397    0.011041    0.505679    
#> 482: 0.913198    1.139354    3.542363    0.665488    0.023412    0.011044    0.505702    
#> 483: 0.913172    1.139375    3.542336    0.665712    0.023430    0.011043    0.505724    
#> 484: 0.913294    1.139304    3.542368    0.666145    0.023430    0.011050    0.505757    
#> 485: 0.913313    1.139309    3.542399    0.666175    0.023442    0.011055    0.505784    
#> 486: 0.913339    1.139318    3.542441    0.666088    0.023444    0.011054    0.505792    
#> 487: 0.913631    1.139312    3.542493    0.666413    0.023435    0.011057    0.505790    
#> 488: 0.913649    1.139294    3.542526    0.666262    0.023438    0.011057    0.505775    
#> 489: 0.913791    1.139254    3.542530    0.666330    0.023452    0.011060    0.505781    
#> 490: 0.913838    1.139268    3.542535    0.666288    0.023470    0.011055    0.505738    
#> 491: 0.913927    1.139317    3.542534    0.666423    0.023469    0.011057    0.505681    
#> 492: 0.914008    1.139362    3.542516    0.666692    0.023464    0.011050    0.505683    
#> 493: 0.914097    1.139363    3.542535    0.667083    0.023458    0.011043    0.505673    
#> 494: 0.914279    1.139369    3.542539    0.667112    0.023460    0.011047    0.505671    
#> 495: 0.914409    1.139385    3.542549    0.667212    0.023454    0.011040    0.505660    
#> 496: 0.914562    1.139444    3.542532    0.667074    0.023452    0.011042    0.505674    
#> 497: 0.914636    1.139470    3.542547    0.666991    0.023434    0.011043    0.505722    
#> 498: 0.914663    1.139468    3.542539    0.666927    0.023434    0.011043    0.505668    
#> 499: 0.914668    1.139526    3.542526    0.666949    0.023421    0.011048    0.505669    
#> 500: 0.914652    1.139547    3.542514    0.666864    0.023396    0.011054    0.505645    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.346494    0.973646    3.446383    0.392401    0.078972    0.016800    1.678691    
#> 002: 0.543145    1.028533    3.487166    0.372781    0.075024    0.016235    1.139165    
#> 003: 0.717662    1.021149    3.504140    0.354142    0.071273    0.015424    0.857182    
#> 004: 0.708971    1.050257    3.512992    0.378445    0.067709    0.016060    0.777334    
#> 005: 0.773569    1.061994    3.505648    0.415341    0.064323    0.015257    0.758218    
#> 006: 0.737262    1.076866    3.501799    0.467371    0.061107    0.014494    0.734317    
#> 007: 0.676017    1.082579    3.491127    0.444002    0.058052    0.013769    0.735265    
#> 008: 0.660811    1.078970    3.481212    0.421802    0.055149    0.015326    0.757474    
#> 009: 0.643518    1.088090    3.470360    0.400712    0.052392    0.014560    0.746650    
#> 010: 0.669948    1.060195    3.467484    0.450212    0.052118    0.013832    0.757264    
#> 011: 0.737624    1.084746    3.484852    0.477148    0.051316    0.015382    0.750341    
#> 012: 0.719913    1.072035    3.482626    0.453291    0.048750    0.017301    0.741047    
#> 013: 0.662140    1.056868    3.475477    0.506523    0.046313    0.017197    0.766322    
#> 014: 0.709011    1.051595    3.488368    0.481197    0.056073    0.016338    0.763371    
#> 015: 0.740456    1.049488    3.509218    0.457137    0.053269    0.015521    0.753916    
#> 016: 0.732395    1.083720    3.511371    0.434280    0.050606    0.015598    0.775513    
#> 017: 0.754639    1.077729    3.513518    0.450048    0.048076    0.014818    0.743467    
#> 018: 0.739312    1.088399    3.499202    0.448855    0.045672    0.014077    0.734871    
#> 019: 0.709356    1.082524    3.496137    0.486813    0.044792    0.013373    0.720026    
#> 020: 0.735499    1.068251    3.504429    0.505079    0.043838    0.013963    0.742890    
#> 021: 0.800806    1.049582    3.518523    0.532429    0.041646    0.013265    0.732990    
#> 022: 0.783255    1.043543    3.528884    0.505808    0.039564    0.013719    0.733771    
#> 023: 0.848270    1.040729    3.541169    0.480517    0.037586    0.017274    0.758705    
#> 024: 0.839473    1.056436    3.532160    0.456492    0.035706    0.019455    0.753452    
#> 025: 0.801119    1.025068    3.524231    0.509619    0.034592    0.018483    0.763005    
#> 026: 0.740334    1.082141    3.497780    0.526130    0.033722    0.017559    0.729452    
#> 027: 0.729880    1.097018    3.487798    0.499824    0.036268    0.016681    0.755398    
#> 028: 0.760627    1.069494    3.505097    0.497981    0.034455    0.018439    0.717814    
#> 029: 0.768851    1.053532    3.496194    0.473082    0.037287    0.019427    0.732631    
#> 030: 0.737291    1.084602    3.498468    0.489013    0.037367    0.018455    0.733397    
#> 031: 0.734135    1.060959    3.510830    0.464562    0.036007    0.020593    0.733256    
#> 032: 0.714886    1.073730    3.504420    0.507833    0.036398    0.019563    0.733377    
#> 033: 0.741634    1.070180    3.495962    0.537754    0.034578    0.020631    0.736989    
#> 034: 0.749460    1.066769    3.493310    0.581222    0.032849    0.019600    0.740160    
#> 035: 0.710374    1.063287    3.485280    0.552161    0.031207    0.018620    0.715380    
#> 036: 0.724937    1.083586    3.485898    0.524553    0.032853    0.017689    0.736606    
#> 037: 0.709907    1.074408    3.488612    0.498325    0.031210    0.018408    0.745890    
#> 038: 0.755714    1.079626    3.484308    0.586170    0.029650    0.019341    0.732316    
#> 039: 0.743803    1.072294    3.501333    0.571408    0.031046    0.019456    0.724727    
#> 040: 0.720082    1.075963    3.509158    0.542837    0.032107    0.018484    0.734915    
#> 041: 0.717509    1.070031    3.495530    0.515695    0.034395    0.017559    0.728440    
#> 042: 0.775495    1.043343    3.502055    0.529516    0.032788    0.016681    0.723078    
#> 043: 0.710594    1.058672    3.489626    0.503041    0.036522    0.015847    0.730216    
#> 044: 0.697698    1.087787    3.490024    0.477889    0.034696    0.015623    0.729184    
#> 045: 0.690473    1.097942    3.482941    0.488954    0.032961    0.014841    0.721442    
#> 046: 0.702837    1.086443    3.493106    0.507149    0.031313    0.015051    0.730560    
#> 047: 0.703604    1.082741    3.484595    0.481792    0.032163    0.014298    0.720357    
#> 048: 0.718425    1.072205    3.493171    0.468226    0.049139    0.013584    0.725632    
#> 049: 0.701020    1.048026    3.491755    0.444815    0.046682    0.013447    0.746913    
#> 050: 0.766091    1.028290    3.498690    0.441841    0.051565    0.014214    0.748313    
#> 051: 0.760344    1.056870    3.496552    0.551618    0.048986    0.013504    0.750711    
#> 052: 0.766522    1.060567    3.504534    0.524037    0.051840    0.012828    0.744049    
#> 053: 0.815563    1.060676    3.505759    0.603943    0.056991    0.012187    0.733846    
#> 054: 0.702706    1.072790    3.498583    0.573746    0.062009    0.011578    0.737787    
#> 055: 0.710224    1.092934    3.487061    0.555571    0.058908    0.010999    0.726959    
#> 056: 0.727088    1.079359    3.481273    0.540829    0.055963    0.011908    0.742864    
#> 057: 0.707157    1.065288    3.486863    0.513788    0.053165    0.012685    0.753494    
#> 058: 0.701138    1.077197    3.481719    0.528211    0.050506    0.015056    0.731937    
#> 059: 0.727524    1.031380    3.490768    0.602632    0.047981    0.020666    0.751894    
#> 060: 0.760979    1.025768    3.508032    0.572501    0.048441    0.019633    0.752708    
#> 061: 0.790985    1.030348    3.518012    0.543876    0.046019    0.018651    0.775866    
#> 062: 0.757024    1.051579    3.518227    0.516682    0.044805    0.017719    0.773695    
#> 063: 0.759894    1.033324    3.519500    0.490848    0.042564    0.017952    0.784843    
#> 064: 0.769917    1.049893    3.524641    0.469243    0.042448    0.017054    0.752565    
#> 065: 0.790774    1.053340    3.507913    0.529495    0.042902    0.017303    0.732303    
#> 066: 0.770861    1.077290    3.512407    0.503020    0.040757    0.019515    0.740626    
#> 067: 0.727897    1.069473    3.498524    0.477869    0.038719    0.019338    0.725204    
#> 068: 0.688627    1.081246    3.505767    0.453976    0.043529    0.018371    0.746075    
#> 069: 0.700295    1.089474    3.490119    0.443854    0.048401    0.017453    0.726665    
#> 070: 0.707839    1.073567    3.497624    0.515019    0.046780    0.018750    0.722036    
#> 071: 0.702587    1.090059    3.485717    0.514149    0.052199    0.018900    0.726812    
#> 072: 0.700391    1.066561    3.490610    0.488441    0.049589    0.017955    0.727521    
#> 073: 0.707238    1.078422    3.500270    0.464019    0.047110    0.017058    0.733574    
#> 074: 0.720067    1.066964    3.496542    0.454505    0.044754    0.016205    0.736801    
#> 075: 0.726950    1.068934    3.511914    0.537314    0.042517    0.015394    0.736696    
#> 076: 0.717630    1.085604    3.493747    0.586088    0.040391    0.014625    0.739280    
#> 077: 0.771315    1.069630    3.492877    0.613302    0.038461    0.013894    0.723496    
#> 078: 0.764230    1.064611    3.500002    0.582636    0.038597    0.013199    0.728079    
#> 079: 0.770769    1.078795    3.501602    0.629211    0.047283    0.013274    0.734282    
#> 080: 0.773238    1.062758    3.502357    0.637903    0.046396    0.012949    0.747736    
#> 081: 0.778944    1.072553    3.498129    0.621935    0.044076    0.014524    0.738647    
#> 082: 0.811334    1.043011    3.507099    0.743533    0.041872    0.017195    0.733004    
#> 083: 0.738967    1.061661    3.503911    0.706357    0.039779    0.019455    0.749231    
#> 084: 0.767086    1.052695    3.501994    0.671039    0.037790    0.019664    0.730500    
#> 085: 0.756606    1.058806    3.509270    0.637487    0.044657    0.018681    0.723976    
#> 086: 0.771481    1.076500    3.502271    0.605613    0.042424    0.017747    0.744232    
#> 087: 0.744977    1.068006    3.495333    0.575332    0.044653    0.016860    0.723493    
#> 088: 0.663428    1.048674    3.493713    0.546565    0.042421    0.016017    0.730486    
#> 089: 0.685007    1.074816    3.482744    0.519237    0.045355    0.015216    0.742034    
#> 090: 0.664291    1.087545    3.473134    0.512974    0.043087    0.014455    0.753171    
#> 091: 0.670842    1.073049    3.469802    0.530163    0.040933    0.014716    0.726851    
#> 092: 0.661313    1.098593    3.462869    0.570408    0.038886    0.016110    0.732042    
#> 093: 0.621096    1.086468    3.462710    0.541887    0.036942    0.015361    0.738590    
#> 094: 0.664182    1.100273    3.460802    0.514793    0.035095    0.018018    0.740217    
#> 095: 0.685041    1.098071    3.489116    0.581896    0.037358    0.018848    0.728821    
#> 096: 0.658524    1.103764    3.474217    0.633853    0.038399    0.017906    0.723977    
#> 097: 0.704555    1.119680    3.473794    0.602161    0.041710    0.017011    0.732482    
#> 098: 0.720535    1.112771    3.481949    0.572053    0.042541    0.016797    0.728285    
#> 099: 0.649651    1.064150    3.472154    0.543450    0.040414    0.015957    0.748173    
#> 100: 0.680657    1.067093    3.485417    0.569560    0.038393    0.015159    0.727131    
#> 101: 0.689266    1.057743    3.474753    0.541082    0.036473    0.014401    0.735848    
#> 102: 0.643175    1.061880    3.459521    0.514028    0.034650    0.013681    0.726816    
#> 103: 0.708531    1.067258    3.482519    0.488326    0.032917    0.012997    0.718823    
#> 104: 0.692060    1.061399    3.499638    0.475734    0.031271    0.014036    0.733277    
#> 105: 0.693015    1.059529    3.485319    0.481395    0.030542    0.015349    0.730589    
#> 106: 0.734376    1.063363    3.488118    0.522630    0.030697    0.014582    0.737227    
#> 107: 0.748757    1.088821    3.495491    0.582110    0.031344    0.013853    0.738209    
#> 108: 0.681236    1.087311    3.479660    0.553005    0.039644    0.015564    0.740610    
#> 109: 0.694732    1.071550    3.495563    0.525354    0.037662    0.014786    0.744861    
#> 110: 0.700786    1.077069    3.483990    0.499087    0.035779    0.014046    0.734827    
#> 111: 0.708520    1.084238    3.491793    0.474132    0.039889    0.013344    0.721456    
#> 112: 0.688540    1.059908    3.483774    0.450426    0.042319    0.014381    0.726482    
#> 113: 0.710537    1.084448    3.498569    0.453495    0.040203    0.016910    0.720367    
#> 114: 0.717293    1.070094    3.498732    0.430820    0.042926    0.018820    0.714322    
#> 115: 0.722366    1.049317    3.500411    0.430996    0.040780    0.017879    0.739103    
#> 116: 0.720391    1.066150    3.490309    0.485061    0.038741    0.019614    0.746481    
#> 117: 0.671045    1.086593    3.489050    0.460808    0.036853    0.022627    0.739120    
#> 118: 0.722612    1.088750    3.492626    0.489235    0.041297    0.021496    0.732625    
#> 119: 0.764203    1.065865    3.495010    0.611766    0.041247    0.020421    0.735490    
#> 120: 0.705315    1.072387    3.484488    0.581178    0.040500    0.019400    0.731194    
#> 121: 0.728728    1.091326    3.491343    0.552119    0.043735    0.018430    0.731855    
#> 122: 0.731658    1.065561    3.501086    0.524513    0.041548    0.018933    0.728280    
#> 123: 0.750804    1.076564    3.496289    0.498287    0.039471    0.018043    0.728652    
#> 124: 0.729412    1.106290    3.486292    0.539202    0.044927    0.019417    0.729086    
#> 125: 0.753960    1.105810    3.485441    0.523067    0.042680    0.018446    0.737633    
#> 126: 0.704546    1.121204    3.474378    0.569978    0.049480    0.017524    0.734084    
#> 127: 0.677927    1.083506    3.475942    0.541479    0.047006    0.016647    0.721967    
#> 128: 0.686315    1.078700    3.495313    0.556693    0.044655    0.015815    0.731286    
#> 129: 0.765683    1.092703    3.505311    0.643496    0.060026    0.015024    0.734291    
#> 130: 0.797253    1.082965    3.504410    0.611321    0.058359    0.014273    0.734253    
#> 131: 0.753817    1.066190    3.497460    0.580755    0.058931    0.017125    0.721429    
#> 132: 0.738443    1.051637    3.495413    0.551717    0.055985    0.016269    0.731562    
#> 133: 0.740460    1.059204    3.505615    0.524131    0.053185    0.015780    0.729817    
#> 134: 0.772397    1.053367    3.516573    0.497925    0.050526    0.014991    0.739008    
#> 135: 0.762632    1.065826    3.514859    0.473029    0.048000    0.016639    0.739799    
#> 136: 0.763554    1.046243    3.505885    0.452011    0.045600    0.015807    0.741693    
#> 137: 0.810873    1.055507    3.501158    0.564977    0.043320    0.015016    0.769361    
#> 138: 0.730862    1.043220    3.498979    0.543003    0.041154    0.014266    0.748881    
#> 139: 0.700370    1.059523    3.507835    0.515853    0.043705    0.013552    0.749534    
#> 140: 0.771329    1.081346    3.509060    0.547652    0.041519    0.016415    0.752137    
#> 141: 0.761075    1.059895    3.516363    0.555092    0.040668    0.015594    0.750811    
#> 142: 0.760308    1.038284    3.519948    0.527338    0.050957    0.014881    0.759611    
#> 143: 0.713198    1.050242    3.515071    0.500971    0.048409    0.016722    0.754216    
#> 144: 0.734288    1.071768    3.511273    0.475922    0.045989    0.015886    0.729388    
#> 145: 0.682962    1.088292    3.486985    0.452126    0.043689    0.015092    0.735140    
#> 146: 0.717282    1.097418    3.493820    0.476923    0.041505    0.014578    0.716398    
#> 147: 0.666444    1.082451    3.487412    0.453077    0.039429    0.014926    0.723320    
#> 148: 0.693743    1.088638    3.505002    0.430423    0.037458    0.015331    0.723748    
#> 149: 0.679800    1.066580    3.502227    0.408902    0.035585    0.014840    0.753080    
#> 150: 0.742239    1.068719    3.496677    0.463822    0.034167    0.014098    0.753055    
#> 151: 0.656251    1.096249    3.486465    0.440631    0.045451    0.013394    0.726616    
#> 152: 0.659296    1.079593    3.491627    0.417567    0.044511    0.014428    0.735173    
#> 153: 0.704169    1.096140    3.503988    0.434447    0.049930    0.013463    0.732927    
#> 154: 0.735053    1.094958    3.508080    0.441711    0.037606    0.013835    0.760448    
#> 155: 0.728369    1.080606    3.490168    0.585265    0.040392    0.014640    0.722823    
#> 156: 0.730137    1.077281    3.506036    0.498441    0.038919    0.018920    0.746797    
#> 157: 0.681078    1.063624    3.513431    0.409158    0.037925    0.016568    0.734842    
#> 158: 0.756254    1.065024    3.494866    0.486292    0.041641    0.012235    0.737847    
#> 159: 0.718995    1.094839    3.501630    0.427282    0.038109    0.012512    0.749383    
#> 160: 0.773120    1.053446    3.512461    0.451385    0.039270    0.013907    0.755778    
#> 161: 0.765362    1.044064    3.516822    0.434836    0.044169    0.014110    0.749237    
#> 162: 0.737052    1.070640    3.495679    0.483555    0.034900    0.013500    0.758234    
#> 163: 0.712290    1.057606    3.493009    0.538091    0.036275    0.013368    0.743234    
#> 164: 0.716436    1.081550    3.491660    0.442503    0.036821    0.011128    0.738366    
#> 165: 0.719666    1.070866    3.489193    0.518223    0.043646    0.009198    0.739349    
#> 166: 0.739963    1.102885    3.488257    0.572171    0.050287    0.008939    0.730960    
#> 167: 0.724678    1.098718    3.500193    0.468067    0.039286    0.011405    0.723394    
#> 168: 0.740075    1.094227    3.497499    0.466188    0.036351    0.014453    0.706520    
#> 169: 0.725931    1.116327    3.485642    0.483558    0.035931    0.011350    0.721760    
#> 170: 0.714459    1.092068    3.484497    0.463873    0.032738    0.013226    0.733370    
#> 171: 0.713686    1.072718    3.490503    0.469224    0.036756    0.009819    0.729792    
#> 172: 0.701479    1.083453    3.492052    0.498109    0.034179    0.011024    0.721266    
#> 173: 0.669255    1.097506    3.476195    0.402083    0.033193    0.013038    0.728484    
#> 174: 0.679726    1.104855    3.479756    0.423143    0.030501    0.012663    0.725772    
#> 175: 0.669256    1.098742    3.472770    0.473990    0.037437    0.011336    0.754605    
#> 176: 0.670340    1.118814    3.488802    0.396783    0.040232    0.012724    0.727072    
#> 177: 0.696189    1.099107    3.489941    0.515619    0.038845    0.007500    0.742216    
#> 178: 0.697531    1.083147    3.481984    0.471216    0.038920    0.006249    0.743983    
#> 179: 0.742846    1.105163    3.490452    0.588929    0.051478    0.007583    0.738434    
#> 180: 0.673364    1.084708    3.489001    0.392158    0.058102    0.008078    0.734128    
#> 181: 0.686729    1.069041    3.478791    0.401455    0.054573    0.008854    0.730375    
#> 182: 0.676890    1.100166    3.460478    0.481642    0.053322    0.008976    0.739561    
#> 183: 0.640817    1.133501    3.454070    0.433856    0.038559    0.007564    0.741630    
#> 184: 0.644854    1.105865    3.460875    0.513069    0.042483    0.007633    0.737650    
#> 185: 0.651447    1.124990    3.462813    0.453066    0.053317    0.008360    0.746410    
#> 186: 0.625831    1.121082    3.467152    0.458955    0.051038    0.006901    0.749440    
#> 187: 0.647464    1.107950    3.483725    0.474689    0.046031    0.008491    0.735431    
#> 188: 0.643826    1.097465    3.474259    0.518921    0.039015    0.009803    0.732218    
#> 189: 0.701433    1.089075    3.480363    0.515095    0.036636    0.011368    0.725400    
#> 190: 0.731800    1.087686    3.493641    0.500622    0.033781    0.010996    0.723426    
#> 191: 0.715399    1.092130    3.486577    0.512908    0.037381    0.010794    0.719788    
#> 192: 0.680114    1.078196    3.488991    0.467826    0.037835    0.010595    0.739065    
#> 193: 0.720771    1.095188    3.481645    0.490000    0.044902    0.009291    0.730517    
#> 194: 0.692373    1.104382    3.477488    0.494053    0.049750    0.011329    0.745034    
#> 195: 0.667099    1.097480    3.477106    0.435070    0.042258    0.011639    0.746903    
#> 196: 0.657485    1.104741    3.486162    0.467333    0.046227    0.010432    0.747461    
#> 197: 0.632959    1.110925    3.500849    0.399301    0.046884    0.007799    0.764339    
#> 198: 0.755360    1.082878    3.487200    0.482879    0.047506    0.010060    0.738651    
#> 199: 0.710491    1.061677    3.498576    0.397239    0.045759    0.010494    0.730267    
#> 200: 0.659377    1.076931    3.491110    0.345252    0.039755    0.013289    0.745719    
#> 201: 0.649836    1.074202    3.487373    0.367456    0.039148    0.012717    0.740156    
#> 202: 0.655495    1.079432    3.484508    0.376237    0.039637    0.013104    0.742952    
#> 203: 0.677054    1.079766    3.483028    0.407886    0.042017    0.012922    0.739953    
#> 204: 0.682878    1.077476    3.484038    0.423198    0.044696    0.012587    0.742573    
#> 205: 0.685314    1.082347    3.486210    0.430659    0.047254    0.012397    0.746067    
#> 206: 0.694066    1.083051    3.489714    0.448206    0.046017    0.012971    0.750710    
#> 207: 0.690647    1.081855    3.489342    0.448441    0.044055    0.013328    0.750819    
#> 208: 0.685890    1.080722    3.489545    0.439088    0.042934    0.013632    0.749829    
#> 209: 0.689000    1.079297    3.489591    0.442233    0.041617    0.013787    0.748933    
#> 210: 0.690841    1.077670    3.489722    0.448111    0.041328    0.013726    0.746149    
#> 211: 0.695900    1.077794    3.490479    0.455377    0.040980    0.013627    0.743941    
#> 212: 0.696779    1.077255    3.490818    0.458147    0.040917    0.013482    0.743594    
#> 213: 0.695239    1.074941    3.490386    0.455525    0.041081    0.013793    0.744295    
#> 214: 0.696528    1.073245    3.490519    0.456714    0.041341    0.014009    0.744455    
#> 215: 0.696535    1.072287    3.491723    0.455015    0.041291    0.014375    0.743700    
#> 216: 0.699553    1.070826    3.492293    0.461054    0.040971    0.014567    0.744406    
#> 217: 0.700089    1.071370    3.492303    0.464274    0.040543    0.014622    0.743470    
#> 218: 0.700872    1.072116    3.491987    0.463048    0.040586    0.014444    0.743297    
#> 219: 0.700126    1.072665    3.491033    0.464707    0.040715    0.014316    0.743395    
#> 220: 0.698525    1.073728    3.490781    0.462258    0.041028    0.014284    0.743169    
#> 221: 0.696658    1.074107    3.490509    0.461136    0.041074    0.014244    0.742574    
#> 222: 0.698388    1.074057    3.490508    0.464083    0.040500    0.014417    0.742572    
#> 223: 0.700813    1.073497    3.490935    0.466985    0.040105    0.014649    0.742183    
#> 224: 0.702779    1.073346    3.491500    0.468487    0.039855    0.014677    0.742402    
#> 225: 0.702795    1.071988    3.492259    0.466908    0.040005    0.014605    0.742812    
#> 226: 0.702597    1.070797    3.491894    0.467663    0.039949    0.014484    0.743317    
#> 227: 0.701531    1.070168    3.492004    0.469912    0.040195    0.014322    0.743290    
#> 228: 0.700602    1.071185    3.491776    0.468657    0.040463    0.014247    0.743562    
#> 229: 0.700073    1.071449    3.491349    0.469325    0.040604    0.014153    0.743086    
#> 230: 0.699841    1.071636    3.490851    0.467044    0.040563    0.014060    0.743325    
#> 231: 0.698959    1.071799    3.491063    0.464997    0.040472    0.013998    0.743463    
#> 232: 0.697412    1.071271    3.491226    0.463422    0.040521    0.013955    0.743791    
#> 233: 0.696580    1.070360    3.491308    0.464508    0.040447    0.014014    0.743808    
#> 234: 0.696818    1.070562    3.491350    0.466899    0.040337    0.014085    0.743186    
#> 235: 0.696635    1.070120    3.491129    0.467878    0.040215    0.014044    0.742589    
#> 236: 0.696385    1.070239    3.491036    0.467965    0.040268    0.014013    0.742593    
#> 237: 0.698869    1.070324    3.491277    0.469734    0.040302    0.014036    0.743252    
#> 238: 0.700641    1.070857    3.491447    0.472656    0.040339    0.014073    0.743372    
#> 239: 0.701704    1.071345    3.491798    0.474188    0.040087    0.014121    0.743462    
#> 240: 0.702900    1.071529    3.492091    0.475685    0.040094    0.014146    0.742710    
#> 241: 0.704640    1.071311    3.492301    0.477604    0.039920    0.014225    0.742419    
#> 242: 0.704350    1.071090    3.492235    0.478029    0.039819    0.014273    0.743009    
#> 243: 0.703627    1.071937    3.492275    0.477653    0.039953    0.014310    0.743494    
#> 244: 0.703391    1.072020    3.492477    0.475476    0.039993    0.014391    0.743738    
#> 245: 0.704075    1.071645    3.492907    0.474408    0.039825    0.014420    0.744335    
#> 246: 0.704290    1.071175    3.493341    0.471786    0.039740    0.014500    0.744354    
#> 247: 0.705178    1.071062    3.493626    0.473262    0.039793    0.014558    0.744207    
#> 248: 0.705910    1.071350    3.493775    0.474024    0.039917    0.014558    0.744134    
#> 249: 0.706025    1.071267    3.493882    0.475420    0.039763    0.014609    0.744305    
#> 250: 0.706829    1.071661    3.494123    0.477251    0.039589    0.014638    0.744672    
#> 251: 0.707468    1.072260    3.494263    0.479268    0.039480    0.014651    0.745001    
#> 252: 0.708817    1.072314    3.494618    0.480898    0.039338    0.014686    0.744860    
#> 253: 0.708858    1.072330    3.494896    0.480995    0.039306    0.014701    0.744881    
#> 254: 0.709234    1.072779    3.495191    0.480061    0.039226    0.014736    0.744936    
#> 255: 0.709376    1.072711    3.495412    0.478294    0.039251    0.014726    0.745187    
#> 256: 0.710185    1.072496    3.495543    0.478397    0.039321    0.014772    0.745104    
#> 257: 0.710619    1.071987    3.495592    0.478759    0.039482    0.014774    0.744699    
#> 258: 0.710438    1.071069    3.495655    0.478210    0.039526    0.014695    0.744653    
#> 259: 0.710652    1.070489    3.495669    0.477979    0.039663    0.014677    0.744943    
#> 260: 0.710434    1.070539    3.495788    0.477308    0.039698    0.014660    0.744783    
#> 261: 0.710056    1.070775    3.495718    0.476004    0.039705    0.014619    0.744741    
#> 262: 0.709931    1.071281    3.495648    0.476134    0.039721    0.014612    0.744534    
#> 263: 0.709579    1.071608    3.495623    0.476613    0.039741    0.014579    0.744305    
#> 264: 0.709677    1.071480    3.495676    0.477835    0.039793    0.014581    0.744419    
#> 265: 0.709985    1.071242    3.495747    0.478314    0.039812    0.014596    0.744455    
#> 266: 0.710059    1.071172    3.495667    0.479664    0.039766    0.014614    0.744303    
#> 267: 0.710510    1.071366    3.495863    0.480746    0.039780    0.014622    0.744146    
#> 268: 0.710831    1.071359    3.495802    0.481371    0.039840    0.014635    0.743905    
#> 269: 0.710971    1.071346    3.495789    0.481969    0.039829    0.014637    0.743645    
#> 270: 0.711040    1.071448    3.495557    0.482641    0.039743    0.014660    0.743219    
#> 271: 0.710857    1.071801    3.495205    0.482584    0.039734    0.014651    0.743076    
#> 272: 0.711035    1.071876    3.495103    0.482418    0.039753    0.014631    0.743231    
#> 273: 0.710219    1.072199    3.495060    0.481538    0.039866    0.014626    0.743463    
#> 274: 0.710098    1.072250    3.495137    0.480261    0.039899    0.014592    0.743398    
#> 275: 0.710055    1.072176    3.495111    0.479767    0.039937    0.014552    0.743046    
#> 276: 0.710645    1.072068    3.495372    0.479442    0.039889    0.014546    0.743003    
#> 277: 0.710786    1.072151    3.495677    0.478848    0.039827    0.014556    0.742802    
#> 278: 0.711460    1.072088    3.495904    0.479090    0.039811    0.014573    0.742841    
#> 279: 0.711813    1.071825    3.496034    0.480241    0.039821    0.014585    0.743014    
#> 280: 0.712071    1.071984    3.496091    0.480477    0.039798    0.014584    0.742998    
#> 281: 0.711608    1.072054    3.496196    0.480861    0.039821    0.014543    0.743100    
#> 282: 0.711491    1.072243    3.496271    0.481713    0.039891    0.014539    0.743108    
#> 283: 0.711331    1.072295    3.496329    0.482749    0.039939    0.014560    0.743302    
#> 284: 0.711117    1.072122    3.496289    0.483643    0.039934    0.014564    0.743126    
#> 285: 0.711614    1.072121    3.496216    0.485001    0.039958    0.014619    0.743212    
#> 286: 0.711928    1.072281    3.495945    0.486140    0.039886    0.014666    0.743421    
#> 287: 0.712107    1.072516    3.495729    0.487195    0.039865    0.014706    0.743630    
#> 288: 0.712505    1.072428    3.495649    0.487875    0.039806    0.014725    0.743624    
#> 289: 0.712573    1.072385    3.495538    0.488443    0.039774    0.014738    0.743434    
#> 290: 0.712432    1.072585    3.495396    0.488415    0.039860    0.014731    0.743381    
#> 291: 0.712566    1.072967    3.495324    0.489083    0.039953    0.014704    0.743209    
#> 292: 0.712494    1.072977    3.495257    0.490049    0.039946    0.014708    0.743087    
#> 293: 0.712508    1.072964    3.495136    0.491039    0.039905    0.014714    0.742896    
#> 294: 0.712396    1.073406    3.495011    0.491667    0.039970    0.014687    0.742850    
#> 295: 0.712893    1.073385    3.494956    0.493113    0.040078    0.014633    0.742676    
#> 296: 0.712891    1.073307    3.494889    0.492570    0.040121    0.014587    0.742798    
#> 297: 0.713370    1.073395    3.494865    0.492962    0.040173    0.014547    0.742716    
#> 298: 0.713483    1.073303    3.494802    0.493441    0.040193    0.014511    0.742601    
#> 299: 0.713442    1.073461    3.494606    0.494097    0.040188    0.014498    0.742302    
#> 300: 0.713427    1.073519    3.494585    0.494164    0.040158    0.014512    0.742012    
#> 301: 0.713451    1.073453    3.494427    0.493392    0.040085    0.014488    0.742158    
#> 302: 0.713590    1.073398    3.494400    0.492888    0.040045    0.014479    0.742257    
#> 303: 0.713746    1.073420    3.494334    0.493189    0.039955    0.014473    0.742115    
#> 304: 0.714021    1.073549    3.494161    0.494591    0.039934    0.014453    0.742131    
#> 305: 0.713671    1.073293    3.494009    0.495062    0.039926    0.014431    0.742132    
#> 306: 0.713060    1.073134    3.493919    0.494366    0.039883    0.014412    0.742212    
#> 307: 0.712854    1.073015    3.493829    0.493468    0.039896    0.014428    0.742330    
#> 308: 0.712247    1.072834    3.493732    0.493073    0.039877    0.014425    0.742610    
#> 309: 0.712109    1.072811    3.493601    0.493337    0.039865    0.014413    0.742899    
#> 310: 0.712536    1.072886    3.493487    0.493921    0.039879    0.014372    0.743021    
#> 311: 0.712396    1.072918    3.493393    0.493859    0.039868    0.014355    0.742967    
#> 312: 0.712244    1.072899    3.493296    0.494163    0.039797    0.014338    0.742946    
#> 313: 0.712280    1.072614    3.493234    0.494031    0.039744    0.014342    0.743005    
#> 314: 0.712233    1.072470    3.493281    0.494042    0.039676    0.014364    0.742883    
#> 315: 0.712369    1.072413    3.493279    0.494131    0.039645    0.014356    0.742697    
#> 316: 0.712597    1.072454    3.493316    0.494378    0.039635    0.014330    0.742523    
#> 317: 0.712912    1.072445    3.493433    0.493949    0.039674    0.014324    0.742373    
#> 318: 0.713132    1.072479    3.493403    0.494293    0.039703    0.014321    0.742269    
#> 319: 0.713286    1.072428    3.493440    0.494399    0.039719    0.014330    0.742211    
#> 320: 0.712627    1.072585    3.493294    0.494320    0.039777    0.014302    0.742245    
#> 321: 0.712255    1.072816    3.493081    0.494804    0.039804    0.014265    0.742227    
#> 322: 0.711818    1.072934    3.492832    0.494625    0.039831    0.014239    0.742259    
#> 323: 0.711063    1.073071    3.492651    0.494556    0.039822    0.014206    0.742296    
#> 324: 0.711062    1.073099    3.492721    0.494429    0.039846    0.014217    0.742176    
#> 325: 0.710942    1.073231    3.492651    0.494120    0.039847    0.014216    0.742063    
#> 326: 0.710879    1.073067    3.492603    0.494542    0.039859    0.014205    0.741893    
#> 327: 0.710957    1.073126    3.492576    0.494881    0.039759    0.014219    0.741709    
#> 328: 0.710973    1.073255    3.492531    0.494702    0.039754    0.014194    0.741726    
#> 329: 0.711313    1.073377    3.492583    0.494290    0.039740    0.014167    0.741677    
#> 330: 0.711176    1.073574    3.492528    0.493797    0.039802    0.014160    0.741695    
#> 331: 0.711346    1.073903    3.492488    0.493704    0.039821    0.014140    0.741774    
#> 332: 0.711707    1.073807    3.492610    0.493783    0.039808    0.014126    0.741814    
#> 333: 0.711864    1.073771    3.492586    0.494330    0.039836    0.014106    0.741744    
#> 334: 0.711594    1.073813    3.492468    0.494398    0.039845    0.014115    0.741710    
#> 335: 0.711317    1.073856    3.492377    0.494858    0.039892    0.014122    0.741613    
#> 336: 0.710966    1.073909    3.492334    0.494822    0.039889    0.014141    0.741672    
#> 337: 0.710882    1.074254    3.492208    0.495284    0.039962    0.014147    0.741563    
#> 338: 0.710714    1.074470    3.492155    0.495850    0.039993    0.014131    0.741557    
#> 339: 0.710339    1.074662    3.492095    0.495603    0.040014    0.014120    0.741456    
#> 340: 0.710113    1.074615    3.492062    0.495746    0.040064    0.014097    0.741396    
#> 341: 0.710297    1.074535    3.492091    0.495528    0.040063    0.014072    0.741374    
#> 342: 0.709846    1.074475    3.491988    0.495276    0.040077    0.014047    0.741287    
#> 343: 0.709429    1.074530    3.492011    0.494420    0.040048    0.014038    0.741291    
#> 344: 0.709461    1.074524    3.492055    0.494309    0.040041    0.014041    0.741292    
#> 345: 0.709203    1.074520    3.492066    0.493672    0.040091    0.014035    0.741212    
#> 346: 0.708854    1.074655    3.491954    0.493241    0.040072    0.014022    0.741149    
#> 347: 0.708903    1.074641    3.491819    0.493902    0.040055    0.014026    0.741226    
#> 348: 0.708577    1.074909    3.491677    0.494084    0.040031    0.014005    0.741403    
#> 349: 0.708649    1.074834    3.491633    0.494923    0.040036    0.014015    0.741356    
#> 350: 0.708718    1.074788    3.491623    0.495401    0.040059    0.014013    0.741209    
#> 351: 0.708957    1.074926    3.491614    0.495851    0.040066    0.014010    0.741227    
#> 352: 0.708657    1.075114    3.491552    0.495999    0.040106    0.013989    0.741447    
#> 353: 0.708850    1.075310    3.491572    0.495826    0.040177    0.013949    0.741461    
#> 354: 0.709104    1.075375    3.491541    0.496005    0.040246    0.013911    0.741401    
#> 355: 0.709373    1.075308    3.491533    0.495607    0.040278    0.013882    0.741267    
#> 356: 0.709201    1.075344    3.491542    0.494890    0.040339    0.013859    0.741312    
#> 357: 0.709300    1.075387    3.491552    0.495077    0.040372    0.013844    0.741264    
#> 358: 0.709306    1.075551    3.491582    0.494729    0.040342    0.013835    0.741320    
#> 359: 0.709096    1.075794    3.491549    0.494423    0.040393    0.013831    0.741272    
#> 360: 0.708898    1.075889    3.491398    0.494139    0.040390    0.013820    0.741114    
#> 361: 0.708429    1.076041    3.491265    0.493391    0.040421    0.013818    0.740966    
#> 362: 0.708385    1.075982    3.491213    0.492822    0.040405    0.013819    0.740832    
#> 363: 0.708227    1.075959    3.491196    0.492367    0.040392    0.013828    0.740654    
#> 364: 0.708152    1.076031    3.491151    0.492128    0.040307    0.013853    0.740649    
#> 365: 0.708157    1.075971    3.491195    0.491683    0.040292    0.013885    0.740666    
#> 366: 0.708115    1.075945    3.491166    0.491435    0.040261    0.013909    0.740668    
#> 367: 0.708001    1.075962    3.491165    0.491254    0.040258    0.013900    0.740630    
#> 368: 0.707920    1.076163    3.491033    0.491741    0.040292    0.013881    0.740560    
#> 369: 0.707885    1.076230    3.490924    0.492378    0.040299    0.013858    0.740582    
#> 370: 0.707910    1.076335    3.490854    0.492758    0.040383    0.013839    0.740618    
#> 371: 0.707577    1.076374    3.490650    0.492996    0.040375    0.013819    0.740630    
#> 372: 0.707285    1.076561    3.490512    0.493359    0.040400    0.013798    0.740719    
#> 373: 0.706697    1.076752    3.490355    0.493159    0.040421    0.013784    0.740818    
#> 374: 0.706531    1.076756    3.490264    0.492949    0.040437    0.013766    0.740779    
#> 375: 0.706154    1.076831    3.490198    0.492299    0.040448    0.013747    0.740803    
#> 376: 0.705897    1.076934    3.490071    0.491672    0.040464    0.013740    0.740723    
#> 377: 0.705727    1.077131    3.489967    0.491254    0.040565    0.013718    0.740732    
#> 378: 0.705628    1.077222    3.489864    0.490851    0.040564    0.013700    0.740763    
#> 379: 0.705444    1.077164    3.489831    0.490575    0.040593    0.013670    0.740726    
#> 380: 0.705387    1.077210    3.489788    0.490483    0.040658    0.013662    0.740640    
#> 381: 0.705223    1.077331    3.489732    0.490431    0.040673    0.013640    0.740683    
#> 382: 0.705135    1.077359    3.489736    0.489887    0.040697    0.013628    0.740685    
#> 383: 0.705400    1.077351    3.489796    0.489856    0.040712    0.013621    0.740500    
#> 384: 0.705553    1.077368    3.489844    0.490005    0.040778    0.013602    0.740420    
#> 385: 0.705763    1.077427    3.489890    0.489989    0.040817    0.013581    0.740413    
#> 386: 0.706108    1.077493    3.490028    0.489859    0.040868    0.013562    0.740385    
#> 387: 0.706390    1.077473    3.490124    0.489861    0.040878    0.013557    0.740359    
#> 388: 0.706704    1.077415    3.490189    0.490343    0.040885    0.013547    0.740332    
#> 389: 0.706943    1.077222    3.490224    0.490450    0.040905    0.013537    0.740471    
#> 390: 0.706885    1.077154    3.490243    0.490482    0.040908    0.013537    0.740538    
#> 391: 0.706964    1.077097    3.490221    0.490523    0.040895    0.013553    0.740510    
#> 392: 0.707139    1.077140    3.490261    0.490722    0.040907    0.013558    0.740501    
#> 393: 0.707169    1.077166    3.490155    0.490791    0.040930    0.013543    0.740577    
#> 394: 0.707192    1.077220    3.490076    0.490766    0.040920    0.013541    0.740637    
#> 395: 0.707386    1.077343    3.490064    0.490740    0.040938    0.013536    0.740605    
#> 396: 0.707449    1.077399    3.490097    0.491141    0.040928    0.013539    0.740542    
#> 397: 0.707658    1.077490    3.490140    0.491762    0.040954    0.013546    0.740505    
#> 398: 0.707962    1.077590    3.490142    0.492354    0.040947    0.013536    0.740461    
#> 399: 0.708108    1.077695    3.490171    0.492664    0.040971    0.013538    0.740395    
#> 400: 0.708331    1.077774    3.490205    0.493184    0.040987    0.013532    0.740378    
#> 401: 0.708327    1.077829    3.490198    0.493106    0.040962    0.013538    0.740424    
#> 402: 0.708315    1.077783    3.490202    0.493016    0.040993    0.013542    0.740340    
#> 403: 0.708793    1.077682    3.490237    0.493620    0.041016    0.013556    0.740284    
#> 404: 0.708905    1.077686    3.490210    0.493521    0.041061    0.013565    0.740159    
#> 405: 0.708812    1.077658    3.490202    0.493573    0.041087    0.013566    0.740165    
#> 406: 0.708953    1.077722    3.490212    0.493443    0.041164    0.013572    0.740309    
#> 407: 0.708960    1.077846    3.490207    0.493598    0.041162    0.013562    0.740373    
#> 408: 0.709102    1.078016    3.490195    0.493259    0.041124    0.013557    0.740450    
#> 409: 0.709096    1.078065    3.490159    0.492701    0.041099    0.013537    0.740445    
#> 410: 0.709081    1.078140    3.490110    0.492556    0.041100    0.013521    0.740357    
#> 411: 0.709130    1.078073    3.490056    0.492833    0.041110    0.013505    0.740311    
#> 412: 0.709154    1.078091    3.490058    0.492335    0.041070    0.013512    0.740299    
#> 413: 0.709162    1.078086    3.490050    0.491809    0.041068    0.013503    0.740294    
#> 414: 0.709107    1.078080    3.490074    0.491902    0.041108    0.013492    0.740159    
#> 415: 0.709426    1.078065    3.490065    0.492065    0.041099    0.013487    0.740165    
#> 416: 0.709624    1.078079    3.490088    0.492063    0.041112    0.013493    0.740086    
#> 417: 0.709649    1.078033    3.490104    0.492024    0.041090    0.013503    0.740091    
#> 418: 0.709460    1.078073    3.490086    0.491781    0.041067    0.013516    0.740088    
#> 419: 0.709384    1.078177    3.490041    0.491822    0.041032    0.013525    0.740149    
#> 420: 0.709464    1.078155    3.490046    0.491875    0.040998    0.013530    0.740103    
#> 421: 0.709434    1.078139    3.490090    0.491440    0.041000    0.013532    0.740040    
#> 422: 0.709464    1.077999    3.490072    0.491605    0.041002    0.013548    0.739998    
#> 423: 0.709478    1.077996    3.490021    0.491350    0.041048    0.013551    0.739968    
#> 424: 0.709287    1.078012    3.489926    0.491330    0.041101    0.013552    0.739949    
#> 425: 0.709335    1.078070    3.489888    0.491571    0.041145    0.013555    0.740059    
#> 426: 0.709360    1.078106    3.489947    0.491711    0.041126    0.013556    0.740051    
#> 427: 0.709329    1.078085    3.489974    0.491608    0.041075    0.013565    0.740036    
#> 428: 0.709231    1.078109    3.490000    0.491136    0.041055    0.013550    0.740103    
#> 429: 0.709341    1.078055    3.490060    0.490872    0.041015    0.013545    0.740172    
#> 430: 0.709231    1.078015    3.490083    0.490519    0.041022    0.013543    0.740215    
#> 431: 0.709228    1.078037    3.490089    0.490166    0.041013    0.013541    0.740152    
#> 432: 0.709284    1.078071    3.490091    0.490394    0.041060    0.013538    0.740146    
#> 433: 0.709349    1.078129    3.490129    0.491115    0.041117    0.013551    0.740093    
#> 434: 0.709209    1.078029    3.490111    0.491463    0.041160    0.013552    0.740021    
#> 435: 0.709297    1.077999    3.490115    0.491657    0.041170    0.013567    0.739904    
#> 436: 0.709291    1.077894    3.490115    0.491520    0.041142    0.013577    0.739905    
#> 437: 0.709148    1.077876    3.490084    0.491286    0.041108    0.013588    0.739983    
#> 438: 0.709118    1.078055    3.490047    0.491373    0.041112    0.013580    0.739930    
#> 439: 0.709196    1.078167    3.490001    0.491691    0.041089    0.013579    0.739868    
#> 440: 0.709018    1.078226    3.489998    0.491376    0.041071    0.013560    0.739874    
#> 441: 0.709193    1.078197    3.490050    0.491208    0.041082    0.013568    0.739825    
#> 442: 0.709226    1.078291    3.490091    0.491221    0.041065    0.013568    0.739743    
#> 443: 0.709530    1.078363    3.490112    0.491551    0.041025    0.013586    0.739655    
#> 444: 0.709523    1.078471    3.490058    0.491508    0.040969    0.013598    0.739569    
#> 445: 0.709599    1.078541    3.490008    0.492116    0.040954    0.013606    0.739514    
#> 446: 0.709562    1.078599    3.489972    0.492779    0.040917    0.013614    0.739488    
#> 447: 0.709656    1.078678    3.489966    0.493031    0.040868    0.013625    0.739493    
#> 448: 0.709671    1.078737    3.489973    0.493069    0.040823    0.013638    0.739494    
#> 449: 0.709815    1.078799    3.490071    0.492778    0.040786    0.013644    0.739502    
#> 450: 0.709884    1.078783    3.490120    0.492714    0.040735    0.013636    0.739588    
#> 451: 0.710104    1.078775    3.490141    0.493402    0.040702    0.013632    0.739664    
#> 452: 0.710226    1.078766    3.490154    0.493674    0.040703    0.013631    0.739644    
#> 453: 0.710272    1.078743    3.490161    0.493533    0.040734    0.013616    0.739591    
#> 454: 0.710193    1.078855    3.490127    0.493472    0.040746    0.013599    0.739506    
#> 455: 0.710166    1.078870    3.490097    0.493233    0.040777    0.013579    0.739568    
#> 456: 0.710009    1.078870    3.490091    0.493214    0.040797    0.013570    0.739572    
#> 457: 0.710007    1.078816    3.490125    0.493370    0.040788    0.013558    0.739575    
#> 458: 0.710048    1.078883    3.490157    0.493623    0.040766    0.013552    0.739571    
#> 459: 0.709907    1.078996    3.490149    0.493682    0.040782    0.013543    0.739580    
#> 460: 0.709786    1.079099    3.490083    0.493588    0.040813    0.013537    0.739592    
#> 461: 0.709731    1.079246    3.490046    0.493751    0.040825    0.013527    0.739643    
#> 462: 0.709587    1.079439    3.490009    0.493926    0.040840    0.013520    0.739688    
#> 463: 0.709490    1.079513    3.490020    0.493594    0.040859    0.013511    0.739723    
#> 464: 0.709444    1.079621    3.489999    0.493355    0.040866    0.013513    0.739688    
#> 465: 0.709397    1.079551    3.489978    0.493090    0.040848    0.013522    0.739629    
#> 466: 0.709412    1.079548    3.489949    0.493053    0.040825    0.013520    0.739615    
#> 467: 0.709198    1.079551    3.489951    0.493015    0.040779    0.013525    0.739535    
#> 468: 0.709364    1.079528    3.490008    0.493241    0.040762    0.013528    0.739534    
#> 469: 0.709523    1.079591    3.490061    0.493443    0.040735    0.013549    0.739519    
#> 470: 0.709546    1.079593    3.490044    0.493846    0.040684    0.013564    0.739504    
#> 471: 0.709497    1.079597    3.490021    0.493907    0.040666    0.013570    0.739509    
#> 472: 0.709464    1.079589    3.490012    0.493867    0.040623    0.013574    0.739602    
#> 473: 0.709384    1.079617    3.489996    0.493511    0.040580    0.013580    0.739561    
#> 474: 0.709314    1.079609    3.489939    0.493461    0.040598    0.013579    0.739537    
#> 475: 0.709314    1.079659    3.489917    0.493187    0.040585    0.013584    0.739513    
#> 476: 0.709275    1.079616    3.489912    0.493391    0.040582    0.013585    0.739570    
#> 477: 0.709026    1.079603    3.489926    0.493035    0.040566    0.013592    0.739528    
#> 478: 0.708804    1.079620    3.489899    0.492818    0.040551    0.013593    0.739536    
#> 479: 0.708891    1.079666    3.489883    0.492646    0.040547    0.013591    0.739585    
#> 480: 0.708898    1.079689    3.489893    0.492452    0.040528    0.013593    0.739668    
#> 481: 0.708778    1.079663    3.489853    0.492068    0.040524    0.013588    0.739728    
#> 482: 0.708831    1.079646    3.489823    0.491978    0.040522    0.013592    0.739792    
#> 483: 0.708733    1.079700    3.489766    0.492300    0.040490    0.013590    0.739754    
#> 484: 0.708672    1.079683    3.489726    0.492625    0.040492    0.013581    0.739782    
#> 485: 0.708654    1.079740    3.489686    0.493109    0.040536    0.013571    0.739743    
#> 486: 0.708511    1.079803    3.489671    0.492929    0.040550    0.013559    0.739728    
#> 487: 0.708745    1.079833    3.489740    0.492714    0.040547    0.013556    0.739661    
#> 488: 0.708768    1.079769    3.489784    0.492590    0.040518    0.013564    0.739580    
#> 489: 0.708893    1.079727    3.489827    0.492351    0.040499    0.013569    0.739553    
#> 490: 0.709103    1.079733    3.489881    0.492480    0.040463    0.013577    0.739586    
#> 491: 0.709288    1.079734    3.489976    0.492496    0.040433    0.013595    0.739591    
#> 492: 0.709389    1.079782    3.490006    0.492537    0.040404    0.013613    0.739624    
#> 493: 0.709249    1.079804    3.490026    0.492487    0.040379    0.013639    0.739636    
#> 494: 0.709375    1.079897    3.490031    0.492360    0.040364    0.013658    0.739617    
#> 495: 0.709483    1.079992    3.490045    0.492775    0.040359    0.013673    0.739533    
#> 496: 0.709701    1.080000    3.490049    0.492928    0.040354    0.013683    0.739521    
#> 497: 0.709702    1.079962    3.490032    0.493236    0.040365    0.013690    0.739506    
#> 498: 0.709569    1.079974    3.489965    0.493220    0.040364    0.013694    0.739490    
#> 499: 0.709489    1.080018    3.489929    0.493395    0.040386    0.013698    0.739473    
#> 500: 0.709503    1.079970    3.489891    0.493501    0.040397    0.013688    0.739466    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.282968    0.967584    3.447598    0.392401    0.078940    0.016800    1.735794    
#> 002: 0.146577    1.034059    3.481324    0.372781    0.074993    0.015960    1.061638    
#> 003: 0.198727    0.996534    3.511705    0.354142    0.073357    0.015162    0.869937    
#> 004: 0.169441    1.023829    3.511878    0.336435    0.077976    0.014404    0.771889    
#> 005: 0.233362    1.016925    3.508551    0.319613    0.092166    0.013684    0.701567    
#> 006: 0.194173    1.035009    3.485726    0.303633    0.108688    0.013000    0.653678    
#> 007: 0.129868    1.054532    3.470416    0.288451    0.121413    0.013941    0.641198    
#> 008: 0.121952    1.026718    3.469655    0.274029    0.115343    0.018353    0.647772    
#> 009: 0.100961    1.016010    3.470102    0.260327    0.109575    0.019742    0.653353    
#> 010: 0.142443    1.024220    3.464956    0.247311    0.104097    0.018755    0.660624    
#> 011: 0.185532    1.043571    3.468077    0.234945    0.119489    0.017817    0.659553    
#> 012: 0.159234    1.038441    3.461236    0.223198    0.113515    0.016927    0.663108    
#> 013: 0.111926    1.049441    3.458518    0.212038    0.109393    0.016080    0.660765    
#> 014: 0.165432    1.055893    3.470587    0.201436    0.103923    0.015276    0.675331    
#> 015: 0.179068    1.063926    3.479818    0.191364    0.098727    0.018784    0.622664    
#> 016: 0.181449    1.048234    3.492259    0.181796    0.097195    0.020046    0.621303    
#> 017: 0.188637    1.055046    3.489991    0.172706    0.092335    0.020627    0.619433    
#> 018: 0.196306    1.038003    3.475752    0.175679    0.087718    0.021138    0.629530    
#> 019: 0.146717    1.041616    3.474663    0.169348    0.083332    0.021081    0.625892    
#> 020: 0.161033    1.046668    3.480993    0.178166    0.089012    0.021688    0.632660    
#> 021: 0.173099    1.029818    3.487320    0.169257    0.084562    0.023714    0.630907    
#> 022: 0.177407    1.039017    3.490548    0.167281    0.080334    0.022528    0.615018    
#> 023: 0.265441    1.023786    3.510750    0.167488    0.088656    0.023300    0.636379    
#> 024: 0.251849    1.030044    3.512884    0.159113    0.087647    0.022135    0.637640    
#> 025: 0.255064    1.006247    3.512135    0.151158    0.083264    0.023120    0.635696    
#> 026: 0.243030    1.021753    3.507557    0.143600    0.080869    0.021964    0.631489    
#> 027: 0.195022    1.042221    3.502995    0.136420    0.081383    0.020866    0.644513    
#> 028: 0.253941    1.029056    3.516951    0.129599    0.085442    0.019823    0.617880    
#> 029: 0.249356    1.032733    3.507836    0.135031    0.105617    0.020379    0.622700    
#> 030: 0.240047    1.039732    3.511659    0.128280    0.100336    0.022004    0.637594    
#> 031: 0.234397    0.996421    3.513048    0.127919    0.095319    0.021063    0.632442    
#> 032: 0.216042    0.997092    3.516809    0.126884    0.090553    0.022444    0.624549    
#> 033: 0.200922    1.034407    3.508692    0.133817    0.099265    0.021907    0.626237    
#> 034: 0.235790    1.042025    3.513534    0.127236    0.094302    0.020812    0.641630    
#> 035: 0.203177    1.019925    3.503387    0.130636    0.091345    0.019771    0.619482    
#> 036: 0.223364    1.037317    3.505751    0.124105    0.093254    0.020354    0.609634    
#> 037: 0.225452    1.035630    3.498401    0.125973    0.092855    0.019336    0.604820    
#> 038: 0.204760    1.040804    3.485802    0.119674    0.104633    0.018370    0.625452    
#> 039: 0.205515    1.051277    3.488435    0.158109    0.101684    0.017451    0.616454    
#> 040: 0.188374    1.041889    3.496362    0.150203    0.096600    0.016579    0.645668    
#> 041: 0.168287    1.048570    3.486987    0.142693    0.091770    0.017252    0.637566    
#> 042: 0.201881    1.041188    3.477901    0.135558    0.087181    0.017793    0.633370    
#> 043: 0.180643    1.053209    3.477400    0.128780    0.085334    0.017901    0.641541    
#> 044: 0.170670    1.063398    3.471323    0.123786    0.094766    0.017006    0.613764    
#> 045: 0.168681    1.085986    3.466788    0.130445    0.090028    0.016156    0.623756    
#> 046: 0.203905    1.057190    3.470405    0.136638    0.096021    0.018449    0.616203    
#> 047: 0.186533    1.051443    3.480409    0.141113    0.099271    0.020232    0.601288    
#> 048: 0.191912    1.045969    3.482103    0.153598    0.106947    0.019221    0.615367    
#> 049: 0.191347    1.062681    3.488255    0.145918    0.113698    0.018260    0.630842    
#> 050: 0.242177    1.005265    3.504932    0.138623    0.108013    0.017347    0.636894    
#> 051: 0.229218    1.019386    3.504918    0.149041    0.102613    0.019091    0.638430    
#> 052: 0.195704    1.017931    3.509146    0.141589    0.097482    0.019712    0.618604    
#> 053: 0.194070    1.025884    3.486503    0.182947    0.107040    0.018727    0.626917    
#> 054: 0.156928    1.029992    3.488461    0.173799    0.110514    0.020719    0.630549    
#> 055: 0.189608    1.019374    3.493760    0.165109    0.110444    0.020845    0.624106    
#> 056: 0.225042    1.004607    3.509631    0.156854    0.104921    0.023179    0.627862    
#> 057: 0.221484    1.016387    3.515044    0.159174    0.100503    0.022020    0.631002    
#> 058: 0.201798    1.024225    3.497680    0.151215    0.096769    0.020919    0.620166    
#> 059: 0.224680    1.009764    3.507573    0.143654    0.098020    0.020062    0.647542    
#> 060: 0.181726    0.993097    3.497836    0.136472    0.098836    0.019059    0.657032    
#> 061: 0.200365    1.027303    3.505198    0.140712    0.093895    0.018106    0.662793    
#> 062: 0.214472    1.033481    3.514738    0.165442    0.116528    0.017201    0.659800    
#> 063: 0.265542    1.001185    3.511632    0.157169    0.110701    0.016341    0.657608    
#> 064: 0.232473    1.026240    3.511126    0.149311    0.107158    0.015524    0.650355    
#> 065: 0.226434    1.016149    3.498994    0.141845    0.111215    0.014748    0.636135    
#> 066: 0.231609    1.045570    3.502037    0.141646    0.114366    0.014010    0.634563    
#> 067: 0.207348    1.023343    3.495428    0.151946    0.108647    0.015178    0.632209    
#> 068: 0.170316    1.013599    3.497550    0.146261    0.109785    0.014419    0.653642    
#> 069: 0.159775    1.042403    3.480725    0.138948    0.117676    0.013698    0.656291    
#> 070: 0.189410    1.036928    3.495292    0.132000    0.125712    0.014649    0.632173    
#> 071: 0.189621    1.022116    3.482236    0.125400    0.119426    0.013917    0.640374    
#> 072: 0.151036    1.006447    3.484556    0.135325    0.113455    0.013221    0.641755    
#> 073: 0.157020    1.034922    3.485160    0.134248    0.129048    0.012560    0.639604    
#> 074: 0.164886    1.015742    3.480114    0.144268    0.124467    0.011932    0.645554    
#> 075: 0.178892    1.003550    3.505223    0.137054    0.130519    0.011397    0.655889    
#> 076: 0.227998    1.018916    3.515766    0.130201    0.123993    0.010827    0.630388    
#> 077: 0.265940    1.011965    3.513686    0.136157    0.117793    0.015184    0.621120    
#> 078: 0.234911    1.018434    3.506097    0.135677    0.111903    0.014424    0.617299    
#> 079: 0.217804    1.022452    3.506781    0.128893    0.131578    0.013703    0.639600    
#> 080: 0.230999    1.016995    3.512272    0.125228    0.124999    0.014858    0.646246    
#> 081: 0.213178    1.033199    3.500227    0.119623    0.118750    0.017468    0.632106    
#> 082: 0.185079    1.012746    3.505805    0.113642    0.117529    0.016595    0.647047    
#> 083: 0.198388    1.036377    3.503439    0.130302    0.111652    0.015765    0.636208    
#> 084: 0.220130    1.034675    3.493113    0.125910    0.107798    0.019347    0.628186    
#> 085: 0.205265    1.041068    3.501897    0.135330    0.102408    0.019158    0.642861    
#> 086: 0.197716    1.029431    3.496627    0.135209    0.101092    0.018460    0.626778    
#> 087: 0.173084    1.031433    3.488122    0.137596    0.096037    0.021355    0.642038    
#> 088: 0.122635    1.048198    3.485710    0.144540    0.092732    0.020846    0.669054    
#> 089: 0.158702    1.065062    3.469593    0.147715    0.099773    0.021976    0.637683    
#> 090: 0.131752    1.054528    3.463322    0.152669    0.099434    0.020921    0.621334    
#> 091: 0.128798    1.040343    3.454407    0.145035    0.094462    0.020072    0.634739    
#> 092: 0.140773    1.051254    3.466200    0.137783    0.089739    0.019068    0.652028    
#> 093: 0.130852    1.040662    3.474382    0.130894    0.085252    0.021950    0.648036    
#> 094: 0.145272    1.064008    3.480142    0.124350    0.103700    0.020853    0.638392    
#> 095: 0.150490    1.033802    3.481402    0.118132    0.098515    0.019810    0.629817    
#> 096: 0.139385    1.036398    3.475468    0.124848    0.096297    0.018820    0.622462    
#> 097: 0.181106    1.056715    3.474928    0.122618    0.098037    0.017879    0.623985    
#> 098: 0.166116    1.080436    3.482855    0.130004    0.099730    0.017064    0.630506    
#> 099: 0.163088    1.039858    3.477167    0.123504    0.103095    0.016210    0.624058    
#> 100: 0.152298    1.035276    3.472537    0.120089    0.108981    0.015400    0.622814    
#> 101: 0.141098    1.038809    3.465508    0.122392    0.105623    0.014630    0.618606    
#> 102: 0.132179    1.061695    3.450385    0.116272    0.109053    0.013898    0.634924    
#> 103: 0.146614    1.054848    3.466138    0.122810    0.104613    0.013203    0.626448    
#> 104: 0.133224    1.047462    3.474500    0.132933    0.101300    0.012543    0.643407    
#> 105: 0.181301    1.017422    3.478939    0.175143    0.114392    0.012545    0.630019    
#> 106: 0.195824    1.036986    3.481844    0.166385    0.108672    0.014348    0.636980    
#> 107: 0.228037    1.040692    3.489824    0.158066    0.105786    0.015170    0.643215    
#> 108: 0.206608    1.015699    3.490036    0.150163    0.101523    0.016283    0.647075    
#> 109: 0.208318    1.033050    3.509537    0.142655    0.096447    0.017727    0.640709    
#> 110: 0.198123    1.010279    3.486119    0.135522    0.091625    0.018827    0.633673    
#> 111: 0.203040    1.025127    3.495668    0.128746    0.087043    0.018928    0.617740    
#> 112: 0.190555    1.003504    3.480667    0.122309    0.087415    0.018436    0.631007    
#> 113: 0.197294    1.047019    3.488052    0.128308    0.089105    0.018796    0.616628    
#> 114: 0.209764    1.034855    3.491972    0.125345    0.087516    0.017857    0.630698    
#> 115: 0.204086    1.018787    3.486916    0.122651    0.083786    0.021614    0.665014    
#> 116: 0.175887    1.050146    3.481725    0.116518    0.092855    0.027369    0.662549    
#> 117: 0.175507    1.067455    3.489412    0.112041    0.088212    0.026001    0.642848    
#> 118: 0.192964    1.035436    3.485737    0.141385    0.083802    0.024701    0.628963    
#> 119: 0.196511    1.032382    3.484956    0.135321    0.088313    0.023466    0.613290    
#> 120: 0.213128    1.016953    3.500748    0.128555    0.083897    0.022293    0.609644    
#> 121: 0.205632    1.062513    3.496924    0.122127    0.088751    0.021316    0.632101    
#> 122: 0.208891    1.028055    3.495107    0.150721    0.085603    0.020250    0.625310    
#> 123: 0.200718    1.038116    3.481291    0.153242    0.091741    0.019238    0.630234    
#> 124: 0.218609    1.045657    3.487058    0.145580    0.087154    0.018276    0.626599    
#> 125: 0.231805    1.052412    3.496132    0.144350    0.105838    0.017940    0.624982    
#> 126: 0.192837    1.045144    3.487616    0.153424    0.100546    0.021994    0.638332    
#> 127: 0.183757    1.026155    3.482536    0.158895    0.095519    0.020894    0.640812    
#> 128: 0.142577    1.052682    3.484544    0.150951    0.100963    0.019849    0.642258    
#> 129: 0.187692    1.050285    3.490144    0.143403    0.095914    0.018857    0.648966    
#> 130: 0.210860    1.054219    3.492505    0.136233    0.092491    0.017914    0.628275    
#> 131: 0.149459    1.051112    3.469147    0.129421    0.108929    0.017018    0.628403    
#> 132: 0.125074    1.062020    3.454621    0.122950    0.103483    0.016167    0.625830    
#> 133: 0.127999    1.064215    3.456454    0.138562    0.098308    0.015637    0.622862    
#> 134: 0.142381    1.040395    3.474982    0.131634    0.093393    0.017603    0.620102    
#> 135: 0.144253    1.049120    3.477646    0.126911    0.096535    0.016723    0.623213    
#> 136: 0.173458    1.034348    3.490434    0.120565    0.092223    0.017501    0.619873    
#> 137: 0.225629    1.023787    3.509260    0.114537    0.087612    0.022118    0.620697    
#> 138: 0.208198    1.033551    3.497678    0.108810    0.093900    0.021164    0.619987    
#> 139: 0.218647    1.035124    3.504554    0.103370    0.111692    0.021211    0.631618    
#> 140: 0.228568    1.035479    3.511012    0.110484    0.106107    0.020151    0.636943    
#> 141: 0.226601    1.016397    3.513161    0.104960    0.100802    0.019143    0.633031    
#> 142: 0.241411    1.016883    3.522872    0.099712    0.095762    0.019529    0.649385    
#> 143: 0.203746    1.049296    3.509209    0.097569    0.093522    0.021329    0.641060    
#> 144: 0.258717    1.019625    3.529740    0.128740    0.088846    0.020263    0.633082    
#> 145: 0.190179    1.029861    3.496564    0.133509    0.089902    0.019250    0.631914    
#> 146: 0.204106    1.043138    3.508309    0.126834    0.085407    0.018287    0.644111    
#> 147: 0.173922    1.021606    3.493547    0.153822    0.083672    0.022872    0.608519    
#> 148: 0.201666    1.040952    3.503849    0.157459    0.092009    0.021729    0.627528    
#> 149: 0.202050    1.013108    3.494416    0.160484    0.087409    0.020982    0.631540    
#> 150: 0.213977    1.017407    3.486500    0.152459    0.092097    0.021222    0.634389    
#> 151: 0.173560    1.052653    3.486679    0.144836    0.100650    0.020161    0.624586    
#> 152: 0.174929    1.035899    3.488868    0.133032    0.094900    0.013656    0.625884    
#> 153: 0.183939    1.034156    3.500238    0.126461    0.105701    0.014443    0.639612    
#> 154: 0.216178    1.035364    3.502240    0.119689    0.111564    0.014954    0.640803    
#> 155: 0.195267    1.006550    3.496678    0.094373    0.124165    0.012673    0.662718    
#> 156: 0.192843    1.022433    3.496908    0.105772    0.115009    0.014593    0.649606    
#> 157: 0.222103    1.025796    3.507251    0.107358    0.120624    0.012855    0.643346    
#> 158: 0.225590    1.030694    3.497536    0.097837    0.120337    0.013373    0.632149    
#> 159: 0.169101    1.048839    3.489569    0.103383    0.123134    0.014840    0.624017    
#> 160: 0.210095    0.999635    3.508710    0.103487    0.114175    0.016694    0.628685    
#> 161: 0.177598    1.033903    3.494949    0.093295    0.098558    0.016135    0.647185    
#> 162: 0.202031    1.044612    3.483658    0.086416    0.103780    0.016202    0.648734    
#> 163: 0.233279    1.025525    3.499428    0.095625    0.098166    0.017139    0.646862    
#> 164: 0.227146    1.009013    3.499068    0.113576    0.091227    0.014778    0.621547    
#> 165: 0.239855    1.014689    3.508783    0.106435    0.087276    0.022759    0.609632    
#> 166: 0.263942    1.042435    3.514234    0.128718    0.090155    0.021155    0.632449    
#> 167: 0.256202    1.046317    3.517105    0.134919    0.094834    0.018234    0.631829    
#> 168: 0.220454    1.060405    3.499014    0.115662    0.104490    0.012390    0.654919    
#> 169: 0.178550    1.072559    3.487614    0.099102    0.103211    0.013987    0.647727    
#> 170: 0.184895    1.049632    3.485404    0.102889    0.114530    0.012930    0.632885    
#> 171: 0.152214    1.033267    3.484486    0.098993    0.103172    0.012951    0.618412    
#> 172: 0.152158    1.073143    3.476295    0.120395    0.115319    0.012773    0.631768    
#> 173: 0.175380    1.059369    3.468445    0.133570    0.106044    0.012566    0.618724    
#> 174: 0.180881    1.037613    3.484233    0.131829    0.096558    0.015219    0.618012    
#> 175: 0.187498    1.040419    3.473062    0.131774    0.102781    0.015658    0.627047    
#> 176: 0.191388    1.059688    3.489829    0.124370    0.112449    0.015142    0.616658    
#> 177: 0.195000    1.043121    3.498279    0.102707    0.098019    0.012749    0.630372    
#> 178: 0.222221    1.042824    3.496438    0.115041    0.107768    0.014534    0.620042    
#> 179: 0.227771    1.063819    3.493125    0.101623    0.114731    0.017794    0.615644    
#> 180: 0.168352    1.049173    3.492368    0.136672    0.098622    0.016665    0.621615    
#> 181: 0.175204    1.055107    3.473443    0.130597    0.091734    0.018821    0.619849    
#> 182: 0.150155    1.066001    3.463822    0.118013    0.096005    0.023178    0.644712    
#> 183: 0.132179    1.077227    3.463273    0.119509    0.105894    0.023470    0.636601    
#> 184: 0.149747    1.032470    3.476339    0.109822    0.094628    0.019050    0.629359    
#> 185: 0.122110    1.067505    3.465257    0.120532    0.100049    0.018577    0.627585    
#> 186: 0.138933    1.070642    3.463731    0.112584    0.113810    0.022206    0.642660    
#> 187: 0.152407    1.041469    3.481450    0.109243    0.087043    0.019837    0.647983    
#> 188: 0.124592    1.061542    3.474737    0.106251    0.106521    0.016565    0.658472    
#> 189: 0.166473    1.071348    3.482834    0.105191    0.099703    0.015794    0.647408    
#> 190: 0.171663    1.042954    3.491193    0.110494    0.088210    0.019265    0.626678    
#> 191: 0.179353    1.058480    3.484554    0.137098    0.089973    0.019333    0.627902    
#> 192: 0.196179    1.058662    3.490929    0.138913    0.068055    0.021583    0.620379    
#> 193: 0.229081    1.047462    3.503162    0.123245    0.070061    0.021286    0.621502    
#> 194: 0.187951    1.042305    3.491632    0.128095    0.083681    0.018265    0.637840    
#> 195: 0.160257    1.036375    3.482792    0.113772    0.088780    0.020450    0.633349    
#> 196: 0.162495    1.038867    3.493488    0.115041    0.086384    0.023425    0.645983    
#> 197: 0.150093    1.045708    3.509071    0.136826    0.092985    0.026052    0.654848    
#> 198: 0.202601    1.018243    3.505090    0.134184    0.088351    0.024442    0.616836    
#> 199: 0.168250    1.030185    3.493207    0.138399    0.097420    0.021918    0.628016    
#> 200: 0.182316    1.044900    3.486779    0.132262    0.112850    0.020564    0.624626    
#> 201: 0.168450    1.048792    3.488655    0.124836    0.105833    0.019971    0.621124    
#> 202: 0.166666    1.050178    3.487654    0.127982    0.104546    0.019369    0.623366    
#> 203: 0.174002    1.048015    3.486163    0.128516    0.101637    0.019115    0.623946    
#> 204: 0.179844    1.041531    3.487933    0.128724    0.102010    0.019654    0.626930    
#> 205: 0.180279    1.045347    3.488006    0.127405    0.101478    0.020025    0.630130    
#> 206: 0.182129    1.047645    3.489032    0.127669    0.101745    0.019816    0.632937    
#> 207: 0.181131    1.043604    3.489181    0.124836    0.100549    0.019984    0.634352    
#> 208: 0.182859    1.043172    3.490175    0.124508    0.099378    0.019934    0.635116    
#> 209: 0.185345    1.040450    3.490746    0.122476    0.099779    0.019730    0.634640    
#> 210: 0.187620    1.037257    3.491740    0.120251    0.099764    0.019415    0.634190    
#> 211: 0.188397    1.037821    3.492412    0.118132    0.099911    0.019227    0.633029    
#> 212: 0.188315    1.037068    3.492835    0.118539    0.099322    0.018999    0.632209    
#> 213: 0.191298    1.035662    3.493752    0.119832    0.098600    0.018895    0.632187    
#> 214: 0.194706    1.034653    3.494623    0.118928    0.098169    0.018797    0.632234    
#> 215: 0.196083    1.034958    3.495489    0.118008    0.098075    0.018695    0.632641    
#> 216: 0.196440    1.033955    3.495760    0.118280    0.098615    0.018637    0.632822    
#> 217: 0.195376    1.034732    3.495486    0.118024    0.098737    0.018396    0.632576    
#> 218: 0.194718    1.036033    3.494865    0.118513    0.099173    0.018165    0.631864    
#> 219: 0.194128    1.035698    3.493928    0.117777    0.099127    0.017798    0.632370    
#> 220: 0.192527    1.036339    3.493691    0.117278    0.099106    0.017725    0.632432    
#> 221: 0.192151    1.036111    3.493470    0.117657    0.098752    0.017734    0.632041    
#> 222: 0.192498    1.036211    3.492974    0.117567    0.099085    0.017715    0.632507    
#> 223: 0.192712    1.036785    3.492427    0.116587    0.099356    0.017609    0.633418    
#> 224: 0.193818    1.036911    3.492685    0.116246    0.099674    0.017472    0.633406    
#> 225: 0.194100    1.035050    3.493098    0.116039    0.099358    0.017416    0.633904    
#> 226: 0.195096    1.033100    3.493239    0.115947    0.099851    0.017279    0.634708    
#> 227: 0.194276    1.032984    3.493499    0.115802    0.100023    0.017317    0.635442    
#> 228: 0.193494    1.033810    3.492875    0.116350    0.100094    0.017306    0.635709    
#> 229: 0.193503    1.033562    3.492841    0.116397    0.099843    0.017261    0.635047    
#> 230: 0.194228    1.032990    3.492949    0.116734    0.099227    0.017215    0.634433    
#> 231: 0.194701    1.032552    3.493476    0.116757    0.099034    0.017329    0.633763    
#> 232: 0.195127    1.032164    3.493892    0.116917    0.098440    0.017313    0.633002    
#> 233: 0.195206    1.031058    3.494269    0.116796    0.098133    0.017311    0.632641    
#> 234: 0.195357    1.031072    3.494360    0.116283    0.098068    0.017307    0.632343    
#> 235: 0.194822    1.031093    3.493931    0.115459    0.097611    0.017302    0.632311    
#> 236: 0.194276    1.031793    3.493500    0.115045    0.097667    0.017282    0.632806    
#> 237: 0.193982    1.032206    3.493032    0.114938    0.097799    0.017269    0.633570    
#> 238: 0.193991    1.032759    3.492704    0.114344    0.098245    0.017216    0.634671    
#> 239: 0.193448    1.033319    3.492275    0.113844    0.098630    0.017184    0.634984    
#> 240: 0.193467    1.033613    3.492061    0.113789    0.098631    0.017163    0.634747    
#> 241: 0.193500    1.032988    3.492260    0.113497    0.098877    0.017169    0.634809    
#> 242: 0.193548    1.032791    3.492238    0.112955    0.098805    0.017234    0.634996    
#> 243: 0.192796    1.033166    3.492085    0.112899    0.098694    0.017266    0.635101    
#> 244: 0.192432    1.033442    3.492049    0.113493    0.098581    0.017342    0.634963    
#> 245: 0.192987    1.032900    3.492311    0.113810    0.098744    0.017310    0.635185    
#> 246: 0.192785    1.032613    3.492252    0.113745    0.098601    0.017292    0.635320    
#> 247: 0.192591    1.032393    3.492435    0.113916    0.098766    0.017309    0.635251    
#> 248: 0.192595    1.032168    3.492387    0.114411    0.098586    0.017237    0.635083    
#> 249: 0.192628    1.032112    3.492644    0.114428    0.098582    0.017235    0.635009    
#> 250: 0.193091    1.032143    3.492992    0.114886    0.098738    0.017308    0.634803    
#> 251: 0.193836    1.032424    3.493334    0.115470    0.098725    0.017307    0.634570    
#> 252: 0.195158    1.032780    3.493804    0.115432    0.098846    0.017267    0.634510    
#> 253: 0.196204    1.032729    3.494262    0.115446    0.099010    0.017297    0.634272    
#> 254: 0.196878    1.032251    3.494673    0.115426    0.099150    0.017241    0.634044    
#> 255: 0.197380    1.032086    3.494939    0.115784    0.099160    0.017207    0.633985    
#> 256: 0.197821    1.031891    3.495012    0.115699    0.099086    0.017154    0.633938    
#> 257: 0.197927    1.031750    3.494879    0.115629    0.099319    0.017066    0.634048    
#> 258: 0.197539    1.031631    3.494769    0.115725    0.099229    0.017009    0.633962    
#> 259: 0.197289    1.031381    3.494758    0.116203    0.099192    0.016989    0.633773    
#> 260: 0.197020    1.031603    3.494742    0.116486    0.099086    0.016995    0.633436    
#> 261: 0.196943    1.031523    3.494719    0.117376    0.098990    0.016993    0.633180    
#> 262: 0.197386    1.031599    3.494814    0.117893    0.098871    0.017019    0.633161    
#> 263: 0.197117    1.031776    3.494846    0.118064    0.098845    0.017021    0.633257    
#> 264: 0.197173    1.031568    3.494999    0.117960    0.098791    0.017010    0.633585    
#> 265: 0.197476    1.031499    3.495069    0.118002    0.098863    0.017006    0.633558    
#> 266: 0.197628    1.031430    3.495155    0.117935    0.098888    0.016952    0.633503    
#> 267: 0.198025    1.031392    3.495437    0.117530    0.098946    0.016937    0.633590    
#> 268: 0.198427    1.031141    3.495460    0.117584    0.098974    0.016921    0.633643    
#> 269: 0.198970    1.031332    3.495455    0.117620    0.099236    0.016900    0.633904    
#> 270: 0.199274    1.031623    3.495391    0.117438    0.099270    0.016897    0.633952    
#> 271: 0.199188    1.031464    3.495310    0.117408    0.099145    0.016902    0.634225    
#> 272: 0.199152    1.031299    3.495325    0.117620    0.098946    0.016928    0.634539    
#> 273: 0.199138    1.031451    3.495414    0.117897    0.098902    0.016934    0.634581    
#> 274: 0.198859    1.031558    3.495376    0.117915    0.098822    0.016905    0.634708    
#> 275: 0.198754    1.031614    3.495270    0.117834    0.098849    0.016892    0.634762    
#> 276: 0.198405    1.032126    3.495109    0.117891    0.098860    0.016877    0.634646    
#> 277: 0.197995    1.032406    3.495121    0.117788    0.098780    0.016886    0.634498    
#> 278: 0.197884    1.032488    3.495143    0.117441    0.098899    0.016890    0.634815    
#> 279: 0.197941    1.032272    3.495257    0.117369    0.099052    0.016907    0.635095    
#> 280: 0.198216    1.032401    3.495316    0.117403    0.099101    0.016891    0.635164    
#> 281: 0.198207    1.032532    3.495447    0.117352    0.099009    0.016882    0.635066    
#> 282: 0.198177    1.032536    3.495529    0.117178    0.099014    0.016896    0.635119    
#> 283: 0.198377    1.032605    3.495722    0.116975    0.098868    0.016934    0.635280    
#> 284: 0.198616    1.032286    3.495829    0.116448    0.098585    0.016971    0.635206    
#> 285: 0.199007    1.032420    3.495709    0.115949    0.098400    0.016988    0.635327    
#> 286: 0.199254    1.032518    3.495750    0.115660    0.098472    0.017018    0.635116    
#> 287: 0.199316    1.032411    3.495771    0.115455    0.098368    0.017047    0.635316    
#> 288: 0.199722    1.032194    3.495942    0.115190    0.098539    0.017067    0.635374    
#> 289: 0.200183    1.031980    3.496117    0.115164    0.098581    0.017103    0.635361    
#> 290: 0.200306    1.031820    3.496171    0.115061    0.098555    0.017119    0.635337    
#> 291: 0.200570    1.031833    3.496381    0.114965    0.098360    0.017161    0.635346    
#> 292: 0.200719    1.031894    3.496455    0.115154    0.098199    0.017178    0.635167    
#> 293: 0.200516    1.031900    3.496438    0.115306    0.098121    0.017163    0.635064    
#> 294: 0.200156    1.032058    3.496262    0.115411    0.098139    0.017131    0.634864    
#> 295: 0.200125    1.031903    3.496217    0.115493    0.097964    0.017174    0.634753    
#> 296: 0.200005    1.032077    3.496139    0.115615    0.097724    0.017235    0.634681    
#> 297: 0.200184    1.032351    3.495994    0.115668    0.097535    0.017284    0.634608    
#> 298: 0.200288    1.032458    3.495920    0.115751    0.097419    0.017313    0.634537    
#> 299: 0.200439    1.032557    3.495919    0.115716    0.097304    0.017353    0.634377    
#> 300: 0.200748    1.032296    3.496062    0.115756    0.097287    0.017350    0.634346    
#> 301: 0.200886    1.032201    3.496028    0.115982    0.097270    0.017348    0.634376    
#> 302: 0.200765    1.032227    3.495937    0.116114    0.097405    0.017329    0.634271    
#> 303: 0.200548    1.032406    3.495841    0.116072    0.097393    0.017347    0.634167    
#> 304: 0.200681    1.032638    3.495766    0.116210    0.097362    0.017385    0.634070    
#> 305: 0.200463    1.032661    3.495637    0.116169    0.097399    0.017412    0.634072    
#> 306: 0.200109    1.032932    3.495388    0.116157    0.097355    0.017415    0.634086    
#> 307: 0.199837    1.033113    3.495213    0.116170    0.097375    0.017389    0.634284    
#> 308: 0.199678    1.033108    3.495171    0.116174    0.097511    0.017362    0.634459    
#> 309: 0.199906    1.032687    3.495176    0.116063    0.097463    0.017324    0.634707    
#> 310: 0.200125    1.032573    3.495185    0.115978    0.097648    0.017281    0.634796    
#> 311: 0.200149    1.032453    3.495239    0.115978    0.097669    0.017271    0.634785    
#> 312: 0.200167    1.032260    3.495205    0.116011    0.097689    0.017243    0.634635    
#> 313: 0.200121    1.032079    3.495121    0.116033    0.097893    0.017207    0.634754    
#> 314: 0.199790    1.032268    3.494942    0.115999    0.098045    0.017148    0.634666    
#> 315: 0.199327    1.032551    3.494792    0.116056    0.098201    0.017111    0.634688    
#> 316: 0.199445    1.032818    3.494722    0.115779    0.098228    0.017098    0.634803    
#> 317: 0.199513    1.033016    3.494734    0.115853    0.098256    0.017094    0.634774    
#> 318: 0.199726    1.033020    3.494777    0.115791    0.098083    0.017116    0.634796    
#> 319: 0.199871    1.032921    3.494855    0.115723    0.098045    0.017107    0.634846    
#> 320: 0.199660    1.032748    3.494832    0.115729    0.098009    0.017096    0.634993    
#> 321: 0.199559    1.032830    3.494777    0.115571    0.098201    0.017087    0.635161    
#> 322: 0.199304    1.032932    3.494608    0.115542    0.098392    0.017043    0.635304    
#> 323: 0.198890    1.032821    3.494557    0.115597    0.098433    0.017027    0.635368    
#> 324: 0.198898    1.032786    3.494539    0.115774    0.098590    0.016974    0.635384    
#> 325: 0.198893    1.032822    3.494570    0.115826    0.098692    0.016940    0.635385    
#> 326: 0.198743    1.032634    3.494518    0.115800    0.098855    0.016887    0.635519    
#> 327: 0.198709    1.032648    3.494568    0.115653    0.098993    0.016839    0.635675    
#> 328: 0.198907    1.032740    3.494556    0.115633    0.098929    0.016795    0.635615    
#> 329: 0.199040    1.032879    3.494540    0.115640    0.099001    0.016776    0.635597    
#> 330: 0.199079    1.033012    3.494573    0.115649    0.099011    0.016786    0.635604    
#> 331: 0.199125    1.033118    3.494612    0.115742    0.099009    0.016798    0.635467    
#> 332: 0.199190    1.033056    3.494767    0.115718    0.098855    0.016831    0.635406    
#> 333: 0.199213    1.033029    3.494769    0.115584    0.098786    0.016851    0.635311    
#> 334: 0.199374    1.032794    3.494765    0.115577    0.098656    0.016846    0.635338    
#> 335: 0.199433    1.032671    3.494769    0.115418    0.098536    0.016850    0.635357    
#> 336: 0.199090    1.032906    3.494724    0.115313    0.098543    0.016853    0.635462    
#> 337: 0.198988    1.033230    3.494590    0.115002    0.098544    0.016836    0.635584    
#> 338: 0.199106    1.033323    3.494676    0.115000    0.098449    0.016815    0.635678    
#> 339: 0.199053    1.033490    3.494665    0.115064    0.098390    0.016811    0.635722    
#> 340: 0.198883    1.033397    3.494647    0.115029    0.098313    0.016816    0.635721    
#> 341: 0.198893    1.033387    3.494629    0.115049    0.098385    0.016795    0.635764    
#> 342: 0.198724    1.033283    3.494558    0.114973    0.098446    0.016799    0.635685    
#> 343: 0.198383    1.033356    3.494500    0.115139    0.098486    0.016797    0.635509    
#> 344: 0.198429    1.033348    3.494522    0.115247    0.098425    0.016817    0.635445    
#> 345: 0.198294    1.033402    3.494500    0.115332    0.098366    0.016830    0.635373    
#> 346: 0.198115    1.033423    3.494342    0.115506    0.098283    0.016812    0.635256    
#> 347: 0.197944    1.033480    3.494221    0.115496    0.098314    0.016814    0.635289    
#> 348: 0.197832    1.033553    3.494138    0.115565    0.098414    0.016810    0.635224    
#> 349: 0.197839    1.033441    3.494114    0.115480    0.098499    0.016795    0.635265    
#> 350: 0.197507    1.033495    3.494004    0.115396    0.098564    0.016764    0.635276    
#> 351: 0.197417    1.033732    3.493881    0.115294    0.098572    0.016736    0.635366    
#> 352: 0.197211    1.034003    3.493810    0.115202    0.098705    0.016715    0.635498    
#> 353: 0.197211    1.034208    3.493690    0.115260    0.098701    0.016699    0.635470    
#> 354: 0.197344    1.034227    3.493576    0.115308    0.098702    0.016692    0.635532    
#> 355: 0.197750    1.034178    3.493620    0.115352    0.098613    0.016696    0.635464    
#> 356: 0.197905    1.034105    3.493689    0.115376    0.098600    0.016713    0.635427    
#> 357: 0.198238    1.034224    3.493758    0.115439    0.098515    0.016734    0.635325    
#> 358: 0.198277    1.034359    3.493779    0.115392    0.098442    0.016758    0.635235    
#> 359: 0.198258    1.034428    3.493757    0.115275    0.098397    0.016762    0.635222    
#> 360: 0.197895    1.034581    3.493557    0.115209    0.098431    0.016735    0.635085    
#> 361: 0.197675    1.034661    3.493428    0.115159    0.098496    0.016704    0.635024    
#> 362: 0.197497    1.034748    3.493271    0.115186    0.098570    0.016685    0.634972    
#> 363: 0.197356    1.034748    3.493234    0.115232    0.098569    0.016675    0.634948    
#> 364: 0.197196    1.034885    3.493141    0.115305    0.098706    0.016653    0.635045    
#> 365: 0.197024    1.034809    3.493116    0.115310    0.098826    0.016652    0.635074    
#> 366: 0.196940    1.034727    3.493063    0.115472    0.098885    0.016651    0.635081    
#> 367: 0.196877    1.034789    3.493050    0.115484    0.099004    0.016622    0.635133    
#> 368: 0.197018    1.034899    3.493030    0.115397    0.098996    0.016617    0.635044    
#> 369: 0.196836    1.034887    3.493014    0.115329    0.099009    0.016607    0.635044    
#> 370: 0.196567    1.034975    3.492980    0.115281    0.099035    0.016592    0.634967    
#> 371: 0.196334    1.035045    3.492849    0.115155    0.099011    0.016567    0.635082    
#> 372: 0.196199    1.035193    3.492800    0.115008    0.099052    0.016555    0.635091    
#> 373: 0.195996    1.035406    3.492734    0.115043    0.099089    0.016536    0.635048    
#> 374: 0.195904    1.035445    3.492602    0.115071    0.099062    0.016533    0.635013    
#> 375: 0.195868    1.035399    3.492618    0.115249    0.099184    0.016527    0.634966    
#> 376: 0.195836    1.035485    3.492638    0.115268    0.099195    0.016528    0.634820    
#> 377: 0.195788    1.035568    3.492615    0.115325    0.099104    0.016534    0.634783    
#> 378: 0.195607    1.035657    3.492545    0.115312    0.099061    0.016544    0.634729    
#> 379: 0.195414    1.035583    3.492537    0.115377    0.099068    0.016526    0.634707    
#> 380: 0.195163    1.035561    3.492513    0.115352    0.099026    0.016493    0.634720    
#> 381: 0.195039    1.035551    3.492458    0.115455    0.098989    0.016473    0.634722    
#> 382: 0.194933    1.035629    3.492403    0.115517    0.098993    0.016479    0.634641    
#> 383: 0.195059    1.035659    3.492413    0.115549    0.098928    0.016484    0.634603    
#> 384: 0.195025    1.035545    3.492432    0.115695    0.098882    0.016481    0.634585    
#> 385: 0.194954    1.035624    3.492392    0.115729    0.098914    0.016484    0.634568    
#> 386: 0.195010    1.035774    3.492419    0.115779    0.098924    0.016501    0.634570    
#> 387: 0.195081    1.035869    3.492450    0.115782    0.098941    0.016506    0.634563    
#> 388: 0.195035    1.035897    3.492481    0.115660    0.098905    0.016538    0.634587    
#> 389: 0.195013    1.035905    3.492447    0.115610    0.098804    0.016555    0.634653    
#> 390: 0.195066    1.035912    3.492479    0.115617    0.098639    0.016584    0.634612    
#> 391: 0.195080    1.035883    3.492507    0.115603    0.098532    0.016598    0.634503    
#> 392: 0.195135    1.035962    3.492554    0.115620    0.098431    0.016610    0.634491    
#> 393: 0.195085    1.035966    3.492505    0.115658    0.098319    0.016611    0.634430    
#> 394: 0.195004    1.036062    3.492446    0.115697    0.098295    0.016612    0.634366    
#> 395: 0.195048    1.036221    3.492419    0.115760    0.098269    0.016628    0.634316    
#> 396: 0.195203    1.036284    3.492439    0.115748    0.098207    0.016651    0.634242    
#> 397: 0.195260    1.036228    3.492512    0.115714    0.098154    0.016677    0.634217    
#> 398: 0.195400    1.036190    3.492572    0.115666    0.098068    0.016717    0.634217    
#> 399: 0.195518    1.036141    3.492638    0.115581    0.098023    0.016744    0.634164    
#> 400: 0.195588    1.036076    3.492726    0.115499    0.097958    0.016756    0.634148    
#> 401: 0.195625    1.036064    3.492748    0.115451    0.097930    0.016774    0.634150    
#> 402: 0.195645    1.036132    3.492756    0.115446    0.097876    0.016793    0.634072    
#> 403: 0.195701    1.036138    3.492739    0.115509    0.097895    0.016818    0.633953    
#> 404: 0.195716    1.036174    3.492636    0.115628    0.097894    0.016826    0.633875    
#> 405: 0.195727    1.036277    3.492623    0.115685    0.097880    0.016812    0.633840    
#> 406: 0.195670    1.036300    3.492611    0.115710    0.097876    0.016809    0.633902    
#> 407: 0.195661    1.036293    3.492649    0.115702    0.097913    0.016800    0.633907    
#> 408: 0.195655    1.036300    3.492658    0.115653    0.097917    0.016795    0.633901    
#> 409: 0.195562    1.036208    3.492612    0.115693    0.098002    0.016782    0.633866    
#> 410: 0.195538    1.036257    3.492535    0.115775    0.098079    0.016761    0.633862    
#> 411: 0.195597    1.036148    3.492473    0.115891    0.098079    0.016748    0.633908    
#> 412: 0.195619    1.036221    3.492419    0.115993    0.098035    0.016748    0.633916    
#> 413: 0.195630    1.036254    3.492355    0.116147    0.098017    0.016743    0.633961    
#> 414: 0.195484    1.036295    3.492346    0.116208    0.097975    0.016734    0.633966    
#> 415: 0.195534    1.036235    3.492328    0.116218    0.097926    0.016738    0.633969    
#> 416: 0.195660    1.036285    3.492351    0.116191    0.098004    0.016748    0.633916    
#> 417: 0.195625    1.036279    3.492352    0.116150    0.097999    0.016749    0.633855    
#> 418: 0.195472    1.036318    3.492390    0.116113    0.098032    0.016741    0.633841    
#> 419: 0.195527    1.036423    3.492424    0.116157    0.098101    0.016756    0.633845    
#> 420: 0.195613    1.036421    3.492429    0.116217    0.098100    0.016739    0.633822    
#> 421: 0.195622    1.036456    3.492467    0.116203    0.098165    0.016724    0.633848    
#> 422: 0.195814    1.036368    3.492515    0.116139    0.098237    0.016720    0.633910    
#> 423: 0.195910    1.036309    3.492533    0.116144    0.098218    0.016716    0.633972    
#> 424: 0.195761    1.036325    3.492473    0.116109    0.098273    0.016702    0.633933    
#> 425: 0.195864    1.036337    3.492444    0.116026    0.098279    0.016694    0.633972    
#> 426: 0.195857    1.036420    3.492404    0.115977    0.098322    0.016683    0.633948    
#> 427: 0.195680    1.036411    3.492398    0.115950    0.098288    0.016667    0.633923    
#> 428: 0.195457    1.036510    3.492374    0.116012    0.098283    0.016655    0.633945    
#> 429: 0.195396    1.036569    3.492366    0.116009    0.098314    0.016643    0.633951    
#> 430: 0.195316    1.036556    3.492325    0.116056    0.098325    0.016636    0.633912    
#> 431: 0.195176    1.036499    3.492265    0.116148    0.098329    0.016629    0.633826    
#> 432: 0.195010    1.036479    3.492274    0.116152    0.098317    0.016640    0.633734    
#> 433: 0.195028    1.036468    3.492346    0.116123    0.098267    0.016654    0.633730    
#> 434: 0.194986    1.036361    3.492408    0.115990    0.098172    0.016683    0.633755    
#> 435: 0.195125    1.036286    3.492452    0.115936    0.098102    0.016692    0.633776    
#> 436: 0.195142    1.036103    3.492545    0.115873    0.098069    0.016725    0.633802    
#> 437: 0.195121    1.035988    3.492559    0.115802    0.098041    0.016735    0.633824    
#> 438: 0.195198    1.035977    3.492601    0.115736    0.098023    0.016736    0.633837    
#> 439: 0.195216    1.036051    3.492643    0.115632    0.098018    0.016733    0.633851    
#> 440: 0.195126    1.036113    3.492691    0.115528    0.097994    0.016741    0.633869    
#> 441: 0.195108    1.036105    3.492725    0.115549    0.098006    0.016732    0.633863    
#> 442: 0.195113    1.036213    3.492756    0.115620    0.098070    0.016720    0.633746    
#> 443: 0.195098    1.036254    3.492750    0.115577    0.098043    0.016718    0.633721    
#> 444: 0.195075    1.036274    3.492696    0.115555    0.098081    0.016714    0.633745    
#> 445: 0.194942    1.036371    3.492641    0.115473    0.098139    0.016711    0.633806    
#> 446: 0.194790    1.036456    3.492556    0.115398    0.098208    0.016699    0.633768    
#> 447: 0.194870    1.036457    3.492555    0.115463    0.098177    0.016706    0.633723    
#> 448: 0.194953    1.036471    3.492590    0.115483    0.098190    0.016713    0.633676    
#> 449: 0.195066    1.036453    3.492709    0.115539    0.098239    0.016729    0.633663    
#> 450: 0.195009    1.036365    3.492735    0.115546    0.098185    0.016757    0.633595    
#> 451: 0.195062    1.036313    3.492739    0.115500    0.098190    0.016774    0.633631    
#> 452: 0.194933    1.036344    3.492721    0.115497    0.098184    0.016781    0.633609    
#> 453: 0.194873    1.036284    3.492690    0.115574    0.098120    0.016780    0.633551    
#> 454: 0.194760    1.036453    3.492638    0.115651    0.098185    0.016778    0.633514    
#> 455: 0.194700    1.036503    3.492602    0.115698    0.098096    0.016771    0.633523    
#> 456: 0.194599    1.036447    3.492578    0.115746    0.098019    0.016790    0.633467    
#> 457: 0.194536    1.036511    3.492593    0.115823    0.097933    0.016815    0.633402    
#> 458: 0.194474    1.036669    3.492573    0.115858    0.097881    0.016826    0.633319    
#> 459: 0.194343    1.036810    3.492523    0.115866    0.097767    0.016842    0.633286    
#> 460: 0.194208    1.036917    3.492437    0.115915    0.097693    0.016848    0.633248    
#> 461: 0.194052    1.036948    3.492407    0.115928    0.097659    0.016861    0.633232    
#> 462: 0.194042    1.037050    3.492417    0.115888    0.097619    0.016893    0.633191    
#> 463: 0.194194    1.037111    3.492462    0.115883    0.097587    0.016902    0.633178    
#> 464: 0.194262    1.037153    3.492484    0.115865    0.097598    0.016892    0.633097    
#> 465: 0.194358    1.037021    3.492534    0.115881    0.097567    0.016890    0.633060    
#> 466: 0.194463    1.037053    3.492532    0.115844    0.097562    0.016879    0.633015    
#> 467: 0.194406    1.036993    3.492531    0.115829    0.097583    0.016866    0.632958    
#> 468: 0.194559    1.037039    3.492574    0.115818    0.097564    0.016865    0.633010    
#> 469: 0.194588    1.037125    3.492608    0.115830    0.097594    0.016866    0.633022    
#> 470: 0.194547    1.037186    3.492582    0.115776    0.097631    0.016870    0.632976    
#> 471: 0.194414    1.037115    3.492555    0.115742    0.097583    0.016871    0.632961    
#> 472: 0.194382    1.037129    3.492562    0.115776    0.097643    0.016875    0.632928    
#> 473: 0.194301    1.037105    3.492561    0.115766    0.097662    0.016880    0.632902    
#> 474: 0.194351    1.037058    3.492568    0.115730    0.097712    0.016874    0.632945    
#> 475: 0.194389    1.037105    3.492578    0.115718    0.097728    0.016872    0.632946    
#> 476: 0.194479    1.037120    3.492588    0.115677    0.097789    0.016864    0.632998    
#> 477: 0.194517    1.037118    3.492624    0.115613    0.097845    0.016848    0.632977    
#> 478: 0.194507    1.037135    3.492634    0.115640    0.097853    0.016836    0.632993    
#> 479: 0.194621    1.037118    3.492684    0.115641    0.097854    0.016835    0.633012    
#> 480: 0.194766    1.037095    3.492719    0.115620    0.097868    0.016838    0.633101    
#> 481: 0.194739    1.037143    3.492722    0.115637    0.097895    0.016834    0.633096    
#> 482: 0.194786    1.037196    3.492701    0.115720    0.097922    0.016846    0.633048    
#> 483: 0.194762    1.037135    3.492709    0.115716    0.097917    0.016840    0.633042    
#> 484: 0.194758    1.037016    3.492730    0.115685    0.097884    0.016835    0.633089    
#> 485: 0.194829    1.037005    3.492739    0.115708    0.097871    0.016832    0.633063    
#> 486: 0.194900    1.036996    3.492752    0.115681    0.097833    0.016833    0.633002    
#> 487: 0.194963    1.036981    3.492794    0.115678    0.097821    0.016846    0.632981    
#> 488: 0.194916    1.036886    3.492804    0.115691    0.097814    0.016846    0.632951    
#> 489: 0.194914    1.036863    3.492771    0.115686    0.097867    0.016840    0.632970    
#> 490: 0.194992    1.036874    3.492802    0.115679    0.097910    0.016842    0.632963    
#> 491: 0.195038    1.036928    3.492842    0.115710    0.097969    0.016853    0.632917    
#> 492: 0.195043    1.036929    3.492835    0.115731    0.098010    0.016853    0.632947    
#> 493: 0.195040    1.036961    3.492818    0.115837    0.098021    0.016857    0.632948    
#> 494: 0.195026    1.037056    3.492764    0.115915    0.098017    0.016853    0.632897    
#> 495: 0.195090    1.037074    3.492741    0.115924    0.098004    0.016850    0.632867    
#> 496: 0.195118    1.037110    3.492703    0.115871    0.098025    0.016847    0.632898    
#> 497: 0.195004    1.037092    3.492681    0.115736    0.098057    0.016848    0.632904    
#> 498: 0.194968    1.037106    3.492616    0.115690    0.098109    0.016832    0.632848    
#> 499: 0.194894    1.037141    3.492549    0.115663    0.098126    0.016819    0.632822    
#> 500: 0.194855    1.037150    3.492521    0.115662    0.098133    0.016817    0.632784    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.287940    0.992578    3.441305    0.392401    0.083389    0.016800    1.848002    
#> 002: 0.244705    1.023433    3.480910    0.372781    0.079219    0.017045    1.128066    
#> 003: 0.374338    0.999369    3.514607    0.354142    0.075258    0.016193    0.918613    
#> 004: 0.378141    1.040804    3.528265    0.336435    0.075637    0.015383    0.802871    
#> 005: 0.407722    1.068296    3.525572    0.319613    0.071855    0.014614    0.745317    
#> 006: 0.368125    1.080039    3.503487    0.386136    0.068263    0.013883    0.692154    
#> 007: 0.328531    1.099214    3.495924    0.369524    0.064849    0.013189    0.714198    
#> 008: 0.312661    1.098590    3.488458    0.392845    0.076201    0.012627    0.708956    
#> 009: 0.265736    1.090876    3.477131    0.401736    0.072391    0.012589    0.702473    
#> 010: 0.279692    1.080449    3.479868    0.391132    0.068771    0.011960    0.720107    
#> 011: 0.364755    1.100307    3.487202    0.439040    0.069968    0.011842    0.702796    
#> 012: 0.334820    1.101306    3.479115    0.417088    0.066469    0.011346    0.701835    
#> 013: 0.276635    1.113859    3.474158    0.404181    0.063146    0.011574    0.711803    
#> 014: 0.312613    1.099737    3.490274    0.383972    0.070772    0.012419    0.729238    
#> 015: 0.329320    1.100203    3.500244    0.442879    0.067234    0.013849    0.702401    
#> 016: 0.328107    1.112621    3.509824    0.420735    0.063872    0.016021    0.704339    
#> 017: 0.342018    1.108695    3.510513    0.452724    0.060679    0.015395    0.690916    
#> 018: 0.349411    1.115168    3.491328    0.525477    0.057645    0.014766    0.695316    
#> 019: 0.305735    1.100233    3.488634    0.499203    0.056346    0.015650    0.692362    
#> 020: 0.323381    1.102889    3.493199    0.474243    0.070779    0.014867    0.689054    
#> 021: 0.328902    1.086674    3.497641    0.454020    0.067240    0.014124    0.694459    
#> 022: 0.320892    1.097566    3.499421    0.431319    0.063878    0.015041    0.670761    
#> 023: 0.401228    1.103037    3.520213    0.449628    0.060684    0.018227    0.696300    
#> 024: 0.367452    1.115289    3.509425    0.427147    0.057650    0.019312    0.695049    
#> 025: 0.334657    1.100813    3.494292    0.405789    0.054767    0.018346    0.690945    
#> 026: 0.312366    1.138952    3.479954    0.385500    0.052029    0.018179    0.700320    
#> 027: 0.268460    1.143676    3.477070    0.388067    0.049428    0.019655    0.717971    
#> 028: 0.326133    1.131656    3.493721    0.406167    0.051809    0.020892    0.706348    
#> 029: 0.372534    1.138495    3.495302    0.439781    0.063152    0.020258    0.713427    
#> 030: 0.334279    1.132641    3.492034    0.417792    0.059995    0.020116    0.699911    
#> 031: 0.314287    1.106939    3.504728    0.425983    0.056995    0.019110    0.718592    
#> 032: 0.346533    1.107312    3.507230    0.443743    0.056031    0.020705    0.706327    
#> 033: 0.328546    1.112215    3.497431    0.421556    0.055226    0.020123    0.702427    
#> 034: 0.368622    1.113587    3.495945    0.400478    0.058179    0.019117    0.709554    
#> 035: 0.339115    1.089942    3.490815    0.380454    0.062390    0.018161    0.687461    
#> 036: 0.356213    1.098652    3.500088    0.449491    0.059271    0.017308    0.684694    
#> 037: 0.332021    1.125397    3.495783    0.452662    0.059173    0.016443    0.706329    
#> 038: 0.346646    1.110271    3.494426    0.430029    0.056214    0.015621    0.706960    
#> 039: 0.350750    1.124496    3.512096    0.408528    0.067772    0.014840    0.676135    
#> 040: 0.334196    1.132828    3.506496    0.388101    0.064383    0.014635    0.704099    
#> 041: 0.355401    1.098454    3.510845    0.369146    0.061164    0.016101    0.693253    
#> 042: 0.419230    1.087944    3.516538    0.350688    0.058106    0.015296    0.698416    
#> 043: 0.356994    1.101248    3.503999    0.380842    0.055200    0.016599    0.690734    
#> 044: 0.346491    1.115139    3.496921    0.411025    0.058292    0.015769    0.700331    
#> 045: 0.342259    1.135748    3.484784    0.401579    0.057142    0.014981    0.693544    
#> 046: 0.335081    1.117376    3.486848    0.399598    0.057351    0.014232    0.686519    
#> 047: 0.326931    1.126886    3.478406    0.480538    0.054484    0.014904    0.682162    
#> 048: 0.341848    1.112590    3.482654    0.493581    0.051760    0.014159    0.698115    
#> 049: 0.361428    1.095864    3.492130    0.504532    0.062001    0.013451    0.690239    
#> 050: 0.349140    1.089280    3.497657    0.479305    0.065105    0.012779    0.705018    
#> 051: 0.335127    1.095628    3.492423    0.455340    0.061850    0.013035    0.726837    
#> 052: 0.363421    1.121642    3.504228    0.432573    0.058757    0.013909    0.706891    
#> 053: 0.373714    1.096501    3.505816    0.410944    0.055819    0.013213    0.703235    
#> 054: 0.343711    1.100572    3.505775    0.412349    0.053028    0.016972    0.715728    
#> 055: 0.339762    1.104273    3.506473    0.444427    0.056960    0.016124    0.711245    
#> 056: 0.338570    1.081925    3.507796    0.422206    0.055781    0.015495    0.717315    
#> 057: 0.337974    1.099414    3.506485    0.401096    0.067333    0.015075    0.710540    
#> 058: 0.315207    1.088520    3.491274    0.381041    0.065157    0.014321    0.718636    
#> 059: 0.302781    1.069541    3.498924    0.361989    0.061899    0.016142    0.717626    
#> 060: 0.336849    1.071272    3.512044    0.343889    0.058804    0.020265    0.736862    
#> 061: 0.385109    1.081539    3.517018    0.385031    0.055864    0.022295    0.753341    
#> 062: 0.351758    1.111226    3.514010    0.365779    0.053071    0.022284    0.728364    
#> 063: 0.402695    1.078822    3.516996    0.361002    0.052186    0.021170    0.714308    
#> 064: 0.368119    1.091425    3.528165    0.362110    0.049576    0.020112    0.724047    
#> 065: 0.390284    1.078411    3.505081    0.420716    0.047098    0.022848    0.717382    
#> 066: 0.362912    1.083346    3.506419    0.413215    0.046593    0.021705    0.683023    
#> 067: 0.365827    1.094354    3.515646    0.392554    0.047522    0.022488    0.688343    
#> 068: 0.341305    1.096093    3.513342    0.372926    0.047628    0.021364    0.692169    
#> 069: 0.323192    1.118714    3.493596    0.390439    0.053642    0.020296    0.682496    
#> 070: 0.337827    1.102380    3.500437    0.400055    0.050960    0.019908    0.692454    
#> 071: 0.284434    1.146301    3.460595    0.381143    0.048412    0.020229    0.720791    
#> 072: 0.270081    1.106703    3.481430    0.372769    0.045991    0.020539    0.706835    
#> 073: 0.310970    1.118890    3.491361    0.418334    0.054273    0.019512    0.705748    
#> 074: 0.350647    1.107127    3.492058    0.414156    0.059284    0.019056    0.708531    
#> 075: 0.349269    1.107142    3.515258    0.432096    0.056320    0.018103    0.705572    
#> 076: 0.389814    1.121915    3.520365    0.522000    0.053504    0.020368    0.702044    
#> 077: 0.399492    1.093359    3.511743    0.534631    0.057597    0.019350    0.689077    
#> 078: 0.365246    1.092260    3.510455    0.507899    0.054717    0.018382    0.697714    
#> 079: 0.376198    1.108447    3.513510    0.482505    0.051982    0.017722    0.709043    
#> 080: 0.360344    1.101979    3.497880    0.458379    0.049383    0.021560    0.710055    
#> 081: 0.345242    1.099752    3.504224    0.435460    0.046913    0.020482    0.700877    
#> 082: 0.310546    1.092944    3.497525    0.436855    0.048985    0.019458    0.715062    
#> 083: 0.339910    1.120419    3.492637    0.555740    0.055347    0.018485    0.716311    
#> 084: 0.370360    1.116427    3.500174    0.527953    0.065119    0.017561    0.697118    
#> 085: 0.362833    1.125099    3.503334    0.501555    0.061863    0.016683    0.707254    
#> 086: 0.394089    1.109607    3.503530    0.476477    0.058770    0.017224    0.706601    
#> 087: 0.352478    1.113222    3.482427    0.455152    0.055832    0.016363    0.685868    
#> 088: 0.282553    1.114684    3.485383    0.432395    0.053040    0.015553    0.702846    
#> 089: 0.332544    1.124104    3.485033    0.410775    0.062193    0.017084    0.694135    
#> 090: 0.323729    1.129246    3.487201    0.391332    0.069429    0.016230    0.695956    
#> 091: 0.282806    1.093985    3.480933    0.409754    0.065958    0.015418    0.702660    
#> 092: 0.270627    1.125153    3.461908    0.389266    0.062660    0.016376    0.714362    
#> 093: 0.226937    1.116893    3.460774    0.418177    0.063121    0.015823    0.707417    
#> 094: 0.284563    1.141764    3.463752    0.516337    0.060405    0.015154    0.702318    
#> 095: 0.270824    1.162755    3.482985    0.490520    0.057385    0.018846    0.688597    
#> 096: 0.261090    1.134819    3.477576    0.465994    0.054516    0.017903    0.698682    
#> 097: 0.362729    1.136841    3.486559    0.497279    0.053065    0.017008    0.677992    
#> 098: 0.346404    1.140244    3.496961    0.497892    0.050412    0.016158    0.694930    
#> 099: 0.336754    1.117133    3.492496    0.472997    0.048643    0.015350    0.711578    
#> 100: 0.330659    1.115435    3.495522    0.449347    0.053183    0.014582    0.713070    
#> 101: 0.287002    1.092172    3.472124    0.426880    0.054565    0.013853    0.712464    
#> 102: 0.307068    1.088719    3.475037    0.420685    0.055230    0.013161    0.694183    
#> 103: 0.351319    1.114211    3.479538    0.475642    0.058543    0.012503    0.683329    
#> 104: 0.334771    1.119540    3.492941    0.553179    0.060986    0.011877    0.706048    
#> 105: 0.319882    1.114113    3.482475    0.525520    0.057937    0.011284    0.709601    
#> 106: 0.335256    1.116506    3.488177    0.499244    0.061321    0.011930    0.688445    
#> 107: 0.349441    1.106161    3.491177    0.474282    0.063693    0.013046    0.699485    
#> 108: 0.355012    1.102895    3.486878    0.450568    0.060508    0.014553    0.718565    
#> 109: 0.344785    1.117072    3.501827    0.428040    0.070287    0.016746    0.704599    
#> 110: 0.335929    1.107942    3.480679    0.459376    0.066773    0.015908    0.691525    
#> 111: 0.345870    1.124706    3.496098    0.436407    0.063434    0.015113    0.681838    
#> 112: 0.356226    1.081568    3.498097    0.414586    0.060262    0.015894    0.692129    
#> 113: 0.380590    1.113201    3.501628    0.488344    0.057249    0.017202    0.674763    
#> 114: 0.383994    1.105315    3.505103    0.493278    0.057104    0.017155    0.691603    
#> 115: 0.373532    1.084724    3.498842    0.492033    0.058557    0.019029    0.700097    
#> 116: 0.356863    1.134106    3.486685    0.498864    0.055629    0.019247    0.698631    
#> 117: 0.325666    1.127322    3.490943    0.474347    0.052985    0.018284    0.693340    
#> 118: 0.356190    1.112466    3.490283    0.450632    0.064980    0.017370    0.682118    
#> 119: 0.330453    1.123627    3.488502    0.428101    0.066561    0.016502    0.701143    
#> 120: 0.345428    1.109427    3.496140    0.478195    0.063233    0.015735    0.694273    
#> 121: 0.361460    1.131516    3.493272    0.459352    0.060071    0.017279    0.700147    
#> 122: 0.369493    1.106917    3.503219    0.436384    0.057068    0.016415    0.716780    
#> 123: 0.368188    1.134296    3.481035    0.494721    0.054214    0.015594    0.705820    
#> 124: 0.318262    1.160831    3.473673    0.469985    0.051504    0.014815    0.718219    
#> 125: 0.344859    1.146430    3.476327    0.446486    0.048929    0.014074    0.696380    
#> 126: 0.314558    1.147048    3.477698    0.424161    0.058386    0.013370    0.696287    
#> 127: 0.337603    1.133808    3.473329    0.402953    0.055466    0.012702    0.718135    
#> 128: 0.329820    1.122375    3.487246    0.384115    0.063942    0.012067    0.704957    
#> 129: 0.381106    1.124560    3.499949    0.376673    0.060745    0.011873    0.712887    
#> 130: 0.382707    1.129911    3.497177    0.357916    0.060463    0.013278    0.703551    
#> 131: 0.352511    1.104124    3.493262    0.340020    0.064096    0.013670    0.708117    
#> 132: 0.292181    1.130573    3.474424    0.351161    0.070527    0.015200    0.716135    
#> 133: 0.293565    1.115827    3.479810    0.363030    0.067001    0.015814    0.718466    
#> 134: 0.332296    1.098923    3.500017    0.388595    0.063651    0.023120    0.701159    
#> 135: 0.340934    1.082839    3.513807    0.369165    0.060468    0.021964    0.723144    
#> 136: 0.351082    1.065811    3.515328    0.352698    0.057445    0.022193    0.718565    
#> 137: 0.391397    1.070026    3.518995    0.408125    0.057880    0.023951    0.708400    
#> 138: 0.339697    1.099851    3.502461    0.387718    0.063979    0.022754    0.692806    
#> 139: 0.339822    1.109751    3.508183    0.442093    0.060780    0.021616    0.685019    
#> 140: 0.373071    1.110300    3.504554    0.422315    0.059332    0.020535    0.706150    
#> 141: 0.349829    1.090930    3.506770    0.472442    0.056366    0.019843    0.699178    
#> 142: 0.399307    1.066214    3.530400    0.448820    0.053547    0.018851    0.718485    
#> 143: 0.325854    1.086378    3.517045    0.426379    0.067396    0.019381    0.702686    
#> 144: 0.387979    1.094603    3.520032    0.496459    0.064026    0.018412    0.679274    
#> 145: 0.365578    1.103517    3.502329    0.471636    0.060825    0.017491    0.684280    
#> 146: 0.301304    1.125936    3.501546    0.448054    0.057784    0.018451    0.706715    
#> 147: 0.307204    1.110696    3.484668    0.425651    0.054895    0.019370    0.678541    
#> 148: 0.311119    1.120851    3.496255    0.439130    0.058171    0.020718    0.688197    
#> 149: 0.338039    1.104891    3.497486    0.500914    0.055262    0.020066    0.704610    
#> 150: 0.392191    1.091091    3.494544    0.498932    0.052499    0.022064    0.708090    
#> 151: 0.312262    1.124355    3.480676    0.512026    0.049874    0.020961    0.686465    
#> 152: 0.293271    1.126742    3.485492    0.415763    0.043642    0.020607    0.707399    
#> 153: 0.322648    1.125057    3.497664    0.405769    0.048402    0.023060    0.706844    
#> 154: 0.382805    1.109674    3.503341    0.399399    0.043167    0.024565    0.711540    
#> 155: 0.360156    1.085429    3.499159    0.376356    0.045386    0.019206    0.701232    
#> 156: 0.344294    1.100402    3.506878    0.374467    0.042890    0.017550    0.699771    
#> 157: 0.357428    1.113915    3.503120    0.442006    0.048029    0.020277    0.703927    
#> 158: 0.344089    1.136938    3.488241    0.431996    0.045855    0.018496    0.708091    
#> 159: 0.324935    1.134147    3.499153    0.398954    0.050915    0.020260    0.704427    
#> 160: 0.346572    1.095582    3.501275    0.422327    0.046404    0.019709    0.706945    
#> 161: 0.344828    1.100411    3.506825    0.400154    0.039786    0.023496    0.709498    
#> 162: 0.345101    1.124204    3.506468    0.422358    0.046340    0.020604    0.691587    
#> 163: 0.388514    1.111904    3.497344    0.432583    0.045314    0.023243    0.685898    
#> 164: 0.365906    1.106522    3.493153    0.439141    0.038831    0.020087    0.705471    
#> 165: 0.385590    1.093723    3.511719    0.424039    0.046418    0.023018    0.702403    
#> 166: 0.364286    1.124480    3.508689    0.405675    0.048410    0.021447    0.685483    
#> 167: 0.388999    1.128681    3.517311    0.369889    0.054531    0.019154    0.712417    
#> 168: 0.380437    1.141132    3.503350    0.405186    0.052826    0.019443    0.709264    
#> 169: 0.330484    1.162821    3.482037    0.366638    0.047506    0.026846    0.728347    
#> 170: 0.328749    1.122865    3.482035    0.337898    0.044923    0.022947    0.712188    
#> 171: 0.283739    1.131126    3.476543    0.371900    0.051696    0.019130    0.697426    
#> 172: 0.276516    1.127649    3.482346    0.410053    0.052862    0.019163    0.693084    
#> 173: 0.276905    1.159768    3.457117    0.404096    0.047284    0.016591    0.693485    
#> 174: 0.315150    1.131719    3.472208    0.443122    0.053997    0.013973    0.683523    
#> 175: 0.320762    1.129950    3.474127    0.399743    0.053791    0.015252    0.711780    
#> 176: 0.310535    1.142175    3.485371    0.430898    0.054868    0.015012    0.682584    
#> 177: 0.366664    1.118090    3.510635    0.422959    0.048253    0.014932    0.703985    
#> 178: 0.371449    1.099100    3.506094    0.417557    0.054264    0.018180    0.692113    
#> 179: 0.371604    1.103094    3.505681    0.360429    0.047392    0.018364    0.694391    
#> 180: 0.331820    1.107510    3.504625    0.348952    0.053852    0.017415    0.689318    
#> 181: 0.310038    1.095805    3.489185    0.330219    0.051034    0.014587    0.708442    
#> 182: 0.269452    1.114870    3.467708    0.364484    0.065369    0.011040    0.722760    
#> 183: 0.307725    1.139298    3.473525    0.399445    0.078513    0.011130    0.683939    
#> 184: 0.306376    1.119505    3.469792    0.477491    0.065170    0.013381    0.682819    
#> 185: 0.328066    1.130259    3.482756    0.461573    0.057268    0.013079    0.703049    
#> 186: 0.286972    1.149795    3.482608    0.451144    0.068479    0.011408    0.709390    
#> 187: 0.337623    1.113835    3.490389    0.467636    0.053282    0.012856    0.718031    
#> 188: 0.307648    1.133479    3.491177    0.472550    0.061999    0.014361    0.712253    
#> 189: 0.315601    1.147631    3.491883    0.439845    0.068329    0.012833    0.714676    
#> 190: 0.271860    1.144698    3.484511    0.428779    0.050332    0.011502    0.705568    
#> 191: 0.277305    1.141692    3.464301    0.533453    0.051793    0.010156    0.700463    
#> 192: 0.270268    1.156230    3.462863    0.532999    0.062532    0.012749    0.704492    
#> 193: 0.320935    1.147424    3.471677    0.508804    0.062910    0.013459    0.691496    
#> 194: 0.305470    1.135289    3.474652    0.425333    0.060113    0.012996    0.696386    
#> 195: 0.291492    1.137173    3.470249    0.448020    0.052883    0.013046    0.703779    
#> 196: 0.277438    1.138632    3.470932    0.481995    0.054176    0.012307    0.706292    
#> 197: 0.248030    1.146762    3.484536    0.435636    0.066089    0.015686    0.717674    
#> 198: 0.307464    1.129375    3.479529    0.409551    0.054788    0.017041    0.680080    
#> 199: 0.282240    1.104807    3.478640    0.387745    0.062827    0.015893    0.699427    
#> 200: 0.303806    1.110328    3.478878    0.429033    0.055689    0.014669    0.724378    
#> 201: 0.308705    1.113189    3.485317    0.413964    0.050993    0.015830    0.707964    
#> 202: 0.305580    1.114536    3.486865    0.416662    0.050995    0.015965    0.709419    
#> 203: 0.314968    1.114226    3.483837    0.429121    0.051166    0.016424    0.705965    
#> 204: 0.317662    1.109702    3.486126    0.421399    0.053932    0.016530    0.705104    
#> 205: 0.320506    1.112631    3.485998    0.431404    0.055106    0.016601    0.706544    
#> 206: 0.319815    1.117063    3.486442    0.439387    0.053795    0.016126    0.707574    
#> 207: 0.319664    1.118384    3.485418    0.436075    0.054128    0.016050    0.706779    
#> 208: 0.321551    1.121096    3.484692    0.438014    0.054053    0.016121    0.705999    
#> 209: 0.327995    1.118874    3.485133    0.441814    0.055041    0.016145    0.706991    
#> 210: 0.329077    1.117305    3.485987    0.438028    0.054923    0.016125    0.707114    
#> 211: 0.333093    1.117269    3.487979    0.433871    0.054627    0.015905    0.706924    
#> 212: 0.337639    1.115571    3.490084    0.432200    0.054664    0.016058    0.707017    
#> 213: 0.343436    1.111364    3.492103    0.432101    0.055631    0.016230    0.707082    
#> 214: 0.346900    1.109767    3.493412    0.432769    0.056060    0.016224    0.708318    
#> 215: 0.351514    1.109074    3.494769    0.433848    0.056589    0.016306    0.708153    
#> 216: 0.355920    1.108709    3.495022    0.435950    0.056610    0.016209    0.709490    
#> 217: 0.355257    1.109170    3.494900    0.435198    0.056907    0.016044    0.708268    
#> 218: 0.354637    1.110102    3.494808    0.433565    0.057038    0.016084    0.707667    
#> 219: 0.352470    1.110213    3.493377    0.436282    0.056461    0.016264    0.707315    
#> 220: 0.348829    1.110902    3.492669    0.435690    0.056086    0.016625    0.706910    
#> 221: 0.347083    1.110654    3.492755    0.435600    0.055588    0.016563    0.706089    
#> 222: 0.346108    1.110553    3.492194    0.436287    0.055190    0.016656    0.706077    
#> 223: 0.345903    1.110847    3.491943    0.436189    0.054927    0.016694    0.705667    
#> 224: 0.346792    1.111797    3.492049    0.435571    0.055042    0.016525    0.705222    
#> 225: 0.346943    1.110260    3.492736    0.436406    0.055103    0.016398    0.705387    
#> 226: 0.346925    1.108950    3.492828    0.434746    0.055342    0.016354    0.705400    
#> 227: 0.346828    1.108756    3.493575    0.434491    0.055601    0.016407    0.704846    
#> 228: 0.345021    1.109270    3.493017    0.432812    0.055485    0.016641    0.704754    
#> 229: 0.344595    1.109152    3.492874    0.433935    0.055125    0.016662    0.704371    
#> 230: 0.344337    1.108741    3.492766    0.434572    0.054888    0.016591    0.704488    
#> 231: 0.344797    1.109188    3.492830    0.436333    0.054944    0.016592    0.703979    
#> 232: 0.344099    1.109183    3.493025    0.436379    0.054768    0.016611    0.703613    
#> 233: 0.342950    1.108441    3.493310    0.436157    0.054762    0.016681    0.703650    
#> 234: 0.341923    1.108361    3.493312    0.435154    0.054871    0.016657    0.703933    
#> 235: 0.341669    1.107756    3.493259    0.435281    0.054915    0.016572    0.703590    
#> 236: 0.341638    1.107952    3.493332    0.436036    0.054895    0.016544    0.703070    
#> 237: 0.342295    1.107647    3.493385    0.438560    0.054791    0.016522    0.702834    
#> 238: 0.343240    1.107509    3.493650    0.439163    0.054660    0.016511    0.702886    
#> 239: 0.343058    1.107714    3.493593    0.439439    0.054521    0.016442    0.703174    
#> 240: 0.342891    1.107576    3.493773    0.438740    0.054505    0.016307    0.703029    
#> 241: 0.343478    1.106975    3.494208    0.438472    0.054647    0.016255    0.702804    
#> 242: 0.343219    1.106726    3.494209    0.438315    0.054848    0.016195    0.702819    
#> 243: 0.343212    1.106584    3.494328    0.436714    0.054938    0.016190    0.703048    
#> 244: 0.342453    1.106292    3.494265    0.437517    0.054731    0.016190    0.703010    
#> 245: 0.342342    1.105778    3.494330    0.437288    0.054772    0.016199    0.703300    
#> 246: 0.342296    1.105488    3.494351    0.436006    0.054787    0.016163    0.703954    
#> 247: 0.342118    1.105312    3.494540    0.435308    0.054655    0.016101    0.703786    
#> 248: 0.341678    1.105660    3.494557    0.434415    0.054531    0.016013    0.703716    
#> 249: 0.340761    1.106009    3.494416    0.432631    0.054841    0.015922    0.704553    
#> 250: 0.341205    1.106454    3.494305    0.432869    0.055004    0.015871    0.704780    
#> 251: 0.341790    1.107011    3.494354    0.433952    0.054927    0.015836    0.705072    
#> 252: 0.342454    1.107191    3.494850    0.434055    0.054904    0.015737    0.705505    
#> 253: 0.342799    1.107364    3.495027    0.433893    0.054944    0.015723    0.705856    
#> 254: 0.343178    1.107875    3.495281    0.432678    0.054945    0.015717    0.706076    
#> 255: 0.343430    1.108230    3.495536    0.432312    0.054872    0.015725    0.706085    
#> 256: 0.343768    1.107978    3.495679    0.432161    0.054728    0.015749    0.706370    
#> 257: 0.344165    1.107572    3.495816    0.431942    0.054687    0.015728    0.706546    
#> 258: 0.343618    1.107286    3.495875    0.431317    0.054618    0.015701    0.706530    
#> 259: 0.342907    1.107388    3.495767    0.431331    0.054639    0.015735    0.706528    
#> 260: 0.342707    1.107777    3.495634    0.431503    0.054598    0.015712    0.706248    
#> 261: 0.342813    1.107815    3.495704    0.432404    0.054597    0.015693    0.706251    
#> 262: 0.342882    1.108035    3.495768    0.432519    0.054677    0.015693    0.706247    
#> 263: 0.343070    1.108462    3.495769    0.432385    0.054745    0.015676    0.706347    
#> 264: 0.342648    1.108799    3.495632    0.431594    0.054933    0.015641    0.706445    
#> 265: 0.342322    1.109072    3.495553    0.431230    0.055223    0.015618    0.706309    
#> 266: 0.341941    1.109404    3.495441    0.430811    0.055487    0.015550    0.706217    
#> 267: 0.341564    1.109411    3.495371    0.430056    0.055685    0.015497    0.706601    
#> 268: 0.341215    1.109328    3.495146    0.428715    0.055760    0.015440    0.706726    
#> 269: 0.341597    1.109211    3.495019    0.429008    0.055749    0.015413    0.706856    
#> 270: 0.341654    1.109339    3.494806    0.430455    0.055711    0.015389    0.706867    
#> 271: 0.341957    1.109410    3.494655    0.430234    0.055633    0.015394    0.707188    
#> 272: 0.342122    1.109054    3.494612    0.431086    0.055657    0.015410    0.707594    
#> 273: 0.341936    1.109167    3.494578    0.431121    0.055740    0.015423    0.707820    
#> 274: 0.341528    1.109203    3.494627    0.431510    0.055659    0.015407    0.707694    
#> 275: 0.341730    1.109139    3.494543    0.432972    0.055603    0.015401    0.707511    
#> 276: 0.341580    1.109457    3.494676    0.434019    0.055472    0.015486    0.707329    
#> 277: 0.341417    1.110065    3.494679    0.434659    0.055455    0.015602    0.707146    
#> 278: 0.340753    1.110308    3.494623    0.433978    0.055542    0.015633    0.707153    
#> 279: 0.340131    1.110250    3.494510    0.432820    0.055557    0.015666    0.707160    
#> 280: 0.339783    1.110500    3.494511    0.432298    0.055563    0.015684    0.706969    
#> 281: 0.339154    1.110574    3.494415    0.432293    0.055618    0.015660    0.706992    
#> 282: 0.338483    1.110769    3.494230    0.433267    0.055676    0.015672    0.707002    
#> 283: 0.338863    1.110830    3.494314    0.433710    0.055680    0.015691    0.706997    
#> 284: 0.338854    1.110748    3.494319    0.433345    0.055544    0.015697    0.706817    
#> 285: 0.338938    1.110731    3.494190    0.434555    0.055551    0.015684    0.706565    
#> 286: 0.338862    1.110818    3.494013    0.435566    0.055542    0.015710    0.706463    
#> 287: 0.338576    1.111015    3.493934    0.436728    0.055516    0.015735    0.706386    
#> 288: 0.338483    1.110939    3.493809    0.437628    0.055512    0.015716    0.706504    
#> 289: 0.338749    1.110799    3.493823    0.438780    0.055494    0.015679    0.706554    
#> 290: 0.339089    1.110735    3.493823    0.440351    0.055501    0.015667    0.706642    
#> 291: 0.339280    1.110856    3.493907    0.440582    0.055432    0.015643    0.706660    
#> 292: 0.339256    1.110956    3.493951    0.440005    0.055349    0.015621    0.706784    
#> 293: 0.338681    1.111022    3.493855    0.439229    0.055302    0.015613    0.706881    
#> 294: 0.338327    1.111205    3.493699    0.438657    0.055392    0.015611    0.706990    
#> 295: 0.337849    1.110979    3.493564    0.438368    0.055299    0.015632    0.706959    
#> 296: 0.337849    1.110862    3.493625    0.438186    0.055194    0.015682    0.707021    
#> 297: 0.337950    1.110927    3.493624    0.438245    0.055135    0.015739    0.706917    
#> 298: 0.338002    1.110899    3.493661    0.437541    0.055068    0.015788    0.707021    
#> 299: 0.338333    1.110980    3.493791    0.437355    0.055040    0.015804    0.706794    
#> 300: 0.338713    1.110698    3.493995    0.437248    0.055074    0.015772    0.706771    
#> 301: 0.339062    1.110364    3.494131    0.436990    0.055101    0.015762    0.706932    
#> 302: 0.339270    1.110076    3.494241    0.436685    0.055102    0.015765    0.706840    
#> 303: 0.339142    1.110344    3.494210    0.436389    0.055169    0.015768    0.706590    
#> 304: 0.339117    1.110578    3.494070    0.435776    0.055210    0.015765    0.706507    
#> 305: 0.338740    1.110507    3.493933    0.435702    0.055252    0.015796    0.706339    
#> 306: 0.338222    1.110591    3.493686    0.435902    0.055223    0.015804    0.706266    
#> 307: 0.337949    1.110627    3.493454    0.436525    0.055293    0.015797    0.706290    
#> 308: 0.337656    1.110781    3.493228    0.437546    0.055427    0.015790    0.706318    
#> 309: 0.337700    1.110637    3.493121    0.438113    0.055466    0.015770    0.706577    
#> 310: 0.338026    1.110502    3.493042    0.438731    0.055424    0.015778    0.706595    
#> 311: 0.338366    1.110539    3.493039    0.438798    0.055380    0.015794    0.706545    
#> 312: 0.338080    1.110415    3.492915    0.439464    0.055368    0.015801    0.706588    
#> 313: 0.337564    1.110289    3.492798    0.440390    0.055425    0.015796    0.706758    
#> 314: 0.337050    1.110327    3.492739    0.439824    0.055414    0.015780    0.706799    
#> 315: 0.336817    1.110433    3.492702    0.438880    0.055443    0.015790    0.706782    
#> 316: 0.337068    1.110456    3.492698    0.438761    0.055334    0.015808    0.706867    
#> 317: 0.337096    1.110405    3.492881    0.438141    0.055322    0.015801    0.707151    
#> 318: 0.337423    1.110410    3.492921    0.437724    0.055223    0.015783    0.707195    
#> 319: 0.337382    1.110343    3.492998    0.437664    0.055153    0.015759    0.707187    
#> 320: 0.336908    1.110256    3.492910    0.438014    0.055052    0.015741    0.707297    
#> 321: 0.336774    1.110295    3.492795    0.438280    0.054998    0.015699    0.707408    
#> 322: 0.336463    1.110265    3.492639    0.438061    0.054900    0.015676    0.707529    
#> 323: 0.335878    1.110362    3.492522    0.437958    0.054834    0.015684    0.707594    
#> 324: 0.335719    1.110432    3.492594    0.437265    0.054865    0.015673    0.707543    
#> 325: 0.335910    1.110564    3.492594    0.436689    0.054824    0.015667    0.707506    
#> 326: 0.335763    1.110497    3.492538    0.436827    0.054859    0.015650    0.707414    
#> 327: 0.335885    1.110518    3.492595    0.436805    0.054845    0.015622    0.707370    
#> 328: 0.336112    1.110563    3.492694    0.436179    0.054829    0.015621    0.707242    
#> 329: 0.336476    1.110608    3.492831    0.435896    0.054772    0.015608    0.707099    
#> 330: 0.336463    1.110669    3.492920    0.435409    0.054763    0.015623    0.707063    
#> 331: 0.336701    1.110907    3.493000    0.435114    0.054746    0.015644    0.706958    
#> 332: 0.336823    1.110826    3.493127    0.434647    0.054675    0.015674    0.706946    
#> 333: 0.337042    1.110773    3.493136    0.434567    0.054715    0.015698    0.706876    
#> 334: 0.336999    1.110653    3.493076    0.434700    0.054732    0.015683    0.706711    
#> 335: 0.336845    1.110736    3.492982    0.434421    0.054780    0.015647    0.706757    
#> 336: 0.336519    1.111060    3.492936    0.434022    0.054933    0.015619    0.706963    
#> 337: 0.336432    1.111374    3.492766    0.433938    0.054941    0.015600    0.706962    
#> 338: 0.336380    1.111537    3.492746    0.433612    0.054891    0.015576    0.706949    
#> 339: 0.336045    1.111814    3.492636    0.433193    0.054905    0.015561    0.706865    
#> 340: 0.335935    1.111734    3.492615    0.432776    0.054814    0.015570    0.706780    
#> 341: 0.335934    1.111634    3.492639    0.432319    0.054741    0.015582    0.706756    
#> 342: 0.335693    1.111486    3.492551    0.432034    0.054705    0.015591    0.706687    
#> 343: 0.335625    1.111510    3.492549    0.432372    0.054674    0.015614    0.706591    
#> 344: 0.335701    1.111540    3.492593    0.432894    0.054636    0.015626    0.706626    
#> 345: 0.335863    1.111516    3.492599    0.433308    0.054555    0.015639    0.706616    
#> 346: 0.335984    1.111597    3.492530    0.433440    0.054515    0.015631    0.706525    
#> 347: 0.335839    1.111632    3.492360    0.433409    0.054509    0.015626    0.706665    
#> 348: 0.335556    1.111809    3.492268    0.433070    0.054509    0.015618    0.706738    
#> 349: 0.335354    1.111852    3.492175    0.433318    0.054544    0.015594    0.706696    
#> 350: 0.334927    1.111834    3.492093    0.432797    0.054552    0.015570    0.706776    
#> 351: 0.334544    1.112037    3.491998    0.432318    0.054578    0.015559    0.706783    
#> 352: 0.333973    1.112188    3.491943    0.431934    0.054565    0.015588    0.706858    
#> 353: 0.334001    1.112348    3.491964    0.431562    0.054572    0.015610    0.706893    
#> 354: 0.333968    1.112347    3.491914    0.431324    0.054585    0.015628    0.706852    
#> 355: 0.334314    1.112185    3.492041    0.431196    0.054507    0.015670    0.706788    
#> 356: 0.334409    1.112118    3.492114    0.431125    0.054441    0.015678    0.706841    
#> 357: 0.334723    1.112135    3.492196    0.430747    0.054377    0.015695    0.706835    
#> 358: 0.334788    1.112182    3.492291    0.430711    0.054351    0.015687    0.706747    
#> 359: 0.334770    1.112237    3.492322    0.430745    0.054331    0.015663    0.706662    
#> 360: 0.334645    1.112258    3.492269    0.430870    0.054292    0.015628    0.706543    
#> 361: 0.334648    1.112271    3.492245    0.430830    0.054347    0.015607    0.706405    
#> 362: 0.334835    1.112284    3.492194    0.430820    0.054370    0.015590    0.706224    
#> 363: 0.334914    1.112140    3.492228    0.430702    0.054319    0.015578    0.706169    
#> 364: 0.334925    1.112185    3.492236    0.430677    0.054302    0.015569    0.706244    
#> 365: 0.335120    1.112058    3.492297    0.430863    0.054319    0.015545    0.706359    
#> 366: 0.335318    1.112121    3.492240    0.431380    0.054282    0.015522    0.706530    
#> 367: 0.335427    1.112174    3.492235    0.431383    0.054270    0.015504    0.706476    
#> 368: 0.335566    1.112244    3.492229    0.431393    0.054284    0.015482    0.706376    
#> 369: 0.335485    1.112199    3.492209    0.431247    0.054254    0.015471    0.706401    
#> 370: 0.335312    1.112304    3.492176    0.430930    0.054314    0.015449    0.706393    
#> 371: 0.335146    1.112313    3.492047    0.431009    0.054314    0.015441    0.706367    
#> 372: 0.335057    1.112392    3.492000    0.431243    0.054318    0.015413    0.706454    
#> 373: 0.334711    1.112570    3.491890    0.431382    0.054362    0.015399    0.706526    
#> 374: 0.334792    1.112568    3.491839    0.432079    0.054407    0.015382    0.706425    
#> 375: 0.334796    1.112575    3.491806    0.432452    0.054489    0.015376    0.706383    
#> 376: 0.334700    1.112757    3.491751    0.432528    0.054564    0.015363    0.706305    
#> 377: 0.334476    1.112897    3.491698    0.432434    0.054511    0.015357    0.706264    
#> 378: 0.334221    1.112912    3.491628    0.432162    0.054413    0.015364    0.706322    
#> 379: 0.334162    1.112759    3.491693    0.431805    0.054359    0.015381    0.706248    
#> 380: 0.334092    1.112679    3.491691    0.431882    0.054278    0.015376    0.706256    
#> 381: 0.333947    1.112549    3.491719    0.431690    0.054208    0.015384    0.706183    
#> 382: 0.334024    1.112544    3.491756    0.431835    0.054106    0.015387    0.706090    
#> 383: 0.334090    1.112473    3.491790    0.431617    0.054050    0.015378    0.706117    
#> 384: 0.333907    1.112391    3.491771    0.431533    0.054056    0.015362    0.706158    
#> 385: 0.333875    1.112306    3.491807    0.431063    0.054059    0.015360    0.706129    
#> 386: 0.334159    1.112430    3.491872    0.430927    0.054099    0.015368    0.706084    
#> 387: 0.334457    1.112495    3.491992    0.431112    0.054082    0.015375    0.705955    
#> 388: 0.334681    1.112528    3.492038    0.431382    0.054093    0.015372    0.705873    
#> 389: 0.334800    1.112402    3.492032    0.431766    0.054132    0.015365    0.705862    
#> 390: 0.335034    1.112366    3.492017    0.432302    0.054119    0.015363    0.705801    
#> 391: 0.335327    1.112305    3.492028    0.432461    0.054122    0.015344    0.705752    
#> 392: 0.335502    1.112259    3.492128    0.432364    0.054156    0.015344    0.705812    
#> 393: 0.335551    1.112111    3.492181    0.432081    0.054144    0.015351    0.705842    
#> 394: 0.335807    1.112074    3.492204    0.432227    0.054161    0.015331    0.705850    
#> 395: 0.335985    1.112074    3.492220    0.432264    0.054199    0.015325    0.705824    
#> 396: 0.336203    1.112054    3.492258    0.432369    0.054180    0.015325    0.705793    
#> 397: 0.336383    1.112024    3.492332    0.432413    0.054191    0.015307    0.705786    
#> 398: 0.336638    1.111888    3.492426    0.432915    0.054165    0.015308    0.705745    
#> 399: 0.336921    1.111794    3.492581    0.433042    0.054130    0.015314    0.705706    
#> 400: 0.337075    1.111755    3.492668    0.432614    0.054116    0.015315    0.705708    
#> 401: 0.337212    1.111733    3.492707    0.432373    0.054143    0.015305    0.705753    
#> 402: 0.337331    1.111764    3.492750    0.432253    0.054137    0.015302    0.705799    
#> 403: 0.337388    1.111721    3.492765    0.432040    0.054115    0.015311    0.705853    
#> 404: 0.337258    1.111820    3.492647    0.431950    0.054108    0.015308    0.705941    
#> 405: 0.337125    1.111870    3.492619    0.432044    0.054157    0.015296    0.706005    
#> 406: 0.337171    1.111944    3.492662    0.431759    0.054233    0.015278    0.706119    
#> 407: 0.337190    1.111941    3.492747    0.431305    0.054252    0.015272    0.706149    
#> 408: 0.337443    1.111995    3.492780    0.431098    0.054277    0.015270    0.706132    
#> 409: 0.337325    1.112008    3.492774    0.430766    0.054237    0.015276    0.706048    
#> 410: 0.337166    1.112038    3.492699    0.430520    0.054173    0.015277    0.705993    
#> 411: 0.337111    1.111945    3.492628    0.430538    0.054113    0.015289    0.705992    
#> 412: 0.337021    1.111972    3.492612    0.430406    0.054041    0.015313    0.706012    
#> 413: 0.336948    1.111978    3.492583    0.430099    0.054012    0.015332    0.706023    
#> 414: 0.336655    1.112016    3.492546    0.430185    0.053955    0.015339    0.706026    
#> 415: 0.336722    1.112048    3.492541    0.429981    0.053921    0.015344    0.705950    
#> 416: 0.336880    1.112064    3.492587    0.429658    0.053897    0.015343    0.705943    
#> 417: 0.337031    1.111967    3.492623    0.429604    0.053853    0.015354    0.705914    
#> 418: 0.337054    1.111919    3.492669    0.429708    0.053808    0.015353    0.705873    
#> 419: 0.337099    1.112151    3.492676    0.429878    0.053817    0.015365    0.705806    
#> 420: 0.337096    1.112373    3.492636    0.429892    0.053778    0.015370    0.705743    
#> 421: 0.336959    1.112489    3.492615    0.430010    0.053725    0.015365    0.705689    
#> 422: 0.336949    1.112533    3.492570    0.429848    0.053717    0.015355    0.705627    
#> 423: 0.336988    1.112538    3.492560    0.429989    0.053701    0.015358    0.705697    
#> 424: 0.336783    1.112571    3.492438    0.430250    0.053685    0.015350    0.705691    
#> 425: 0.336714    1.112732    3.492371    0.430626    0.053749    0.015337    0.705703    
#> 426: 0.336810    1.112898    3.492375    0.430885    0.053820    0.015337    0.705646    
#> 427: 0.336717    1.112930    3.492359    0.431148    0.053830    0.015346    0.705540    
#> 428: 0.336602    1.112988    3.492337    0.431070    0.053772    0.015356    0.705587    
#> 429: 0.336571    1.112983    3.492349    0.431148    0.053711    0.015376    0.705536    
#> 430: 0.336560    1.112953    3.492365    0.431232    0.053684    0.015395    0.705491    
#> 431: 0.336680    1.112905    3.492403    0.431107    0.053683    0.015400    0.705435    
#> 432: 0.336788    1.112938    3.492432    0.431076    0.053682    0.015400    0.705370    
#> 433: 0.336919    1.113011    3.492445    0.431124    0.053732    0.015383    0.705432    
#> 434: 0.336780    1.112915    3.492445    0.430804    0.053720    0.015378    0.705504    
#> 435: 0.336842    1.112887    3.492428    0.430873    0.053711    0.015379    0.705434    
#> 436: 0.336809    1.112865    3.492414    0.430607    0.053749    0.015371    0.705423    
#> 437: 0.336808    1.112827    3.492384    0.430559    0.053765    0.015369    0.705422    
#> 438: 0.336835    1.112922    3.492381    0.430837    0.053750    0.015363    0.705370    
#> 439: 0.336764    1.113078    3.492374    0.430612    0.053784    0.015368    0.705311    
#> 440: 0.336602    1.113169    3.492350    0.430585    0.053784    0.015368    0.705269    
#> 441: 0.336520    1.113157    3.492373    0.430384    0.053813    0.015370    0.705250    
#> 442: 0.336361    1.113190    3.492369    0.430329    0.053801    0.015364    0.705223    
#> 443: 0.336289    1.113245    3.492342    0.430329    0.053800    0.015374    0.705135    
#> 444: 0.336247    1.113292    3.492281    0.430287    0.053808    0.015389    0.705096    
#> 445: 0.336014    1.113301    3.492202    0.430120    0.053803    0.015406    0.705175    
#> 446: 0.335873    1.113380    3.492137    0.430200    0.053795    0.015418    0.705163    
#> 447: 0.335774    1.113493    3.492101    0.430027    0.053809    0.015429    0.705173    
#> 448: 0.335585    1.113474    3.492089    0.430016    0.053817    0.015442    0.705151    
#> 449: 0.335548    1.113571    3.492130    0.429980    0.053862    0.015451    0.705132    
#> 450: 0.335612    1.113607    3.492147    0.429942    0.053900    0.015471    0.705165    
#> 451: 0.335567    1.113635    3.492141    0.429778    0.053915    0.015478    0.705168    
#> 452: 0.335455    1.113614    3.492128    0.429641    0.053903    0.015468    0.705188    
#> 453: 0.335470    1.113578    3.492147    0.429671    0.053862    0.015465    0.705234    
#> 454: 0.335429    1.113637    3.492182    0.429511    0.053906    0.015468    0.705203    
#> 455: 0.335357    1.113588    3.492188    0.429418    0.053895    0.015484    0.705222    
#> 456: 0.335294    1.113536    3.492153    0.429480    0.053918    0.015493    0.705244    
#> 457: 0.335200    1.113537    3.492153    0.429455    0.053902    0.015518    0.705172    
#> 458: 0.335163    1.113650    3.492155    0.429528    0.053900    0.015539    0.705135    
#> 459: 0.334862    1.113823    3.492098    0.429530    0.053899    0.015551    0.705151    
#> 460: 0.334610    1.113881    3.492021    0.429316    0.053910    0.015560    0.705118    
#> 461: 0.334441    1.113984    3.491970    0.429066    0.053914    0.015561    0.705124    
#> 462: 0.334374    1.114128    3.491959    0.429173    0.053921    0.015559    0.705046    
#> 463: 0.334446    1.114204    3.491984    0.429300    0.053927    0.015567    0.704967    
#> 464: 0.334556    1.114262    3.491984    0.429454    0.053937    0.015575    0.704868    
#> 465: 0.334647    1.114102    3.492022    0.429649    0.053953    0.015573    0.704806    
#> 466: 0.334746    1.114075    3.492047    0.429681    0.053957    0.015575    0.704848    
#> 467: 0.334734    1.113993    3.492058    0.429684    0.053926    0.015589    0.704751    
#> 468: 0.334881    1.113996    3.492118    0.429850    0.053924    0.015607    0.704760    
#> 469: 0.335041    1.113998    3.492219    0.429574    0.053987    0.015629    0.704803    
#> 470: 0.334945    1.114086    3.492201    0.429535    0.054035    0.015639    0.704819    
#> 471: 0.334743    1.114099    3.492147    0.429455    0.054020    0.015645    0.704800    
#> 472: 0.334668    1.114192    3.492079    0.429320    0.054062    0.015645    0.704796    
#> 473: 0.334573    1.114233    3.492028    0.429200    0.054060    0.015643    0.704752    
#> 474: 0.334503    1.114285    3.491953    0.429338    0.054098    0.015635    0.704817    
#> 475: 0.334509    1.114433    3.491890    0.429605    0.054147    0.015628    0.704803    
#> 476: 0.334507    1.114522    3.491826    0.429865    0.054212    0.015619    0.704821    
#> 477: 0.334384    1.114575    3.491786    0.429738    0.054265    0.015611    0.704777    
#> 478: 0.334262    1.114573    3.491783    0.429561    0.054313    0.015601    0.704805    
#> 479: 0.334339    1.114663    3.491806    0.429524    0.054379    0.015595    0.704795    
#> 480: 0.334393    1.114685    3.491796    0.429588    0.054434    0.015603    0.704845    
#> 481: 0.334333    1.114711    3.491762    0.429627    0.054462    0.015608    0.704825    
#> 482: 0.334384    1.114706    3.491748    0.429444    0.054468    0.015628    0.704860    
#> 483: 0.334334    1.114630    3.491743    0.429277    0.054458    0.015630    0.704940    
#> 484: 0.334320    1.114475    3.491784    0.429332    0.054402    0.015640    0.704996    
#> 485: 0.334272    1.114525    3.491771    0.429131    0.054395    0.015640    0.705083    
#> 486: 0.334187    1.114569    3.491774    0.428999    0.054420    0.015637    0.705100    
#> 487: 0.334247    1.114674    3.491846    0.428822    0.054429    0.015639    0.705111    
#> 488: 0.334216    1.114579    3.491914    0.428589    0.054446    0.015632    0.705122    
#> 489: 0.334295    1.114509    3.491940    0.428533    0.054441    0.015633    0.705191    
#> 490: 0.334427    1.114543    3.491968    0.428575    0.054479    0.015628    0.705149    
#> 491: 0.334441    1.114621    3.492003    0.428670    0.054502    0.015621    0.705149    
#> 492: 0.334373    1.114726    3.492006    0.428789    0.054524    0.015606    0.705270    
#> 493: 0.334335    1.114745    3.492006    0.428738    0.054587    0.015602    0.705296    
#> 494: 0.334365    1.114822    3.491970    0.428637    0.054620    0.015606    0.705248    
#> 495: 0.334435    1.114858    3.491970    0.428727    0.054597    0.015596    0.705198    
#> 496: 0.334516    1.114938    3.491920    0.428952    0.054625    0.015587    0.705150    
#> 497: 0.334401    1.114918    3.491883    0.429028    0.054602    0.015576    0.705178    
#> 498: 0.334355    1.114887    3.491854    0.429173    0.054643    0.015566    0.705123    
#> 499: 0.334329    1.114937    3.491815    0.428892    0.054633    0.015561    0.705130    
#> 500: 0.334308    1.114872    3.491809    0.428699    0.054624    0.015558    0.705157    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.321167    0.965573    3.442328    0.392401    0.072521    0.016800    1.702904    
#> 002: 0.451719    1.016499    3.478587    0.372781    0.068895    0.015960    1.194804    
#> 003: 0.635178    0.974154    3.510822    0.354142    0.065450    0.015162    0.884536    
#> 004: 0.624620    1.012289    3.514987    0.336435    0.062178    0.014404    0.787556    
#> 005: 0.715152    1.014717    3.514129    0.399488    0.059069    0.013684    0.726083    
#> 006: 0.670099    1.025529    3.498523    0.379514    0.056116    0.013000    0.707160    
#> 007: 0.608071    1.040961    3.481891    0.431349    0.053310    0.012350    0.728253    
#> 008: 0.622380    1.025201    3.487459    0.447446    0.050644    0.011732    0.717541    
#> 009: 0.588177    1.011253    3.485390    0.425073    0.048112    0.011146    0.731451    
#> 010: 0.615018    1.009634    3.488638    0.403820    0.045706    0.010588    0.745275    
#> 011: 0.634858    1.020825    3.499043    0.392486    0.047132    0.010059    0.729850    
#> 012: 0.671714    1.025803    3.487361    0.486550    0.044775    0.009556    0.722347    
#> 013: 0.598394    1.034531    3.473373    0.559011    0.054635    0.009078    0.722644    
#> 014: 0.644399    1.051331    3.482830    0.531060    0.051903    0.008624    0.738305    
#> 015: 0.669606    1.035624    3.509448    0.504507    0.049796    0.009524    0.717922    
#> 016: 0.664929    1.046536    3.501233    0.479282    0.047306    0.010105    0.718136    
#> 017: 0.633048    1.050135    3.497755    0.488790    0.044941    0.009600    0.717788    
#> 018: 0.675626    1.056213    3.480055    0.464351    0.044310    0.009120    0.742299    
#> 019: 0.606312    1.049976    3.480706    0.441133    0.046122    0.008664    0.725571    
#> 020: 0.662981    1.042322    3.487624    0.434150    0.045633    0.008230    0.724082    
#> 021: 0.660946    1.035690    3.490517    0.412443    0.043352    0.007819    0.724629    
#> 022: 0.616195    1.033621    3.495123    0.391821    0.045069    0.007428    0.727162    
#> 023: 0.726067    1.036826    3.513366    0.372230    0.042816    0.007938    0.754502    
#> 024: 0.682103    1.054949    3.507725    0.361447    0.040675    0.007777    0.739894    
#> 025: 0.649545    1.031441    3.499477    0.383969    0.045555    0.007388    0.739404    
#> 026: 0.616977    1.059319    3.489247    0.424100    0.051192    0.007997    0.738453    
#> 027: 0.614430    1.081661    3.482104    0.443606    0.048632    0.007793    0.732488    
#> 028: 0.677215    1.056580    3.494846    0.425742    0.046201    0.007413    0.703937    
#> 029: 0.658197    1.037836    3.487627    0.404454    0.047560    0.007042    0.735780    
#> 030: 0.670464    1.052439    3.492396    0.440997    0.048113    0.006690    0.724322    
#> 031: 0.625122    1.044086    3.497622    0.418947    0.048753    0.008423    0.718508    
#> 032: 0.644136    1.035145    3.509624    0.398000    0.046315    0.008002    0.719893    
#> 033: 0.606034    1.036754    3.490894    0.393139    0.043999    0.007602    0.718834    
#> 034: 0.629345    1.041302    3.487209    0.397676    0.053378    0.007222    0.729343    
#> 035: 0.590908    1.041108    3.482391    0.377792    0.054323    0.006861    0.726985    
#> 036: 0.610767    1.049836    3.484315    0.358902    0.051607    0.006518    0.736225    
#> 037: 0.620746    1.054091    3.490947    0.391991    0.049027    0.006894    0.753258    
#> 038: 0.648034    1.038843    3.483748    0.406821    0.046576    0.006549    0.734018    
#> 039: 0.652142    1.048363    3.488393    0.386480    0.045211    0.007507    0.719263    
#> 040: 0.606345    1.058226    3.487304    0.383308    0.042951    0.007132    0.722925    
#> 041: 0.598272    1.047562    3.488881    0.388793    0.049425    0.006775    0.705997    
#> 042: 0.659577    1.026735    3.486325    0.444387    0.051092    0.006503    0.714608    
#> 043: 0.610768    1.048983    3.477497    0.422168    0.048537    0.007501    0.719102    
#> 044: 0.602329    1.059731    3.478325    0.401496    0.046110    0.008395    0.720300    
#> 045: 0.586231    1.079152    3.469314    0.399023    0.043805    0.007976    0.721024    
#> 046: 0.592867    1.069584    3.465272    0.399855    0.041615    0.007577    0.716426    
#> 047: 0.605345    1.054331    3.465509    0.391205    0.043644    0.007198    0.721250    
#> 048: 0.594724    1.047567    3.478088    0.371645    0.042163    0.006838    0.729355    
#> 049: 0.611457    1.034799    3.491227    0.353063    0.050687    0.006496    0.734463    
#> 050: 0.646605    1.032153    3.486031    0.356452    0.050068    0.006171    0.764912    
#> 051: 0.605110    1.046614    3.486452    0.349216    0.052257    0.006969    0.761470    
#> 052: 0.594651    1.045286    3.489561    0.331755    0.051382    0.007078    0.755936    
#> 053: 0.650088    1.027819    3.494420    0.407329    0.049362    0.007052    0.729124    
#> 054: 0.618809    1.033919    3.494115    0.386962    0.049815    0.009089    0.721926    
#> 055: 0.633010    1.037076    3.484856    0.420683    0.053837    0.008705    0.720655    
#> 056: 0.645424    1.025429    3.493670    0.444978    0.051145    0.009190    0.724203    
#> 057: 0.622260    1.041430    3.487594    0.422729    0.050716    0.009660    0.731054    
#> 058: 0.658674    1.044601    3.488476    0.424784    0.048180    0.009177    0.728542    
#> 059: 0.636747    1.017780    3.487467    0.458992    0.045771    0.008718    0.741505    
#> 060: 0.643785    1.006561    3.498277    0.464794    0.049008    0.008282    0.751504    
#> 061: 0.701537    1.014456    3.501636    0.441554    0.057158    0.008789    0.736716    
#> 062: 0.632931    1.037865    3.505010    0.419476    0.071145    0.008350    0.743954    
#> 063: 0.639393    1.021755    3.490362    0.446741    0.067588    0.008740    0.736704    
#> 064: 0.615540    1.055183    3.489196    0.424404    0.064208    0.008303    0.721796    
#> 065: 0.677794    1.046460    3.477352    0.427380    0.060998    0.007888    0.719542    
#> 066: 0.639277    1.065978    3.477217    0.406011    0.057948    0.008009    0.716160    
#> 067: 0.610028    1.055850    3.477304    0.385710    0.055051    0.009261    0.712218    
#> 068: 0.601397    1.043176    3.491281    0.366425    0.052298    0.010968    0.730708    
#> 069: 0.563446    1.060079    3.468133    0.348104    0.049683    0.010920    0.754558    
#> 070: 0.605991    1.052614    3.486823    0.368821    0.051267    0.010374    0.735216    
#> 071: 0.593951    1.087696    3.465622    0.411789    0.048704    0.009856    0.754590    
#> 072: 0.594393    1.061229    3.464607    0.466579    0.049278    0.009363    0.713626    
#> 073: 0.635300    1.059369    3.488839    0.466813    0.050864    0.008895    0.697643    
#> 074: 0.630579    1.040187    3.490113    0.443472    0.051092    0.008502    0.723028    
#> 075: 0.675964    1.031731    3.506903    0.489377    0.048538    0.008760    0.714447    
#> 076: 0.690467    1.047843    3.508050    0.496944    0.046111    0.008322    0.737419    
#> 077: 0.715200    1.027807    3.504215    0.512376    0.043805    0.008819    0.708538    
#> 078: 0.662588    1.027391    3.501293    0.486757    0.048770    0.009967    0.698039    
#> 079: 0.690177    1.054132    3.504080    0.534925    0.059001    0.009469    0.710470    
#> 080: 0.656521    1.027161    3.500851    0.508179    0.064949    0.010467    0.744122    
#> 081: 0.656115    1.042531    3.499130    0.482770    0.061702    0.011326    0.720162    
#> 082: 0.651297    1.035306    3.510175    0.458631    0.058617    0.010760    0.764515    
#> 083: 0.708564    1.044902    3.512959    0.525815    0.056090    0.010222    0.743515    
#> 084: 0.696106    1.050124    3.498681    0.499743    0.053286    0.009711    0.730709    
#> 085: 0.639539    1.039079    3.508416    0.474756    0.055030    0.009225    0.737089    
#> 086: 0.644299    1.032916    3.501648    0.451018    0.052279    0.008764    0.756813    
#> 087: 0.658591    1.034125    3.495451    0.428467    0.049665    0.008326    0.749608    
#> 088: 0.567294    1.046256    3.483095    0.407044    0.047698    0.007909    0.729202    
#> 089: 0.627106    1.063181    3.478943    0.386692    0.057433    0.007514    0.743650    
#> 090: 0.589614    1.053711    3.482048    0.367357    0.054562    0.007138    0.725955    
#> 091: 0.607097    1.034237    3.481619    0.371509    0.051834    0.007208    0.715375    
#> 092: 0.602097    1.055282    3.473671    0.402018    0.049587    0.009433    0.714553    
#> 093: 0.558379    1.038355    3.473277    0.381917    0.049787    0.009241    0.716022    
#> 094: 0.580450    1.059872    3.469098    0.362821    0.059297    0.010574    0.726423    
#> 095: 0.614028    1.065629    3.479501    0.401458    0.056332    0.010045    0.734976    
#> 096: 0.584223    1.066391    3.473642    0.428314    0.053515    0.009543    0.724954    
#> 097: 0.642349    1.078093    3.480008    0.485856    0.050840    0.009066    0.717504    
#> 098: 0.630886    1.092668    3.485121    0.461563    0.048298    0.008613    0.732986    
#> 099: 0.579099    1.046768    3.479216    0.438485    0.045883    0.008182    0.732343    
#> 100: 0.597190    1.049296    3.470424    0.426815    0.043589    0.007773    0.716700    
#> 101: 0.544643    1.043557    3.456568    0.408316    0.041409    0.007384    0.729074    
#> 102: 0.565428    1.042873    3.449642    0.445368    0.045563    0.007015    0.724654    
#> 103: 0.586153    1.061906    3.462578    0.423099    0.047047    0.006664    0.724555    
#> 104: 0.575355    1.047554    3.475280    0.401944    0.045441    0.006331    0.749275    
#> 105: 0.579274    1.057328    3.479878    0.381847    0.053582    0.006015    0.739244    
#> 106: 0.582836    1.060501    3.473580    0.448889    0.052862    0.005714    0.728020    
#> 107: 0.647475    1.065676    3.473541    0.442685    0.050219    0.006333    0.744759    
#> 108: 0.605500    1.054670    3.473484    0.420551    0.047708    0.006070    0.740310    
#> 109: 0.589440    1.052297    3.481093    0.403970    0.045322    0.006610    0.743266    
#> 110: 0.626079    1.049956    3.474690    0.402704    0.050732    0.006279    0.716221    
#> 111: 0.615750    1.060515    3.472721    0.424347    0.052093    0.005965    0.708881    
#> 112: 0.595715    1.045558    3.471762    0.403129    0.069040    0.005667    0.710367    
#> 113: 0.601136    1.061225    3.477133    0.382973    0.067561    0.005384    0.722826    
#> 114: 0.611207    1.064738    3.480770    0.363824    0.066256    0.005143    0.728319    
#> 115: 0.607757    1.031906    3.473135    0.376709    0.067875    0.004886    0.756929    
#> 116: 0.609208    1.047939    3.480832    0.371138    0.064482    0.004641    0.749588    
#> 117: 0.597775    1.080111    3.478887    0.403225    0.066077    0.004409    0.718135    
#> 118: 0.631529    1.063437    3.477617    0.383064    0.062773    0.004189    0.722102    
#> 119: 0.593321    1.048021    3.475818    0.394547    0.059634    0.004898    0.734843    
#> 120: 0.596835    1.052822    3.477860    0.477945    0.056653    0.004950    0.728764    
#> 121: 0.611474    1.080133    3.474205    0.454048    0.053820    0.005225    0.723513    
#> 122: 0.601651    1.042199    3.478252    0.431346    0.051129    0.005242    0.723673    
#> 123: 0.628853    1.067741    3.478090    0.409778    0.048573    0.005582    0.739552    
#> 124: 0.620035    1.094274    3.476300    0.412956    0.046144    0.006603    0.726999    
#> 125: 0.605107    1.095598    3.465802    0.433076    0.043837    0.006427    0.703073    
#> 126: 0.562040    1.096362    3.455980    0.411423    0.041645    0.006798    0.730773    
#> 127: 0.601813    1.071821    3.458585    0.408538    0.040967    0.006458    0.737379    
#> 128: 0.597510    1.061987    3.469403    0.416726    0.048192    0.006135    0.721884    
#> 129: 0.636147    1.059864    3.480840    0.419602    0.061468    0.005828    0.722333    
#> 130: 0.682438    1.073016    3.488436    0.413688    0.058395    0.005537    0.711730    
#> 131: 0.647186    1.045726    3.482289    0.426253    0.055475    0.006400    0.723454    
#> 132: 0.617369    1.064861    3.472987    0.435415    0.052701    0.006737    0.716547    
#> 133: 0.610493    1.060453    3.472451    0.413645    0.058122    0.006543    0.729482    
#> 134: 0.624992    1.047993    3.488020    0.422302    0.055216    0.006802    0.720369    
#> 135: 0.628998    1.034354    3.490775    0.402359    0.061236    0.006844    0.731207    
#> 136: 0.623850    1.029822    3.487976    0.430623    0.058174    0.006502    0.724237    
#> 137: 0.648046    1.021080    3.492208    0.484977    0.055266    0.006177    0.728659    
#> 138: 0.622489    1.057519    3.477606    0.490941    0.057901    0.005868    0.720696    
#> 139: 0.619653    1.058890    3.477168    0.542522    0.055095    0.005863    0.710996    
#> 140: 0.620566    1.075437    3.482335    0.515396    0.059302    0.005569    0.728957    
#> 141: 0.644046    1.045705    3.496372    0.489626    0.072365    0.005291    0.738824    
#> 142: 0.690786    1.027007    3.502078    0.501755    0.069418    0.005026    0.745390    
#> 143: 0.660591    1.074581    3.497005    0.503395    0.065947    0.005301    0.752712    
#> 144: 0.648258    1.060657    3.498162    0.478225    0.062650    0.005418    0.743790    
#> 145: 0.632846    1.048661    3.490435    0.454314    0.059525    0.006127    0.715191    
#> 146: 0.642982    1.050290    3.492308    0.510888    0.057497    0.006956    0.723317    
#> 147: 0.605072    1.024168    3.488395    0.485344    0.054623    0.007617    0.705715    
#> 148: 0.615169    1.048753    3.499717    0.461076    0.051891    0.008232    0.705159    
#> 149: 0.590412    1.043692    3.485364    0.438023    0.055506    0.008111    0.727742    
#> 150: 0.634610    1.046550    3.485196    0.416121    0.063964    0.007705    0.718752    
#> 151: 0.571264    1.057972    3.475249    0.395315    0.062316    0.007320    0.737086    
#> 152: 0.543960    1.065494    3.477535    0.317969    0.051958    0.006211    0.727367    
#> 153: 0.563292    1.073222    3.475314    0.333826    0.050697    0.005757    0.746942    
#> 154: 0.614285    1.074339    3.481052    0.314901    0.048405    0.005696    0.756237    
#> 155: 0.589397    1.049924    3.481704    0.349873    0.056380    0.004507    0.737450    
#> 156: 0.596964    1.066182    3.491549    0.337239    0.057239    0.005669    0.746536    
#> 157: 0.637064    1.050364    3.493489    0.322463    0.064494    0.006184    0.742066    
#> 158: 0.651976    1.070076    3.489177    0.367146    0.056786    0.006072    0.730259    
#> 159: 0.586185    1.084906    3.477218    0.380220    0.045894    0.005988    0.733868    
#> 160: 0.647453    1.048413    3.488855    0.368014    0.051314    0.006357    0.735360    
#> 161: 0.622498    1.044477    3.484789    0.372293    0.063496    0.006326    0.730073    
#> 162: 0.606675    1.058635    3.478703    0.325551    0.063235    0.006382    0.742873    
#> 163: 0.619635    1.036906    3.483119    0.325511    0.062121    0.005683    0.739293    
#> 164: 0.587932    1.049861    3.479275    0.334568    0.055680    0.005849    0.741877    
#> 165: 0.639329    1.031969    3.491536    0.377199    0.052641    0.005728    0.742933    
#> 166: 0.644142    1.071061    3.489517    0.381823    0.054353    0.004819    0.737476    
#> 167: 0.647974    1.065878    3.495692    0.390531    0.049501    0.004147    0.747714    
#> 168: 0.676661    1.067020    3.498318    0.456214    0.052890    0.004579    0.728513    
#> 169: 0.676234    1.078150    3.495037    0.490574    0.056880    0.005497    0.739996    
#> 170: 0.644807    1.037290    3.494335    0.402689    0.051459    0.004577    0.746624    
#> 171: 0.642313    1.047950    3.492189    0.416091    0.054094    0.004607    0.714278    
#> 172: 0.611900    1.065069    3.494350    0.396148    0.051308    0.004313    0.707438    
#> 173: 0.607959    1.057372    3.485668    0.359225    0.054663    0.005484    0.717488    
#> 174: 0.628989    1.039964    3.491399    0.380169    0.043092    0.005716    0.717767    
#> 175: 0.631693    1.042980    3.481519    0.428386    0.050954    0.005732    0.730366    
#> 176: 0.578919    1.069954    3.478843    0.350057    0.049460    0.005145    0.721501    
#> 177: 0.637065    1.067433    3.481729    0.391196    0.041744    0.005292    0.722125    
#> 178: 0.632608    1.050624    3.483324    0.419828    0.042563    0.005651    0.720132    
#> 179: 0.657067    1.063032    3.483439    0.471361    0.049515    0.005905    0.723185    
#> 180: 0.605007    1.048522    3.487637    0.380668    0.045666    0.007768    0.713576    
#> 181: 0.601352    1.041209    3.462696    0.381577    0.047629    0.007959    0.703111    
#> 182: 0.612366    1.067140    3.460327    0.407643    0.054387    0.006430    0.708939    
#> 183: 0.566609    1.081244    3.452474    0.347287    0.041745    0.006264    0.718007    
#> 184: 0.532111    1.071279    3.454771    0.368672    0.039434    0.005723    0.738247    
#> 185: 0.555185    1.092862    3.452042    0.414187    0.039181    0.007665    0.729353    
#> 186: 0.533922    1.096777    3.450023    0.431699    0.036740    0.007516    0.738460    
#> 187: 0.564062    1.059584    3.467300    0.402308    0.040015    0.006870    0.729256    
#> 188: 0.550953    1.072327    3.466971    0.434912    0.044410    0.008677    0.743201    
#> 189: 0.604769    1.087654    3.479559    0.370039    0.042334    0.009341    0.732990    
#> 190: 0.628410    1.067846    3.489042    0.474350    0.036872    0.008320    0.733526    
#> 191: 0.582282    1.078108    3.465789    0.361351    0.037973    0.006218    0.732656    
#> 192: 0.553022    1.067367    3.466825    0.350358    0.032076    0.005000    0.742682    
#> 193: 0.582057    1.086980    3.463912    0.331073    0.037808    0.003901    0.744817    
#> 194: 0.537551    1.068737    3.453765    0.343145    0.047468    0.004422    0.743569    
#> 195: 0.530678    1.076730    3.448228    0.343888    0.041063    0.004011    0.757161    
#> 196: 0.529321    1.084595    3.457457    0.311736    0.042959    0.004635    0.790669    
#> 197: 0.557125    1.088521    3.475647    0.317599    0.053634    0.004995    0.750475    
#> 198: 0.607614    1.062947    3.463431    0.303971    0.054010    0.005628    0.734875    
#> 199: 0.548172    1.059965    3.469441    0.328058    0.053417    0.005174    0.733027    
#> 200: 0.554061    1.063385    3.469718    0.369053    0.059375    0.004503    0.719057    
#> 201: 0.561195    1.059588    3.468890    0.388551    0.059760    0.005143    0.714734    
#> 202: 0.559396    1.059700    3.466981    0.397331    0.055810    0.005375    0.720497    
#> 203: 0.577499    1.060657    3.465449    0.429885    0.054978    0.005908    0.718953    
#> 204: 0.584145    1.058162    3.466820    0.430391    0.055472    0.005908    0.721402    
#> 205: 0.588503    1.063027    3.468813    0.426048    0.055391    0.005825    0.723969    
#> 206: 0.591459    1.066489    3.470856    0.423625    0.056083    0.005768    0.728561    
#> 207: 0.594697    1.065745    3.471498    0.427369    0.055147    0.005528    0.728691    
#> 208: 0.597018    1.065470    3.472032    0.423353    0.053842    0.005486    0.727617    
#> 209: 0.600487    1.062441    3.473251    0.418231    0.053425    0.005468    0.727140    
#> 210: 0.604474    1.058636    3.475120    0.419387    0.054111    0.005434    0.725720    
#> 211: 0.609178    1.058378    3.476436    0.419907    0.054535    0.005295    0.724045    
#> 212: 0.611680    1.057455    3.477327    0.418892    0.054075    0.005326    0.723055    
#> 213: 0.613328    1.055227    3.477883    0.411738    0.053190    0.005420    0.723956    
#> 214: 0.614949    1.054871    3.478188    0.405484    0.052782    0.005391    0.724583    
#> 215: 0.612458    1.056384    3.478448    0.403354    0.052880    0.005333    0.724057    
#> 216: 0.613584    1.056379    3.478538    0.403508    0.053164    0.005218    0.725604    
#> 217: 0.613499    1.057211    3.478398    0.404726    0.053112    0.005132    0.725476    
#> 218: 0.613264    1.058152    3.477647    0.403335    0.052778    0.005056    0.725800    
#> 219: 0.612459    1.057753    3.477018    0.406871    0.053134    0.004984    0.726437    
#> 220: 0.610418    1.058041    3.476721    0.407240    0.053343    0.004968    0.726533    
#> 221: 0.609682    1.058532    3.476320    0.406968    0.053163    0.004919    0.726852    
#> 222: 0.609298    1.058538    3.476437    0.403507    0.053773    0.004936    0.727273    
#> 223: 0.610055    1.058951    3.476682    0.402369    0.053851    0.004965    0.726401    
#> 224: 0.610858    1.059063    3.477148    0.399634    0.053896    0.004965    0.726572    
#> 225: 0.610926    1.057201    3.477590    0.400664    0.053830    0.004945    0.726669    
#> 226: 0.609878    1.055592    3.477431    0.400344    0.053707    0.004922    0.727435    
#> 227: 0.608792    1.055257    3.477302    0.399736    0.053743    0.004878    0.726740    
#> 228: 0.607871    1.056500    3.476893    0.400294    0.054300    0.004895    0.726987    
#> 229: 0.605898    1.056135    3.476569    0.398169    0.054235    0.004910    0.726618    
#> 230: 0.606016    1.056082    3.476417    0.398199    0.053949    0.004871    0.726967    
#> 231: 0.606347    1.056172    3.476506    0.399552    0.054006    0.004887    0.726755    
#> 232: 0.604976    1.056279    3.476574    0.398348    0.054093    0.004854    0.727288    
#> 233: 0.604435    1.055516    3.476749    0.396290    0.054203    0.004792    0.727714    
#> 234: 0.604326    1.055640    3.477028    0.396581    0.054566    0.004753    0.727837    
#> 235: 0.604343    1.055371    3.476998    0.396375    0.054543    0.004687    0.728012    
#> 236: 0.604209    1.055771    3.476761    0.395489    0.054634    0.004659    0.728215    
#> 237: 0.605115    1.055459    3.476767    0.396595    0.054974    0.004648    0.728647    
#> 238: 0.605972    1.055749    3.476745    0.398773    0.055371    0.004623    0.728347    
#> 239: 0.605857    1.056113    3.476621    0.400893    0.055439    0.004593    0.728571    
#> 240: 0.607506    1.056012    3.476718    0.404480    0.055657    0.004577    0.728332    
#> 241: 0.608733    1.055590    3.477011    0.405880    0.055470    0.004582    0.728530    
#> 242: 0.609732    1.054894    3.477109    0.406177    0.055462    0.004603    0.729479    
#> 243: 0.609507    1.055390    3.477152    0.406533    0.055355    0.004616    0.730260    
#> 244: 0.608534    1.055339    3.477223    0.404933    0.055150    0.004630    0.730766    
#> 245: 0.608305    1.055204    3.477201    0.405820    0.054914    0.004640    0.731400    
#> 246: 0.608648    1.054854    3.477391    0.404011    0.054553    0.004708    0.731453    
#> 247: 0.609646    1.054720    3.477780    0.402755    0.054267    0.004750    0.731574    
#> 248: 0.609571    1.054593    3.478001    0.401350    0.054099    0.004755    0.731548    
#> 249: 0.609301    1.054631    3.478177    0.401489    0.054015    0.004768    0.731441    
#> 250: 0.609953    1.055080    3.478367    0.401121    0.053930    0.004804    0.731459    
#> 251: 0.610606    1.055191    3.478676    0.399715    0.053847    0.004817    0.731387    
#> 252: 0.610763    1.055209    3.478929    0.399660    0.053816    0.004834    0.731094    
#> 253: 0.610511    1.055282    3.479047    0.398631    0.053891    0.004871    0.730996    
#> 254: 0.610463    1.055869    3.479200    0.397443    0.054140    0.004884    0.730908    
#> 255: 0.609787    1.056170    3.479391    0.395715    0.054315    0.004926    0.730821    
#> 256: 0.610038    1.056024    3.479399    0.394470    0.054365    0.004960    0.730613    
#> 257: 0.610132    1.055571    3.479426    0.394056    0.054287    0.004962    0.730693    
#> 258: 0.610025    1.055238    3.479422    0.393381    0.054085    0.004946    0.730782    
#> 259: 0.610214    1.055132    3.479424    0.393916    0.054059    0.004933    0.730696    
#> 260: 0.609698    1.055111    3.479449    0.394747    0.054099    0.004918    0.730866    
#> 261: 0.610109    1.055012    3.479623    0.394556    0.054199    0.004914    0.731021    
#> 262: 0.610842    1.055226    3.479752    0.396636    0.054557    0.004901    0.730901    
#> 263: 0.610710    1.055532    3.479749    0.397056    0.054645    0.004921    0.730555    
#> 264: 0.610097    1.055854    3.479596    0.397148    0.054572    0.004922    0.730759    
#> 265: 0.609692    1.056195    3.479572    0.396391    0.054680    0.004910    0.731075    
#> 266: 0.610000    1.056443    3.479597    0.396538    0.054712    0.004902    0.731274    
#> 267: 0.610239    1.056696    3.479667    0.396342    0.054915    0.004895    0.731350    
#> 268: 0.610275    1.056824    3.479578    0.395893    0.054913    0.004878    0.731220    
#> 269: 0.610749    1.056756    3.479542    0.395617    0.054847    0.004875    0.731111    
#> 270: 0.610492    1.056994    3.479326    0.395653    0.054906    0.004862    0.730818    
#> 271: 0.610346    1.057131    3.479196    0.395792    0.055033    0.004857    0.730911    
#> 272: 0.610229    1.057204    3.479003    0.396120    0.055200    0.004858    0.731334    
#> 273: 0.609609    1.057611    3.478838    0.396005    0.055280    0.004848    0.731716    
#> 274: 0.609149    1.057761    3.478840    0.395782    0.055309    0.004826    0.731761    
#> 275: 0.609246    1.057995    3.478614    0.395850    0.055378    0.004818    0.731744    
#> 276: 0.608589    1.058261    3.478646    0.395546    0.055564    0.004835    0.731800    
#> 277: 0.608451    1.058550    3.478785    0.395329    0.055689    0.004850    0.731744    
#> 278: 0.608598    1.058433    3.478955    0.395354    0.055853    0.004866    0.731697    
#> 279: 0.608740    1.058177    3.479063    0.395961    0.056160    0.004887    0.731819    
#> 280: 0.609212    1.057875    3.479336    0.396075    0.056092    0.004896    0.731688    
#> 281: 0.609536    1.057703    3.479466    0.395577    0.056113    0.004892    0.731754    
#> 282: 0.609712    1.057678    3.479598    0.394619    0.056378    0.004876    0.731955    
#> 283: 0.610009    1.057462    3.479748    0.394628    0.056378    0.004861    0.732620    
#> 284: 0.609799    1.057199    3.479809    0.394095    0.056241    0.004856    0.732550    
#> 285: 0.609541    1.057425    3.479638    0.394116    0.056211    0.004843    0.732642    
#> 286: 0.609556    1.057720    3.479444    0.393939    0.056208    0.004842    0.732695    
#> 287: 0.609012    1.057981    3.479228    0.394282    0.056227    0.004847    0.732823    
#> 288: 0.609255    1.058088    3.479107    0.394455    0.056210    0.004855    0.732882    
#> 289: 0.609856    1.057976    3.479092    0.395081    0.056078    0.004855    0.732929    
#> 290: 0.609963    1.057932    3.479150    0.395093    0.056026    0.004854    0.733087    
#> 291: 0.610061    1.058028    3.479258    0.394795    0.056021    0.004855    0.732956    
#> 292: 0.609662    1.058211    3.479161    0.394780    0.055970    0.004857    0.732807    
#> 293: 0.609492    1.058408    3.478955    0.394294    0.055977    0.004855    0.732776    
#> 294: 0.608839    1.058749    3.478807    0.393969    0.055961    0.004841    0.732844    
#> 295: 0.608511    1.058699    3.478664    0.394120    0.055997    0.004827    0.732691    
#> 296: 0.608289    1.058736    3.478601    0.394003    0.055900    0.004825    0.732628    
#> 297: 0.608101    1.059081    3.478407    0.394126    0.055807    0.004825    0.732698    
#> 298: 0.607554    1.059206    3.478278    0.394393    0.055665    0.004823    0.732581    
#> 299: 0.607377    1.059543    3.478123    0.394889    0.055602    0.004817    0.732407    
#> 300: 0.607370    1.059569    3.478073    0.394553    0.055565    0.004811    0.732240    
#> 301: 0.607494    1.059378    3.478011    0.394231    0.055643    0.004809    0.732235    
#> 302: 0.607128    1.059471    3.477935    0.394085    0.055664    0.004807    0.732361    
#> 303: 0.606499    1.059602    3.477867    0.393801    0.055693    0.004824    0.732250    
#> 304: 0.606291    1.059770    3.477799    0.393078    0.055688    0.004851    0.732127    
#> 305: 0.606010    1.059419    3.477800    0.392860    0.055739    0.004876    0.732050    
#> 306: 0.605590    1.059349    3.477665    0.392179    0.055670    0.004897    0.732081    
#> 307: 0.605470    1.059240    3.477594    0.392478    0.055735    0.004903    0.732075    
#> 308: 0.604583    1.059245    3.477436    0.392169    0.055869    0.004906    0.732294    
#> 309: 0.604436    1.059258    3.477317    0.391968    0.055922    0.004921    0.732510    
#> 310: 0.604551    1.059329    3.477202    0.392005    0.055979    0.004924    0.732668    
#> 311: 0.604523    1.059400    3.477109    0.391661    0.055976    0.004936    0.732519    
#> 312: 0.603894    1.059543    3.477010    0.391082    0.055968    0.004947    0.732655    
#> 313: 0.603329    1.059592    3.476929    0.390335    0.055900    0.004952    0.732781    
#> 314: 0.602861    1.059600    3.476830    0.390376    0.055861    0.004957    0.732875    
#> 315: 0.602467    1.059705    3.476778    0.389988    0.055820    0.004961    0.732898    
#> 316: 0.602321    1.059771    3.476707    0.389703    0.055767    0.004960    0.733008    
#> 317: 0.602083    1.059776    3.476613    0.389515    0.055711    0.004956    0.733165    
#> 318: 0.602211    1.059830    3.476570    0.389454    0.055569    0.004956    0.733195    
#> 319: 0.602658    1.059826    3.476624    0.389741    0.055527    0.004956    0.733277    
#> 320: 0.602400    1.059773    3.476555    0.389533    0.055495    0.004955    0.733376    
#> 321: 0.602068    1.059710    3.476432    0.389906    0.055438    0.004958    0.733361    
#> 322: 0.601702    1.059834    3.476256    0.389217    0.055410    0.004958    0.733386    
#> 323: 0.601089    1.060058    3.476114    0.388862    0.055353    0.004952    0.733325    
#> 324: 0.600790    1.060229    3.476048    0.388405    0.055420    0.004939    0.733186    
#> 325: 0.600645    1.060429    3.475945    0.388141    0.055466    0.004934    0.733080    
#> 326: 0.600727    1.060287    3.475921    0.388477    0.055538    0.004935    0.732999    
#> 327: 0.600947    1.060285    3.475936    0.388522    0.055649    0.004942    0.732875    
#> 328: 0.601316    1.060386    3.475924    0.388238    0.055652    0.004939    0.732872    
#> 329: 0.601482    1.060589    3.475870    0.388028    0.055673    0.004933    0.732902    
#> 330: 0.601401    1.060688    3.475856    0.387707    0.055645    0.004937    0.732928    
#> 331: 0.601442    1.061000    3.475803    0.387672    0.055698    0.004938    0.732753    
#> 332: 0.601453    1.060995    3.475776    0.387587    0.055642    0.004936    0.732770    
#> 333: 0.601374    1.061026    3.475672    0.388048    0.055618    0.004933    0.732736    
#> 334: 0.601072    1.060844    3.475597    0.387957    0.055596    0.004933    0.732687    
#> 335: 0.600605    1.060855    3.475464    0.388020    0.055563    0.004933    0.732658    
#> 336: 0.600222    1.060980    3.475348    0.387898    0.055577    0.004938    0.732728    
#> 337: 0.600286    1.061251    3.475259    0.388358    0.055562    0.004936    0.732768    
#> 338: 0.600422    1.061462    3.475267    0.388655    0.055560    0.004933    0.732828    
#> 339: 0.600129    1.061695    3.475225    0.388919    0.055544    0.004923    0.732780    
#> 340: 0.600000    1.061709    3.475259    0.388885    0.055603    0.004916    0.732754    
#> 341: 0.600266    1.061676    3.475304    0.388831    0.055641    0.004913    0.732719    
#> 342: 0.599969    1.061602    3.475264    0.389062    0.055665    0.004912    0.732636    
#> 343: 0.599717    1.061723    3.475280    0.388776    0.055725    0.004907    0.732632    
#> 344: 0.599666    1.061798    3.475297    0.388386    0.055754    0.004907    0.732714    
#> 345: 0.599669    1.061721    3.475330    0.388034    0.055754    0.004904    0.732750    
#> 346: 0.599761    1.061699    3.475287    0.387786    0.055712    0.004894    0.732774    
#> 347: 0.599813    1.061529    3.475197    0.388067    0.055694    0.004901    0.732913    
#> 348: 0.599541    1.061585    3.475142    0.388226    0.055767    0.004914    0.732892    
#> 349: 0.599264    1.061459    3.475087    0.388864    0.055784    0.004917    0.732880    
#> 350: 0.599160    1.061322    3.475069    0.388859    0.055763    0.004919    0.732923    
#> 351: 0.599180    1.061472    3.475027    0.389347    0.055697    0.004923    0.732986    
#> 352: 0.598898    1.061606    3.475000    0.389462    0.055721    0.004931    0.733002    
#> 353: 0.599028    1.061696    3.474961    0.388990    0.055681    0.004927    0.732961    
#> 354: 0.598960    1.061695    3.474865    0.389289    0.055574    0.004919    0.732879    
#> 355: 0.599237    1.061573    3.474821    0.389171    0.055566    0.004913    0.733015    
#> 356: 0.599310    1.061405    3.474856    0.389011    0.055590    0.004911    0.733045    
#> 357: 0.599564    1.061440    3.474875    0.388928    0.055560    0.004909    0.733009    
#> 358: 0.599597    1.061332    3.474938    0.388628    0.055520    0.004911    0.732912    
#> 359: 0.599541    1.061451    3.474936    0.388325    0.055549    0.004909    0.732897    
#> 360: 0.599406    1.061564    3.474854    0.387837    0.055531    0.004902    0.732856    
#> 361: 0.599140    1.061657    3.474771    0.387513    0.055527    0.004900    0.732800    
#> 362: 0.599254    1.061682    3.474749    0.387579    0.055471    0.004902    0.732640    
#> 363: 0.599495    1.061691    3.474776    0.387502    0.055436    0.004902    0.732528    
#> 364: 0.599775    1.061655    3.474839    0.387268    0.055410    0.004906    0.732403    
#> 365: 0.599875    1.061586    3.474905    0.386911    0.055301    0.004911    0.732445    
#> 366: 0.600137    1.061566    3.474900    0.386716    0.055253    0.004917    0.732406    
#> 367: 0.600323    1.061612    3.474930    0.386744    0.055316    0.004921    0.732255    
#> 368: 0.600436    1.061660    3.474872    0.387140    0.055294    0.004928    0.732170    
#> 369: 0.600206    1.061630    3.474835    0.387278    0.055306    0.004919    0.732276    
#> 370: 0.600280    1.061683    3.474833    0.387282    0.055280    0.004923    0.732316    
#> 371: 0.600082    1.061847    3.474747    0.387317    0.055296    0.004917    0.732310    
#> 372: 0.599905    1.061980    3.474687    0.387350    0.055337    0.004912    0.732371    
#> 373: 0.599538    1.062096    3.474590    0.387302    0.055329    0.004907    0.732495    
#> 374: 0.599545    1.062121    3.474520    0.387178    0.055338    0.004907    0.732417    
#> 375: 0.599468    1.062189    3.474471    0.386969    0.055379    0.004916    0.732375    
#> 376: 0.599424    1.062166    3.474442    0.386890    0.055425    0.004918    0.732368    
#> 377: 0.599336    1.062183    3.474409    0.386964    0.055467    0.004922    0.732424    
#> 378: 0.599104    1.062163    3.474324    0.386884    0.055423    0.004927    0.732498    
#> 379: 0.598872    1.062071    3.474264    0.386887    0.055426    0.004917    0.732454    
#> 380: 0.598643    1.062074    3.474243    0.386807    0.055402    0.004915    0.732414    
#> 381: 0.598459    1.062022    3.474215    0.387060    0.055372    0.004911    0.732385    
#> 382: 0.598499    1.061967    3.474194    0.387194    0.055323    0.004904    0.732254    
#> 383: 0.598616    1.061955    3.474140    0.387319    0.055250    0.004898    0.732270    
#> 384: 0.598618    1.061908    3.474113    0.387151    0.055212    0.004895    0.732178    
#> 385: 0.598638    1.061950    3.474101    0.386778    0.055161    0.004897    0.732188    
#> 386: 0.598876    1.062075    3.474172    0.386650    0.055061    0.004900    0.732173    
#> 387: 0.599098    1.062156    3.474257    0.386636    0.055012    0.004914    0.732169    
#> 388: 0.599273    1.062160    3.474277    0.386838    0.054976    0.004922    0.732123    
#> 389: 0.599183    1.061986    3.474238    0.386952    0.054965    0.004926    0.732150    
#> 390: 0.599122    1.061914    3.474195    0.387078    0.054934    0.004937    0.732119    
#> 391: 0.599248    1.061826    3.474191    0.386975    0.054916    0.004940    0.732083    
#> 392: 0.599331    1.061768    3.474234    0.386913    0.054901    0.004939    0.732104    
#> 393: 0.599196    1.061703    3.474242    0.386657    0.054886    0.004938    0.732141    
#> 394: 0.599244    1.061692    3.474221    0.386462    0.054847    0.004936    0.732142    
#> 395: 0.599456    1.061829    3.474218    0.386201    0.054823    0.004939    0.732226    
#> 396: 0.599477    1.061898    3.474220    0.386130    0.054793    0.004942    0.732292    
#> 397: 0.599582    1.061904    3.474219    0.386890    0.054745    0.004957    0.732338    
#> 398: 0.599647    1.061957    3.474238    0.387687    0.054720    0.004971    0.732300    
#> 399: 0.599772    1.061903    3.474313    0.388190    0.054680    0.004981    0.732258    
#> 400: 0.599995    1.061882    3.474318    0.388577    0.054668    0.004994    0.732224    
#> 401: 0.599973    1.061882    3.474326    0.388523    0.054659    0.005011    0.732213    
#> 402: 0.600043    1.061891    3.474328    0.388431    0.054577    0.005024    0.732193    
#> 403: 0.600245    1.061963    3.474314    0.388390    0.054564    0.005031    0.732150    
#> 404: 0.600190    1.062078    3.474249    0.388402    0.054510    0.005028    0.732155    
#> 405: 0.600103    1.062123    3.474256    0.388366    0.054530    0.005027    0.732182    
#> 406: 0.600228    1.062168    3.474265    0.388853    0.054583    0.005029    0.732145    
#> 407: 0.600316    1.062162    3.474292    0.388995    0.054638    0.005026    0.732116    
#> 408: 0.600555    1.062247    3.474300    0.389193    0.054683    0.005026    0.732137    
#> 409: 0.600560    1.062186    3.474257    0.389322    0.054722    0.005028    0.732012    
#> 410: 0.600454    1.062284    3.474162    0.389493    0.054768    0.005031    0.732015    
#> 411: 0.600563    1.062122    3.474161    0.389631    0.054830    0.005034    0.732133    
#> 412: 0.600655    1.062116    3.474155    0.389777    0.054846    0.005033    0.732174    
#> 413: 0.600656    1.062137    3.474124    0.389820    0.054890    0.005036    0.732066    
#> 414: 0.600364    1.062071    3.474090    0.389508    0.054911    0.005038    0.731984    
#> 415: 0.600494    1.062031    3.474106    0.389497    0.054854    0.005042    0.731950    
#> 416: 0.600583    1.062130    3.474122    0.389555    0.054835    0.005048    0.731841    
#> 417: 0.600403    1.062182    3.474101    0.389378    0.054845    0.005052    0.731766    
#> 418: 0.600281    1.062222    3.474087    0.389366    0.054894    0.005050    0.731751    
#> 419: 0.600131    1.062279    3.474026    0.389410    0.054952    0.005046    0.731723    
#> 420: 0.600263    1.062257    3.474015    0.389638    0.055010    0.005039    0.731695    
#> 421: 0.600031    1.062251    3.474009    0.389735    0.055030    0.005030    0.731716    
#> 422: 0.600203    1.062107    3.474011    0.389758    0.055033    0.005023    0.731730    
#> 423: 0.600352    1.062050    3.474021    0.389553    0.055078    0.005018    0.731747    
#> 424: 0.600237    1.062020    3.473998    0.389331    0.055082    0.005011    0.731758    
#> 425: 0.600241    1.062095    3.473986    0.389512    0.055033    0.005007    0.731730    
#> 426: 0.600203    1.062192    3.473986    0.389587    0.055009    0.005004    0.731697    
#> 427: 0.600046    1.062173    3.473979    0.389448    0.054978    0.005010    0.731637    
#> 428: 0.599909    1.062250    3.473960    0.389339    0.054949    0.005020    0.731619    
#> 429: 0.599952    1.062268    3.474001    0.389492    0.054926    0.005025    0.731540    
#> 430: 0.599897    1.062328    3.474013    0.389487    0.054912    0.005024    0.731451    
#> 431: 0.599739    1.062350    3.473973    0.389467    0.054903    0.005021    0.731387    
#> 432: 0.599783    1.062480    3.473948    0.389608    0.054895    0.005024    0.731361    
#> 433: 0.599966    1.062667    3.473962    0.389946    0.054906    0.005031    0.731379    
#> 434: 0.600067    1.062593    3.474004    0.390225    0.054920    0.005039    0.731387    
#> 435: 0.600264    1.062577    3.474023    0.390345    0.054881    0.005049    0.731401    
#> 436: 0.600373    1.062549    3.474029    0.390115    0.054848    0.005049    0.731390    
#> 437: 0.600517    1.062533    3.474038    0.389978    0.054813    0.005052    0.731410    
#> 438: 0.600533    1.062669    3.474088    0.390241    0.054798    0.005047    0.731417    
#> 439: 0.600756    1.062745    3.474097    0.390241    0.054841    0.005039    0.731354    
#> 440: 0.600891    1.062707    3.474144    0.390320    0.054830    0.005034    0.731297    
#> 441: 0.600879    1.062652    3.474181    0.390179    0.054860    0.005035    0.731187    
#> 442: 0.600727    1.062728    3.474207    0.389906    0.054923    0.005031    0.731144    
#> 443: 0.600798    1.062872    3.474251    0.389732    0.054965    0.005026    0.731125    
#> 444: 0.600730    1.062925    3.474232    0.389671    0.054982    0.005021    0.731112    
#> 445: 0.600638    1.063008    3.474184    0.389629    0.054973    0.005022    0.731133    
#> 446: 0.600509    1.063092    3.474141    0.389484    0.054952    0.005022    0.731153    
#> 447: 0.600656    1.063143    3.474138    0.389372    0.054954    0.005024    0.731141    
#> 448: 0.600654    1.063112    3.474177    0.389489    0.054971    0.005031    0.731062    
#> 449: 0.600840    1.063092    3.474277    0.389547    0.054959    0.005039    0.731043    
#> 450: 0.600897    1.063099    3.474295    0.389746    0.054903    0.005041    0.731025    
#> 451: 0.601039    1.063119    3.474283    0.389846    0.054856    0.005040    0.730974    
#> 452: 0.600995    1.063118    3.474275    0.389841    0.054799    0.005036    0.730886    
#> 453: 0.600896    1.063094    3.474276    0.389625    0.054766    0.005034    0.730902    
#> 454: 0.600829    1.063133    3.474272    0.389542    0.054758    0.005036    0.730856    
#> 455: 0.600872    1.063119    3.474241    0.389675    0.054739    0.005039    0.730823    
#> 456: 0.600775    1.063076    3.474223    0.389544    0.054719    0.005044    0.730935    
#> 457: 0.600739    1.063061    3.474234    0.389508    0.054689    0.005046    0.730909    
#> 458: 0.600706    1.063107    3.474249    0.389584    0.054653    0.005048    0.730912    
#> 459: 0.600665    1.063131    3.474264    0.389750    0.054624    0.005047    0.730976    
#> 460: 0.600596    1.063095    3.474260    0.389840    0.054600    0.005050    0.731011    
#> 461: 0.600560    1.063109    3.474238    0.390195    0.054567    0.005057    0.730976    
#> 462: 0.600452    1.063168    3.474245    0.390502    0.054562    0.005060    0.730941    
#> 463: 0.600420    1.063203    3.474228    0.390679    0.054543    0.005060    0.730895    
#> 464: 0.600466    1.063169    3.474227    0.390683    0.054539    0.005059    0.730845    
#> 465: 0.600594    1.063073    3.474244    0.390639    0.054529    0.005055    0.730814    
#> 466: 0.600654    1.063065    3.474242    0.390733    0.054517    0.005054    0.730793    
#> 467: 0.600677    1.063022    3.474265    0.390544    0.054475    0.005061    0.730774    
#> 468: 0.600889    1.062981    3.474312    0.390689    0.054468    0.005066    0.730799    
#> 469: 0.600883    1.062994    3.474343    0.390776    0.054440    0.005071    0.730821    
#> 470: 0.600775    1.062952    3.474368    0.390998    0.054426    0.005075    0.730783    
#> 471: 0.600729    1.062885    3.474392    0.391239    0.054399    0.005076    0.730780    
#> 472: 0.600666    1.062846    3.474428    0.391014    0.054367    0.005080    0.730850    
#> 473: 0.600589    1.062804    3.474452    0.390770    0.054335    0.005079    0.730846    
#> 474: 0.600750    1.062639    3.474502    0.390888    0.054390    0.005078    0.730884    
#> 475: 0.600899    1.062660    3.474536    0.390728    0.054364    0.005076    0.730913    
#> 476: 0.600919    1.062668    3.474513    0.390714    0.054376    0.005072    0.731031    
#> 477: 0.600784    1.062656    3.474524    0.390516    0.054391    0.005072    0.731015    
#> 478: 0.600688    1.062591    3.474547    0.390519    0.054332    0.005074    0.731011    
#> 479: 0.600694    1.062665    3.474564    0.390611    0.054332    0.005072    0.731011    
#> 480: 0.600733    1.062686    3.474592    0.390672    0.054341    0.005074    0.731024    
#> 481: 0.600702    1.062640    3.474616    0.390580    0.054326    0.005079    0.731044    
#> 482: 0.600835    1.062659    3.474609    0.390527    0.054299    0.005086    0.731116    
#> 483: 0.600727    1.062599    3.474605    0.390402    0.054288    0.005086    0.731152    
#> 484: 0.600634    1.062490    3.474616    0.390365    0.054276    0.005082    0.731143    
#> 485: 0.600711    1.062444    3.474638    0.390475    0.054295    0.005082    0.731137    
#> 486: 0.600766    1.062465    3.474629    0.390448    0.054259    0.005079    0.731139    
#> 487: 0.600962    1.062502    3.474672    0.390336    0.054253    0.005083    0.731125    
#> 488: 0.601071    1.062425    3.474723    0.390247    0.054234    0.005084    0.731181    
#> 489: 0.601252    1.062285    3.474770    0.390110    0.054219    0.005090    0.731205    
#> 490: 0.601463    1.062260    3.474853    0.390158    0.054206    0.005095    0.731218    
#> 491: 0.601593    1.062263    3.474919    0.390144    0.054230    0.005092    0.731213    
#> 492: 0.601639    1.062294    3.474952    0.390084    0.054211    0.005091    0.731278    
#> 493: 0.601526    1.062322    3.474971    0.390041    0.054186    0.005093    0.731314    
#> 494: 0.601651    1.062378    3.474978    0.390102    0.054167    0.005095    0.731200    
#> 495: 0.601819    1.062396    3.475027    0.390211    0.054134    0.005098    0.731178    
#> 496: 0.602064    1.062470    3.475044    0.390653    0.054103    0.005101    0.731163    
#> 497: 0.601918    1.062472    3.475065    0.390747    0.054068    0.005103    0.731141    
#> 498: 0.601812    1.062430    3.475053    0.390851    0.054065    0.005103    0.731126    
#> 499: 0.601768    1.062477    3.475038    0.391013    0.054105    0.005104    0.731095    
#> 500: 0.601715    1.062438    3.475024    0.390975    0.054080    0.005107    0.731122    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.301619    0.962496    3.434253    0.392401    0.075013    0.016800    1.661222    
#> 002: 0.363117    0.930429    3.463680    0.372781    0.071262    0.015960    1.131201    
#> 003: 0.473335    0.893653    3.447195    0.354142    0.067699    0.015162    0.906400    
#> 004: 0.447472    0.909165    3.445264    0.336435    0.064314    0.014404    0.755168    
#> 005: 0.479463    0.932230    3.427041    0.347589    0.061098    0.013684    0.713096    
#> 006: 0.396791    0.962652    3.408809    0.393909    0.058044    0.015102    0.668861    
#> 007: 0.347021    0.983452    3.393267    0.374213    0.055141    0.015670    0.687756    
#> 008: 0.340405    0.984538    3.379812    0.437924    0.052384    0.019762    0.682362    
#> 009: 0.284259    0.980179    3.364139    0.451933    0.049765    0.020555    0.664420    
#> 010: 0.313268    0.978342    3.379015    0.429336    0.047277    0.020345    0.684445    
#> 011: 0.380938    0.985122    3.378412    0.533628    0.044913    0.022292    0.686855    
#> 012: 0.394369    0.969345    3.377675    0.594358    0.042667    0.023869    0.665251    
#> 013: 0.331786    0.979776    3.368723    0.564640    0.040534    0.023982    0.674082    
#> 014: 0.378567    0.976754    3.377787    0.536408    0.038507    0.024211    0.685882    
#> 015: 0.408243    0.977144    3.404524    0.509588    0.036582    0.027559    0.659797    
#> 016: 0.397742    0.973075    3.405572    0.515822    0.035210    0.027022    0.670890    
#> 017: 0.388969    0.978621    3.398772    0.490031    0.036608    0.026446    0.656953    
#> 018: 0.393168    0.964936    3.384996    0.581619    0.034777    0.025124    0.664406    
#> 019: 0.393329    0.977150    3.391596    0.552538    0.035882    0.023868    0.655504    
#> 020: 0.431794    0.962168    3.403436    0.524911    0.043851    0.025265    0.660375    
#> 021: 0.442033    0.957319    3.409140    0.541174    0.041658    0.027368    0.656732    
#> 022: 0.395945    0.973039    3.402433    0.514115    0.039575    0.026000    0.665615    
#> 023: 0.408602    0.985839    3.393852    0.516493    0.037596    0.024700    0.676625    
#> 024: 0.376377    0.999462    3.390918    0.490668    0.035717    0.023465    0.658096    
#> 025: 0.374593    0.990764    3.376626    0.488704    0.033931    0.028729    0.655806    
#> 026: 0.367233    0.998943    3.369956    0.533252    0.032234    0.027292    0.659918    
#> 027: 0.336030    1.005109    3.364660    0.506589    0.030623    0.025928    0.670235    
#> 028: 0.392106    0.990667    3.386002    0.511146    0.029091    0.027240    0.664517    
#> 029: 0.400878    0.986978    3.385874    0.485588    0.027637    0.025878    0.684252    
#> 030: 0.348881    1.001879    3.378537    0.461309    0.028765    0.026895    0.680954    
#> 031: 0.324997    0.984536    3.385886    0.438244    0.027433    0.025550    0.677454    
#> 032: 0.363384    1.004889    3.386885    0.416331    0.030998    0.024438    0.676981    
#> 033: 0.351336    1.003938    3.375722    0.474780    0.031661    0.023216    0.665226    
#> 034: 0.377361    1.004064    3.386146    0.451041    0.042669    0.024912    0.649185    
#> 035: 0.360854    0.987063    3.382369    0.428489    0.040536    0.023667    0.636355    
#> 036: 0.357649    0.992331    3.378978    0.465424    0.038509    0.022483    0.653990    
#> 037: 0.359198    1.008352    3.373868    0.502633    0.048070    0.021359    0.662498    
#> 038: 0.349871    1.016220    3.364848    0.477501    0.045679    0.020291    0.661809    
#> 039: 0.345615    0.993251    3.374568    0.490593    0.043395    0.023362    0.649215    
#> 040: 0.355495    1.002551    3.384468    0.466063    0.041226    0.026241    0.674448    
#> 041: 0.339636    0.998520    3.368494    0.442760    0.039164    0.024928    0.663246    
#> 042: 0.382434    0.991684    3.378822    0.454022    0.037206    0.023682    0.655189    
#> 043: 0.349301    0.992975    3.364623    0.431321    0.037365    0.022498    0.683561    
#> 044: 0.349589    1.000457    3.372987    0.423097    0.035497    0.021373    0.690197    
#> 045: 0.347731    1.015135    3.368383    0.412638    0.046141    0.020304    0.671363    
#> 046: 0.340603    1.000564    3.374550    0.449428    0.049019    0.019289    0.676875    
#> 047: 0.344162    1.003187    3.362401    0.560130    0.046568    0.018325    0.668673    
#> 048: 0.333320    1.011306    3.363074    0.566622    0.045068    0.017408    0.655998    
#> 049: 0.363009    1.003649    3.370212    0.694788    0.048525    0.017364    0.670474    
#> 050: 0.359686    0.985646    3.379171    0.660048    0.046098    0.019909    0.665576    
#> 051: 0.356018    0.992882    3.363509    0.627046    0.046521    0.020304    0.662789    
#> 052: 0.363646    0.994901    3.381249    0.595694    0.044195    0.019288    0.660663    
#> 053: 0.381507    0.982885    3.381508    0.565909    0.041985    0.021560    0.644411    
#> 054: 0.379762    0.985645    3.395352    0.541092    0.039886    0.020482    0.663309    
#> 055: 0.408530    0.988106    3.395638    0.520630    0.037892    0.019488    0.670626    
#> 056: 0.417783    0.979654    3.396067    0.494598    0.035997    0.020770    0.685975    
#> 057: 0.397665    0.975403    3.400306    0.469868    0.034197    0.021339    0.696721    
#> 058: 0.362748    0.985496    3.383686    0.500445    0.032487    0.021329    0.689539    
#> 059: 0.318314    0.957939    3.382458    0.475423    0.030863    0.020771    0.699334    
#> 060: 0.384162    0.958608    3.397335    0.452899    0.039656    0.020906    0.682924    
#> 061: 0.422225    0.962814    3.407010    0.430254    0.039273    0.024100    0.692071    
#> 062: 0.403534    0.967131    3.402286    0.431592    0.046803    0.022895    0.705958    
#> 063: 0.430420    0.958707    3.401856    0.428449    0.044463    0.021750    0.715273    
#> 064: 0.403217    0.977249    3.407540    0.471575    0.042239    0.020663    0.687817    
#> 065: 0.405507    0.979073    3.380047    0.457433    0.040127    0.022441    0.679821    
#> 066: 0.388095    0.983107    3.380679    0.487646    0.038121    0.021319    0.674196    
#> 067: 0.369972    0.978904    3.385256    0.463264    0.036215    0.026698    0.673481    
#> 068: 0.353607    0.987955    3.387654    0.452014    0.034404    0.025363    0.681797    
#> 069: 0.362333    0.991543    3.381491    0.429413    0.038049    0.024095    0.682992    
#> 070: 0.369757    0.988999    3.400628    0.413723    0.045263    0.022890    0.676790    
#> 071: 0.368723    0.998776    3.388452    0.393036    0.044474    0.021746    0.673729    
#> 072: 0.359402    0.967051    3.389140    0.373385    0.042251    0.020658    0.684699    
#> 073: 0.390257    0.958622    3.414893    0.359268    0.046805    0.019626    0.668182    
#> 074: 0.390929    0.963017    3.404067    0.435661    0.045401    0.018644    0.665839    
#> 075: 0.441780    0.955613    3.420333    0.489196    0.044756    0.017712    0.675958    
#> 076: 0.473437    0.947744    3.430103    0.595219    0.042519    0.017325    0.680716    
#> 077: 0.463971    0.945983    3.410778    0.565458    0.046795    0.020815    0.689359    
#> 078: 0.415965    0.961408    3.404957    0.537185    0.044455    0.021274    0.675014    
#> 079: 0.410387    0.970730    3.397159    0.510326    0.047533    0.020210    0.679835    
#> 080: 0.401876    0.959872    3.398230    0.484809    0.048605    0.019200    0.677663    
#> 081: 0.373900    0.978828    3.393001    0.460569    0.046174    0.018240    0.669212    
#> 082: 0.375803    0.967691    3.397646    0.437541    0.043866    0.019738    0.674785    
#> 083: 0.405410    0.984198    3.404474    0.536391    0.041672    0.020477    0.673072    
#> 084: 0.400827    0.987085    3.386930    0.509572    0.039589    0.020003    0.678490    
#> 085: 0.417343    0.998594    3.391588    0.544468    0.041299    0.022090    0.675180    
#> 086: 0.371535    0.986337    3.386561    0.565340    0.039234    0.023199    0.663588    
#> 087: 0.389348    0.985481    3.384877    0.580111    0.037272    0.024884    0.649799    
#> 088: 0.341970    0.979799    3.384924    0.551106    0.037678    0.026248    0.669777    
#> 089: 0.361779    0.986143    3.376639    0.523550    0.040230    0.028506    0.650399    
#> 090: 0.326919    0.990983    3.366605    0.497373    0.038219    0.030058    0.657956    
#> 091: 0.328379    0.986390    3.353082    0.486410    0.036308    0.029565    0.660684    
#> 092: 0.358428    0.991621    3.360253    0.563730    0.034492    0.029801    0.652331    
#> 093: 0.319503    0.992376    3.363353    0.535544    0.033668    0.028311    0.670797    
#> 094: 0.344286    0.995755    3.375069    0.513539    0.031985    0.028822    0.659314    
#> 095: 0.333461    0.997621    3.381940    0.487862    0.030386    0.031606    0.677000    
#> 096: 0.311576    1.016239    3.361297    0.463469    0.036624    0.030025    0.663391    
#> 097: 0.327827    1.022281    3.351528    0.523552    0.034793    0.029932    0.654456    
#> 098: 0.381849    1.007661    3.381699    0.497374    0.033053    0.029548    0.675966    
#> 099: 0.357571    0.984643    3.366495    0.472505    0.033976    0.028071    0.664536    
#> 100: 0.348938    0.989451    3.381516    0.511064    0.032804    0.029306    0.659029    
#> 101: 0.338628    0.980570    3.361863    0.485510    0.031164    0.029654    0.655700    
#> 102: 0.333477    0.978347    3.356436    0.476278    0.033118    0.028172    0.657741    
#> 103: 0.378703    0.988111    3.364386    0.522125    0.034107    0.026763    0.658710    
#> 104: 0.366007    0.997489    3.384212    0.518148    0.035347    0.025425    0.670834    
#> 105: 0.405960    0.988527    3.389545    0.500045    0.037961    0.024538    0.667572    
#> 106: 0.397619    0.987125    3.394465    0.475043    0.036063    0.023521    0.657360    
#> 107: 0.395347    0.991220    3.387825    0.520387    0.034260    0.022734    0.658912    
#> 108: 0.343170    0.986411    3.388907    0.507665    0.032547    0.023666    0.683171    
#> 109: 0.346294    0.985489    3.387162    0.482281    0.030919    0.025428    0.680184    
#> 110: 0.372244    0.994246    3.362736    0.507841    0.032460    0.024157    0.664205    
#> 111: 0.373991    1.009422    3.367798    0.498586    0.030837    0.022949    0.653821    
#> 112: 0.323239    0.991830    3.352782    0.526011    0.031773    0.021801    0.658638    
#> 113: 0.323069    1.015668    3.364407    0.536116    0.030184    0.025335    0.650883    
#> 114: 0.355132    1.011728    3.362830    0.509311    0.030623    0.024069    0.668321    
#> 115: 0.396300    0.975379    3.364363    0.595880    0.032104    0.022865    0.675323    
#> 116: 0.427441    0.987341    3.369558    0.578988    0.038243    0.025196    0.671361    
#> 117: 0.415073    1.000147    3.388975    0.698844    0.036331    0.025453    0.674176    
#> 118: 0.410458    0.993548    3.386897    0.663902    0.034576    0.024181    0.671650    
#> 119: 0.382824    1.007638    3.388500    0.630707    0.032847    0.022972    0.696429    
#> 120: 0.326172    1.003738    3.373142    0.599172    0.039404    0.023943    0.678646    
#> 121: 0.343838    1.017616    3.359175    0.569213    0.037434    0.022746    0.680670    
#> 122: 0.350381    1.005235    3.372197    0.540752    0.038834    0.021608    0.686312    
#> 123: 0.380869    1.027935    3.366582    0.513715    0.044214    0.020528    0.664661    
#> 124: 0.350463    1.028094    3.370955    0.488029    0.042280    0.020547    0.667009    
#> 125: 0.385976    1.000615    3.374861    0.504410    0.040289    0.023381    0.677920    
#> 126: 0.364000    1.009043    3.363300    0.520912    0.038274    0.022212    0.682688    
#> 127: 0.378058    0.995284    3.367356    0.568528    0.036361    0.027902    0.684939    
#> 128: 0.369858    0.991173    3.376265    0.582708    0.037028    0.026507    0.684538    
#> 129: 0.411151    1.005142    3.382647    0.591185    0.040515    0.026118    0.671108    
#> 130: 0.446150    1.006494    3.385685    0.607249    0.045202    0.024812    0.665871    
#> 131: 0.352383    0.993450    3.375367    0.576887    0.043569    0.023572    0.674256    
#> 132: 0.327810    1.006013    3.366742    0.548042    0.047825    0.022393    0.667097    
#> 133: 0.342844    0.975108    3.369903    0.520640    0.049824    0.021273    0.670846    
#> 134: 0.335809    0.972921    3.372341    0.511325    0.047333    0.024582    0.674368    
#> 135: 0.343287    0.988099    3.373013    0.485759    0.047128    0.023352    0.668081    
#> 136: 0.350153    0.989102    3.374828    0.461471    0.047494    0.022185    0.661171    
#> 137: 0.379327    0.975292    3.388028    0.467615    0.046102    0.024762    0.660160    
#> 138: 0.332364    0.983166    3.373786    0.444234    0.052094    0.023524    0.668078    
#> 139: 0.337948    1.005874    3.386432    0.509029    0.049917    0.022348    0.677464    
#> 140: 0.363113    1.018812    3.391172    0.483578    0.047421    0.023142    0.669333    
#> 141: 0.365242    0.984214    3.397535    0.460806    0.045050    0.025411    0.650120    
#> 142: 0.411081    0.956309    3.411808    0.482655    0.042798    0.024140    0.661298    
#> 143: 0.382707    0.971033    3.400959    0.458523    0.040658    0.026196    0.678761    
#> 144: 0.448633    0.978865    3.415399    0.551359    0.038625    0.027335    0.637710    
#> 145: 0.380940    0.979288    3.385337    0.580839    0.036694    0.025968    0.655026    
#> 146: 0.381661    0.988550    3.382040    0.551797    0.036154    0.024670    0.655820    
#> 147: 0.351980    0.990954    3.366842    0.524207    0.040053    0.023842    0.656799    
#> 148: 0.360499    0.982936    3.385293    0.497997    0.041903    0.022650    0.662611    
#> 149: 0.356830    0.986779    3.374265    0.504406    0.043749    0.021517    0.657559    
#> 150: 0.382431    0.989911    3.369690    0.533685    0.041561    0.020442    0.675413    
#> 151: 0.357811    1.004997    3.377417    0.540468    0.045554    0.021573    0.650203    
#> 152: 0.346010    0.996244    3.383108    0.491101    0.033320    0.024817    0.656206    
#> 153: 0.353970    1.007441    3.383116    0.471510    0.041494    0.018726    0.674174    
#> 154: 0.380948    1.025894    3.378292    0.534478    0.046439    0.016472    0.678777    
#> 155: 0.374443    1.001073    3.373376    0.494974    0.050073    0.013783    0.662357    
#> 156: 0.367734    0.988951    3.378157    0.521978    0.056841    0.017984    0.660490    
#> 157: 0.369469    0.987002    3.382012    0.491790    0.066943    0.017027    0.666402    
#> 158: 0.391736    1.003888    3.376555    0.494595    0.052164    0.016846    0.649313    
#> 159: 0.354888    0.997120    3.388761    0.440053    0.040636    0.020318    0.658484    
#> 160: 0.380477    0.970892    3.389944    0.455924    0.043441    0.019667    0.676751    
#> 161: 0.363079    0.984635    3.384074    0.425386    0.046827    0.019246    0.684883    
#> 162: 0.349120    1.003748    3.376612    0.456053    0.056036    0.018107    0.689312    
#> 163: 0.385871    0.989113    3.373655    0.457196    0.060026    0.020225    0.664663    
#> 164: 0.383583    1.008075    3.380703    0.496614    0.049272    0.023181    0.653475    
#> 165: 0.403889    0.992749    3.378202    0.591777    0.045500    0.024316    0.664521    
#> 166: 0.421396    1.008625    3.387796    0.543149    0.056254    0.025124    0.665343    
#> 167: 0.396967    1.012561    3.388630    0.459146    0.046175    0.019772    0.685833    
#> 168: 0.361112    1.011363    3.382937    0.455469    0.046566    0.016801    0.672900    
#> 169: 0.351137    1.028439    3.369474    0.391578    0.042323    0.017450    0.686283    
#> 170: 0.351213    0.994278    3.382049    0.390989    0.039173    0.018505    0.681585    
#> 171: 0.346227    0.993553    3.381189    0.405533    0.032584    0.015458    0.665089    
#> 172: 0.353812    1.009383    3.374000    0.448029    0.039418    0.014525    0.662441    
#> 173: 0.349527    1.004437    3.371012    0.457699    0.035679    0.020015    0.667960    
#> 174: 0.350036    1.006705    3.376122    0.537316    0.035850    0.014480    0.666425    
#> 175: 0.335015    0.993578    3.369977    0.469820    0.033767    0.016960    0.678664    
#> 176: 0.337346    1.009391    3.368806    0.495964    0.031901    0.017091    0.679490    
#> 177: 0.361290    1.010896    3.374350    0.526124    0.035263    0.019128    0.687439    
#> 178: 0.388364    0.982492    3.379565    0.566875    0.036131    0.020246    0.680783    
#> 179: 0.395771    0.997461    3.371224    0.489774    0.036730    0.020658    0.686845    
#> 180: 0.349224    0.998213    3.375982    0.446364    0.039327    0.019282    0.676034    
#> 181: 0.329760    1.000780    3.359799    0.433975    0.035935    0.019707    0.668686    
#> 182: 0.330957    0.993209    3.357693    0.490658    0.029677    0.024566    0.668881    
#> 183: 0.365810    1.009048    3.367236    0.541546    0.028047    0.023270    0.666542    
#> 184: 0.374654    0.984154    3.379800    0.526602    0.025883    0.023853    0.649393    
#> 185: 0.349728    0.991047    3.372387    0.480214    0.024306    0.023805    0.667914    
#> 186: 0.349413    1.001510    3.380703    0.474041    0.023246    0.023660    0.710126    
#> 187: 0.353670    0.974789    3.391097    0.429730    0.029614    0.024060    0.713786    
#> 188: 0.333508    0.983308    3.388835    0.388419    0.035721    0.026773    0.705326    
#> 189: 0.337085    0.993932    3.386583    0.410982    0.032643    0.025784    0.705439    
#> 190: 0.354942    0.981943    3.389871    0.421604    0.027120    0.025155    0.695417    
#> 191: 0.368032    1.000633    3.384363    0.433792    0.030933    0.024571    0.686340    
#> 192: 0.345131    1.000800    3.388356    0.393997    0.033706    0.024988    0.689746    
#> 193: 0.392721    1.010771    3.388384    0.420416    0.030367    0.025315    0.699226    
#> 194: 0.368878    0.995280    3.380877    0.392020    0.043395    0.022266    0.706718    
#> 195: 0.317168    1.004118    3.365984    0.422637    0.051415    0.016903    0.692260    
#> 196: 0.348923    0.997985    3.375966    0.480176    0.049411    0.020077    0.691476    
#> 197: 0.325507    1.006283    3.389928    0.472164    0.048565    0.021196    0.689580    
#> 198: 0.363598    0.987807    3.379632    0.495479    0.037312    0.023758    0.666355    
#> 199: 0.327965    0.986397    3.378767    0.471891    0.038764    0.024053    0.666962    
#> 200: 0.356050    0.986391    3.381307    0.530477    0.031745    0.024631    0.677915    
#> 201: 0.341673    0.983882    3.383395    0.490061    0.033002    0.027125    0.679029    
#> 202: 0.336562    0.985237    3.379711    0.471620    0.034461    0.025795    0.676447    
#> 203: 0.352889    0.985918    3.378883    0.480700    0.035493    0.024984    0.675835    
#> 204: 0.350589    0.981749    3.380119    0.491846    0.037558    0.025044    0.675868    
#> 205: 0.360819    0.987970    3.379700    0.521784    0.038520    0.024921    0.677001    
#> 206: 0.362390    0.993883    3.379245    0.528195    0.038709    0.024499    0.677172    
#> 207: 0.357096    0.996422    3.376240    0.530650    0.037908    0.023926    0.678106    
#> 208: 0.355133    0.996319    3.375599    0.530355    0.037081    0.023203    0.678722    
#> 209: 0.356762    0.994844    3.375353    0.525118    0.037465    0.022751    0.678028    
#> 210: 0.358573    0.993968    3.375722    0.526933    0.037606    0.022163    0.675789    
#> 211: 0.362424    0.993718    3.376406    0.523278    0.037474    0.022079    0.674175    
#> 212: 0.364461    0.993568    3.376641    0.522114    0.038240    0.022073    0.672792    
#> 213: 0.366293    0.992023    3.376936    0.519979    0.038745    0.022141    0.671991    
#> 214: 0.366564    0.991481    3.377692    0.516196    0.039241    0.021927    0.671612    
#> 215: 0.366974    0.991230    3.378461    0.512645    0.039833    0.021608    0.671528    
#> 216: 0.370637    0.989694    3.379564    0.509312    0.040970    0.021338    0.672417    
#> 217: 0.370805    0.990102    3.380053    0.507134    0.042367    0.021047    0.671921    
#> 218: 0.371583    0.990606    3.380072    0.502569    0.042793    0.020886    0.671455    
#> 219: 0.369962    0.990246    3.379819    0.499853    0.042991    0.020855    0.671432    
#> 220: 0.369758    0.989855    3.380237    0.499279    0.043011    0.020841    0.670937    
#> 221: 0.369692    0.989685    3.380136    0.497775    0.043277    0.020855    0.670881    
#> 222: 0.370306    0.989595    3.380326    0.494828    0.043311    0.021073    0.670859    
#> 223: 0.369985    0.990600    3.379868    0.496156    0.043378    0.021201    0.669875    
#> 224: 0.371346    0.991707    3.379864    0.494763    0.043126    0.021243    0.669312    
#> 225: 0.370024    0.991406    3.379769    0.493495    0.042961    0.021243    0.668658    
#> 226: 0.368966    0.990450    3.379382    0.493315    0.042868    0.021299    0.668562    
#> 227: 0.368729    0.990694    3.379130    0.492308    0.042658    0.021371    0.668326    
#> 228: 0.367184    0.991638    3.378601    0.490434    0.042509    0.021359    0.668478    
#> 229: 0.366071    0.991724    3.378273    0.489844    0.042214    0.021297    0.668147    
#> 230: 0.365741    0.991982    3.378028    0.491888    0.042180    0.021295    0.667483    
#> 231: 0.365590    0.992496    3.378059    0.495563    0.042150    0.021352    0.667095    
#> 232: 0.364526    0.992626    3.378178    0.493639    0.041907    0.021298    0.667104    
#> 233: 0.364486    0.992291    3.378127    0.494837    0.041647    0.021311    0.666941    
#> 234: 0.364147    0.992672    3.377982    0.495462    0.041375    0.021338    0.666772    
#> 235: 0.363384    0.992637    3.377867    0.495359    0.041230    0.021326    0.666825    
#> 236: 0.362965    0.993460    3.377278    0.495820    0.041139    0.021250    0.666920    
#> 237: 0.363907    0.993322    3.377147    0.498282    0.040947    0.021238    0.667638    
#> 238: 0.363896    0.993250    3.377383    0.497822    0.040815    0.021261    0.668352    
#> 239: 0.363420    0.993716    3.377118    0.496951    0.040764    0.021296    0.668971    
#> 240: 0.362969    0.993875    3.376844    0.496483    0.040648    0.021340    0.669061    
#> 241: 0.362903    0.993459    3.376854    0.496445    0.040397    0.021269    0.669585    
#> 242: 0.362562    0.992993    3.376667    0.495961    0.040420    0.021207    0.669887    
#> 243: 0.362642    0.993097    3.376911    0.494312    0.040299    0.021226    0.670707    
#> 244: 0.362672    0.993017    3.377094    0.492464    0.040243    0.021274    0.670709    
#> 245: 0.362986    0.992561    3.377459    0.491593    0.040251    0.021205    0.670956    
#> 246: 0.363359    0.992216    3.377789    0.490831    0.040338    0.021191    0.671081    
#> 247: 0.363240    0.991873    3.377923    0.491058    0.040295    0.021153    0.670897    
#> 248: 0.362623    0.991975    3.377810    0.489614    0.040178    0.021145    0.670847    
#> 249: 0.362416    0.991938    3.377933    0.488749    0.040204    0.021158    0.670571    
#> 250: 0.363161    0.992033    3.378276    0.489456    0.040290    0.021211    0.670528    
#> 251: 0.364288    0.992210    3.378662    0.490272    0.040250    0.021242    0.670425    
#> 252: 0.365269    0.992067    3.379005    0.491903    0.040375    0.021247    0.670532    
#> 253: 0.365306    0.992091    3.379041    0.492822    0.040465    0.021262    0.670543    
#> 254: 0.365467    0.992177    3.379068    0.492134    0.040466    0.021315    0.670257    
#> 255: 0.365442    0.992487    3.379136    0.492174    0.040240    0.021385    0.670033    
#> 256: 0.366273    0.992556    3.379129    0.492847    0.040084    0.021415    0.669879    
#> 257: 0.366246    0.992251    3.379217    0.492057    0.039997    0.021408    0.669478    
#> 258: 0.366091    0.991948    3.379275    0.491814    0.039955    0.021434    0.669262    
#> 259: 0.366422    0.991718    3.379442    0.491716    0.039846    0.021443    0.669124    
#> 260: 0.366798    0.991801    3.379538    0.491824    0.039802    0.021352    0.668945    
#> 261: 0.367150    0.991519    3.379813    0.490842    0.039674    0.021283    0.668905    
#> 262: 0.367000    0.991384    3.379917    0.490296    0.039691    0.021193    0.668946    
#> 263: 0.366086    0.991548    3.379912    0.488789    0.039663    0.021173    0.669359    
#> 264: 0.365193    0.991996    3.379599    0.488098    0.039862    0.021186    0.669505    
#> 265: 0.365158    0.992372    3.379645    0.487612    0.039923    0.021191    0.669762    
#> 266: 0.365517    0.992542    3.379789    0.487665    0.040024    0.021165    0.669821    
#> 267: 0.365469    0.992536    3.380026    0.487076    0.040036    0.021129    0.669845    
#> 268: 0.365428    0.992426    3.380113    0.486246    0.040014    0.021084    0.669590    
#> 269: 0.366428    0.992362    3.380300    0.487026    0.039884    0.021106    0.669342    
#> 270: 0.367206    0.992484    3.380410    0.488163    0.039812    0.021140    0.669118    
#> 271: 0.367342    0.992490    3.380371    0.489674    0.039794    0.021185    0.669032    
#> 272: 0.367496    0.992368    3.380294    0.490970    0.039885    0.021218    0.669313    
#> 273: 0.367317    0.992596    3.380196    0.491647    0.039897    0.021213    0.669352    
#> 274: 0.366730    0.992771    3.380103    0.493125    0.039942    0.021142    0.669324    
#> 275: 0.366620    0.993003    3.379822    0.495448    0.039903    0.021162    0.669250    
#> 276: 0.366296    0.993324    3.379722    0.497195    0.039893    0.021178    0.669139    
#> 277: 0.366314    0.993717    3.379781    0.498132    0.039853    0.021190    0.669079    
#> 278: 0.365777    0.993881    3.379704    0.497703    0.039889    0.021167    0.669014    
#> 279: 0.365109    0.993912    3.379675    0.496044    0.040009    0.021124    0.668985    
#> 280: 0.364987    0.994134    3.379683    0.494543    0.040045    0.021079    0.668891    
#> 281: 0.364789    0.994284    3.379717    0.493859    0.040140    0.021047    0.668745    
#> 282: 0.365029    0.994407    3.379806    0.494096    0.040195    0.021051    0.668719    
#> 283: 0.365409    0.994449    3.379968    0.494701    0.040318    0.021127    0.668793    
#> 284: 0.365664    0.994215    3.380061    0.495343    0.040335    0.021150    0.668595    
#> 285: 0.365944    0.994133    3.379987    0.497046    0.040359    0.021190    0.668448    
#> 286: 0.366130    0.994242    3.379818    0.498341    0.040440    0.021194    0.668594    
#> 287: 0.366251    0.994534    3.379652    0.499493    0.040522    0.021192    0.668565    
#> 288: 0.366386    0.994634    3.379556    0.500277    0.040492    0.021198    0.668524    
#> 289: 0.366980    0.994629    3.379597    0.501731    0.040510    0.021223    0.668495    
#> 290: 0.367109    0.994659    3.379633    0.501884    0.040452    0.021227    0.668676    
#> 291: 0.367328    0.994756    3.379787    0.501116    0.040409    0.021226    0.668522    
#> 292: 0.367438    0.994766    3.379890    0.500251    0.040475    0.021204    0.668448    
#> 293: 0.367648    0.994629    3.379995    0.500326    0.040415    0.021189    0.668337    
#> 294: 0.367800    0.994675    3.380005    0.500104    0.040403    0.021207    0.668224    
#> 295: 0.367866    0.994413    3.380017    0.499810    0.040365    0.021203    0.668143    
#> 296: 0.368033    0.994326    3.380043    0.499111    0.040437    0.021200    0.668169    
#> 297: 0.367979    0.994324    3.380012    0.498816    0.040472    0.021185    0.668153    
#> 298: 0.368063    0.994238    3.380053    0.498829    0.040505    0.021215    0.668023    
#> 299: 0.368310    0.994316    3.380063    0.499085    0.040460    0.021248    0.667933    
#> 300: 0.368536    0.994241    3.380199    0.498600    0.040487    0.021236    0.667783    
#> 301: 0.368763    0.994011    3.380255    0.497482    0.040476    0.021217    0.667786    
#> 302: 0.368706    0.993832    3.380224    0.496848    0.040406    0.021213    0.667660    
#> 303: 0.368617    0.993840    3.380132    0.496818    0.040371    0.021218    0.667439    
#> 304: 0.368473    0.994040    3.379990    0.496808    0.040400    0.021233    0.667354    
#> 305: 0.368247    0.993838    3.379916    0.496881    0.040415    0.021250    0.667166    
#> 306: 0.368022    0.993705    3.379843    0.496938    0.040414    0.021335    0.667008    
#> 307: 0.367629    0.993625    3.379754    0.497272    0.040353    0.021380    0.667098    
#> 308: 0.367429    0.993640    3.379602    0.497429    0.040344    0.021365    0.667193    
#> 309: 0.367370    0.993619    3.379573    0.497538    0.040382    0.021330    0.667419    
#> 310: 0.367548    0.993534    3.379507    0.498096    0.040344    0.021327    0.667563    
#> 311: 0.367458    0.993408    3.379470    0.499157    0.040271    0.021360    0.667531    
#> 312: 0.367423    0.993237    3.379387    0.499390    0.040285    0.021369    0.667527    
#> 313: 0.367231    0.993034    3.379287    0.499838    0.040363    0.021336    0.667686    
#> 314: 0.366732    0.993008    3.379195    0.499102    0.040358    0.021305    0.667689    
#> 315: 0.366212    0.993058    3.379082    0.498032    0.040381    0.021273    0.667626    
#> 316: 0.365963    0.993081    3.378984    0.497811    0.040440    0.021236    0.667585    
#> 317: 0.365867    0.993123    3.379011    0.497150    0.040500    0.021246    0.667658    
#> 318: 0.365718    0.993196    3.378940    0.496731    0.040573    0.021268    0.667547    
#> 319: 0.365628    0.993154    3.378949    0.496706    0.040594    0.021301    0.667609    
#> 320: 0.365316    0.993112    3.378844    0.497265    0.040620    0.021319    0.667606    
#> 321: 0.365125    0.993225    3.378691    0.497754    0.040720    0.021317    0.667672    
#> 322: 0.364846    0.993237    3.378534    0.497420    0.040743    0.021315    0.667826    
#> 323: 0.364428    0.993272    3.378437    0.497117    0.040760    0.021271    0.667829    
#> 324: 0.364118    0.993473    3.378371    0.496269    0.040806    0.021228    0.667820    
#> 325: 0.363862    0.993786    3.378310    0.495592    0.040876    0.021220    0.667753    
#> 326: 0.363849    0.993735    3.378233    0.495546    0.040893    0.021225    0.667725    
#> 327: 0.363978    0.993715    3.378209    0.495674    0.040969    0.021258    0.667643    
#> 328: 0.363958    0.993887    3.378080    0.495864    0.041002    0.021296    0.667583    
#> 329: 0.363999    0.993995    3.377988    0.495926    0.040921    0.021332    0.667402    
#> 330: 0.363789    0.994059    3.377936    0.496010    0.040863    0.021348    0.667319    
#> 331: 0.363915    0.994246    3.377965    0.496035    0.040822    0.021378    0.667285    
#> 332: 0.363941    0.994089    3.378008    0.496079    0.040703    0.021411    0.667355    
#> 333: 0.364271    0.993899    3.378033    0.496321    0.040610    0.021489    0.667334    
#> 334: 0.364315    0.993731    3.377996    0.496146    0.040593    0.021550    0.667207    
#> 335: 0.364304    0.993689    3.377965    0.495788    0.040524    0.021579    0.667231    
#> 336: 0.363921    0.993693    3.377927    0.495300    0.040389    0.021596    0.667350    
#> 337: 0.363580    0.993782    3.377859    0.494818    0.040289    0.021612    0.667397    
#> 338: 0.363372    0.993839    3.377894    0.494126    0.040243    0.021606    0.667394    
#> 339: 0.363121    0.993910    3.377818    0.493740    0.040271    0.021607    0.667269    
#> 340: 0.362923    0.993855    3.377737    0.493745    0.040316    0.021637    0.667231    
#> 341: 0.362723    0.993844    3.377698    0.493518    0.040326    0.021664    0.667154    
#> 342: 0.362399    0.993782    3.377606    0.493492    0.040369    0.021661    0.667054    
#> 343: 0.362300    0.993824    3.377599    0.493463    0.040406    0.021679    0.667029    
#> 344: 0.362395    0.993802    3.377572    0.494165    0.040407    0.021672    0.667000    
#> 345: 0.362571    0.993726    3.377606    0.494492    0.040419    0.021683    0.666964    
#> 346: 0.362645    0.993757    3.377526    0.494539    0.040406    0.021683    0.666902    
#> 347: 0.362437    0.993575    3.377457    0.493832    0.040409    0.021692    0.666937    
#> 348: 0.362214    0.993535    3.377461    0.493671    0.040503    0.021720    0.666964    
#> 349: 0.361999    0.993428    3.377435    0.493618    0.040578    0.021736    0.666882    
#> 350: 0.361794    0.993237    3.377402    0.493132    0.040604    0.021750    0.666835    
#> 351: 0.361669    0.993335    3.377392    0.492827    0.040632    0.021742    0.666887    
#> 352: 0.361673    0.993448    3.377363    0.492357    0.040630    0.021744    0.667044    
#> 353: 0.361777    0.993621    3.377382    0.492078    0.040618    0.021757    0.667054    
#> 354: 0.361789    0.993651    3.377362    0.492057    0.040615    0.021760    0.666951    
#> 355: 0.362031    0.993615    3.377343    0.491769    0.040619    0.021730    0.666945    
#> 356: 0.361943    0.993592    3.377330    0.491544    0.040619    0.021708    0.667068    
#> 357: 0.361834    0.993611    3.377293    0.491273    0.040599    0.021695    0.666945    
#> 358: 0.361859    0.993625    3.377338    0.491043    0.040616    0.021690    0.666791    
#> 359: 0.361991    0.993639    3.377341    0.491215    0.040614    0.021686    0.666699    
#> 360: 0.362020    0.993647    3.377260    0.491438    0.040605    0.021668    0.666597    
#> 361: 0.362214    0.993670    3.377223    0.491749    0.040595    0.021676    0.666465    
#> 362: 0.362403    0.993628    3.377244    0.492089    0.040582    0.021651    0.666354    
#> 363: 0.362672    0.993582    3.377311    0.492601    0.040577    0.021672    0.666196    
#> 364: 0.363004    0.993579    3.377331    0.492715    0.040593    0.021667    0.666161    
#> 365: 0.363249    0.993421    3.377426    0.492934    0.040558    0.021665    0.666343    
#> 366: 0.363627    0.993293    3.377453    0.493437    0.040527    0.021665    0.666408    
#> 367: 0.363568    0.993271    3.377408    0.493127    0.040477    0.021631    0.666436    
#> 368: 0.363587    0.993339    3.377356    0.492944    0.040474    0.021633    0.666380    
#> 369: 0.363427    0.993423    3.377341    0.492860    0.040486    0.021631    0.666389    
#> 370: 0.363256    0.993555    3.377302    0.492230    0.040523    0.021594    0.666442    
#> 371: 0.363046    0.993680    3.377225    0.492176    0.040528    0.021586    0.666436    
#> 372: 0.362675    0.993761    3.377143    0.492114    0.040528    0.021568    0.666431    
#> 373: 0.362268    0.993938    3.377025    0.492191    0.040493    0.021565    0.666488    
#> 374: 0.362082    0.993999    3.376927    0.492274    0.040432    0.021567    0.666504    
#> 375: 0.361888    0.994097    3.376863    0.492223    0.040452    0.021566    0.666490    
#> 376: 0.361689    0.994187    3.376791    0.492313    0.040426    0.021580    0.666435    
#> 377: 0.361591    0.994251    3.376731    0.492344    0.040383    0.021590    0.666371    
#> 378: 0.361531    0.994222    3.376711    0.492508    0.040376    0.021585    0.666401    
#> 379: 0.361296    0.994031    3.376735    0.492596    0.040367    0.021597    0.666390    
#> 380: 0.361237    0.993955    3.376760    0.492424    0.040353    0.021594    0.666369    
#> 381: 0.361024    0.993877    3.376753    0.492709    0.040348    0.021580    0.666440    
#> 382: 0.360959    0.993858    3.376776    0.492616    0.040333    0.021569    0.666402    
#> 383: 0.360847    0.993921    3.376753    0.492706    0.040333    0.021583    0.666281    
#> 384: 0.360603    0.994017    3.376690    0.492541    0.040304    0.021587    0.666299    
#> 385: 0.360479    0.994046    3.376603    0.492430    0.040275    0.021625    0.666288    
#> 386: 0.360412    0.994160    3.376545    0.492700    0.040280    0.021646    0.666294    
#> 387: 0.360638    0.994242    3.376604    0.493299    0.040287    0.021659    0.666283    
#> 388: 0.360831    0.994391    3.376646    0.494069    0.040303    0.021687    0.666217    
#> 389: 0.360845    0.994303    3.376632    0.494554    0.040352    0.021710    0.666241    
#> 390: 0.360714    0.994392    3.376507    0.495061    0.040421    0.021706    0.666237    
#> 391: 0.360606    0.994445    3.376425    0.495059    0.040471    0.021690    0.666216    
#> 392: 0.360319    0.994522    3.376378    0.494572    0.040500    0.021678    0.666229    
#> 393: 0.360110    0.994521    3.376259    0.494451    0.040531    0.021658    0.666264    
#> 394: 0.360050    0.994556    3.376202    0.494507    0.040513    0.021672    0.666236    
#> 395: 0.359981    0.994630    3.376166    0.494626    0.040497    0.021692    0.666163    
#> 396: 0.360032    0.994692    3.376136    0.494848    0.040505    0.021706    0.666103    
#> 397: 0.360093    0.994675    3.376138    0.495142    0.040529    0.021696    0.666065    
#> 398: 0.360256    0.994662    3.376142    0.495721    0.040542    0.021694    0.666062    
#> 399: 0.360167    0.994684    3.376158    0.496037    0.040542    0.021694    0.665960    
#> 400: 0.360156    0.994789    3.376149    0.495984    0.040530    0.021700    0.665930    
#> 401: 0.360169    0.994906    3.376086    0.495935    0.040561    0.021711    0.665969    
#> 402: 0.360192    0.995008    3.376013    0.495905    0.040564    0.021730    0.665969    
#> 403: 0.360062    0.995102    3.375948    0.495879    0.040519    0.021736    0.665974    
#> 404: 0.359893    0.995231    3.375851    0.495771    0.040472    0.021726    0.666001    
#> 405: 0.359808    0.995338    3.375828    0.495843    0.040410    0.021731    0.665997    
#> 406: 0.359687    0.995393    3.375795    0.495543    0.040394    0.021729    0.666019    
#> 407: 0.359703    0.995377    3.375841    0.495313    0.040389    0.021723    0.665985    
#> 408: 0.359918    0.995393    3.375872    0.495223    0.040384    0.021727    0.665986    
#> 409: 0.360013    0.995366    3.375909    0.495074    0.040385    0.021718    0.665988    
#> 410: 0.360100    0.995345    3.375916    0.494576    0.040413    0.021683    0.666097    
#> 411: 0.360227    0.995179    3.375981    0.494475    0.040444    0.021686    0.666122    
#> 412: 0.360154    0.995163    3.375983    0.494426    0.040441    0.021689    0.666162    
#> 413: 0.360069    0.995224    3.375942    0.494546    0.040420    0.021692    0.666151    
#> 414: 0.359834    0.995297    3.375924    0.494264    0.040389    0.021707    0.666220    
#> 415: 0.359766    0.995375    3.375873    0.494034    0.040357    0.021708    0.666234    
#> 416: 0.359645    0.995445    3.375866    0.493861    0.040327    0.021718    0.666266    
#> 417: 0.359686    0.995457    3.375834    0.494130    0.040278    0.021709    0.666276    
#> 418: 0.359797    0.995414    3.375873    0.494310    0.040246    0.021699    0.666211    
#> 419: 0.359844    0.995467    3.375879    0.494262    0.040261    0.021699    0.666154    
#> 420: 0.359976    0.995471    3.375921    0.494208    0.040253    0.021696    0.666121    
#> 421: 0.359877    0.995495    3.375959    0.494389    0.040227    0.021700    0.666071    
#> 422: 0.360034    0.995417    3.376024    0.494553    0.040221    0.021727    0.665979    
#> 423: 0.360242    0.995296    3.376078    0.494484    0.040243    0.021727    0.666027    
#> 424: 0.360269    0.995236    3.376037    0.494515    0.040244    0.021732    0.666079    
#> 425: 0.360206    0.995292    3.375990    0.494357    0.040248    0.021751    0.666139    
#> 426: 0.360152    0.995364    3.375964    0.494261    0.040224    0.021737    0.666100    
#> 427: 0.359977    0.995402    3.375963    0.494043    0.040215    0.021727    0.666124    
#> 428: 0.359855    0.995470    3.375958    0.493616    0.040181    0.021718    0.666155    
#> 429: 0.359751    0.995536    3.375970    0.493308    0.040170    0.021719    0.666147    
#> 430: 0.359704    0.995559    3.375963    0.493275    0.040123    0.021729    0.666187    
#> 431: 0.359698    0.995559    3.375921    0.493225    0.040107    0.021707    0.666158    
#> 432: 0.359567    0.995640    3.375919    0.493165    0.040121    0.021702    0.666124    
#> 433: 0.359552    0.995788    3.375910    0.493066    0.040135    0.021689    0.666172    
#> 434: 0.359474    0.995725    3.375920    0.492981    0.040147    0.021672    0.666151    
#> 435: 0.359421    0.995711    3.375906    0.492810    0.040174    0.021654    0.666108    
#> 436: 0.359418    0.995653    3.375976    0.492595    0.040200    0.021648    0.666090    
#> 437: 0.359468    0.995620    3.375954    0.492555    0.040222    0.021660    0.666072    
#> 438: 0.359512    0.995768    3.375954    0.492651    0.040203    0.021653    0.666071    
#> 439: 0.359453    0.995912    3.375924    0.492313    0.040198    0.021646    0.666127    
#> 440: 0.359372    0.996036    3.375929    0.492080    0.040195    0.021636    0.666187    
#> 441: 0.359333    0.996041    3.375900    0.491755    0.040165    0.021632    0.666215    
#> 442: 0.359193    0.996129    3.375896    0.491552    0.040184    0.021628    0.666200    
#> 443: 0.359100    0.996232    3.375824    0.491496    0.040161    0.021634    0.666160    
#> 444: 0.358915    0.996339    3.375747    0.491377    0.040123    0.021646    0.666078    
#> 445: 0.358642    0.996434    3.375647    0.491167    0.040064    0.021670    0.666073    
#> 446: 0.358434    0.996534    3.375544    0.491380    0.040028    0.021680    0.666040    
#> 447: 0.358196    0.996621    3.375434    0.491270    0.040019    0.021676    0.666072    
#> 448: 0.357999    0.996684    3.375418    0.491361    0.040028    0.021678    0.666028    
#> 449: 0.358002    0.996740    3.375492    0.491257    0.040049    0.021664    0.666076    
#> 450: 0.358029    0.996736    3.375538    0.490912    0.040060    0.021664    0.666112    
#> 451: 0.358096    0.996777    3.375561    0.490864    0.040072    0.021657    0.666191    
#> 452: 0.358171    0.996761    3.375580    0.490812    0.040069    0.021642    0.666151    
#> 453: 0.358197    0.996787    3.375588    0.490920    0.040058    0.021633    0.666089    
#> 454: 0.358213    0.996867    3.375588    0.490918    0.040026    0.021641    0.666027    
#> 455: 0.358349    0.996858    3.375632    0.491073    0.040004    0.021644    0.665959    
#> 456: 0.358427    0.996832    3.375650    0.491325    0.039995    0.021646    0.665960    
#> 457: 0.358371    0.996801    3.375654    0.491257    0.039989    0.021662    0.665886    
#> 458: 0.358430    0.996914    3.375662    0.491293    0.039996    0.021659    0.665848    
#> 459: 0.358071    0.997019    3.375616    0.491041    0.040004    0.021639    0.665904    
#> 460: 0.357763    0.997073    3.375530    0.490853    0.040064    0.021619    0.665889    
#> 461: 0.357545    0.997122    3.375509    0.490697    0.040077    0.021612    0.665861    
#> 462: 0.357425    0.997191    3.375527    0.490725    0.040082    0.021618    0.665831    
#> 463: 0.357435    0.997232    3.375539    0.490854    0.040096    0.021620    0.665788    
#> 464: 0.357454    0.997194    3.375541    0.490866    0.040075    0.021624    0.665764    
#> 465: 0.357564    0.997049    3.375581    0.490863    0.040059    0.021629    0.665728    
#> 466: 0.357638    0.997018    3.375588    0.490856    0.040036    0.021629    0.665737    
#> 467: 0.357546    0.997003    3.375586    0.490948    0.039988    0.021631    0.665700    
#> 468: 0.357746    0.996983    3.375611    0.491307    0.039949    0.021618    0.665770    
#> 469: 0.357699    0.997014    3.375622    0.491159    0.039940    0.021609    0.665872    
#> 470: 0.357661    0.997026    3.375609    0.491246    0.039933    0.021616    0.665922    
#> 471: 0.357635    0.997042    3.375576    0.491335    0.039902    0.021621    0.665985    
#> 472: 0.357522    0.997061    3.375536    0.491446    0.039909    0.021612    0.665982    
#> 473: 0.357354    0.997084    3.375488    0.491371    0.039917    0.021599    0.665930    
#> 474: 0.357189    0.997094    3.375429    0.491390    0.039927    0.021588    0.665957    
#> 475: 0.357243    0.997109    3.375428    0.491339    0.039942    0.021586    0.665919    
#> 476: 0.357249    0.997094    3.375438    0.491493    0.039948    0.021581    0.665942    
#> 477: 0.357228    0.997122    3.375469    0.491212    0.039957    0.021578    0.665924    
#> 478: 0.357159    0.997079    3.375485    0.490846    0.039952    0.021576    0.665943    
#> 479: 0.357233    0.997050    3.375499    0.490633    0.039952    0.021568    0.665959    
#> 480: 0.357273    0.997070    3.375486    0.490458    0.040012    0.021557    0.665974    
#> 481: 0.357258    0.997085    3.375484    0.490279    0.040022    0.021533    0.665975    
#> 482: 0.357235    0.997105    3.375454    0.490016    0.040044    0.021505    0.665999    
#> 483: 0.357134    0.997096    3.375465    0.489859    0.040076    0.021478    0.666008    
#> 484: 0.357125    0.997004    3.375488    0.489677    0.040083    0.021462    0.666021    
#> 485: 0.357122    0.996988    3.375517    0.489501    0.040095    0.021460    0.666026    
#> 486: 0.357178    0.997017    3.375592    0.489523    0.040111    0.021449    0.666036    
#> 487: 0.357278    0.997034    3.375668    0.489289    0.040127    0.021438    0.666068    
#> 488: 0.357240    0.996961    3.375709    0.489185    0.040120    0.021428    0.666055    
#> 489: 0.357375    0.996848    3.375745    0.489156    0.040125    0.021430    0.666104    
#> 490: 0.357561    0.996787    3.375782    0.489295    0.040132    0.021424    0.666091    
#> 491: 0.357738    0.996780    3.375854    0.489314    0.040093    0.021441    0.666058    
#> 492: 0.357854    0.996815    3.375892    0.489130    0.040112    0.021443    0.666095    
#> 493: 0.357834    0.996824    3.375908    0.488963    0.040119    0.021452    0.666033    
#> 494: 0.357970    0.996825    3.375914    0.488913    0.040140    0.021447    0.665949    
#> 495: 0.358116    0.996851    3.375918    0.488837    0.040131    0.021437    0.665895    
#> 496: 0.358288    0.996894    3.375935    0.488883    0.040125    0.021425    0.665875    
#> 497: 0.358193    0.996886    3.375937    0.488557    0.040104    0.021426    0.665943    
#> 498: 0.358301    0.996891    3.375957    0.488622    0.040105    0.021432    0.665885    
#> 499: 0.358281    0.996922    3.375923    0.488542    0.040118    0.021438    0.665858    
#> 500: 0.358227    0.996941    3.375899    0.488489    0.040129    0.021438    0.665827    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.294497    0.962941    3.441558    0.392401    0.074566    0.016800    1.849466    
#> 002: 0.358245    1.042516    3.439993    0.372781    0.070838    0.015960    1.218211    
#> 003: 0.569918    1.001323    3.468951    0.453064    0.067296    0.015162    0.846196    
#> 004: 0.544769    0.990764    3.457846    0.570438    0.063931    0.014404    0.753565    
#> 005: 0.606312    0.993520    3.449519    0.729771    0.060735    0.013684    0.708648    
#> 006: 0.578225    0.987742    3.430862    0.795260    0.057698    0.013000    0.685389    
#> 007: 0.586521    1.003470    3.422951    0.849829    0.055523    0.012350    0.679317    
#> 008: 0.565373    0.993988    3.429589    0.807337    0.057941    0.011732    0.674547    
#> 009: 0.531962    0.973279    3.419052    0.766971    0.055044    0.011146    0.678314    
#> 010: 0.579168    0.976614    3.423232    0.829609    0.052292    0.010588    0.683335    
#> 011: 0.640124    0.985871    3.437597    0.897146    0.049677    0.010059    0.684869    
#> 012: 0.588271    0.970258    3.428464    0.895814    0.047194    0.009556    0.690127    
#> 013: 0.568640    0.972814    3.436084    0.851024    0.044834    0.009083    0.684559    
#> 014: 0.628243    0.968000    3.442506    1.000886    0.042592    0.008629    0.689794    
#> 015: 0.636589    0.970108    3.453034    0.950841    0.044258    0.008197    0.678996    
#> 016: 0.641040    0.972877    3.458755    0.927188    0.052593    0.007788    0.662879    
#> 017: 0.623424    0.966656    3.459275    0.880829    0.052221    0.007398    0.670167    
#> 018: 0.663030    0.958109    3.451527    0.868134    0.049610    0.007028    0.679501    
#> 019: 0.641183    0.969997    3.447872    0.900203    0.048021    0.006677    0.660705    
#> 020: 0.667988    0.947890    3.457391    0.855193    0.045620    0.008161    0.670688    
#> 021: 0.649696    0.936044    3.468104    0.872594    0.043495    0.007753    0.663265    
#> 022: 0.723034    0.932943    3.475957    0.917390    0.041321    0.007365    0.665618    
#> 023: 0.773074    0.951466    3.483053    0.965434    0.053559    0.007859    0.671191    
#> 024: 0.745061    0.974513    3.475592    0.976025    0.052741    0.007517    0.647101    
#> 025: 0.737516    0.962614    3.461822    1.042672    0.050104    0.007141    0.657612    
#> 026: 0.691869    0.983972    3.444098    1.122624    0.047776    0.006784    0.668805    
#> 027: 0.673403    0.985375    3.450645    1.066493    0.054707    0.006706    0.657213    
#> 028: 0.745325    0.981958    3.450850    1.228049    0.059654    0.006370    0.643201    
#> 029: 0.735153    0.976072    3.445415    1.288099    0.056671    0.007172    0.647872    
#> 030: 0.764239    0.983978    3.440926    1.464767    0.053837    0.007178    0.667211    
#> 031: 0.709577    0.966351    3.447316    1.391529    0.051146    0.006819    0.669451    
#> 032: 0.629945    0.972716    3.449144    1.321952    0.052425    0.006478    0.667885    
#> 033: 0.684670    0.975850    3.449274    1.255855    0.054807    0.006154    0.650602    
#> 034: 0.729399    0.996870    3.448633    1.193062    0.052067    0.006912    0.666460    
#> 035: 0.659503    0.970231    3.444576    1.133409    0.049464    0.006567    0.647126    
#> 036: 0.656599    0.964703    3.452518    1.076738    0.049014    0.006238    0.668664    
#> 037: 0.688725    0.983181    3.455355    1.022902    0.048592    0.005926    0.687544    
#> 038: 0.652324    0.980321    3.447828    1.006698    0.053973    0.006142    0.674484    
#> 039: 0.717981    0.994190    3.450161    1.312298    0.053351    0.006058    0.669440    
#> 040: 0.691825    0.981202    3.444009    1.246683    0.050683    0.005755    0.674862    
#> 041: 0.664814    0.959494    3.450113    1.184349    0.056448    0.005468    0.667815    
#> 042: 0.729303    0.977385    3.443318    1.185668    0.053626    0.006136    0.664454    
#> 043: 0.636585    0.995987    3.437668    1.126385    0.050944    0.006145    0.667562    
#> 044: 0.671312    1.002593    3.439487    1.070065    0.048397    0.005838    0.664490    
#> 045: 0.669857    1.003312    3.439422    1.017515    0.051281    0.005546    0.654656    
#> 046: 0.734159    0.969687    3.444325    1.161564    0.048717    0.005269    0.652419    
#> 047: 0.721047    0.990960    3.433491    1.110378    0.052223    0.005351    0.662018    
#> 048: 0.630007    0.986001    3.427579    1.054860    0.052709    0.005272    0.660725    
#> 049: 0.580809    0.966980    3.434708    1.002117    0.050073    0.005046    0.655930    
#> 050: 0.679926    0.947980    3.434217    1.127346    0.055735    0.005430    0.675633    
#> 051: 0.632198    0.960467    3.437053    1.070979    0.058485    0.005975    0.684692    
#> 052: 0.649973    0.981601    3.445713    1.017430    0.060080    0.006114    0.670055    
#> 053: 0.676173    0.967220    3.449089    0.966558    0.057437    0.005808    0.666436    
#> 054: 0.633740    0.967863    3.453462    0.918230    0.055851    0.005518    0.674242    
#> 055: 0.604777    0.977282    3.437205    0.872319    0.061508    0.005242    0.676888    
#> 056: 0.648940    0.986314    3.441359    0.902950    0.062493    0.004980    0.695853    
#> 057: 0.637186    0.982035    3.448879    0.872491    0.064985    0.004731    0.671806    
#> 058: 0.616815    0.989864    3.442416    0.828866    0.061735    0.004858    0.673749    
#> 059: 0.655324    0.947225    3.448969    0.951857    0.058649    0.007130    0.681571    
#> 060: 0.692850    0.937818    3.458060    0.931776    0.061091    0.007776    0.680172    
#> 061: 0.743973    0.968619    3.461974    1.167998    0.058656    0.007387    0.681157    
#> 062: 0.730657    0.986589    3.459778    1.109598    0.071974    0.008270    0.686760    
#> 063: 0.760193    0.958508    3.457979    1.252441    0.068375    0.008781    0.701211    
#> 064: 0.680368    0.948470    3.460031    1.189819    0.064956    0.008616    0.688031    
#> 065: 0.704357    0.967008    3.438922    1.130328    0.063771    0.008185    0.670216    
#> 066: 0.704872    0.980362    3.443075    1.169121    0.060582    0.009384    0.655803    
#> 067: 0.654042    0.982325    3.441860    1.110665    0.057553    0.010036    0.654392    
#> 068: 0.613009    0.979907    3.448971    1.055131    0.056049    0.009534    0.667518    
#> 069: 0.623725    0.974933    3.432542    1.002375    0.053247    0.009057    0.663387    
#> 070: 0.637730    0.977071    3.446852    0.996620    0.063983    0.008605    0.674403    
#> 071: 0.633238    1.018179    3.425590    0.977089    0.070168    0.008174    0.671246    
#> 072: 0.581369    0.992262    3.425314    0.995513    0.066659    0.007766    0.687218    
#> 073: 0.637167    0.976615    3.449511    0.985601    0.063326    0.007377    0.674026    
#> 074: 0.606509    0.963633    3.440709    0.936321    0.060160    0.007008    0.664822    
#> 075: 0.666731    0.957922    3.453738    1.045620    0.057152    0.006658    0.698244    
#> 076: 0.653241    0.978427    3.453723    0.993339    0.054294    0.006325    0.681061    
#> 077: 0.679979    0.954229    3.445716    0.943672    0.051580    0.007780    0.692923    
#> 078: 0.688921    0.966508    3.457147    0.917550    0.049001    0.008873    0.663640    
#> 079: 0.754147    0.988823    3.459834    1.113731    0.050076    0.008430    0.684090    
#> 080: 0.744992    0.978506    3.458827    1.189715    0.050959    0.008008    0.701769    
#> 081: 0.609985    0.985444    3.444684    1.130229    0.048411    0.007608    0.683434    
#> 082: 0.633194    0.977645    3.461424    1.073718    0.051046    0.007227    0.686320    
#> 083: 0.668514    0.968528    3.469722    1.020032    0.048493    0.006866    0.676561    
#> 084: 0.683696    0.968754    3.462607    0.969030    0.058549    0.006604    0.698153    
#> 085: 0.684674    0.962307    3.467068    0.992271    0.070756    0.006593    0.666921    
#> 086: 0.727819    0.963062    3.462996    1.045844    0.067218    0.006263    0.654431    
#> 087: 0.637221    0.957240    3.455296    0.993552    0.063857    0.005950    0.659761    
#> 088: 0.678527    0.942537    3.462564    0.973695    0.060664    0.005653    0.666688    
#> 089: 0.706195    0.972632    3.446426    1.070107    0.057631    0.005370    0.660740    
#> 090: 0.674432    0.971528    3.447164    1.016602    0.065918    0.005101    0.663138    
#> 091: 0.688427    0.954562    3.437149    1.054988    0.062622    0.004846    0.668902    
#> 092: 0.662952    0.980927    3.442850    1.002239    0.059491    0.005636    0.665174    
#> 093: 0.602824    0.974714    3.440374    0.952127    0.056517    0.006090    0.685632    
#> 094: 0.572119    0.989662    3.432670    0.904520    0.053691    0.007014    0.676158    
#> 095: 0.626360    0.990283    3.433192    0.977627    0.051006    0.007921    0.655964    
#> 096: 0.665562    0.990361    3.437920    1.067702    0.053225    0.007867    0.656158    
#> 097: 0.627411    1.016232    3.428629    1.029691    0.050564    0.007473    0.663271    
#> 098: 0.682301    1.012677    3.442335    1.039796    0.052079    0.007591    0.665200    
#> 099: 0.637331    0.971576    3.437398    0.987806    0.057716    0.007212    0.680399    
#> 100: 0.643387    0.981263    3.435135    1.029695    0.064508    0.006851    0.658227    
#> 101: 0.572426    0.981617    3.417735    0.978210    0.061283    0.006509    0.656067    
#> 102: 0.591195    0.977821    3.416046    0.929300    0.058219    0.006183    0.657261    
#> 103: 0.579683    0.997676    3.421472    0.882835    0.055308    0.005874    0.657507    
#> 104: 0.645198    0.983517    3.432410    1.071305    0.052543    0.005580    0.662365    
#> 105: 0.691097    0.980844    3.434025    1.162559    0.055636    0.005301    0.674057    
#> 106: 0.735567    0.976459    3.429378    1.467507    0.055113    0.005319    0.672400    
#> 107: 0.801162    0.992514    3.436813    1.622350    0.056879    0.005895    0.671389    
#> 108: 0.676552    0.994787    3.433859    1.541232    0.062875    0.005628    0.672465    
#> 109: 0.685651    0.988009    3.437559    1.464171    0.062915    0.005346    0.673015    
#> 110: 0.665142    0.992443    3.425730    1.390962    0.059769    0.005079    0.675220    
#> 111: 0.654185    0.994280    3.432662    1.321414    0.056781    0.004825    0.677915    
#> 112: 0.595245    0.968745    3.435470    1.255343    0.062305    0.004584    0.680701    
#> 113: 0.556626    0.999909    3.433997    1.192576    0.059189    0.004550    0.660975    
#> 114: 0.633081    0.981362    3.434054    1.132947    0.056230    0.004323    0.654654    
#> 115: 0.716146    0.958097    3.439021    1.213800    0.053418    0.004107    0.674043    
#> 116: 0.766742    0.992174    3.440214    1.516792    0.053527    0.004069    0.654801    
#> 117: 0.719734    1.000452    3.441467    1.440952    0.050850    0.004698    0.653303    
#> 118: 0.713623    0.988256    3.439795    1.368904    0.048308    0.004463    0.663828    
#> 119: 0.647544    0.998117    3.435746    1.300459    0.051991    0.004240    0.677782    
#> 120: 0.652904    0.981650    3.435744    1.235436    0.049724    0.004028    0.677529    
#> 121: 0.658003    1.014001    3.431145    1.173664    0.057073    0.003879    0.670091    
#> 122: 0.617048    0.990690    3.437569    1.114981    0.057685    0.005099    0.673299    
#> 123: 0.671489    1.008635    3.435634    1.059232    0.060817    0.005457    0.675466    
#> 124: 0.629252    1.016046    3.431840    1.007124    0.057776    0.005443    0.656463    
#> 125: 0.716170    1.010592    3.432650    1.210520    0.054887    0.007290    0.644962    
#> 126: 0.664341    1.017044    3.424860    1.149994    0.052143    0.007166    0.656897    
#> 127: 0.744875    1.003260    3.424013    1.274726    0.049536    0.006808    0.663035    
#> 128: 0.725205    0.992941    3.443900    1.378966    0.052788    0.006468    0.658188    
#> 129: 0.680345    0.993351    3.449801    1.310018    0.050149    0.007114    0.663894    
#> 130: 0.733511    1.003794    3.447640    1.244517    0.049446    0.006759    0.657109    
#> 131: 0.635541    0.973092    3.443009    1.182291    0.052914    0.006421    0.645199    
#> 132: 0.620587    0.977967    3.437333    1.123177    0.050268    0.006100    0.659600    
#> 133: 0.639131    0.966815    3.438005    1.067018    0.047755    0.006028    0.653251    
#> 134: 0.613207    0.952567    3.442457    1.013667    0.045367    0.007306    0.663252    
#> 135: 0.616989    0.969385    3.447409    0.962984    0.048243    0.007097    0.672602    
#> 136: 0.613628    0.960377    3.449647    0.914834    0.057068    0.006742    0.673667    
#> 137: 0.660082    0.960854    3.453497    0.904802    0.054215    0.008416    0.673659    
#> 138: 0.646554    0.980034    3.454237    0.859562    0.051504    0.008022    0.674718    
#> 139: 0.663896    0.985473    3.463436    0.883192    0.055085    0.007621    0.678598    
#> 140: 0.678577    0.970113    3.463191    0.939687    0.064185    0.007240    0.679212    
#> 141: 0.670519    0.960167    3.465555    0.943574    0.061696    0.006878    0.667561    
#> 142: 0.705722    0.926795    3.474466    0.984972    0.058611    0.006534    0.667516    
#> 143: 0.634638    0.951537    3.473819    0.972564    0.055680    0.008988    0.678347    
#> 144: 0.726935    0.970585    3.466960    1.083280    0.052896    0.008539    0.657320    
#> 145: 0.713830    0.991238    3.454283    1.070427    0.050252    0.008112    0.670240    
#> 146: 0.700289    0.978659    3.461767    1.016906    0.047739    0.008766    0.659424    
#> 147: 0.639673    0.966402    3.452173    0.966060    0.045352    0.008984    0.640302    
#> 148: 0.612714    0.969908    3.458308    0.917757    0.046457    0.008535    0.653079    
#> 149: 0.649444    0.961724    3.462221    0.871870    0.044134    0.008108    0.657454    
#> 150: 0.687732    0.957321    3.451075    0.905375    0.041927    0.007702    0.674005    
#> 151: 0.641928    0.981637    3.443687    0.935879    0.039831    0.007317    0.674848    
#> 152: 0.575143    0.979083    3.438720    0.841494    0.038025    0.007214    0.681221    
#> 153: 0.584471    1.019936    3.437111    0.793733    0.058452    0.006049    0.663777    
#> 154: 0.597931    1.016434    3.437741    0.821412    0.055983    0.005428    0.668718    
#> 155: 0.599736    0.986891    3.435554    0.781200    0.053379    0.004499    0.671604    
#> 156: 0.631199    1.002287    3.446103    0.784846    0.052926    0.004848    0.668255    
#> 157: 0.624396    0.995944    3.455987    0.821902    0.063266    0.005606    0.670661    
#> 158: 0.642212    0.992973    3.450779    0.785097    0.051212    0.005922    0.671212    
#> 159: 0.621556    0.989094    3.457892    0.858704    0.053029    0.006007    0.663028    
#> 160: 0.662897    0.967705    3.461347    0.942091    0.048771    0.006333    0.649642    
#> 161: 0.663486    0.969817    3.453691    0.920463    0.046148    0.006058    0.659804    
#> 162: 0.641765    0.989011    3.439205    0.834255    0.045904    0.005825    0.683801    
#> 163: 0.602914    0.978784    3.431820    0.831147    0.048844    0.006318    0.673132    
#> 164: 0.658831    0.980746    3.445054    0.981628    0.047346    0.006254    0.667886    
#> 165: 0.705876    0.957914    3.452773    1.104786    0.047784    0.007876    0.673648    
#> 166: 0.790366    0.995909    3.450931    1.268379    0.053774    0.006800    0.668416    
#> 167: 0.774638    0.999413    3.458139    1.363262    0.050887    0.006401    0.668141    
#> 168: 0.739509    0.986519    3.459842    1.112455    0.063257    0.005909    0.665481    
#> 169: 0.715698    0.999889    3.457250    1.162339    0.063662    0.005005    0.678528    
#> 170: 0.694189    0.964331    3.459455    0.935667    0.062874    0.005199    0.675034    
#> 171: 0.650347    0.964087    3.459987    0.827713    0.052594    0.004174    0.668834    
#> 172: 0.586656    0.972301    3.456647    0.760326    0.048177    0.003975    0.660385    
#> 173: 0.626284    0.995421    3.448907    0.819185    0.060166    0.003844    0.656997    
#> 174: 0.680530    0.966432    3.451711    0.856717    0.055828    0.003961    0.652055    
#> 175: 0.626775    0.983526    3.443194    0.859443    0.065729    0.003049    0.670223    
#> 176: 0.691125    0.985332    3.445923    1.024433    0.050726    0.002581    0.668516    
#> 177: 0.663650    0.968822    3.450754    0.953606    0.046856    0.002001    0.683830    
#> 178: 0.682349    0.966496    3.451926    0.860543    0.050537    0.002534    0.673527    
#> 179: 0.717435    0.990733    3.450400    1.129759    0.052386    0.003143    0.677551    
#> 180: 0.648762    0.996440    3.443971    0.994431    0.045534    0.003518    0.669843    
#> 181: 0.652115    0.978144    3.431052    1.007353    0.052286    0.003828    0.661343    
#> 182: 0.558961    0.986863    3.424384    0.772144    0.058200    0.004450    0.666021    
#> 183: 0.602813    0.989359    3.424230    0.834759    0.054488    0.004552    0.662832    
#> 184: 0.577253    0.979218    3.429010    0.736990    0.050181    0.003841    0.677865    
#> 185: 0.574860    0.999535    3.423137    0.824508    0.051623    0.003202    0.684730    
#> 186: 0.587062    1.018888    3.422987    0.859181    0.057001    0.002831    0.690349    
#> 187: 0.598485    1.017425    3.428657    0.830623    0.050366    0.002082    0.674633    
#> 188: 0.583756    1.014052    3.421042    0.811424    0.054862    0.001699    0.686162    
#> 189: 0.611670    1.016906    3.423580    0.880046    0.057773    0.001353    0.699744    
#> 190: 0.635043    1.004720    3.425547    0.962536    0.046329    0.001202    0.678955    
#> 191: 0.641857    1.003180    3.423344    1.003409    0.048698    0.001352    0.680597    
#> 192: 0.595333    0.985625    3.426499    0.860238    0.056041    0.001719    0.676203    
#> 193: 0.643393    1.012622    3.427530    0.965371    0.055462    0.001560    0.661844    
#> 194: 0.591532    0.990482    3.426790    0.850712    0.077247    0.001887    0.664516    
#> 195: 0.603969    0.992070    3.421223    0.933459    0.085059    0.001992    0.673620    
#> 196: 0.609138    0.990518    3.425440    0.840519    0.079054    0.001595    0.683040    
#> 197: 0.597374    0.991244    3.430454    0.867472    0.074558    0.001507    0.694524    
#> 198: 0.643604    0.984430    3.425977    1.054234    0.061448    0.001796    0.674352    
#> 199: 0.627219    0.988146    3.428819    1.096566    0.057447    0.001859    0.672709    
#> 200: 0.602877    1.004740    3.433297    0.959319    0.066796    0.001554    0.686432    
#> 201: 0.589663    0.996155    3.435110    0.834618    0.061352    0.001780    0.678452    
#> 202: 0.612752    0.996926    3.435206    0.894223    0.065384    0.001830    0.678179    
#> 203: 0.623260    0.996032    3.434890    0.915566    0.065342    0.001898    0.675696    
#> 204: 0.637096    0.991409    3.435991    0.940879    0.065287    0.002005    0.676341    
#> 205: 0.642171    0.994828    3.436503    0.937827    0.064939    0.002079    0.677723    
#> 206: 0.640376    0.996835    3.437816    0.913674    0.064979    0.002064    0.679066    
#> 207: 0.640689    0.996785    3.437808    0.936113    0.064781    0.002062    0.679655    
#> 208: 0.642894    0.994374    3.438413    0.934608    0.064410    0.002099    0.677853    
#> 209: 0.643466    0.990273    3.439209    0.929968    0.064813    0.002122    0.677822    
#> 210: 0.643264    0.987475    3.439893    0.924853    0.064128    0.002158    0.678418    
#> 211: 0.643435    0.987413    3.440979    0.913881    0.063624    0.002167    0.678615    
#> 212: 0.647845    0.985728    3.441588    0.921655    0.063309    0.002213    0.677535    
#> 213: 0.652579    0.983020    3.441894    0.935444    0.063608    0.002286    0.676866    
#> 214: 0.652632    0.981510    3.442007    0.933175    0.062933    0.002365    0.675495    
#> 215: 0.653631    0.980748    3.442123    0.935640    0.062111    0.002434    0.674470    
#> 216: 0.653340    0.979513    3.442558    0.924909    0.062362    0.002484    0.674509    
#> 217: 0.655230    0.979429    3.442756    0.925710    0.062476    0.002563    0.673340    
#> 218: 0.654116    0.980060    3.442542    0.922535    0.062783    0.002643    0.672546    
#> 219: 0.652625    0.980453    3.441591    0.921474    0.062740    0.002704    0.673169    
#> 220: 0.648075    0.980677    3.441218    0.918120    0.062668    0.002747    0.673089    
#> 221: 0.645429    0.980655    3.440588    0.917146    0.062576    0.002767    0.672482    
#> 222: 0.642757    0.980758    3.440087    0.916011    0.062637    0.002803    0.672247    
#> 223: 0.642539    0.980170    3.439700    0.921117    0.062425    0.002828    0.671658    
#> 224: 0.642525    0.980710    3.439628    0.920932    0.062359    0.002833    0.671438    
#> 225: 0.640237    0.979527    3.439449    0.920495    0.062348    0.002826    0.671420    
#> 226: 0.639169    0.978502    3.439157    0.920613    0.062486    0.002802    0.672106    
#> 227: 0.638996    0.978647    3.439166    0.920114    0.062765    0.002796    0.672530    
#> 228: 0.637760    0.979524    3.438715    0.920153    0.062808    0.002797    0.672280    
#> 229: 0.636570    0.979551    3.438450    0.915578    0.062663    0.002780    0.672280    
#> 230: 0.636528    0.979501    3.438373    0.915592    0.062567    0.002754    0.672250    
#> 231: 0.636556    0.979754    3.438454    0.918463    0.062625    0.002742    0.672087    
#> 232: 0.635378    0.979352    3.438778    0.919041    0.062759    0.002735    0.671941    
#> 233: 0.635054    0.978652    3.438955    0.920537    0.062996    0.002741    0.671578    
#> 234: 0.636546    0.978456    3.439210    0.925661    0.063116    0.002745    0.671431    
#> 235: 0.636678    0.978017    3.439208    0.924380    0.062944    0.002737    0.671545    
#> 236: 0.637410    0.978224    3.439118    0.925383    0.062870    0.002725    0.671361    
#> 237: 0.638769    0.978032    3.439065    0.928759    0.062794    0.002717    0.671386    
#> 238: 0.638116    0.978203    3.439077    0.925299    0.062925    0.002727    0.671734    
#> 239: 0.636712    0.978807    3.439075    0.919859    0.062899    0.002723    0.671850    
#> 240: 0.636890    0.978797    3.439117    0.918169    0.062686    0.002715    0.672073    
#> 241: 0.637580    0.978174    3.439273    0.917334    0.062482    0.002716    0.672608    
#> 242: 0.637943    0.977805    3.439349    0.915169    0.062474    0.002727    0.673263    
#> 243: 0.636941    0.977899    3.439307    0.912680    0.062498    0.002749    0.673827    
#> 244: 0.636250    0.977518    3.439341    0.908599    0.062386    0.002780    0.674229    
#> 245: 0.637515    0.977291    3.439463    0.908102    0.062125    0.002781    0.674722    
#> 246: 0.638148    0.977479    3.439602    0.908502    0.062082    0.002783    0.674571    
#> 247: 0.637949    0.977086    3.439834    0.907359    0.062052    0.002794    0.674496    
#> 248: 0.637541    0.977315    3.439921    0.907067    0.061935    0.002790    0.674337    
#> 249: 0.637337    0.977752    3.439938    0.908788    0.061899    0.002782    0.674496    
#> 250: 0.638058    0.978274    3.439940    0.908153    0.062014    0.002792    0.674541    
#> 251: 0.638821    0.979197    3.440081    0.908752    0.062084    0.002789    0.674811    
#> 252: 0.638862    0.979575    3.440264    0.908145    0.062219    0.002770    0.675028    
#> 253: 0.639268    0.980007    3.440418    0.909546    0.062198    0.002777    0.674931    
#> 254: 0.639581    0.980152    3.440558    0.909399    0.062060    0.002782    0.674867    
#> 255: 0.639558    0.980216    3.440749    0.909726    0.061744    0.002800    0.674745    
#> 256: 0.640469    0.979878    3.440753    0.911919    0.061636    0.002807    0.674871    
#> 257: 0.640210    0.979490    3.440752    0.911340    0.061792    0.002817    0.674994    
#> 258: 0.640092    0.979320    3.440744    0.911743    0.061838    0.002805    0.674929    
#> 259: 0.640582    0.979368    3.440728    0.913702    0.061670    0.002806    0.674746    
#> 260: 0.640253    0.979529    3.440800    0.912523    0.061605    0.002810    0.674606    
#> 261: 0.640110    0.979392    3.440917    0.911864    0.061736    0.002818    0.674594    
#> 262: 0.640428    0.979531    3.441036    0.913705    0.061733    0.002835    0.674643    
#> 263: 0.640320    0.979744    3.441009    0.915065    0.061657    0.002856    0.674672    
#> 264: 0.639791    0.979920    3.440960    0.914481    0.061509    0.002868    0.674911    
#> 265: 0.639573    0.980203    3.440944    0.917009    0.061421    0.002873    0.675279    
#> 266: 0.640053    0.980665    3.440970    0.918122    0.061405    0.002871    0.675482    
#> 267: 0.640563    0.980635    3.441056    0.919898    0.061360    0.002881    0.675806    
#> 268: 0.641401    0.980550    3.441093    0.920788    0.061412    0.002876    0.675524    
#> 269: 0.641966    0.980535    3.441108    0.920512    0.061564    0.002872    0.675397    
#> 270: 0.642535    0.980603    3.440967    0.921191    0.061558    0.002873    0.675373    
#> 271: 0.642761    0.980464    3.440892    0.923066    0.061491    0.002869    0.675407    
#> 272: 0.642599    0.980252    3.440784    0.922254    0.061319    0.002873    0.675738    
#> 273: 0.642363    0.980564    3.440768    0.922232    0.061252    0.002883    0.675870    
#> 274: 0.642299    0.980859    3.440808    0.922150    0.061073    0.002888    0.675688    
#> 275: 0.642424    0.981047    3.440800    0.921998    0.060893    0.002907    0.675593    
#> 276: 0.642292    0.981223    3.440886    0.923206    0.060737    0.002940    0.675797    
#> 277: 0.641997    0.981673    3.440996    0.923659    0.060694    0.002965    0.675980    
#> 278: 0.641468    0.981598    3.441034    0.923335    0.060597    0.002989    0.675911    
#> 279: 0.640948    0.981272    3.441063    0.922839    0.060540    0.003011    0.675712    
#> 280: 0.641011    0.981210    3.441137    0.923518    0.060352    0.003032    0.675688    
#> 281: 0.640805    0.981163    3.441253    0.922129    0.060161    0.003044    0.675609    
#> 282: 0.641030    0.981045    3.441372    0.921502    0.059956    0.003068    0.675701    
#> 283: 0.641890    0.980909    3.441545    0.923153    0.059847    0.003089    0.675829    
#> 284: 0.641989    0.980541    3.441657    0.922640    0.059783    0.003102    0.675566    
#> 285: 0.641547    0.980555    3.441580    0.920715    0.059632    0.003116    0.675701    
#> 286: 0.641542    0.980715    3.441517    0.920125    0.059498    0.003129    0.675695    
#> 287: 0.641148    0.980880    3.441388    0.919975    0.059412    0.003138    0.675640    
#> 288: 0.641503    0.981067    3.441279    0.920067    0.059389    0.003138    0.675703    
#> 289: 0.642065    0.981097    3.441224    0.920671    0.059341    0.003140    0.675545    
#> 290: 0.642293    0.981200    3.441154    0.921038    0.059225    0.003143    0.675704    
#> 291: 0.642061    0.981355    3.441130    0.920876    0.059179    0.003150    0.675551    
#> 292: 0.641927    0.981340    3.441079    0.920939    0.059154    0.003151    0.675319    
#> 293: 0.641947    0.981348    3.440983    0.921076    0.059077    0.003167    0.675107    
#> 294: 0.641762    0.981362    3.440879    0.920727    0.059043    0.003184    0.675012    
#> 295: 0.641306    0.981014    3.440832    0.919241    0.059050    0.003188    0.674967    
#> 296: 0.640904    0.980832    3.440881    0.918183    0.058975    0.003202    0.675001    
#> 297: 0.640753    0.980954    3.440832    0.917770    0.058944    0.003211    0.675103    
#> 298: 0.640659    0.980872    3.440814    0.917762    0.058889    0.003216    0.674960    
#> 299: 0.640483    0.980989    3.440789    0.917793    0.058818    0.003215    0.674727    
#> 300: 0.640753    0.980884    3.440809    0.920007    0.058889    0.003210    0.674601    
#> 301: 0.640692    0.980780    3.440741    0.920691    0.058925    0.003209    0.674742    
#> 302: 0.640410    0.980952    3.440685    0.919454    0.058873    0.003209    0.674839    
#> 303: 0.639942    0.981336    3.440649    0.918628    0.058756    0.003214    0.674816    
#> 304: 0.639888    0.981737    3.440569    0.919686    0.058621    0.003224    0.674801    
#> 305: 0.640066    0.981638    3.440584    0.921013    0.058504    0.003231    0.674710    
#> 306: 0.639956    0.981588    3.440533    0.922364    0.058408    0.003230    0.674709    
#> 307: 0.640289    0.981593    3.440432    0.924247    0.058362    0.003220    0.674840    
#> 308: 0.639842    0.981590    3.440334    0.924027    0.058455    0.003215    0.675027    
#> 309: 0.639786    0.981380    3.440264    0.924379    0.058504    0.003212    0.675219    
#> 310: 0.639736    0.981353    3.440149    0.923315    0.058631    0.003207    0.675242    
#> 311: 0.639673    0.981293    3.440116    0.923757    0.058640    0.003206    0.675295    
#> 312: 0.639098    0.981206    3.440061    0.923065    0.058670    0.003201    0.675450    
#> 313: 0.638436    0.981097    3.439999    0.922066    0.058836    0.003197    0.675465    
#> 314: 0.637726    0.981098    3.439913    0.921973    0.058959    0.003189    0.675383    
#> 315: 0.637146    0.981233    3.439842    0.921377    0.059005    0.003189    0.675318    
#> 316: 0.637226    0.981263    3.439763    0.921993    0.058963    0.003184    0.675291    
#> 317: 0.637431    0.981196    3.439737    0.922084    0.058915    0.003172    0.675328    
#> 318: 0.637336    0.981375    3.439628    0.921937    0.058828    0.003169    0.675338    
#> 319: 0.637251    0.981468    3.439581    0.922322    0.058783    0.003169    0.675268    
#> 320: 0.636667    0.981547    3.439454    0.921950    0.058828    0.003173    0.675340    
#> 321: 0.636254    0.981725    3.439291    0.922131    0.058886    0.003167    0.675412    
#> 322: 0.635995    0.981840    3.439126    0.921469    0.058897    0.003159    0.675618    
#> 323: 0.635478    0.981940    3.439020    0.920339    0.058927    0.003155    0.675638    
#> 324: 0.635772    0.982119    3.439030    0.920993    0.058973    0.003152    0.675617    
#> 325: 0.635895    0.982217    3.438998    0.920688    0.058955    0.003154    0.675515    
#> 326: 0.636005    0.982044    3.438972    0.921307    0.059023    0.003158    0.675587    
#> 327: 0.635779    0.981968    3.439022    0.920291    0.059052    0.003158    0.675644    
#> 328: 0.635758    0.981934    3.439069    0.919691    0.058972    0.003157    0.675621    
#> 329: 0.635827    0.982077    3.439105    0.919576    0.058970    0.003163    0.675571    
#> 330: 0.635294    0.982197    3.439120    0.919018    0.058980    0.003164    0.675478    
#> 331: 0.635313    0.982400    3.439111    0.918888    0.058934    0.003167    0.675383    
#> 332: 0.635172    0.982401    3.439077    0.918655    0.058853    0.003173    0.675306    
#> 333: 0.634948    0.982449    3.439001    0.918093    0.058799    0.003178    0.675220    
#> 334: 0.634830    0.982491    3.438906    0.918604    0.058766    0.003179    0.675157    
#> 335: 0.634378    0.982703    3.438768    0.918130    0.058829    0.003182    0.675109    
#> 336: 0.634043    0.982957    3.438643    0.918008    0.058858    0.003184    0.675182    
#> 337: 0.633407    0.983205    3.438513    0.917492    0.058776    0.003183    0.675288    
#> 338: 0.633041    0.983320    3.438445    0.917637    0.058742    0.003178    0.675361    
#> 339: 0.632705    0.983455    3.438401    0.917448    0.058712    0.003177    0.675337    
#> 340: 0.632672    0.983328    3.438416    0.917750    0.058697    0.003177    0.675336    
#> 341: 0.632928    0.983365    3.438413    0.918803    0.058691    0.003182    0.675228    
#> 342: 0.632469    0.983303    3.438360    0.918195    0.058660    0.003186    0.675114    
#> 343: 0.632004    0.983410    3.438338    0.917063    0.058650    0.003184    0.675058    
#> 344: 0.631915    0.983482    3.438341    0.916879    0.058609    0.003183    0.674977    
#> 345: 0.632062    0.983420    3.438382    0.917189    0.058627    0.003186    0.674868    
#> 346: 0.632108    0.983436    3.438361    0.917155    0.058564    0.003186    0.674763    
#> 347: 0.632159    0.983375    3.438275    0.917384    0.058510    0.003192    0.674698    
#> 348: 0.631944    0.983487    3.438210    0.917342    0.058463    0.003201    0.674574    
#> 349: 0.632007    0.983440    3.438162    0.917589    0.058398    0.003208    0.674458    
#> 350: 0.631821    0.983378    3.438100    0.917671    0.058306    0.003217    0.674340    
#> 351: 0.631851    0.983491    3.438026    0.917754    0.058266    0.003220    0.674302    
#> 352: 0.631428    0.983682    3.437994    0.916807    0.058221    0.003227    0.674326    
#> 353: 0.631506    0.983901    3.437937    0.916821    0.058160    0.003236    0.674390    
#> 354: 0.631484    0.984006    3.437815    0.917197    0.058072    0.003246    0.674446    
#> 355: 0.631831    0.983927    3.437775    0.918366    0.057991    0.003254    0.674513    
#> 356: 0.632076    0.983889    3.437786    0.918669    0.058019    0.003258    0.674549    
#> 357: 0.632262    0.983957    3.437783    0.918591    0.057982    0.003267    0.674482    
#> 358: 0.632100    0.983988    3.437831    0.917805    0.058023    0.003268    0.674399    
#> 359: 0.632050    0.984028    3.437864    0.917727    0.058096    0.003274    0.674323    
#> 360: 0.631983    0.983990    3.437830    0.917079    0.058129    0.003279    0.674237    
#> 361: 0.631877    0.983947    3.437782    0.916650    0.058134    0.003281    0.674230    
#> 362: 0.631596    0.983904    3.437745    0.916070    0.058120    0.003281    0.674102    
#> 363: 0.631639    0.983766    3.437751    0.916010    0.058068    0.003289    0.674076    
#> 364: 0.631607    0.983683    3.437748    0.915489    0.058079    0.003292    0.674027    
#> 365: 0.631700    0.983572    3.437768    0.915309    0.058054    0.003290    0.674054    
#> 366: 0.632020    0.983520    3.437792    0.914959    0.058012    0.003288    0.674134    
#> 367: 0.631956    0.983494    3.437838    0.914259    0.057953    0.003283    0.674155    
#> 368: 0.632170    0.983537    3.437809    0.914642    0.057919    0.003285    0.674131    
#> 369: 0.632123    0.983497    3.437801    0.914738    0.057951    0.003281    0.674124    
#> 370: 0.632106    0.983504    3.437768    0.915584    0.058012    0.003275    0.674109    
#> 371: 0.631952    0.983492    3.437690    0.916227    0.058004    0.003272    0.674111    
#> 372: 0.631697    0.983489    3.437635    0.916420    0.057985    0.003271    0.674143    
#> 373: 0.631498    0.983614    3.437557    0.917250    0.058026    0.003266    0.674128    
#> 374: 0.631533    0.983635    3.437449    0.917329    0.058000    0.003268    0.674104    
#> 375: 0.631128    0.983632    3.437389    0.917425    0.058017    0.003266    0.674159    
#> 376: 0.630728    0.983698    3.437325    0.917412    0.057932    0.003268    0.674144    
#> 377: 0.630698    0.983732    3.437302    0.918114    0.057896    0.003272    0.674077    
#> 378: 0.630561    0.983692    3.437269    0.917979    0.057914    0.003280    0.674028    
#> 379: 0.630377    0.983537    3.437299    0.918492    0.057927    0.003286    0.673972    
#> 380: 0.630118    0.983437    3.437296    0.917788    0.057942    0.003291    0.673962    
#> 381: 0.629854    0.983401    3.437304    0.917407    0.057914    0.003289    0.673993    
#> 382: 0.629978    0.983413    3.437271    0.918205    0.057898    0.003289    0.673917    
#> 383: 0.630187    0.983494    3.437274    0.918613    0.057940    0.003287    0.673898    
#> 384: 0.630039    0.983454    3.437304    0.918516    0.057901    0.003287    0.673895    
#> 385: 0.630005    0.983488    3.437329    0.918326    0.057881    0.003288    0.673846    
#> 386: 0.630377    0.983634    3.437358    0.919118    0.057847    0.003285    0.673839    
#> 387: 0.630614    0.983760    3.437381    0.919779    0.057824    0.003289    0.673775    
#> 388: 0.630514    0.983753    3.437379    0.919689    0.057784    0.003286    0.673795    
#> 389: 0.630326    0.983637    3.437342    0.919563    0.057773    0.003289    0.673818    
#> 390: 0.630384    0.983650    3.437327    0.920161    0.057726    0.003290    0.673729    
#> 391: 0.630320    0.983675    3.437297    0.919595    0.057665    0.003290    0.673607    
#> 392: 0.630300    0.983743    3.437340    0.919682    0.057634    0.003291    0.673528    
#> 393: 0.630305    0.983680    3.437355    0.919943    0.057563    0.003295    0.673434    
#> 394: 0.630248    0.983719    3.437336    0.919834    0.057559    0.003298    0.673364    
#> 395: 0.630252    0.983834    3.437327    0.920144    0.057503    0.003301    0.673307    
#> 396: 0.630331    0.983836    3.437323    0.920993    0.057448    0.003304    0.673270    
#> 397: 0.630285    0.983804    3.437342    0.920879    0.057444    0.003302    0.673205    
#> 398: 0.630288    0.983818    3.437348    0.920381    0.057374    0.003308    0.673222    
#> 399: 0.630474    0.983821    3.437416    0.920677    0.057377    0.003314    0.673199    
#> 400: 0.630693    0.983887    3.437498    0.920708    0.057365    0.003315    0.673135    
#> 401: 0.630783    0.983871    3.437563    0.920787    0.057396    0.003319    0.673122    
#> 402: 0.630875    0.983869    3.437608    0.920597    0.057384    0.003325    0.673034    
#> 403: 0.631006    0.983894    3.437641    0.920342    0.057358    0.003330    0.672936    
#> 404: 0.631116    0.983884    3.437634    0.919906    0.057320    0.003332    0.672907    
#> 405: 0.630732    0.983933    3.437644    0.918948    0.057250    0.003335    0.672936    
#> 406: 0.630770    0.983974    3.437655    0.918618    0.057184    0.003338    0.672982    
#> 407: 0.630885    0.984043    3.437703    0.918263    0.057096    0.003342    0.673074    
#> 408: 0.631099    0.984161    3.437729    0.918203    0.057003    0.003341    0.673118    
#> 409: 0.631162    0.984137    3.437717    0.918300    0.056957    0.003340    0.673078    
#> 410: 0.630999    0.984144    3.437675    0.917889    0.056965    0.003338    0.673117    
#> 411: 0.631029    0.983960    3.437658    0.917815    0.056985    0.003339    0.673127    
#> 412: 0.631055    0.984031    3.437643    0.917674    0.056992    0.003340    0.673127    
#> 413: 0.631003    0.984022    3.437605    0.917091    0.056999    0.003340    0.673152    
#> 414: 0.630808    0.984084    3.437595    0.917170    0.056940    0.003338    0.673230    
#> 415: 0.630813    0.984083    3.437585    0.916649    0.056906    0.003339    0.673256    
#> 416: 0.631121    0.984188    3.437588    0.917620    0.056881    0.003339    0.673195    
#> 417: 0.631374    0.984245    3.437571    0.918175    0.056856    0.003335    0.673167    
#> 418: 0.631401    0.984341    3.437572    0.918118    0.056887    0.003332    0.673077    
#> 419: 0.631508    0.984421    3.437567    0.918361    0.056895    0.003332    0.673000    
#> 420: 0.631568    0.984433    3.437563    0.918570    0.056892    0.003331    0.672970    
#> 421: 0.631431    0.984490    3.437558    0.918264    0.056892    0.003328    0.672923    
#> 422: 0.631524    0.984418    3.437561    0.918145    0.056877    0.003325    0.672913    
#> 423: 0.631515    0.984352    3.437567    0.917926    0.056892    0.003323    0.672918    
#> 424: 0.631411    0.984353    3.437556    0.917658    0.056903    0.003322    0.672855    
#> 425: 0.631458    0.984401    3.437546    0.918040    0.056924    0.003323    0.672831    
#> 426: 0.631364    0.984484    3.437546    0.917856    0.056927    0.003319    0.672847    
#> 427: 0.631069    0.984440    3.437526    0.917275    0.056869    0.003317    0.672887    
#> 428: 0.630806    0.984445    3.437520    0.916456    0.056773    0.003316    0.672920    
#> 429: 0.630715    0.984408    3.437555    0.916129    0.056765    0.003319    0.672879    
#> 430: 0.630664    0.984410    3.437567    0.916567    0.056726    0.003322    0.672886    
#> 431: 0.630669    0.984432    3.437528    0.917097    0.056647    0.003323    0.672858    
#> 432: 0.630705    0.984546    3.437523    0.917532    0.056604    0.003327    0.672841    
#> 433: 0.630616    0.984643    3.437523    0.917639    0.056588    0.003326    0.672828    
#> 434: 0.630400    0.984559    3.437515    0.917525    0.056562    0.003326    0.672838    
#> 435: 0.630335    0.984550    3.437487    0.917452    0.056573    0.003327    0.672777    
#> 436: 0.630284    0.984516    3.437463    0.917271    0.056587    0.003329    0.672724    
#> 437: 0.630175    0.984534    3.437420    0.916794    0.056556    0.003333    0.672685    
#> 438: 0.629924    0.984658    3.437387    0.916513    0.056530    0.003331    0.672617    
#> 439: 0.629943    0.984792    3.437347    0.916298    0.056511    0.003328    0.672547    
#> 440: 0.629868    0.984894    3.437330    0.916264    0.056561    0.003323    0.672462    
#> 441: 0.629833    0.984890    3.437325    0.915816    0.056608    0.003322    0.672390    
#> 442: 0.629703    0.984958    3.437337    0.915735    0.056579    0.003320    0.672329    
#> 443: 0.629806    0.985036    3.437354    0.915592    0.056547    0.003321    0.672286    
#> 444: 0.629848    0.985051    3.437348    0.915750    0.056557    0.003323    0.672295    
#> 445: 0.629703    0.985088    3.437316    0.915745    0.056567    0.003323    0.672325    
#> 446: 0.629696    0.985166    3.437278    0.915672    0.056578    0.003322    0.672293    
#> 447: 0.629663    0.985190    3.437274    0.915684    0.056571    0.003326    0.672241    
#> 448: 0.629521    0.985224    3.437271    0.915325    0.056533    0.003334    0.672179    
#> 449: 0.629432    0.985300    3.437324    0.915119    0.056514    0.003338    0.672133    
#> 450: 0.629522    0.985300    3.437357    0.915165    0.056523    0.003340    0.672077    
#> 451: 0.629735    0.985383    3.437365    0.915667    0.056567    0.003338    0.672069    
#> 452: 0.629793    0.985408    3.437337    0.915916    0.056578    0.003338    0.672076    
#> 453: 0.629852    0.985387    3.437326    0.916379    0.056613    0.003335    0.672009    
#> 454: 0.629800    0.985487    3.437308    0.916611    0.056636    0.003332    0.671952    
#> 455: 0.629850    0.985530    3.437279    0.916943    0.056651    0.003332    0.671908    
#> 456: 0.629783    0.985452    3.437268    0.916814    0.056643    0.003332    0.671999    
#> 457: 0.629666    0.985416    3.437263    0.916457    0.056640    0.003332    0.671950    
#> 458: 0.629600    0.985485    3.437303    0.916261    0.056674    0.003334    0.671933    
#> 459: 0.629518    0.985582    3.437346    0.916322    0.056707    0.003337    0.671927    
#> 460: 0.629374    0.985580    3.437367    0.916072    0.056712    0.003340    0.671936    
#> 461: 0.629271    0.985623    3.437400    0.915835    0.056740    0.003339    0.671893    
#> 462: 0.629155    0.985601    3.437427    0.915380    0.056736    0.003341    0.671831    
#> 463: 0.629006    0.985674    3.437408    0.914929    0.056727    0.003345    0.671759    
#> 464: 0.629036    0.985676    3.437403    0.914531    0.056709    0.003347    0.671659    
#> 465: 0.628912    0.985543    3.437381    0.914102    0.056680    0.003343    0.671678    
#> 466: 0.628930    0.985568    3.437349    0.914627    0.056659    0.003339    0.671647    
#> 467: 0.628958    0.985547    3.437326    0.915019    0.056656    0.003337    0.671543    
#> 468: 0.629165    0.985537    3.437319    0.915811    0.056626    0.003338    0.671527    
#> 469: 0.629225    0.985603    3.437328    0.915874    0.056589    0.003341    0.671595    
#> 470: 0.629072    0.985605    3.437321    0.915857    0.056560    0.003347    0.671613    
#> 471: 0.628838    0.985553    3.437306    0.915526    0.056531    0.003349    0.671628    
#> 472: 0.628818    0.985523    3.437315    0.916000    0.056555    0.003349    0.671594    
#> 473: 0.628704    0.985481    3.437292    0.915715    0.056563    0.003351    0.671568    
#> 474: 0.628557    0.985464    3.437286    0.915215    0.056575    0.003353    0.671617    
#> 475: 0.628472    0.985546    3.437273    0.914827    0.056595    0.003358    0.671610    
#> 476: 0.628437    0.985558    3.437256    0.914920    0.056624    0.003358    0.671597    
#> 477: 0.628420    0.985631    3.437260    0.915164    0.056631    0.003356    0.671553    
#> 478: 0.628254    0.985633    3.437279    0.914954    0.056606    0.003353    0.671605    
#> 479: 0.628238    0.985719    3.437287    0.914566    0.056620    0.003351    0.671652    
#> 480: 0.628298    0.985720    3.437328    0.914419    0.056625    0.003355    0.671655    
#> 481: 0.628361    0.985709    3.437347    0.914138    0.056636    0.003356    0.671601    
#> 482: 0.628552    0.985720    3.437366    0.914578    0.056608    0.003356    0.671604    
#> 483: 0.628649    0.985667    3.437389    0.914736    0.056639    0.003357    0.671613    
#> 484: 0.628662    0.985570    3.437419    0.914639    0.056632    0.003356    0.671629    
#> 485: 0.628693    0.985588    3.437449    0.914737    0.056615    0.003357    0.671698    
#> 486: 0.628792    0.985678    3.437445    0.914750    0.056634    0.003357    0.671765    
#> 487: 0.628894    0.985722    3.437455    0.914789    0.056640    0.003358    0.671771    
#> 488: 0.628878    0.985723    3.437456    0.914992    0.056630    0.003359    0.671801    
#> 489: 0.628924    0.985686    3.437458    0.915056    0.056625    0.003358    0.671795    
#> 490: 0.629057    0.985653    3.437484    0.915497    0.056651    0.003360    0.671785    
#> 491: 0.629443    0.985694    3.437514    0.916746    0.056677    0.003361    0.671791    
#> 492: 0.629565    0.985711    3.437508    0.917476    0.056718    0.003362    0.671875    
#> 493: 0.629751    0.985691    3.437511    0.918799    0.056759    0.003365    0.671882    
#> 494: 0.629987    0.985771    3.437506    0.919273    0.056819    0.003366    0.671860    
#> 495: 0.629969    0.985849    3.437507    0.919134    0.056850    0.003366    0.671818    
#> 496: 0.630112    0.985925    3.437486    0.919202    0.056852    0.003362    0.671841    
#> 497: 0.630096    0.985888    3.437498    0.919412    0.056874    0.003362    0.671874    
#> 498: 0.630038    0.985812    3.437489    0.919513    0.056881    0.003361    0.671863    
#> 499: 0.630001    0.985852    3.437443    0.919237    0.056879    0.003361    0.671848    
#> 500: 0.630100    0.985816    3.437424    0.919708    0.056897    0.003361    0.671840    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.285286    0.958822    3.448187    0.392401    0.079823    0.016800    1.579830    
#> 002: 0.314541    1.018406    3.454234    0.372781    0.075832    0.015960    1.048378    
#> 003: 0.360922    0.949250    3.456281    0.354142    0.072040    0.015162    0.834413    
#> 004: 0.379576    0.967649    3.466152    0.336435    0.068438    0.014404    0.758404    
#> 005: 0.411254    0.968364    3.456427    0.319613    0.065016    0.013684    0.714361    
#> 006: 0.357439    0.949718    3.448962    0.303633    0.061765    0.013000    0.660239    
#> 007: 0.329344    0.964889    3.440710    0.288451    0.058677    0.012350    0.655284    
#> 008: 0.324648    0.962089    3.438522    0.274029    0.055743    0.011732    0.672014    
#> 009: 0.298653    0.945928    3.427151    0.260327    0.052956    0.011146    0.669243    
#> 010: 0.303085    0.947256    3.431662    0.247311    0.050308    0.010588    0.673707    
#> 011: 0.355374    0.955066    3.439327    0.234945    0.057974    0.010097    0.675922    
#> 012: 0.364447    0.944742    3.437559    0.238174    0.055075    0.009841    0.670358    
#> 013: 0.333277    0.953641    3.435880    0.233836    0.052321    0.012460    0.657491    
#> 014: 0.363331    0.948767    3.450253    0.222144    0.049705    0.011837    0.678630    
#> 015: 0.401453    0.943149    3.467793    0.212452    0.051208    0.011245    0.659694    
#> 016: 0.342244    0.978319    3.452849    0.233100    0.056591    0.010683    0.666973    
#> 017: 0.345071    0.975418    3.447540    0.239759    0.055307    0.010428    0.657113    
#> 018: 0.305624    0.981658    3.423014    0.233637    0.066586    0.009907    0.653431    
#> 019: 0.281998    0.981117    3.421535    0.221955    0.063257    0.009411    0.652291    
#> 020: 0.323173    0.983032    3.432925    0.210857    0.060094    0.008941    0.665983    
#> 021: 0.343206    0.975519    3.443890    0.200314    0.057090    0.008494    0.666572    
#> 022: 0.328486    0.961821    3.447414    0.190299    0.054235    0.008069    0.649028    
#> 023: 0.398332    0.967438    3.460249    0.214046    0.051523    0.007665    0.686863    
#> 024: 0.411789    0.979924    3.456326    0.205897    0.048947    0.007282    0.673354    
#> 025: 0.367750    0.955652    3.441447    0.216609    0.046500    0.006918    0.663789    
#> 026: 0.345438    0.981670    3.434676    0.209002    0.047194    0.008322    0.653103    
#> 027: 0.345691    0.996023    3.440348    0.212516    0.050055    0.009889    0.667013    
#> 028: 0.356831    0.977622    3.445329    0.201891    0.047967    0.009395    0.653981    
#> 029: 0.367888    0.981847    3.441254    0.223032    0.058114    0.008925    0.668211    
#> 030: 0.378364    0.985507    3.437938    0.211881    0.055208    0.008513    0.679769    
#> 031: 0.350292    0.977676    3.448643    0.201287    0.052448    0.008087    0.668790    
#> 032: 0.323551    0.964177    3.444199    0.191222    0.049825    0.007683    0.655222    
#> 033: 0.319380    0.978261    3.440119    0.181661    0.050360    0.008135    0.650137    
#> 034: 0.336769    0.974733    3.436550    0.191719    0.049676    0.007729    0.657331    
#> 035: 0.312413    0.968477    3.436125    0.182133    0.047192    0.007342    0.671483    
#> 036: 0.328013    0.982790    3.430112    0.188274    0.058233    0.006975    0.659031    
#> 037: 0.314394    0.985162    3.430603    0.184391    0.064414    0.006626    0.658024    
#> 038: 0.346317    0.981743    3.429570    0.195395    0.063713    0.006511    0.660313    
#> 039: 0.340289    0.976867    3.438156    0.185625    0.060528    0.007224    0.666100    
#> 040: 0.301212    0.992163    3.438721    0.176344    0.057501    0.007305    0.685301    
#> 041: 0.310139    0.962309    3.439528    0.167527    0.054626    0.008772    0.667601    
#> 042: 0.357033    0.964776    3.436090    0.196142    0.051895    0.009679    0.648005    
#> 043: 0.304626    0.977594    3.427297    0.186335    0.049300    0.009195    0.656351    
#> 044: 0.343638    0.985223    3.430699    0.203845    0.048762    0.008735    0.654764    
#> 045: 0.324060    0.998717    3.428603    0.235347    0.046324    0.008935    0.641869    
#> 046: 0.309090    0.982713    3.430093    0.223579    0.052204    0.008489    0.650106    
#> 047: 0.333147    0.974123    3.431926    0.217982    0.049594    0.009827    0.651924    
#> 048: 0.357378    0.967758    3.439355    0.212297    0.047114    0.010532    0.671751    
#> 049: 0.316681    0.959756    3.442131    0.201683    0.048099    0.011306    0.673881    
#> 050: 0.383585    0.935968    3.450437    0.239137    0.045694    0.011129    0.658693    
#> 051: 0.359769    0.955710    3.448367    0.228974    0.048542    0.012309    0.659567    
#> 052: 0.345236    0.972450    3.450622    0.217525    0.048404    0.011693    0.641647    
#> 053: 0.344469    0.962717    3.440618    0.206649    0.049128    0.011109    0.651792    
#> 054: 0.332018    0.968256    3.442356    0.204772    0.055440    0.011002    0.671784    
#> 055: 0.350707    0.953138    3.445667    0.209653    0.052668    0.010452    0.682814    
#> 056: 0.368382    0.956860    3.445992    0.214862    0.057063    0.011123    0.681096    
#> 057: 0.343901    0.937169    3.455310    0.215180    0.054210    0.011590    0.696279    
#> 058: 0.365929    0.955488    3.446450    0.212333    0.051500    0.012332    0.671439    
#> 059: 0.374324    0.925655    3.461729    0.201717    0.053733    0.012604    0.674695    
#> 060: 0.373621    0.923196    3.463745    0.191649    0.058418    0.013786    0.673104    
#> 061: 0.362652    0.940935    3.451589    0.182066    0.055583    0.013097    0.674246    
#> 062: 0.359967    0.954377    3.462288    0.173081    0.077476    0.012442    0.677983    
#> 063: 0.391470    0.925109    3.458751    0.194313    0.073603    0.011820    0.678617    
#> 064: 0.379572    0.944880    3.458263    0.188369    0.069922    0.011229    0.677422    
#> 065: 0.383634    0.952905    3.447861    0.178950    0.066426    0.010667    0.677914    
#> 066: 0.345443    1.004914    3.446459    0.184395    0.063105    0.010134    0.657727    
#> 067: 0.330559    0.967588    3.432008    0.175175    0.059950    0.009627    0.678684    
#> 068: 0.303566    0.965443    3.440096    0.177316    0.057630    0.011295    0.691715    
#> 069: 0.286619    0.976423    3.429486    0.193155    0.054749    0.010730    0.692813    
#> 070: 0.334265    0.965410    3.450122    0.183497    0.055437    0.010194    0.697300    
#> 071: 0.351229    0.980422    3.439096    0.174322    0.059695    0.009684    0.715563    
#> 072: 0.302816    0.964072    3.428870    0.165606    0.056710    0.009200    0.694902    
#> 073: 0.369874    0.983347    3.443838    0.238632    0.060531    0.008770    0.665182    
#> 074: 0.342461    0.952210    3.436419    0.226700    0.058141    0.008331    0.661157    
#> 075: 0.338602    0.961679    3.455133    0.215365    0.055234    0.007915    0.655085    
#> 076: 0.361499    0.979735    3.458569    0.204597    0.055326    0.007592    0.650783    
#> 077: 0.374383    0.952086    3.450054    0.194367    0.052559    0.007213    0.662339    
#> 078: 0.369667    0.962264    3.451980    0.209333    0.049931    0.009107    0.635517    
#> 079: 0.374027    0.983493    3.450253    0.251044    0.057214    0.010063    0.648070    
#> 080: 0.364980    0.958655    3.446706    0.249427    0.062017    0.010567    0.653440    
#> 081: 0.366900    0.957306    3.445388    0.236956    0.058916    0.011214    0.644084    
#> 082: 0.328234    0.959484    3.448704    0.225108    0.059036    0.011335    0.666546    
#> 083: 0.338055    0.991089    3.440101    0.250031    0.056085    0.013367    0.661126    
#> 084: 0.343646    1.001426    3.427004    0.237529    0.053280    0.012699    0.665147    
#> 085: 0.308329    0.999429    3.435875    0.225653    0.052378    0.012064    0.664756    
#> 086: 0.314174    0.979978    3.433034    0.214370    0.054556    0.011931    0.656300    
#> 087: 0.298677    0.984808    3.425755    0.217034    0.054699    0.011335    0.652416    
#> 088: 0.252223    0.972971    3.425075    0.239463    0.051964    0.010768    0.671302    
#> 089: 0.303216    0.992282    3.425427    0.227490    0.060088    0.010230    0.669329    
#> 090: 0.284942    0.985328    3.421687    0.216116    0.065930    0.009718    0.675004    
#> 091: 0.319034    0.955999    3.422514    0.210455    0.067425    0.009232    0.667320    
#> 092: 0.314901    0.982410    3.424426    0.199932    0.064054    0.008771    0.678461    
#> 093: 0.303526    0.975624    3.427700    0.189936    0.060851    0.008332    0.666088    
#> 094: 0.312641    0.981189    3.426295    0.180439    0.057808    0.007916    0.672319    
#> 095: 0.328571    0.989262    3.438093    0.178883    0.060216    0.007520    0.665554    
#> 096: 0.279548    0.985573    3.435101    0.192471    0.057206    0.007741    0.647223    
#> 097: 0.364014    0.983440    3.445221    0.204483    0.054346    0.007487    0.657610    
#> 098: 0.342539    0.990798    3.447565    0.200941    0.051628    0.007806    0.681639    
#> 099: 0.327248    0.968627    3.431823    0.232198    0.060189    0.007662    0.651078    
#> 100: 0.307272    0.982329    3.434910    0.220588    0.057180    0.007900    0.644733    
#> 101: 0.283761    0.967340    3.418219    0.209559    0.056511    0.008139    0.651633    
#> 102: 0.277209    0.982350    3.412262    0.199081    0.057158    0.007732    0.653142    
#> 103: 0.308544    0.994976    3.415956    0.196270    0.054300    0.008415    0.663231    
#> 104: 0.301672    0.989874    3.426692    0.237086    0.061008    0.008964    0.668346    
#> 105: 0.309085    0.966679    3.423958    0.225232    0.059330    0.008516    0.664714    
#> 106: 0.337973    0.978436    3.428248    0.213970    0.056363    0.009159    0.657349    
#> 107: 0.342348    0.975248    3.433451    0.230206    0.053545    0.010518    0.649242    
#> 108: 0.361884    0.973991    3.440930    0.218695    0.054306    0.009992    0.674681    
#> 109: 0.338359    0.956992    3.450558    0.207760    0.051590    0.009492    0.690620    
#> 110: 0.340100    0.953996    3.427477    0.202674    0.049011    0.009018    0.663486    
#> 111: 0.332327    0.961839    3.430315    0.199992    0.046560    0.008567    0.647076    
#> 112: 0.306756    0.958248    3.423460    0.215576    0.046706    0.009237    0.663820    
#> 113: 0.316785    0.992692    3.431050    0.204797    0.051336    0.008776    0.648412    
#> 114: 0.318267    0.995384    3.435250    0.252330    0.048769    0.008356    0.657778    
#> 115: 0.318205    0.969550    3.428932    0.239714    0.046331    0.009813    0.662007    
#> 116: 0.308898    0.979808    3.428323    0.227728    0.050125    0.011144    0.663671    
#> 117: 0.296911    0.990110    3.428858    0.216342    0.048104    0.010587    0.659651    
#> 118: 0.360279    0.975290    3.444398    0.234203    0.045698    0.010057    0.656434    
#> 119: 0.369319    0.962507    3.454866    0.222493    0.046666    0.010301    0.654861    
#> 120: 0.334236    0.938160    3.452996    0.221275    0.046946    0.012319    0.652257    
#> 121: 0.346615    0.975337    3.443128    0.210211    0.054535    0.011703    0.667151    
#> 122: 0.345674    0.954073    3.452495    0.199701    0.067004    0.011118    0.666729    
#> 123: 0.364562    0.961143    3.445430    0.203209    0.063654    0.010562    0.667345    
#> 124: 0.358914    0.998090    3.447715    0.205230    0.060471    0.010591    0.646299    
#> 125: 0.368106    0.987237    3.440678    0.231000    0.057448    0.010061    0.649792    
#> 126: 0.344670    0.999566    3.436085    0.219450    0.054575    0.012698    0.662973    
#> 127: 0.354688    0.985102    3.436238    0.218223    0.051846    0.012063    0.663782    
#> 128: 0.324842    0.959254    3.451111    0.207312    0.057970    0.011460    0.647452    
#> 129: 0.360184    0.967663    3.451992    0.196946    0.058850    0.010887    0.663634    
#> 130: 0.389915    0.973915    3.447926    0.187099    0.059762    0.010343    0.650634    
#> 131: 0.373860    0.966519    3.444743    0.177744    0.064433    0.009826    0.648435    
#> 132: 0.319473    0.969094    3.436875    0.168857    0.061211    0.009334    0.680314    
#> 133: 0.338961    0.954264    3.445425    0.160414    0.066178    0.008922    0.690521    
#> 134: 0.362588    0.950160    3.457576    0.157826    0.076770    0.008476    0.670890    
#> 135: 0.337572    0.944556    3.452073    0.162324    0.082750    0.008136    0.674315    
#> 136: 0.350217    0.933879    3.452201    0.154207    0.078613    0.007729    0.676424    
#> 137: 0.370808    0.948376    3.458562    0.146497    0.074682    0.007343    0.686074    
#> 138: 0.351096    0.967528    3.451189    0.143949    0.070948    0.009295    0.667538    
#> 139: 0.362838    0.963738    3.467309    0.148954    0.067401    0.009925    0.679270    
#> 140: 0.366489    0.959749    3.467508    0.159847    0.066714    0.009429    0.678048    
#> 141: 0.349737    0.932719    3.457612    0.180979    0.063379    0.008958    0.652959    
#> 142: 0.383530    0.927245    3.468749    0.171930    0.061660    0.008510    0.665751    
#> 143: 0.369200    0.960982    3.458689    0.176354    0.058577    0.009621    0.673824    
#> 144: 0.393781    0.944918    3.475294    0.205976    0.055648    0.009140    0.656887    
#> 145: 0.365189    0.957381    3.454092    0.195677    0.052866    0.008683    0.651808    
#> 146: 0.358208    0.968168    3.454499    0.203886    0.050223    0.008249    0.657573    
#> 147: 0.322817    0.951109    3.438065    0.193692    0.047712    0.007836    0.651782    
#> 148: 0.322870    0.970722    3.446144    0.184127    0.050271    0.007444    0.655681    
#> 149: 0.319450    0.971610    3.433152    0.193094    0.058472    0.007072    0.684250    
#> 150: 0.327912    0.970845    3.426710    0.183439    0.064529    0.006719    0.688841    
#> 151: 0.289679    0.996872    3.430280    0.211224    0.065010    0.006679    0.674512    
#> 152: 0.303218    0.973756    3.437265    0.179357    0.053587    0.006225    0.682909    
#> 153: 0.334154    0.977894    3.443625    0.173033    0.051720    0.008349    0.682573    
#> 154: 0.355968    0.979191    3.443185    0.147451    0.047778    0.007955    0.695934    
#> 155: 0.339171    0.969743    3.445245    0.129976    0.063485    0.008320    0.669621    
#> 156: 0.353457    0.964968    3.456821    0.131096    0.067455    0.007580    0.695804    
#> 157: 0.377078    0.951564    3.459624    0.174161    0.072200    0.007372    0.694056    
#> 158: 0.386603    0.977963    3.457908    0.160328    0.066962    0.009168    0.693747    
#> 159: 0.323827    0.979815    3.450470    0.169427    0.069448    0.007631    0.672805    
#> 160: 0.363620    0.934224    3.456628    0.226953    0.066113    0.008048    0.663020    
#> 161: 0.360148    0.957585    3.448808    0.192474    0.057596    0.008583    0.672437    
#> 162: 0.328202    0.980148    3.434492    0.161001    0.063362    0.007404    0.683798    
#> 163: 0.334282    0.964875    3.432700    0.156840    0.078047    0.006771    0.660639    
#> 164: 0.327598    0.974348    3.439211    0.172003    0.067170    0.008829    0.670652    
#> 165: 0.357742    0.951905    3.451973    0.165285    0.058451    0.012242    0.657399    
#> 166: 0.367333    0.970684    3.447176    0.173315    0.054691    0.011672    0.658778    
#> 167: 0.359250    0.986879    3.449546    0.184210    0.050356    0.011286    0.660484    
#> 168: 0.358918    0.982374    3.440112    0.202045    0.055824    0.009484    0.657586    
#> 169: 0.347191    0.999378    3.440709    0.163757    0.054001    0.009571    0.677853    
#> 170: 0.331833    0.975863    3.442601    0.142066    0.058335    0.006966    0.657609    
#> 171: 0.325313    0.956278    3.448056    0.155173    0.044962    0.008497    0.642815    
#> 172: 0.316867    0.979252    3.438103    0.161096    0.049985    0.008389    0.652886    
#> 173: 0.284374    1.011799    3.416392    0.205888    0.061378    0.010174    0.655283    
#> 174: 0.287930    0.980859    3.427295    0.212103    0.044714    0.012473    0.643080    
#> 175: 0.288616    0.996033    3.414329    0.191500    0.049465    0.013604    0.661192    
#> 176: 0.297285    1.001028    3.431382    0.195737    0.041393    0.011359    0.660755    
#> 177: 0.315773    1.000389    3.428872    0.213615    0.039638    0.011901    0.654153    
#> 178: 0.323641    0.977459    3.437279    0.172959    0.037672    0.010487    0.653661    
#> 179: 0.377724    0.990422    3.444520    0.159820    0.046195    0.010945    0.670332    
#> 180: 0.355175    0.988022    3.447340    0.158111    0.042300    0.008793    0.673151    
#> 181: 0.330020    0.954766    3.429811    0.173114    0.044108    0.009473    0.660356    
#> 182: 0.285079    0.972770    3.422369    0.169816    0.038155    0.010981    0.665319    
#> 183: 0.305837    0.983983    3.427196    0.170922    0.038843    0.011641    0.646261    
#> 184: 0.314816    0.975443    3.436739    0.168537    0.045249    0.009542    0.685596    
#> 185: 0.313164    0.995771    3.427491    0.171861    0.048066    0.007942    0.664025    
#> 186: 0.320713    1.002326    3.435874    0.180456    0.047587    0.010527    0.653248    
#> 187: 0.328782    0.986257    3.437474    0.197198    0.054891    0.010639    0.653054    
#> 188: 0.289966    0.989655    3.432594    0.164863    0.057796    0.008382    0.674456    
#> 189: 0.322810    1.006741    3.435011    0.170425    0.049937    0.008568    0.675471    
#> 190: 0.297363    0.993921    3.430503    0.147908    0.049884    0.009147    0.667511    
#> 191: 0.301714    0.994560    3.425178    0.188338    0.052985    0.007400    0.664471    
#> 192: 0.279312    1.001805    3.420352    0.212703    0.043594    0.008916    0.660538    
#> 193: 0.322611    1.003714    3.426680    0.230244    0.044916    0.007517    0.645044    
#> 194: 0.302727    0.974428    3.428589    0.199603    0.055814    0.009176    0.667265    
#> 195: 0.316113    0.988470    3.429067    0.224079    0.051996    0.011667    0.645292    
#> 196: 0.328719    0.985754    3.432146    0.237953    0.044034    0.012022    0.647990    
#> 197: 0.301029    0.987275    3.443378    0.212726    0.048842    0.011573    0.668459    
#> 198: 0.328956    0.983282    3.435681    0.209633    0.043288    0.011125    0.658245    
#> 199: 0.330014    0.966894    3.440130    0.206497    0.049352    0.009285    0.641266    
#> 200: 0.336358    0.963175    3.436529    0.245096    0.053494    0.012018    0.653898    
#> 201: 0.346556    0.966351    3.442605    0.236815    0.051649    0.012859    0.653228    
#> 202: 0.346251    0.969536    3.441742    0.237389    0.050155    0.012608    0.650754    
#> 203: 0.354262    0.969118    3.440898    0.235380    0.047285    0.012451    0.652661    
#> 204: 0.351623    0.965647    3.443505    0.230024    0.045479    0.012072    0.657832    
#> 205: 0.349485    0.969050    3.443664    0.228482    0.043750    0.011758    0.662050    
#> 206: 0.347711    0.971112    3.443571    0.227175    0.044833    0.011485    0.662035    
#> 207: 0.345231    0.972881    3.442217    0.225175    0.045804    0.011276    0.660242    
#> 208: 0.341347    0.974077    3.441541    0.220630    0.046501    0.011029    0.658324    
#> 209: 0.343142    0.971582    3.441557    0.219244    0.047095    0.010980    0.657757    
#> 210: 0.343942    0.969990    3.441419    0.217634    0.047556    0.010901    0.657479    
#> 211: 0.348011    0.971078    3.442519    0.217644    0.047781    0.010888    0.658018    
#> 212: 0.350689    0.970202    3.442793    0.214808    0.047837    0.010705    0.659117    
#> 213: 0.351698    0.968720    3.443210    0.210840    0.048103    0.010500    0.660394    
#> 214: 0.352149    0.968310    3.443367    0.208443    0.047897    0.010361    0.661243    
#> 215: 0.351624    0.968484    3.443253    0.206227    0.047764    0.010207    0.662347    
#> 216: 0.352064    0.968141    3.443150    0.203860    0.048253    0.010245    0.663820    
#> 217: 0.351408    0.968778    3.442853    0.202245    0.048734    0.010148    0.663460    
#> 218: 0.350488    0.969212    3.442421    0.200122    0.049002    0.010081    0.663326    
#> 219: 0.348887    0.968705    3.441733    0.198468    0.048871    0.010019    0.663451    
#> 220: 0.347672    0.968887    3.441406    0.197737    0.048791    0.009973    0.663632    
#> 221: 0.346253    0.969455    3.441071    0.196561    0.048956    0.009908    0.663070    
#> 222: 0.345316    0.969435    3.440733    0.195344    0.049380    0.009904    0.663259    
#> 223: 0.345545    0.970322    3.440226    0.195099    0.049467    0.009928    0.663348    
#> 224: 0.345257    0.970972    3.440117    0.195473    0.049314    0.009994    0.663270    
#> 225: 0.344874    0.969926    3.440226    0.195322    0.049154    0.010068    0.663170    
#> 226: 0.344913    0.969230    3.440141    0.194768    0.049209    0.010019    0.663296    
#> 227: 0.344629    0.969304    3.440338    0.196489    0.049198    0.010015    0.663025    
#> 228: 0.343844    0.970187    3.439677    0.197388    0.049353    0.010044    0.662805    
#> 229: 0.342077    0.970403    3.439016    0.197420    0.049445    0.010086    0.661862    
#> 230: 0.341617    0.970748    3.438523    0.197378    0.049496    0.010113    0.661927    
#> 231: 0.340275    0.971716    3.438060    0.197213    0.049791    0.010132    0.661697    
#> 232: 0.338412    0.971561    3.438146    0.197544    0.049780    0.010151    0.661724    
#> 233: 0.337319    0.971316    3.438072    0.198858    0.049692    0.010158    0.661664    
#> 234: 0.336353    0.971673    3.438011    0.199292    0.049661    0.010245    0.661553    
#> 235: 0.336611    0.971314    3.437928    0.200155    0.049327    0.010343    0.661470    
#> 236: 0.336828    0.971361    3.437827    0.200562    0.049190    0.010393    0.661799    
#> 237: 0.337999    0.970794    3.438033    0.199928    0.049020    0.010421    0.662225    
#> 238: 0.338318    0.970581    3.438234    0.199312    0.049191    0.010392    0.662921    
#> 239: 0.338341    0.970928    3.438268    0.198840    0.049545    0.010414    0.662664    
#> 240: 0.338573    0.970416    3.438754    0.198347    0.049613    0.010426    0.662613    
#> 241: 0.339559    0.969395    3.439164    0.199144    0.049623    0.010403    0.662680    
#> 242: 0.339918    0.969053    3.439110    0.199703    0.049512    0.010398    0.663202    
#> 243: 0.339606    0.969489    3.439022    0.200026    0.049582    0.010349    0.663546    
#> 244: 0.338939    0.969418    3.439083    0.200718    0.049370    0.010305    0.664082    
#> 245: 0.339159    0.969329    3.439299    0.200506    0.049478    0.010292    0.664431    
#> 246: 0.339201    0.969088    3.439396    0.200056    0.049424    0.010284    0.664310    
#> 247: 0.339352    0.968703    3.439605    0.199504    0.049616    0.010241    0.664075    
#> 248: 0.339123    0.968961    3.439693    0.199017    0.049757    0.010190    0.663699    
#> 249: 0.338688    0.968800    3.439816    0.198348    0.049822    0.010155    0.663926    
#> 250: 0.339692    0.969062    3.440048    0.198787    0.049891    0.010148    0.663886    
#> 251: 0.339808    0.969305    3.440286    0.198471    0.050041    0.010113    0.663909    
#> 252: 0.340219    0.969122    3.440503    0.197935    0.050244    0.010092    0.663747    
#> 253: 0.340160    0.968824    3.440584    0.197718    0.050378    0.010087    0.663829    
#> 254: 0.340138    0.968710    3.440860    0.197958    0.050573    0.010078    0.663794    
#> 255: 0.340403    0.968848    3.441011    0.198757    0.050596    0.010051    0.664004    
#> 256: 0.341064    0.968669    3.441067    0.198708    0.050472    0.010035    0.664177    
#> 257: 0.340857    0.968505    3.441019    0.198251    0.050530    0.010038    0.664228    
#> 258: 0.340577    0.968331    3.441032    0.198658    0.050559    0.010016    0.664080    
#> 259: 0.340109    0.968202    3.440927    0.198954    0.050601    0.010039    0.663928    
#> 260: 0.339814    0.968508    3.440907    0.198922    0.050620    0.010067    0.663563    
#> 261: 0.339751    0.968661    3.440890    0.199304    0.050608    0.010064    0.663471    
#> 262: 0.340169    0.969041    3.440851    0.199733    0.050463    0.010033    0.663424    
#> 263: 0.339923    0.969484    3.440847    0.199727    0.050341    0.010005    0.663554    
#> 264: 0.339859    0.969585    3.440823    0.199718    0.050215    0.009993    0.663710    
#> 265: 0.340316    0.969494    3.440927    0.200064    0.049960    0.010018    0.663789    
#> 266: 0.341146    0.969434    3.441118    0.200500    0.049866    0.010031    0.663547    
#> 267: 0.341537    0.969164    3.441353    0.200976    0.049806    0.010033    0.663551    
#> 268: 0.341361    0.968788    3.441320    0.200782    0.049851    0.010010    0.663713    
#> 269: 0.342144    0.968460    3.441393    0.200825    0.049934    0.010011    0.663828    
#> 270: 0.342519    0.968743    3.441393    0.200662    0.049910    0.009996    0.663487    
#> 271: 0.342457    0.968772    3.441380    0.200672    0.049875    0.009994    0.663556    
#> 272: 0.342296    0.968737    3.441344    0.200134    0.049825    0.010001    0.663764    
#> 273: 0.342127    0.969038    3.441327    0.200205    0.049709    0.010015    0.663677    
#> 274: 0.341559    0.969333    3.441232    0.199936    0.049668    0.010033    0.663687    
#> 275: 0.341060    0.969478    3.440993    0.199685    0.049546    0.010045    0.663654    
#> 276: 0.340858    0.969767    3.441056    0.200037    0.049558    0.010040    0.663675    
#> 277: 0.341182    0.970027    3.441241    0.200345    0.049593    0.010057    0.663561    
#> 278: 0.341407    0.969960    3.441396    0.200346    0.049653    0.010060    0.663544    
#> 279: 0.341293    0.969775    3.441459    0.199701    0.049800    0.010046    0.663759    
#> 280: 0.341320    0.969842    3.441507    0.199562    0.049860    0.010025    0.663774    
#> 281: 0.341163    0.969950    3.441583    0.199572    0.049916    0.010017    0.663980    
#> 282: 0.341429    0.970082    3.441739    0.199825    0.050021    0.009998    0.664085    
#> 283: 0.341679    0.969956    3.441902    0.199645    0.050186    0.009987    0.664473    
#> 284: 0.341776    0.969807    3.441978    0.199414    0.050228    0.009993    0.664587    
#> 285: 0.341643    0.969926    3.441852    0.199184    0.050331    0.010001    0.664701    
#> 286: 0.341591    0.970051    3.441791    0.199117    0.050530    0.009999    0.664600    
#> 287: 0.341290    0.970201    3.441664    0.199414    0.050523    0.009975    0.664691    
#> 288: 0.341420    0.970113    3.441671    0.199552    0.050551    0.009991    0.664705    
#> 289: 0.341727    0.969889    3.441743    0.199702    0.050593    0.010000    0.664435    
#> 290: 0.341917    0.969781    3.441836    0.200038    0.050569    0.010014    0.664556    
#> 291: 0.342162    0.969917    3.441937    0.199923    0.050538    0.010041    0.664287    
#> 292: 0.342202    0.969941    3.441951    0.199818    0.050553    0.010043    0.664179    
#> 293: 0.342112    0.969873    3.441915    0.199672    0.050473    0.010040    0.664059    
#> 294: 0.342028    0.969896    3.441898    0.199820    0.050496    0.010046    0.664074    
#> 295: 0.341878    0.969625    3.441910    0.199539    0.050464    0.010046    0.663985    
#> 296: 0.341878    0.969523    3.441889    0.199316    0.050423    0.010059    0.664061    
#> 297: 0.341820    0.969773    3.441859    0.199070    0.050425    0.010077    0.664075    
#> 298: 0.341807    0.969925    3.441854    0.199143    0.050376    0.010085    0.664061    
#> 299: 0.341912    0.970111    3.441798    0.199177    0.050301    0.010082    0.663946    
#> 300: 0.342185    0.970098    3.441831    0.199491    0.050358    0.010090    0.663685    
#> 301: 0.342325    0.970125    3.441772    0.199928    0.050315    0.010089    0.663517    
#> 302: 0.342558    0.970284    3.441746    0.200299    0.050289    0.010094    0.663297    
#> 303: 0.342529    0.970334    3.441753    0.200271    0.050297    0.010103    0.663091    
#> 304: 0.342333    0.970573    3.441616    0.200218    0.050293    0.010103    0.662968    
#> 305: 0.342234    0.970387    3.441591    0.200265    0.050327    0.010092    0.662787    
#> 306: 0.342003    0.970162    3.441598    0.200199    0.050307    0.010081    0.662807    
#> 307: 0.342143    0.970008    3.441575    0.200433    0.050333    0.010076    0.662785    
#> 308: 0.341963    0.969895    3.441500    0.200409    0.050372    0.010070    0.662909    
#> 309: 0.341650    0.969725    3.441381    0.200470    0.050401    0.010082    0.662904    
#> 310: 0.341666    0.969700    3.441252    0.200473    0.050425    0.010102    0.662980    
#> 311: 0.341259    0.969813    3.441101    0.200643    0.050427    0.010098    0.662987    
#> 312: 0.340834    0.969987    3.440834    0.200805    0.050390    0.010109    0.662933    
#> 313: 0.340449    0.969883    3.440667    0.201044    0.050357    0.010117    0.663142    
#> 314: 0.340151    0.969954    3.440557    0.201421    0.050350    0.010113    0.663189    
#> 315: 0.339583    0.970051    3.440423    0.201431    0.050363    0.010101    0.663238    
#> 316: 0.339475    0.970152    3.440380    0.201383    0.050439    0.010088    0.663210    
#> 317: 0.339589    0.970099    3.440442    0.201259    0.050461    0.010067    0.663442    
#> 318: 0.339734    0.970175    3.440386    0.201269    0.050335    0.010069    0.663492    
#> 319: 0.339599    0.970239    3.440345    0.201384    0.050274    0.010086    0.663522    
#> 320: 0.339336    0.970253    3.440253    0.201677    0.050300    0.010101    0.663452    
#> 321: 0.339066    0.970316    3.440112    0.201891    0.050378    0.010117    0.663438    
#> 322: 0.338829    0.970406    3.439961    0.201933    0.050467    0.010126    0.663314    
#> 323: 0.338378    0.970537    3.439913    0.201730    0.050502    0.010132    0.663287    
#> 324: 0.338234    0.970765    3.439863    0.201422    0.050504    0.010122    0.663232    
#> 325: 0.338108    0.970956    3.439730    0.201234    0.050505    0.010110    0.663295    
#> 326: 0.337931    0.970906    3.439644    0.201009    0.050516    0.010100    0.663348    
#> 327: 0.337911    0.970822    3.439640    0.200824    0.050579    0.010099    0.663378    
#> 328: 0.337891    0.970891    3.439605    0.200445    0.050568    0.010094    0.663485    
#> 329: 0.337884    0.971016    3.439615    0.200156    0.050609    0.010078    0.663515    
#> 330: 0.337790    0.971144    3.439613    0.199890    0.050592    0.010071    0.663636    
#> 331: 0.337764    0.971260    3.439589    0.199841    0.050592    0.010062    0.663591    
#> 332: 0.337953    0.971293    3.439675    0.200064    0.050556    0.010064    0.663450    
#> 333: 0.337894    0.971335    3.439628    0.199937    0.050503    0.010071    0.663310    
#> 334: 0.337759    0.971199    3.439588    0.199781    0.050439    0.010068    0.663285    
#> 335: 0.337628    0.971186    3.439530    0.199814    0.050345    0.010069    0.663246    
#> 336: 0.337443    0.971212    3.439439    0.200055    0.050249    0.010093    0.663268    
#> 337: 0.337388    0.971288    3.439389    0.200169    0.050179    0.010114    0.663370    
#> 338: 0.337369    0.971336    3.439379    0.200235    0.050174    0.010143    0.663435    
#> 339: 0.337273    0.971395    3.439366    0.200137    0.050215    0.010152    0.663378    
#> 340: 0.337209    0.971328    3.439365    0.199985    0.050332    0.010152    0.663399    
#> 341: 0.337270    0.971246    3.439379    0.200009    0.050462    0.010147    0.663357    
#> 342: 0.337064    0.971011    3.439367    0.199918    0.050503    0.010150    0.663335    
#> 343: 0.336896    0.971018    3.439349    0.199942    0.050551    0.010135    0.663286    
#> 344: 0.336978    0.970942    3.439366    0.200055    0.050561    0.010129    0.663305    
#> 345: 0.337087    0.970861    3.439436    0.200116    0.050616    0.010122    0.663279    
#> 346: 0.336894    0.970934    3.439366    0.200038    0.050690    0.010099    0.663245    
#> 347: 0.337038    0.970867    3.439303    0.199971    0.050762    0.010095    0.663347    
#> 348: 0.336780    0.970961    3.439243    0.199776    0.050882    0.010100    0.663398    
#> 349: 0.336619    0.970862    3.439244    0.199870    0.050894    0.010124    0.663471    
#> 350: 0.336599    0.970709    3.439231    0.199895    0.050951    0.010131    0.663467    
#> 351: 0.336706    0.970823    3.439196    0.199930    0.051010    0.010134    0.663391    
#> 352: 0.336520    0.970981    3.439178    0.199731    0.051075    0.010132    0.663476    
#> 353: 0.336427    0.971131    3.439131    0.199525    0.051055    0.010137    0.663450    
#> 354: 0.336380    0.971157    3.439033    0.199389    0.051004    0.010140    0.663493    
#> 355: 0.336616    0.971102    3.439003    0.199376    0.050974    0.010126    0.663488    
#> 356: 0.336649    0.971093    3.439023    0.199544    0.050997    0.010110    0.663546    
#> 357: 0.336807    0.971224    3.439035    0.199613    0.050994    0.010109    0.663405    
#> 358: 0.336870    0.971168    3.439089    0.199620    0.051027    0.010102    0.663300    
#> 359: 0.336855    0.971242    3.439062    0.199593    0.051041    0.010083    0.663248    
#> 360: 0.336861    0.971379    3.438958    0.199795    0.051095    0.010072    0.663103    
#> 361: 0.336652    0.971438    3.438905    0.199760    0.051097    0.010055    0.662983    
#> 362: 0.336641    0.971517    3.438837    0.199620    0.051119    0.010041    0.662878    
#> 363: 0.336574    0.971460    3.438805    0.199466    0.051086    0.010030    0.662859    
#> 364: 0.336618    0.971592    3.438757    0.199431    0.051141    0.010018    0.662793    
#> 365: 0.336597    0.971515    3.438790    0.199533    0.051147    0.010024    0.662866    
#> 366: 0.336646    0.971534    3.438774    0.199390    0.051153    0.010030    0.662965    
#> 367: 0.336677    0.971495    3.438765    0.199317    0.051095    0.010033    0.662976    
#> 368: 0.336860    0.971553    3.438753    0.199144    0.051072    0.010052    0.662887    
#> 369: 0.336855    0.971571    3.438749    0.199061    0.051129    0.010053    0.662896    
#> 370: 0.336858    0.971714    3.438733    0.198979    0.051186    0.010074    0.662853    
#> 371: 0.336784    0.971631    3.438682    0.198792    0.051187    0.010068    0.662904    
#> 372: 0.336816    0.971720    3.438678    0.198911    0.051183    0.010083    0.662841    
#> 373: 0.336458    0.971936    3.438545    0.198981    0.051156    0.010094    0.662771    
#> 374: 0.336231    0.971941    3.438445    0.199137    0.051096    0.010113    0.662619    
#> 375: 0.335944    0.972019    3.438344    0.199157    0.051099    0.010128    0.662607    
#> 376: 0.335782    0.972127    3.438248    0.199234    0.051058    0.010151    0.662496    
#> 377: 0.335556    0.972172    3.438193    0.199459    0.051044    0.010165    0.662386    
#> 378: 0.335376    0.972152    3.438130    0.199673    0.051044    0.010178    0.662366    
#> 379: 0.335170    0.972112    3.438056    0.199788    0.051060    0.010191    0.662380    
#> 380: 0.334940    0.972067    3.437966    0.200049    0.051108    0.010198    0.662325    
#> 381: 0.334749    0.972035    3.437946    0.200055    0.051096    0.010196    0.662254    
#> 382: 0.334783    0.972052    3.437973    0.200165    0.051100    0.010197    0.662131    
#> 383: 0.334853    0.972061    3.437988    0.200073    0.051102    0.010188    0.662047    
#> 384: 0.334941    0.971971    3.438072    0.199984    0.051106    0.010183    0.662071    
#> 385: 0.335069    0.971914    3.438161    0.199798    0.051139    0.010183    0.662070    
#> 386: 0.335199    0.971943    3.438271    0.199685    0.051157    0.010183    0.662050    
#> 387: 0.335513    0.971958    3.438374    0.199560    0.051191    0.010183    0.662083    
#> 388: 0.335751    0.971943    3.438474    0.199579    0.051156    0.010189    0.662031    
#> 389: 0.335773    0.971707    3.438498    0.199538    0.051167    0.010186    0.662072    
#> 390: 0.335634    0.971660    3.438509    0.199435    0.051154    0.010183    0.662101    
#> 391: 0.335637    0.971546    3.438516    0.199221    0.051105    0.010179    0.662085    
#> 392: 0.335646    0.971520    3.438559    0.199324    0.051062    0.010176    0.662100    
#> 393: 0.335416    0.971389    3.438482    0.199306    0.051020    0.010176    0.662075    
#> 394: 0.335328    0.971408    3.438419    0.199500    0.051032    0.010179    0.662091    
#> 395: 0.335420    0.971440    3.438382    0.199580    0.051068    0.010186    0.662121    
#> 396: 0.335388    0.971484    3.438368    0.199537    0.051097    0.010179    0.662185    
#> 397: 0.335397    0.971479    3.438371    0.199595    0.051118    0.010184    0.662224    
#> 398: 0.335373    0.971478    3.438343    0.199544    0.051110    0.010186    0.662261    
#> 399: 0.335503    0.971512    3.438398    0.199656    0.051170    0.010186    0.662144    
#> 400: 0.335566    0.971631    3.438421    0.199623    0.051225    0.010180    0.662108    
#> 401: 0.335559    0.971732    3.438391    0.199719    0.051316    0.010181    0.662166    
#> 402: 0.335524    0.971835    3.438326    0.199790    0.051364    0.010180    0.662199    
#> 403: 0.335631    0.971852    3.438311    0.199756    0.051385    0.010182    0.662191    
#> 404: 0.335595    0.971879    3.438237    0.199744    0.051376    0.010180    0.662156    
#> 405: 0.335477    0.971941    3.438187    0.199837    0.051343    0.010176    0.662184    
#> 406: 0.335482    0.971989    3.438150    0.200045    0.051333    0.010176    0.662181    
#> 407: 0.335427    0.972057    3.438152    0.199941    0.051375    0.010166    0.662134    
#> 408: 0.335503    0.972096    3.438164    0.199993    0.051362    0.010156    0.662140    
#> 409: 0.335530    0.972069    3.438127    0.199945    0.051331    0.010142    0.662150    
#> 410: 0.335588    0.972115    3.438065    0.199955    0.051368    0.010131    0.662188    
#> 411: 0.335658    0.972040    3.438035    0.200133    0.051337    0.010129    0.662210    
#> 412: 0.335639    0.972131    3.437954    0.200112    0.051337    0.010118    0.662175    
#> 413: 0.335622    0.972146    3.437911    0.200047    0.051328    0.010117    0.662237    
#> 414: 0.335479    0.972174    3.437918    0.200093    0.051303    0.010117    0.662226    
#> 415: 0.335521    0.972207    3.437900    0.200031    0.051275    0.010119    0.662219    
#> 416: 0.335590    0.972281    3.437919    0.200014    0.051278    0.010123    0.662253    
#> 417: 0.335581    0.972251    3.437892    0.200188    0.051295    0.010122    0.662210    
#> 418: 0.335387    0.972278    3.437881    0.200377    0.051285    0.010127    0.662134    
#> 419: 0.335425    0.972341    3.437895    0.200574    0.051334    0.010133    0.662108    
#> 420: 0.335424    0.972374    3.437881    0.200593    0.051391    0.010126    0.662064    
#> 421: 0.335368    0.972399    3.437863    0.200665    0.051422    0.010121    0.662016    
#> 422: 0.335362    0.972370    3.437819    0.200664    0.051427    0.010113    0.661991    
#> 423: 0.335408    0.972317    3.437803    0.200690    0.051486    0.010111    0.661993    
#> 424: 0.335330    0.972335    3.437741    0.200683    0.051538    0.010111    0.662020    
#> 425: 0.335272    0.972407    3.437741    0.200781    0.051496    0.010106    0.662111    
#> 426: 0.335245    0.972447    3.437721    0.200726    0.051478    0.010099    0.662091    
#> 427: 0.335117    0.972379    3.437709    0.200699    0.051446    0.010084    0.662110    
#> 428: 0.335041    0.972373    3.437702    0.200616    0.051484    0.010071    0.662131    
#> 429: 0.335016    0.972374    3.437713    0.200487    0.051553    0.010059    0.662152    
#> 430: 0.335000    0.972469    3.437711    0.200362    0.051573    0.010046    0.662263    
#> 431: 0.334940    0.972389    3.437681    0.200236    0.051611    0.010036    0.662234    
#> 432: 0.334775    0.972426    3.437661    0.200020    0.051643    0.010027    0.662179    
#> 433: 0.334783    0.972524    3.437719    0.199885    0.051610    0.010034    0.662220    
#> 434: 0.334752    0.972415    3.437736    0.199773    0.051593    0.010030    0.662233    
#> 435: 0.334881    0.972333    3.437771    0.199711    0.051582    0.010029    0.662224    
#> 436: 0.335031    0.972267    3.437811    0.199621    0.051618    0.010019    0.662278    
#> 437: 0.335045    0.972261    3.437832    0.199530    0.051663    0.010009    0.662303    
#> 438: 0.335067    0.972392    3.437867    0.199410    0.051660    0.010004    0.662327    
#> 439: 0.335070    0.972499    3.437859    0.199345    0.051656    0.010004    0.662275    
#> 440: 0.335033    0.972555    3.437859    0.199417    0.051674    0.009998    0.662244    
#> 441: 0.335069    0.972577    3.437857    0.199496    0.051673    0.009995    0.662165    
#> 442: 0.334919    0.972628    3.437841    0.199464    0.051695    0.009985    0.662126    
#> 443: 0.334847    0.972719    3.437780    0.199371    0.051661    0.009978    0.662131    
#> 444: 0.334753    0.972783    3.437728    0.199399    0.051650    0.009974    0.662113    
#> 445: 0.334644    0.972816    3.437660    0.199348    0.051644    0.009970    0.662137    
#> 446: 0.334444    0.972857    3.437587    0.199344    0.051647    0.009963    0.662134    
#> 447: 0.334544    0.972856    3.437616    0.199392    0.051606    0.009962    0.662068    
#> 448: 0.334581    0.972855    3.437644    0.199516    0.051557    0.009969    0.661991    
#> 449: 0.334623    0.972915    3.437706    0.199532    0.051513    0.009977    0.661961    
#> 450: 0.334662    0.972908    3.437728    0.199541    0.051504    0.009986    0.661951    
#> 451: 0.334791    0.972944    3.437729    0.199453    0.051507    0.009980    0.661970    
#> 452: 0.334782    0.972981    3.437708    0.199583    0.051498    0.009975    0.661918    
#> 453: 0.334759    0.973035    3.437696    0.199660    0.051480    0.009972    0.661823    
#> 454: 0.334747    0.973103    3.437704    0.199574    0.051449    0.009966    0.661771    
#> 455: 0.334793    0.973065    3.437718    0.199574    0.051437    0.009962    0.661716    
#> 456: 0.334770    0.973048    3.437704    0.199651    0.051448    0.009950    0.661724    
#> 457: 0.334748    0.973018    3.437754    0.199575    0.051494    0.009942    0.661645    
#> 458: 0.334740    0.973066    3.437790    0.199475    0.051506    0.009934    0.661638    
#> 459: 0.334689    0.973144    3.437800    0.199497    0.051495    0.009925    0.661636    
#> 460: 0.334745    0.973181    3.437805    0.199432    0.051496    0.009921    0.661611    
#> 461: 0.334720    0.973222    3.437809    0.199206    0.051502    0.009921    0.661645    
#> 462: 0.334612    0.973263    3.437818    0.199101    0.051516    0.009925    0.661662    
#> 463: 0.334673    0.973349    3.437811    0.199014    0.051505    0.009927    0.661675    
#> 464: 0.334635    0.973408    3.437779    0.199012    0.051504    0.009927    0.661661    
#> 465: 0.334615    0.973286    3.437782    0.199016    0.051499    0.009918    0.661676    
#> 466: 0.334639    0.973268    3.437779    0.198996    0.051510    0.009908    0.661666    
#> 467: 0.334620    0.973218    3.437802    0.199026    0.051546    0.009894    0.661633    
#> 468: 0.334719    0.973223    3.437842    0.199073    0.051550    0.009889    0.661694    
#> 469: 0.334822    0.973294    3.437868    0.199074    0.051530    0.009880    0.661731    
#> 470: 0.334781    0.973327    3.437828    0.199119    0.051528    0.009878    0.661704    
#> 471: 0.334702    0.973291    3.437813    0.199204    0.051498    0.009879    0.661646    
#> 472: 0.334674    0.973321    3.437806    0.199179    0.051510    0.009873    0.661633    
#> 473: 0.334580    0.973317    3.437804    0.199147    0.051507    0.009866    0.661563    
#> 474: 0.334492    0.973287    3.437809    0.199059    0.051495    0.009870    0.661546    
#> 475: 0.334488    0.973370    3.437818    0.199063    0.051460    0.009871    0.661536    
#> 476: 0.334472    0.973386    3.437781    0.198987    0.051439    0.009875    0.661576    
#> 477: 0.334435    0.973460    3.437793    0.198889    0.051410    0.009878    0.661495    
#> 478: 0.334327    0.973523    3.437784    0.198829    0.051385    0.009888    0.661500    
#> 479: 0.334324    0.973565    3.437784    0.198870    0.051336    0.009894    0.661557    
#> 480: 0.334362    0.973570    3.437778    0.198867    0.051328    0.009895    0.661651    
#> 481: 0.334376    0.973582    3.437755    0.198961    0.051359    0.009900    0.661692    
#> 482: 0.334366    0.973625    3.437740    0.198965    0.051371    0.009892    0.661671    
#> 483: 0.334314    0.973622    3.437728    0.198898    0.051407    0.009887    0.661630    
#> 484: 0.334381    0.973495    3.437747    0.198868    0.051414    0.009885    0.661633    
#> 485: 0.334392    0.973480    3.437768    0.198757    0.051404    0.009879    0.661676    
#> 486: 0.334515    0.973482    3.437805    0.198690    0.051394    0.009874    0.661686    
#> 487: 0.334724    0.973487    3.437855    0.198675    0.051375    0.009873    0.661761    
#> 488: 0.334795    0.973462    3.437898    0.198710    0.051383    0.009863    0.661798    
#> 489: 0.334848    0.973417    3.437892    0.198664    0.051409    0.009852    0.661855    
#> 490: 0.334891    0.973494    3.437905    0.198562    0.051417    0.009837    0.661854    
#> 491: 0.334865    0.973569    3.437928    0.198514    0.051400    0.009833    0.661812    
#> 492: 0.334868    0.973599    3.437938    0.198623    0.051384    0.009836    0.661801    
#> 493: 0.334814    0.973625    3.437937    0.198573    0.051366    0.009834    0.661862    
#> 494: 0.334998    0.973625    3.437962    0.198581    0.051377    0.009828    0.661866    
#> 495: 0.335095    0.973663    3.437983    0.198578    0.051373    0.009827    0.661868    
#> 496: 0.335141    0.973640    3.437962    0.198567    0.051312    0.009826    0.661856    
#> 497: 0.335132    0.973611    3.437967    0.198590    0.051307    0.009827    0.661819    
#> 498: 0.335160    0.973590    3.437954    0.198661    0.051291    0.009824    0.661758    
#> 499: 0.335151    0.973619    3.437922    0.198527    0.051314    0.009817    0.661778    
#> 500: 0.335267    0.973549    3.437920    0.198599    0.051325    0.009815    0.661842    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.285780    0.971500    3.451828    0.392401    0.081402    0.016800    1.750260    
#> 002: 0.295438    1.030248    3.463916    0.376495    0.077332    0.015960    1.139983    
#> 003: 0.436538    1.027110    3.495255    0.381046    0.073465    0.015162    0.853670    
#> 004: 0.436379    1.028390    3.509405    0.408015    0.069792    0.014404    0.739959    
#> 005: 0.509354    1.027918    3.504487    0.575758    0.066302    0.013684    0.670428    
#> 006: 0.466445    1.040042    3.494823    0.563559    0.072933    0.013000    0.606536    
#> 007: 0.469163    1.056521    3.498156    0.581119    0.071871    0.014556    0.619755    
#> 008: 0.450758    1.055042    3.494185    0.568630    0.081198    0.014065    0.598787    
#> 009: 0.407121    1.033696    3.491446    0.540198    0.093579    0.013362    0.614596    
#> 010: 0.435394    1.046643    3.488833    0.594685    0.088900    0.012902    0.616775    
#> 011: 0.475894    1.057842    3.489652    0.672931    0.084455    0.013689    0.596182    
#> 012: 0.492449    1.053124    3.479042    0.837691    0.085049    0.013004    0.591547    
#> 013: 0.457792    1.069253    3.469543    0.808561    0.083383    0.013044    0.612433    
#> 014: 0.504904    1.053805    3.482235    0.835793    0.079214    0.012392    0.626950    
#> 015: 0.534987    1.073795    3.491676    0.866208    0.075253    0.011772    0.614327    
#> 016: 0.553283    1.068215    3.494965    0.828729    0.071491    0.011183    0.628241    
#> 017: 0.501463    1.058155    3.496850    0.815889    0.074159    0.010624    0.596396    
#> 018: 0.516863    1.062152    3.491922    0.775095    0.075266    0.013004    0.596954    
#> 019: 0.495129    1.067665    3.488384    0.736340    0.071503    0.012354    0.582317    
#> 020: 0.525666    1.076951    3.496765    0.764682    0.067928    0.014572    0.605102    
#> 021: 0.504097    1.068126    3.501325    0.726448    0.073386    0.013977    0.610597    
#> 022: 0.506176    1.061275    3.511434    0.690126    0.069717    0.013310    0.589195    
#> 023: 0.603707    1.048718    3.524501    0.780599    0.080973    0.017245    0.600440    
#> 024: 0.584036    1.066646    3.510033    0.814562    0.083860    0.016383    0.586323    
#> 025: 0.577937    1.049855    3.500862    0.903141    0.085730    0.015564    0.584618    
#> 026: 0.568644    1.066356    3.503474    0.857984    0.092870    0.014786    0.606574    
#> 027: 0.532651    1.080474    3.498430    0.815085    0.088226    0.014046    0.613307    
#> 028: 0.527315    1.074569    3.493906    0.774330    0.083815    0.013344    0.601443    
#> 029: 0.521151    1.074180    3.485626    0.794795    0.082078    0.015406    0.622527    
#> 030: 0.559281    1.072060    3.488896    0.885114    0.080800    0.014636    0.620509    
#> 031: 0.523989    1.059404    3.497422    0.875411    0.094343    0.013904    0.607888    
#> 032: 0.442532    1.047455    3.493064    0.831641    0.089626    0.013209    0.596465    
#> 033: 0.456129    1.055746    3.482964    0.790059    0.085144    0.012549    0.604075    
#> 034: 0.476225    1.086512    3.486773    0.750556    0.080887    0.011921    0.605053    
#> 035: 0.477565    1.068711    3.489911    0.713028    0.076843    0.011325    0.590402    
#> 036: 0.488868    1.069788    3.492137    0.677377    0.079382    0.011164    0.605606    
#> 037: 0.449078    1.075614    3.486881    0.643508    0.075412    0.012561    0.619829    
#> 038: 0.497791    1.072166    3.489200    0.679765    0.074010    0.012860    0.597038    
#> 039: 0.488664    1.064918    3.497991    0.648985    0.071514    0.013767    0.598074    
#> 040: 0.476684    1.076796    3.502418    0.654900    0.081793    0.013859    0.613218    
#> 041: 0.525249    1.060629    3.499138    0.679937    0.077703    0.014234    0.608829    
#> 042: 0.548780    1.065513    3.497584    0.777979    0.073818    0.014828    0.592840    
#> 043: 0.478003    1.077192    3.479992    0.739080    0.070127    0.014086    0.587179    
#> 044: 0.472964    1.066364    3.482168    0.702126    0.066796    0.014310    0.590692    
#> 045: 0.472083    1.086373    3.476261    0.751075    0.068127    0.013595    0.579990    
#> 046: 0.455445    1.076522    3.482837    0.713521    0.080252    0.012915    0.585741    
#> 047: 0.459053    1.088967    3.475701    0.677845    0.084597    0.012269    0.603549    
#> 048: 0.468163    1.085606    3.480258    0.643953    0.090616    0.011656    0.608836    
#> 049: 0.472847    1.073200    3.487511    0.658065    0.086974    0.011073    0.610152    
#> 050: 0.509947    1.039485    3.490105    0.795200    0.088207    0.011124    0.607302    
#> 051: 0.497648    1.070246    3.484130    0.755440    0.083797    0.011126    0.619087    
#> 052: 0.509916    1.083044    3.490570    0.778668    0.079607    0.012486    0.611159    
#> 053: 0.508868    1.074390    3.491478    0.739734    0.076987    0.012012    0.606257    
#> 054: 0.462693    1.069451    3.499106    0.702747    0.083471    0.013250    0.605043    
#> 055: 0.445407    1.064676    3.490627    0.667610    0.079297    0.012587    0.607612    
#> 056: 0.476250    1.052208    3.492988    0.649855    0.081541    0.012097    0.616130    
#> 057: 0.524712    1.065907    3.506349    0.726835    0.083090    0.012691    0.622204    
#> 058: 0.526831    1.054786    3.496592    0.693414    0.097060    0.012057    0.629988    
#> 059: 0.462262    1.015117    3.495094    0.675062    0.099761    0.012254    0.625923    
#> 060: 0.458127    1.031519    3.502541    0.641308    0.094773    0.014666    0.639453    
#> 061: 0.524679    1.056677    3.506503    0.612305    0.090034    0.014716    0.625005    
#> 062: 0.504037    1.055467    3.507841    0.628432    0.085532    0.015384    0.623248    
#> 063: 0.517044    1.026055    3.500141    0.655885    0.081256    0.014615    0.631154    
#> 064: 0.464539    1.053060    3.499073    0.623091    0.080252    0.013884    0.622977    
#> 065: 0.493895    1.031427    3.488165    0.646133    0.089625    0.013799    0.604595    
#> 066: 0.472320    1.068941    3.486422    0.618501    0.088882    0.014431    0.601114    
#> 067: 0.464145    1.065612    3.487694    0.621571    0.084438    0.014823    0.598221    
#> 068: 0.447960    1.070119    3.485692    0.660968    0.080216    0.014082    0.611784    
#> 069: 0.456198    1.065587    3.486050    0.646958    0.081246    0.014879    0.612247    
#> 070: 0.430713    1.041067    3.497187    0.614610    0.077713    0.016525    0.611071    
#> 071: 0.443706    1.078891    3.475918    0.619700    0.073827    0.015698    0.626326    
#> 072: 0.460616    1.069588    3.476629    0.690108    0.081787    0.014914    0.599017    
#> 073: 0.576793    1.083175    3.503085    0.969107    0.077698    0.014168    0.600115    
#> 074: 0.527217    1.047236    3.498451    0.920652    0.073813    0.015027    0.585054    
#> 075: 0.507050    1.056288    3.506190    0.874619    0.072946    0.017799    0.596102    
#> 076: 0.566235    1.050954    3.525220    0.830888    0.069298    0.016909    0.607816    
#> 077: 0.558051    1.029226    3.522181    0.789344    0.065833    0.019701    0.596119    
#> 078: 0.536975    1.031537    3.514423    0.749877    0.067515    0.019843    0.590696    
#> 079: 0.537939    1.053710    3.498429    0.784331    0.064139    0.019176    0.613130    
#> 080: 0.547194    1.046743    3.496516    0.800686    0.063342    0.018217    0.628764    
#> 081: 0.494935    1.064093    3.496957    0.871078    0.069960    0.017306    0.622620    
#> 082: 0.507179    1.057437    3.505352    0.827524    0.078231    0.018005    0.620126    
#> 083: 0.508552    1.079700    3.493624    0.915465    0.074320    0.017380    0.615052    
#> 084: 0.492741    1.073621    3.489375    0.869692    0.078115    0.016511    0.616105    
#> 085: 0.480420    1.075008    3.503403    0.826208    0.074209    0.017618    0.605115    
#> 086: 0.533622    1.063273    3.503733    0.784897    0.070499    0.016737    0.596096    
#> 087: 0.539271    1.073450    3.492415    0.898448    0.066974    0.015900    0.599967    
#> 088: 0.480896    1.068983    3.492873    0.888578    0.065547    0.015105    0.604034    
#> 089: 0.446355    1.087165    3.482796    0.844149    0.067963    0.014350    0.609814    
#> 090: 0.444441    1.064082    3.478731    0.801941    0.068155    0.013632    0.627180    
#> 091: 0.465778    1.055647    3.464035    0.761844    0.074020    0.012951    0.622329    
#> 092: 0.473333    1.067160    3.470536    0.743129    0.086365    0.012303    0.629264    
#> 093: 0.431279    1.058608    3.470262    0.705972    0.093890    0.011688    0.622522    
#> 094: 0.427712    1.076868    3.467489    0.673004    0.098898    0.011103    0.618194    
#> 095: 0.414194    1.094497    3.466577    0.659088    0.093953    0.010679    0.604436    
#> 096: 0.410675    1.076174    3.467227    0.631440    0.089256    0.010145    0.592452    
#> 097: 0.407811    1.085387    3.463284    0.633227    0.092357    0.011258    0.598772    
#> 098: 0.470432    1.086789    3.487750    0.665803    0.090738    0.010695    0.605204    
#> 099: 0.493517    1.064050    3.483937    0.683160    0.086201    0.010248    0.616048    
#> 100: 0.452986    1.068315    3.485058    0.649002    0.094857    0.011112    0.605730    
#> 101: 0.449222    1.058553    3.478895    0.659927    0.090114    0.010557    0.604633    
#> 102: 0.443093    1.071599    3.467957    0.655688    0.085608    0.010029    0.605839    
#> 103: 0.446899    1.076944    3.470562    0.661726    0.081328    0.009527    0.587429    
#> 104: 0.454144    1.083881    3.481918    0.665847    0.079188    0.009051    0.603606    
#> 105: 0.453476    1.069818    3.469988    0.693641    0.092281    0.008598    0.606242    
#> 106: 0.472220    1.063857    3.478516    0.735546    0.089945    0.008169    0.612746    
#> 107: 0.469387    1.077082    3.484950    0.719921    0.100998    0.007760    0.607424    
#> 108: 0.496796    1.053444    3.485859    0.802440    0.095948    0.007372    0.607131    
#> 109: 0.466170    1.069975    3.493255    0.762318    0.108024    0.007003    0.612089    
#> 110: 0.457642    1.075569    3.477402    0.724202    0.107164    0.006653    0.622580    
#> 111: 0.474696    1.075616    3.483185    0.687992    0.102098    0.006321    0.612323    
#> 112: 0.457151    1.043904    3.477484    0.653592    0.103306    0.006005    0.635452    
#> 113: 0.434022    1.089415    3.475815    0.654536    0.098141    0.005704    0.614676    
#> 114: 0.488396    1.074738    3.477056    0.720147    0.102036    0.005419    0.605857    
#> 115: 0.454390    1.046176    3.480601    0.684140    0.110827    0.005462    0.614364    
#> 116: 0.476620    1.076361    3.491538    0.649933    0.105285    0.005371    0.606206    
#> 117: 0.461885    1.072653    3.493310    0.617436    0.103712    0.006639    0.611330    
#> 118: 0.492514    1.048575    3.490748    0.660284    0.098527    0.006307    0.626064    
#> 119: 0.479836    1.064032    3.486951    0.692754    0.099186    0.006466    0.646243    
#> 120: 0.460484    1.055317    3.488262    0.727379    0.105417    0.006998    0.632051    
#> 121: 0.509557    1.102340    3.486024    0.706596    0.100146    0.008483    0.626594    
#> 122: 0.508998    1.086466    3.491189    0.682058    0.095139    0.010347    0.603916    
#> 123: 0.497594    1.101091    3.484627    0.647955    0.090382    0.009829    0.607228    
#> 124: 0.500073    1.117636    3.465097    0.773503    0.086989    0.009338    0.620607    
#> 125: 0.450005    1.095081    3.468266    0.734828    0.094803    0.009573    0.631106    
#> 126: 0.402987    1.107985    3.459595    0.698087    0.093588    0.011099    0.618788    
#> 127: 0.443752    1.074616    3.467078    0.663182    0.097402    0.010544    0.607689    
#> 128: 0.442341    1.068712    3.479437    0.630023    0.092531    0.010335    0.608847    
#> 129: 0.459931    1.080020    3.483624    0.598522    0.087905    0.009855    0.619999    
#> 130: 0.481165    1.071920    3.488396    0.613873    0.083510    0.009363    0.597825    
#> 131: 0.494845    1.057338    3.479526    0.673179    0.081238    0.011009    0.583415    
#> 132: 0.464844    1.067554    3.478974    0.687961    0.093676    0.010459    0.599802    
#> 133: 0.433748    1.056424    3.481829    0.653563    0.088992    0.009936    0.610308    
#> 134: 0.498208    1.040415    3.499844    0.781919    0.084543    0.010271    0.606602    
#> 135: 0.547945    1.053006    3.513130    0.742823    0.080315    0.010504    0.606839    
#> 136: 0.485499    1.040245    3.509990    0.705682    0.079267    0.009979    0.610436    
#> 137: 0.514642    1.040734    3.507607    0.670398    0.075304    0.012831    0.615835    
#> 138: 0.476148    1.058061    3.497859    0.647659    0.071538    0.012189    0.613430    
#> 139: 0.465568    1.067781    3.503968    0.626698    0.080574    0.011952    0.598247    
#> 140: 0.468129    1.060135    3.500065    0.595363    0.083313    0.011355    0.607600    
#> 141: 0.484335    1.031425    3.506440    0.634852    0.079148    0.010787    0.613359    
#> 142: 0.524220    1.046500    3.512537    0.629127    0.082226    0.010856    0.622038    
#> 143: 0.463967    1.069389    3.500669    0.656739    0.091201    0.011626    0.612569    
#> 144: 0.530136    1.053685    3.515068    0.633604    0.086641    0.011045    0.611970    
#> 145: 0.506235    1.052411    3.497892    0.685035    0.082309    0.010493    0.609785    
#> 146: 0.510066    1.059169    3.506620    0.725781    0.081890    0.010700    0.607938    
#> 147: 0.492201    1.045329    3.494949    0.689492    0.077795    0.012011    0.601639    
#> 148: 0.475330    1.043138    3.509355    0.665857    0.073906    0.011411    0.610133    
#> 149: 0.470131    1.037869    3.504585    0.632564    0.070210    0.013242    0.606515    
#> 150: 0.507360    1.054864    3.495974    0.700295    0.072836    0.012580    0.622949    
#> 151: 0.480475    1.067765    3.492354    0.689759    0.069222    0.011951    0.612471    
#> 152: 0.498912    1.063184    3.499889    0.797498    0.075166    0.010926    0.606549    
#> 153: 0.479926    1.071893    3.496400    0.835389    0.093436    0.010913    0.614972    
#> 154: 0.523233    1.064588    3.494291    0.746328    0.092300    0.010360    0.622950    
#> 155: 0.453132    1.063362    3.489999    0.606066    0.070286    0.010230    0.624913    
#> 156: 0.513551    1.065464    3.502344    0.617361    0.074879    0.012683    0.615812    
#> 157: 0.497161    1.046773    3.507582    0.641586    0.073107    0.015784    0.620765    
#> 158: 0.542544    1.066330    3.508840    0.654372    0.068200    0.014151    0.581250    
#> 159: 0.491144    1.052541    3.515851    0.657829    0.070290    0.012814    0.598032    
#> 160: 0.543188    1.008381    3.526135    0.709171    0.077894    0.013070    0.603685    
#> 161: 0.484150    1.043196    3.513309    0.625220    0.075228    0.015647    0.601373    
#> 162: 0.517736    1.046987    3.509543    0.595037    0.064609    0.016303    0.611296    
#> 163: 0.543915    1.043377    3.501006    0.670915    0.061452    0.014537    0.613725    
#> 164: 0.484114    1.056296    3.504147    0.534429    0.058781    0.015115    0.598581    
#> 165: 0.490761    1.049763    3.489994    0.636552    0.069800    0.012570    0.605940    
#> 166: 0.497691    1.073977    3.489100    0.530632    0.076189    0.009394    0.610341    
#> 167: 0.469759    1.088484    3.493345    0.558338    0.089546    0.009217    0.616776    
#> 168: 0.536906    1.082348    3.500946    0.712635    0.092150    0.009750    0.611840    
#> 169: 0.492775    1.101303    3.496517    0.558334    0.100946    0.008053    0.612772    
#> 170: 0.544223    1.075912    3.498268    0.662300    0.087492    0.009747    0.598233    
#> 171: 0.481018    1.077670    3.490161    0.710831    0.090684    0.009411    0.599305    
#> 172: 0.459284    1.083310    3.486759    0.670194    0.087578    0.008581    0.596161    
#> 173: 0.477654    1.094292    3.468534    0.725672    0.088499    0.007533    0.608732    
#> 174: 0.471939    1.078475    3.475457    0.709055    0.091627    0.006747    0.598075    
#> 175: 0.483673    1.051294    3.475025    0.831015    0.099091    0.006425    0.602969    
#> 176: 0.492482    1.092418    3.479972    0.715808    0.089668    0.005648    0.595497    
#> 177: 0.474450    1.076623    3.482183    0.697443    0.105766    0.005644    0.606416    
#> 178: 0.455509    1.052019    3.481417    0.649594    0.089432    0.006445    0.599523    
#> 179: 0.501266    1.093531    3.486996    0.575249    0.087418    0.006113    0.623981    
#> 180: 0.483943    1.079320    3.487069    0.701124    0.075807    0.005746    0.617371    
#> 181: 0.478194    1.070736    3.470928    0.690605    0.089168    0.004773    0.621078    
#> 182: 0.421934    1.088448    3.460357    0.743816    0.111548    0.004465    0.634271    
#> 183: 0.436561    1.100609    3.462893    0.550355    0.099528    0.005306    0.629115    
#> 184: 0.441001    1.065744    3.473786    0.522322    0.096978    0.004742    0.638879    
#> 185: 0.418945    1.076225    3.478471    0.555879    0.095665    0.005118    0.628768    
#> 186: 0.413681    1.112016    3.476645    0.544893    0.100022    0.005686    0.626194    
#> 187: 0.447135    1.073223    3.492543    0.550695    0.089541    0.006620    0.612773    
#> 188: 0.459269    1.075858    3.489290    0.601674    0.085247    0.005786    0.627697    
#> 189: 0.451503    1.079609    3.488008    0.626908    0.089928    0.007612    0.615512    
#> 190: 0.456488    1.079026    3.491821    0.549389    0.088018    0.009219    0.593328    
#> 191: 0.471233    1.077312    3.484883    0.602399    0.082783    0.009274    0.582190    
#> 192: 0.448862    1.079463    3.482967    0.640303    0.080800    0.007964    0.591170    
#> 193: 0.475615    1.078891    3.481538    0.666459    0.072503    0.008855    0.595482    
#> 194: 0.448196    1.075839    3.479462    0.563180    0.080892    0.008618    0.606999    
#> 195: 0.412067    1.073818    3.469082    0.588967    0.071557    0.007803    0.624888    
#> 196: 0.434329    1.070824    3.485802    0.561951    0.096279    0.010289    0.624556    
#> 197: 0.423740    1.059688    3.501152    0.572981    0.071750    0.012603    0.629557    
#> 198: 0.491469    1.053554    3.489474    0.654290    0.084033    0.012943    0.611985    
#> 199: 0.510747    1.063359    3.494006    0.740109    0.079275    0.012855    0.621638    
#> 200: 0.471691    1.059973    3.489040    0.755203    0.080733    0.013083    0.631213    
#> 201: 0.487290    1.053568    3.490584    0.822595    0.083563    0.012869    0.624203    
#> 202: 0.502154    1.052568    3.491127    0.888426    0.085889    0.011989    0.623296    
#> 203: 0.517449    1.049256    3.489489    0.931105    0.087162    0.011851    0.619006    
#> 204: 0.516025    1.046259    3.491664    0.912398    0.088276    0.011108    0.621689    
#> 205: 0.522296    1.053061    3.493066    0.903259    0.089723    0.011126    0.624011    
#> 206: 0.521241    1.057772    3.494058    0.891257    0.089548    0.010832    0.623162    
#> 207: 0.519953    1.059474    3.493551    0.867051    0.089773    0.010537    0.622833    
#> 208: 0.521380    1.060981    3.493610    0.855306    0.088752    0.010234    0.620897    
#> 209: 0.526709    1.058489    3.494227    0.860095    0.086887    0.010343    0.619901    
#> 210: 0.529460    1.057228    3.495179    0.854245    0.085462    0.010365    0.619140    
#> 211: 0.531384    1.056287    3.497029    0.842301    0.084374    0.010522    0.616633    
#> 212: 0.531050    1.055199    3.497541    0.826817    0.083393    0.010711    0.615641    
#> 213: 0.531407    1.054101    3.498385    0.810357    0.083076    0.010967    0.616020    
#> 214: 0.532904    1.054027    3.498736    0.799490    0.082653    0.011303    0.616000    
#> 215: 0.529599    1.054675    3.499468    0.782964    0.082173    0.011548    0.615964    
#> 216: 0.530390    1.053604    3.499954    0.775424    0.081651    0.011531    0.616933    
#> 217: 0.527672    1.053817    3.500290    0.765992    0.080940    0.011544    0.615762    
#> 218: 0.525828    1.054433    3.500214    0.760806    0.080786    0.011718    0.614868    
#> 219: 0.524329    1.053912    3.499545    0.755182    0.080144    0.011987    0.615654    
#> 220: 0.522614    1.054043    3.499392    0.759682    0.079334    0.012118    0.615613    
#> 221: 0.521145    1.054357    3.499244    0.756387    0.078964    0.012158    0.614961    
#> 222: 0.519394    1.054050    3.499212    0.747817    0.079002    0.012249    0.614973    
#> 223: 0.520557    1.053000    3.499503    0.747219    0.078843    0.012410    0.614311    
#> 224: 0.521806    1.053350    3.500083    0.748183    0.078907    0.012409    0.613858    
#> 225: 0.522152    1.052167    3.500506    0.749407    0.078973    0.012391    0.613512    
#> 226: 0.520354    1.051127    3.500621    0.744646    0.078888    0.012293    0.613421    
#> 227: 0.519477    1.050960    3.500691    0.739176    0.079397    0.012156    0.612969    
#> 228: 0.517806    1.051515    3.500305    0.735450    0.079817    0.012075    0.612439    
#> 229: 0.514747    1.051723    3.499819    0.731763    0.080410    0.012013    0.611742    
#> 230: 0.513495    1.051466    3.499458    0.729222    0.080773    0.011959    0.611075    
#> 231: 0.512247    1.051860    3.499392    0.727205    0.080602    0.011897    0.611047    
#> 232: 0.510617    1.051957    3.499470    0.724540    0.080480    0.011842    0.610726    
#> 233: 0.509004    1.051173    3.499591    0.724179    0.080504    0.011890    0.610735    
#> 234: 0.507420    1.051075    3.499679    0.720968    0.080527    0.011917    0.610763    
#> 235: 0.507739    1.051295    3.499584    0.720687    0.080367    0.011856    0.610796    
#> 236: 0.509662    1.051861    3.499647    0.727325    0.080537    0.011849    0.610962    
#> 237: 0.510551    1.052272    3.499696    0.730736    0.080556    0.011823    0.610929    
#> 238: 0.510781    1.052349    3.499666    0.731642    0.080782    0.011835    0.611484    
#> 239: 0.510131    1.052280    3.499793    0.729102    0.080956    0.011871    0.611098    
#> 240: 0.510566    1.051730    3.500172    0.726620    0.081213    0.011868    0.610808    
#> 241: 0.511120    1.050705    3.500556    0.725835    0.081182    0.011853    0.610853    
#> 242: 0.511202    1.050099    3.500588    0.726896    0.081606    0.011910    0.611144    
#> 243: 0.510752    1.050415    3.500551    0.727026    0.081904    0.011937    0.611299    
#> 244: 0.510528    1.050601    3.500563    0.728657    0.082029    0.011934    0.611404    
#> 245: 0.510567    1.050044    3.500711    0.728545    0.081900    0.011867    0.611722    
#> 246: 0.510977    1.049828    3.501037    0.726454    0.081805    0.011854    0.611786    
#> 247: 0.511211    1.049554    3.501256    0.725075    0.081802    0.011889    0.611821    
#> 248: 0.511244    1.049927    3.501333    0.723881    0.081733    0.011878    0.611457    
#> 249: 0.510295    1.050405    3.501182    0.721819    0.081641    0.011878    0.611505    
#> 250: 0.511103    1.051076    3.501168    0.722922    0.081631    0.011861    0.611356    
#> 251: 0.511654    1.051720    3.501469    0.721942    0.081594    0.011866    0.611439    
#> 252: 0.512713    1.052199    3.501828    0.722125    0.081693    0.011885    0.611398    
#> 253: 0.512721    1.052467    3.501903    0.721090    0.081525    0.011906    0.611542    
#> 254: 0.513213    1.052740    3.501941    0.722413    0.081553    0.011910    0.611766    
#> 255: 0.514055    1.053011    3.501978    0.725307    0.081939    0.011895    0.611549    
#> 256: 0.514049    1.053050    3.501778    0.724808    0.082166    0.011861    0.611659    
#> 257: 0.513081    1.052827    3.501605    0.722882    0.081989    0.011833    0.611846    
#> 258: 0.512528    1.052548    3.501410    0.722318    0.082064    0.011769    0.612221    
#> 259: 0.512108    1.052771    3.501221    0.721693    0.082000    0.011702    0.612223    
#> 260: 0.511679    1.053027    3.501162    0.720356    0.081858    0.011643    0.612225    
#> 261: 0.511951    1.053167    3.501250    0.720483    0.081786    0.011614    0.612109    
#> 262: 0.512250    1.053382    3.501329    0.719862    0.081715    0.011574    0.612033    
#> 263: 0.512078    1.053447    3.501288    0.718367    0.081638    0.011595    0.612112    
#> 264: 0.511443    1.053741    3.501112    0.718469    0.081625    0.011578    0.612294    
#> 265: 0.511456    1.053746    3.501035    0.719312    0.081831    0.011603    0.612561    
#> 266: 0.511679    1.053848    3.500948    0.721858    0.081794    0.011635    0.612775    
#> 267: 0.511431    1.054015    3.500925    0.723530    0.081768    0.011658    0.612834    
#> 268: 0.511738    1.053991    3.500885    0.723789    0.081774    0.011657    0.612785    
#> 269: 0.512236    1.054061    3.500815    0.724248    0.081854    0.011645    0.612729    
#> 270: 0.512749    1.054442    3.500667    0.724870    0.081847    0.011649    0.612438    
#> 271: 0.513046    1.054715    3.500430    0.725755    0.081921    0.011604    0.612538    
#> 272: 0.513199    1.054313    3.500438    0.723375    0.082058    0.011555    0.612945    
#> 273: 0.513361    1.054445    3.500493    0.723878    0.082381    0.011503    0.613180    
#> 274: 0.513673    1.054526    3.500578    0.723806    0.082523    0.011454    0.613360    
#> 275: 0.513815    1.054675    3.500525    0.722917    0.082686    0.011412    0.613365    
#> 276: 0.514222    1.055037    3.500689    0.723587    0.082680    0.011387    0.613355    
#> 277: 0.513997    1.055350    3.500819    0.723804    0.082583    0.011358    0.613448    
#> 278: 0.514689    1.055312    3.501020    0.724955    0.082607    0.011329    0.613571    
#> 279: 0.514923    1.055060    3.501246    0.725088    0.082654    0.011323    0.613684    
#> 280: 0.514987    1.055149    3.501430    0.723602    0.082660    0.011343    0.613533    
#> 281: 0.514828    1.055089    3.501603    0.722965    0.082585    0.011348    0.613522    
#> 282: 0.514695    1.055183    3.501742    0.721744    0.082466    0.011354    0.613300    
#> 283: 0.514406    1.055428    3.501812    0.720056    0.082262    0.011390    0.613426    
#> 284: 0.514229    1.055339    3.501785    0.718806    0.082200    0.011406    0.613228    
#> 285: 0.514058    1.055279    3.501736    0.717689    0.082060    0.011430    0.613173    
#> 286: 0.513670    1.055282    3.501665    0.716633    0.081847    0.011430    0.613147    
#> 287: 0.513055    1.055438    3.501591    0.715483    0.081724    0.011429    0.613192    
#> 288: 0.512864    1.055294    3.501540    0.715199    0.081652    0.011415    0.613180    
#> 289: 0.513340    1.055132    3.501541    0.717089    0.081652    0.011412    0.613160    
#> 290: 0.513548    1.055122    3.501495    0.718135    0.081739    0.011392    0.613291    
#> 291: 0.513318    1.055521    3.501425    0.717383    0.081800    0.011361    0.613224    
#> 292: 0.512804    1.055630    3.501350    0.715966    0.081863    0.011340    0.613195    
#> 293: 0.512911    1.055691    3.501312    0.715952    0.081819    0.011324    0.613156    
#> 294: 0.512828    1.055931    3.501247    0.715563    0.081839    0.011310    0.613028    
#> 295: 0.513155    1.055742    3.501237    0.716130    0.081845    0.011295    0.612793    
#> 296: 0.513437    1.055746    3.501197    0.717904    0.081811    0.011282    0.612760    
#> 297: 0.513408    1.055912    3.501152    0.718612    0.081721    0.011282    0.612753    
#> 298: 0.513337    1.055765    3.501179    0.717835    0.081695    0.011253    0.612794    
#> 299: 0.513188    1.055717    3.501151    0.717882    0.081588    0.011224    0.612880    
#> 300: 0.513172    1.055589    3.501218    0.717828    0.081472    0.011207    0.612822    
#> 301: 0.513509    1.055447    3.501170    0.718626    0.081431    0.011196    0.612668    
#> 302: 0.513858    1.055523    3.501109    0.719674    0.081441    0.011187    0.612457    
#> 303: 0.513876    1.055671    3.501025    0.719665    0.081359    0.011181    0.612278    
#> 304: 0.514176    1.055884    3.500866    0.720844    0.081206    0.011162    0.612178    
#> 305: 0.513629    1.055874    3.500705    0.720126    0.081151    0.011166    0.612079    
#> 306: 0.513085    1.055859    3.500522    0.719310    0.081284    0.011150    0.612112    
#> 307: 0.512741    1.055740    3.500343    0.719989    0.081373    0.011148    0.612159    
#> 308: 0.512443    1.055674    3.500212    0.721340    0.081398    0.011172    0.612345    
#> 309: 0.512255    1.055513    3.500068    0.722481    0.081412    0.011210    0.612488    
#> 310: 0.512340    1.055549    3.499862    0.724350    0.081428    0.011237    0.612416    
#> 311: 0.512423    1.055472    3.499776    0.725025    0.081483    0.011237    0.612315    
#> 312: 0.511950    1.055348    3.499673    0.724428    0.081488    0.011236    0.612373    
#> 313: 0.511607    1.055058    3.499573    0.724877    0.081515    0.011231    0.612435    
#> 314: 0.511243    1.055083    3.499468    0.724935    0.081551    0.011215    0.612360    
#> 315: 0.510840    1.055323    3.499358    0.724564    0.081516    0.011195    0.612343    
#> 316: 0.510261    1.055444    3.499206    0.723560    0.081643    0.011176    0.612368    
#> 317: 0.510040    1.055517    3.499088    0.723398    0.081734    0.011167    0.612397    
#> 318: 0.509655    1.055791    3.498902    0.723047    0.081794    0.011163    0.612366    
#> 319: 0.509528    1.055950    3.498794    0.723523    0.081799    0.011160    0.612360    
#> 320: 0.508988    1.055983    3.498627    0.722816    0.081835    0.011157    0.612377    
#> 321: 0.508460    1.056060    3.498458    0.721623    0.081732    0.011158    0.612452    
#> 322: 0.508243    1.055957    3.498332    0.720615    0.081639    0.011143    0.612349    
#> 323: 0.507843    1.055939    3.498273    0.719749    0.081594    0.011146    0.612336    
#> 324: 0.507686    1.055976    3.498262    0.719380    0.081509    0.011148    0.612193    
#> 325: 0.507698    1.056126    3.498249    0.718786    0.081467    0.011135    0.612057    
#> 326: 0.507385    1.055994    3.498165    0.717719    0.081523    0.011108    0.611960    
#> 327: 0.507163    1.056004    3.498150    0.717221    0.081469    0.011099    0.611854    
#> 328: 0.506997    1.056166    3.498095    0.716558    0.081504    0.011084    0.611784    
#> 329: 0.507262    1.056302    3.498129    0.716221    0.081591    0.011079    0.611689    
#> 330: 0.507286    1.056232    3.498187    0.715464    0.081603    0.011059    0.611888    
#> 331: 0.507362    1.056243    3.498263    0.714965    0.081593    0.011027    0.611961    
#> 332: 0.507259    1.056206    3.498341    0.713970    0.081604    0.011012    0.612156    
#> 333: 0.506964    1.056108    3.498343    0.712573    0.081645    0.011001    0.612144    
#> 334: 0.506887    1.055913    3.498345    0.711603    0.081516    0.011007    0.612067    
#> 335: 0.506642    1.055963    3.498292    0.710896    0.081560    0.011002    0.611943    
#> 336: 0.506375    1.056121    3.498208    0.710715    0.081592    0.010994    0.611798    
#> 337: 0.506011    1.056552    3.498074    0.710679    0.081641    0.010982    0.611803    
#> 338: 0.505852    1.056785    3.498029    0.710197    0.081701    0.010982    0.611795    
#> 339: 0.505615    1.057041    3.498011    0.709724    0.081670    0.011001    0.611757    
#> 340: 0.505474    1.057131    3.497971    0.708844    0.081635    0.011015    0.611773    
#> 341: 0.505569    1.057087    3.498030    0.708435    0.081547    0.011018    0.611749    
#> 342: 0.505231    1.056936    3.498022    0.707877    0.081474    0.011011    0.611721    
#> 343: 0.505088    1.056949    3.498065    0.707464    0.081483    0.011003    0.611631    
#> 344: 0.505158    1.057006    3.498090    0.706875    0.081511    0.010997    0.611562    
#> 345: 0.505046    1.057029    3.498145    0.706176    0.081482    0.010995    0.611535    
#> 346: 0.504721    1.057081    3.498107    0.705324    0.081355    0.010996    0.611461    
#> 347: 0.505032    1.057034    3.498079    0.706466    0.081333    0.011017    0.611406    
#> 348: 0.504753    1.057156    3.498010    0.706159    0.081248    0.011024    0.611420    
#> 349: 0.504373    1.057148    3.497892    0.705817    0.081174    0.011028    0.611392    
#> 350: 0.504161    1.057151    3.497748    0.706798    0.081148    0.011019    0.611385    
#> 351: 0.504330    1.057307    3.497609    0.708135    0.081156    0.011011    0.611406    
#> 352: 0.504125    1.057453    3.497537    0.708454    0.081144    0.011009    0.611376    
#> 353: 0.503987    1.057649    3.497488    0.707728    0.081155    0.010986    0.611344    
#> 354: 0.503622    1.057797    3.497335    0.706912    0.081082    0.010986    0.611289    
#> 355: 0.503557    1.057787    3.497278    0.706482    0.081078    0.010967    0.611303    
#> 356: 0.503861    1.057783    3.497271    0.706778    0.081152    0.010947    0.611338    
#> 357: 0.504231    1.057789    3.497268    0.707293    0.081203    0.010926    0.611296    
#> 358: 0.504415    1.057838    3.497275    0.707637    0.081232    0.010914    0.611248    
#> 359: 0.504417    1.057964    3.497230    0.707564    0.081314    0.010896    0.611158    
#> 360: 0.504455    1.058031    3.497161    0.707603    0.081312    0.010885    0.610980    
#> 361: 0.504371    1.057943    3.497123    0.707603    0.081212    0.010884    0.610963    
#> 362: 0.504358    1.057814    3.497123    0.707201    0.081160    0.010881    0.610768    
#> 363: 0.504355    1.057734    3.497190    0.706783    0.081142    0.010884    0.610550    
#> 364: 0.504594    1.057646    3.497252    0.707130    0.081058    0.010903    0.610451    
#> 365: 0.504675    1.057522    3.497306    0.706984    0.081051    0.010919    0.610394    
#> 366: 0.504443    1.057504    3.497247    0.706204    0.081013    0.010920    0.610393    
#> 367: 0.504354    1.057641    3.497222    0.705897    0.081041    0.010919    0.610306    
#> 368: 0.504301    1.057747    3.497137    0.705788    0.081002    0.010919    0.610278    
#> 369: 0.503856    1.057784    3.497086    0.705369    0.081005    0.010928    0.610370    
#> 370: 0.503727    1.057937    3.497067    0.705279    0.080985    0.010940    0.610245    
#> 371: 0.503409    1.058067    3.496989    0.705157    0.080977    0.010943    0.610160    
#> 372: 0.503117    1.058217    3.496912    0.705180    0.081023    0.010940    0.610118    
#> 373: 0.502899    1.058413    3.496823    0.705399    0.081059    0.010943    0.610070    
#> 374: 0.502932    1.058439    3.496771    0.705627    0.081034    0.010937    0.610001    
#> 375: 0.502717    1.058498    3.496727    0.705260    0.081007    0.010928    0.610061    
#> 376: 0.502706    1.058607    3.496678    0.706429    0.081092    0.010924    0.610047    
#> 377: 0.502792    1.058726    3.496685    0.706641    0.081242    0.010901    0.610054    
#> 378: 0.502768    1.058719    3.496707    0.705823    0.081293    0.010879    0.610047    
#> 379: 0.502568    1.058565    3.496749    0.705008    0.081303    0.010858    0.610029    
#> 380: 0.502580    1.058488    3.496775    0.704847    0.081400    0.010848    0.609965    
#> 381: 0.502422    1.058459    3.496759    0.704752    0.081412    0.010843    0.609971    
#> 382: 0.502268    1.058432    3.496737    0.704769    0.081385    0.010851    0.609898    
#> 383: 0.502074    1.058319    3.496738    0.704416    0.081375    0.010863    0.609808    
#> 384: 0.501802    1.058305    3.496772    0.704104    0.081341    0.010879    0.609807    
#> 385: 0.501917    1.058377    3.496789    0.704511    0.081283    0.010885    0.609780    
#> 386: 0.502148    1.058576    3.496798    0.704663    0.081225    0.010887    0.609813    
#> 387: 0.502155    1.058723    3.496818    0.704164    0.081171    0.010908    0.609794    
#> 388: 0.502163    1.058757    3.496835    0.703704    0.081096    0.010918    0.609823    
#> 389: 0.502235    1.058650    3.496823    0.703725    0.081040    0.010929    0.609846    
#> 390: 0.502226    1.058688    3.496808    0.703436    0.080984    0.010937    0.609808    
#> 391: 0.502086    1.058707    3.496768    0.703288    0.080926    0.010948    0.609714    
#> 392: 0.502172    1.058719    3.496773    0.703460    0.080878    0.010954    0.609704    
#> 393: 0.502163    1.058645    3.496767    0.703511    0.080815    0.010958    0.609645    
#> 394: 0.502260    1.058560    3.496759    0.703433    0.080802    0.010959    0.609563    
#> 395: 0.502437    1.058684    3.496771    0.703577    0.080778    0.010957    0.609551    
#> 396: 0.502443    1.058704    3.496779    0.703746    0.080735    0.010957    0.609505    
#> 397: 0.502515    1.058582    3.496827    0.703932    0.080674    0.010968    0.609543    
#> 398: 0.502745    1.058443    3.496901    0.703773    0.080650    0.010967    0.609585    
#> 399: 0.502729    1.058390    3.496962    0.703602    0.080604    0.010958    0.609570    
#> 400: 0.503013    1.058455    3.496980    0.703661    0.080576    0.010959    0.609565    
#> 401: 0.502966    1.058507    3.496959    0.703311    0.080617    0.010964    0.609596    
#> 402: 0.502927    1.058662    3.496916    0.703222    0.080626    0.010976    0.609670    
#> 403: 0.503014    1.058804    3.496867    0.703170    0.080668    0.010979    0.609654    
#> 404: 0.502926    1.058854    3.496796    0.702944    0.080694    0.010986    0.609635    
#> 405: 0.502619    1.058915    3.496771    0.702723    0.080765    0.010989    0.609640    
#> 406: 0.502547    1.059048    3.496728    0.703295    0.080776    0.011004    0.609606    
#> 407: 0.502697    1.059103    3.496735    0.704050    0.080870    0.011002    0.609607    
#> 408: 0.502930    1.059141    3.496734    0.704503    0.080920    0.010992    0.609555    
#> 409: 0.503063    1.059037    3.496727    0.704863    0.080868    0.010981    0.609499    
#> 410: 0.503061    1.059050    3.496708    0.705345    0.080878    0.010983    0.609503    
#> 411: 0.503155    1.058946    3.496669    0.706214    0.080889    0.010979    0.609556    
#> 412: 0.503190    1.059032    3.496622    0.706888    0.080914    0.010985    0.609548    
#> 413: 0.503294    1.059119    3.496577    0.707424    0.080949    0.010978    0.609577    
#> 414: 0.503184    1.059093    3.496591    0.707401    0.080964    0.010975    0.609535    
#> 415: 0.503305    1.059094    3.496598    0.707244    0.080988    0.010976    0.609440    
#> 416: 0.503383    1.059165    3.496626    0.706795    0.081015    0.010978    0.609381    
#> 417: 0.503377    1.059154    3.496620    0.706575    0.081041    0.010973    0.609323    
#> 418: 0.503045    1.059179    3.496568    0.706179    0.081094    0.010954    0.609224    
#> 419: 0.502841    1.059242    3.496510    0.706070    0.081080    0.010937    0.609200    
#> 420: 0.502769    1.059319    3.496504    0.705706    0.081154    0.010926    0.609164    
#> 421: 0.502723    1.059369    3.496547    0.705458    0.081221    0.010908    0.609105    
#> 422: 0.502803    1.059369    3.496562    0.705506    0.081260    0.010894    0.609091    
#> 423: 0.502934    1.059315    3.496566    0.705863    0.081265    0.010890    0.609079    
#> 424: 0.502939    1.059296    3.496567    0.705906    0.081278    0.010883    0.608997    
#> 425: 0.502998    1.059346    3.496545    0.706593    0.081270    0.010884    0.608963    
#> 426: 0.502930    1.059409    3.496481    0.706801    0.081247    0.010877    0.609006    
#> 427: 0.502737    1.059464    3.496421    0.706693    0.081256    0.010880    0.608960    
#> 428: 0.502744    1.059571    3.496357    0.707256    0.081291    0.010878    0.608956    
#> 429: 0.502688    1.059676    3.496344    0.707434    0.081314    0.010867    0.608968    
#> 430: 0.502535    1.059733    3.496348    0.707071    0.081332    0.010869    0.608953    
#> 431: 0.502452    1.059719    3.496358    0.706653    0.081311    0.010867    0.608894    
#> 432: 0.502420    1.059705    3.496362    0.706933    0.081266    0.010872    0.608824    
#> 433: 0.502443    1.059823    3.496412    0.706845    0.081220    0.010882    0.608831    
#> 434: 0.502254    1.059756    3.496443    0.706343    0.081153    0.010895    0.608796    
#> 435: 0.502307    1.059669    3.496457    0.705798    0.081102    0.010907    0.608761    
#> 436: 0.502376    1.059645    3.496495    0.705284    0.081017    0.010911    0.608756    
#> 437: 0.502410    1.059634    3.496525    0.704825    0.080991    0.010912    0.608735    
#> 438: 0.502450    1.059724    3.496573    0.704246    0.080982    0.010900    0.608697    
#> 439: 0.502528    1.059724    3.496595    0.704085    0.080997    0.010891    0.608638    
#> 440: 0.502746    1.059670    3.496679    0.703868    0.081014    0.010878    0.608717    
#> 441: 0.502871    1.059578    3.496754    0.703713    0.081049    0.010867    0.608670    
#> 442: 0.502713    1.059544    3.496801    0.703126    0.081067    0.010861    0.608624    
#> 443: 0.502782    1.059534    3.496816    0.702683    0.081075    0.010852    0.608616    
#> 444: 0.502730    1.059569    3.496783    0.702462    0.081134    0.010837    0.608574    
#> 445: 0.502599    1.059623    3.496731    0.702262    0.081193    0.010825    0.608580    
#> 446: 0.502320    1.059685    3.496674    0.701841    0.081231    0.010809    0.608546    
#> 447: 0.502322    1.059706    3.496672    0.701910    0.081268    0.010803    0.608515    
#> 448: 0.502189    1.059673    3.496666    0.702044    0.081296    0.010799    0.608491    
#> 449: 0.502190    1.059698    3.496754    0.701873    0.081302    0.010797    0.608606    
#> 450: 0.502329    1.059683    3.496783    0.702262    0.081310    0.010794    0.608661    
#> 451: 0.502462    1.059653    3.496811    0.702358    0.081353    0.010792    0.608721    
#> 452: 0.502438    1.059660    3.496816    0.702395    0.081378    0.010793    0.608719    
#> 453: 0.502319    1.059772    3.496756    0.702310    0.081420    0.010782    0.608706    
#> 454: 0.502148    1.059923    3.496699    0.701804    0.081452    0.010772    0.608679    
#> 455: 0.502055    1.060053    3.496657    0.701553    0.081470    0.010759    0.608681    
#> 456: 0.501875    1.060102    3.496619    0.701173    0.081487    0.010755    0.608700    
#> 457: 0.501803    1.060065    3.496641    0.700969    0.081471    0.010749    0.608664    
#> 458: 0.501777    1.060103    3.496705    0.700535    0.081438    0.010748    0.608629    
#> 459: 0.501620    1.060190    3.496732    0.700233    0.081408    0.010748    0.608659    
#> 460: 0.501534    1.060144    3.496748    0.700002    0.081347    0.010757    0.608681    
#> 461: 0.501461    1.060159    3.496755    0.699897    0.081309    0.010770    0.608650    
#> 462: 0.501347    1.060264    3.496747    0.699652    0.081270    0.010773    0.608643    
#> 463: 0.501267    1.060334    3.496721    0.699394    0.081239    0.010765    0.608690    
#> 464: 0.501291    1.060376    3.496720    0.699135    0.081200    0.010757    0.608667    
#> 465: 0.501288    1.060286    3.496704    0.699179    0.081160    0.010755    0.608619    
#> 466: 0.501288    1.060334    3.496682    0.699192    0.081150    0.010749    0.608573    
#> 467: 0.501311    1.060279    3.496696    0.699144    0.081185    0.010748    0.608501    
#> 468: 0.501441    1.060256    3.496760    0.698719    0.081180    0.010760    0.608464    
#> 469: 0.501504    1.060349    3.496820    0.698157    0.081185    0.010766    0.608485    
#> 470: 0.501333    1.060392    3.496805    0.698130    0.081188    0.010769    0.608422    
#> 471: 0.501312    1.060380    3.496787    0.698039    0.081195    0.010763    0.608387    
#> 472: 0.501305    1.060376    3.496810    0.698180    0.081212    0.010765    0.608347    
#> 473: 0.501181    1.060368    3.496804    0.698040    0.081188    0.010763    0.608293    
#> 474: 0.501098    1.060402    3.496778    0.697913    0.081167    0.010775    0.608309    
#> 475: 0.501001    1.060512    3.496732    0.698029    0.081125    0.010777    0.608308    
#> 476: 0.500842    1.060487    3.496673    0.697871    0.081072    0.010778    0.608422    
#> 477: 0.500928    1.060442    3.496682    0.698318    0.081041    0.010783    0.608405    
#> 478: 0.500938    1.060411    3.496664    0.698867    0.081038    0.010785    0.608425    
#> 479: 0.501168    1.060422    3.496647    0.699723    0.081054    0.010784    0.608427    
#> 480: 0.501201    1.060418    3.496622    0.700478    0.081008    0.010783    0.608473    
#> 481: 0.501224    1.060393    3.496592    0.701057    0.080957    0.010784    0.608471    
#> 482: 0.501259    1.060432    3.496534    0.701801    0.080924    0.010786    0.608496    
#> 483: 0.501176    1.060478    3.496511    0.701796    0.080854    0.010787    0.608484    
#> 484: 0.501078    1.060448    3.496484    0.701711    0.080802    0.010780    0.608488    
#> 485: 0.501001    1.060516    3.496444    0.701547    0.080756    0.010787    0.608519    
#> 486: 0.500954    1.060627    3.496423    0.701731    0.080736    0.010790    0.608510    
#> 487: 0.501162    1.060678    3.496455    0.702410    0.080699    0.010799    0.608477    
#> 488: 0.501329    1.060688    3.496483    0.703005    0.080709    0.010804    0.608404    
#> 489: 0.501533    1.060682    3.496509    0.703285    0.080673    0.010816    0.608368    
#> 490: 0.501597    1.060697    3.496530    0.703147    0.080657    0.010831    0.608299    
#> 491: 0.501665    1.060791    3.496555    0.703210    0.080673    0.010833    0.608298    
#> 492: 0.501730    1.060858    3.496534    0.703633    0.080684    0.010832    0.608313    
#> 493: 0.501724    1.060798    3.496576    0.703342    0.080647    0.010845    0.608317    
#> 494: 0.501826    1.060808    3.496577    0.703260    0.080638    0.010850    0.608299    
#> 495: 0.501943    1.060825    3.496597    0.703154    0.080629    0.010856    0.608279    
#> 496: 0.502193    1.060902    3.496570    0.703748    0.080621    0.010863    0.608256    
#> 497: 0.502306    1.060881    3.496590    0.704019    0.080635    0.010860    0.608245    
#> 498: 0.502381    1.060829    3.496563    0.704492    0.080605    0.010857    0.608292    
#> 499: 0.502432    1.060826    3.496538    0.704410    0.080663    0.010852    0.608342    
#> 500: 0.502507    1.060777    3.496513    0.704584    0.080709    0.010845    0.608320    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.285890    0.964316    3.443101    0.392401    0.079274    0.016800    1.494046    
#> 002: 0.358107    1.100637    3.453973    0.372781    0.075310    0.015960    0.988383    
#> 003: 0.457433    1.059539    3.488394    0.354142    0.071545    0.015162    0.744591    
#> 004: 0.461911    1.088794    3.489349    0.336435    0.067967    0.014404    0.686405    
#> 005: 0.560565    1.070013    3.501586    0.319613    0.064569    0.013684    0.645116    
#> 006: 0.539598    1.067991    3.506964    0.303633    0.061341    0.013000    0.571329    
#> 007: 0.501245    1.091702    3.495716    0.288451    0.058274    0.013103    0.556173    
#> 008: 0.501169    1.084193    3.491565    0.274029    0.055360    0.012609    0.566561    
#> 009: 0.478950    1.056197    3.499138    0.260327    0.052592    0.013181    0.566146    
#> 010: 0.504864    1.060660    3.493449    0.247311    0.049962    0.013015    0.574836    
#> 011: 0.563657    1.047192    3.509239    0.234945    0.047464    0.013618    0.583193    
#> 012: 0.547890    1.059842    3.497716    0.225782    0.045091    0.015693    0.567272    
#> 013: 0.487506    1.065336    3.483477    0.214493    0.042836    0.018451    0.565169    
#> 014: 0.520873    1.064953    3.497488    0.239753    0.040695    0.017529    0.564828    
#> 015: 0.531068    1.074438    3.503776    0.227765    0.038660    0.016652    0.563476    
#> 016: 0.512412    1.077108    3.511918    0.216377    0.036727    0.015820    0.579273    
#> 017: 0.535029    1.078893    3.508230    0.233117    0.034891    0.017376    0.561638    
#> 018: 0.550420    1.084517    3.501709    0.221462    0.033146    0.016507    0.566384    
#> 019: 0.506203    1.077613    3.497518    0.210389    0.031489    0.015940    0.560447    
#> 020: 0.516302    1.075602    3.501762    0.207886    0.030631    0.019725    0.580445    
#> 021: 0.543234    1.063107    3.510300    0.201468    0.029099    0.018739    0.574084    
#> 022: 0.522462    1.068152    3.517648    0.193917    0.027644    0.020834    0.558975    
#> 023: 0.587800    1.072581    3.516005    0.205840    0.026262    0.020201    0.572101    
#> 024: 0.586270    1.086012    3.524483    0.210112    0.024949    0.021641    0.555176    
#> 025: 0.557963    1.062237    3.508465    0.212123    0.023702    0.022788    0.560895    
#> 026: 0.508534    1.084130    3.494529    0.201517    0.022516    0.021648    0.564331    
#> 027: 0.489732    1.095192    3.490696    0.245726    0.021391    0.020566    0.578884    
#> 028: 0.530192    1.080612    3.498554    0.233440    0.020321    0.019538    0.570786    
#> 029: 0.536373    1.070932    3.491817    0.239568    0.020860    0.019039    0.582081    
#> 030: 0.538199    1.088400    3.496153    0.235432    0.019817    0.019675    0.576474    
#> 031: 0.526267    1.067864    3.513566    0.243374    0.018826    0.019015    0.570946    
#> 032: 0.500960    1.055550    3.510162    0.231205    0.018302    0.018442    0.575767    
#> 033: 0.499510    1.062930    3.505897    0.219645    0.017386    0.018530    0.583712    
#> 034: 0.527244    1.078659    3.503450    0.208672    0.016517    0.019619    0.563608    
#> 035: 0.507404    1.056497    3.505418    0.212607    0.015691    0.018638    0.555699    
#> 036: 0.525523    1.079266    3.500078    0.201977    0.014926    0.017706    0.562153    
#> 037: 0.508613    1.081374    3.498553    0.196144    0.018077    0.017266    0.572618    
#> 038: 0.519599    1.082633    3.498009    0.222471    0.020601    0.018546    0.564879    
#> 039: 0.548261    1.081323    3.508336    0.211347    0.019571    0.018417    0.568005    
#> 040: 0.532254    1.078241    3.509271    0.226507    0.018593    0.018038    0.569693    
#> 041: 0.525265    1.078074    3.495849    0.253079    0.017663    0.019250    0.563756    
#> 042: 0.523985    1.073100    3.500759    0.245854    0.016780    0.018888    0.566567    
#> 043: 0.491356    1.092116    3.487392    0.247727    0.015941    0.019492    0.586490    
#> 044: 0.499554    1.091978    3.494119    0.235341    0.015144    0.018518    0.582913    
#> 045: 0.494955    1.095131    3.490912    0.223574    0.016419    0.017874    0.569405    
#> 046: 0.502501    1.081843    3.498052    0.212395    0.018459    0.017573    0.559971    
#> 047: 0.522655    1.074215    3.498396    0.203826    0.017536    0.016970    0.549552    
#> 048: 0.520541    1.059665    3.503356    0.193635    0.017764    0.020845    0.561047    
#> 049: 0.506286    1.065961    3.501947    0.195269    0.016876    0.019802    0.581630    
#> 050: 0.549286    1.048811    3.512716    0.201647    0.016032    0.021225    0.590752    
#> 051: 0.533186    1.055604    3.508678    0.191564    0.015231    0.023215    0.576220    
#> 052: 0.550814    1.070672    3.517768    0.209064    0.017402    0.022054    0.553461    
#> 053: 0.536749    1.059850    3.514025    0.205217    0.017032    0.020951    0.558575    
#> 054: 0.506388    1.057414    3.507326    0.200303    0.018365    0.019904    0.567662    
#> 055: 0.502532    1.064402    3.508789    0.206350    0.017447    0.018909    0.577720    
#> 056: 0.509978    1.061622    3.513307    0.197864    0.021499    0.017963    0.587132    
#> 057: 0.527135    1.053548    3.520559    0.207632    0.020424    0.017065    0.585645    
#> 058: 0.502283    1.057393    3.503576    0.197251    0.019403    0.016212    0.584158    
#> 059: 0.503563    1.038803    3.501079    0.192056    0.019990    0.017737    0.607695    
#> 060: 0.524382    1.031918    3.514356    0.190930    0.020856    0.020167    0.599249    
#> 061: 0.560872    1.038682    3.524025    0.181384    0.019813    0.019159    0.592483    
#> 062: 0.540430    1.057657    3.522071    0.229116    0.018822    0.019094    0.597654    
#> 063: 0.572155    1.045292    3.515327    0.217660    0.017881    0.018281    0.604264    
#> 064: 0.570242    1.054055    3.527553    0.210893    0.016987    0.021083    0.588805    
#> 065: 0.568690    1.048518    3.513458    0.207465    0.016138    0.020322    0.578843    
#> 066: 0.543255    1.052435    3.511066    0.204214    0.015331    0.019306    0.578065    
#> 067: 0.503946    1.055643    3.501577    0.194003    0.014564    0.020202    0.569829    
#> 068: 0.465072    1.073308    3.501971    0.187825    0.013836    0.021730    0.585491    
#> 069: 0.505507    1.081387    3.498913    0.187118    0.013144    0.020644    0.599788    
#> 070: 0.543969    1.079707    3.501276    0.237391    0.013161    0.019611    0.595442    
#> 071: 0.497145    1.095137    3.481751    0.225522    0.017412    0.018718    0.585223    
#> 072: 0.476327    1.083797    3.485889    0.223241    0.016541    0.017782    0.574442    
#> 073: 0.512500    1.083913    3.497226    0.232581    0.015714    0.016893    0.562684    
#> 074: 0.501714    1.070261    3.498355    0.220952    0.014929    0.016756    0.579664    
#> 075: 0.520122    1.065893    3.524948    0.209904    0.014182    0.016708    0.566384    
#> 076: 0.561574    1.078962    3.523569    0.200941    0.015291    0.017426    0.584149    
#> 077: 0.578003    1.067773    3.517171    0.192422    0.015331    0.016555    0.581013    
#> 078: 0.576983    1.067763    3.521628    0.201732    0.015122    0.017630    0.568132    
#> 079: 0.541001    1.067645    3.513776    0.191645    0.014366    0.016748    0.577995    
#> 080: 0.559001    1.061646    3.514120    0.225775    0.015053    0.015911    0.586276    
#> 081: 0.557262    1.058920    3.510249    0.225570    0.017116    0.015115    0.572084    
#> 082: 0.531095    1.051516    3.514445    0.214292    0.017469    0.017775    0.573030    
#> 083: 0.524544    1.061762    3.509389    0.203577    0.016596    0.018472    0.586976    
#> 084: 0.540151    1.073603    3.514763    0.204601    0.021453    0.018475    0.575863    
#> 085: 0.583722    1.072307    3.533798    0.194371    0.020621    0.017551    0.587603    
#> 086: 0.578593    1.058244    3.530678    0.184652    0.024445    0.016674    0.568443    
#> 087: 0.545386    1.057194    3.523887    0.178207    0.027069    0.015840    0.566441    
#> 088: 0.491689    1.056328    3.520348    0.177835    0.025716    0.016772    0.576760    
#> 089: 0.536401    1.056680    3.508363    0.179163    0.024430    0.017993    0.575370    
#> 090: 0.492148    1.075133    3.497341    0.186288    0.023209    0.017094    0.563053    
#> 091: 0.473790    1.082976    3.479446    0.203012    0.023356    0.016239    0.564169    
#> 092: 0.488752    1.097723    3.472292    0.219982    0.022188    0.015427    0.570667    
#> 093: 0.465628    1.090017    3.475900    0.208983    0.021079    0.017072    0.589842    
#> 094: 0.472263    1.100978    3.484630    0.198534    0.020025    0.017856    0.584776    
#> 095: 0.483118    1.103324    3.492877    0.188607    0.025632    0.017870    0.575556    
#> 096: 0.445806    1.101294    3.479849    0.193089    0.028193    0.016976    0.564422    
#> 097: 0.512671    1.115457    3.498478    0.229799    0.026783    0.020168    0.551557    
#> 098: 0.506132    1.114467    3.494788    0.232315    0.025444    0.019159    0.557724    
#> 099: 0.486566    1.092073    3.483831    0.220700    0.025717    0.018201    0.556021    
#> 100: 0.496285    1.102337    3.488155    0.222520    0.024431    0.018232    0.560252    
#> 101: 0.464710    1.095355    3.472275    0.216300    0.023312    0.017321    0.547745    
#> 102: 0.484768    1.084262    3.479666    0.214953    0.022768    0.016455    0.547649    
#> 103: 0.522222    1.081679    3.496339    0.254701    0.021629    0.017735    0.552210    
#> 104: 0.516770    1.080109    3.503214    0.241966    0.024107    0.017421    0.554665    
#> 105: 0.539730    1.066661    3.509075    0.234646    0.022947    0.018738    0.557647    
#> 106: 0.528717    1.072511    3.509646    0.222914    0.022786    0.020505    0.551598    
#> 107: 0.566676    1.078093    3.508686    0.211768    0.021646    0.019484    0.561701    
#> 108: 0.525414    1.090273    3.507509    0.221781    0.023614    0.018510    0.571408    
#> 109: 0.522270    1.077723    3.512925    0.210692    0.022433    0.017584    0.578178    
#> 110: 0.522635    1.071744    3.500261    0.200157    0.021312    0.016756    0.568331    
#> 111: 0.521266    1.070707    3.507959    0.203371    0.020246    0.018079    0.556491    
#> 112: 0.508503    1.053166    3.499733    0.223241    0.019234    0.020205    0.574941    
#> 113: 0.540786    1.063118    3.514882    0.227358    0.018272    0.020182    0.561904    
#> 114: 0.551174    1.069164    3.515308    0.232851    0.017358    0.022185    0.567397    
#> 115: 0.573080    1.035272    3.517114    0.225886    0.016491    0.021136    0.583742    
#> 116: 0.554609    1.057534    3.505751    0.226208    0.015666    0.022057    0.590736    
#> 117: 0.493656    1.082536    3.514216    0.214897    0.014883    0.021156    0.581114    
#> 118: 0.515785    1.073552    3.505852    0.214140    0.015896    0.020098    0.583442    
#> 119: 0.520293    1.067218    3.506518    0.259253    0.016524    0.022796    0.574321    
#> 120: 0.504447    1.076165    3.502411    0.246290    0.019589    0.021656    0.567624    
#> 121: 0.508167    1.086396    3.494103    0.233976    0.021590    0.020573    0.577406    
#> 122: 0.540197    1.060866    3.514063    0.222277    0.020511    0.019544    0.577688    
#> 123: 0.568404    1.090652    3.506997    0.211163    0.022484    0.018567    0.567574    
#> 124: 0.567095    1.094185    3.510883    0.200605    0.025826    0.017950    0.565174    
#> 125: 0.566030    1.094214    3.510673    0.216477    0.024535    0.018213    0.563414    
#> 126: 0.532649    1.098960    3.502461    0.205654    0.023308    0.020229    0.570186    
#> 127: 0.558401    1.085960    3.498559    0.195371    0.022143    0.019707    0.588515    
#> 128: 0.504333    1.085295    3.502418    0.200534    0.021036    0.019141    0.560262    
#> 129: 0.508401    1.090688    3.497337    0.230162    0.020818    0.018535    0.557166    
#> 130: 0.534950    1.094625    3.497740    0.241921    0.021534    0.017996    0.552458    
#> 131: 0.501699    1.080096    3.482589    0.229825    0.023412    0.017400    0.549888    
#> 132: 0.488491    1.082111    3.474738    0.218435    0.022242    0.017206    0.568189    
#> 133: 0.497869    1.078221    3.486516    0.244230    0.021130    0.016346    0.570138    
#> 134: 0.530945    1.046953    3.511715    0.268660    0.021149    0.017538    0.559345    
#> 135: 0.529739    1.036298    3.516051    0.257145    0.020881    0.016910    0.564198    
#> 136: 0.541129    1.039408    3.505225    0.263706    0.027689    0.016064    0.569768    
#> 137: 0.578042    1.050531    3.518344    0.258566    0.026304    0.015261    0.580553    
#> 138: 0.546588    1.059913    3.515723    0.245637    0.024989    0.015471    0.576945    
#> 139: 0.527678    1.071202    3.513874    0.243227    0.025738    0.015115    0.566177    
#> 140: 0.518333    1.075745    3.511153    0.251123    0.027326    0.015965    0.580315    
#> 141: 0.525300    1.062576    3.505047    0.244738    0.026507    0.015166    0.558550    
#> 142: 0.532873    1.050594    3.515629    0.259275    0.025181    0.016905    0.555766    
#> 143: 0.504641    1.060816    3.510464    0.246312    0.023922    0.022357    0.560866    
#> 144: 0.549073    1.056641    3.512640    0.233996    0.022726    0.024013    0.553675    
#> 145: 0.519074    1.067393    3.504437    0.222296    0.021590    0.024605    0.560247    
#> 146: 0.512019    1.069691    3.514868    0.211181    0.020510    0.023398    0.569936    
#> 147: 0.494897    1.078494    3.498735    0.215333    0.019485    0.022254    0.571651    
#> 148: 0.490350    1.081176    3.505934    0.227870    0.018511    0.021141    0.564607    
#> 149: 0.494913    1.074044    3.494704    0.216476    0.017585    0.020084    0.588146    
#> 150: 0.522487    1.054414    3.492615    0.205653    0.017956    0.019080    0.585511    
#> 151: 0.489210    1.082431    3.490562    0.197700    0.018902    0.018126    0.569346    
#> 152: 0.463082    1.086814    3.485626    0.220076    0.020153    0.019916    0.559389    
#> 153: 0.467412    1.104387    3.500047    0.207751    0.025263    0.017778    0.580274    
#> 154: 0.522865    1.099060    3.498567    0.202747    0.019140    0.015656    0.578233    
#> 155: 0.528961    1.072159    3.501011    0.210200    0.014367    0.018543    0.557124    
#> 156: 0.524081    1.067337    3.500608    0.208734    0.016303    0.023272    0.563071    
#> 157: 0.537161    1.072304    3.519068    0.224936    0.013536    0.025419    0.563594    
#> 158: 0.557076    1.074931    3.513297    0.227048    0.016015    0.021856    0.547068    
#> 159: 0.521365    1.071812    3.522787    0.221322    0.020763    0.017209    0.554896    
#> 160: 0.587801    1.053192    3.534106    0.213530    0.017479    0.017351    0.563623    
#> 161: 0.568815    1.065401    3.520370    0.232906    0.017659    0.019709    0.568683    
#> 162: 0.550994    1.068656    3.509100    0.235901    0.016599    0.016381    0.563794    
#> 163: 0.527654    1.068597    3.493304    0.236369    0.022438    0.014583    0.555990    
#> 164: 0.511587    1.075774    3.496289    0.232530    0.021864    0.018303    0.552876    
#> 165: 0.508615    1.088778    3.490329    0.193525    0.021245    0.016895    0.571315    
#> 166: 0.509087    1.118817    3.492437    0.195034    0.018182    0.017408    0.577804    
#> 167: 0.523514    1.110286    3.500752    0.215108    0.017057    0.019777    0.575297    
#> 168: 0.537844    1.097153    3.507448    0.234143    0.016601    0.017044    0.567803    
#> 169: 0.513983    1.102689    3.504178    0.222822    0.015856    0.017605    0.580695    
#> 170: 0.528052    1.075568    3.510982    0.228796    0.019636    0.015821    0.559340    
#> 171: 0.508017    1.078870    3.492848    0.221406    0.016997    0.015702    0.551743    
#> 172: 0.496627    1.082744    3.496921    0.214541    0.012132    0.017112    0.566790    
#> 173: 0.514675    1.094024    3.494213    0.225074    0.011920    0.023199    0.554003    
#> 174: 0.515634    1.085522    3.506156    0.196480    0.009483    0.021379    0.574133    
#> 175: 0.532190    1.082399    3.496934    0.184386    0.011387    0.020294    0.581482    
#> 176: 0.497793    1.082388    3.503251    0.163968    0.010119    0.020249    0.571420    
#> 177: 0.549866    1.086452    3.519465    0.201729    0.011042    0.020329    0.576104    
#> 178: 0.542214    1.074429    3.514788    0.181988    0.010610    0.016053    0.574474    
#> 179: 0.546826    1.078598    3.506203    0.225248    0.011046    0.017635    0.587534    
#> 180: 0.513185    1.070089    3.512290    0.185022    0.012651    0.015430    0.577116    
#> 181: 0.526333    1.061758    3.500358    0.186990    0.014543    0.018387    0.566038    
#> 182: 0.505621    1.064603    3.502358    0.200912    0.014347    0.021334    0.569113    
#> 183: 0.533833    1.072558    3.514902    0.165582    0.015099    0.025941    0.572478    
#> 184: 0.549776    1.059769    3.521904    0.188179    0.014628    0.021519    0.570406    
#> 185: 0.555304    1.074389    3.507559    0.180829    0.015825    0.015860    0.564493    
#> 186: 0.521269    1.087981    3.501873    0.179315    0.016806    0.018021    0.578384    
#> 187: 0.511227    1.066119    3.509902    0.203305    0.017021    0.023695    0.568537    
#> 188: 0.496244    1.079138    3.502146    0.210563    0.016165    0.020514    0.572031    
#> 189: 0.517233    1.086829    3.506737    0.204997    0.015798    0.019269    0.584185    
#> 190: 0.515250    1.078395    3.514692    0.172879    0.013741    0.021670    0.559453    
#> 191: 0.521964    1.080800    3.504207    0.151810    0.013195    0.021714    0.565924    
#> 192: 0.518577    1.079271    3.508235    0.218346    0.012928    0.021226    0.563482    
#> 193: 0.550361    1.077624    3.518858    0.242274    0.011769    0.024974    0.565375    
#> 194: 0.537835    1.065263    3.509566    0.227607    0.009788    0.024764    0.567203    
#> 195: 0.493842    1.070538    3.498441    0.208096    0.011049    0.024889    0.573504    
#> 196: 0.509849    1.071609    3.501639    0.203361    0.014113    0.025198    0.578992    
#> 197: 0.521197    1.081501    3.515056    0.190007    0.011436    0.025693    0.581981    
#> 198: 0.549185    1.071828    3.509598    0.213932    0.006806    0.027400    0.567453    
#> 199: 0.536742    1.069701    3.510216    0.232829    0.006120    0.028040    0.562105    
#> 200: 0.521679    1.075331    3.503930    0.248683    0.006248    0.026280    0.565581    
#> 201: 0.518006    1.069290    3.509187    0.245671    0.005845    0.028483    0.570402    
#> 202: 0.525554    1.067014    3.512690    0.257866    0.005949    0.029974    0.567030    
#> 203: 0.540468    1.065871    3.512271    0.262556    0.006757    0.029984    0.568497    
#> 204: 0.546849    1.060538    3.515352    0.267890    0.007011    0.029790    0.567222    
#> 205: 0.548957    1.059336    3.516602    0.267222    0.007391    0.029991    0.567597    
#> 206: 0.548677    1.060012    3.516514    0.266030    0.007373    0.029966    0.565813    
#> 207: 0.544746    1.059102    3.514959    0.258495    0.007292    0.029515    0.566575    
#> 208: 0.544648    1.058180    3.514967    0.251818    0.007455    0.028465    0.566250    
#> 209: 0.546342    1.057504    3.514058    0.252789    0.007672    0.027934    0.565931    
#> 210: 0.548199    1.057400    3.514121    0.252782    0.007658    0.027770    0.565986    
#> 211: 0.550481    1.057469    3.514613    0.251271    0.007711    0.027268    0.565820    
#> 212: 0.553025    1.056907    3.515787    0.247551    0.007741    0.027051    0.565288    
#> 213: 0.555053    1.055671    3.516379    0.244868    0.007768    0.027028    0.566728    
#> 214: 0.557208    1.055143    3.516998    0.242965    0.007716    0.026957    0.567747    
#> 215: 0.556757    1.054740    3.517897    0.241196    0.007621    0.027219    0.568993    
#> 216: 0.558427    1.053814    3.518366    0.240362    0.007576    0.027628    0.571100    
#> 217: 0.558339    1.053610    3.518682    0.237471    0.007457    0.027875    0.571682    
#> 218: 0.557451    1.053709    3.518565    0.236589    0.007469    0.028008    0.571654    
#> 219: 0.556029    1.054000    3.517170    0.237993    0.007414    0.027878    0.571619    
#> 220: 0.553255    1.054548    3.516470    0.238449    0.007377    0.027913    0.571620    
#> 221: 0.550947    1.054913    3.515768    0.238585    0.007384    0.027799    0.571158    
#> 222: 0.549710    1.054516    3.515161    0.239712    0.007374    0.027653    0.571313    
#> 223: 0.551125    1.054415    3.515466    0.239566    0.007356    0.027602    0.571363    
#> 224: 0.553097    1.054166    3.516017    0.240258    0.007265    0.027505    0.571692    
#> 225: 0.554021    1.053449    3.517112    0.239455    0.007323    0.027314    0.572019    
#> 226: 0.554360    1.052772    3.516870    0.238089    0.007385    0.027175    0.572415    
#> 227: 0.554388    1.052754    3.516962    0.238695    0.007445    0.027118    0.572510    
#> 228: 0.552714    1.053281    3.516341    0.238518    0.007453    0.026980    0.572621    
#> 229: 0.551445    1.053650    3.516043    0.237472    0.007456    0.026843    0.572254    
#> 230: 0.551098    1.053623    3.515951    0.236849    0.007478    0.026704    0.572265    
#> 231: 0.550476    1.053951    3.515970    0.235567    0.007494    0.026508    0.572354    
#> 232: 0.549059    1.054132    3.515860    0.234592    0.007527    0.026333    0.572533    
#> 233: 0.548345    1.053897    3.515673    0.234080    0.007538    0.026293    0.572771    
#> 234: 0.547212    1.053992    3.515296    0.233791    0.007603    0.026288    0.572667    
#> 235: 0.546485    1.053908    3.515248    0.233460    0.007651    0.026267    0.572819    
#> 236: 0.545612    1.054068    3.514791    0.233547    0.007628    0.026219    0.572789    
#> 237: 0.545028    1.054223    3.514355    0.233617    0.007640    0.026149    0.573439    
#> 238: 0.544845    1.054570    3.514162    0.234576    0.007678    0.026080    0.573989    
#> 239: 0.544592    1.055346    3.513767    0.234867    0.007786    0.026054    0.574155    
#> 240: 0.543811    1.055786    3.513636    0.235139    0.007838    0.025978    0.573839    
#> 241: 0.543654    1.055889    3.513547    0.234752    0.007889    0.025895    0.573639    
#> 242: 0.543345    1.056050    3.513302    0.233646    0.007957    0.025846    0.573716    
#> 243: 0.543070    1.056251    3.513434    0.232727    0.008052    0.025846    0.573863    
#> 244: 0.542469    1.055957    3.513580    0.233182    0.008074    0.025764    0.574434    
#> 245: 0.543219    1.055874    3.513664    0.232739    0.008099    0.025706    0.574727    
#> 246: 0.543585    1.055627    3.513937    0.232867    0.008186    0.025660    0.574919    
#> 247: 0.543367    1.055452    3.513988    0.231925    0.008305    0.025627    0.574887    
#> 248: 0.543099    1.055509    3.513914    0.231341    0.008459    0.025576    0.574370    
#> 249: 0.542699    1.055598    3.513887    0.231314    0.008540    0.025523    0.573972    
#> 250: 0.542552    1.055813    3.513974    0.230806    0.008598    0.025479    0.574150    
#> 251: 0.542950    1.055878    3.514263    0.230243    0.008615    0.025439    0.574346    
#> 252: 0.543068    1.056000    3.514560    0.230563    0.008622    0.025467    0.574463    
#> 253: 0.543375    1.056169    3.514549    0.230760    0.008658    0.025489    0.574767    
#> 254: 0.543713    1.056299    3.514586    0.230944    0.008628    0.025532    0.575189    
#> 255: 0.543927    1.056239    3.514716    0.230932    0.008604    0.025468    0.575391    
#> 256: 0.543784    1.056252    3.514687    0.230269    0.008584    0.025407    0.575585    
#> 257: 0.544366    1.055996    3.514817    0.230492    0.008605    0.025411    0.575210    
#> 258: 0.544139    1.055745    3.514776    0.230004    0.008598    0.025368    0.575191    
#> 259: 0.543883    1.055827    3.514689    0.229462    0.008604    0.025292    0.575585    
#> 260: 0.543841    1.055990    3.514737    0.228658    0.008612    0.025274    0.575564    
#> 261: 0.543971    1.056025    3.514853    0.228693    0.008659    0.025252    0.575815    
#> 262: 0.543968    1.056098    3.514830    0.228128    0.008683    0.025198    0.575735    
#> 263: 0.543227    1.056283    3.514724    0.227455    0.008668    0.025161    0.575797    
#> 264: 0.542315    1.056285    3.514555    0.227000    0.008714    0.025162    0.575765    
#> 265: 0.542623    1.056225    3.514537    0.227040    0.008733    0.025245    0.575711    
#> 266: 0.542309    1.056360    3.514390    0.226716    0.008754    0.025261    0.575781    
#> 267: 0.542063    1.056417    3.514421    0.227202    0.008755    0.025303    0.575895    
#> 268: 0.542002    1.056413    3.514362    0.226873    0.008776    0.025337    0.575960    
#> 269: 0.542367    1.056413    3.514314    0.226669    0.008763    0.025402    0.575842    
#> 270: 0.542615    1.056325    3.514427    0.226578    0.008767    0.025374    0.575889    
#> 271: 0.542796    1.056288    3.514384    0.226761    0.008759    0.025364    0.575913    
#> 272: 0.542710    1.056368    3.514325    0.226548    0.008760    0.025386    0.576021    
#> 273: 0.542294    1.056547    3.514303    0.226628    0.008768    0.025418    0.576057    
#> 274: 0.541784    1.056779    3.514300    0.226327    0.008793    0.025406    0.575955    
#> 275: 0.541734    1.056955    3.514129    0.226000    0.008791    0.025332    0.575872    
#> 276: 0.541525    1.057131    3.514142    0.225805    0.008786    0.025327    0.575787    
#> 277: 0.541247    1.057426    3.514233    0.225647    0.008799    0.025325    0.575636    
#> 278: 0.541123    1.057627    3.514312    0.225471    0.008799    0.025334    0.575511    
#> 279: 0.540750    1.057673    3.514309    0.225475    0.008824    0.025259    0.575574    
#> 280: 0.540622    1.057709    3.514318    0.225157    0.008853    0.025213    0.575654    
#> 281: 0.540270    1.057898    3.514332    0.224541    0.008884    0.025193    0.575711    
#> 282: 0.540242    1.058229    3.514342    0.223885    0.008913    0.025181    0.575740    
#> 283: 0.539988    1.058480    3.514315    0.223355    0.008991    0.025161    0.575930    
#> 284: 0.539677    1.058554    3.514259    0.223038    0.009054    0.025129    0.575754    
#> 285: 0.539394    1.058668    3.514022    0.223080    0.009113    0.025124    0.575704    
#> 286: 0.539217    1.058755    3.513849    0.222871    0.009151    0.025080    0.575593    
#> 287: 0.538785    1.058794    3.513738    0.222669    0.009167    0.025030    0.575578    
#> 288: 0.538991    1.058703    3.513760    0.222718    0.009207    0.024980    0.575501    
#> 289: 0.539106    1.058607    3.513724    0.222661    0.009241    0.024931    0.575468    
#> 290: 0.539033    1.058530    3.513788    0.222496    0.009275    0.024927    0.575423    
#> 291: 0.539129    1.058671    3.513890    0.222067    0.009266    0.024961    0.575391    
#> 292: 0.539024    1.058805    3.513865    0.221779    0.009251    0.024927    0.575393    
#> 293: 0.538937    1.058907    3.513885    0.221740    0.009238    0.024879    0.575348    
#> 294: 0.538594    1.059062    3.513769    0.221528    0.009249    0.024833    0.575263    
#> 295: 0.538473    1.058994    3.513720    0.221758    0.009258    0.024778    0.575050    
#> 296: 0.538384    1.058944    3.513703    0.221853    0.009263    0.024750    0.575149    
#> 297: 0.538474    1.059003    3.513685    0.221677    0.009264    0.024724    0.575211    
#> 298: 0.538743    1.058954    3.513671    0.221908    0.009274    0.024683    0.575023    
#> 299: 0.538630    1.059135    3.513575    0.221950    0.009273    0.024666    0.574895    
#> 300: 0.538836    1.059180    3.513594    0.221839    0.009284    0.024662    0.574765    
#> 301: 0.538924    1.059199    3.513497    0.221704    0.009293    0.024615    0.574938    
#> 302: 0.539008    1.059213    3.513343    0.221746    0.009306    0.024603    0.574902    
#> 303: 0.538812    1.059298    3.513245    0.221494    0.009311    0.024565    0.574790    
#> 304: 0.538912    1.059467    3.513189    0.221544    0.009330    0.024535    0.574870    
#> 305: 0.538943    1.059329    3.513203    0.221487    0.009325    0.024511    0.574822    
#> 306: 0.538629    1.059177    3.513127    0.221389    0.009319    0.024514    0.574667    
#> 307: 0.538264    1.059010    3.512971    0.220898    0.009318    0.024519    0.574839    
#> 308: 0.538024    1.058875    3.512913    0.220914    0.009305    0.024510    0.575026    
#> 309: 0.537810    1.058701    3.512859    0.220813    0.009307    0.024497    0.575177    
#> 310: 0.537765    1.058646    3.512804    0.220764    0.009306    0.024472    0.575168    
#> 311: 0.537744    1.058580    3.512791    0.220543    0.009323    0.024458    0.575216    
#> 312: 0.537478    1.058530    3.512688    0.220322    0.009331    0.024466    0.575263    
#> 313: 0.537245    1.058430    3.512617    0.220146    0.009328    0.024475    0.575277    
#> 314: 0.537064    1.058417    3.512507    0.220317    0.009326    0.024485    0.575201    
#> 315: 0.536873    1.058437    3.512462    0.220328    0.009323    0.024467    0.575146    
#> 316: 0.536817    1.058420    3.512411    0.220242    0.009322    0.024434    0.575137    
#> 317: 0.536737    1.058363    3.512452    0.219992    0.009326    0.024426    0.575321    
#> 318: 0.536736    1.058339    3.512410    0.219948    0.009325    0.024386    0.575223    
#> 319: 0.536905    1.058285    3.512457    0.220028    0.009307    0.024391    0.575317    
#> 320: 0.536735    1.058343    3.512436    0.219909    0.009308    0.024383    0.575413    
#> 321: 0.536388    1.058431    3.512279    0.219688    0.009319    0.024357    0.575598    
#> 322: 0.536398    1.058564    3.512206    0.219452    0.009335    0.024329    0.575652    
#> 323: 0.535947    1.058619    3.512049    0.219410    0.009352    0.024288    0.575680    
#> 324: 0.535748    1.058807    3.512000    0.219582    0.009335    0.024268    0.575688    
#> 325: 0.535283    1.058936    3.511892    0.219614    0.009326    0.024263    0.575763    
#> 326: 0.535215    1.058866    3.511849    0.219563    0.009311    0.024283    0.575801    
#> 327: 0.535406    1.058841    3.511850    0.219884    0.009289    0.024309    0.575739    
#> 328: 0.535708    1.058722    3.511906    0.220060    0.009289    0.024319    0.575795    
#> 329: 0.535883    1.058572    3.511985    0.220182    0.009284    0.024327    0.575788    
#> 330: 0.536046    1.058488    3.512107    0.220086    0.009283    0.024358    0.575765    
#> 331: 0.536213    1.058548    3.512151    0.220028    0.009292    0.024332    0.575758    
#> 332: 0.536474    1.058453    3.512245    0.219839    0.009302    0.024318    0.575786    
#> 333: 0.536417    1.058411    3.512226    0.219731    0.009300    0.024310    0.575767    
#> 334: 0.536219    1.058374    3.512118    0.219815    0.009291    0.024290    0.575694    
#> 335: 0.536020    1.058421    3.512003    0.219785    0.009290    0.024284    0.575648    
#> 336: 0.535817    1.058519    3.511982    0.219813    0.009276    0.024276    0.575616    
#> 337: 0.535719    1.058634    3.511882    0.219929    0.009271    0.024275    0.575468    
#> 338: 0.535493    1.058727    3.511838    0.219967    0.009280    0.024262    0.575347    
#> 339: 0.535124    1.058840    3.511728    0.219982    0.009295    0.024240    0.575309    
#> 340: 0.534945    1.058846    3.511665    0.219830    0.009318    0.024218    0.575217    
#> 341: 0.534990    1.058874    3.511673    0.219876    0.009325    0.024192    0.575150    
#> 342: 0.534569    1.058934    3.511593    0.219701    0.009331    0.024187    0.575144    
#> 343: 0.534313    1.059021    3.511516    0.219514    0.009343    0.024186    0.575140    
#> 344: 0.534213    1.059008    3.511470    0.219246    0.009350    0.024183    0.575272    
#> 345: 0.534286    1.059028    3.511528    0.219066    0.009369    0.024155    0.575232    
#> 346: 0.534206    1.059134    3.511492    0.218845    0.009379    0.024131    0.575178    
#> 347: 0.534332    1.059056    3.511519    0.218951    0.009402    0.024105    0.575205    
#> 348: 0.534347    1.059031    3.511535    0.218952    0.009438    0.024102    0.575194    
#> 349: 0.534187    1.059106    3.511436    0.219038    0.009455    0.024106    0.575099    
#> 350: 0.534109    1.059129    3.511372    0.219323    0.009470    0.024121    0.574989    
#> 351: 0.534275    1.059265    3.511310    0.219599    0.009477    0.024102    0.574995    
#> 352: 0.533845    1.059411    3.511231    0.219813    0.009494    0.024061    0.575221    
#> 353: 0.533958    1.059563    3.511193    0.219816    0.009528    0.024035    0.575225    
#> 354: 0.534034    1.059577    3.511177    0.219807    0.009555    0.024010    0.575208    
#> 355: 0.534373    1.059521    3.511175    0.219944    0.009585    0.023985    0.575144    
#> 356: 0.534157    1.059449    3.511108    0.219790    0.009610    0.023972    0.575306    
#> 357: 0.534007    1.059481    3.511057    0.219855    0.009611    0.023952    0.575262    
#> 358: 0.533861    1.059624    3.511037    0.219862    0.009629    0.023922    0.575144    
#> 359: 0.533668    1.059766    3.510929    0.220006    0.009637    0.023906    0.575000    
#> 360: 0.533478    1.059851    3.510786    0.219971    0.009639    0.023893    0.574927    
#> 361: 0.533423    1.059954    3.510701    0.220105    0.009646    0.023866    0.574759    
#> 362: 0.533493    1.060003    3.510633    0.220295    0.009666    0.023838    0.574587    
#> 363: 0.533630    1.059993    3.510642    0.220230    0.009678    0.023816    0.574461    
#> 364: 0.533779    1.059978    3.510681    0.220112    0.009690    0.023818    0.574425    
#> 365: 0.533798    1.059942    3.510683    0.220040    0.009718    0.023803    0.574425    
#> 366: 0.533819    1.059982    3.510625    0.219939    0.009732    0.023807    0.574466    
#> 367: 0.533827    1.060042    3.510595    0.219738    0.009731    0.023792    0.574488    
#> 368: 0.533667    1.060056    3.510529    0.219631    0.009734    0.023781    0.574420    
#> 369: 0.533518    1.060049    3.510460    0.219552    0.009738    0.023760    0.574429    
#> 370: 0.533513    1.060098    3.510452    0.219568    0.009743    0.023712    0.574445    
#> 371: 0.533399    1.060129    3.510328    0.219515    0.009749    0.023669    0.574477    
#> 372: 0.533473    1.060116    3.510331    0.219516    0.009754    0.023673    0.574514    
#> 373: 0.533423    1.060154    3.510351    0.219525    0.009759    0.023688    0.574519    
#> 374: 0.533520    1.060115    3.510343    0.219500    0.009759    0.023679    0.574505    
#> 375: 0.533659    1.060127    3.510363    0.219442    0.009762    0.023651    0.574595    
#> 376: 0.533851    1.060158    3.510443    0.219404    0.009747    0.023640    0.574605    
#> 377: 0.533847    1.060194    3.510491    0.219327    0.009733    0.023636    0.574649    
#> 378: 0.533820    1.060148    3.510461    0.219286    0.009727    0.023635    0.574675    
#> 379: 0.533720    1.060086    3.510421    0.219223    0.009723    0.023635    0.574662    
#> 380: 0.533570    1.060074    3.510394    0.219135    0.009719    0.023629    0.574642    
#> 381: 0.533333    1.060022    3.510341    0.219001    0.009728    0.023602    0.574657    
#> 382: 0.533226    1.059990    3.510294    0.218923    0.009732    0.023578    0.574608    
#> 383: 0.533175    1.059977    3.510257    0.218817    0.009736    0.023565    0.574530    
#> 384: 0.533015    1.059978    3.510241    0.218799    0.009720    0.023560    0.574557    
#> 385: 0.533057    1.059981    3.510317    0.218845    0.009728    0.023552    0.574555    
#> 386: 0.533253    1.060020    3.510397    0.218801    0.009742    0.023544    0.574570    
#> 387: 0.533604    1.060021    3.510531    0.218627    0.009746    0.023521    0.574568    
#> 388: 0.533767    1.060028    3.510579    0.218319    0.009752    0.023518    0.574646    
#> 389: 0.533961    1.059913    3.510611    0.218229    0.009762    0.023519    0.574738    
#> 390: 0.533824    1.059885    3.510568    0.218168    0.009769    0.023485    0.574831    
#> 391: 0.533888    1.059881    3.510541    0.218222    0.009760    0.023478    0.574894    
#> 392: 0.533807    1.059870    3.510558    0.218322    0.009761    0.023483    0.574958    
#> 393: 0.533644    1.059812    3.510523    0.218326    0.009768    0.023487    0.574974    
#> 394: 0.533581    1.059788    3.510509    0.218431    0.009767    0.023493    0.574962    
#> 395: 0.533802    1.059828    3.510521    0.218500    0.009775    0.023469    0.574945    
#> 396: 0.533931    1.059892    3.510546    0.218544    0.009788    0.023444    0.574896    
#> 397: 0.534041    1.059899    3.510591    0.218515    0.009802    0.023426    0.574946    
#> 398: 0.534240    1.059909    3.510626    0.218644    0.009805    0.023421    0.574981    
#> 399: 0.534224    1.059995    3.510624    0.218519    0.009826    0.023430    0.574977    
#> 400: 0.534188    1.060094    3.510635    0.218308    0.009843    0.023415    0.574982    
#> 401: 0.534190    1.060171    3.510654    0.218230    0.009849    0.023400    0.575081    
#> 402: 0.534246    1.060188    3.510675    0.218095    0.009864    0.023379    0.575058    
#> 403: 0.534481    1.060201    3.510686    0.218101    0.009876    0.023369    0.575042    
#> 404: 0.534579    1.060240    3.510664    0.218098    0.009903    0.023352    0.575053    
#> 405: 0.534675    1.060288    3.510681    0.218273    0.009909    0.023341    0.575048    
#> 406: 0.534677    1.060314    3.510615    0.218448    0.009921    0.023318    0.575078    
#> 407: 0.534710    1.060382    3.510618    0.218638    0.009937    0.023309    0.575047    
#> 408: 0.534764    1.060473    3.510604    0.218569    0.009929    0.023289    0.575122    
#> 409: 0.534744    1.060444    3.510558    0.218495    0.009928    0.023271    0.575163    
#> 410: 0.534742    1.060440    3.510524    0.218552    0.009930    0.023256    0.575115    
#> 411: 0.534768    1.060318    3.510520    0.218729    0.009940    0.023258    0.575153    
#> 412: 0.534795    1.060247    3.510549    0.218768    0.009948    0.023236    0.575150    
#> 413: 0.534720    1.060264    3.510547    0.218738    0.009962    0.023219    0.575199    
#> 414: 0.534682    1.060267    3.510568    0.218776    0.009970    0.023210    0.575163    
#> 415: 0.534807    1.060201    3.510571    0.218799    0.009973    0.023195    0.575102    
#> 416: 0.534917    1.060163    3.510610    0.218652    0.009986    0.023177    0.575081    
#> 417: 0.535114    1.060070    3.510680    0.218470    0.009998    0.023171    0.575036    
#> 418: 0.535105    1.060012    3.510754    0.218364    0.010007    0.023170    0.574978    
#> 419: 0.535229    1.060078    3.510761    0.218334    0.010014    0.023174    0.574919    
#> 420: 0.535354    1.060116    3.510792    0.218271    0.010012    0.023179    0.574852    
#> 421: 0.535365    1.060160    3.510826    0.218248    0.010016    0.023199    0.574802    
#> 422: 0.535505    1.060122    3.510840    0.218300    0.010018    0.023207    0.574774    
#> 423: 0.535611    1.060099    3.510862    0.218307    0.010018    0.023189    0.574695    
#> 424: 0.535595    1.060081    3.510857    0.218331    0.010014    0.023207    0.574612    
#> 425: 0.535789    1.060103    3.510844    0.218454    0.010023    0.023229    0.574637    
#> 426: 0.535851    1.060158    3.510800    0.218645    0.010022    0.023216    0.574611    
#> 427: 0.535738    1.060139    3.510823    0.218585    0.010008    0.023196    0.574592    
#> 428: 0.535664    1.060129    3.510874    0.218606    0.010000    0.023164    0.574654    
#> 429: 0.535675    1.060137    3.510896    0.218530    0.009996    0.023145    0.574709    
#> 430: 0.535775    1.060117    3.510908    0.218545    0.009993    0.023122    0.574799    
#> 431: 0.535805    1.060100    3.510890    0.218376    0.009981    0.023095    0.574836    
#> 432: 0.535646    1.060126    3.510884    0.218231    0.009976    0.023100    0.574883    
#> 433: 0.535591    1.060157    3.510907    0.218159    0.009977    0.023099    0.574889    
#> 434: 0.535535    1.060172    3.510882    0.218118    0.009972    0.023084    0.574910    
#> 435: 0.535494    1.060164    3.510865    0.218065    0.009969    0.023081    0.574932    
#> 436: 0.535469    1.060136    3.510891    0.217933    0.009971    0.023081    0.574922    
#> 437: 0.535468    1.060135    3.510918    0.217878    0.009965    0.023079    0.574872    
#> 438: 0.535448    1.060195    3.510899    0.217892    0.009961    0.023073    0.574810    
#> 439: 0.535480    1.060220    3.510914    0.217980    0.009951    0.023080    0.574786    
#> 440: 0.535330    1.060270    3.510899    0.217929    0.009955    0.023064    0.574808    
#> 441: 0.535189    1.060265    3.510866    0.217857    0.009944    0.023072    0.574820    
#> 442: 0.535053    1.060264    3.510841    0.217816    0.009929    0.023074    0.574813    
#> 443: 0.535108    1.060285    3.510830    0.217927    0.009916    0.023086    0.574838    
#> 444: 0.535041    1.060285    3.510780    0.218084    0.009905    0.023114    0.574817    
#> 445: 0.534936    1.060305    3.510734    0.218160    0.009911    0.023129    0.574802    
#> 446: 0.534769    1.060394    3.510649    0.218206    0.009918    0.023124    0.574771    
#> 447: 0.534787    1.060462    3.510608    0.218208    0.009928    0.023116    0.574740    
#> 448: 0.534731    1.060559    3.510597    0.218144    0.009931    0.023120    0.574702    
#> 449: 0.534753    1.060643    3.510658    0.218156    0.009936    0.023108    0.574677    
#> 450: 0.534583    1.060697    3.510631    0.218135    0.009957    0.023096    0.574650    
#> 451: 0.534663    1.060796    3.510606    0.218172    0.009978    0.023105    0.574645    
#> 452: 0.534760    1.060861    3.510633    0.218166    0.009994    0.023111    0.574615    
#> 453: 0.534645    1.060947    3.510587    0.218129    0.010002    0.023122    0.574593    
#> 454: 0.534564    1.061061    3.510530    0.218112    0.010003    0.023121    0.574649    
#> 455: 0.534395    1.061155    3.510444    0.218175    0.010002    0.023118    0.574627    
#> 456: 0.534144    1.061168    3.510364    0.218228    0.009995    0.023103    0.574647    
#> 457: 0.534080    1.061182    3.510392    0.218185    0.009990    0.023099    0.574613    
#> 458: 0.534071    1.061280    3.510413    0.218177    0.009999    0.023107    0.574657    
#> 459: 0.533890    1.061363    3.510385    0.218257    0.010010    0.023106    0.574646    
#> 460: 0.533754    1.061431    3.510308    0.218355    0.010020    0.023104    0.574593    
#> 461: 0.533637    1.061496    3.510290    0.218509    0.010029    0.023089    0.574591    
#> 462: 0.533589    1.061555    3.510286    0.218706    0.010030    0.023090    0.574555    
#> 463: 0.533591    1.061599    3.510280    0.218761    0.010037    0.023088    0.574543    
#> 464: 0.533590    1.061681    3.510238    0.218764    0.010036    0.023077    0.574493    
#> 465: 0.533432    1.061664    3.510193    0.218706    0.010032    0.023065    0.574488    
#> 466: 0.533370    1.061709    3.510119    0.218632    0.010033    0.023051    0.574489    
#> 467: 0.533306    1.061727    3.510137    0.218556    0.010033    0.023047    0.574449    
#> 468: 0.533458    1.061733    3.510210    0.218453    0.010028    0.023042    0.574466    
#> 469: 0.533408    1.061778    3.510246    0.218337    0.010027    0.023019    0.574531    
#> 470: 0.533344    1.061825    3.510216    0.218322    0.010021    0.023015    0.574582    
#> 471: 0.533298    1.061851    3.510234    0.218193    0.010011    0.023007    0.574590    
#> 472: 0.533322    1.061836    3.510245    0.218071    0.010005    0.022993    0.574587    
#> 473: 0.533258    1.061833    3.510247    0.218082    0.009998    0.022983    0.574565    
#> 474: 0.533289    1.061780    3.510253    0.218207    0.009998    0.022985    0.574598    
#> 475: 0.533285    1.061794    3.510245    0.218276    0.009990    0.022977    0.574633    
#> 476: 0.533354    1.061759    3.510231    0.218312    0.009979    0.022965    0.574733    
#> 477: 0.533217    1.061774    3.510219    0.218309    0.009976    0.022969    0.574731    
#> 478: 0.533218    1.061772    3.510237    0.218314    0.009978    0.022952    0.574745    
#> 479: 0.533285    1.061766    3.510250    0.218341    0.009974    0.022956    0.574746    
#> 480: 0.533241    1.061725    3.510242    0.218373    0.009975    0.022954    0.574785    
#> 481: 0.533198    1.061697    3.510225    0.218355    0.009989    0.022951    0.574761    
#> 482: 0.533260    1.061695    3.510207    0.218467    0.009996    0.022939    0.574755    
#> 483: 0.533188    1.061698    3.510199    0.218489    0.009996    0.022942    0.574716    
#> 484: 0.533149    1.061686    3.510172    0.218569    0.010001    0.022935    0.574687    
#> 485: 0.533191    1.061749    3.510156    0.218714    0.010012    0.022925    0.574652    
#> 486: 0.533193    1.061826    3.510167    0.218654    0.010026    0.022910    0.574607    
#> 487: 0.533363    1.061888    3.510225    0.218740    0.010037    0.022897    0.574595    
#> 488: 0.533404    1.061865    3.510262    0.218619    0.010038    0.022888    0.574583    
#> 489: 0.533572    1.061843    3.510252    0.218711    0.010042    0.022878    0.574603    
#> 490: 0.533667    1.061893    3.510286    0.218690    0.010047    0.022871    0.574609    
#> 491: 0.533679    1.061933    3.510295    0.218747    0.010050    0.022867    0.574593    
#> 492: 0.533685    1.061968    3.510282    0.218844    0.010060    0.022883    0.574605    
#> 493: 0.533613    1.061995    3.510292    0.218736    0.010080    0.022879    0.574642    
#> 494: 0.533633    1.062065    3.510275    0.218587    0.010096    0.022874    0.574670    
#> 495: 0.533727    1.062098    3.510286    0.218515    0.010108    0.022868    0.574634    
#> 496: 0.533841    1.062144    3.510277    0.218543    0.010104    0.022854    0.574642    
#> 497: 0.533704    1.062132    3.510262    0.218585    0.010116    0.022859    0.574658    
#> 498: 0.533773    1.062137    3.510246    0.218562    0.010128    0.022853    0.574639    
#> 499: 0.533841    1.062164    3.510252    0.218469    0.010141    0.022847    0.574686    
#> 500: 0.533895    1.062140    3.510267    0.218326    0.010154    0.022835    0.574686    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.300305    0.978225    3.435901    0.392401    0.087071    0.016800    1.858234    
#> 002: 0.472242    1.055168    3.439311    0.372781    0.082717    0.015960    1.326111    
#> 003: 0.627580    0.997682    3.442958    0.354142    0.078582    0.015162    1.034081    
#> 004: 0.602719    1.028504    3.440828    0.336435    0.074653    0.014404    0.962979    
#> 005: 0.670109    1.028856    3.434927    0.319613    0.070920    0.013684    0.938705    
#> 006: 0.650876    1.042733    3.421627    0.303633    0.067374    0.013000    0.921032    
#> 007: 0.561025    1.052039    3.415103    0.301596    0.064005    0.012350    0.948352    
#> 008: 0.560405    1.017195    3.405488    0.286516    0.060805    0.011732    0.931569    
#> 009: 0.569565    1.012036    3.423056    0.272190    0.057765    0.011146    0.921565    
#> 010: 0.641540    0.994231    3.426676    0.295318    0.054876    0.010588    0.920347    
#> 011: 0.702261    1.023490    3.440280    0.302059    0.055857    0.010059    0.925972    
#> 012: 0.663205    1.023906    3.428326    0.286956    0.053064    0.013237    0.938391    
#> 013: 0.601730    1.015123    3.425116    0.272608    0.050411    0.012575    0.926372    
#> 014: 0.636278    1.016437    3.426266    0.277125    0.047890    0.011946    0.949448    
#> 015: 0.659586    1.024914    3.448138    0.263269    0.045496    0.011349    0.922256    
#> 016: 0.658094    1.022066    3.462550    0.250105    0.051369    0.010781    0.905718    
#> 017: 0.661470    1.023545    3.443664    0.253976    0.054450    0.010242    0.900219    
#> 018: 0.682723    1.031800    3.432434    0.250480    0.051728    0.009730    0.919706    
#> 019: 0.607165    1.003837    3.437907    0.239011    0.049141    0.010327    0.899519    
#> 020: 0.624166    1.020426    3.441851    0.250561    0.046684    0.011095    0.905145    
#> 021: 0.655407    1.023477    3.439155    0.271379    0.044350    0.013081    0.884774    
#> 022: 0.649763    1.037649    3.447422    0.351950    0.047992    0.012427    0.872531    
#> 023: 0.753920    1.031225    3.446408    0.334352    0.045593    0.011806    0.917356    
#> 024: 0.703849    1.051807    3.456357    0.317635    0.043530    0.013619    0.916746    
#> 025: 0.686891    1.021125    3.444586    0.350354    0.049106    0.012938    0.931274    
#> 026: 0.651696    1.064589    3.434957    0.332837    0.056614    0.012291    0.913207    
#> 027: 0.643608    1.042811    3.426223    0.316195    0.053783    0.011676    0.922263    
#> 028: 0.713494    1.031822    3.444235    0.300385    0.052866    0.011092    0.892557    
#> 029: 0.710249    1.040870    3.436284    0.312938    0.050222    0.010832    0.916626    
#> 030: 0.705743    1.031341    3.436146    0.366607    0.047711    0.014216    0.900034    
#> 031: 0.646615    1.024489    3.444131    0.348277    0.045326    0.013505    0.917722    
#> 032: 0.642907    1.022903    3.446580    0.330863    0.043059    0.014249    0.902435    
#> 033: 0.640425    1.042394    3.440192    0.373051    0.040906    0.014022    0.898034    
#> 034: 0.706733    1.057988    3.428424    0.429994    0.038861    0.015462    0.874419    
#> 035: 0.663626    1.029889    3.427164    0.410590    0.040073    0.014689    0.868199    
#> 036: 0.640211    1.064735    3.426500    0.390060    0.041767    0.014465    0.891735    
#> 037: 0.668907    1.048028    3.431305    0.370557    0.041757    0.014990    0.892203    
#> 038: 0.741796    1.035456    3.431657    0.471815    0.043326    0.014241    0.896154    
#> 039: 0.666198    1.022312    3.439932    0.448224    0.041160    0.014873    0.896065    
#> 040: 0.655237    1.013243    3.456076    0.425813    0.040338    0.016702    0.897803    
#> 041: 0.677286    0.995972    3.456098    0.404522    0.039206    0.016658    0.896802    
#> 042: 0.749019    0.989673    3.461406    0.398366    0.043439    0.015825    0.885808    
#> 043: 0.671695    1.021198    3.440566    0.400825    0.041267    0.015034    0.885352    
#> 044: 0.659872    1.032351    3.442277    0.380783    0.039203    0.014282    0.919546    
#> 045: 0.662060    1.045641    3.433884    0.361744    0.040799    0.013568    0.906980    
#> 046: 0.655782    1.025235    3.439782    0.343657    0.038759    0.013614    0.904921    
#> 047: 0.666484    1.030950    3.431586    0.326474    0.049097    0.013720    0.902368    
#> 048: 0.700405    1.030778    3.438862    0.310150    0.054882    0.013034    0.896326    
#> 049: 0.666383    1.022307    3.444914    0.294643    0.052138    0.012382    0.915868    
#> 050: 0.732709    1.009337    3.443396    0.316628    0.051097    0.011763    0.916363    
#> 051: 0.674360    1.023409    3.432595    0.333800    0.053751    0.011311    0.916962    
#> 052: 0.682674    1.024370    3.442654    0.364116    0.051064    0.010746    0.899632    
#> 053: 0.670452    1.020573    3.438233    0.345910    0.055804    0.010208    0.894499    
#> 054: 0.619216    1.017974    3.442751    0.328615    0.055674    0.012155    0.906506    
#> 055: 0.625041    1.008490    3.430427    0.321312    0.053954    0.014761    0.901049    
#> 056: 0.647536    1.014811    3.432596    0.315653    0.051257    0.015238    0.905593    
#> 057: 0.647372    1.021024    3.429006    0.351445    0.051595    0.014476    0.900057    
#> 058: 0.651230    1.044563    3.423045    0.362593    0.049016    0.013752    0.908823    
#> 059: 0.634721    0.998305    3.430301    0.377994    0.059295    0.013969    0.911400    
#> 060: 0.658090    0.994029    3.442268    0.359094    0.067049    0.013271    0.942963    
#> 061: 0.710999    1.015742    3.448328    0.372846    0.063697    0.012607    0.926491    
#> 062: 0.670857    1.048871    3.447557    0.354204    0.060512    0.011977    0.945495    
#> 063: 0.702137    1.016066    3.454743    0.336494    0.057486    0.011378    0.947439    
#> 064: 0.676990    1.030208    3.449063    0.319669    0.055471    0.012437    0.909827    
#> 065: 0.687890    1.006159    3.443379    0.303686    0.064872    0.013432    0.909938    
#> 066: 0.696387    1.021927    3.453645    0.288501    0.061629    0.012760    0.923980    
#> 067: 0.698991    1.015288    3.440492    0.294436    0.058547    0.013332    0.910175    
#> 068: 0.621980    1.032671    3.445348    0.279714    0.055620    0.012665    0.910262    
#> 069: 0.631855    1.051212    3.422622    0.392093    0.053978    0.014911    0.911775    
#> 070: 0.693574    1.029999    3.439723    0.410103    0.069517    0.015306    0.878938    
#> 071: 0.648746    1.064623    3.412999    0.389598    0.070938    0.014540    0.891401    
#> 072: 0.572950    1.021756    3.410961    0.393888    0.067391    0.013813    0.899899    
#> 073: 0.657921    1.043044    3.434694    0.374891    0.064022    0.013123    0.902327    
#> 074: 0.647366    1.060892    3.437749    0.359054    0.063572    0.012466    0.903134    
#> 075: 0.678676    1.032205    3.449344    0.341102    0.060394    0.011843    0.897537    
#> 076: 0.715466    1.061494    3.459844    0.324047    0.057374    0.011251    0.912148    
#> 077: 0.736976    1.044505    3.447413    0.307844    0.054505    0.013974    0.890795    
#> 078: 0.698401    1.023016    3.456510    0.292452    0.051780    0.014142    0.886074    
#> 079: 0.693374    1.030120    3.455013    0.336458    0.061849    0.013435    0.912189    
#> 080: 0.695681    1.011369    3.445185    0.440139    0.058756    0.012763    0.897166    
#> 081: 0.681718    1.039369    3.436739    0.418132    0.055818    0.012125    0.890242    
#> 082: 0.689541    1.014933    3.440032    0.397225    0.053027    0.011519    0.906830    
#> 083: 0.643946    1.026863    3.443050    0.377364    0.050376    0.010943    0.926466    
#> 084: 0.697420    1.023468    3.444048    0.364059    0.047857    0.010396    0.911009    
#> 085: 0.709798    1.034020    3.452709    0.395351    0.053711    0.009876    0.944525    
#> 086: 0.701280    0.995414    3.456185    0.375583    0.051025    0.009382    0.942303    
#> 087: 0.656673    0.990396    3.448721    0.356804    0.048474    0.008913    0.936505    
#> 088: 0.643886    0.994138    3.451480    0.338964    0.046050    0.009965    0.939836    
#> 089: 0.693304    1.020217    3.444470    0.322016    0.048561    0.009467    0.944549    
#> 090: 0.608829    1.023729    3.439397    0.305915    0.046133    0.008994    0.930787    
#> 091: 0.623309    1.020633    3.418391    0.329260    0.048970    0.008544    0.905357    
#> 092: 0.635939    1.061533    3.411811    0.349064    0.047741    0.009109    0.889052    
#> 093: 0.612875    1.056080    3.406250    0.331611    0.045354    0.011860    0.903244    
#> 094: 0.571011    1.075376    3.397979    0.315030    0.043086    0.011503    0.910778    
#> 095: 0.576607    1.061183    3.421731    0.301646    0.044423    0.012941    0.918585    
#> 096: 0.583635    1.073083    3.403527    0.392908    0.047302    0.012294    0.921548    
#> 097: 0.630537    1.078396    3.397932    0.373263    0.044937    0.011679    0.923678    
#> 098: 0.663400    1.075104    3.421575    0.371094    0.042690    0.011095    0.922565    
#> 099: 0.589494    1.058661    3.394914    0.419071    0.048605    0.010540    0.916348    
#> 100: 0.558673    1.074957    3.389812    0.398118    0.051356    0.010013    0.907310    
#> 101: 0.555804    1.056252    3.388981    0.378212    0.052961    0.009513    0.905118    
#> 102: 0.574687    1.042066    3.393223    0.359301    0.050313    0.009037    0.908896    
#> 103: 0.656498    1.033609    3.420181    0.341336    0.055204    0.008585    0.922924    
#> 104: 0.656904    1.048654    3.426422    0.371297    0.059472    0.008156    0.920493    
#> 105: 0.669259    1.049240    3.422973    0.408619    0.070283    0.007748    0.911469    
#> 106: 0.683839    1.043055    3.421054    0.450991    0.066769    0.007361    0.908287    
#> 107: 0.699163    1.070250    3.422150    0.428441    0.063430    0.006993    0.930661    
#> 108: 0.646956    1.042405    3.423145    0.407019    0.062884    0.006643    0.917459    
#> 109: 0.652211    1.038672    3.432697    0.386668    0.059739    0.006416    0.890465    
#> 110: 0.650754    1.042546    3.414965    0.367760    0.063324    0.006095    0.899081    
#> 111: 0.609387    1.051402    3.418699    0.349372    0.060158    0.005790    0.894541    
#> 112: 0.611168    1.041228    3.411581    0.331903    0.073750    0.005500    0.909668    
#> 113: 0.633498    1.047478    3.421151    0.315308    0.072164    0.005225    0.895259    
#> 114: 0.618956    1.064398    3.423114    0.299542    0.078763    0.004964    0.904349    
#> 115: 0.643657    1.032619    3.419998    0.284565    0.074825    0.005373    0.911198    
#> 116: 0.639671    1.063046    3.423551    0.313871    0.071084    0.007102    0.907079    
#> 117: 0.614103    1.076514    3.422346    0.298177    0.068892    0.006747    0.912839    
#> 118: 0.682856    1.048218    3.425438    0.333986    0.065448    0.006410    0.909473    
#> 119: 0.692551    1.061085    3.426295    0.421606    0.075391    0.006089    0.897429    
#> 120: 0.627350    1.034023    3.414844    0.400526    0.073573    0.005785    0.902846    
#> 121: 0.656387    1.064045    3.416365    0.380499    0.069894    0.005496    0.901993    
#> 122: 0.660104    1.040381    3.423195    0.361474    0.066399    0.005221    0.914771    
#> 123: 0.690702    1.061502    3.428149    0.343401    0.067609    0.004960    0.927677    
#> 124: 0.674299    1.068979    3.431525    0.326231    0.064228    0.004712    0.924207    
#> 125: 0.674293    1.055737    3.433045    0.339361    0.066597    0.004824    0.931688    
#> 126: 0.638844    1.052703    3.423402    0.322393    0.063700    0.004583    0.938895    
#> 127: 0.649732    1.036733    3.420522    0.306274    0.067411    0.005025    0.923858    
#> 128: 0.615066    1.035983    3.424787    0.339724    0.078400    0.004774    0.921632    
#> 129: 0.690187    1.047493    3.429884    0.344721    0.089627    0.004535    0.928622    
#> 130: 0.647318    1.059529    3.434767    0.327485    0.085145    0.004308    0.911524    
#> 131: 0.655188    1.014878    3.427619    0.311111    0.088593    0.004589    0.929336    
#> 132: 0.591661    1.034095    3.413560    0.295555    0.084163    0.005158    0.930716    
#> 133: 0.594080    1.036666    3.411194    0.281552    0.079955    0.004900    0.929646    
#> 134: 0.638826    1.002348    3.424527    0.267475    0.075958    0.006471    0.939581    
#> 135: 0.619058    1.024957    3.426222    0.254101    0.083756    0.006148    0.937253    
#> 136: 0.593619    1.009021    3.418270    0.298015    0.082712    0.005840    0.905910    
#> 137: 0.653448    1.040657    3.422024    0.364579    0.078576    0.005548    0.902728    
#> 138: 0.635478    1.040838    3.423059    0.373323    0.074647    0.005271    0.899055    
#> 139: 0.644029    1.058042    3.428198    0.376316    0.079189    0.005007    0.883240    
#> 140: 0.673077    1.065824    3.437601    0.424948    0.075230    0.005762    0.899369    
#> 141: 0.690791    1.040327    3.441726    0.403700    0.080024    0.005474    0.889652    
#> 142: 0.695329    1.017762    3.442747    0.383515    0.076023    0.005201    0.898714    
#> 143: 0.646648    1.041363    3.447988    0.364340    0.072222    0.005954    0.925429    
#> 144: 0.691944    1.038905    3.453768    0.346123    0.068611    0.005657    0.908526    
#> 145: 0.680248    1.043468    3.434332    0.328817    0.069009    0.005374    0.915311    
#> 146: 0.649466    1.034522    3.436116    0.325988    0.070028    0.005105    0.918726    
#> 147: 0.613427    1.036374    3.431352    0.309689    0.066527    0.006633    0.894328    
#> 148: 0.635219    1.025319    3.443370    0.317609    0.063201    0.007835    0.896209    
#> 149: 0.617103    1.018330    3.441846    0.301728    0.060041    0.007443    0.934193    
#> 150: 0.666092    1.006643    3.445422    0.318191    0.058666    0.007071    0.920349    
#> 151: 0.595607    1.044532    3.424163    0.302281    0.061833    0.006718    0.927457    
#> 152: 0.577122    1.055229    3.418721    0.261469    0.070114    0.003898    0.931713    
#> 153: 0.576980    1.079791    3.419677    0.313056    0.076921    0.003723    0.944150    
#> 154: 0.650508    1.075291    3.423676    0.276680    0.087986    0.005249    0.932128    
#> 155: 0.621530    1.055103    3.419353    0.325961    0.083769    0.003604    0.925899    
#> 156: 0.642730    1.060867    3.431323    0.281967    0.095662    0.003746    0.926001    
#> 157: 0.625366    1.052640    3.438183    0.256256    0.111981    0.002836    0.935206    
#> 158: 0.668204    1.032662    3.438215    0.246735    0.081979    0.002305    0.933856    
#> 159: 0.652294    1.038644    3.443145    0.296365    0.047125    0.001687    0.948041    
#> 160: 0.658131    1.033192    3.443194    0.317128    0.056841    0.001984    0.927890    
#> 161: 0.658002    1.025660    3.441537    0.342572    0.074029    0.002259    0.924546    
#> 162: 0.643209    1.057173    3.423574    0.318619    0.071579    0.002046    0.919816    
#> 163: 0.653337    1.048307    3.424865    0.394979    0.070222    0.002596    0.913294    
#> 164: 0.676512    1.046828    3.423837    0.307006    0.080940    0.002579    0.920907    
#> 165: 0.647592    1.023634    3.436760    0.253510    0.071781    0.002423    0.932631    
#> 166: 0.677638    1.064432    3.435762    0.295290    0.073435    0.002189    0.933215    
#> 167: 0.694770    1.057494    3.437525    0.343072    0.061637    0.001544    0.937675    
#> 168: 0.680442    1.067544    3.440944    0.347735    0.068058    0.001759    0.943310    
#> 169: 0.669894    1.076635    3.431606    0.382404    0.067253    0.001463    0.961291    
#> 170: 0.680614    1.047281    3.423442    0.314000    0.069591    0.001784    0.930609    
#> 171: 0.616229    1.055581    3.420043    0.307409    0.064207    0.001946    0.920264    
#> 172: 0.630586    1.081104    3.419526    0.285864    0.070085    0.001507    0.902779    
#> 173: 0.580724    1.071614    3.406886    0.261828    0.065069    0.001983    0.933908    
#> 174: 0.608600    1.061603    3.405903    0.274968    0.058664    0.001943    0.919957    
#> 175: 0.578540    1.071714    3.399216    0.272878    0.072880    0.001893    0.934867    
#> 176: 0.613064    1.082172    3.400928    0.259293    0.063757    0.001194    0.937104    
#> 177: 0.615040    1.074283    3.405071    0.296218    0.062320    0.001335    0.912388    
#> 178: 0.602269    1.059636    3.408970    0.243110    0.066904    0.001275    0.926615    
#> 179: 0.628559    1.075270    3.409834    0.284967    0.073805    0.001515    0.916811    
#> 180: 0.587447    1.056254    3.412313    0.309201    0.065818    0.001690    0.924122    
#> 181: 0.606574    1.026944    3.406109    0.295650    0.077191    0.001437    0.912043    
#> 182: 0.571114    1.037270    3.405292    0.255317    0.092770    0.001764    0.921567    
#> 183: 0.555748    1.065352    3.401382    0.234777    0.054941    0.002007    0.933810    
#> 184: 0.602184    1.035302    3.402636    0.252577    0.058534    0.001974    0.940665    
#> 185: 0.557492    1.086958    3.399155    0.238878    0.057708    0.002134    0.926121    
#> 186: 0.566029    1.097017    3.408169    0.229055    0.069704    0.002729    0.927473    
#> 187: 0.590601    1.048895    3.413730    0.343060    0.062195    0.002237    0.940138    
#> 188: 0.598504    1.085022    3.401703    0.347775    0.061805    0.002664    0.939837    
#> 189: 0.641640    1.080946    3.400293    0.397030    0.067027    0.002662    0.930977    
#> 190: 0.640526    1.071548    3.404276    0.434340    0.057143    0.002341    0.916522    
#> 191: 0.580304    1.080224    3.400625    0.373178    0.063024    0.001962    0.925667    
#> 192: 0.586364    1.093179    3.399429    0.358879    0.051956    0.002061    0.941974    
#> 193: 0.669359    1.085191    3.400923    0.400215    0.045593    0.001246    0.912438    
#> 194: 0.596101    1.055951    3.396189    0.383146    0.065346    0.001596    0.922471    
#> 195: 0.566087    1.061602    3.388750    0.355910    0.080613    0.001610    0.951780    
#> 196: 0.553379    1.062353    3.395247    0.297947    0.099241    0.001377    0.933773    
#> 197: 0.513175    1.080063    3.402032    0.238236    0.076662    0.001267    0.951320    
#> 198: 0.606337    1.057998    3.393768    0.273027    0.079265    0.001608    0.928529    
#> 199: 0.598256    1.039998    3.398902    0.281460    0.064535    0.001269    0.932540    
#> 200: 0.598930    1.063121    3.400558    0.295254    0.076730    0.001160    0.949320    
#> 201: 0.593761    1.047967    3.403557    0.274150    0.076431    0.001072    0.942522    
#> 202: 0.585880    1.049154    3.403433    0.262107    0.074111    0.001060    0.947237    
#> 203: 0.592702    1.051913    3.403266    0.260840    0.074140    0.001035    0.947548    
#> 204: 0.595896    1.046053    3.403258    0.263236    0.075922    0.000981    0.948995    
#> 205: 0.593072    1.051154    3.402765    0.265263    0.079290    0.000976    0.951283    
#> 206: 0.595972    1.058067    3.402706    0.272877    0.079637    0.000983    0.951508    
#> 207: 0.595624    1.057429    3.402560    0.282517    0.078097    0.000993    0.947910    
#> 208: 0.596606    1.055745    3.403061    0.280381    0.076692    0.000984    0.946005    
#> 209: 0.598591    1.055221    3.403468    0.280931    0.075820    0.000971    0.943750    
#> 210: 0.602599    1.056178    3.403736    0.283185    0.075154    0.000951    0.940897    
#> 211: 0.604394    1.057176    3.404355    0.284970    0.075533    0.000933    0.939648    
#> 212: 0.606778    1.056102    3.405062    0.281528    0.074731    0.000926    0.938404    
#> 213: 0.608974    1.054600    3.405193    0.282168    0.074954    0.000929    0.938734    
#> 214: 0.609219    1.053906    3.405330    0.286678    0.074931    0.000923    0.940048    
#> 215: 0.607873    1.054497    3.405398    0.290734    0.074608    0.000933    0.940312    
#> 216: 0.611384    1.053145    3.405466    0.295458    0.074412    0.000936    0.940623    
#> 217: 0.610546    1.054867    3.405272    0.296437    0.074624    0.000948    0.939578    
#> 218: 0.611303    1.056895    3.404889    0.298130    0.074561    0.000948    0.939060    
#> 219: 0.610616    1.056786    3.404505    0.302149    0.074961    0.000947    0.939141    
#> 220: 0.609994    1.057302    3.404573    0.302902    0.074992    0.000938    0.938205    
#> 221: 0.608409    1.058059    3.404391    0.303166    0.075208    0.000932    0.937159    
#> 222: 0.609535    1.058240    3.404363    0.305986    0.075042    0.000928    0.936085    
#> 223: 0.610662    1.058345    3.404317    0.306328    0.075629    0.000920    0.934722    
#> 224: 0.612307    1.059313    3.404395    0.307249    0.076317    0.000914    0.934090    
#> 225: 0.612860    1.058361    3.404467    0.306575    0.076111    0.000904    0.934039    
#> 226: 0.612414    1.057568    3.404288    0.307503    0.075962    0.000897    0.933747    
#> 227: 0.610875    1.056672    3.404405    0.309293    0.076025    0.000887    0.934019    
#> 228: 0.609319    1.057827    3.404292    0.308321    0.076344    0.000887    0.934211    
#> 229: 0.608591    1.057461    3.404215    0.308322    0.076432    0.000891    0.934051    
#> 230: 0.608059    1.056896    3.404262    0.306684    0.076648    0.000890    0.933907    
#> 231: 0.607902    1.056882    3.404424    0.305114    0.076623    0.000888    0.934053    
#> 232: 0.607273    1.056712    3.404757    0.305615    0.076649    0.000884    0.934202    
#> 233: 0.607678    1.056152    3.404882    0.306117    0.076651    0.000891    0.935002    
#> 234: 0.607325    1.056284    3.405116    0.307938    0.076868    0.000893    0.935364    
#> 235: 0.607623    1.056636    3.405117    0.309295    0.076626    0.000894    0.935277    
#> 236: 0.606621    1.056911    3.405093    0.308500    0.076647    0.000896    0.935505    
#> 237: 0.607506    1.056485    3.405093    0.308365    0.076595    0.000902    0.935880    
#> 238: 0.607668    1.056270    3.405094    0.308272    0.076865    0.000909    0.935810    
#> 239: 0.607569    1.056867    3.405016    0.308906    0.076829    0.000908    0.936401    
#> 240: 0.607439    1.056403    3.405050    0.308012    0.076946    0.000900    0.936821    
#> 241: 0.607328    1.055522    3.405149    0.308516    0.076656    0.000894    0.936852    
#> 242: 0.607567    1.055940    3.405231    0.309160    0.076872    0.000893    0.937045    
#> 243: 0.606567    1.056538    3.405151    0.308675    0.077096    0.000892    0.936912    
#> 244: 0.605886    1.056054    3.405043    0.306873    0.077097    0.000897    0.936895    
#> 245: 0.605455    1.055740    3.404884    0.305990    0.076784    0.000899    0.937204    
#> 246: 0.604791    1.055621    3.404863    0.306937    0.076792    0.000912    0.936941    
#> 247: 0.603794    1.055189    3.404853    0.306040    0.076612    0.000918    0.936715    
#> 248: 0.603636    1.055416    3.404926    0.305333    0.076433    0.000922    0.936407    
#> 249: 0.602917    1.055452    3.404883    0.305760    0.076210    0.000928    0.936267    
#> 250: 0.603226    1.055902    3.404870    0.305871    0.076052    0.000937    0.936206    
#> 251: 0.602957    1.056660    3.404849    0.305096    0.076064    0.000935    0.936378    
#> 252: 0.603328    1.056946    3.404893    0.305942    0.075767    0.000936    0.936717    
#> 253: 0.603542    1.057104    3.404922    0.306544    0.075605    0.000940    0.936669    
#> 254: 0.604597    1.057542    3.405112    0.307530    0.075612    0.000941    0.936127    
#> 255: 0.604388    1.057681    3.405352    0.307778    0.075640    0.000945    0.935945    
#> 256: 0.604851    1.057436    3.405420    0.308166    0.075597    0.000950    0.935779    
#> 257: 0.604771    1.056910    3.405384    0.307124    0.075723    0.000949    0.935703    
#> 258: 0.604530    1.056551    3.405269    0.306945    0.075811    0.000942    0.935387    
#> 259: 0.604440    1.056393    3.405262    0.306951    0.076002    0.000939    0.935296    
#> 260: 0.604283    1.056583    3.405335    0.306324    0.075941    0.000933    0.935312    
#> 261: 0.604164    1.056593    3.405432    0.306370    0.075871    0.000933    0.935184    
#> 262: 0.604366    1.056408    3.405480    0.305625    0.075896    0.000928    0.935454    
#> 263: 0.604444    1.056648    3.405559    0.306529    0.075701    0.000934    0.935227    
#> 264: 0.604625    1.056399    3.405614    0.306904    0.075330    0.000932    0.935627    
#> 265: 0.604912    1.056549    3.405672    0.306813    0.075015    0.000933    0.936201    
#> 266: 0.605369    1.057216    3.405633    0.306721    0.074701    0.000934    0.936715    
#> 267: 0.605453    1.057396    3.405581    0.308058    0.074729    0.000935    0.936584    
#> 268: 0.605606    1.057498    3.405464    0.308784    0.074708    0.000930    0.936438    
#> 269: 0.606219    1.057199    3.405369    0.308502    0.074777    0.000926    0.936408    
#> 270: 0.606489    1.057261    3.405247    0.308655    0.074771    0.000927    0.936263    
#> 271: 0.606853    1.057210    3.405141    0.309271    0.074867    0.000927    0.936519    
#> 272: 0.607113    1.057097    3.405040    0.309304    0.074822    0.000928    0.936952    
#> 273: 0.606973    1.057454    3.404994    0.309109    0.074808    0.000928    0.937168    
#> 274: 0.606558    1.057871    3.405011    0.308710    0.074787    0.000926    0.937608    
#> 275: 0.606708    1.058128    3.405010    0.308415    0.074924    0.000922    0.937365    
#> 276: 0.606625    1.058301    3.405117    0.308630    0.074992    0.000924    0.937550    
#> 277: 0.606280    1.058590    3.405150    0.308058    0.074978    0.000923    0.937524    
#> 278: 0.605796    1.058598    3.405112    0.307892    0.074936    0.000919    0.937480    
#> 279: 0.605835    1.058577    3.405118    0.308525    0.075026    0.000922    0.937622    
#> 280: 0.605537    1.058821    3.405143    0.308736    0.074948    0.000921    0.937568    
#> 281: 0.605233    1.058836    3.405133    0.308590    0.074873    0.000918    0.937732    
#> 282: 0.605281    1.058905    3.405160    0.308719    0.074823    0.000917    0.937712    
#> 283: 0.605720    1.059114    3.405165    0.308960    0.074853    0.000917    0.937592    
#> 284: 0.605669    1.059025    3.405203    0.309059    0.074910    0.000916    0.937354    
#> 285: 0.605980    1.058948    3.405162    0.309487    0.074754    0.000917    0.937291    
#> 286: 0.606308    1.059046    3.405098    0.309749    0.074972    0.000918    0.937379    
#> 287: 0.606552    1.059061    3.405035    0.309559    0.074993    0.000922    0.937279    
#> 288: 0.606820    1.058969    3.405049    0.309701    0.075056    0.000926    0.937287    
#> 289: 0.607103    1.058728    3.405073    0.309225    0.075036    0.000929    0.937609    
#> 290: 0.607047    1.058831    3.405038    0.308906    0.074948    0.000930    0.937682    
#> 291: 0.607218    1.059245    3.405040    0.308776    0.075062    0.000929    0.937313    
#> 292: 0.607028    1.059350    3.405022    0.308857    0.075138    0.000928    0.937094    
#> 293: 0.606892    1.059487    3.404994    0.308618    0.075134    0.000924    0.937080    
#> 294: 0.606783    1.059896    3.404937    0.309078    0.075073    0.000921    0.937221    
#> 295: 0.606720    1.059671    3.404897    0.309056    0.075033    0.000918    0.937051    
#> 296: 0.606878    1.059448    3.404931    0.309095    0.075018    0.000920    0.936913    
#> 297: 0.607247    1.059558    3.404931    0.309041    0.075008    0.000920    0.936719    
#> 298: 0.607322    1.059460    3.404952    0.308927    0.074952    0.000920    0.936606    
#> 299: 0.607737    1.059637    3.404962    0.309146    0.074915    0.000917    0.936499    
#> 300: 0.607912    1.059682    3.405047    0.309881    0.074887    0.000916    0.936336    
#> 301: 0.608390    1.059676    3.405070    0.310045    0.074904    0.000918    0.936568    
#> 302: 0.608461    1.059797    3.405063    0.310233    0.074701    0.000921    0.936515    
#> 303: 0.608279    1.059955    3.405064    0.310206    0.074423    0.000925    0.936442    
#> 304: 0.608506    1.060090    3.405123    0.310471    0.074286    0.000930    0.936371    
#> 305: 0.608519    1.059735    3.405192    0.310703    0.074277    0.000934    0.936097    
#> 306: 0.608270    1.059475    3.405215    0.310403    0.074286    0.000936    0.935986    
#> 307: 0.608431    1.059454    3.405161    0.309588    0.074296    0.000935    0.936191    
#> 308: 0.608128    1.059246    3.405125    0.310295    0.074322    0.000935    0.936255    
#> 309: 0.608349    1.059017    3.405097    0.310492    0.074245    0.000937    0.936336    
#> 310: 0.608957    1.058874    3.405038    0.310653    0.074260    0.000935    0.936392    
#> 311: 0.609004    1.058837    3.405022    0.310463    0.074210    0.000935    0.936228    
#> 312: 0.608715    1.058610    3.404989    0.310022    0.074290    0.000938    0.936149    
#> 313: 0.608480    1.058439    3.404972    0.310106    0.074342    0.000936    0.936209    
#> 314: 0.608286    1.058606    3.404953    0.310289    0.074379    0.000933    0.936070    
#> 315: 0.607860    1.058684    3.404954    0.310515    0.074291    0.000932    0.936104    
#> 316: 0.607918    1.058602    3.405008    0.310904    0.074293    0.000931    0.936136    
#> 317: 0.607810    1.058477    3.405036    0.310758    0.074373    0.000927    0.936362    
#> 318: 0.607975    1.058374    3.405008    0.311188    0.074405    0.000925    0.936389    
#> 319: 0.608090    1.058206    3.404984    0.311043    0.074477    0.000922    0.936404    
#> 320: 0.607466    1.058223    3.404924    0.310554    0.074497    0.000923    0.936276    
#> 321: 0.607001    1.058337    3.404832    0.310147    0.074582    0.000927    0.936426    
#> 322: 0.607173    1.058377    3.404754    0.310290    0.074500    0.000927    0.936307    
#> 323: 0.606620    1.058300    3.404731    0.310271    0.074432    0.000928    0.936259    
#> 324: 0.606768    1.058508    3.404770    0.310715    0.074481    0.000928    0.936063    
#> 325: 0.606735    1.058699    3.404785    0.310757    0.074528    0.000930    0.935876    
#> 326: 0.606637    1.058466    3.404750    0.310765    0.074656    0.000928    0.935794    
#> 327: 0.606653    1.058626    3.404740    0.310722    0.074825    0.000928    0.935710    
#> 328: 0.607088    1.058800    3.404700    0.310701    0.074835    0.000928    0.935663    
#> 329: 0.607313    1.058932    3.404712    0.310388    0.074837    0.000929    0.935730    
#> 330: 0.606740    1.058949    3.404714    0.309693    0.074834    0.000929    0.935866    
#> 331: 0.606820    1.059044    3.404707    0.309412    0.074821    0.000929    0.935881    
#> 332: 0.606854    1.058990    3.404681    0.309387    0.074725    0.000930    0.935891    
#> 333: 0.606770    1.059010    3.404638    0.309646    0.074768    0.000930    0.935897    
#> 334: 0.606720    1.058905    3.404591    0.309641    0.074666    0.000930    0.935947    
#> 335: 0.606727    1.058919    3.404530    0.309909    0.074635    0.000931    0.935890    
#> 336: 0.606482    1.059026    3.404502    0.310083    0.074586    0.000933    0.935811    
#> 337: 0.606605    1.059171    3.404460    0.310234    0.074559    0.000932    0.935782    
#> 338: 0.606819    1.059234    3.404483    0.310277    0.074544    0.000931    0.935690    
#> 339: 0.606659    1.059288    3.404485    0.310291    0.074457    0.000930    0.935631    
#> 340: 0.606573    1.059114    3.404523    0.310375    0.074479    0.000930    0.935570    
#> 341: 0.606803    1.059097    3.404565    0.310439    0.074390    0.000929    0.935628    
#> 342: 0.606662    1.059027    3.404578    0.310317    0.074279    0.000930    0.935507    
#> 343: 0.606456    1.059117    3.404618    0.309907    0.074206    0.000930    0.935499    
#> 344: 0.606887    1.059145    3.404639    0.310091    0.074264    0.000932    0.935520    
#> 345: 0.607134    1.059065    3.404652    0.309770    0.074426    0.000933    0.935495    
#> 346: 0.607019    1.059132    3.404649    0.309769    0.074466    0.000934    0.935438    
#> 347: 0.607095    1.059099    3.404586    0.310016    0.074503    0.000935    0.935313    
#> 348: 0.606811    1.059135    3.404527    0.310473    0.074495    0.000935    0.935443    
#> 349: 0.606892    1.059202    3.404492    0.311007    0.074527    0.000934    0.935220    
#> 350: 0.606788    1.059184    3.404461    0.311410    0.074491    0.000933    0.935018    
#> 351: 0.606816    1.059415    3.404409    0.311488    0.074524    0.000934    0.934922    
#> 352: 0.606446    1.059479    3.404401    0.311515    0.074521    0.000934    0.935016    
#> 353: 0.606332    1.059658    3.404392    0.311444    0.074533    0.000935    0.934989    
#> 354: 0.606396    1.059598    3.404333    0.311308    0.074467    0.000937    0.934953    
#> 355: 0.606840    1.059484    3.404290    0.311498    0.074519    0.000939    0.935003    
#> 356: 0.606768    1.059261    3.404269    0.311448    0.074610    0.000938    0.935094    
#> 357: 0.606742    1.059276    3.404245    0.311702    0.074635    0.000936    0.935103    
#> 358: 0.606484    1.059451    3.404251    0.311616    0.074605    0.000936    0.935049    
#> 359: 0.606310    1.059559    3.404246    0.311534    0.074679    0.000935    0.934909    
#> 360: 0.606145    1.059615    3.404222    0.311453    0.074657    0.000935    0.934804    
#> 361: 0.605879    1.059628    3.404206    0.311280    0.074604    0.000934    0.934712    
#> 362: 0.605892    1.059679    3.404172    0.311560    0.074572    0.000933    0.934629    
#> 363: 0.605950    1.059599    3.404140    0.311576    0.074571    0.000932    0.934508    
#> 364: 0.606192    1.059738    3.404096    0.311594    0.074504    0.000931    0.934428    
#> 365: 0.606177    1.059768    3.404102    0.311521    0.074396    0.000932    0.934604    
#> 366: 0.606050    1.059819    3.404041    0.311423    0.074326    0.000932    0.934658    
#> 367: 0.605895    1.059811    3.403990    0.311313    0.074301    0.000932    0.934661    
#> 368: 0.606128    1.060047    3.403950    0.312091    0.074272    0.000935    0.934488    
#> 369: 0.606095    1.060003    3.403943    0.312552    0.074339    0.000936    0.934403    
#> 370: 0.605906    1.060024    3.403910    0.312728    0.074396    0.000937    0.934222    
#> 371: 0.605761    1.060157    3.403841    0.312615    0.074371    0.000937    0.934093    
#> 372: 0.605731    1.060177    3.403805    0.312500    0.074341    0.000937    0.934180    
#> 373: 0.605426    1.060298    3.403764    0.312362    0.074326    0.000937    0.934309    
#> 374: 0.605216    1.060402    3.403710    0.312712    0.074329    0.000937    0.934349    
#> 375: 0.605109    1.060447    3.403649    0.312955    0.074401    0.000938    0.934437    
#> 376: 0.604969    1.060515    3.403633    0.312666    0.074463    0.000936    0.934387    
#> 377: 0.604768    1.060535    3.403622    0.312603    0.074577    0.000935    0.934315    
#> 378: 0.604480    1.060443    3.403571    0.312473    0.074640    0.000936    0.934467    
#> 379: 0.604133    1.060283    3.403595    0.312408    0.074742    0.000936    0.934404    
#> 380: 0.603771    1.060263    3.403599    0.312131    0.074880    0.000935    0.934362    
#> 381: 0.603624    1.060176    3.403609    0.312008    0.074863    0.000934    0.934479    
#> 382: 0.603768    1.060141    3.403595    0.312152    0.074891    0.000932    0.934339    
#> 383: 0.604011    1.060116    3.403594    0.312114    0.074843    0.000932    0.934233    
#> 384: 0.604041    1.060076    3.403608    0.311801    0.074818    0.000931    0.934189    
#> 385: 0.604023    1.060023    3.403644    0.311756    0.074779    0.000933    0.934186    
#> 386: 0.604192    1.060258    3.403682    0.311887    0.074759    0.000933    0.934121    
#> 387: 0.604415    1.060418    3.403718    0.311765    0.074741    0.000934    0.933989    
#> 388: 0.604585    1.060537    3.403734    0.311825    0.074732    0.000933    0.933994    
#> 389: 0.604719    1.060463    3.403735    0.311879    0.074724    0.000930    0.934016    
#> 390: 0.604542    1.060402    3.403723    0.311818    0.074639    0.000929    0.933989    
#> 391: 0.604641    1.060231    3.403722    0.311877    0.074603    0.000927    0.934037    
#> 392: 0.604649    1.060215    3.403763    0.312027    0.074611    0.000927    0.934026    
#> 393: 0.604560    1.060196    3.403786    0.312063    0.074593    0.000927    0.933990    
#> 394: 0.604657    1.060140    3.403792    0.312551    0.074532    0.000928    0.933851    
#> 395: 0.605154    1.060209    3.403818    0.312748    0.074503    0.000929    0.933820    
#> 396: 0.605274    1.060349    3.403830    0.313078    0.074476    0.000928    0.933792    
#> 397: 0.605200    1.060362    3.403868    0.313181    0.074518    0.000929    0.933593    
#> 398: 0.605397    1.060292    3.403906    0.313193    0.074577    0.000931    0.933507    
#> 399: 0.605440    1.060354    3.403950    0.313202    0.074616    0.000933    0.933546    
#> 400: 0.605379    1.060351    3.403984    0.313235    0.074622    0.000934    0.933589    
#> 401: 0.605429    1.060488    3.403977    0.313268    0.074645    0.000937    0.933460    
#> 402: 0.605392    1.060619    3.403974    0.313267    0.074586    0.000937    0.933458    
#> 403: 0.605544    1.060572    3.403984    0.313195    0.074522    0.000939    0.933410    
#> 404: 0.605690    1.060620    3.403981    0.313188    0.074501    0.000938    0.933294    
#> 405: 0.605737    1.060599    3.404022    0.313272    0.074484    0.000938    0.933378    
#> 406: 0.605952    1.060686    3.404054    0.313645    0.074551    0.000939    0.933386    
#> 407: 0.606119    1.060800    3.404095    0.313807    0.074534    0.000940    0.933308    
#> 408: 0.606108    1.060934    3.404137    0.313666    0.074482    0.000941    0.933321    
#> 409: 0.606153    1.060909    3.404129    0.313369    0.074498    0.000941    0.933227    
#> 410: 0.606080    1.060947    3.404112    0.313160    0.074489    0.000941    0.933145    
#> 411: 0.606090    1.060791    3.404088    0.313126    0.074469    0.000941    0.933092    
#> 412: 0.606062    1.060911    3.404074    0.312755    0.074426    0.000940    0.933034    
#> 413: 0.605992    1.060979    3.404031    0.312242    0.074457    0.000939    0.933043    
#> 414: 0.605761    1.061000    3.404011    0.312121    0.074434    0.000938    0.933037    
#> 415: 0.606019    1.061053    3.403996    0.312305    0.074381    0.000939    0.933021    
#> 416: 0.606256    1.061206    3.403989    0.312492    0.074373    0.000939    0.932971    
#> 417: 0.606406    1.061189    3.403979    0.312461    0.074377    0.000940    0.933000    
#> 418: 0.606333    1.061265    3.403957    0.312411    0.074401    0.000940    0.933054    
#> 419: 0.606471    1.061420    3.403949    0.312507    0.074367    0.000940    0.933113    
#> 420: 0.606723    1.061455    3.403952    0.312457    0.074365    0.000941    0.933138    
#> 421: 0.606700    1.061448    3.403960    0.312299    0.074401    0.000941    0.933155    
#> 422: 0.606841    1.061336    3.403966    0.312099    0.074423    0.000943    0.933145    
#> 423: 0.607138    1.061304    3.403988    0.312053    0.074497    0.000943    0.933130    
#> 424: 0.607198    1.061269    3.403993    0.311951    0.074512    0.000942    0.933116    
#> 425: 0.607464    1.061360    3.404015    0.312410    0.074521    0.000942    0.933111    
#> 426: 0.607723    1.061433    3.404035    0.312802    0.074480    0.000943    0.933140    
#> 427: 0.607644    1.061338    3.404021    0.312863    0.074457    0.000944    0.933095    
#> 428: 0.607570    1.061306    3.403999    0.312719    0.074405    0.000945    0.933134    
#> 429: 0.607594    1.061305    3.403994    0.312632    0.074425    0.000944    0.933061    
#> 430: 0.607509    1.061329    3.403988    0.312206    0.074451    0.000944    0.933046    
#> 431: 0.607375    1.061332    3.403970    0.312034    0.074407    0.000943    0.933018    
#> 432: 0.607515    1.061385    3.403972    0.312183    0.074384    0.000944    0.932987    
#> 433: 0.607668    1.061521    3.403991    0.312296    0.074394    0.000945    0.932927    
#> 434: 0.607441    1.061508    3.403999    0.312354    0.074431    0.000945    0.932819    
#> 435: 0.607366    1.061557    3.404012    0.312358    0.074406    0.000944    0.932775    
#> 436: 0.607309    1.061488    3.404013    0.312206    0.074395    0.000944    0.932759    
#> 437: 0.607191    1.061467    3.404005    0.312018    0.074340    0.000945    0.932801    
#> 438: 0.607232    1.061652    3.404007    0.312105    0.074353    0.000944    0.932779    
#> 439: 0.607318    1.061790    3.403996    0.312068    0.074358    0.000944    0.932702    
#> 440: 0.607138    1.061914    3.403991    0.311986    0.074397    0.000942    0.932688    
#> 441: 0.607046    1.061858    3.403989    0.311915    0.074435    0.000942    0.932675    
#> 442: 0.606799    1.061912    3.403989    0.311592    0.074429    0.000940    0.932626    
#> 443: 0.606769    1.061971    3.403990    0.311720    0.074451    0.000939    0.932594    
#> 444: 0.606737    1.061973    3.403994    0.311609    0.074479    0.000938    0.932557    
#> 445: 0.606766    1.061976    3.404003    0.311668    0.074517    0.000938    0.932544    
#> 446: 0.606626    1.062016    3.403997    0.311817    0.074546    0.000939    0.932508    
#> 447: 0.606844    1.062027    3.404004    0.311691    0.074533    0.000939    0.932501    
#> 448: 0.606881    1.062040    3.404024    0.311453    0.074504    0.000938    0.932470    
#> 449: 0.606920    1.062113    3.404076    0.311154    0.074472    0.000938    0.932482    
#> 450: 0.606902    1.062127    3.404089    0.311077    0.074397    0.000938    0.932474    
#> 451: 0.606925    1.062221    3.404091    0.311372    0.074317    0.000937    0.932448    
#> 452: 0.606808    1.062315    3.404068    0.311315    0.074332    0.000937    0.932436    
#> 453: 0.606733    1.062376    3.404056    0.311059    0.074344    0.000935    0.932407    
#> 454: 0.606799    1.062525    3.404039    0.311283    0.074369    0.000934    0.932270    
#> 455: 0.607017    1.062552    3.404027    0.311476    0.074331    0.000935    0.932291    
#> 456: 0.606936    1.062509    3.404028    0.311304    0.074298    0.000936    0.932301    
#> 457: 0.606897    1.062456    3.404034    0.311330    0.074251    0.000937    0.932329    
#> 458: 0.606901    1.062524    3.404068    0.311392    0.074236    0.000937    0.932372    
#> 459: 0.606794    1.062745    3.404097    0.311575    0.074253    0.000938    0.932379    
#> 460: 0.606709    1.062810    3.404107    0.311519    0.074251    0.000938    0.932418    
#> 461: 0.606526    1.062824    3.404114    0.311568    0.074220    0.000939    0.932432    
#> 462: 0.606423    1.062873    3.404127    0.311745    0.074272    0.000939    0.932388    
#> 463: 0.606437    1.062953    3.404111    0.311659    0.074302    0.000938    0.932359    
#> 464: 0.606457    1.062973    3.404116    0.311587    0.074327    0.000937    0.932326    
#> 465: 0.606419    1.062819    3.404118    0.311456    0.074322    0.000936    0.932377    
#> 466: 0.606604    1.062848    3.404114    0.311907    0.074303    0.000935    0.932436    
#> 467: 0.606543    1.062786    3.404119    0.311925    0.074284    0.000935    0.932398    
#> 468: 0.606631    1.062777    3.404131    0.312112    0.074277    0.000936    0.932397    
#> 469: 0.606673    1.062882    3.404166    0.312341    0.074231    0.000937    0.932401    
#> 470: 0.606530    1.062916    3.404181    0.312629    0.074210    0.000937    0.932385    
#> 471: 0.606404    1.062835    3.404185    0.312908    0.074195    0.000937    0.932445    
#> 472: 0.606402    1.062812    3.404186    0.313017    0.074168    0.000937    0.932398    
#> 473: 0.606177    1.062840    3.404171    0.313078    0.074129    0.000937    0.932343    
#> 474: 0.606126    1.062812    3.404170    0.313024    0.074091    0.000937    0.932387    
#> 475: 0.606244    1.062902    3.404160    0.312957    0.074058    0.000936    0.932375    
#> 476: 0.606363    1.062933    3.404144    0.312940    0.074097    0.000936    0.932473    
#> 477: 0.606358    1.063004    3.404138    0.313049    0.074144    0.000937    0.932333    
#> 478: 0.606349    1.062947    3.404135    0.313096    0.074096    0.000936    0.932329    
#> 479: 0.606406    1.062997    3.404139    0.312889    0.074163    0.000937    0.932355    
#> 480: 0.606553    1.063009    3.404162    0.312896    0.074193    0.000939    0.932399    
#> 481: 0.606547    1.063017    3.404181    0.312825    0.074150    0.000940    0.932404    
#> 482: 0.606652    1.062992    3.404179    0.312771    0.074103    0.000941    0.932494    
#> 483: 0.606700    1.062948    3.404158    0.312945    0.074078    0.000940    0.932502    
#> 484: 0.606710    1.062852    3.404161    0.313076    0.074068    0.000940    0.932501    
#> 485: 0.606664    1.062961    3.404177    0.313277    0.074065    0.000940    0.932501    
#> 486: 0.606625    1.062984    3.404185    0.313219    0.074103    0.000938    0.932457    
#> 487: 0.606864    1.062971    3.404224    0.313214    0.074081    0.000938    0.932469    
#> 488: 0.606845    1.062924    3.404251    0.313308    0.074031    0.000939    0.932483    
#> 489: 0.606950    1.062900    3.404269    0.313198    0.073997    0.000940    0.932541    
#> 490: 0.606958    1.062925    3.404285    0.313112    0.073933    0.000940    0.932604    
#> 491: 0.606970    1.063025    3.404295    0.313002    0.073954    0.000939    0.932583    
#> 492: 0.606816    1.063101    3.404303    0.313017    0.073967    0.000940    0.932666    
#> 493: 0.606736    1.063165    3.404318    0.312964    0.073968    0.000941    0.932747    
#> 494: 0.606830    1.063251    3.404323    0.312828    0.073973    0.000941    0.932746    
#> 495: 0.607018    1.063251    3.404343    0.312752    0.073920    0.000941    0.932692    
#> 496: 0.607161    1.063266    3.404345    0.312919    0.073914    0.000943    0.932658    
#> 497: 0.607103    1.063255    3.404344    0.313081    0.073890    0.000945    0.932617    
#> 498: 0.607231    1.063225    3.404338    0.313071    0.073850    0.000945    0.932551    
#> 499: 0.607323    1.063277    3.404326    0.313136    0.073891    0.000945    0.932502    
#> 500: 0.607354    1.063182    3.404319    0.313056    0.073950    0.000945    0.932448    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.300990    1.001977    3.451498    0.392401    0.075288    0.016800    1.755230    
#> 002: 0.333972    1.103454    3.491885    0.372781    0.071524    0.021090    1.133106    
#> 003: 0.528169    1.078688    3.510141    0.427177    0.067947    0.020036    0.869219    
#> 004: 0.565731    1.114467    3.532403    0.474124    0.064550    0.019034    0.734046    
#> 005: 0.669432    1.126715    3.527661    0.546047    0.061323    0.018082    0.646717    
#> 006: 0.622141    1.135890    3.532822    0.518745    0.058256    0.020166    0.593993    
#> 007: 0.612558    1.138110    3.521233    0.528269    0.055344    0.020709    0.582980    
#> 008: 0.644696    1.123419    3.516282    0.675621    0.052576    0.022155    0.569110    
#> 009: 0.640202    1.108741    3.524138    0.702810    0.049948    0.021047    0.573831    
#> 010: 0.653497    1.125272    3.528683    0.720164    0.047450    0.023587    0.567428    
#> 011: 0.735136    1.126169    3.537361    0.813921    0.045078    0.025027    0.568324    
#> 012: 0.700929    1.123470    3.533503    0.773225    0.054807    0.023776    0.561297    
#> 013: 0.632845    1.118660    3.524795    0.734564    0.059155    0.024963    0.559282    
#> 014: 0.662985    1.126174    3.539766    0.697836    0.069446    0.024237    0.566941    
#> 015: 0.698688    1.116540    3.548750    0.662944    0.065974    0.023025    0.553834    
#> 016: 0.722608    1.132549    3.551666    0.629797    0.064921    0.021874    0.565437    
#> 017: 0.690087    1.132796    3.549337    0.598307    0.061675    0.020780    0.543265    
#> 018: 0.703056    1.145400    3.531551    0.671096    0.060621    0.019741    0.537047    
#> 019: 0.653399    1.133310    3.530299    0.637541    0.063090    0.018754    0.537399    
#> 020: 0.680835    1.123747    3.534338    0.672890    0.061763    0.017817    0.549012    
#> 021: 0.679720    1.131098    3.541529    0.639246    0.060197    0.016926    0.538168    
#> 022: 0.750709    1.133105    3.559206    0.704158    0.058809    0.017346    0.535578    
#> 023: 0.808921    1.126423    3.559865    0.739378    0.064871    0.017013    0.556368    
#> 024: 0.758873    1.134300    3.550894    0.719196    0.061628    0.016162    0.550465    
#> 025: 0.742361    1.129164    3.549015    0.683236    0.058546    0.015354    0.556191    
#> 026: 0.718618    1.143945    3.549855    0.649074    0.057887    0.018305    0.560695    
#> 027: 0.674166    1.148325    3.542869    0.616621    0.060380    0.017390    0.575535    
#> 028: 0.706331    1.133816    3.548445    0.747742    0.057361    0.017768    0.556438    
#> 029: 0.718412    1.140378    3.529821    0.792184    0.060728    0.020540    0.549071    
#> 030: 0.694590    1.157808    3.526093    0.839048    0.057691    0.022168    0.550707    
#> 031: 0.674200    1.135749    3.525365    0.797096    0.054807    0.021597    0.549836    
#> 032: 0.658937    1.144895    3.522152    0.757241    0.053869    0.021879    0.539911    
#> 033: 0.657604    1.163407    3.517774    0.734917    0.070009    0.020785    0.553169    
#> 034: 0.706841    1.156092    3.528278    0.777235    0.066508    0.019746    0.559693    
#> 035: 0.677019    1.122079    3.528363    0.738373    0.063183    0.018758    0.547911    
#> 036: 0.685645    1.136904    3.537801    0.701455    0.065137    0.017820    0.562784    
#> 037: 0.717703    1.155341    3.533635    0.689355    0.068506    0.017563    0.576735    
#> 038: 0.722337    1.146849    3.538429    0.656636    0.065636    0.018502    0.556551    
#> 039: 0.691415    1.141125    3.534653    0.699170    0.074500    0.017870    0.538931    
#> 040: 0.660728    1.146537    3.542436    0.664211    0.070775    0.020206    0.548131    
#> 041: 0.642976    1.140691    3.535092    0.631001    0.067236    0.019196    0.537178    
#> 042: 0.650902    1.117620    3.536458    0.599451    0.063874    0.018236    0.542994    
#> 043: 0.653965    1.147373    3.523218    0.575331    0.061412    0.018115    0.546358    
#> 044: 0.646295    1.139258    3.527790    0.587552    0.058341    0.019302    0.544220    
#> 045: 0.653115    1.153593    3.520801    0.565653    0.056344    0.019706    0.536578    
#> 046: 0.676616    1.146560    3.532008    0.639316    0.061791    0.021066    0.536401    
#> 047: 0.666999    1.157006    3.530661    0.613279    0.072097    0.020012    0.536765    
#> 048: 0.667709    1.140928    3.536096    0.583721    0.068493    0.019012    0.546465    
#> 049: 0.660137    1.145718    3.537311    0.603412    0.065068    0.018061    0.554373    
#> 050: 0.748041    1.119077    3.547869    0.693981    0.061815    0.020228    0.557249    
#> 051: 0.702771    1.120158    3.539943    0.730998    0.068126    0.019390    0.552792    
#> 052: 0.723466    1.145113    3.546045    0.747558    0.071722    0.018421    0.546167    
#> 053: 0.735754    1.123852    3.542958    0.752880    0.068233    0.019493    0.549672    
#> 054: 0.680026    1.128522    3.541146    0.715236    0.064821    0.023593    0.562460    
#> 055: 0.662668    1.122499    3.541042    0.679475    0.061580    0.022413    0.569467    
#> 056: 0.727083    1.124706    3.541421    0.680317    0.061245    0.021292    0.548592    
#> 057: 0.726757    1.129100    3.545663    0.682994    0.058182    0.020228    0.558865    
#> 058: 0.702559    1.134372    3.538736    0.648845    0.055511    0.020190    0.565953    
#> 059: 0.656923    1.092248    3.546098    0.616402    0.053353    0.022286    0.585309    
#> 060: 0.697978    1.089411    3.556635    0.605000    0.062582    0.023352    0.580971    
#> 061: 0.764738    1.109031    3.563049    0.660967    0.059453    0.028464    0.578935    
#> 062: 0.747581    1.112360    3.561615    0.710649    0.056480    0.029150    0.576476    
#> 063: 0.739409    1.095330    3.558963    0.675117    0.053656    0.027692    0.579190    
#> 064: 0.713755    1.110634    3.562083    0.641361    0.061707    0.026307    0.578368    
#> 065: 0.755460    1.112410    3.552472    0.657753    0.058622    0.024992    0.570938    
#> 066: 0.721252    1.131300    3.546144    0.661616    0.055691    0.023743    0.552569    
#> 067: 0.708541    1.107451    3.538348    0.648854    0.054752    0.022555    0.547593    
#> 068: 0.691549    1.115560    3.548091    0.685381    0.052898    0.021428    0.568855    
#> 069: 0.695265    1.110784    3.535561    0.677058    0.059959    0.022854    0.586925    
#> 070: 0.731694    1.122325    3.560886    0.643205    0.060868    0.023043    0.571464    
#> 071: 0.692078    1.133695    3.538918    0.642792    0.057825    0.021891    0.576707    
#> 072: 0.621411    1.112707    3.533253    0.610652    0.062082    0.020796    0.570066    
#> 073: 0.674665    1.134725    3.555054    0.617095    0.072351    0.022775    0.579731    
#> 074: 0.652451    1.115211    3.541955    0.595803    0.068733    0.027518    0.551007    
#> 075: 0.685554    1.104801    3.563713    0.636573    0.065296    0.032206    0.559840    
#> 076: 0.719680    1.114633    3.562059    0.690038    0.062032    0.030596    0.558478    
#> 077: 0.761727    1.111924    3.554348    0.790656    0.058930    0.029066    0.541227    
#> 078: 0.736501    1.116763    3.545107    0.786109    0.055983    0.027613    0.526141    
#> 079: 0.682171    1.123919    3.554966    0.746804    0.059959    0.029098    0.546108    
#> 080: 0.734493    1.120479    3.560841    0.709464    0.056961    0.029266    0.542439    
#> 081: 0.711556    1.120350    3.550975    0.673991    0.055314    0.027803    0.533331    
#> 082: 0.685678    1.118768    3.545170    0.677165    0.053568    0.026413    0.555399    
#> 083: 0.728902    1.140130    3.548076    0.752210    0.050890    0.025092    0.549960    
#> 084: 0.737301    1.135536    3.543082    0.732182    0.059559    0.023837    0.537082    
#> 085: 0.709690    1.141446    3.557256    0.718009    0.056581    0.024375    0.544367    
#> 086: 0.756196    1.127110    3.550136    0.858256    0.053752    0.025836    0.549670    
#> 087: 0.746507    1.127080    3.542215    0.815343    0.051065    0.024544    0.545035    
#> 088: 0.727310    1.112602    3.555476    0.774576    0.048723    0.023317    0.536325    
#> 089: 0.729783    1.136001    3.540218    0.747778    0.053672    0.022151    0.546714    
#> 090: 0.675860    1.123765    3.537211    0.710389    0.062555    0.021239    0.569062    
#> 091: 0.666508    1.120504    3.532261    0.674870    0.065264    0.020177    0.551589    
#> 092: 0.635336    1.132655    3.519745    0.641126    0.080072    0.019168    0.555374    
#> 093: 0.615480    1.135144    3.521724    0.609070    0.076068    0.018210    0.563675    
#> 094: 0.670576    1.144239    3.516680    0.626934    0.072265    0.017299    0.543697    
#> 095: 0.656509    1.145473    3.526036    0.660538    0.068652    0.017819    0.548221    
#> 096: 0.642201    1.141086    3.522966    0.647287    0.065219    0.019837    0.536670    
#> 097: 0.656320    1.155637    3.525812    0.658614    0.062872    0.018845    0.538256    
#> 098: 0.673358    1.153905    3.528635    0.722378    0.059729    0.020799    0.545947    
#> 099: 0.677963    1.139658    3.528909    0.686259    0.056742    0.019985    0.538260    
#> 100: 0.660458    1.147007    3.536051    0.651946    0.053905    0.022434    0.541184    
#> 101: 0.617431    1.138763    3.511833    0.619349    0.053204    0.022916    0.552208    
#> 102: 0.660090    1.124856    3.528173    0.599188    0.059063    0.022708    0.559186    
#> 103: 0.693382    1.140767    3.543626    0.675923    0.062284    0.021572    0.534249    
#> 104: 0.687205    1.149658    3.545528    0.642127    0.065753    0.020494    0.544076    
#> 105: 0.715298    1.127684    3.544828    0.713574    0.062465    0.020945    0.554806    
#> 106: 0.705770    1.127081    3.540895    0.677896    0.062343    0.019897    0.565190    
#> 107: 0.670342    1.133650    3.530456    0.644001    0.065086    0.018903    0.543014    
#> 108: 0.682724    1.131111    3.536627    0.705057    0.061831    0.017957    0.547557    
#> 109: 0.669287    1.141893    3.537272    0.669804    0.068489    0.017060    0.550352    
#> 110: 0.689027    1.127195    3.538048    0.636314    0.065065    0.016207    0.545064    
#> 111: 0.686707    1.133323    3.536839    0.604498    0.061812    0.015396    0.541966    
#> 112: 0.668414    1.119053    3.534496    0.574273    0.068654    0.014626    0.544710    
#> 113: 0.684739    1.153149    3.542150    0.641651    0.072645    0.013895    0.536436    
#> 114: 0.692148    1.139763    3.540429    0.609796    0.078962    0.013200    0.539528    
#> 115: 0.694768    1.120141    3.535204    0.579306    0.075013    0.015411    0.549258    
#> 116: 0.711602    1.128365    3.546998    0.572228    0.071263    0.015409    0.540265    
#> 117: 0.646608    1.136355    3.546326    0.543616    0.067700    0.015492    0.567065    
#> 118: 0.675700    1.113438    3.545302    0.528898    0.064408    0.016490    0.568168    
#> 119: 0.641398    1.125220    3.539818    0.564807    0.067634    0.016638    0.567081    
#> 120: 0.639616    1.115824    3.542167    0.536567    0.064252    0.016439    0.566081    
#> 121: 0.683347    1.129226    3.551166    0.518916    0.061040    0.016712    0.564685    
#> 122: 0.699683    1.110512    3.552698    0.640392    0.057988    0.016672    0.557558    
#> 123: 0.765794    1.140643    3.546382    0.711174    0.055775    0.015838    0.558426    
#> 124: 0.747541    1.151842    3.543249    0.759842    0.064795    0.017301    0.555313    
#> 125: 0.725662    1.145652    3.535053    0.721850    0.072493    0.016436    0.550714    
#> 126: 0.721791    1.158416    3.529754    0.753485    0.068959    0.018178    0.560632    
#> 127: 0.688308    1.144008    3.537593    0.715811    0.067243    0.017269    0.568829    
#> 128: 0.703409    1.130649    3.558056    0.680020    0.073812    0.018717    0.572362    
#> 129: 0.741780    1.128669    3.557156    0.673449    0.078473    0.017781    0.582867    
#> 130: 0.760895    1.132091    3.547659    0.732395    0.077484    0.016892    0.567691    
#> 131: 0.733967    1.108757    3.544683    0.699434    0.073609    0.016845    0.554402    
#> 132: 0.713575    1.111075    3.536101    0.664462    0.069929    0.016002    0.566542    
#> 133: 0.682196    1.113892    3.548542    0.631239    0.066433    0.015202    0.567516    
#> 134: 0.660117    1.116391    3.539738    0.643928    0.070982    0.014442    0.561624    
#> 135: 0.672469    1.118609    3.543475    0.611732    0.073270    0.013720    0.565803    
#> 136: 0.668045    1.123601    3.540458    0.582731    0.069606    0.015146    0.555887    
#> 137: 0.687313    1.114491    3.539949    0.598803    0.070403    0.014389    0.571907    
#> 138: 0.654714    1.133470    3.529720    0.603249    0.069327    0.013669    0.569490    
#> 139: 0.639573    1.138111    3.535526    0.582487    0.065861    0.012986    0.562601    
#> 140: 0.679770    1.152256    3.534490    0.708765    0.070500    0.014102    0.560839    
#> 141: 0.652760    1.136526    3.533166    0.673326    0.078556    0.013397    0.556823    
#> 142: 0.675583    1.122459    3.545279    0.639660    0.078416    0.015643    0.572020    
#> 143: 0.653940    1.151539    3.535528    0.607677    0.077939    0.014860    0.562016    
#> 144: 0.732091    1.135623    3.555747    0.619582    0.074042    0.014117    0.554366    
#> 145: 0.702360    1.139682    3.541705    0.684790    0.074284    0.013943    0.543085    
#> 146: 0.693399    1.141625    3.542180    0.653054    0.071589    0.013246    0.552732    
#> 147: 0.659036    1.136075    3.526583    0.670313    0.068009    0.014964    0.544263    
#> 148: 0.659414    1.147379    3.539587    0.636797    0.073714    0.017192    0.528808    
#> 149: 0.699280    1.118397    3.548437    0.643458    0.070028    0.017029    0.544197    
#> 150: 0.709767    1.116994    3.538063    0.666737    0.075168    0.016177    0.548324    
#> 151: 0.663876    1.142256    3.540158    0.633401    0.079486    0.015369    0.538756    
#> 152: 0.668259    1.139133    3.540240    0.677434    0.076469    0.013651    0.541820    
#> 153: 0.701528    1.144690    3.546875    0.719335    0.072257    0.015653    0.540228    
#> 154: 0.738521    1.144146    3.549681    0.721375    0.072366    0.015401    0.536850    
#> 155: 0.722829    1.123426    3.540406    0.742497    0.071803    0.015024    0.542786    
#> 156: 0.733376    1.121943    3.548903    0.767674    0.078549    0.016930    0.554937    
#> 157: 0.752960    1.116454    3.552914    0.693517    0.074502    0.016031    0.556534    
#> 158: 0.724316    1.134769    3.548706    0.673887    0.068450    0.014808    0.551381    
#> 159: 0.707220    1.126625    3.563346    0.647172    0.066121    0.013520    0.548397    
#> 160: 0.760645    1.097566    3.570879    0.682553    0.059830    0.014322    0.565871    
#> 161: 0.724145    1.122671    3.549563    0.612339    0.060810    0.013333    0.573130    
#> 162: 0.728955    1.122673    3.550138    0.656979    0.073815    0.014623    0.570366    
#> 163: 0.737287    1.110920    3.554225    0.663630    0.070793    0.016471    0.555780    
#> 164: 0.732520    1.115935    3.546318    0.705153    0.073935    0.017565    0.555441    
#> 165: 0.759837    1.115816    3.545964    0.750904    0.069064    0.018435    0.555493    
#> 166: 0.799091    1.144657    3.549750    0.841426    0.065081    0.015802    0.580100    
#> 167: 0.754472    1.156392    3.555476    0.679534    0.071620    0.016453    0.596976    
#> 168: 0.740361    1.153274    3.546114    0.699738    0.068347    0.013766    0.571338    
#> 169: 0.707932    1.163608    3.529709    0.644026    0.079513    0.012806    0.565474    
#> 170: 0.699525    1.139443    3.537899    0.681125    0.065563    0.014007    0.543720    
#> 171: 0.708133    1.134822    3.538888    0.717805    0.069381    0.013523    0.542036    
#> 172: 0.690850    1.151856    3.533631    0.729138    0.068331    0.013478    0.546955    
#> 173: 0.658517    1.167072    3.523347    0.665206    0.061747    0.014149    0.560382    
#> 174: 0.665452    1.145424    3.534258    0.683681    0.068809    0.013632    0.561411    
#> 175: 0.667205    1.161489    3.517417    0.706018    0.065921    0.015607    0.556879    
#> 176: 0.704022    1.172859    3.524798    0.825771    0.076716    0.015661    0.557261    
#> 177: 0.695975    1.148815    3.533264    0.728695    0.068588    0.019614    0.545933    
#> 178: 0.708872    1.133833    3.535501    0.729809    0.077150    0.016619    0.546090    
#> 179: 0.707920    1.142736    3.530326    0.688319    0.058021    0.017544    0.569688    
#> 180: 0.689698    1.127441    3.531670    0.696363    0.066691    0.015300    0.551101    
#> 181: 0.668488    1.122296    3.528251    0.671439    0.055106    0.014910    0.568395    
#> 182: 0.606689    1.138014    3.510116    0.660842    0.064871    0.012111    0.578547    
#> 183: 0.672857    1.145284    3.521463    0.705247    0.071897    0.014093    0.573049    
#> 184: 0.662738    1.150748    3.526136    0.710524    0.084643    0.013488    0.569247    
#> 185: 0.643061    1.164090    3.513079    0.684822    0.084530    0.015854    0.569207    
#> 186: 0.598125    1.164733    3.515558    0.554115    0.072722    0.016915    0.558486    
#> 187: 0.636544    1.151267    3.523163    0.541242    0.062259    0.017178    0.536842    
#> 188: 0.625483    1.159389    3.523903    0.522750    0.065294    0.017616    0.551762    
#> 189: 0.636127    1.155842    3.531941    0.651479    0.053518    0.021346    0.553326    
#> 190: 0.652342    1.155672    3.534807    0.605883    0.054350    0.019482    0.537430    
#> 191: 0.687147    1.150082    3.530907    0.718517    0.054628    0.020973    0.526914    
#> 192: 0.646740    1.150825    3.530995    0.624635    0.054538    0.021982    0.548330    
#> 193: 0.655290    1.145365    3.530400    0.611405    0.059704    0.019903    0.539566    
#> 194: 0.642893    1.138385    3.524595    0.564127    0.047942    0.023948    0.554432    
#> 195: 0.595814    1.144903    3.524784    0.526316    0.051933    0.022686    0.544037    
#> 196: 0.628114    1.147845    3.535021    0.618194    0.055140    0.021109    0.561102    
#> 197: 0.679867    1.144841    3.543291    0.739851    0.053193    0.023488    0.559174    
#> 198: 0.718401    1.117253    3.543160    0.640762    0.063772    0.019259    0.552059    
#> 199: 0.684184    1.114929    3.547426    0.623598    0.054185    0.020336    0.553284    
#> 200: 0.671707    1.133211    3.555243    0.545135    0.056878    0.017246    0.569337    
#> 201: 0.673297    1.127105    3.555952    0.560603    0.058523    0.016367    0.563146    
#> 202: 0.690787    1.126412    3.557229    0.601348    0.058123    0.017012    0.557150    
#> 203: 0.705575    1.121352    3.554867    0.613388    0.059009    0.017951    0.553279    
#> 204: 0.710217    1.116460    3.554632    0.636767    0.060020    0.017822    0.555840    
#> 205: 0.707250    1.121680    3.553049    0.642797    0.059828    0.017938    0.557957    
#> 206: 0.708616    1.123962    3.552619    0.646479    0.059453    0.017836    0.559769    
#> 207: 0.706808    1.124721    3.551514    0.636193    0.060696    0.017327    0.558523    
#> 208: 0.709059    1.125938    3.551155    0.639815    0.061432    0.017202    0.555916    
#> 209: 0.710423    1.123638    3.550303    0.638255    0.061891    0.017006    0.554462    
#> 210: 0.707808    1.122958    3.550135    0.635437    0.062686    0.017081    0.553495    
#> 211: 0.709533    1.123686    3.550498    0.633182    0.062427    0.017108    0.552715    
#> 212: 0.709642    1.122661    3.550747    0.631999    0.062089    0.017233    0.551814    
#> 213: 0.712398    1.120534    3.550673    0.640716    0.062039    0.017258    0.552608    
#> 214: 0.716073    1.119337    3.551325    0.652277    0.061722    0.017368    0.552149    
#> 215: 0.717023    1.119549    3.551463    0.653875    0.061902    0.017420    0.551775    
#> 216: 0.719470    1.118459    3.551930    0.659563    0.061576    0.017724    0.552819    
#> 217: 0.719509    1.118287    3.552322    0.664934    0.061611    0.017943    0.552139    
#> 218: 0.720435    1.118573    3.551825    0.671859    0.061462    0.017970    0.551242    
#> 219: 0.717000    1.118467    3.550521    0.666518    0.061699    0.017937    0.550817    
#> 220: 0.713061    1.119349    3.549394    0.665178    0.061880    0.017805    0.550402    
#> 221: 0.711747    1.120163    3.548639    0.667412    0.062331    0.017806    0.549583    
#> 222: 0.710076    1.120929    3.547642    0.667977    0.062681    0.017796    0.549196    
#> 223: 0.710488    1.121813    3.546919    0.670981    0.063011    0.017793    0.549572    
#> 224: 0.711053    1.122863    3.546741    0.672522    0.063032    0.017814    0.549432    
#> 225: 0.709906    1.122283    3.546820    0.670494    0.063289    0.017786    0.549844    
#> 226: 0.707951    1.121392    3.546594    0.668205    0.063438    0.017625    0.549795    
#> 227: 0.707501    1.121047    3.546631    0.663186    0.063459    0.017479    0.549696    
#> 228: 0.706031    1.121391    3.546298    0.657996    0.063479    0.017368    0.549993    
#> 229: 0.704321    1.121293    3.546020    0.656925    0.063190    0.017292    0.550266    
#> 230: 0.704745    1.121360    3.545880    0.657880    0.063260    0.017230    0.550279    
#> 231: 0.705421    1.121378    3.545836    0.661587    0.063358    0.017139    0.549744    
#> 232: 0.705559    1.121370    3.546000    0.664692    0.063350    0.017120    0.549346    
#> 233: 0.704331    1.120972    3.545967    0.665874    0.063640    0.017031    0.549543    
#> 234: 0.704371    1.120654    3.545973    0.665319    0.063632    0.017049    0.549506    
#> 235: 0.704533    1.120432    3.545980    0.664097    0.063796    0.017022    0.549262    
#> 236: 0.704714    1.120493    3.545916    0.663897    0.063889    0.017022    0.549054    
#> 237: 0.706331    1.120139    3.546011    0.667508    0.063804    0.017060    0.549392    
#> 238: 0.707814    1.120105    3.546213    0.670028    0.063793    0.017034    0.549644    
#> 239: 0.707812    1.120310    3.546039    0.669838    0.063692    0.016957    0.550032    
#> 240: 0.706634    1.120375    3.545929    0.667126    0.063555    0.016836    0.550115    
#> 241: 0.705988    1.119964    3.545744    0.665632    0.063678    0.016724    0.550102    
#> 242: 0.705791    1.119786    3.545470    0.666535    0.063920    0.016687    0.550230    
#> 243: 0.705664    1.120374    3.545249    0.666131    0.064039    0.016629    0.550362    
#> 244: 0.706064    1.120380    3.545245    0.669388    0.063933    0.016606    0.550831    
#> 245: 0.706422    1.120090    3.545160    0.671177    0.063818    0.016609    0.551421    
#> 246: 0.706348    1.120181    3.544995    0.671254    0.063817    0.016613    0.551582    
#> 247: 0.706171    1.120089    3.545121    0.670920    0.063833    0.016658    0.551489    
#> 248: 0.705725    1.120879    3.544939    0.669702    0.063995    0.016688    0.551407    
#> 249: 0.704252    1.121163    3.544825    0.668756    0.064203    0.016688    0.551464    
#> 250: 0.704546    1.121125    3.544993    0.669066    0.064105    0.016720    0.551511    
#> 251: 0.705848    1.121406    3.545157    0.671413    0.064343    0.016752    0.551438    
#> 252: 0.705739    1.121680    3.545353    0.669908    0.064383    0.016764    0.551465    
#> 253: 0.705514    1.121816    3.545316    0.668907    0.064402    0.016742    0.551546    
#> 254: 0.705725    1.122148    3.545214    0.669117    0.064243    0.016761    0.551623    
#> 255: 0.706158    1.122709    3.545109    0.670383    0.064163    0.016743    0.551707    
#> 256: 0.706285    1.122870    3.544902    0.671382    0.063924    0.016811    0.551712    
#> 257: 0.705615    1.122937    3.544800    0.670150    0.063693    0.016859    0.551897    
#> 258: 0.705123    1.122968    3.544737    0.669536    0.063702    0.016900    0.551837    
#> 259: 0.704847    1.122948    3.544728    0.669541    0.063588    0.016944    0.551719    
#> 260: 0.704915    1.123137    3.544818    0.668179    0.063542    0.016995    0.551567    
#> 261: 0.704939    1.123075    3.544910    0.667332    0.063476    0.017034    0.551441    
#> 262: 0.704495    1.123594    3.544978    0.665686    0.063459    0.017068    0.551324    
#> 263: 0.703934    1.124058    3.544927    0.663426    0.063449    0.017108    0.551550    
#> 264: 0.703193    1.124463    3.544903    0.661723    0.063490    0.017087    0.551799    
#> 265: 0.702939    1.124589    3.544871    0.661173    0.063559    0.017105    0.551934    
#> 266: 0.702853    1.124675    3.544881    0.660776    0.063530    0.017159    0.551919    
#> 267: 0.702267    1.124700    3.544860    0.659791    0.063528    0.017178    0.552006    
#> 268: 0.702179    1.124673    3.544739    0.661047    0.063609    0.017171    0.551963    
#> 269: 0.703096    1.124493    3.544793    0.663286    0.063636    0.017162    0.551935    
#> 270: 0.703983    1.124619    3.544820    0.665220    0.063694    0.017121    0.551808    
#> 271: 0.704232    1.124610    3.544760    0.665805    0.063580    0.017122    0.551895    
#> 272: 0.704750    1.124448    3.544859    0.665778    0.063507    0.017187    0.552208    
#> 273: 0.705026    1.124421    3.545002    0.666858    0.063382    0.017240    0.552325    
#> 274: 0.705120    1.124567    3.545127    0.665546    0.063466    0.017317    0.552292    
#> 275: 0.705354    1.124445    3.545087    0.665129    0.063403    0.017355    0.552384    
#> 276: 0.704997    1.124556    3.545229    0.663418    0.063252    0.017364    0.552570    
#> 277: 0.704345    1.124801    3.545409    0.662271    0.063255    0.017377    0.552678    
#> 278: 0.704274    1.124787    3.545588    0.661149    0.063286    0.017357    0.552702    
#> 279: 0.704538    1.124651    3.545764    0.662173    0.063391    0.017373    0.552986    
#> 280: 0.704231    1.124812    3.545775    0.661718    0.063374    0.017413    0.552941    
#> 281: 0.704060    1.124805    3.545873    0.661896    0.063301    0.017454    0.552889    
#> 282: 0.704454    1.124852    3.545886    0.663049    0.063216    0.017478    0.552912    
#> 283: 0.704748    1.125041    3.545852    0.664169    0.063255    0.017490    0.553079    
#> 284: 0.704574    1.124929    3.545827    0.664239    0.063414    0.017483    0.552948    
#> 285: 0.704527    1.124983    3.545671    0.665005    0.063496    0.017485    0.552872    
#> 286: 0.704335    1.125077    3.545471    0.665630    0.063464    0.017486    0.552765    
#> 287: 0.703783    1.125559    3.545207    0.665369    0.063447    0.017506    0.552749    
#> 288: 0.703552    1.125680    3.545015    0.665195    0.063376    0.017565    0.552840    
#> 289: 0.703846    1.125707    3.544976    0.665182    0.063213    0.017607    0.552836    
#> 290: 0.704140    1.125648    3.545086    0.664872    0.063197    0.017637    0.552770    
#> 291: 0.704452    1.125681    3.545340    0.663994    0.063167    0.017687    0.552638    
#> 292: 0.704677    1.125523    3.545368    0.664011    0.063101    0.017741    0.552558    
#> 293: 0.704373    1.125545    3.545308    0.664151    0.063041    0.017802    0.552454    
#> 294: 0.704105    1.125695    3.545181    0.663536    0.062943    0.017823    0.552350    
#> 295: 0.704059    1.125549    3.545124    0.662844    0.062870    0.017853    0.552247    
#> 296: 0.704055    1.125410    3.545199    0.661924    0.062930    0.017889    0.552271    
#> 297: 0.703869    1.125571    3.545131    0.661861    0.062913    0.017912    0.552182    
#> 298: 0.703880    1.125597    3.545117    0.662451    0.062892    0.017943    0.551992    
#> 299: 0.703794    1.125763    3.544945    0.663425    0.062912    0.017964    0.551887    
#> 300: 0.703701    1.125720    3.544930    0.663685    0.062839    0.018025    0.551770    
#> 301: 0.703874    1.125764    3.544811    0.663957    0.062785    0.018072    0.551689    
#> 302: 0.704099    1.125755    3.544765    0.664981    0.062786    0.018127    0.551546    
#> 303: 0.703834    1.126001    3.544660    0.664933    0.062822    0.018144    0.551416    
#> 304: 0.703580    1.126280    3.544400    0.665574    0.062958    0.018155    0.551466    
#> 305: 0.703204    1.126211    3.544274    0.665013    0.062992    0.018178    0.551482    
#> 306: 0.702756    1.126336    3.544064    0.665184    0.062989    0.018219    0.551390    
#> 307: 0.702156    1.126300    3.543932    0.664781    0.062879    0.018286    0.551422    
#> 308: 0.701802    1.126241    3.543781    0.665136    0.062859    0.018329    0.551459    
#> 309: 0.701573    1.126019    3.543712    0.665505    0.062832    0.018382    0.551514    
#> 310: 0.701442    1.125998    3.543525    0.665716    0.062706    0.018430    0.551490    
#> 311: 0.701387    1.126060    3.543453    0.667148    0.062614    0.018489    0.551440    
#> 312: 0.701670    1.126073    3.543372    0.668996    0.062520    0.018546    0.551406    
#> 313: 0.701487    1.126045    3.543237    0.669642    0.062553    0.018602    0.551491    
#> 314: 0.701035    1.126136    3.543118    0.669683    0.062527    0.018641    0.551478    
#> 315: 0.700390    1.126258    3.542985    0.669278    0.062473    0.018674    0.551463    
#> 316: 0.700452    1.126540    3.542917    0.670343    0.062457    0.018673    0.551428    
#> 317: 0.700927    1.126651    3.542886    0.672189    0.062456    0.018684    0.551406    
#> 318: 0.700927    1.126837    3.542784    0.671962    0.062508    0.018675    0.551383    
#> 319: 0.701288    1.126857    3.542846    0.672895    0.062489    0.018699    0.551370    
#> 320: 0.701616    1.126799    3.542919    0.673522    0.062472    0.018691    0.551410    
#> 321: 0.701324    1.126910    3.542777    0.672801    0.062464    0.018692    0.551517    
#> 322: 0.701501    1.127034    3.542680    0.673158    0.062465    0.018690    0.551533    
#> 323: 0.701097    1.127103    3.542639    0.672977    0.062385    0.018682    0.551621    
#> 324: 0.701063    1.127244    3.542644    0.673172    0.062425    0.018698    0.551590    
#> 325: 0.701282    1.127430    3.542553    0.674228    0.062439    0.018684    0.551645    
#> 326: 0.701429    1.127372    3.542458    0.675579    0.062384    0.018689    0.551629    
#> 327: 0.701708    1.127439    3.542406    0.676739    0.062347    0.018689    0.551593    
#> 328: 0.702251    1.127577    3.542387    0.678057    0.062363    0.018676    0.551479    
#> 329: 0.702728    1.127520    3.542426    0.679122    0.062346    0.018670    0.551364    
#> 330: 0.703181    1.127481    3.542406    0.681370    0.062341    0.018664    0.551368    
#> 331: 0.703722    1.127577    3.542335    0.683458    0.062395    0.018654    0.551339    
#> 332: 0.704070    1.127600    3.542362    0.684684    0.062452    0.018643    0.551338    
#> 333: 0.703744    1.127677    3.542203    0.684465    0.062540    0.018611    0.551288    
#> 334: 0.703718    1.127694    3.542018    0.685249    0.062616    0.018599    0.551275    
#> 335: 0.703562    1.127808    3.541888    0.685336    0.062695    0.018587    0.551242    
#> 336: 0.703311    1.127923    3.541754    0.685824    0.062795    0.018596    0.551239    
#> 337: 0.703102    1.128157    3.541649    0.685345    0.062814    0.018586    0.551239    
#> 338: 0.703194    1.128147    3.541686    0.685682    0.062805    0.018627    0.551162    
#> 339: 0.703310    1.128177    3.541732    0.685757    0.062805    0.018652    0.551097    
#> 340: 0.703273    1.128069    3.541776    0.685223    0.062773    0.018670    0.551107    
#> 341: 0.703364    1.127953    3.541869    0.684994    0.062786    0.018696    0.551063    
#> 342: 0.703180    1.127814    3.541887    0.684565    0.062755    0.018716    0.551035    
#> 343: 0.703309    1.127813    3.541881    0.685204    0.062766    0.018715    0.551080    
#> 344: 0.703649    1.127781    3.541899    0.686668    0.062777    0.018725    0.551124    
#> 345: 0.703833    1.127762    3.541914    0.687632    0.062704    0.018755    0.551076    
#> 346: 0.703986    1.127908    3.541835    0.688833    0.062700    0.018799    0.551024    
#> 347: 0.703900    1.127885    3.541771    0.689166    0.062636    0.018836    0.551067    
#> 348: 0.703574    1.127838    3.541676    0.689494    0.062599    0.018863    0.551065    
#> 349: 0.703597    1.127709    3.541711    0.689760    0.062550    0.018877    0.551139    
#> 350: 0.703574    1.127496    3.541726    0.689981    0.062561    0.018859    0.551226    
#> 351: 0.703357    1.127532    3.541712    0.689860    0.062561    0.018843    0.551220    
#> 352: 0.703216    1.127671    3.541682    0.689763    0.062576    0.018865    0.551313    
#> 353: 0.703411    1.127769    3.541675    0.689903    0.062559    0.018870    0.551199    
#> 354: 0.703216    1.127785    3.541639    0.689091    0.062596    0.018875    0.551249    
#> 355: 0.703613    1.127659    3.541619    0.689100    0.062691    0.018872    0.551254    
#> 356: 0.703529    1.127571    3.541680    0.688696    0.062685    0.018855    0.551393    
#> 357: 0.703544    1.127575    3.541658    0.688804    0.062712    0.018830    0.551357    
#> 358: 0.703338    1.127637    3.541632    0.688868    0.062836    0.018812    0.551229    
#> 359: 0.703054    1.127739    3.541566    0.688638    0.062851    0.018816    0.551108    
#> 360: 0.702828    1.127812    3.541461    0.688237    0.062819    0.018826    0.550955    
#> 361: 0.702549    1.127878    3.541307    0.688483    0.062867    0.018839    0.550881    
#> 362: 0.702195    1.127949    3.541183    0.688583    0.062902    0.018831    0.550727    
#> 363: 0.701876    1.128050    3.541085    0.688919    0.062920    0.018824    0.550632    
#> 364: 0.701935    1.128116    3.540989    0.689994    0.062987    0.018830    0.550645    
#> 365: 0.701733    1.128234    3.540872    0.690734    0.063030    0.018856    0.550695    
#> 366: 0.701441    1.128332    3.540721    0.691097    0.062970    0.018873    0.550750    
#> 367: 0.701472    1.128434    3.540614    0.691566    0.062964    0.018880    0.550745    
#> 368: 0.701446    1.128605    3.540555    0.691383    0.062980    0.018879    0.550655    
#> 369: 0.701220    1.128681    3.540541    0.691097    0.062975    0.018896    0.550629    
#> 370: 0.701146    1.128767    3.540525    0.690874    0.062992    0.018921    0.550586    
#> 371: 0.700980    1.128807    3.540479    0.690678    0.063006    0.018930    0.550489    
#> 372: 0.700640    1.128909    3.540375    0.690877    0.063020    0.018930    0.550418    
#> 373: 0.700165    1.129091    3.540248    0.690700    0.063040    0.018939    0.550451    
#> 374: 0.699889    1.129132    3.540208    0.689972    0.063032    0.018946    0.550429    
#> 375: 0.699482    1.129198    3.540131    0.689223    0.063037    0.018942    0.550425    
#> 376: 0.699213    1.129362    3.540079    0.688499    0.063039    0.018936    0.550471    
#> 377: 0.698921    1.129473    3.540051    0.687779    0.063017    0.018936    0.550529    
#> 378: 0.698552    1.129497    3.539979    0.687145    0.062952    0.018931    0.550555    
#> 379: 0.698262    1.129359    3.540008    0.686588    0.062901    0.018926    0.550585    
#> 380: 0.698110    1.129374    3.539998    0.686267    0.062823    0.018930    0.550643    
#> 381: 0.697844    1.129349    3.539953    0.685603    0.062756    0.018958    0.550658    
#> 382: 0.697698    1.129350    3.539911    0.685300    0.062705    0.018962    0.550535    
#> 383: 0.697789    1.129361    3.539893    0.685833    0.062707    0.018949    0.550456    
#> 384: 0.697827    1.129371    3.539902    0.686083    0.062697    0.018945    0.550417    
#> 385: 0.698049    1.129381    3.539907    0.686173    0.062695    0.018923    0.550430    
#> 386: 0.698145    1.129504    3.539947    0.686018    0.062721    0.018914    0.550504    
#> 387: 0.698149    1.129558    3.539974    0.685743    0.062694    0.018927    0.550510    
#> 388: 0.698135    1.129551    3.540000    0.685575    0.062684    0.018930    0.550501    
#> 389: 0.698068    1.129412    3.540029    0.685156    0.062700    0.018948    0.550526    
#> 390: 0.697896    1.129529    3.539990    0.684747    0.062691    0.018959    0.550599    
#> 391: 0.698030    1.129461    3.539971    0.684776    0.062648    0.018959    0.550567    
#> 392: 0.698246    1.129424    3.540022    0.685120    0.062612    0.018946    0.550584    
#> 393: 0.698404    1.129365    3.540020    0.685764    0.062648    0.018931    0.550562    
#> 394: 0.698635    1.129358    3.539993    0.686993    0.062659    0.018906    0.550584    
#> 395: 0.698940    1.129369    3.540006    0.688534    0.062693    0.018897    0.550626    
#> 396: 0.699133    1.129412    3.540004    0.689743    0.062774    0.018886    0.550553    
#> 397: 0.699206    1.129344    3.540024    0.690181    0.062788    0.018880    0.550577    
#> 398: 0.699344    1.129329    3.540061    0.690509    0.062800    0.018864    0.550526    
#> 399: 0.699305    1.129344    3.540152    0.690265    0.062751    0.018852    0.550505    
#> 400: 0.699406    1.129396    3.540195    0.690186    0.062734    0.018851    0.550521    
#> 401: 0.699467    1.129502    3.540180    0.689950    0.062745    0.018846    0.550544    
#> 402: 0.699425    1.129585    3.540117    0.689697    0.062736    0.018826    0.550615    
#> 403: 0.699511    1.129658    3.540052    0.689984    0.062753    0.018796    0.550668    
#> 404: 0.699383    1.129743    3.539992    0.689933    0.062746    0.018783    0.550631    
#> 405: 0.699095    1.129799    3.539946    0.689785    0.062797    0.018766    0.550620    
#> 406: 0.698858    1.129891    3.539919    0.689248    0.062830    0.018763    0.550571    
#> 407: 0.698882    1.129890    3.539948    0.689240    0.062831    0.018763    0.550551    
#> 408: 0.698917    1.129925    3.539964    0.688561    0.062885    0.018747    0.550545    
#> 409: 0.698845    1.129824    3.539981    0.688171    0.062939    0.018729    0.550525    
#> 410: 0.698869    1.129800    3.540002    0.687998    0.062974    0.018732    0.550478    
#> 411: 0.698898    1.129648    3.540005    0.687783    0.062925    0.018726    0.550552    
#> 412: 0.698821    1.129631    3.539994    0.687596    0.062936    0.018709    0.550612    
#> 413: 0.698820    1.129736    3.539936    0.687967    0.062953    0.018696    0.550644    
#> 414: 0.698679    1.129748    3.539928    0.688034    0.062962    0.018684    0.550680    
#> 415: 0.698858    1.129717    3.539928    0.688377    0.062978    0.018667    0.550698    
#> 416: 0.698996    1.129767    3.539979    0.688169    0.062990    0.018672    0.550786    
#> 417: 0.699002    1.129830    3.539960    0.688256    0.063017    0.018672    0.550802    
#> 418: 0.698814    1.129876    3.539969    0.687729    0.063014    0.018674    0.550812    
#> 419: 0.698626    1.129914    3.539965    0.687294    0.063019    0.018679    0.550878    
#> 420: 0.698694    1.129888    3.539975    0.687273    0.063023    0.018681    0.550865    
#> 421: 0.698702    1.129953    3.540040    0.686955    0.062998    0.018692    0.550864    
#> 422: 0.698890    1.129868    3.540098    0.687173    0.062971    0.018700    0.550891    
#> 423: 0.699141    1.129827    3.540142    0.687201    0.062944    0.018727    0.550904    
#> 424: 0.699090    1.129830    3.540144    0.686921    0.062886    0.018737    0.550951    
#> 425: 0.699104    1.129851    3.540129    0.686598    0.062854    0.018741    0.551028    
#> 426: 0.699310    1.129923    3.540123    0.687302    0.062878    0.018747    0.551015    
#> 427: 0.699353    1.129920    3.540114    0.687943    0.062853    0.018751    0.550974    
#> 428: 0.699222    1.129953    3.540096    0.687847    0.062840    0.018751    0.551012    
#> 429: 0.699172    1.130004    3.540079    0.687638    0.062821    0.018744    0.551044    
#> 430: 0.699056    1.130089    3.540020    0.687427    0.062837    0.018744    0.551016    
#> 431: 0.698949    1.130147    3.539982    0.687547    0.062773    0.018743    0.550958    
#> 432: 0.698822    1.130292    3.539930    0.687790    0.062718    0.018757    0.550942    
#> 433: 0.698772    1.130368    3.539953    0.687825    0.062733    0.018755    0.550997    
#> 434: 0.698547    1.130303    3.539947    0.687338    0.062715    0.018753    0.551016    
#> 435: 0.698573    1.130224    3.539960    0.687229    0.062685    0.018757    0.550985    
#> 436: 0.698605    1.130111    3.540052    0.687464    0.062682    0.018756    0.551082    
#> 437: 0.698674    1.129998    3.540062    0.687516    0.062672    0.018755    0.551138    
#> 438: 0.698618    1.130093    3.540036    0.687366    0.062653    0.018754    0.551114    
#> 439: 0.698531    1.130215    3.540008    0.686819    0.062655    0.018754    0.551068    
#> 440: 0.698461    1.130350    3.540018    0.686268    0.062587    0.018753    0.551077    
#> 441: 0.698556    1.130385    3.540027    0.686368    0.062565    0.018747    0.551048    
#> 442: 0.698412    1.130444    3.539996    0.686162    0.062547    0.018749    0.551012    
#> 443: 0.698245    1.130558    3.539913    0.686106    0.062581    0.018734    0.550969    
#> 444: 0.698164    1.130649    3.539846    0.685968    0.062643    0.018722    0.550970    
#> 445: 0.697993    1.130734    3.539794    0.685723    0.062663    0.018722    0.550984    
#> 446: 0.697696    1.130828    3.539738    0.685254    0.062695    0.018721    0.550973    
#> 447: 0.697787    1.130922    3.539732    0.685347    0.062723    0.018714    0.550996    
#> 448: 0.697738    1.130936    3.539747    0.685338    0.062729    0.018703    0.551008    
#> 449: 0.697768    1.131021    3.539797    0.685180    0.062756    0.018694    0.551056    
#> 450: 0.697583    1.131038    3.539788    0.684781    0.062748    0.018682    0.551075    
#> 451: 0.697427    1.131075    3.539761    0.684420    0.062768    0.018678    0.551094    
#> 452: 0.697341    1.131152    3.539737    0.684175    0.062760    0.018671    0.551090    
#> 453: 0.697160    1.131230    3.539700    0.683753    0.062718    0.018680    0.551063    
#> 454: 0.697145    1.131369    3.539666    0.684140    0.062673    0.018676    0.551039    
#> 455: 0.697196    1.131405    3.539631    0.684986    0.062655    0.018670    0.551091    
#> 456: 0.697123    1.131337    3.539627    0.684946    0.062657    0.018662    0.551099    
#> 457: 0.697188    1.131279    3.539658    0.685177    0.062613    0.018661    0.551051    
#> 458: 0.697182    1.131345    3.539663    0.685026    0.062592    0.018671    0.551017    
#> 459: 0.696970    1.131498    3.539652    0.684480    0.062636    0.018682    0.550982    
#> 460: 0.696904    1.131561    3.539643    0.684199    0.062651    0.018682    0.550951    
#> 461: 0.696774    1.131634    3.539616    0.684080    0.062674    0.018679    0.550909    
#> 462: 0.696711    1.131703    3.539620    0.684069    0.062664    0.018664    0.550874    
#> 463: 0.696707    1.131751    3.539622    0.684184    0.062648    0.018649    0.550892    
#> 464: 0.696799    1.131797    3.539584    0.684377    0.062668    0.018632    0.550885    
#> 465: 0.696917    1.131705    3.539593    0.684503    0.062683    0.018626    0.550830    
#> 466: 0.696944    1.131684    3.539610    0.684280    0.062673    0.018620    0.550806    
#> 467: 0.696960    1.131623    3.539624    0.684348    0.062651    0.018614    0.550777    
#> 468: 0.697026    1.131654    3.539659    0.684200    0.062632    0.018612    0.550773    
#> 469: 0.696983    1.131726    3.539669    0.683692    0.062616    0.018608    0.550796    
#> 470: 0.696805    1.131735    3.539637    0.683383    0.062601    0.018604    0.550764    
#> 471: 0.696658    1.131723    3.539644    0.682928    0.062581    0.018609    0.550759    
#> 472: 0.696644    1.131677    3.539645    0.682878    0.062581    0.018616    0.550726    
#> 473: 0.696583    1.131645    3.539655    0.682648    0.062580    0.018618    0.550662    
#> 474: 0.696395    1.131628    3.539640    0.682199    0.062584    0.018621    0.550685    
#> 475: 0.696401    1.131661    3.539631    0.682008    0.062593    0.018620    0.550674    
#> 476: 0.696423    1.131642    3.539635    0.681813    0.062642    0.018619    0.550665    
#> 477: 0.696455    1.131589    3.539692    0.681560    0.062688    0.018617    0.550638    
#> 478: 0.696487    1.131511    3.539757    0.681630    0.062728    0.018619    0.550661    
#> 479: 0.696812    1.131463    3.539817    0.682282    0.062778    0.018608    0.550628    
#> 480: 0.696931    1.131434    3.539823    0.682595    0.062809    0.018599    0.550632    
#> 481: 0.697067    1.131449    3.539828    0.682945    0.062817    0.018579    0.550647    
#> 482: 0.697044    1.131458    3.539791    0.683141    0.062852    0.018569    0.550672    
#> 483: 0.696841    1.131464    3.539749    0.683058    0.062852    0.018557    0.550712    
#> 484: 0.696775    1.131422    3.539737    0.683040    0.062850    0.018557    0.550737    
#> 485: 0.696716    1.131491    3.539705    0.683265    0.062873    0.018563    0.550751    
#> 486: 0.696698    1.131546    3.539700    0.683183    0.062870    0.018561    0.550743    
#> 487: 0.696765    1.131591    3.539744    0.683100    0.062878    0.018568    0.550760    
#> 488: 0.696913    1.131557    3.539781    0.683123    0.062900    0.018572    0.550737    
#> 489: 0.696976    1.131556    3.539754    0.683389    0.062909    0.018587    0.550710    
#> 490: 0.697083    1.131610    3.539746    0.683698    0.062920    0.018603    0.550673    
#> 491: 0.697144    1.131699    3.539753    0.683787    0.062931    0.018600    0.550628    
#> 492: 0.697170    1.131801    3.539730    0.684060    0.062945    0.018596    0.550637    
#> 493: 0.697080    1.131831    3.539713    0.684234    0.062963    0.018597    0.550619    
#> 494: 0.697185    1.131894    3.539662    0.684439    0.062928    0.018601    0.550606    
#> 495: 0.697229    1.131951    3.539627    0.684788    0.062922    0.018602    0.550564    
#> 496: 0.697114    1.132028    3.539577    0.684297    0.062932    0.018601    0.550581    
#> 497: 0.696939    1.132061    3.539545    0.683932    0.062904    0.018597    0.550608    
#> 498: 0.696878    1.132035    3.539524    0.683727    0.062902    0.018588    0.550575    
#> 499: 0.696832    1.132048    3.539507    0.683447    0.062905    0.018583    0.550513    
#> 500: 0.696884    1.131959    3.539490    0.683433    0.062886    0.018578    0.550485    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.351556    0.969088    3.444705    0.392401    0.089363    0.016800    1.767836    
#> 002: 0.468370    0.996592    3.461630    0.372781    0.084895    0.017929    1.121808    
#> 003: 0.628218    0.955922    3.469258    0.354142    0.080650    0.017033    0.855462    
#> 004: 0.582518    0.966036    3.460475    0.399863    0.076618    0.016181    0.752309    
#> 005: 0.671553    0.970553    3.460019    0.432909    0.072787    0.015372    0.670496    
#> 006: 0.663760    0.986413    3.450217    0.463148    0.069147    0.014604    0.636202    
#> 007: 0.646417    1.004699    3.442759    0.464294    0.065690    0.013873    0.643055    
#> 008: 0.639437    0.996934    3.439781    0.541637    0.062405    0.018083    0.635466    
#> 009: 0.627982    0.989975    3.433521    0.556586    0.059285    0.017179    0.637108    
#> 010: 0.626189    0.994506    3.442726    0.602988    0.056321    0.018397    0.630647    
#> 011: 0.682398    0.998064    3.444925    0.637245    0.053505    0.018309    0.628876    
#> 012: 0.693692    0.997594    3.440880    0.605383    0.050830    0.017394    0.627164    
#> 013: 0.631742    0.997569    3.434748    0.575114    0.052479    0.019520    0.630212    
#> 014: 0.654812    0.992643    3.448171    0.629166    0.064283    0.020656    0.638295    
#> 015: 0.710040    1.008164    3.451741    0.686843    0.063408    0.019623    0.620109    
#> 016: 0.669334    1.004773    3.447977    0.652501    0.060237    0.022152    0.626454    
#> 017: 0.688210    1.011684    3.451325    0.651775    0.057225    0.021044    0.610827    
#> 018: 0.674637    1.011842    3.442315    0.627701    0.054364    0.019992    0.613371    
#> 019: 0.625767    1.005523    3.437997    0.596316    0.052423    0.018993    0.614008    
#> 020: 0.694414    1.022176    3.441427    0.686937    0.061534    0.018043    0.615238    
#> 021: 0.681404    1.009015    3.449330    0.652590    0.058457    0.017141    0.621404    
#> 022: 0.683358    1.002109    3.458791    0.647120    0.055535    0.016401    0.600533    
#> 023: 0.762298    0.993578    3.472779    0.632577    0.052758    0.017103    0.630214    
#> 024: 0.709542    1.019686    3.454693    0.704968    0.050120    0.017840    0.619863    
#> 025: 0.725215    1.008163    3.448535    0.669719    0.047614    0.017307    0.628818    
#> 026: 0.671723    1.039636    3.445771    0.636233    0.045726    0.019760    0.649626    
#> 027: 0.640966    1.041503    3.440015    0.604422    0.053473    0.018772    0.666570    
#> 028: 0.672301    1.016313    3.449199    0.574200    0.050799    0.018221    0.636742    
#> 029: 0.685126    1.006618    3.438033    0.573527    0.053028    0.018416    0.637238    
#> 030: 0.704521    1.032540    3.437704    0.676726    0.050376    0.019074    0.629113    
#> 031: 0.615757    1.014326    3.433558    0.642890    0.049621    0.018120    0.623615    
#> 032: 0.662194    0.999175    3.435677    0.655386    0.047140    0.017214    0.613336    
#> 033: 0.649252    1.006644    3.437843    0.622617    0.044853    0.017322    0.605690    
#> 034: 0.675160    1.027447    3.434597    0.651388    0.049142    0.016889    0.601875    
#> 035: 0.651577    1.015812    3.442968    0.618819    0.046685    0.017460    0.589026    
#> 036: 0.657390    1.017003    3.441448    0.587878    0.044351    0.018709    0.607456    
#> 037: 0.678980    1.023481    3.443020    0.578206    0.042133    0.021508    0.628936    
#> 038: 0.687332    1.025432    3.442030    0.637504    0.040863    0.023925    0.625206    
#> 039: 0.706885    1.007531    3.446825    0.690314    0.044383    0.027883    0.609499    
#> 040: 0.675202    1.023678    3.448017    0.655798    0.043488    0.026489    0.599666    
#> 041: 0.654591    1.012591    3.443381    0.623008    0.041314    0.025165    0.608176    
#> 042: 0.657171    0.999790    3.440595    0.591858    0.039248    0.023906    0.624256    
#> 043: 0.625205    1.031746    3.429598    0.562265    0.040965    0.022711    0.617699    
#> 044: 0.625958    1.029858    3.430941    0.534152    0.040606    0.023715    0.611717    
#> 045: 0.645054    1.046230    3.426738    0.519341    0.039764    0.022530    0.612075    
#> 046: 0.630690    1.040822    3.423816    0.568438    0.038026    0.022503    0.609945    
#> 047: 0.607834    1.035976    3.425163    0.540016    0.037618    0.021378    0.604275    
#> 048: 0.667175    1.019041    3.438887    0.619434    0.035737    0.021796    0.626919    
#> 049: 0.678497    1.005386    3.443728    0.588462    0.035095    0.020707    0.621429    
#> 050: 0.687368    0.986977    3.454015    0.581895    0.037334    0.019671    0.620590    
#> 051: 0.698357    1.008759    3.448047    0.603697    0.042029    0.018688    0.622778    
#> 052: 0.705650    0.992839    3.466706    0.582324    0.039928    0.019282    0.617878    
#> 053: 0.742261    0.981683    3.454920    0.789674    0.037931    0.018318    0.630549    
#> 054: 0.666060    1.000970    3.452801    0.750190    0.036035    0.020914    0.665226    
#> 055: 0.676844    1.003821    3.450383    0.712681    0.037931    0.019868    0.643332    
#> 056: 0.736192    0.993645    3.454161    0.721900    0.045405    0.018875    0.632460    
#> 057: 0.734430    0.994563    3.459092    0.685805    0.043135    0.020619    0.618924    
#> 058: 0.713656    1.004580    3.443647    0.702345    0.040978    0.020030    0.619519    
#> 059: 0.682796    0.984060    3.437622    0.667228    0.038929    0.019200    0.644440    
#> 060: 0.720229    0.974165    3.459000    0.633866    0.036983    0.020506    0.656566    
#> 061: 0.756386    0.984386    3.462597    0.684669    0.035134    0.026116    0.660732    
#> 062: 0.714545    0.999965    3.464882    0.675324    0.036185    0.025995    0.688021    
#> 063: 0.730053    0.978374    3.458717    0.679426    0.037607    0.024695    0.680673    
#> 064: 0.706340    1.000323    3.460432    0.645455    0.038303    0.023460    0.675300    
#> 065: 0.717208    0.980820    3.453336    0.646783    0.036388    0.022287    0.669435    
#> 066: 0.725380    0.993439    3.463732    0.624793    0.036892    0.021173    0.638726    
#> 067: 0.703859    0.986411    3.459494    0.608883    0.040384    0.020114    0.615770    
#> 068: 0.677791    0.993475    3.463396    0.587444    0.039045    0.019108    0.639565    
#> 069: 0.661527    1.015012    3.454256    0.588073    0.037121    0.019100    0.652462    
#> 070: 0.705894    1.013775    3.468457    0.558669    0.036721    0.019145    0.641612    
#> 071: 0.689166    1.026912    3.442157    0.543794    0.036651    0.018188    0.647587    
#> 072: 0.667678    1.012926    3.449081    0.516605    0.042723    0.021626    0.635465    
#> 073: 0.671235    1.017152    3.454021    0.535875    0.051351    0.020545    0.635354    
#> 074: 0.664402    1.013200    3.449980    0.518963    0.048783    0.020436    0.623532    
#> 075: 0.697162    1.008809    3.471996    0.535294    0.046344    0.022686    0.625168    
#> 076: 0.696271    1.003324    3.457564    0.577542    0.044027    0.021552    0.618445    
#> 077: 0.710815    1.002671    3.456518    0.619282    0.046136    0.020474    0.625609    
#> 078: 0.707109    0.999514    3.464559    0.610545    0.043829    0.021650    0.610555    
#> 079: 0.683204    1.010102    3.457606    0.580018    0.041638    0.023406    0.634627    
#> 080: 0.692217    1.005281    3.451564    0.552473    0.045836    0.024859    0.627665    
#> 081: 0.689238    1.013583    3.448888    0.534083    0.043545    0.023616    0.614605    
#> 082: 0.688839    1.002300    3.454636    0.656643    0.047146    0.022435    0.624954    
#> 083: 0.759378    1.017783    3.468168    0.756757    0.044789    0.022668    0.632816    
#> 084: 0.780328    1.003324    3.466244    0.819183    0.052707    0.025671    0.630428    
#> 085: 0.757264    1.008935    3.475314    0.796835    0.050072    0.024388    0.629074    
#> 086: 0.755706    0.999028    3.463932    0.786834    0.047568    0.026248    0.621775    
#> 087: 0.759961    0.996523    3.453978    0.825788    0.045190    0.024936    0.633312    
#> 088: 0.689921    1.012608    3.452309    0.784499    0.043527    0.023689    0.626616    
#> 089: 0.680308    1.014251    3.434894    0.745274    0.047210    0.022504    0.620519    
#> 090: 0.627798    1.030035    3.431672    0.708010    0.052521    0.021379    0.626394    
#> 091: 0.624838    1.025869    3.424273    0.672610    0.051173    0.020310    0.624830    
#> 092: 0.634628    1.038181    3.423773    0.638979    0.048614    0.019295    0.622548    
#> 093: 0.598187    1.032313    3.424201    0.607030    0.052032    0.018330    0.629797    
#> 094: 0.617529    1.024217    3.426385    0.605615    0.049430    0.017413    0.623583    
#> 095: 0.655390    1.012803    3.446761    0.685884    0.046959    0.016543    0.636969    
#> 096: 0.630820    1.018948    3.437470    0.651589    0.044611    0.018961    0.612282    
#> 097: 0.637687    1.032514    3.432171    0.648136    0.042380    0.019155    0.599878    
#> 098: 0.708831    1.038253    3.438072    0.627099    0.040261    0.020234    0.603414    
#> 099: 0.669316    1.013898    3.435111    0.595744    0.038248    0.019223    0.615123    
#> 100: 0.683428    1.019700    3.447549    0.565957    0.036336    0.020383    0.626453    
#> 101: 0.661334    0.998501    3.435514    0.586177    0.034811    0.019364    0.625181    
#> 102: 0.698994    0.995176    3.431107    0.749423    0.043533    0.019611    0.622953    
#> 103: 0.754262    0.996997    3.448098    0.891684    0.043665    0.019418    0.620007    
#> 104: 0.712096    0.995405    3.455352    0.847100    0.041481    0.018601    0.626571    
#> 105: 0.747353    1.020370    3.451768    0.902995    0.048917    0.021926    0.630715    
#> 106: 0.705932    1.013485    3.451655    0.857845    0.046471    0.020830    0.627190    
#> 107: 0.675399    1.019749    3.439571    0.814953    0.044148    0.019788    0.610246    
#> 108: 0.667043    1.019590    3.439387    0.774205    0.041940    0.018799    0.625862    
#> 109: 0.686528    1.005089    3.451572    0.735495    0.039843    0.017859    0.612349    
#> 110: 0.678991    1.006053    3.440726    0.698720    0.044641    0.016966    0.610822    
#> 111: 0.699450    1.010523    3.450044    0.663784    0.042409    0.016118    0.593855    
#> 112: 0.685378    0.999747    3.444148    0.630595    0.044281    0.015312    0.620344    
#> 113: 0.675496    1.020213    3.446703    0.604622    0.042067    0.016645    0.599570    
#> 114: 0.699753    1.023251    3.448747    0.595288    0.040937    0.018808    0.599966    
#> 115: 0.705757    0.997887    3.449971    0.576995    0.044122    0.020135    0.600578    
#> 116: 0.719879    1.011751    3.455786    0.560663    0.042008    0.019128    0.610356    
#> 117: 0.666187    1.019701    3.456449    0.542324    0.039908    0.018172    0.624990    
#> 118: 0.699924    1.006525    3.459109    0.581182    0.037913    0.020843    0.622067    
#> 119: 0.666096    0.989225    3.455868    0.574688    0.036017    0.025389    0.636730    
#> 120: 0.678341    0.986949    3.466703    0.545953    0.034216    0.025795    0.641150    
#> 121: 0.671489    1.011108    3.457681    0.540488    0.032505    0.024804    0.637454    
#> 122: 0.693995    1.002924    3.452844    0.638244    0.030880    0.023564    0.626657    
#> 123: 0.736686    1.033668    3.444659    0.773368    0.029336    0.022721    0.632468    
#> 124: 0.679994    1.048511    3.438779    0.734699    0.028533    0.024786    0.633636    
#> 125: 0.676239    1.047436    3.438488    0.697964    0.028270    0.023547    0.638855    
#> 126: 0.727797    1.035698    3.440621    0.663066    0.034091    0.024107    0.632578    
#> 127: 0.711277    1.015475    3.445252    0.629913    0.032387    0.022902    0.639662    
#> 128: 0.699555    0.995812    3.453898    0.598417    0.039611    0.021757    0.625173    
#> 129: 0.709836    1.006372    3.460939    0.568496    0.041112    0.020669    0.619654    
#> 130: 0.759545    1.008983    3.454809    0.668050    0.039056    0.019635    0.606876    
#> 131: 0.726001    0.989902    3.449661    0.634647    0.037104    0.020450    0.613168    
#> 132: 0.668687    0.996277    3.445431    0.602915    0.041671    0.019427    0.606386    
#> 133: 0.706852    0.984144    3.456504    0.600754    0.045607    0.018456    0.617604    
#> 134: 0.723426    0.987530    3.471132    0.627626    0.045747    0.017533    0.634020    
#> 135: 0.760938    0.982049    3.474037    0.694986    0.043460    0.016657    0.631048    
#> 136: 0.700555    0.972915    3.471747    0.660237    0.041287    0.017634    0.629879    
#> 137: 0.747593    0.978359    3.471358    0.627225    0.039223    0.016752    0.638093    
#> 138: 0.699036    0.996047    3.463231    0.595864    0.046472    0.015914    0.635082    
#> 139: 0.689193    0.991700    3.464666    0.589845    0.044148    0.019341    0.624399    
#> 140: 0.750757    1.015452    3.461848    0.608727    0.041941    0.020730    0.635726    
#> 141: 0.686082    0.992623    3.464875    0.578291    0.051018    0.019693    0.634379    
#> 142: 0.697978    0.968786    3.475564    0.549376    0.049325    0.018709    0.648360    
#> 143: 0.676800    0.992457    3.466641    0.521907    0.050967    0.017773    0.654895    
#> 144: 0.720370    0.998762    3.474482    0.495812    0.048419    0.016884    0.650723    
#> 145: 0.690298    1.007757    3.455399    0.519084    0.046531    0.016040    0.634919    
#> 146: 0.667272    1.000761    3.466056    0.558456    0.044205    0.015499    0.650463    
#> 147: 0.654265    0.989699    3.443700    0.619651    0.041994    0.019510    0.615242    
#> 148: 0.664105    1.009474    3.449843    0.626165    0.043954    0.018535    0.616938    
#> 149: 0.658304    1.006271    3.446200    0.605187    0.044647    0.018880    0.616409    
#> 150: 0.662253    1.015557    3.430857    0.574928    0.055519    0.019143    0.636448    
#> 151: 0.574090    1.037067    3.423951    0.546182    0.056188    0.018186    0.625203    
#> 152: 0.629089    1.031092    3.437569    0.565027    0.054537    0.018169    0.624206    
#> 153: 0.646748    1.027495    3.438521    0.601530    0.048338    0.016674    0.633621    
#> 154: 0.708903    1.031794    3.438634    0.700361    0.043080    0.015322    0.642389    
#> 155: 0.623920    1.010662    3.444240    0.568474    0.046463    0.016734    0.621025    
#> 156: 0.652407    1.002238    3.454645    0.565117    0.048700    0.014247    0.640387    
#> 157: 0.684576    0.999005    3.454041    0.570627    0.046298    0.015203    0.653118    
#> 158: 0.685720    1.023897    3.450987    0.547911    0.048429    0.014911    0.629080    
#> 159: 0.685718    1.016513    3.462115    0.560645    0.050819    0.012735    0.634607    
#> 160: 0.758375    0.991371    3.475953    0.679355    0.053316    0.014498    0.643896    
#> 161: 0.739506    0.994571    3.473040    0.618792    0.053000    0.015406    0.648360    
#> 162: 0.713722    0.979112    3.455758    0.571124    0.051113    0.015151    0.648312    
#> 163: 0.707820    0.983207    3.455733    0.639009    0.051647    0.014724    0.643298    
#> 164: 0.732395    1.007770    3.469796    0.629918    0.042434    0.019516    0.619974    
#> 165: 0.697829    0.987908    3.455301    0.667133    0.049240    0.016644    0.615993    
#> 166: 0.721480    1.020799    3.451895    0.590346    0.041002    0.012300    0.640339    
#> 167: 0.762930    1.023235    3.456802    0.615068    0.040074    0.015355    0.650261    
#> 168: 0.710642    1.029495    3.458094    0.553550    0.038442    0.014352    0.627688    
#> 169: 0.655389    1.038457    3.447704    0.479415    0.043239    0.015315    0.627040    
#> 170: 0.671267    1.020283    3.449767    0.531842    0.041428    0.016681    0.601168    
#> 171: 0.671763    1.023219    3.448606    0.548494    0.045668    0.014794    0.614866    
#> 172: 0.684885    1.021294    3.444745    0.655363    0.043892    0.014392    0.621319    
#> 173: 0.682490    1.030162    3.440579    0.548532    0.037455    0.016967    0.619453    
#> 174: 0.704343    1.012450    3.464552    0.594157    0.038474    0.017708    0.614950    
#> 175: 0.687811    1.003006    3.453815    0.552654    0.042894    0.018281    0.624843    
#> 176: 0.726349    1.015798    3.462199    0.666321    0.048830    0.015838    0.610993    
#> 177: 0.687848    1.010391    3.462884    0.593940    0.043193    0.017770    0.635016    
#> 178: 0.706945    1.003592    3.462078    0.615703    0.052318    0.016715    0.628980    
#> 179: 0.737451    1.018538    3.458229    0.569694    0.040948    0.016154    0.644907    
#> 180: 0.707235    1.002396    3.457557    0.618025    0.045503    0.015779    0.633863    
#> 181: 0.713080    0.987232    3.439081    0.672420    0.040563    0.012666    0.651937    
#> 182: 0.695403    0.990873    3.441103    0.601633    0.039344    0.013108    0.664002    
#> 183: 0.708315    1.017052    3.438027    0.599461    0.040760    0.013758    0.637847    
#> 184: 0.681287    1.009062    3.439495    0.624392    0.048586    0.013429    0.628850    
#> 185: 0.639697    1.031553    3.436268    0.500206    0.051259    0.019778    0.622527    
#> 186: 0.639914    1.037753    3.434415    0.472494    0.050295    0.020546    0.633749    
#> 187: 0.642886    1.004992    3.452517    0.459125    0.040401    0.025609    0.626210    
#> 188: 0.631462    1.020869    3.436368    0.487021    0.036120    0.027161    0.645306    
#> 189: 0.655563    1.022597    3.443224    0.585866    0.037393    0.024066    0.638375    
#> 190: 0.648439    1.013990    3.451008    0.528387    0.037212    0.021363    0.631345    
#> 191: 0.655553    1.027908    3.438395    0.566843    0.032481    0.021941    0.616583    
#> 192: 0.637609    1.024030    3.437941    0.580822    0.037655    0.020688    0.623607    
#> 193: 0.689067    1.028466    3.444104    0.546949    0.044316    0.016996    0.625758    
#> 194: 0.654758    1.025379    3.444384    0.508561    0.041816    0.016536    0.636966    
#> 195: 0.613107    1.027341    3.438650    0.460399    0.034544    0.016203    0.627620    
#> 196: 0.634615    1.020107    3.441979    0.476138    0.031240    0.018401    0.632818    
#> 197: 0.642897    1.023707    3.460023    0.529056    0.037418    0.019277    0.630634    
#> 198: 0.667024    1.006929    3.449004    0.516984    0.039147    0.018165    0.610654    
#> 199: 0.687319    0.993666    3.449382    0.617088    0.038498    0.015298    0.606262    
#> 200: 0.650314    0.996932    3.454382    0.442483    0.040449    0.013769    0.626266    
#> 201: 0.644621    0.995497    3.457467    0.441340    0.040432    0.014312    0.628647    
#> 202: 0.654082    0.997607    3.459179    0.468518    0.039755    0.014757    0.630501    
#> 203: 0.669226    0.995006    3.459541    0.487500    0.038912    0.015298    0.629118    
#> 204: 0.677660    0.990771    3.462448    0.517338    0.039699    0.015408    0.630224    
#> 205: 0.678616    0.995203    3.461632    0.522489    0.040675    0.015321    0.633873    
#> 206: 0.682217    0.999135    3.461951    0.530627    0.041179    0.015098    0.636474    
#> 207: 0.680159    0.999001    3.460325    0.524007    0.041708    0.014840    0.638224    
#> 208: 0.680888    0.998580    3.460492    0.524158    0.041980    0.014849    0.637895    
#> 209: 0.684792    0.996748    3.460700    0.528255    0.042560    0.014794    0.638003    
#> 210: 0.685973    0.995551    3.461474    0.526031    0.042756    0.014795    0.637066    
#> 211: 0.688938    0.996395    3.461375    0.524278    0.042792    0.015002    0.635883    
#> 212: 0.689607    0.995553    3.461544    0.527862    0.042299    0.015325    0.635351    
#> 213: 0.692771    0.992829    3.462191    0.539961    0.041884    0.015703    0.635074    
#> 214: 0.696652    0.990957    3.462864    0.549213    0.041901    0.015942    0.633711    
#> 215: 0.697441    0.990383    3.463297    0.552150    0.042138    0.016203    0.632941    
#> 216: 0.703774    0.988069    3.464281    0.554433    0.042474    0.016345    0.635036    
#> 217: 0.705589    0.987462    3.464848    0.555581    0.042033    0.016488    0.633763    
#> 218: 0.708302    0.988196    3.464777    0.560079    0.041536    0.016485    0.632837    
#> 219: 0.706121    0.988176    3.463867    0.555351    0.041436    0.016534    0.633021    
#> 220: 0.704031    0.988353    3.463324    0.554202    0.041116    0.016456    0.633467    
#> 221: 0.703056    0.988708    3.462676    0.553877    0.040833    0.016428    0.633539    
#> 222: 0.702057    0.989314    3.462219    0.552354    0.040611    0.016534    0.633352    
#> 223: 0.701255    0.989783    3.461933    0.551576    0.040370    0.016704    0.632593    
#> 224: 0.702885    0.990944    3.462049    0.552382    0.040167    0.016749    0.632385    
#> 225: 0.702168    0.990560    3.462515    0.547851    0.040401    0.016758    0.632849    
#> 226: 0.700942    0.990004    3.462263    0.545543    0.040430    0.016698    0.633033    
#> 227: 0.698859    0.990056    3.461946    0.542033    0.040413    0.016626    0.632919    
#> 228: 0.697839    0.990708    3.461581    0.538707    0.040437    0.016569    0.633118    
#> 229: 0.696954    0.990916    3.461424    0.538049    0.040379    0.016545    0.632530    
#> 230: 0.697970    0.990958    3.461326    0.538746    0.040369    0.016440    0.632393    
#> 231: 0.699116    0.991346    3.461357    0.540674    0.040757    0.016393    0.632294    
#> 232: 0.699094    0.991331    3.461309    0.543975    0.041158    0.016360    0.631934    
#> 233: 0.698763    0.990664    3.461407    0.543866    0.041521    0.016370    0.632021    
#> 234: 0.698890    0.990685    3.461330    0.541708    0.041727    0.016395    0.632239    
#> 235: 0.697813    0.990950    3.461022    0.538275    0.041879    0.016285    0.632608    
#> 236: 0.696371    0.991506    3.460548    0.536596    0.042078    0.016210    0.632890    
#> 237: 0.695781    0.991954    3.460229    0.537547    0.042170    0.016148    0.633246    
#> 238: 0.695642    0.992511    3.460131    0.536881    0.042304    0.016062    0.633882    
#> 239: 0.695258    0.993368    3.459877    0.537180    0.042402    0.016002    0.633776    
#> 240: 0.695274    0.993858    3.459856    0.535861    0.042511    0.015913    0.633577    
#> 241: 0.695031    0.993745    3.459982    0.535100    0.042581    0.015832    0.633357    
#> 242: 0.694658    0.993540    3.459755    0.535987    0.042584    0.015765    0.633453    
#> 243: 0.693803    0.994011    3.459446    0.535913    0.042567    0.015763    0.633539    
#> 244: 0.693531    0.994092    3.459307    0.537523    0.042524    0.015747    0.633744    
#> 245: 0.693673    0.993874    3.459392    0.537329    0.042504    0.015794    0.634305    
#> 246: 0.694111    0.993726    3.459357    0.537175    0.042374    0.015804    0.634763    
#> 247: 0.694213    0.993548    3.459561    0.537883    0.042290    0.015873    0.634652    
#> 248: 0.694178    0.993976    3.459317    0.540047    0.042394    0.015882    0.634081    
#> 249: 0.693325    0.994402    3.459061    0.540638    0.042576    0.015890    0.633745    
#> 250: 0.693038    0.994866    3.459065    0.540789    0.042554    0.015913    0.633728    
#> 251: 0.693803    0.995524    3.459179    0.543260    0.042635    0.015855    0.633496    
#> 252: 0.694476    0.995923    3.459487    0.543388    0.042701    0.015858    0.633646    
#> 253: 0.694496    0.996127    3.459570    0.544656    0.042739    0.015872    0.633587    
#> 254: 0.694535    0.996567    3.459458    0.545291    0.042690    0.015852    0.633525    
#> 255: 0.694555    0.996721    3.459390    0.546996    0.042655    0.015851    0.633546    
#> 256: 0.694965    0.996556    3.459405    0.549237    0.042519    0.015870    0.633827    
#> 257: 0.694980    0.996339    3.459349    0.549641    0.042341    0.015905    0.634015    
#> 258: 0.694683    0.996046    3.459321    0.550383    0.042353    0.015965    0.634053    
#> 259: 0.694869    0.996015    3.459324    0.550961    0.042489    0.016058    0.634059    
#> 260: 0.695024    0.996381    3.459480    0.550928    0.042574    0.016091    0.633850    
#> 261: 0.694996    0.996541    3.459539    0.550594    0.042628    0.016132    0.633855    
#> 262: 0.694802    0.997084    3.459628    0.549828    0.042794    0.016146    0.633719    
#> 263: 0.694194    0.997422    3.459669    0.548391    0.042897    0.016145    0.633540    
#> 264: 0.693488    0.997686    3.459510    0.547586    0.043111    0.016096    0.633390    
#> 265: 0.693146    0.997826    3.459393    0.547219    0.043217    0.016103    0.633256    
#> 266: 0.692740    0.998183    3.459339    0.546484    0.043259    0.016138    0.633100    
#> 267: 0.692923    0.998013    3.459515    0.546498    0.043224    0.016166    0.633314    
#> 268: 0.693289    0.997661    3.459527    0.547764    0.043195    0.016128    0.633413    
#> 269: 0.693967    0.997389    3.459585    0.550120    0.043165    0.016115    0.633531    
#> 270: 0.694561    0.997464    3.459447    0.552211    0.043224    0.016069    0.633242    
#> 271: 0.694641    0.997536    3.459317    0.552836    0.043237    0.016031    0.633142    
#> 272: 0.694743    0.997474    3.459236    0.552256    0.043192    0.016037    0.633387    
#> 273: 0.694195    0.997694    3.459186    0.552084    0.043141    0.016015    0.633558    
#> 274: 0.693657    0.997849    3.459204    0.550622    0.043111    0.016011    0.633236    
#> 275: 0.693884    0.997970    3.459173    0.551497    0.042977    0.016008    0.633039    
#> 276: 0.693508    0.998166    3.459188    0.550874    0.042931    0.016049    0.632956    
#> 277: 0.693184    0.998536    3.459131    0.550410    0.042923    0.016037    0.633070    
#> 278: 0.692332    0.998657    3.459115    0.549349    0.043069    0.015997    0.633168    
#> 279: 0.692301    0.998570    3.459063    0.550294    0.043195    0.016006    0.633099    
#> 280: 0.692102    0.998815    3.458927    0.550463    0.043313    0.016036    0.632794    
#> 281: 0.691800    0.998931    3.458788    0.551519    0.043384    0.016054    0.632658    
#> 282: 0.691541    0.999300    3.458664    0.552343    0.043459    0.016045    0.632610    
#> 283: 0.691552    0.999625    3.458541    0.553475    0.043519    0.016032    0.632805    
#> 284: 0.690843    0.999636    3.458305    0.554320    0.043533    0.016047    0.632652    
#> 285: 0.690420    0.999745    3.458135    0.553713    0.043598    0.016047    0.632646    
#> 286: 0.690225    0.999975    3.457988    0.553493    0.043526    0.016050    0.632742    
#> 287: 0.689795    1.000236    3.457883    0.553051    0.043505    0.016066    0.632847    
#> 288: 0.689672    1.000323    3.457854    0.552330    0.043474    0.016092    0.632958    
#> 289: 0.689693    1.000423    3.457828    0.551739    0.043395    0.016107    0.632987    
#> 290: 0.689640    1.000598    3.457841    0.551127    0.043460    0.016131    0.633115    
#> 291: 0.689890    1.000832    3.457851    0.551170    0.043446    0.016144    0.632890    
#> 292: 0.690057    1.000964    3.457753    0.551714    0.043343    0.016159    0.632645    
#> 293: 0.690064    1.000964    3.457709    0.552741    0.043271    0.016180    0.632507    
#> 294: 0.689952    1.001145    3.457564    0.552931    0.043238    0.016205    0.632251    
#> 295: 0.689644    1.001076    3.457510    0.552944    0.043185    0.016222    0.632062    
#> 296: 0.689473    1.001129    3.457407    0.552314    0.043175    0.016242    0.632016    
#> 297: 0.689365    1.001254    3.457384    0.552525    0.043156    0.016258    0.631922    
#> 298: 0.689522    1.001198    3.457355    0.552921    0.043093    0.016248    0.631781    
#> 299: 0.689742    1.001317    3.457275    0.553853    0.043076    0.016250    0.631663    
#> 300: 0.690007    1.001285    3.457317    0.554486    0.043021    0.016290    0.631404    
#> 301: 0.690222    1.001201    3.457219    0.555076    0.043024    0.016331    0.631350    
#> 302: 0.690744    1.001215    3.457232    0.555990    0.043054    0.016336    0.631268    
#> 303: 0.690861    1.001389    3.457192    0.556076    0.043204    0.016336    0.631090    
#> 304: 0.690899    1.001595    3.457010    0.556902    0.043371    0.016351    0.631063    
#> 305: 0.690713    1.001451    3.456887    0.556996    0.043446    0.016377    0.631017    
#> 306: 0.690407    1.001411    3.456758    0.556919    0.043530    0.016381    0.630906    
#> 307: 0.690055    1.001404    3.456678    0.556455    0.043625    0.016389    0.630965    
#> 308: 0.689954    1.001446    3.456549    0.557620    0.043726    0.016411    0.630900    
#> 309: 0.689797    1.001389    3.456407    0.558471    0.043668    0.016440    0.631051    
#> 310: 0.689960    1.001282    3.456243    0.559061    0.043569    0.016463    0.631052    
#> 311: 0.690158    1.001244    3.456168    0.560179    0.043537    0.016506    0.631011    
#> 312: 0.690447    1.001054    3.456130    0.562104    0.043507    0.016547    0.631033    
#> 313: 0.690599    1.000849    3.456039    0.563062    0.043517    0.016602    0.631165    
#> 314: 0.690372    1.000807    3.455964    0.563576    0.043510    0.016634    0.631091    
#> 315: 0.689909    1.000826    3.455869    0.563578    0.043510    0.016657    0.630949    
#> 316: 0.690220    1.000857    3.455865    0.564225    0.043444    0.016682    0.630885    
#> 317: 0.690723    1.000856    3.455939    0.564827    0.043426    0.016701    0.630978    
#> 318: 0.690815    1.000920    3.455908    0.564864    0.043411    0.016686    0.630981    
#> 319: 0.691267    1.000895    3.455915    0.566321    0.043400    0.016705    0.630968    
#> 320: 0.690982    1.000999    3.455857    0.566414    0.043322    0.016704    0.631103    
#> 321: 0.690448    1.001083    3.455694    0.566119    0.043327    0.016677    0.631128    
#> 322: 0.690452    1.001143    3.455590    0.566609    0.043287    0.016668    0.631049    
#> 323: 0.689914    1.001271    3.455446    0.566609    0.043189    0.016675    0.631037    
#> 324: 0.690102    1.001420    3.455433    0.567517    0.043207    0.016693    0.630932    
#> 325: 0.690229    1.001694    3.455284    0.568846    0.043205    0.016682    0.630930    
#> 326: 0.690481    1.001625    3.455165    0.570728    0.043188    0.016668    0.630988    
#> 327: 0.690741    1.001674    3.455183    0.572187    0.043246    0.016663    0.631064    
#> 328: 0.691109    1.001753    3.455122    0.574096    0.043228    0.016642    0.631030    
#> 329: 0.691344    1.001905    3.455123    0.575282    0.043206    0.016603    0.631054    
#> 330: 0.691455    1.002012    3.455074    0.577061    0.043151    0.016583    0.631035    
#> 331: 0.691923    1.002180    3.455066    0.578050    0.043176    0.016581    0.630929    
#> 332: 0.692065    1.002187    3.455084    0.578715    0.043154    0.016568    0.630940    
#> 333: 0.691615    1.002277    3.454958    0.578176    0.043147    0.016571    0.630943    
#> 334: 0.691299    1.002317    3.454798    0.578485    0.043156    0.016578    0.630856    
#> 335: 0.691175    1.002370    3.454658    0.578946    0.043152    0.016595    0.630753    
#> 336: 0.690745    1.002532    3.454526    0.579125    0.043190    0.016601    0.630702    
#> 337: 0.690326    1.002791    3.454349    0.579655    0.043204    0.016603    0.630650    
#> 338: 0.690308    1.002952    3.454335    0.580383    0.043219    0.016603    0.630542    
#> 339: 0.690400    1.003005    3.454266    0.581229    0.043247    0.016607    0.630532    
#> 340: 0.690480    1.002905    3.454182    0.581841    0.043244    0.016607    0.630492    
#> 341: 0.690349    1.002745    3.454178    0.581714    0.043277    0.016623    0.630480    
#> 342: 0.689990    1.002537    3.454183    0.581536    0.043254    0.016632    0.630551    
#> 343: 0.689803    1.002452    3.454159    0.581411    0.043225    0.016627    0.630511    
#> 344: 0.689815    1.002437    3.454135    0.581634    0.043205    0.016617    0.630398    
#> 345: 0.689767    1.002510    3.454095    0.581757    0.043134    0.016611    0.630268    
#> 346: 0.689972    1.002559    3.454071    0.582645    0.043129    0.016605    0.630094    
#> 347: 0.690223    1.002448    3.454023    0.582954    0.043127    0.016604    0.630033    
#> 348: 0.690183    1.002487    3.453911    0.583478    0.043151    0.016613    0.629989    
#> 349: 0.690161    1.002408    3.453861    0.584106    0.043158    0.016607    0.630009    
#> 350: 0.689928    1.002371    3.453833    0.583988    0.043202    0.016583    0.630029    
#> 351: 0.689667    1.002453    3.453732    0.583590    0.043230    0.016553    0.630086    
#> 352: 0.689167    1.002611    3.453698    0.582944    0.043226    0.016554    0.630137    
#> 353: 0.689186    1.002806    3.453627    0.583483    0.043227    0.016561    0.630143    
#> 354: 0.689010    1.002876    3.453487    0.583089    0.043291    0.016560    0.630129    
#> 355: 0.689205    1.002848    3.453446    0.583118    0.043374    0.016557    0.630136    
#> 356: 0.689012    1.002792    3.453470    0.582571    0.043362    0.016546    0.630273    
#> 357: 0.689141    1.002831    3.453505    0.582657    0.043311    0.016542    0.630223    
#> 358: 0.689287    1.002814    3.453577    0.582471    0.043320    0.016550    0.630162    
#> 359: 0.689124    1.002976    3.453553    0.582422    0.043318    0.016559    0.630050    
#> 360: 0.688917    1.003022    3.453475    0.581840    0.043297    0.016563    0.629951    
#> 361: 0.688793    1.003178    3.453408    0.581531    0.043334    0.016557    0.629838    
#> 362: 0.688799    1.003218    3.453417    0.581248    0.043356    0.016534    0.629697    
#> 363: 0.688929    1.003191    3.453456    0.581725    0.043372    0.016512    0.629537    
#> 364: 0.689141    1.003218    3.453428    0.582448    0.043383    0.016512    0.629416    
#> 365: 0.689171    1.003234    3.453389    0.582854    0.043403    0.016528    0.629366    
#> 366: 0.689068    1.003360    3.453263    0.582901    0.043413    0.016539    0.629356    
#> 367: 0.689075    1.003447    3.453159    0.582949    0.043424    0.016537    0.629349    
#> 368: 0.689291    1.003525    3.453090    0.582930    0.043403    0.016540    0.629292    
#> 369: 0.689374    1.003535    3.453026    0.583329    0.043377    0.016554    0.629247    
#> 370: 0.689289    1.003606    3.452952    0.583094    0.043433    0.016580    0.629263    
#> 371: 0.688874    1.003648    3.452797    0.582676    0.043457    0.016578    0.629229    
#> 372: 0.688356    1.003773    3.452656    0.582613    0.043491    0.016565    0.629171    
#> 373: 0.687892    1.003958    3.452532    0.582368    0.043470    0.016583    0.629153    
#> 374: 0.687649    1.004035    3.452408    0.582528    0.043451    0.016614    0.629054    
#> 375: 0.687558    1.004122    3.452312    0.583404    0.043449    0.016653    0.628886    
#> 376: 0.687377    1.004220    3.452253    0.583696    0.043400    0.016682    0.628695    
#> 377: 0.687180    1.004289    3.452190    0.583593    0.043357    0.016696    0.628608    
#> 378: 0.687032    1.004269    3.452139    0.583698    0.043289    0.016686    0.628644    
#> 379: 0.686865    1.004167    3.452134    0.583493    0.043262    0.016675    0.628641    
#> 380: 0.686912    1.004078    3.452186    0.583359    0.043191    0.016692    0.628670    
#> 381: 0.686830    1.004042    3.452201    0.583096    0.043124    0.016715    0.628595    
#> 382: 0.687002    1.003978    3.452262    0.583463    0.043075    0.016718    0.628418    
#> 383: 0.687126    1.003897    3.452300    0.584175    0.043010    0.016733    0.628331    
#> 384: 0.687066    1.003904    3.452333    0.584467    0.042977    0.016749    0.628268    
#> 385: 0.687131    1.003865    3.452343    0.584670    0.042942    0.016764    0.628235    
#> 386: 0.687250    1.003983    3.452390    0.584887    0.042948    0.016789    0.628224    
#> 387: 0.687403    1.004033    3.452490    0.584707    0.042911    0.016836    0.628152    
#> 388: 0.687498    1.004057    3.452556    0.584472    0.042932    0.016872    0.627981    
#> 389: 0.687379    1.003896    3.452537    0.584210    0.042965    0.016897    0.627969    
#> 390: 0.687070    1.003977    3.452468    0.583935    0.042964    0.016900    0.628010    
#> 391: 0.687108    1.003942    3.452423    0.584345    0.042939    0.016901    0.627945    
#> 392: 0.687222    1.003953    3.452465    0.584920    0.042889    0.016896    0.628036    
#> 393: 0.687480    1.003887    3.452466    0.585462    0.042921    0.016897    0.627972    
#> 394: 0.687773    1.003848    3.452471    0.586226    0.042899    0.016902    0.627977    
#> 395: 0.688036    1.003913    3.452458    0.587488    0.042873    0.016905    0.627941    
#> 396: 0.688230    1.003952    3.452397    0.588617    0.042875    0.016915    0.627886    
#> 397: 0.688354    1.003905    3.452374    0.589092    0.042833    0.016931    0.627937    
#> 398: 0.688621    1.003859    3.452436    0.589222    0.042802    0.016943    0.627970    
#> 399: 0.688739    1.003844    3.452494    0.589219    0.042780    0.016942    0.627992    
#> 400: 0.688913    1.003937    3.452520    0.589272    0.042773    0.016946    0.627959    
#> 401: 0.689063    1.004071    3.452502    0.589104    0.042778    0.016948    0.627966    
#> 402: 0.689082    1.004269    3.452472    0.588938    0.042771    0.016945    0.628006    
#> 403: 0.689157    1.004377    3.452431    0.589095    0.042809    0.016926    0.627949    
#> 404: 0.689025    1.004472    3.452321    0.589540    0.042820    0.016926    0.627817    
#> 405: 0.688793    1.004614    3.452239    0.589696    0.042844    0.016928    0.627811    
#> 406: 0.688536    1.004800    3.452151    0.589537    0.042897    0.016936    0.627868    
#> 407: 0.688490    1.004873    3.452157    0.589743    0.042920    0.016931    0.627851    
#> 408: 0.688461    1.005016    3.452109    0.589344    0.042992    0.016909    0.627894    
#> 409: 0.688429    1.005013    3.452057    0.589109    0.043019    0.016891    0.627856    
#> 410: 0.688325    1.005034    3.452032    0.588930    0.043001    0.016891    0.627803    
#> 411: 0.688517    1.004929    3.452072    0.589162    0.042939    0.016887    0.627877    
#> 412: 0.688577    1.004975    3.452047    0.589100    0.042916    0.016882    0.627900    
#> 413: 0.688645    1.004997    3.452009    0.589254    0.042903    0.016877    0.627918    
#> 414: 0.688452    1.005009    3.452008    0.589609    0.042885    0.016872    0.627899    
#> 415: 0.688624    1.004940    3.452026    0.589661    0.042856    0.016878    0.627868    
#> 416: 0.688791    1.004956    3.452053    0.589897    0.042855    0.016887    0.627851    
#> 417: 0.688899    1.004953    3.452038    0.589907    0.042858    0.016893    0.627875    
#> 418: 0.688722    1.004945    3.452045    0.589474    0.042825    0.016892    0.627842    
#> 419: 0.688739    1.005028    3.452055    0.589310    0.042816    0.016903    0.627842    
#> 420: 0.688939    1.005076    3.452070    0.589535    0.042807    0.016897    0.627832    
#> 421: 0.688840    1.005160    3.452102    0.589490    0.042795    0.016902    0.627868    
#> 422: 0.688979    1.005088    3.452131    0.589803    0.042761    0.016897    0.627928    
#> 423: 0.689052    1.005017    3.452130    0.589942    0.042740    0.016886    0.627928    
#> 424: 0.688909    1.004957    3.452074    0.589651    0.042699    0.016879    0.627918    
#> 425: 0.688832    1.004950    3.452070    0.589514    0.042659    0.016888    0.627952    
#> 426: 0.689031    1.004985    3.452074    0.590208    0.042655    0.016910    0.627927    
#> 427: 0.688992    1.005050    3.452065    0.590722    0.042663    0.016927    0.627828    
#> 428: 0.688872    1.005137    3.452067    0.590753    0.042680    0.016942    0.627833    
#> 429: 0.688784    1.005221    3.452062    0.590417    0.042670    0.016946    0.627855    
#> 430: 0.688670    1.005228    3.452033    0.590132    0.042638    0.016954    0.627891    
#> 431: 0.688718    1.005223    3.451993    0.590275    0.042605    0.016959    0.627773    
#> 432: 0.688631    1.005283    3.451962    0.590465    0.042559    0.016973    0.627695    
#> 433: 0.688557    1.005437    3.451938    0.590506    0.042563    0.016990    0.627656    
#> 434: 0.688309    1.005412    3.451884    0.590320    0.042539    0.017006    0.627609    
#> 435: 0.688278    1.005399    3.451815    0.590377    0.042520    0.017021    0.627558    
#> 436: 0.688295    1.005301    3.451826    0.590942    0.042496    0.017034    0.627587    
#> 437: 0.688387    1.005260    3.451772    0.591562    0.042494    0.017038    0.627629    
#> 438: 0.688275    1.005430    3.451724    0.591911    0.042496    0.017029    0.627591    
#> 439: 0.688128    1.005563    3.451666    0.591873    0.042490    0.017018    0.627583    
#> 440: 0.688049    1.005748    3.451621    0.591539    0.042456    0.017014    0.627656    
#> 441: 0.688125    1.005767    3.451611    0.591781    0.042416    0.017020    0.627650    
#> 442: 0.687859    1.005847    3.451567    0.591610    0.042395    0.017022    0.627610    
#> 443: 0.687774    1.006021    3.451487    0.591583    0.042410    0.017009    0.627581    
#> 444: 0.687790    1.006059    3.451436    0.591691    0.042446    0.016995    0.627590    
#> 445: 0.687787    1.006044    3.451424    0.591877    0.042486    0.016995    0.627592    
#> 446: 0.687627    1.006045    3.451380    0.591832    0.042494    0.016993    0.627516    
#> 447: 0.687702    1.006072    3.451386    0.592164    0.042506    0.017010    0.627497    
#> 448: 0.687685    1.006060    3.451395    0.592268    0.042508    0.017016    0.627448    
#> 449: 0.687713    1.006131    3.451464    0.591990    0.042520    0.017024    0.627420    
#> 450: 0.687552    1.006152    3.451460    0.591707    0.042519    0.017025    0.627432    
#> 451: 0.687459    1.006201    3.451453    0.591504    0.042504    0.017024    0.627498    
#> 452: 0.687339    1.006201    3.451424    0.591329    0.042486    0.017029    0.627522    
#> 453: 0.687222    1.006241    3.451400    0.591018    0.042451    0.017045    0.627528    
#> 454: 0.687233    1.006357    3.451364    0.591576    0.042405    0.017042    0.627523    
#> 455: 0.687470    1.006371    3.451351    0.592386    0.042396    0.017040    0.627546    
#> 456: 0.687444    1.006357    3.451335    0.592598    0.042393    0.017048    0.627590    
#> 457: 0.687613    1.006339    3.451372    0.593257    0.042376    0.017052    0.627545    
#> 458: 0.687765    1.006400    3.451410    0.593582    0.042359    0.017057    0.627459    
#> 459: 0.687610    1.006468    3.451435    0.593451    0.042362    0.017066    0.627423    
#> 460: 0.687350    1.006527    3.451377    0.593312    0.042340    0.017064    0.627390    
#> 461: 0.687318    1.006552    3.451399    0.593288    0.042347    0.017060    0.627388    
#> 462: 0.687228    1.006624    3.451402    0.593098    0.042343    0.017059    0.627369    
#> 463: 0.687110    1.006697    3.451403    0.592954    0.042321    0.017055    0.627390    
#> 464: 0.687073    1.006784    3.451348    0.593014    0.042328    0.017047    0.627305    
#> 465: 0.687090    1.006744    3.451320    0.593222    0.042336    0.017044    0.627209    
#> 466: 0.687042    1.006836    3.451251    0.592920    0.042327    0.017046    0.627207    
#> 467: 0.687043    1.006820    3.451243    0.593021    0.042304    0.017045    0.627179    
#> 468: 0.687195    1.006768    3.451314    0.593115    0.042286    0.017069    0.627201    
#> 469: 0.687386    1.006803    3.451342    0.593286    0.042276    0.017088    0.627233    
#> 470: 0.687275    1.006821    3.451300    0.593122    0.042255    0.017109    0.627283    
#> 471: 0.687139    1.006883    3.451263    0.592947    0.042244    0.017121    0.627298    
#> 472: 0.687108    1.006885    3.451287    0.592780    0.042239    0.017142    0.627282    
#> 473: 0.687057    1.006905    3.451316    0.592513    0.042225    0.017151    0.627254    
#> 474: 0.686914    1.006956    3.451316    0.591808    0.042232    0.017157    0.627330    
#> 475: 0.687027    1.006999    3.451341    0.591610    0.042236    0.017151    0.627342    
#> 476: 0.687094    1.006995    3.451372    0.591641    0.042253    0.017153    0.627318    
#> 477: 0.687214    1.006957    3.451447    0.591537    0.042274    0.017165    0.627232    
#> 478: 0.687157    1.006938    3.451455    0.591686    0.042292    0.017181    0.627247    
#> 479: 0.687337    1.006985    3.451435    0.592360    0.042326    0.017189    0.627230    
#> 480: 0.687377    1.007072    3.451393    0.592866    0.042328    0.017188    0.627273    
#> 481: 0.687315    1.007147    3.451342    0.593138    0.042322    0.017187    0.627311    
#> 482: 0.687210    1.007274    3.451267    0.593198    0.042308    0.017197    0.627290    
#> 483: 0.687053    1.007327    3.451223    0.593442    0.042288    0.017197    0.627328    
#> 484: 0.686960    1.007243    3.451229    0.593531    0.042251    0.017201    0.627351    
#> 485: 0.686937    1.007250    3.451202    0.593978    0.042236    0.017208    0.627358    
#> 486: 0.686818    1.007237    3.451176    0.594303    0.042235    0.017205    0.627330    
#> 487: 0.686861    1.007232    3.451180    0.594758    0.042253    0.017191    0.627390    
#> 488: 0.686868    1.007237    3.451178    0.595042    0.042238    0.017187    0.627384    
#> 489: 0.686948    1.007244    3.451150    0.595166    0.042237    0.017180    0.627367    
#> 490: 0.686905    1.007285    3.451138    0.594915    0.042237    0.017189    0.627333    
#> 491: 0.686826    1.007351    3.451147    0.594845    0.042220    0.017194    0.627306    
#> 492: 0.686663    1.007393    3.451114    0.594608    0.042202    0.017209    0.627308    
#> 493: 0.686486    1.007463    3.451101    0.594428    0.042184    0.017230    0.627280    
#> 494: 0.686559    1.007457    3.451110    0.594273    0.042146    0.017253    0.627228    
#> 495: 0.686677    1.007464    3.451104    0.594454    0.042106    0.017262    0.627181    
#> 496: 0.686740    1.007496    3.451098    0.594117    0.042102    0.017271    0.627205    
#> 497: 0.686671    1.007457    3.451129    0.593651    0.042095    0.017266    0.627238    
#> 498: 0.686617    1.007444    3.451107    0.593299    0.042107    0.017271    0.627189    
#> 499: 0.686483    1.007499    3.451062    0.593185    0.042088    0.017271    0.627143    
#> 500: 0.686555    1.007508    3.451022    0.593442    0.042057    0.017276    0.627112    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.316239    0.969530    3.436277    0.392401    0.081349    0.016800    1.762982    
#> 002: 0.405718    0.976189    3.440080    0.372781    0.077281    0.015960    1.231243    
#> 003: 0.499794    0.922964    3.418000    0.354142    0.073417    0.015162    0.971045    
#> 004: 0.442476    0.918707    3.418345    0.336435    0.069746    0.014404    0.900427    
#> 005: 0.495376    0.952675    3.410926    0.319613    0.066259    0.013684    0.848062    
#> 006: 0.438634    0.972409    3.389833    0.303633    0.068647    0.013000    0.800758    
#> 007: 0.404312    0.953226    3.387785    0.299102    0.076902    0.012350    0.809768    
#> 008: 0.377523    0.949879    3.376161    0.284147    0.073057    0.012984    0.808068    
#> 009: 0.353900    0.949746    3.372342    0.269940    0.069404    0.012642    0.815423    
#> 010: 0.399391    0.933856    3.381031    0.256443    0.065934    0.015642    0.840772    
#> 011: 0.487943    0.932739    3.400668    0.254137    0.062637    0.014860    0.848263    
#> 012: 0.433597    0.937483    3.387123    0.263220    0.059505    0.014117    0.815170    
#> 013: 0.399977    0.948228    3.378706    0.250059    0.061088    0.015423    0.805565    
#> 014: 0.440832    0.918433    3.402056    0.347354    0.058034    0.019000    0.832367    
#> 015: 0.432491    0.933801    3.399090    0.329987    0.055132    0.018050    0.803656    
#> 016: 0.447353    0.947989    3.418177    0.313487    0.052375    0.017147    0.818406    
#> 017: 0.494470    0.947354    3.414665    0.331472    0.049757    0.016290    0.791322    
#> 018: 0.481053    0.951958    3.403663    0.314898    0.052951    0.015476    0.816881    
#> 019: 0.443662    0.944638    3.397403    0.299558    0.050304    0.014702    0.812960    
#> 020: 0.455480    0.932457    3.400760    0.284580    0.051739    0.014575    0.815347    
#> 021: 0.445578    0.926549    3.401785    0.314357    0.065174    0.016606    0.793461    
#> 022: 0.472057    0.922351    3.416592    0.352744    0.070379    0.015776    0.775293    
#> 023: 0.566169    0.916598    3.425220    0.335106    0.078443    0.014987    0.815316    
#> 024: 0.536857    0.960975    3.421867    0.318351    0.074521    0.014238    0.820673    
#> 025: 0.513639    0.916547    3.425284    0.302434    0.070795    0.013526    0.833205    
#> 026: 0.488629    0.947226    3.400980    0.289448    0.067255    0.012850    0.808458    
#> 027: 0.463125    0.958229    3.400132    0.317832    0.063892    0.015707    0.816953    
#> 028: 0.473959    0.956042    3.412602    0.312188    0.060698    0.014922    0.804138    
#> 029: 0.515715    0.944673    3.404978    0.296579    0.063155    0.014176    0.848937    
#> 030: 0.461893    0.961640    3.395497    0.281750    0.059997    0.016854    0.814545    
#> 031: 0.434051    0.940534    3.412094    0.267662    0.062673    0.016011    0.818020    
#> 032: 0.449742    0.925627    3.411194    0.297548    0.065286    0.015210    0.789927    
#> 033: 0.473620    0.947765    3.410157    0.350030    0.077820    0.014450    0.793631    
#> 034: 0.487316    0.969521    3.413145    0.346099    0.073929    0.013727    0.802490    
#> 035: 0.445329    0.956505    3.403161    0.336000    0.070232    0.013041    0.813015    
#> 036: 0.390892    0.956776    3.390061    0.319200    0.083265    0.012389    0.827439    
#> 037: 0.440507    0.974422    3.400481    0.303240    0.083259    0.011770    0.823343    
#> 038: 0.503376    0.953280    3.400158    0.368501    0.090872    0.011181    0.784581    
#> 039: 0.478002    0.930161    3.414737    0.350076    0.086328    0.010622    0.792404    
#> 040: 0.463539    0.937394    3.420762    0.332572    0.082012    0.011474    0.815352    
#> 041: 0.453455    0.911301    3.412290    0.315943    0.077911    0.011011    0.804898    
#> 042: 0.492495    0.916787    3.418695    0.308511    0.074016    0.010461    0.812266    
#> 043: 0.437680    0.952559    3.406138    0.293086    0.070315    0.009938    0.821271    
#> 044: 0.432604    0.961574    3.398931    0.278432    0.066799    0.009441    0.805532    
#> 045: 0.455478    0.965513    3.398332    0.268529    0.063459    0.008969    0.804060    
#> 046: 0.465293    0.945001    3.406221    0.264942    0.073057    0.008552    0.800039    
#> 047: 0.487995    0.955050    3.398755    0.288418    0.072292    0.009531    0.788489    
#> 048: 0.482010    0.955937    3.396174    0.373433    0.069861    0.013980    0.773319    
#> 049: 0.464559    0.938774    3.404427    0.354761    0.069449    0.013281    0.788121    
#> 050: 0.506845    0.914961    3.406660    0.337023    0.066011    0.012617    0.822435    
#> 051: 0.487843    0.931464    3.405191    0.320172    0.069576    0.011986    0.822945    
#> 052: 0.498690    0.945915    3.413691    0.369834    0.071053    0.012737    0.803300    
#> 053: 0.499235    0.939461    3.406710    0.453793    0.070736    0.012100    0.800214    
#> 054: 0.470508    0.923613    3.413173    0.431104    0.073946    0.016502    0.805563    
#> 055: 0.460473    0.936803    3.407891    0.409548    0.081829    0.015677    0.802228    
#> 056: 0.481665    0.920732    3.420808    0.389071    0.081086    0.014893    0.833820    
#> 057: 0.462970    0.924552    3.416809    0.381970    0.090249    0.014148    0.802548    
#> 058: 0.507369    0.917541    3.400800    0.362871    0.085737    0.013441    0.812177    
#> 059: 0.489479    0.907809    3.408173    0.398690    0.097907    0.015167    0.807805    
#> 060: 0.512680    0.915928    3.424600    0.443583    0.093011    0.014409    0.837297    
#> 061: 0.570432    0.916229    3.428659    0.480259    0.088361    0.015582    0.818440    
#> 062: 0.492145    0.940765    3.431307    0.456246    0.083943    0.018813    0.838851    
#> 063: 0.532137    0.889714    3.430602    0.433434    0.079745    0.017873    0.861393    
#> 064: 0.480538    0.912719    3.426350    0.411762    0.075758    0.016979    0.847406    
#> 065: 0.548590    0.931687    3.410138    0.391174    0.071970    0.017018    0.829734    
#> 066: 0.491445    0.957354    3.411920    0.371615    0.068372    0.016243    0.789989    
#> 067: 0.458039    0.937595    3.404019    0.362008    0.064953    0.015431    0.794989    
#> 068: 0.418385    0.949851    3.410815    0.343908    0.065132    0.014660    0.827562    
#> 069: 0.453060    0.958612    3.405973    0.326713    0.067898    0.013927    0.814011    
#> 070: 0.465845    0.950017    3.411999    0.334259    0.085022    0.013263    0.798531    
#> 071: 0.454930    0.973040    3.396936    0.335415    0.080770    0.012600    0.821897    
#> 072: 0.437806    0.920609    3.403708    0.335685    0.076732    0.014082    0.805651    
#> 073: 0.478629    0.936621    3.414672    0.318901    0.072895    0.014573    0.791595    
#> 074: 0.468928    0.926917    3.408234    0.328714    0.077424    0.013844    0.797812    
#> 075: 0.497717    0.909630    3.439625    0.312278    0.089404    0.013152    0.814850    
#> 076: 0.526296    0.929041    3.447216    0.296664    0.084934    0.012742    0.822545    
#> 077: 0.566122    0.911364    3.431287    0.285334    0.080687    0.017206    0.820513    
#> 078: 0.548934    0.905061    3.446428    0.278463    0.076653    0.016346    0.805164    
#> 079: 0.515529    0.906644    3.440776    0.312675    0.072820    0.015528    0.812155    
#> 080: 0.545625    0.897161    3.435227    0.397987    0.069179    0.014752    0.822959    
#> 081: 0.545426    0.913275    3.431753    0.380857    0.065720    0.014014    0.812415    
#> 082: 0.503139    0.926035    3.427903    0.361814    0.068303    0.013314    0.819443    
#> 083: 0.495616    0.943693    3.430425    0.343723    0.064888    0.012648    0.824118    
#> 084: 0.506953    0.944681    3.427577    0.326537    0.069582    0.012779    0.808724    
#> 085: 0.501885    0.965545    3.430762    0.310210    0.066103    0.012140    0.830022    
#> 086: 0.500837    0.942307    3.427017    0.294700    0.062798    0.012016    0.819064    
#> 087: 0.447879    0.946019    3.401513    0.279965    0.059658    0.013157    0.821290    
#> 088: 0.394742    0.929583    3.393830    0.265966    0.057432    0.013253    0.835695    
#> 089: 0.440339    0.948507    3.383462    0.288179    0.054933    0.013174    0.818948    
#> 090: 0.395756    0.945900    3.384473    0.326217    0.084838    0.012515    0.808444    
#> 091: 0.440980    0.934942    3.377307    0.372664    0.080596    0.011889    0.799783    
#> 092: 0.454780    0.960987    3.382924    0.368287    0.082247    0.011295    0.815428    
#> 093: 0.451455    0.937816    3.391903    0.349872    0.078707    0.012100    0.802018    
#> 094: 0.420492    0.946572    3.390355    0.332379    0.074772    0.011495    0.815741    
#> 095: 0.461967    0.950151    3.402776    0.365976    0.075097    0.011809    0.819269    
#> 096: 0.407739    0.944171    3.388637    0.358401    0.077205    0.012153    0.797759    
#> 097: 0.412055    0.968366    3.375570    0.340481    0.073345    0.012826    0.814345    
#> 098: 0.426856    0.971437    3.395441    0.323457    0.069678    0.012185    0.835026    
#> 099: 0.419196    0.954538    3.378219    0.400940    0.074676    0.011576    0.805167    
#> 100: 0.430868    0.969716    3.377450    0.380893    0.076334    0.011300    0.792576    
#> 101: 0.414374    0.962393    3.374626    0.361849    0.072517    0.012819    0.787099    
#> 102: 0.418793    0.958166    3.372466    0.343756    0.068892    0.012178    0.809634    
#> 103: 0.462127    0.955907    3.391807    0.344399    0.065447    0.011569    0.797516    
#> 104: 0.439563    0.959213    3.407293    0.376257    0.079795    0.010991    0.808027    
#> 105: 0.484946    0.948007    3.403739    0.417768    0.075806    0.010441    0.817161    
#> 106: 0.464639    0.958012    3.392267    0.396880    0.072015    0.010855    0.810767    
#> 107: 0.472535    0.949294    3.395990    0.377036    0.079300    0.010313    0.826495    
#> 108: 0.448764    0.959807    3.384541    0.358184    0.075335    0.009797    0.839441    
#> 109: 0.442952    0.942589    3.399426    0.340275    0.085811    0.009307    0.828405    
#> 110: 0.479836    0.936081    3.396241    0.323261    0.081521    0.008842    0.841769    
#> 111: 0.443844    0.943830    3.397452    0.307098    0.077445    0.008400    0.814292    
#> 112: 0.453436    0.912644    3.392499    0.301810    0.073573    0.007980    0.848980    
#> 113: 0.450547    0.945061    3.400793    0.286719    0.079333    0.007581    0.829906    
#> 114: 0.446051    0.946083    3.400067    0.272383    0.082512    0.007202    0.841298    
#> 115: 0.440218    0.947743    3.399729    0.258764    0.078386    0.006842    0.844346    
#> 116: 0.432367    0.953843    3.403705    0.245826    0.074467    0.007397    0.814823    
#> 117: 0.399377    0.962588    3.402564    0.254054    0.070744    0.009130    0.817868    
#> 118: 0.473014    0.938331    3.412776    0.312855    0.067206    0.009506    0.809559    
#> 119: 0.483882    0.934125    3.407728    0.395302    0.065544    0.009031    0.817266    
#> 120: 0.461065    0.928850    3.397961    0.375537    0.062267    0.010550    0.799632    
#> 121: 0.449772    0.944724    3.402632    0.356760    0.066246    0.010022    0.821166    
#> 122: 0.457808    0.912856    3.414259    0.338922    0.064357    0.009521    0.825851    
#> 123: 0.501361    0.941785    3.406822    0.321976    0.073043    0.009045    0.810285    
#> 124: 0.485518    0.969242    3.400342    0.305877    0.069390    0.008953    0.815328    
#> 125: 0.466660    0.965204    3.397004    0.290583    0.076534    0.008856    0.806719    
#> 126: 0.415357    0.968132    3.379627    0.295656    0.072707    0.011923    0.807563    
#> 127: 0.446150    0.962953    3.381686    0.280873    0.069072    0.011326    0.801727    
#> 128: 0.431922    0.935783    3.402755    0.294599    0.073615    0.012191    0.801121    
#> 129: 0.479246    0.962956    3.407380    0.320666    0.069934    0.011581    0.828655    
#> 130: 0.496849    0.955768    3.404517    0.304633    0.066438    0.012775    0.815274    
#> 131: 0.450518    0.927436    3.402643    0.289401    0.065185    0.012833    0.810529    
#> 132: 0.407149    0.941253    3.381933    0.276470    0.072464    0.012191    0.814388    
#> 133: 0.408401    0.928191    3.386610    0.304883    0.068841    0.011582    0.825518    
#> 134: 0.448733    0.915122    3.395825    0.289639    0.073354    0.011331    0.833028    
#> 135: 0.428520    0.940978    3.396936    0.283913    0.075862    0.010764    0.839865    
#> 136: 0.438944    0.911921    3.401996    0.332828    0.075748    0.010907    0.800053    
#> 137: 0.447996    0.922151    3.398053    0.316187    0.071960    0.010362    0.813369    
#> 138: 0.441109    0.935079    3.404332    0.304278    0.068362    0.009844    0.811528    
#> 139: 0.458122    0.940377    3.408649    0.299279    0.075823    0.010825    0.793523    
#> 140: 0.484325    0.966620    3.413219    0.390688    0.072032    0.011112    0.805098    
#> 141: 0.440044    0.941346    3.398031    0.371512    0.070496    0.010556    0.807074    
#> 142: 0.441781    0.941619    3.397786    0.352937    0.066971    0.010028    0.830999    
#> 143: 0.425934    0.948946    3.410002    0.335782    0.067618    0.009527    0.824808    
#> 144: 0.466498    0.945580    3.420178    0.318993    0.064237    0.009050    0.821697    
#> 145: 0.458848    0.969460    3.403699    0.303044    0.072035    0.008598    0.800151    
#> 146: 0.465477    0.966646    3.413024    0.287891    0.068720    0.008566    0.826507    
#> 147: 0.407823    0.927847    3.404884    0.273497    0.069170    0.008480    0.802034    
#> 148: 0.442765    0.941465    3.411208    0.268324    0.069529    0.008056    0.805770    
#> 149: 0.446194    0.934620    3.409585    0.274251    0.066052    0.007653    0.819530    
#> 150: 0.476757    0.931627    3.402857    0.267515    0.062750    0.007271    0.823662    
#> 151: 0.416094    0.960205    3.389349    0.254140    0.059893    0.007220    0.825760    
#> 152: 0.406944    0.967090    3.395250    0.225836    0.060504    0.006822    0.843095    
#> 153: 0.422868    0.971111    3.399095    0.255649    0.057237    0.007225    0.852866    
#> 154: 0.458251    0.987440    3.402756    0.243019    0.073347    0.009471    0.838680    
#> 155: 0.420846    0.947711    3.402256    0.222462    0.053919    0.008144    0.832520    
#> 156: 0.438908    0.973156    3.410324    0.172741    0.068703    0.006585    0.838532    
#> 157: 0.434673    0.947902    3.414663    0.191563    0.071726    0.005967    0.857279    
#> 158: 0.471910    0.970864    3.406425    0.226924    0.063810    0.006885    0.831109    
#> 159: 0.419976    0.970008    3.404899    0.239260    0.073728    0.006128    0.823046    
#> 160: 0.433766    0.945073    3.407904    0.264256    0.076561    0.006127    0.812477    
#> 161: 0.451498    0.950509    3.405450    0.253726    0.066338    0.006275    0.817036    
#> 162: 0.452496    0.961502    3.391681    0.235987    0.063773    0.005508    0.819992    
#> 163: 0.457247    0.946181    3.391115    0.288889    0.071700    0.004417    0.809513    
#> 164: 0.434960    0.947822    3.389438    0.316195    0.064237    0.005205    0.818096    
#> 165: 0.448812    0.935982    3.403154    0.253788    0.074388    0.006448    0.807104    
#> 166: 0.476194    0.973352    3.403331    0.286763    0.082677    0.005552    0.804709    
#> 167: 0.475068    0.961513    3.411965    0.308547    0.102143    0.004221    0.817596    
#> 168: 0.478143    0.957081    3.410448    0.265623    0.110380    0.002989    0.835533    
#> 169: 0.462975    0.959598    3.404471    0.234121    0.090712    0.003178    0.857093    
#> 170: 0.444521    0.947884    3.398785    0.254627    0.090210    0.003550    0.820769    
#> 171: 0.441443    0.947178    3.398526    0.244743    0.075880    0.003436    0.821708    
#> 172: 0.439269    0.956302    3.395713    0.241466    0.078442    0.002868    0.827373    
#> 173: 0.417837    0.959007    3.391993    0.239774    0.082181    0.002765    0.821341    
#> 174: 0.402276    0.941135    3.394439    0.205924    0.080972    0.002621    0.831233    
#> 175: 0.418685    0.954490    3.386839    0.234918    0.084052    0.003157    0.833211    
#> 176: 0.416681    0.974448    3.387725    0.186289    0.080428    0.002942    0.839586    
#> 177: 0.424882    0.968119    3.393001    0.244969    0.075085    0.004309    0.815720    
#> 178: 0.415828    0.961485    3.389944    0.204352    0.088364    0.005245    0.807738    
#> 179: 0.459665    0.978442    3.392934    0.239814    0.080164    0.005737    0.823841    
#> 180: 0.386444    0.968038    3.389338    0.251503    0.067824    0.007840    0.821747    
#> 181: 0.392697    0.955088    3.379889    0.256611    0.067169    0.007209    0.812675    
#> 182: 0.367523    0.958007    3.373162    0.241148    0.072702    0.008341    0.825250    
#> 183: 0.404687    0.960090    3.382920    0.191060    0.077653    0.007816    0.817612    
#> 184: 0.399613    0.958455    3.383797    0.223557    0.067585    0.009364    0.818035    
#> 185: 0.385886    0.972684    3.386848    0.252117    0.063649    0.010491    0.822372    
#> 186: 0.416388    0.986103    3.395879    0.259093    0.068877    0.014233    0.805484    
#> 187: 0.436572    0.950380    3.401784    0.323824    0.068616    0.012078    0.793333    
#> 188: 0.451770    0.951793    3.398308    0.382672    0.073527    0.009361    0.793196    
#> 189: 0.452804    0.964431    3.402860    0.301884    0.066481    0.010224    0.816215    
#> 190: 0.450781    0.940097    3.416482    0.258615    0.055737    0.011124    0.813606    
#> 191: 0.419729    0.945079    3.396292    0.288920    0.048617    0.010395    0.813950    
#> 192: 0.427425    0.958270    3.399363    0.273119    0.051328    0.010805    0.828500    
#> 193: 0.440758    0.972368    3.398886    0.309073    0.038724    0.010439    0.816589    
#> 194: 0.410427    0.977433    3.391492    0.327990    0.049815    0.009429    0.835851    
#> 195: 0.366391    0.960509    3.384156    0.255069    0.046193    0.008620    0.826951    
#> 196: 0.399048    0.956474    3.385719    0.274034    0.064975    0.010821    0.819413    
#> 197: 0.380082    0.968782    3.402494    0.239897    0.058437    0.011112    0.828932    
#> 198: 0.483184    0.941280    3.399148    0.331517    0.061965    0.010605    0.813417    
#> 199: 0.433696    0.925060    3.400296    0.296553    0.056054    0.009682    0.816127    
#> 200: 0.421816    0.940310    3.400615    0.227350    0.066087    0.008681    0.849242    
#> 201: 0.433154    0.938350    3.405814    0.224781    0.061078    0.009176    0.840662    
#> 202: 0.433928    0.943334    3.405127    0.237334    0.064215    0.009542    0.839476    
#> 203: 0.445001    0.942535    3.404372    0.247133    0.062596    0.009944    0.836868    
#> 204: 0.453871    0.936409    3.407147    0.255695    0.062554    0.010068    0.837722    
#> 205: 0.451139    0.937481    3.406471    0.252944    0.061934    0.010118    0.839400    
#> 206: 0.455082    0.941064    3.407237    0.253884    0.062843    0.010026    0.839706    
#> 207: 0.452685    0.942754    3.405871    0.250428    0.064546    0.009874    0.838692    
#> 208: 0.453194    0.944074    3.406068    0.245187    0.064688    0.009878    0.838150    
#> 209: 0.454312    0.943625    3.404704    0.246666    0.065111    0.009752    0.837032    
#> 210: 0.454832    0.944039    3.404476    0.248984    0.064971    0.009652    0.835448    
#> 211: 0.455803    0.945034    3.405339    0.249762    0.065989    0.009636    0.832567    
#> 212: 0.456946    0.944325    3.405881    0.248370    0.065808    0.009631    0.831835    
#> 213: 0.458233    0.941737    3.406204    0.245568    0.066440    0.009519    0.832955    
#> 214: 0.459773    0.940402    3.406428    0.246446    0.066283    0.009559    0.832665    
#> 215: 0.461307    0.940322    3.406722    0.248851    0.066164    0.009663    0.833416    
#> 216: 0.463465    0.939393    3.406844    0.255630    0.067072    0.009763    0.834128    
#> 217: 0.463796    0.941620    3.406747    0.261673    0.067372    0.009855    0.832221    
#> 218: 0.463609    0.942847    3.406163    0.265566    0.068262    0.009889    0.830092    
#> 219: 0.462052    0.942689    3.405019    0.268867    0.067822    0.009937    0.829484    
#> 220: 0.459372    0.943618    3.404037    0.268120    0.066906    0.009762    0.829738    
#> 221: 0.457153    0.944901    3.403396    0.267168    0.066940    0.009645    0.829196    
#> 222: 0.456800    0.945684    3.402837    0.267421    0.067050    0.009618    0.828700    
#> 223: 0.457484    0.946373    3.402573    0.267430    0.067098    0.009556    0.827637    
#> 224: 0.459889    0.947527    3.402890    0.270731    0.067147    0.009544    0.827107    
#> 225: 0.460804    0.945802    3.403234    0.274037    0.066930    0.009595    0.826310    
#> 226: 0.462037    0.944279    3.403189    0.276780    0.067053    0.009561    0.825630    
#> 227: 0.460911    0.944219    3.402969    0.279251    0.066897    0.009594    0.824651    
#> 228: 0.459481    0.945949    3.401982    0.280982    0.066619    0.009604    0.824785    
#> 229: 0.458351    0.946157    3.401491    0.282953    0.066456    0.009654    0.824534    
#> 230: 0.458354    0.945531    3.401395    0.283114    0.066248    0.009651    0.824058    
#> 231: 0.458265    0.945713    3.401469    0.282535    0.066148    0.009688    0.823717    
#> 232: 0.456010    0.945948    3.401599    0.284620    0.065575    0.009763    0.823691    
#> 233: 0.455623    0.945611    3.401412    0.286004    0.065445    0.009806    0.823217    
#> 234: 0.454848    0.945558    3.401324    0.285897    0.065166    0.009849    0.822512    
#> 235: 0.455572    0.945190    3.401356    0.285767    0.064962    0.009903    0.822384    
#> 236: 0.455497    0.945585    3.401349    0.286398    0.065067    0.009962    0.822587    
#> 237: 0.457553    0.945368    3.401656    0.287563    0.064858    0.010058    0.822656    
#> 238: 0.458287    0.945237    3.401995    0.287084    0.065029    0.010093    0.822613    
#> 239: 0.457992    0.945659    3.402277    0.286567    0.065562    0.010198    0.822017    
#> 240: 0.458575    0.945439    3.402670    0.286156    0.065609    0.010227    0.821770    
#> 241: 0.459246    0.944598    3.402976    0.286016    0.066002    0.010134    0.821434    
#> 242: 0.458893    0.944280    3.402919    0.284759    0.066390    0.010110    0.821796    
#> 243: 0.458331    0.944645    3.403151    0.284269    0.066914    0.010074    0.822309    
#> 244: 0.458248    0.944571    3.403499    0.283019    0.066912    0.010144    0.822530    
#> 245: 0.457618    0.944271    3.403561    0.282148    0.067089    0.010252    0.822429    
#> 246: 0.458101    0.944031    3.403788    0.282423    0.067015    0.010345    0.822590    
#> 247: 0.458123    0.943524    3.404165    0.281779    0.066906    0.010370    0.822093    
#> 248: 0.458016    0.943475    3.404398    0.281246    0.066856    0.010362    0.821652    
#> 249: 0.457311    0.943331    3.404473    0.279961    0.066894    0.010361    0.821523    
#> 250: 0.457393    0.943505    3.404488    0.279448    0.067333    0.010406    0.821094    
#> 251: 0.457681    0.943967    3.404627    0.279099    0.067718    0.010407    0.821071    
#> 252: 0.458508    0.943968    3.404899    0.279995    0.067977    0.010419    0.821038    
#> 253: 0.458472    0.944111    3.405017    0.280035    0.067917    0.010445    0.821151    
#> 254: 0.458669    0.943949    3.405341    0.280038    0.068126    0.010420    0.821142    
#> 255: 0.459105    0.944132    3.405780    0.279016    0.068205    0.010416    0.821202    
#> 256: 0.460400    0.943640    3.406158    0.279058    0.068426    0.010442    0.821094    
#> 257: 0.460982    0.943009    3.406322    0.279375    0.068412    0.010439    0.821269    
#> 258: 0.461261    0.942304    3.406433    0.279615    0.068418    0.010408    0.821148    
#> 259: 0.461660    0.941961    3.406529    0.279521    0.068113    0.010393    0.821239    
#> 260: 0.461938    0.942020    3.406665    0.279701    0.067871    0.010405    0.821097    
#> 261: 0.462292    0.941689    3.406842    0.280239    0.067908    0.010419    0.821202    
#> 262: 0.462076    0.941279    3.406796    0.280936    0.067774    0.010416    0.821369    
#> 263: 0.461742    0.941341    3.406799    0.282215    0.067772    0.010401    0.821098    
#> 264: 0.461604    0.941167    3.406875    0.283107    0.067665    0.010392    0.821222    
#> 265: 0.461917    0.941091    3.406977    0.283478    0.067834    0.010397    0.821266    
#> 266: 0.462077    0.941070    3.406945    0.283910    0.067857    0.010449    0.821357    
#> 267: 0.462558    0.941021    3.407094    0.284885    0.067769    0.010496    0.821022    
#> 268: 0.462859    0.940921    3.407085    0.285284    0.067743    0.010497    0.820982    
#> 269: 0.463365    0.940766    3.407044    0.285102    0.067768    0.010474    0.821152    
#> 270: 0.463685    0.940975    3.406865    0.285205    0.067752    0.010414    0.821068    
#> 271: 0.463557    0.941051    3.406671    0.285945    0.067616    0.010371    0.821235    
#> 272: 0.463311    0.940886    3.406579    0.285777    0.067525    0.010351    0.821634    
#> 273: 0.462951    0.941306    3.406601    0.285758    0.067559    0.010336    0.821895    
#> 274: 0.462976    0.941356    3.406722    0.285354    0.067460    0.010326    0.821917    
#> 275: 0.462681    0.941374    3.406628    0.284814    0.067327    0.010323    0.821665    
#> 276: 0.462482    0.941304    3.406775    0.284930    0.067291    0.010330    0.821527    
#> 277: 0.462360    0.941442    3.406931    0.284302    0.067146    0.010335    0.821395    
#> 278: 0.462340    0.941289    3.407077    0.284122    0.067139    0.010338    0.821116    
#> 279: 0.462089    0.941082    3.407157    0.284340    0.067113    0.010405    0.821099    
#> 280: 0.462137    0.941009    3.407247    0.284277    0.067038    0.010431    0.820692    
#> 281: 0.461737    0.941038    3.407271    0.284540    0.066920    0.010476    0.820479    
#> 282: 0.461763    0.941086    3.407348    0.285289    0.066674    0.010548    0.820336    
#> 283: 0.462048    0.941045    3.407441    0.285964    0.066550    0.010627    0.820416    
#> 284: 0.462072    0.940803    3.407537    0.286498    0.066415    0.010672    0.820333    
#> 285: 0.462257    0.940716    3.407494    0.286835    0.066320    0.010707    0.820336    
#> 286: 0.462044    0.940758    3.407466    0.286401    0.066176    0.010712    0.820160    
#> 287: 0.461841    0.940830    3.407439    0.286240    0.066030    0.010708    0.820338    
#> 288: 0.461821    0.940693    3.407425    0.285899    0.066004    0.010688    0.820572    
#> 289: 0.461647    0.940803    3.407336    0.284913    0.066012    0.010685    0.820870    
#> 290: 0.461554    0.940995    3.407182    0.285115    0.065919    0.010676    0.821070    
#> 291: 0.461668    0.941008    3.407200    0.285569    0.065779    0.010658    0.820906    
#> 292: 0.461733    0.940956    3.407220    0.286623    0.065725    0.010622    0.820751    
#> 293: 0.461851    0.940856    3.407129    0.287414    0.065788    0.010595    0.820665    
#> 294: 0.461766    0.940948    3.407020    0.288055    0.065804    0.010586    0.820548    
#> 295: 0.461779    0.940778    3.406936    0.288774    0.065664    0.010614    0.820283    
#> 296: 0.461441    0.940888    3.406858    0.288834    0.065539    0.010661    0.820323    
#> 297: 0.461447    0.940935    3.406750    0.288889    0.065327    0.010690    0.820458    
#> 298: 0.461393    0.940644    3.406763    0.288608    0.065153    0.010695    0.820494    
#> 299: 0.461614    0.940482    3.406829    0.288127    0.065219    0.010677    0.820253    
#> 300: 0.461858    0.940173    3.407011    0.288170    0.065243    0.010671    0.819921    
#> 301: 0.462102    0.939829    3.407044    0.288152    0.065265    0.010657    0.819943    
#> 302: 0.462198    0.939968    3.406970    0.288514    0.065371    0.010670    0.819769    
#> 303: 0.461972    0.940052    3.406954    0.288492    0.065485    0.010688    0.819604    
#> 304: 0.462362    0.940193    3.406962    0.288878    0.065518    0.010707    0.819488    
#> 305: 0.462397    0.939847    3.407043    0.288930    0.065607    0.010750    0.819487    
#> 306: 0.462297    0.939620    3.407005    0.288907    0.065801    0.010741    0.819501    
#> 307: 0.462456    0.939367    3.407021    0.288924    0.065857    0.010757    0.819431    
#> 308: 0.461954    0.939318    3.406945    0.289092    0.065889    0.010764    0.819419    
#> 309: 0.461647    0.939193    3.406853    0.288698    0.065842    0.010765    0.819638    
#> 310: 0.461657    0.939158    3.406683    0.288924    0.065893    0.010785    0.819507    
#> 311: 0.461390    0.939308    3.406547    0.288972    0.065813    0.010813    0.819295    
#> 312: 0.461102    0.939262    3.406440    0.289532    0.065869    0.010842    0.819107    
#> 313: 0.460875    0.939014    3.406363    0.289472    0.066029    0.010873    0.819046    
#> 314: 0.460624    0.939119    3.406298    0.289825    0.066152    0.010854    0.819124    
#> 315: 0.460084    0.939211    3.406277    0.290171    0.066187    0.010857    0.819395    
#> 316: 0.460026    0.939353    3.406254    0.290022    0.066166    0.010856    0.819439    
#> 317: 0.459782    0.939422    3.406229    0.289717    0.066172    0.010843    0.819709    
#> 318: 0.459798    0.939340    3.406197    0.289491    0.066187    0.010840    0.819725    
#> 319: 0.459647    0.939322    3.406226    0.289144    0.066170    0.010840    0.819781    
#> 320: 0.459447    0.939385    3.406193    0.289059    0.066191    0.010842    0.819873    
#> 321: 0.459285    0.939489    3.406086    0.289144    0.066127    0.010847    0.819912    
#> 322: 0.459248    0.939503    3.405914    0.289700    0.066104    0.010837    0.819822    
#> 323: 0.458666    0.939593    3.405838    0.290074    0.066033    0.010860    0.819752    
#> 324: 0.458629    0.939764    3.405868    0.290313    0.065959    0.010873    0.819479    
#> 325: 0.458803    0.939893    3.405843    0.290187    0.065858    0.010877    0.819232    
#> 326: 0.458893    0.939642    3.405845    0.289919    0.065904    0.010864    0.819112    
#> 327: 0.459244    0.939642    3.405906    0.289932    0.065942    0.010864    0.819047    
#> 328: 0.459616    0.939622    3.406052    0.289609    0.065901    0.010859    0.819023    
#> 329: 0.460059    0.939624    3.406171    0.289539    0.065889    0.010868    0.819083    
#> 330: 0.459948    0.939791    3.406201    0.289114    0.065869    0.010877    0.819103    
#> 331: 0.460051    0.940046    3.406189    0.288744    0.065839    0.010863    0.819001    
#> 332: 0.460162    0.939993    3.406239    0.288378    0.065816    0.010869    0.818928    
#> 333: 0.459923    0.939996    3.406210    0.288465    0.065802    0.010901    0.818786    
#> 334: 0.459680    0.940002    3.406110    0.288364    0.065819    0.010906    0.818697    
#> 335: 0.459367    0.940114    3.405982    0.288637    0.065836    0.010907    0.818488    
#> 336: 0.458864    0.940159    3.405892    0.288377    0.065868    0.010922    0.818403    
#> 337: 0.458697    0.940524    3.405761    0.288606    0.065784    0.010917    0.818445    
#> 338: 0.458547    0.940615    3.405717    0.288772    0.065753    0.010954    0.818338    
#> 339: 0.458331    0.940748    3.405641    0.288907    0.065667    0.010978    0.818211    
#> 340: 0.458183    0.940631    3.405680    0.289061    0.065589    0.010994    0.818168    
#> 341: 0.458479    0.940535    3.405823    0.289132    0.065623    0.011007    0.817965    
#> 342: 0.458172    0.940411    3.405811    0.288893    0.065588    0.011022    0.817726    
#> 343: 0.457950    0.940461    3.405820    0.288804    0.065530    0.011020    0.817662    
#> 344: 0.458131    0.940485    3.405914    0.288727    0.065444    0.011050    0.817695    
#> 345: 0.457992    0.940499    3.405932    0.288645    0.065313    0.011072    0.817652    
#> 346: 0.457851    0.940636    3.405818    0.288593    0.065178    0.011083    0.817675    
#> 347: 0.457880    0.940673    3.405711    0.288485    0.065152    0.011088    0.817870    
#> 348: 0.457746    0.941040    3.405617    0.288602    0.065179    0.011098    0.817975    
#> 349: 0.457680    0.941052    3.405557    0.288778    0.065121    0.011095    0.817924    
#> 350: 0.457428    0.940948    3.405488    0.288930    0.065085    0.011087    0.817927    
#> 351: 0.457520    0.941066    3.405448    0.288851    0.065037    0.011082    0.817929    
#> 352: 0.457149    0.941264    3.405414    0.288884    0.065057    0.011105    0.817853    
#> 353: 0.457196    0.941379    3.405310    0.289040    0.065011    0.011132    0.817847    
#> 354: 0.457373    0.941430    3.405194    0.289528    0.064993    0.011180    0.817688    
#> 355: 0.457783    0.941214    3.405244    0.289695    0.064932    0.011186    0.817603    
#> 356: 0.457858    0.941129    3.405315    0.289251    0.064908    0.011192    0.817758    
#> 357: 0.458064    0.941166    3.405347    0.289205    0.064879    0.011191    0.817719    
#> 358: 0.458096    0.941299    3.405395    0.288954    0.064935    0.011195    0.817651    
#> 359: 0.457985    0.941567    3.405396    0.288509    0.064883    0.011184    0.817619    
#> 360: 0.457574    0.941718    3.405264    0.288220    0.064881    0.011168    0.817546    
#> 361: 0.457210    0.941813    3.405128    0.287871    0.064807    0.011147    0.817665    
#> 362: 0.457170    0.941905    3.405033    0.287730    0.064813    0.011118    0.817606    
#> 363: 0.457023    0.941919    3.404980    0.287320    0.064832    0.011097    0.817533    
#> 364: 0.456968    0.942052    3.404970    0.287201    0.064898    0.011083    0.817564    
#> 365: 0.456880    0.941994    3.404979    0.287080    0.065020    0.011087    0.817599    
#> 366: 0.457014    0.942262    3.404858    0.286952    0.065070    0.011090    0.817593    
#> 367: 0.457071    0.942259    3.404859    0.286947    0.065141    0.011085    0.817573    
#> 368: 0.457144    0.942347    3.404807    0.287208    0.065118    0.011091    0.817352    
#> 369: 0.457027    0.942363    3.404765    0.287818    0.065177    0.011110    0.817323    
#> 370: 0.456880    0.942458    3.404719    0.288216    0.065199    0.011138    0.817234    
#> 371: 0.456502    0.942662    3.404483    0.288231    0.065140    0.011159    0.817235    
#> 372: 0.456304    0.942767    3.404340    0.288141    0.065148    0.011188    0.817283    
#> 373: 0.455946    0.942867    3.404259    0.288206    0.065162    0.011195    0.817291    
#> 374: 0.455824    0.942893    3.404129    0.288142    0.065198    0.011194    0.817217    
#> 375: 0.455679    0.942965    3.404057    0.288228    0.065228    0.011206    0.817143    
#> 376: 0.455554    0.942997    3.404021    0.288234    0.065231    0.011219    0.816982    
#> 377: 0.455348    0.943063    3.403903    0.288358    0.065176    0.011235    0.816981    
#> 378: 0.455053    0.943109    3.403778    0.288637    0.065221    0.011240    0.817077    
#> 379: 0.454880    0.943036    3.403741    0.289135    0.065262    0.011246    0.817023    
#> 380: 0.454581    0.943053    3.403648    0.289282    0.065354    0.011250    0.817016    
#> 381: 0.454248    0.943069    3.403570    0.289432    0.065415    0.011256    0.816871    
#> 382: 0.454174    0.943040    3.403489    0.289292    0.065415    0.011254    0.816751    
#> 383: 0.454238    0.942943    3.403504    0.289060    0.065458    0.011246    0.816639    
#> 384: 0.454182    0.942916    3.403559    0.288755    0.065375    0.011237    0.816685    
#> 385: 0.454236    0.942912    3.403624    0.288876    0.065344    0.011246    0.816696    
#> 386: 0.454475    0.943014    3.403714    0.288965    0.065343    0.011258    0.816730    
#> 387: 0.454695    0.943075    3.403815    0.288955    0.065316    0.011282    0.816734    
#> 388: 0.454994    0.943100    3.403908    0.289002    0.065249    0.011312    0.816678    
#> 389: 0.454952    0.943032    3.403917    0.288878    0.065193    0.011329    0.816720    
#> 390: 0.454806    0.942994    3.403879    0.288744    0.065102    0.011346    0.816716    
#> 391: 0.454861    0.942981    3.403855    0.288825    0.065055    0.011343    0.816678    
#> 392: 0.454933    0.943024    3.403854    0.289022    0.065019    0.011337    0.816811    
#> 393: 0.454930    0.942967    3.403823    0.289245    0.065028    0.011349    0.816807    
#> 394: 0.454928    0.942934    3.403818    0.289253    0.064991    0.011349    0.816801    
#> 395: 0.455001    0.942970    3.403807    0.289071    0.064956    0.011355    0.816894    
#> 396: 0.455313    0.942984    3.403882    0.288908    0.064958    0.011339    0.816812    
#> 397: 0.455611    0.942864    3.403955    0.288869    0.064897    0.011325    0.816725    
#> 398: 0.455865    0.942743    3.404045    0.288852    0.064896    0.011322    0.816784    
#> 399: 0.455914    0.942752    3.404056    0.288805    0.064936    0.011310    0.816850    
#> 400: 0.456055    0.942870    3.404062    0.288846    0.064991    0.011298    0.816865    
#> 401: 0.455971    0.943001    3.404044    0.288953    0.065077    0.011294    0.816844    
#> 402: 0.455943    0.943026    3.404055    0.288915    0.065107    0.011303    0.816802    
#> 403: 0.456129    0.942963    3.404057    0.289027    0.065105    0.011302    0.816856    
#> 404: 0.456214    0.942909    3.404037    0.289260    0.065034    0.011288    0.816838    
#> 405: 0.456238    0.942880    3.404055    0.289516    0.065065    0.011283    0.816989    
#> 406: 0.456266    0.942798    3.404048    0.289799    0.065035    0.011288    0.816997    
#> 407: 0.456268    0.942700    3.404122    0.289933    0.065098    0.011277    0.816942    
#> 408: 0.456485    0.942748    3.404159    0.289963    0.065127    0.011261    0.816978    
#> 409: 0.456451    0.942790    3.404110    0.289921    0.065122    0.011241    0.816931    
#> 410: 0.456325    0.942815    3.404009    0.290030    0.065190    0.011232    0.816927    
#> 411: 0.456390    0.942619    3.403976    0.290410    0.065255    0.011214    0.816910    
#> 412: 0.456538    0.942654    3.404008    0.290412    0.065324    0.011199    0.816930    
#> 413: 0.456554    0.942684    3.403974    0.290011    0.065348    0.011181    0.816994    
#> 414: 0.456387    0.942664    3.403985    0.290020    0.065316    0.011165    0.816933    
#> 415: 0.456468    0.942641    3.403988    0.289892    0.065289    0.011149    0.816951    
#> 416: 0.456543    0.942710    3.404013    0.289814    0.065323    0.011135    0.816893    
#> 417: 0.456711    0.942603    3.404011    0.289762    0.065335    0.011119    0.816921    
#> 418: 0.456626    0.942627    3.404029    0.289664    0.065453    0.011096    0.816854    
#> 419: 0.456657    0.942744    3.404004    0.289700    0.065472    0.011084    0.816763    
#> 420: 0.456824    0.942766    3.404029    0.289515    0.065499    0.011063    0.816719    
#> 421: 0.456694    0.942750    3.404063    0.289300    0.065473    0.011045    0.816798    
#> 422: 0.456880    0.942700    3.404092    0.289289    0.065435    0.011029    0.816838    
#> 423: 0.457051    0.942647    3.404130    0.289250    0.065383    0.011032    0.816886    
#> 424: 0.457002    0.942617    3.404127    0.289117    0.065383    0.011020    0.816913    
#> 425: 0.457252    0.942590    3.404147    0.289339    0.065335    0.011010    0.816980    
#> 426: 0.457407    0.942619    3.404144    0.289415    0.065325    0.011007    0.816989    
#> 427: 0.457305    0.942578    3.404168    0.289397    0.065303    0.011006    0.816944    
#> 428: 0.457225    0.942567    3.404159    0.289428    0.065288    0.011005    0.816904    
#> 429: 0.457396    0.942575    3.404223    0.289535    0.065326    0.010998    0.816867    
#> 430: 0.457349    0.942616    3.404248    0.289243    0.065329    0.010995    0.816895    
#> 431: 0.457386    0.942566    3.404257    0.288966    0.065418    0.010992    0.816873    
#> 432: 0.457454    0.942655    3.404289    0.288931    0.065475    0.011002    0.816735    
#> 433: 0.457527    0.942747    3.404314    0.288845    0.065455    0.011007    0.816659    
#> 434: 0.457447    0.942699    3.404342    0.288861    0.065407    0.011009    0.816597    
#> 435: 0.457554    0.942711    3.404375    0.288862    0.065412    0.011010    0.816525    
#> 436: 0.457630    0.942665    3.404415    0.288764    0.065459    0.011008    0.816511    
#> 437: 0.457618    0.942730    3.404431    0.288747    0.065470    0.011011    0.816497    
#> 438: 0.457583    0.942970    3.404432    0.288655    0.065458    0.011018    0.816499    
#> 439: 0.457694    0.943093    3.404456    0.288647    0.065475    0.011010    0.816435    
#> 440: 0.457660    0.943190    3.404465    0.288563    0.065511    0.011004    0.816382    
#> 441: 0.457503    0.943142    3.404452    0.288552    0.065582    0.010987    0.816336    
#> 442: 0.457454    0.943308    3.404451    0.288660    0.065661    0.010976    0.816284    
#> 443: 0.457501    0.943556    3.404394    0.288726    0.065724    0.010962    0.816224    
#> 444: 0.457408    0.943734    3.404314    0.288823    0.065873    0.010949    0.816193    
#> 445: 0.457312    0.943806    3.404222    0.289113    0.065918    0.010956    0.816190    
#> 446: 0.457079    0.943894    3.404126    0.289209    0.065955    0.010953    0.816146    
#> 447: 0.457119    0.944000    3.404055    0.289314    0.065974    0.010957    0.816044    
#> 448: 0.457019    0.944034    3.404036    0.289318    0.065993    0.010945    0.816001    
#> 449: 0.457109    0.944135    3.404127    0.289363    0.066042    0.010935    0.816046    
#> 450: 0.457065    0.944130    3.404120    0.289439    0.066101    0.010935    0.815997    
#> 451: 0.457233    0.944217    3.404070    0.289667    0.066158    0.010929    0.815982    
#> 452: 0.457093    0.944348    3.403959    0.289832    0.066188    0.010926    0.815898    
#> 453: 0.456976    0.944507    3.403848    0.290010    0.066196    0.010925    0.815914    
#> 454: 0.456849    0.944659    3.403740    0.290113    0.066218    0.010920    0.815821    
#> 455: 0.456815    0.944777    3.403655    0.290285    0.066178    0.010924    0.815773    
#> 456: 0.456673    0.944787    3.403589    0.290311    0.066150    0.010937    0.815767    
#> 457: 0.456548    0.944785    3.403585    0.290457    0.066129    0.010941    0.815687    
#> 458: 0.456639    0.944848    3.403599    0.290629    0.066125    0.010944    0.815641    
#> 459: 0.456513    0.944972    3.403615    0.290801    0.066115    0.010961    0.815585    
#> 460: 0.456365    0.944983    3.403593    0.290790    0.066097    0.010978    0.815577    
#> 461: 0.456181    0.944990    3.403594    0.290923    0.066083    0.010993    0.815512    
#> 462: 0.456152    0.945010    3.403627    0.291070    0.066084    0.011010    0.815485    
#> 463: 0.456130    0.945033    3.403622    0.290984    0.066066    0.011008    0.815518    
#> 464: 0.456108    0.945073    3.403598    0.290907    0.066030    0.011007    0.815512    
#> 465: 0.456097    0.944962    3.403604    0.290729    0.066005    0.010995    0.815513    
#> 466: 0.456137    0.944994    3.403562    0.290529    0.066031    0.010984    0.815513    
#> 467: 0.455896    0.945017    3.403555    0.290301    0.066079    0.010963    0.815461    
#> 468: 0.455931    0.945010    3.403542    0.290301    0.066116    0.010956    0.815488    
#> 469: 0.455985    0.945129    3.403523    0.290517    0.066171    0.010962    0.815497    
#> 470: 0.455934    0.945252    3.403450    0.290673    0.066202    0.010965    0.815437    
#> 471: 0.455699    0.945330    3.403377    0.290642    0.066187    0.010952    0.815434    
#> 472: 0.455616    0.945427    3.403344    0.290680    0.066241    0.010951    0.815410    
#> 473: 0.455491    0.945476    3.403329    0.290574    0.066250    0.010943    0.815331    
#> 474: 0.455493    0.945440    3.403332    0.290703    0.066209    0.010944    0.815358    
#> 475: 0.455537    0.945610    3.403292    0.290783    0.066173    0.010950    0.815361    
#> 476: 0.455584    0.945579    3.403219    0.291085    0.066132    0.010962    0.815385    
#> 477: 0.455503    0.945636    3.403186    0.291171    0.066082    0.010969    0.815389    
#> 478: 0.455388    0.945694    3.403159    0.291235    0.066088    0.010983    0.815386    
#> 479: 0.455295    0.945797    3.403135    0.291259    0.066110    0.010988    0.815426    
#> 480: 0.455237    0.945836    3.403121    0.291130    0.066121    0.010982    0.815450    
#> 481: 0.455093    0.945879    3.403106    0.291060    0.066146    0.010970    0.815521    
#> 482: 0.455208    0.945887    3.403094    0.291070    0.066191    0.010961    0.815610    
#> 483: 0.455199    0.945878    3.403068    0.291248    0.066225    0.010946    0.815574    
#> 484: 0.455229    0.945765    3.403079    0.291386    0.066171    0.010939    0.815627    
#> 485: 0.455349    0.945719    3.403099    0.291589    0.066124    0.010937    0.815678    
#> 486: 0.455340    0.945751    3.403123    0.291570    0.066129    0.010925    0.815695    
#> 487: 0.455506    0.945846    3.403137    0.291559    0.066143    0.010913    0.815700    
#> 488: 0.455631    0.945760    3.403194    0.291539    0.066206    0.010901    0.815659    
#> 489: 0.455761    0.945704    3.403230    0.291538    0.066262    0.010898    0.815690    
#> 490: 0.455808    0.945754    3.403251    0.291592    0.066284    0.010895    0.815687    
#> 491: 0.455813    0.945792    3.403319    0.291638    0.066374    0.010898    0.815654    
#> 492: 0.455818    0.945856    3.403332    0.291816    0.066437    0.010897    0.815752    
#> 493: 0.455782    0.945901    3.403316    0.291865    0.066484    0.010897    0.815771    
#> 494: 0.455893    0.945967    3.403307    0.291699    0.066540    0.010886    0.815799    
#> 495: 0.455926    0.945992    3.403311    0.291632    0.066528    0.010881    0.815743    
#> 496: 0.456123    0.946068    3.403275    0.291727    0.066549    0.010876    0.815674    
#> 497: 0.456064    0.946102    3.403254    0.291877    0.066524    0.010876    0.815660    
#> 498: 0.456042    0.946109    3.403215    0.291943    0.066506    0.010878    0.815610    
#> 499: 0.456135    0.946174    3.403183    0.292105    0.066474    0.010876    0.815573    
#> 500: 0.456210    0.946143    3.403183    0.292211    0.066424    0.010881    0.815503    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.320490    0.969577    3.442975    0.392401    0.080196    0.016800    1.697431    
#> 002: 0.641335    1.026342    3.475993    0.372781    0.076186    0.015960    1.135988    
#> 003: 0.853971    1.005894    3.491250    0.354142    0.072377    0.015162    0.853080    
#> 004: 0.878306    1.032774    3.503833    0.336435    0.068758    0.014404    0.767427    
#> 005: 0.991372    1.058540    3.505470    0.392069    0.065320    0.013684    0.730574    
#> 006: 0.959877    1.031488    3.495382    0.449226    0.069209    0.013000    0.674087    
#> 007: 0.942727    1.029861    3.496986    0.468932    0.065749    0.012350    0.676736    
#> 008: 0.910303    1.027397    3.490893    0.463783    0.062462    0.012319    0.685613    
#> 009: 0.888456    1.018378    3.485368    0.538823    0.059338    0.011703    0.694670    
#> 010: 0.935383    1.023192    3.493680    0.606267    0.056372    0.012791    0.695174    
#> 011: 0.992157    1.027109    3.501124    0.575954    0.053553    0.015897    0.701500    
#> 012: 0.959862    1.035657    3.487718    0.547156    0.050875    0.015102    0.689110    
#> 013: 0.927311    1.040595    3.491671    0.533276    0.048332    0.014347    0.700891    
#> 014: 1.027631    1.017358    3.504199    0.605082    0.049375    0.015344    0.713447    
#> 015: 1.026827    1.041497    3.509611    0.588666    0.047324    0.014897    0.680378    
#> 016: 1.036806    1.050370    3.516521    0.619569    0.044958    0.014152    0.702727    
#> 017: 0.991472    1.038311    3.520145    0.588591    0.047819    0.013445    0.680068    
#> 018: 1.034442    1.036704    3.502983    0.647497    0.047534    0.012772    0.682511    
#> 019: 0.954467    1.034213    3.502535    0.615122    0.045157    0.012134    0.692816    
#> 020: 1.024401    1.032820    3.510326    0.618610    0.042900    0.012385    0.699629    
#> 021: 1.003951    1.018749    3.519300    0.587680    0.040864    0.013339    0.692779    
#> 022: 0.971900    1.013278    3.517410    0.558296    0.042040    0.012672    0.678477    
#> 023: 1.041063    1.023902    3.518384    0.530381    0.049571    0.013317    0.680027    
#> 024: 1.066631    1.033690    3.516285    0.589484    0.047093    0.012651    0.662257    
#> 025: 1.013490    1.020389    3.514384    0.587938    0.047822    0.012018    0.664267    
#> 026: 1.007366    1.058813    3.502872    0.667251    0.045430    0.012132    0.670013    
#> 027: 1.009504    1.057232    3.501305    0.670092    0.043159    0.011525    0.694493    
#> 028: 1.012271    1.053183    3.496627    0.694635    0.042913    0.010949    0.659038    
#> 029: 1.053727    1.058558    3.496030    0.725441    0.042444    0.011465    0.680954    
#> 030: 1.071412    1.068633    3.498456    0.831656    0.041223    0.013243    0.674005    
#> 031: 0.989799    1.057455    3.509882    0.790074    0.044700    0.014309    0.675623    
#> 032: 0.999977    1.038916    3.511528    0.750570    0.045687    0.013594    0.673397    
#> 033: 0.946609    1.051783    3.504089    0.713041    0.046901    0.012914    0.683833    
#> 034: 0.967804    1.055123    3.491751    0.677389    0.044556    0.012268    0.697806    
#> 035: 0.920096    1.051122    3.488213    0.643520    0.042328    0.011655    0.686614    
#> 036: 0.941851    1.060369    3.493308    0.611344    0.041798    0.011072    0.696486    
#> 037: 0.995443    1.055006    3.500271    0.594603    0.039708    0.010518    0.713597    
#> 038: 0.978398    1.042881    3.494493    0.564873    0.037723    0.012152    0.703980    
#> 039: 1.003062    1.042358    3.496873    0.687978    0.041492    0.011545    0.704045    
#> 040: 1.022328    1.033180    3.504965    0.674381    0.040381    0.013342    0.676946    
#> 041: 0.938742    1.017110    3.504996    0.640662    0.038362    0.012802    0.684359    
#> 042: 1.029161    1.008190    3.508321    0.645995    0.036444    0.012161    0.668739    
#> 043: 0.925257    1.032803    3.486405    0.613695    0.037158    0.011553    0.671805    
#> 044: 0.922267    1.050426    3.480217    0.583011    0.040188    0.010976    0.684314    
#> 045: 0.983915    1.079051    3.483247    0.666039    0.039578    0.010427    0.689479    
#> 046: 0.987200    1.069271    3.484387    0.687606    0.037599    0.009906    0.687986    
#> 047: 0.948639    1.077560    3.481670    0.653225    0.044894    0.009410    0.683786    
#> 048: 0.958274    1.067184    3.484476    0.620564    0.043287    0.008940    0.686235    
#> 049: 0.947871    1.045156    3.492894    0.589536    0.050104    0.008493    0.698416    
#> 050: 1.025511    1.010134    3.495687    0.647734    0.054786    0.010232    0.693845    
#> 051: 0.986138    1.035853    3.485932    0.662478    0.052220    0.011894    0.693315    
#> 052: 1.026513    1.044550    3.496318    0.629354    0.051132    0.011299    0.674303    
#> 053: 0.998808    1.045095    3.496242    0.631243    0.051743    0.010734    0.666761    
#> 054: 0.985826    1.044006    3.506641    0.599681    0.055300    0.012256    0.681086    
#> 055: 0.917996    1.039807    3.502053    0.569697    0.052535    0.011643    0.691273    
#> 056: 1.013590    1.027888    3.508495    0.541212    0.057771    0.012261    0.711145    
#> 057: 1.004774    1.027755    3.508715    0.542188    0.054882    0.014086    0.721636    
#> 058: 0.972003    1.034392    3.493061    0.556765    0.052138    0.013382    0.702370    
#> 059: 0.965126    0.994202    3.505678    0.541507    0.049531    0.012713    0.708995    
#> 060: 0.994934    0.985957    3.515383    0.585217    0.047054    0.014499    0.710919    
#> 061: 1.084918    0.995704    3.515409    0.696382    0.046372    0.016552    0.719955    
#> 062: 1.049433    1.020862    3.518565    0.688014    0.044053    0.018511    0.723597    
#> 063: 1.102768    1.003556    3.516844    0.780245    0.041851    0.017585    0.726625    
#> 064: 1.104558    1.024247    3.516790    0.741233    0.045998    0.016706    0.717618    
#> 065: 1.065276    1.013040    3.505842    0.704171    0.048388    0.015871    0.690300    
#> 066: 1.011448    1.025796    3.508847    0.668963    0.048912    0.015077    0.675734    
#> 067: 0.960979    1.024840    3.502384    0.635514    0.046640    0.014323    0.684865    
#> 068: 0.978169    1.037880    3.514301    0.603739    0.044308    0.013607    0.681534    
#> 069: 0.948939    1.027697    3.500910    0.573552    0.042093    0.012927    0.698459    
#> 070: 0.945333    1.044610    3.506960    0.544874    0.051924    0.012977    0.692578    
#> 071: 0.975945    1.075138    3.481563    0.572645    0.050274    0.012328    0.720922    
#> 072: 0.979892    1.033516    3.497225    0.544013    0.048094    0.011712    0.717729    
#> 073: 1.032512    1.048263    3.517128    0.684144    0.056585    0.011126    0.700285    
#> 074: 0.983281    1.049016    3.502422    0.649937    0.053756    0.012543    0.664185    
#> 075: 1.035430    1.034098    3.520813    0.678199    0.055100    0.011916    0.681483    
#> 076: 1.014849    1.056035    3.517076    0.644289    0.052345    0.011320    0.685403    
#> 077: 1.023088    1.019800    3.508647    0.612075    0.049728    0.010754    0.708267    
#> 078: 1.034959    1.023516    3.514292    0.618871    0.047241    0.011424    0.680656    
#> 079: 1.038723    1.041629    3.516606    0.664400    0.044879    0.017552    0.695956    
#> 080: 0.991530    1.035980    3.510977    0.631180    0.042635    0.016674    0.711270    
#> 081: 0.949535    1.040004    3.497533    0.599621    0.040504    0.015840    0.699432    
#> 082: 0.963295    1.030683    3.506676    0.569640    0.038972    0.015048    0.702431    
#> 083: 0.978967    1.049960    3.508549    0.541158    0.043141    0.014296    0.689666    
#> 084: 0.978420    1.045817    3.502850    0.545751    0.047821    0.013581    0.685979    
#> 085: 0.947157    1.039133    3.510251    0.518464    0.047387    0.012902    0.686086    
#> 086: 0.986618    1.030950    3.512110    0.566195    0.045017    0.013120    0.688012    
#> 087: 1.021444    1.038296    3.499142    0.662128    0.042766    0.012464    0.680484    
#> 088: 0.952074    1.039463    3.500956    0.657235    0.040628    0.011938    0.679306    
#> 089: 1.004512    1.058815    3.492559    0.674289    0.038597    0.012158    0.680810    
#> 090: 0.979307    1.051456    3.488146    0.640574    0.041114    0.011550    0.689152    
#> 091: 0.931059    1.041215    3.483230    0.608546    0.045987    0.010981    0.678987    
#> 092: 0.935274    1.060498    3.479972    0.578118    0.049718    0.011134    0.685375    
#> 093: 0.884642    1.056933    3.478337    0.549212    0.050778    0.010577    0.700497    
#> 094: 0.879765    1.062323    3.474359    0.521752    0.048239    0.011519    0.685758    
#> 095: 0.920742    1.072477    3.485656    0.520077    0.049576    0.013397    0.684091    
#> 096: 0.896737    1.077839    3.478846    0.599583    0.050837    0.012727    0.679681    
#> 097: 0.915708    1.079020    3.479999    0.572821    0.055223    0.012091    0.664300    
#> 098: 0.934359    1.076326    3.489564    0.544180    0.052462    0.011487    0.682364    
#> 099: 0.963961    1.045085    3.480390    0.566595    0.049839    0.010912    0.692624    
#> 100: 0.981209    1.043871    3.491873    0.594964    0.047347    0.012829    0.680943    
#> 101: 0.925364    1.036398    3.475503    0.565216    0.044980    0.012956    0.681380    
#> 102: 0.905795    1.038316    3.481026    0.536955    0.042731    0.012308    0.680745    
#> 103: 0.966023    1.042930    3.491139    0.543709    0.040594    0.011693    0.687932    
#> 104: 0.944724    1.048590    3.499860    0.574833    0.045317    0.011108    0.685870    
#> 105: 1.015887    1.046000    3.497243    0.654580    0.049107    0.010553    0.698278    
#> 106: 1.003990    1.054565    3.500729    0.621851    0.047904    0.010901    0.688401    
#> 107: 1.008034    1.032937    3.501966    0.595891    0.049492    0.011127    0.690042    
#> 108: 1.019089    1.025103    3.496164    0.614366    0.057067    0.010571    0.708928    
#> 109: 1.003150    1.047834    3.512721    0.583648    0.065272    0.010042    0.690934    
#> 110: 0.958969    1.026809    3.499872    0.554466    0.068340    0.009540    0.687390    
#> 111: 0.962006    1.037870    3.498877    0.526742    0.064923    0.009063    0.674819    
#> 112: 0.942764    1.032772    3.492037    0.511226    0.063598    0.008610    0.678525    
#> 113: 0.922920    1.069650    3.484261    0.522003    0.060419    0.008179    0.666752    
#> 114: 0.929561    1.056145    3.486570    0.569664    0.057398    0.007770    0.688639    
#> 115: 0.954423    1.021945    3.488914    0.624688    0.063376    0.007382    0.686730    
#> 116: 1.029457    1.047869    3.500954    0.743122    0.060207    0.007507    0.706411    
#> 117: 0.966898    1.065364    3.500458    0.705966    0.057197    0.009413    0.691593    
#> 118: 1.003991    1.059324    3.491832    0.723342    0.054337    0.009121    0.687136    
#> 119: 0.984440    1.041168    3.491947    0.687174    0.051620    0.009677    0.707628    
#> 120: 0.921962    1.026497    3.493198    0.652816    0.049039    0.009889    0.697435    
#> 121: 0.922230    1.050682    3.491868    0.620175    0.046962    0.011453    0.689566    
#> 122: 0.980610    1.048841    3.495994    0.589166    0.044614    0.010880    0.696911    
#> 123: 1.060932    1.060002    3.501641    0.650592    0.047942    0.010336    0.678472    
#> 124: 1.064824    1.082632    3.495912    0.759656    0.045545    0.010312    0.669693    
#> 125: 1.054131    1.082774    3.486932    0.780767    0.043267    0.009797    0.669483    
#> 126: 1.060054    1.064062    3.482711    0.917026    0.048050    0.009307    0.682875    
#> 127: 1.030597    1.045590    3.479833    0.871175    0.054489    0.008842    0.682132    
#> 128: 0.977490    1.032982    3.493424    0.827616    0.051765    0.008400    0.697157    
#> 129: 1.061319    1.051595    3.503318    0.786235    0.049822    0.007980    0.701820    
#> 130: 1.054713    1.063853    3.499584    0.790641    0.051027    0.008740    0.681677    
#> 131: 0.994811    1.026959    3.491038    0.751109    0.048476    0.008937    0.685166    
#> 132: 0.979905    1.026277    3.485722    0.713553    0.046052    0.008490    0.683696    
#> 133: 0.928514    1.030094    3.491822    0.677876    0.052198    0.009603    0.702571    
#> 134: 0.967104    1.015591    3.507387    0.643982    0.052472    0.009123    0.725493    
#> 135: 0.929504    1.013251    3.493883    0.611783    0.056775    0.008667    0.727629    
#> 136: 0.912287    1.007522    3.490627    0.581194    0.055491    0.008233    0.683161    
#> 137: 0.904565    1.032993    3.485425    0.552134    0.054061    0.007822    0.706913    
#> 138: 0.963060    1.036038    3.488517    0.564420    0.051358    0.007431    0.687006    
#> 139: 0.931324    1.045954    3.492906    0.540734    0.048790    0.007059    0.689303    
#> 140: 0.975669    1.046343    3.495394    0.559822    0.051512    0.007774    0.700501    
#> 141: 0.991335    1.024446    3.507219    0.579280    0.057921    0.008364    0.702355    
#> 142: 1.029964    1.012192    3.518087    0.550316    0.057209    0.008061    0.698138    
#> 143: 0.969546    1.024223    3.518941    0.544796    0.058015    0.009265    0.697683    
#> 144: 1.025457    1.037573    3.515942    0.526421    0.059979    0.008802    0.676637    
#> 145: 0.947492    1.049803    3.493275    0.562995    0.058024    0.008362    0.676878    
#> 146: 0.956786    1.041980    3.498025    0.543241    0.059391    0.007944    0.674846    
#> 147: 0.917011    1.037774    3.492158    0.516079    0.056421    0.007624    0.683558    
#> 148: 0.868608    1.051218    3.494506    0.490275    0.060648    0.007842    0.682508    
#> 149: 0.920603    1.034045    3.496525    0.546885    0.057615    0.007821    0.690622    
#> 150: 0.994415    1.034420    3.488294    0.645633    0.062899    0.007430    0.676921    
#> 151: 1.025260    1.070451    3.484609    0.846056    0.059754    0.007058    0.674552    
#> 152: 1.059700    1.060989    3.493062    0.858454    0.060728    0.007154    0.683641    
#> 153: 1.015548    1.075697    3.485557    0.889715    0.071305    0.004362    0.686126    
#> 154: 0.987938    1.067153    3.493378    0.670603    0.068549    0.004550    0.683575    
#> 155: 0.924068    1.047382    3.489019    0.527927    0.065968    0.003062    0.691484    
#> 156: 0.920859    1.041807    3.494468    0.543308    0.075455    0.003175    0.702485    
#> 157: 0.959526    1.041425    3.499167    0.497987    0.078850    0.003247    0.719977    
#> 158: 0.972062    1.046587    3.500395    0.528361    0.071486    0.002826    0.702225    
#> 159: 0.923497    1.039192    3.501382    0.517366    0.064432    0.002134    0.707124    
#> 160: 1.028936    1.013123    3.510714    0.658855    0.067159    0.001897    0.712937    
#> 161: 0.966988    1.032320    3.503763    0.568468    0.076214    0.001950    0.727395    
#> 162: 0.977303    1.064748    3.490270    0.608803    0.060230    0.001832    0.712483    
#> 163: 0.951565    1.045548    3.492921    0.499413    0.069335    0.001896    0.706016    
#> 164: 0.959041    1.056704    3.490430    0.563735    0.075722    0.001963    0.707022    
#> 165: 0.976603    1.043409    3.495420    0.618227    0.082839    0.001831    0.711968    
#> 166: 1.028616    1.067901    3.487991    0.730835    0.084584    0.001636    0.721488    
#> 167: 1.028342    1.064321    3.495465    0.736767    0.086098    0.001010    0.747251    
#> 168: 0.994357    1.071654    3.500606    0.638384    0.080637    0.000809    0.726741    
#> 169: 1.010154    1.085559    3.494086    0.652551    0.092135    0.000747    0.758078    
#> 170: 0.995852    1.053663    3.490305    0.633822    0.085794    0.001041    0.723075    
#> 171: 0.995190    1.049131    3.489284    0.679346    0.098168    0.001005    0.711774    
#> 172: 0.972186    1.079317    3.487271    0.682673    0.070006    0.000926    0.716260    
#> 173: 1.005775    1.060821    3.484155    0.791370    0.068223    0.000817    0.706582    
#> 174: 1.016541    1.040016    3.485224    0.749295    0.073803    0.000942    0.702607    
#> 175: 0.952714    1.055397    3.482150    0.628031    0.076613    0.000620    0.707504    
#> 176: 0.975977    1.054251    3.484096    0.538975    0.077024    0.000578    0.704779    
#> 177: 0.941435    1.045875    3.488742    0.476563    0.082977    0.000640    0.713314    
#> 178: 0.937722    1.032514    3.489105    0.521283    0.079558    0.000560    0.718652    
#> 179: 1.004775    1.060767    3.489354    0.661170    0.067461    0.000512    0.742776    
#> 180: 0.907146    1.048706    3.490355    0.584448    0.069572    0.000412    0.727106    
#> 181: 0.922045    1.019984    3.486173    0.568714    0.070962    0.000275    0.721431    
#> 182: 0.891970    1.035115    3.483148    0.518586    0.084890    0.000306    0.745166    
#> 183: 0.940786    1.065096    3.481353    0.574836    0.066813    0.000342    0.723133    
#> 184: 0.940084    1.046411    3.481981    0.539022    0.071102    0.000347    0.733406    
#> 185: 0.908139    1.052003    3.478595    0.559690    0.087066    0.000453    0.707136    
#> 186: 0.911719    1.071217    3.482456    0.538739    0.072340    0.000477    0.722723    
#> 187: 0.924168    1.057866    3.483582    0.534242    0.063860    0.000626    0.704566    
#> 188: 0.894852    1.094293    3.478135    0.448373    0.071969    0.000722    0.717679    
#> 189: 0.914158    1.098003    3.478139    0.431729    0.066240    0.000923    0.725831    
#> 190: 0.878804    1.080386    3.481964    0.438627    0.064771    0.000923    0.712626    
#> 191: 0.877854    1.068865    3.479361    0.517226    0.059737    0.001060    0.722468    
#> 192: 0.878296    1.066812    3.480004    0.449807    0.073062    0.001156    0.713791    
#> 193: 0.938600    1.067004    3.481244    0.502971    0.065689    0.000925    0.712002    
#> 194: 0.903259    1.048978    3.481329    0.498126    0.075378    0.001063    0.713826    
#> 195: 0.860394    1.047712    3.476468    0.468227    0.072376    0.001154    0.711437    
#> 196: 0.910161    1.050336    3.480730    0.528342    0.070704    0.001103    0.707610    
#> 197: 0.915399    1.074840    3.482623    0.682712    0.064524    0.001029    0.711187    
#> 198: 1.015893    1.034255    3.478006    0.734805    0.080743    0.001333    0.701573    
#> 199: 0.873680    1.038482    3.477445    0.529087    0.063842    0.001386    0.703135    
#> 200: 0.861105    1.061567    3.476008    0.495642    0.071820    0.001469    0.724719    
#> 201: 0.878330    1.055275    3.476539    0.497950    0.072496    0.001415    0.709244    
#> 202: 0.881127    1.059753    3.476560    0.509675    0.070845    0.001530    0.708909    
#> 203: 0.892552    1.058669    3.476265    0.534133    0.069419    0.001682    0.707542    
#> 204: 0.898616    1.055540    3.476765    0.532204    0.073395    0.001768    0.708653    
#> 205: 0.905386    1.058934    3.476301    0.534978    0.074703    0.001767    0.709862    
#> 206: 0.912896    1.064501    3.476632    0.556945    0.075707    0.001768    0.712399    
#> 207: 0.915708    1.063438    3.475542    0.580942    0.078265    0.001773    0.713829    
#> 208: 0.918473    1.062996    3.474568    0.586087    0.076030    0.001740    0.712597    
#> 209: 0.921017    1.061177    3.474346    0.578689    0.074405    0.001719    0.711428    
#> 210: 0.921135    1.059837    3.474098    0.573572    0.073816    0.001710    0.710163    
#> 211: 0.921955    1.059715    3.474360    0.571095    0.072701    0.001672    0.708828    
#> 212: 0.925513    1.059445    3.474789    0.565331    0.072171    0.001693    0.707025    
#> 213: 0.927733    1.057691    3.474576    0.560905    0.072103    0.001716    0.707456    
#> 214: 0.928187    1.056557    3.474517    0.564066    0.071525    0.001728    0.707160    
#> 215: 0.927361    1.057515    3.474594    0.561099    0.071442    0.001715    0.707317    
#> 216: 0.927694    1.056713    3.475034    0.557350    0.071406    0.001697    0.707990    
#> 217: 0.927783    1.058066    3.475215    0.560968    0.071172    0.001701    0.707502    
#> 218: 0.926341    1.058261    3.475041    0.557475    0.072285    0.001698    0.706857    
#> 219: 0.924400    1.058227    3.474589    0.552863    0.072798    0.001672    0.707991    
#> 220: 0.921203    1.058386    3.474389    0.552450    0.073048    0.001641    0.709152    
#> 221: 0.920519    1.058519    3.474284    0.551384    0.073339    0.001625    0.709456    
#> 222: 0.919196    1.058219    3.474356    0.548236    0.073460    0.001621    0.709721    
#> 223: 0.920376    1.058002    3.474322    0.549396    0.073423    0.001620    0.709261    
#> 224: 0.922435    1.058514    3.474465    0.551151    0.073155    0.001617    0.709423    
#> 225: 0.920808    1.057171    3.474616    0.549683    0.073209    0.001614    0.709587    
#> 226: 0.919069    1.056070    3.474625    0.547391    0.072511    0.001612    0.709988    
#> 227: 0.917346    1.055796    3.474563    0.540992    0.071965    0.001607    0.710534    
#> 228: 0.916451    1.056588    3.474365    0.536473    0.071834    0.001620    0.710462    
#> 229: 0.915472    1.056356    3.474352    0.533252    0.071612    0.001631    0.709949    
#> 230: 0.916022    1.056005    3.474387    0.534137    0.071675    0.001636    0.709935    
#> 231: 0.916632    1.056194    3.474569    0.539578    0.072127    0.001637    0.709462    
#> 232: 0.916120    1.055915    3.474931    0.540114    0.072266    0.001646    0.709607    
#> 233: 0.916404    1.054949    3.475128    0.543235    0.072839    0.001648    0.709191    
#> 234: 0.916544    1.055010    3.475419    0.542293    0.073217    0.001651    0.708966    
#> 235: 0.916041    1.054448    3.475598    0.540258    0.073461    0.001638    0.708889    
#> 236: 0.917108    1.054711    3.475635    0.543680    0.073649    0.001628    0.709188    
#> 237: 0.919494    1.054828    3.475693    0.547076    0.073879    0.001634    0.709436    
#> 238: 0.920484    1.054819    3.475776    0.548422    0.073955    0.001643    0.709582    
#> 239: 0.919460    1.055450    3.475717    0.548722    0.074025    0.001644    0.709450    
#> 240: 0.920194    1.055095    3.475761    0.550261    0.073837    0.001639    0.709480    
#> 241: 0.921146    1.054246    3.475877    0.553531    0.073571    0.001641    0.709700    
#> 242: 0.921360    1.053835    3.475848    0.556284    0.073790    0.001651    0.709824    
#> 243: 0.921246    1.054226    3.475970    0.555391    0.073912    0.001662    0.710045    
#> 244: 0.921021    1.053984    3.476036    0.555875    0.073787    0.001690    0.710112    
#> 245: 0.920670    1.053531    3.476043    0.556766    0.073519    0.001709    0.710799    
#> 246: 0.920748    1.053603    3.476126    0.556124    0.073191    0.001727    0.711068    
#> 247: 0.921358    1.053703    3.476287    0.557249    0.073016    0.001739    0.711109    
#> 248: 0.921185    1.053940    3.476347    0.557673    0.073093    0.001742    0.710649    
#> 249: 0.920682    1.054223    3.476478    0.554739    0.073158    0.001747    0.710467    
#> 250: 0.921762    1.054469    3.476516    0.555278    0.072969    0.001762    0.710229    
#> 251: 0.922627    1.054798    3.476664    0.554833    0.072835    0.001764    0.710111    
#> 252: 0.922585    1.054901    3.476818    0.552701    0.072904    0.001767    0.710047    
#> 253: 0.921939    1.055067    3.476906    0.551627    0.072798    0.001778    0.709918    
#> 254: 0.922533    1.055373    3.477108    0.551892    0.072738    0.001782    0.709837    
#> 255: 0.923197    1.055593    3.477399    0.553847    0.073073    0.001802    0.709629    
#> 256: 0.923582    1.055290    3.477541    0.553663    0.073388    0.001824    0.709565    
#> 257: 0.923196    1.055089    3.477588    0.553178    0.073505    0.001831    0.709658    
#> 258: 0.923734    1.054708    3.477630    0.554120    0.073552    0.001822    0.709399    
#> 259: 0.923410    1.054571    3.477604    0.555245    0.073410    0.001813    0.709388    
#> 260: 0.922662    1.054856    3.477623    0.555087    0.073295    0.001805    0.709496    
#> 261: 0.922420    1.054862    3.477660    0.554979    0.073060    0.001806    0.709470    
#> 262: 0.922703    1.055182    3.477645    0.556688    0.073066    0.001807    0.709385    
#> 263: 0.922563    1.055552    3.477581    0.556797    0.073232    0.001814    0.708985    
#> 264: 0.921690    1.055652    3.477512    0.556529    0.073268    0.001812    0.709045    
#> 265: 0.923158    1.055812    3.477503    0.559641    0.073405    0.001824    0.708834    
#> 266: 0.924165    1.056142    3.477456    0.562992    0.073261    0.001834    0.708685    
#> 267: 0.924158    1.056335    3.477417    0.565044    0.073203    0.001842    0.708415    
#> 268: 0.925007    1.056084    3.477258    0.567808    0.073203    0.001844    0.708303    
#> 269: 0.926446    1.055624    3.477186    0.571393    0.073200    0.001846    0.708543    
#> 270: 0.927238    1.055747    3.477065    0.573334    0.073265    0.001840    0.708351    
#> 271: 0.927581    1.056059    3.476894    0.575723    0.073296    0.001839    0.708492    
#> 272: 0.927696    1.056213    3.476767    0.576677    0.073163    0.001841    0.708695    
#> 273: 0.927824    1.056662    3.476706    0.579925    0.073043    0.001839    0.709096    
#> 274: 0.928124    1.057072    3.476778    0.581405    0.073154    0.001841    0.709135    
#> 275: 0.928455    1.057109    3.476749    0.581597    0.073122    0.001853    0.709001    
#> 276: 0.928229    1.057259    3.476855    0.581617    0.073059    0.001865    0.708931    
#> 277: 0.927965    1.057185    3.477006    0.580497    0.073111    0.001874    0.708925    
#> 278: 0.928164    1.057061    3.477095    0.580313    0.073167    0.001885    0.709033    
#> 279: 0.928393    1.056786    3.477205    0.580366    0.073222    0.001901    0.709240    
#> 280: 0.928331    1.056825    3.477312    0.579441    0.073150    0.001916    0.709109    
#> 281: 0.928413    1.056939    3.477419    0.578699    0.073079    0.001922    0.708979    
#> 282: 0.928785    1.057151    3.477492    0.579061    0.073008    0.001928    0.709109    
#> 283: 0.928782    1.057067    3.477591    0.579093    0.072824    0.001934    0.709479    
#> 284: 0.928561    1.056756    3.477643    0.577990    0.072763    0.001940    0.709409    
#> 285: 0.928087    1.056589    3.477552    0.576549    0.072653    0.001943    0.709338    
#> 286: 0.927315    1.056745    3.477507    0.575863    0.072372    0.001947    0.709660    
#> 287: 0.926958    1.056786    3.477444    0.575485    0.072159    0.001949    0.709815    
#> 288: 0.927169    1.056734    3.477444    0.575322    0.071999    0.001956    0.709870    
#> 289: 0.927731    1.056615    3.477436    0.576414    0.071837    0.001964    0.709887    
#> 290: 0.928321    1.056632    3.477441    0.577266    0.071890    0.001966    0.709901    
#> 291: 0.928605    1.056851    3.477435    0.577407    0.071873    0.001967    0.709600    
#> 292: 0.928477    1.056902    3.477410    0.577176    0.071880    0.001970    0.709523    
#> 293: 0.928255    1.056899    3.477294    0.577682    0.071835    0.001978    0.709407    
#> 294: 0.928018    1.056991    3.477215    0.577210    0.071695    0.001985    0.709483    
#> 295: 0.927535    1.056554    3.477215    0.576544    0.071740    0.001984    0.709407    
#> 296: 0.927464    1.056250    3.477260    0.576588    0.071771    0.001988    0.709452    
#> 297: 0.927869    1.056391    3.477343    0.576199    0.071730    0.001990    0.709620    
#> 298: 0.927927    1.056454    3.477425    0.575892    0.071652    0.001994    0.709600    
#> 299: 0.928048    1.056595    3.477466    0.575802    0.071634    0.001996    0.709317    
#> 300: 0.928429    1.056434    3.477551    0.576095    0.071549    0.001999    0.709066    
#> 301: 0.929288    1.056454    3.477586    0.576995    0.071492    0.002000    0.708879    
#> 302: 0.929410    1.056542    3.477567    0.577223    0.071527    0.001999    0.708731    
#> 303: 0.929382    1.056683    3.477546    0.577390    0.071499    0.001997    0.708593    
#> 304: 0.929490    1.056836    3.477515    0.577172    0.071449    0.002003    0.708421    
#> 305: 0.929509    1.056586    3.477510    0.577134    0.071316    0.002012    0.708422    
#> 306: 0.929396    1.056374    3.477473    0.577803    0.071302    0.002012    0.708293    
#> 307: 0.929737    1.056385    3.477441    0.578407    0.071162    0.002015    0.708318    
#> 308: 0.929662    1.056283    3.477443    0.578454    0.071136    0.002022    0.708415    
#> 309: 0.930345    1.055987    3.477468    0.579094    0.071135    0.002031    0.708453    
#> 310: 0.930350    1.055952    3.477421    0.577877    0.071029    0.002033    0.708533    
#> 311: 0.930695    1.056037    3.477481    0.577998    0.070936    0.002041    0.708542    
#> 312: 0.930805    1.056031    3.477517    0.578441    0.070818    0.002054    0.708554    
#> 313: 0.930634    1.055859    3.477521    0.577969    0.070814    0.002068    0.708473    
#> 314: 0.930505    1.055746    3.477516    0.578089    0.070770    0.002073    0.708378    
#> 315: 0.930119    1.055838    3.477511    0.578263    0.070705    0.002085    0.708350    
#> 316: 0.930390    1.055768    3.477507    0.578734    0.070634    0.002089    0.708198    
#> 317: 0.930823    1.055744    3.477522    0.579893    0.070671    0.002092    0.708085    
#> 318: 0.931030    1.055646    3.477534    0.579911    0.070651    0.002099    0.707926    
#> 319: 0.931621    1.055629    3.477587    0.580728    0.070614    0.002111    0.707767    
#> 320: 0.931376    1.055773    3.477543    0.580069    0.070672    0.002117    0.707709    
#> 321: 0.930867    1.055854    3.477461    0.578798    0.070635    0.002119    0.707702    
#> 322: 0.930686    1.055961    3.477373    0.578346    0.070746    0.002117    0.707613    
#> 323: 0.930324    1.055968    3.477345    0.577955    0.070734    0.002118    0.707691    
#> 324: 0.930498    1.056026    3.477405    0.577954    0.070782    0.002119    0.707692    
#> 325: 0.930508    1.056237    3.477427    0.577940    0.070758    0.002118    0.707650    
#> 326: 0.930293    1.056039    3.477409    0.577536    0.070767    0.002118    0.707612    
#> 327: 0.930154    1.056153    3.477423    0.576951    0.070879    0.002117    0.707749    
#> 328: 0.929982    1.056135    3.477385    0.576888    0.070978    0.002116    0.707608    
#> 329: 0.930377    1.056096    3.477407    0.577868    0.071047    0.002122    0.707459    
#> 330: 0.930169    1.056103    3.477419    0.578488    0.071072    0.002129    0.707557    
#> 331: 0.930520    1.056203    3.477462    0.578467    0.071072    0.002128    0.707595    
#> 332: 0.930739    1.056180    3.477453    0.579153    0.071079    0.002128    0.707553    
#> 333: 0.930390    1.056238    3.477392    0.578706    0.071070    0.002127    0.707506    
#> 334: 0.930207    1.056168    3.477326    0.578419    0.071103    0.002124    0.707523    
#> 335: 0.930400    1.056281    3.477232    0.578849    0.071204    0.002125    0.707594    
#> 336: 0.930427    1.056627    3.477131    0.580283    0.071171    0.002131    0.707595    
#> 337: 0.930273    1.057010    3.477047    0.580336    0.071162    0.002134    0.707635    
#> 338: 0.929988    1.057156    3.477046    0.580267    0.071084    0.002137    0.707690    
#> 339: 0.929844    1.057376    3.477022    0.580175    0.070996    0.002143    0.707631    
#> 340: 0.929607    1.057478    3.476992    0.579536    0.070928    0.002146    0.707596    
#> 341: 0.929554    1.057502    3.477031    0.578881    0.070852    0.002151    0.707595    
#> 342: 0.929361    1.057388    3.477063    0.578250    0.070823    0.002157    0.707549    
#> 343: 0.929133    1.057417    3.477118    0.578283    0.070783    0.002156    0.707567    
#> 344: 0.929631    1.057577    3.477168    0.579509    0.070868    0.002158    0.707443    
#> 345: 0.929877    1.057553    3.477238    0.580070    0.070857    0.002159    0.707377    
#> 346: 0.930144    1.057585    3.477228    0.580712    0.070812    0.002159    0.707258    
#> 347: 0.930398    1.057530    3.477197    0.580960    0.070798    0.002166    0.707296    
#> 348: 0.930070    1.057630    3.477152    0.580786    0.070803    0.002173    0.707268    
#> 349: 0.930059    1.057563    3.477044    0.580856    0.070753    0.002181    0.707206    
#> 350: 0.930135    1.057529    3.476992    0.581317    0.070700    0.002185    0.707187    
#> 351: 0.930073    1.057584    3.476924    0.581051    0.070626    0.002189    0.707264    
#> 352: 0.929216    1.057650    3.476882    0.580376    0.070634    0.002193    0.707314    
#> 353: 0.929200    1.057838    3.476838    0.579982    0.070639    0.002193    0.707329    
#> 354: 0.929118    1.057859    3.476764    0.579743    0.070658    0.002194    0.707257    
#> 355: 0.929518    1.057801    3.476747    0.580233    0.070753    0.002196    0.707290    
#> 356: 0.929561    1.057705    3.476769    0.579910    0.070839    0.002194    0.707301    
#> 357: 0.929623    1.057854    3.476756    0.579086    0.070895    0.002191    0.707278    
#> 358: 0.929489    1.057893    3.476768    0.578861    0.070939    0.002188    0.707224    
#> 359: 0.929351    1.058070    3.476748    0.578716    0.070982    0.002186    0.707247    
#> 360: 0.929200    1.058124    3.476708    0.578152    0.070993    0.002190    0.707200    
#> 361: 0.928873    1.058156    3.476645    0.577899    0.070929    0.002190    0.707088    
#> 362: 0.928577    1.058195    3.476613    0.577214    0.070876    0.002187    0.707048    
#> 363: 0.928597    1.058233    3.476628    0.577328    0.070914    0.002193    0.706909    
#> 364: 0.928772    1.058237    3.476633    0.577704    0.070942    0.002198    0.706834    
#> 365: 0.928877    1.058200    3.476654    0.578167    0.071009    0.002203    0.706812    
#> 366: 0.928802    1.058141    3.476648    0.577623    0.070948    0.002207    0.706884    
#> 367: 0.928514    1.058138    3.476631    0.576948    0.070932    0.002209    0.706879    
#> 368: 0.928608    1.058223    3.476602    0.576348    0.070858    0.002211    0.706879    
#> 369: 0.928569    1.058251    3.476604    0.576040    0.070830    0.002214    0.706911    
#> 370: 0.928468    1.058317    3.476606    0.576176    0.070786    0.002218    0.706911    
#> 371: 0.928128    1.058315    3.476548    0.575820    0.070692    0.002220    0.706893    
#> 372: 0.927765    1.058418    3.476500    0.575810    0.070697    0.002219    0.707014    
#> 373: 0.927219    1.058493    3.476449    0.575045    0.070677    0.002218    0.707098    
#> 374: 0.927114    1.058647    3.476406    0.574467    0.070653    0.002219    0.707102    
#> 375: 0.926729    1.058638    3.476362    0.573529    0.070648    0.002219    0.707181    
#> 376: 0.926589    1.058740    3.476345    0.573688    0.070643    0.002217    0.707191    
#> 377: 0.926338    1.058767    3.476331    0.573408    0.070635    0.002213    0.707249    
#> 378: 0.926116    1.058790    3.476325    0.572980    0.070598    0.002215    0.707348    
#> 379: 0.925860    1.058679    3.476352    0.572781    0.070555    0.002216    0.707359    
#> 380: 0.925808    1.058574    3.476380    0.572617    0.070590    0.002218    0.707295    
#> 381: 0.925608    1.058504    3.476376    0.572576    0.070638    0.002219    0.707253    
#> 382: 0.926000    1.058508    3.476369    0.573013    0.070622    0.002221    0.707136    
#> 383: 0.926346    1.058538    3.476355    0.573877    0.070691    0.002219    0.707100    
#> 384: 0.926297    1.058524    3.476372    0.574028    0.070723    0.002219    0.707060    
#> 385: 0.926122    1.058520    3.476392    0.573674    0.070679    0.002216    0.706986    
#> 386: 0.926285    1.058539    3.476441    0.573986    0.070627    0.002213    0.706999    
#> 387: 0.926612    1.058557    3.476528    0.573827    0.070543    0.002217    0.706990    
#> 388: 0.926732    1.058549    3.476594    0.573476    0.070490    0.002220    0.706970    
#> 389: 0.926742    1.058461    3.476632    0.573213    0.070489    0.002221    0.707059    
#> 390: 0.926655    1.058446    3.476645    0.572800    0.070430    0.002224    0.707054    
#> 391: 0.926675    1.058478    3.476669    0.572458    0.070375    0.002229    0.706969    
#> 392: 0.926722    1.058441    3.476722    0.572593    0.070394    0.002232    0.706904    
#> 393: 0.926678    1.058326    3.476734    0.572765    0.070450    0.002235    0.706793    
#> 394: 0.926677    1.058374    3.476723    0.572891    0.070436    0.002232    0.706694    
#> 395: 0.926977    1.058369    3.476736    0.573446    0.070444    0.002231    0.706822    
#> 396: 0.927259    1.058423    3.476776    0.574029    0.070552    0.002232    0.706827    
#> 397: 0.927440    1.058321    3.476822    0.574632    0.070562    0.002232    0.706779    
#> 398: 0.927585    1.058217    3.476874    0.574879    0.070617    0.002236    0.706774    
#> 399: 0.927980    1.058205    3.476941    0.575761    0.070598    0.002235    0.706735    
#> 400: 0.928356    1.058387    3.476991    0.576218    0.070694    0.002235    0.706759    
#> 401: 0.928517    1.058516    3.477018    0.576488    0.070723    0.002236    0.706718    
#> 402: 0.928695    1.058557    3.477057    0.576603    0.070770    0.002237    0.706678    
#> 403: 0.929225    1.058557    3.477088    0.577487    0.070746    0.002236    0.706690    
#> 404: 0.929412    1.058615    3.477061    0.577880    0.070763    0.002240    0.706609    
#> 405: 0.929225    1.058649    3.477078    0.577253    0.070799    0.002244    0.706615    
#> 406: 0.929218    1.058641    3.477082    0.577051    0.070781    0.002250    0.706617    
#> 407: 0.929377    1.058698    3.477106    0.577421    0.070815    0.002255    0.706592    
#> 408: 0.929680    1.058803    3.477120    0.577919    0.070859    0.002259    0.706541    
#> 409: 0.929694    1.058756    3.477082    0.578214    0.070846    0.002264    0.706473    
#> 410: 0.929730    1.058774    3.477033    0.578876    0.070850    0.002268    0.706425    
#> 411: 0.930173    1.058669    3.477018    0.580114    0.070838    0.002270    0.706415    
#> 412: 0.930162    1.058798    3.476989    0.580016    0.070852    0.002269    0.706361    
#> 413: 0.930127    1.058829    3.476948    0.580675    0.070885    0.002268    0.706316    
#> 414: 0.930080    1.058860    3.476934    0.581517    0.070921    0.002266    0.706244    
#> 415: 0.930140    1.058843    3.476935    0.581575    0.070930    0.002265    0.706151    
#> 416: 0.930135    1.058891    3.476953    0.581584    0.070913    0.002265    0.706013    
#> 417: 0.930207    1.058916    3.476984    0.581649    0.070896    0.002267    0.705967    
#> 418: 0.930047    1.058940    3.477008    0.581081    0.070915    0.002272    0.706028    
#> 419: 0.930060    1.058974    3.476985    0.581006    0.070815    0.002277    0.706060    
#> 420: 0.929821    1.059047    3.476991    0.580476    0.070770    0.002277    0.706041    
#> 421: 0.929565    1.059101    3.476995    0.580343    0.070784    0.002278    0.706034    
#> 422: 0.929694    1.059073    3.476988    0.580595    0.070767    0.002277    0.706083    
#> 423: 0.929832    1.059061    3.477003    0.580443    0.070747    0.002276    0.706119    
#> 424: 0.929644    1.059119    3.476975    0.580059    0.070680    0.002275    0.706222    
#> 425: 0.929445    1.059161    3.476946    0.579798    0.070620    0.002274    0.706306    
#> 426: 0.929365    1.059334    3.476944    0.579517    0.070610    0.002273    0.706430    
#> 427: 0.929280    1.059339    3.476941    0.579435    0.070580    0.002274    0.706403    
#> 428: 0.929243    1.059378    3.476919    0.579061    0.070574    0.002274    0.706395    
#> 429: 0.929132    1.059400    3.476928    0.578494    0.070568    0.002273    0.706392    
#> 430: 0.929228    1.059390    3.476936    0.578503    0.070616    0.002272    0.706346    
#> 431: 0.929351    1.059333    3.476926    0.579073    0.070583    0.002271    0.706363    
#> 432: 0.929483    1.059402    3.476927    0.580000    0.070591    0.002274    0.706336    
#> 433: 0.929436    1.059473    3.476929    0.580111    0.070555    0.002274    0.706261    
#> 434: 0.929392    1.059320    3.476963    0.580119    0.070512    0.002275    0.706232    
#> 435: 0.929529    1.059260    3.477016    0.580226    0.070451    0.002278    0.706193    
#> 436: 0.929814    1.059143    3.477067    0.580481    0.070385    0.002277    0.706320    
#> 437: 0.929972    1.059070    3.477092    0.580432    0.070371    0.002279    0.706400    
#> 438: 0.929860    1.059140    3.477124    0.580083    0.070339    0.002279    0.706417    
#> 439: 0.929883    1.059229    3.477123    0.580387    0.070280    0.002277    0.706431    
#> 440: 0.929741    1.059256    3.477141    0.580146    0.070216    0.002275    0.706479    
#> 441: 0.929851    1.059151    3.477171    0.580469    0.070200    0.002274    0.706406    
#> 442: 0.929921    1.059167    3.477180    0.580668    0.070186    0.002274    0.706391    
#> 443: 0.930035    1.059246    3.477184    0.580734    0.070195    0.002275    0.706339    
#> 444: 0.930090    1.059278    3.477179    0.580840    0.070249    0.002273    0.706330    
#> 445: 0.930011    1.059338    3.477157    0.580608    0.070244    0.002273    0.706373    
#> 446: 0.929962    1.059407    3.477152    0.580414    0.070204    0.002272    0.706383    
#> 447: 0.930030    1.059452    3.477146    0.580341    0.070193    0.002274    0.706347    
#> 448: 0.929971    1.059520    3.477157    0.580458    0.070196    0.002275    0.706278    
#> 449: 0.929873    1.059620    3.477218    0.580068    0.070202    0.002274    0.706296    
#> 450: 0.929837    1.059634    3.477251    0.579900    0.070182    0.002272    0.706298    
#> 451: 0.929747    1.059637    3.477270    0.579502    0.070217    0.002271    0.706357    
#> 452: 0.929704    1.059689    3.477254    0.579846    0.070243    0.002269    0.706303    
#> 453: 0.929568    1.059708    3.477233    0.579819    0.070234    0.002268    0.706223    
#> 454: 0.929363    1.059791    3.477222    0.579370    0.070224    0.002268    0.706232    
#> 455: 0.929379    1.059837    3.477198    0.579329    0.070249    0.002272    0.706170    
#> 456: 0.929258    1.059785    3.477195    0.579150    0.070236    0.002275    0.706199    
#> 457: 0.929224    1.059752    3.477192    0.579076    0.070209    0.002278    0.706199    
#> 458: 0.929257    1.059822    3.477218    0.578990    0.070230    0.002284    0.706172    
#> 459: 0.928987    1.059969    3.477232    0.578933    0.070277    0.002287    0.706160    
#> 460: 0.928801    1.060009    3.477220    0.578852    0.070252    0.002290    0.706140    
#> 461: 0.928843    1.060049    3.477233    0.578728    0.070301    0.002290    0.706159    
#> 462: 0.928903    1.060078    3.477269    0.578700    0.070318    0.002291    0.706115    
#> 463: 0.929081    1.060126    3.477289    0.578785    0.070232    0.002291    0.706163    
#> 464: 0.929170    1.060106    3.477317    0.578779    0.070182    0.002292    0.706095    
#> 465: 0.929261    1.059989    3.477322    0.578536    0.070186    0.002292    0.706067    
#> 466: 0.929258    1.059995    3.477319    0.578331    0.070176    0.002292    0.706074    
#> 467: 0.929205    1.059982    3.477309    0.578286    0.070145    0.002291    0.706041    
#> 468: 0.929291    1.059986    3.477314    0.578154    0.070143    0.002291    0.706030    
#> 469: 0.929491    1.060046    3.477335    0.578260    0.070129    0.002293    0.706056    
#> 470: 0.929398    1.060068    3.477367    0.578117    0.070093    0.002295    0.706065    
#> 471: 0.929388    1.060033    3.477390    0.577825    0.070086    0.002297    0.706034    
#> 472: 0.929307    1.060008    3.477426    0.577575    0.070069    0.002298    0.706036    
#> 473: 0.929160    1.059970    3.477442    0.577169    0.070063    0.002300    0.706005    
#> 474: 0.929175    1.059965    3.477459    0.576984    0.070078    0.002300    0.706129    
#> 475: 0.929259    1.060044    3.477467    0.576782    0.070028    0.002302    0.706233    
#> 476: 0.929226    1.060079    3.477464    0.576597    0.070002    0.002301    0.706307    
#> 477: 0.929133    1.060108    3.477471    0.576375    0.069990    0.002300    0.706279    
#> 478: 0.929087    1.060088    3.477470    0.576627    0.069995    0.002299    0.706293    
#> 479: 0.929309    1.060143    3.477475    0.577398    0.070037    0.002299    0.706355    
#> 480: 0.929429    1.060188    3.477511    0.577707    0.070043    0.002299    0.706407    
#> 481: 0.929560    1.060138    3.477553    0.577977    0.070060    0.002297    0.706409    
#> 482: 0.929785    1.060105    3.477574    0.578048    0.070083    0.002297    0.706393    
#> 483: 0.929772    1.060016    3.477602    0.577917    0.070084    0.002297    0.706434    
#> 484: 0.929920    1.059908    3.477636    0.577896    0.070125    0.002297    0.706444    
#> 485: 0.930067    1.059953    3.477651    0.578148    0.070172    0.002299    0.706451    
#> 486: 0.930210    1.059961    3.477680    0.578237    0.070180    0.002300    0.706470    
#> 487: 0.930534    1.059967    3.477740    0.578403    0.070160    0.002301    0.706430    
#> 488: 0.930750    1.059931    3.477784    0.578987    0.070143    0.002304    0.706385    
#> 489: 0.930885    1.059906    3.477810    0.578986    0.070167    0.002307    0.706320    
#> 490: 0.931003    1.059872    3.477850    0.578670    0.070139    0.002310    0.706341    
#> 491: 0.931136    1.059899    3.477877    0.578588    0.070152    0.002311    0.706288    
#> 492: 0.931132    1.059913    3.477884    0.578525    0.070164    0.002312    0.706283    
#> 493: 0.931198    1.059901    3.477899    0.578576    0.070169    0.002315    0.706252    
#> 494: 0.931448    1.059910    3.477914    0.579022    0.070124    0.002315    0.706243    
#> 495: 0.931657    1.059894    3.477932    0.579467    0.070090    0.002318    0.706212    
#> 496: 0.931738    1.059961    3.477915    0.579586    0.070052    0.002318    0.706241    
#> 497: 0.931714    1.059965    3.477917    0.579385    0.070035    0.002320    0.706295    
#> 498: 0.931877    1.059931    3.477906    0.579459    0.070002    0.002323    0.706295    
#> 499: 0.931906    1.059944    3.477897    0.579321    0.070029    0.002326    0.706266    
#> 500: 0.932099    1.059909    3.477880    0.579757    0.070027    0.002330    0.706228    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.333124    0.965971    3.444501    0.392401    0.077141    0.016800    1.861600    
#> 002: 0.309002    1.023565    3.464664    0.372781    0.073284    0.015960    1.240504    
#> 003: 0.435808    0.976335    3.448130    0.354142    0.078115    0.015162    0.922010    
#> 004: 0.356973    0.988742    3.429968    0.336435    0.097167    0.014404    0.805939    
#> 005: 0.431552    1.002275    3.430892    0.361141    0.102105    0.013684    0.744558    
#> 006: 0.415336    0.999765    3.419233    0.410304    0.103783    0.013000    0.695887    
#> 007: 0.375262    1.004694    3.415039    0.429790    0.098594    0.012682    0.708461    
#> 008: 0.352696    0.996262    3.413697    0.408300    0.103993    0.014877    0.704023    
#> 009: 0.342979    0.985076    3.412415    0.387885    0.098793    0.014133    0.718655    
#> 010: 0.357293    0.991429    3.412188    0.428338    0.099365    0.016766    0.696996    
#> 011: 0.408451    0.988105    3.408423    0.406921    0.094397    0.017312    0.711353    
#> 012: 0.417065    0.998681    3.412778    0.416339    0.118742    0.016446    0.703983    
#> 013: 0.376567    1.011912    3.413608    0.395522    0.112805    0.015696    0.690643    
#> 014: 0.427285    0.974839    3.427641    0.523766    0.107165    0.018328    0.702684    
#> 015: 0.447381    0.984633    3.448702    0.497578    0.102016    0.017560    0.676383    
#> 016: 0.443601    0.997643    3.441277    0.508756    0.096915    0.020647    0.695394    
#> 017: 0.408228    0.996604    3.434245    0.514000    0.092506    0.022645    0.658185    
#> 018: 0.409688    1.000155    3.424217    0.488300    0.092131    0.021515    0.663700    
#> 019: 0.407419    1.002147    3.420677    0.467801    0.094944    0.020439    0.669886    
#> 020: 0.427720    1.004883    3.426133    0.475295    0.090197    0.019448    0.676760    
#> 021: 0.425344    0.996616    3.434082    0.512189    0.086985    0.020743    0.673156    
#> 022: 0.425361    0.995775    3.439099    0.542638    0.082635    0.022997    0.665579    
#> 023: 0.497496    0.994261    3.444270    0.515506    0.083009    0.021847    0.691655    
#> 024: 0.471653    1.011004    3.446922    0.489731    0.078858    0.020755    0.699825    
#> 025: 0.435712    0.974206    3.444126    0.481863    0.097135    0.024936    0.682415    
#> 026: 0.453521    0.997466    3.439730    0.487631    0.092279    0.026732    0.670617    
#> 027: 0.421459    1.008458    3.429129    0.502238    0.087665    0.032279    0.670243    
#> 028: 0.440989    1.013832    3.437904    0.529949    0.083281    0.030665    0.667718    
#> 029: 0.450654    0.992422    3.429661    0.521322    0.079117    0.029264    0.704806    
#> 030: 0.468773    1.008663    3.424697    0.526884    0.075161    0.027801    0.681755    
#> 031: 0.390852    0.988448    3.443678    0.500540    0.071403    0.028375    0.686146    
#> 032: 0.422980    0.975396    3.450654    0.475513    0.079905    0.026957    0.679650    
#> 033: 0.416823    0.990511    3.443492    0.508764    0.075910    0.025609    0.680201    
#> 034: 0.445551    0.995445    3.440329    0.483326    0.075541    0.024328    0.668769    
#> 035: 0.446965    0.978289    3.430183    0.515035    0.071764    0.023112    0.665668    
#> 036: 0.436768    0.997545    3.427209    0.489283    0.072529    0.022177    0.674192    
#> 037: 0.435395    1.000952    3.446247    0.474783    0.084974    0.028717    0.688654    
#> 038: 0.479590    0.992335    3.434358    0.591226    0.080726    0.027390    0.663582    
#> 039: 0.477642    0.979372    3.439799    0.594164    0.076689    0.031809    0.650379    
#> 040: 0.444737    0.982167    3.448736    0.564456    0.072924    0.031963    0.670924    
#> 041: 0.417276    0.979647    3.432681    0.536233    0.072940    0.030364    0.672849    
#> 042: 0.436014    0.982958    3.434888    0.551765    0.088193    0.028846    0.648193    
#> 043: 0.420406    0.996208    3.426966    0.524177    0.091063    0.027404    0.652841    
#> 044: 0.428520    0.998228    3.425246    0.513724    0.086510    0.026034    0.668555    
#> 045: 0.403060    1.017024    3.430463    0.488038    0.082184    0.025683    0.678409    
#> 046: 0.449938    0.994210    3.438242    0.508314    0.086542    0.024399    0.664481    
#> 047: 0.455309    1.009494    3.430090    0.537153    0.090618    0.024143    0.655749    
#> 048: 0.460542    0.986740    3.432966    0.639769    0.087240    0.027471    0.665411    
#> 049: 0.437289    0.994260    3.432394    0.607781    0.082878    0.026097    0.685002    
#> 050: 0.456208    0.980906    3.433311    0.577392    0.078734    0.028452    0.684535    
#> 051: 0.440346    0.990096    3.423172    0.548522    0.089140    0.027030    0.673051    
#> 052: 0.464121    0.994843    3.439062    0.590147    0.089369    0.025678    0.663766    
#> 053: 0.476736    0.976096    3.430099    0.566273    0.084900    0.024394    0.662281    
#> 054: 0.440819    0.994279    3.438362    0.537959    0.097108    0.023175    0.682582    
#> 055: 0.466058    1.001938    3.448630    0.511061    0.092253    0.024219    0.684699    
#> 056: 0.435052    0.969213    3.437153    0.492917    0.092516    0.025257    0.688478    
#> 057: 0.451053    0.954320    3.443384    0.499726    0.089584    0.025459    0.677780    
#> 058: 0.455576    0.954178    3.435553    0.474740    0.085104    0.026599    0.668794    
#> 059: 0.457506    0.959437    3.442600    0.535704    0.099496    0.025269    0.671708    
#> 060: 0.503198    0.957352    3.453549    0.595065    0.094521    0.024298    0.676392    
#> 061: 0.544592    0.986743    3.465212    0.660594    0.096906    0.027753    0.687399    
#> 062: 0.494614    0.977342    3.469995    0.627564    0.104454    0.026366    0.696675    
#> 063: 0.513369    0.937027    3.456165    0.596186    0.099231    0.027389    0.706918    
#> 064: 0.506816    0.945204    3.461136    0.606553    0.094270    0.029452    0.686428    
#> 065: 0.525223    0.943926    3.456024    0.595377    0.093839    0.027980    0.686380    
#> 066: 0.481869    0.972793    3.455947    0.565608    0.089147    0.026581    0.673220    
#> 067: 0.444349    0.956985    3.434757    0.579766    0.084690    0.026630    0.669984    
#> 068: 0.414800    0.977476    3.435258    0.550777    0.080455    0.025648    0.668542    
#> 069: 0.400938    0.976001    3.423631    0.523239    0.078659    0.028676    0.670930    
#> 070: 0.422116    0.977158    3.434193    0.553281    0.099555    0.027242    0.669256    
#> 071: 0.454193    0.993844    3.427166    0.525617    0.094578    0.025880    0.680907    
#> 072: 0.445593    0.968727    3.436243    0.507834    0.092215    0.024586    0.663112    
#> 073: 0.432462    0.973805    3.444335    0.497695    0.095550    0.025335    0.673529    
#> 074: 0.428831    0.959654    3.439972    0.472811    0.090773    0.024068    0.687793    
#> 075: 0.465615    0.945164    3.469716    0.478953    0.092983    0.023774    0.703462    
#> 076: 0.486671    0.958021    3.473938    0.455005    0.088334    0.024387    0.704883    
#> 077: 0.535675    0.949637    3.470529    0.451822    0.083917    0.027484    0.703426    
#> 078: 0.527371    0.949343    3.468712    0.448987    0.083184    0.028348    0.683245    
#> 079: 0.498644    0.974467    3.456658    0.489830    0.094978    0.030847    0.684127    
#> 080: 0.469273    0.970937    3.455237    0.550212    0.100311    0.031255    0.694157    
#> 081: 0.486526    0.985048    3.444741    0.564710    0.095296    0.029692    0.677553    
#> 082: 0.474959    0.976228    3.451689    0.536474    0.090531    0.028207    0.684298    
#> 083: 0.510802    0.984412    3.449252    0.583938    0.087161    0.028864    0.665076    
#> 084: 0.441029    0.972021    3.437378    0.554741    0.082803    0.032669    0.670653    
#> 085: 0.455517    0.973057    3.452589    0.527004    0.081199    0.031036    0.684712    
#> 086: 0.422654    1.000958    3.438014    0.500653    0.084283    0.029484    0.677020    
#> 087: 0.440548    0.995335    3.431654    0.491460    0.080069    0.028010    0.689832    
#> 088: 0.376069    0.986579    3.438203    0.496532    0.076065    0.026609    0.676332    
#> 089: 0.409936    0.992584    3.419443    0.477850    0.073019    0.025279    0.681471    
#> 090: 0.372714    0.998146    3.415779    0.525998    0.075355    0.024015    0.682104    
#> 091: 0.395418    0.996493    3.408095    0.537046    0.071588    0.022814    0.687716    
#> 092: 0.401025    1.015040    3.409513    0.517556    0.080433    0.021705    0.675402    
#> 093: 0.400002    0.996846    3.420281    0.530645    0.076411    0.021287    0.682698    
#> 094: 0.413186    1.000977    3.421229    0.504113    0.084185    0.020515    0.673306    
#> 095: 0.426035    0.996614    3.427935    0.626090    0.079976    0.021471    0.677008    
#> 096: 0.425006    1.001969    3.425902    0.617818    0.075977    0.026372    0.669100    
#> 097: 0.431847    1.006274    3.420487    0.586927    0.072179    0.025277    0.681127    
#> 098: 0.435559    1.012862    3.424239    0.557581    0.074750    0.025592    0.673681    
#> 099: 0.430823    0.996648    3.415392    0.642171    0.080534    0.024312    0.682201    
#> 100: 0.411885    0.995355    3.414857    0.638447    0.079537    0.026640    0.670522    
#> 101: 0.409867    0.980398    3.409238    0.606525    0.075560    0.026859    0.651914    
#> 102: 0.399175    0.999117    3.410923    0.576199    0.076201    0.025516    0.668312    
#> 103: 0.421310    0.994392    3.422846    0.547389    0.078429    0.024240    0.666404    
#> 104: 0.424099    1.000283    3.432996    0.565027    0.087086    0.023028    0.665980    
#> 105: 0.455686    0.987473    3.427623    0.631790    0.101957    0.021877    0.684943    
#> 106: 0.453544    0.974618    3.426534    0.600201    0.097712    0.022526    0.672023    
#> 107: 0.470623    0.986602    3.429674    0.615177    0.095923    0.022100    0.667184    
#> 108: 0.451796    0.984607    3.439829    0.584418    0.091127    0.020995    0.686603    
#> 109: 0.452970    0.987122    3.445866    0.555197    0.086570    0.019946    0.674282    
#> 110: 0.469536    0.964220    3.433473    0.550429    0.084110    0.018948    0.667807    
#> 111: 0.470859    0.991948    3.439637    0.556051    0.084793    0.018001    0.669073    
#> 112: 0.417883    0.975438    3.428115    0.528248    0.092020    0.017676    0.677163    
#> 113: 0.413940    1.014381    3.426706    0.501836    0.087419    0.017247    0.657277    
#> 114: 0.429014    1.013041    3.425226    0.476744    0.083048    0.018256    0.669491    
#> 115: 0.430930    0.978579    3.427633    0.475297    0.094196    0.018469    0.677261    
#> 116: 0.445346    0.991921    3.429118    0.525542    0.089486    0.020662    0.668020    
#> 117: 0.438123    1.008260    3.445200    0.499265    0.085012    0.025110    0.675023    
#> 118: 0.483366    0.974890    3.448069    0.549557    0.080761    0.032572    0.677619    
#> 119: 0.481330    0.984801    3.438379    0.619070    0.085358    0.036099    0.683079    
#> 120: 0.416852    0.975380    3.430317    0.589548    0.089805    0.034294    0.676430    
#> 121: 0.435113    1.016674    3.428294    0.592284    0.085315    0.032580    0.664100    
#> 122: 0.442302    1.009251    3.430522    0.562670    0.093948    0.030951    0.660556    
#> 123: 0.401899    1.028083    3.418923    0.534537    0.089250    0.029403    0.680706    
#> 124: 0.426933    1.025496    3.421151    0.530231    0.084788    0.027933    0.672741    
#> 125: 0.436043    1.013181    3.427272    0.551960    0.080548    0.026536    0.679913    
#> 126: 0.397958    1.014251    3.412262    0.549649    0.078495    0.025209    0.683012    
#> 127: 0.432561    0.995334    3.408896    0.522167    0.090944    0.025596    0.682403    
#> 128: 0.396054    1.000709    3.419322    0.609367    0.086397    0.026081    0.684125    
#> 129: 0.406477    0.993905    3.418427    0.621505    0.088657    0.027224    0.677137    
#> 130: 0.435281    1.001113    3.416687    0.590429    0.085981    0.025862    0.676167    
#> 131: 0.397446    0.993835    3.408334    0.560908    0.081682    0.024829    0.674262    
#> 132: 0.363782    1.007900    3.384606    0.532862    0.087587    0.023587    0.690889    
#> 133: 0.354832    1.013495    3.399967    0.506219    0.109058    0.022408    0.670958    
#> 134: 0.395803    0.995504    3.420625    0.534529    0.105426    0.021288    0.678671    
#> 135: 0.376674    1.002176    3.415022    0.564585    0.106319    0.021671    0.683977    
#> 136: 0.384538    0.975790    3.421223    0.611332    0.111142    0.021732    0.670860    
#> 137: 0.482653    0.973211    3.434886    0.708983    0.105585    0.022405    0.687052    
#> 138: 0.454525    0.995304    3.424705    0.673534    0.100305    0.021285    0.677400    
#> 139: 0.413222    1.013319    3.418073    0.639857    0.101831    0.021401    0.669420    
#> 140: 0.453697    1.006539    3.435489    0.654775    0.102014    0.024459    0.668166    
#> 141: 0.442902    0.994490    3.432280    0.622036    0.117298    0.023236    0.673034    
#> 142: 0.479922    0.988544    3.445219    0.613638    0.111434    0.022074    0.679153    
#> 143: 0.441783    0.999662    3.439087    0.582956    0.105862    0.021387    0.683059    
#> 144: 0.486512    1.004413    3.440250    0.553809    0.100569    0.020633    0.654341    
#> 145: 0.429788    1.011354    3.425736    0.526118    0.099104    0.022160    0.647174    
#> 146: 0.440970    1.008344    3.432282    0.499812    0.094149    0.021052    0.661041    
#> 147: 0.396119    0.975254    3.423151    0.504529    0.089676    0.022370    0.666294    
#> 148: 0.413702    0.979784    3.426844    0.491324    0.085192    0.024598    0.656912    
#> 149: 0.412040    0.980194    3.437359    0.466758    0.090454    0.024980    0.668180    
#> 150: 0.466899    0.983500    3.423332    0.492018    0.085931    0.026555    0.672987    
#> 151: 0.411331    1.001956    3.421681    0.467417    0.081634    0.027346    0.670708    
#> 152: 0.371786    1.014303    3.417802    0.470067    0.076739    0.027336    0.661732    
#> 153: 0.367237    1.015353    3.428492    0.498058    0.071670    0.028023    0.675627    
#> 154: 0.441096    1.012343    3.434204    0.501063    0.087152    0.027274    0.677826    
#> 155: 0.445637    0.988620    3.432755    0.533030    0.100101    0.022802    0.671796    
#> 156: 0.446673    0.996268    3.436870    0.465687    0.113176    0.019643    0.668977    
#> 157: 0.428263    0.992590    3.441667    0.434371    0.110090    0.018086    0.685119    
#> 158: 0.482464    0.991258    3.441681    0.443482    0.094823    0.019575    0.676338    
#> 159: 0.440916    0.977897    3.451043    0.388924    0.072343    0.020433    0.693842    
#> 160: 0.471261    0.941606    3.464379    0.462039    0.084091    0.019101    0.700498    
#> 161: 0.469528    0.965644    3.453311    0.422265    0.090678    0.015087    0.698303    
#> 162: 0.444150    0.982878    3.439806    0.422784    0.101566    0.016383    0.693749    
#> 163: 0.434537    0.979917    3.427349    0.479861    0.105655    0.012791    0.678340    
#> 164: 0.456496    0.981663    3.431206    0.488871    0.101200    0.015514    0.671297    
#> 165: 0.444010    0.971629    3.439061    0.498154    0.088638    0.022075    0.673443    
#> 166: 0.493334    1.004661    3.441166    0.558743    0.098618    0.018694    0.683308    
#> 167: 0.483352    1.001983    3.446057    0.557210    0.094211    0.014741    0.688380    
#> 168: 0.450255    0.985636    3.445466    0.481735    0.114126    0.016505    0.663221    
#> 169: 0.431254    1.028355    3.427366    0.468117    0.099307    0.014063    0.679938    
#> 170: 0.438447    0.996874    3.436553    0.428390    0.089777    0.016093    0.669485    
#> 171: 0.424124    0.990550    3.434291    0.415850    0.091690    0.019928    0.673901    
#> 172: 0.404743    1.004466    3.431268    0.439792    0.090199    0.020590    0.663736    
#> 173: 0.435495    1.011118    3.427701    0.418451    0.092034    0.022303    0.662622    
#> 174: 0.428502    0.996632    3.434392    0.449594    0.082374    0.026578    0.679875    
#> 175: 0.437885    0.980361    3.423197    0.469017    0.092660    0.029211    0.682552    
#> 176: 0.401608    1.001560    3.433239    0.447149    0.083221    0.025317    0.676201    
#> 177: 0.452435    0.993082    3.440116    0.539472    0.089809    0.033929    0.656590    
#> 178: 0.429930    0.974742    3.428778    0.513841    0.088260    0.030955    0.663722    
#> 179: 0.478219    1.002519    3.425653    0.598376    0.085970    0.029122    0.673080    
#> 180: 0.443834    0.984147    3.442054    0.455237    0.082775    0.030551    0.669929    
#> 181: 0.450234    0.995952    3.433042    0.448621    0.067642    0.029981    0.676205    
#> 182: 0.424059    0.995276    3.425277    0.447215    0.094656    0.029213    0.700833    
#> 183: 0.466798    1.010342    3.432063    0.438067    0.070661    0.026517    0.720333    
#> 184: 0.441983    0.972280    3.447793    0.519665    0.063751    0.030262    0.709436    
#> 185: 0.400345    0.985193    3.437671    0.516355    0.066722    0.032750    0.692750    
#> 186: 0.389960    0.995898    3.424933    0.525369    0.062137    0.041022    0.703854    
#> 187: 0.398022    0.982538    3.419723    0.546413    0.068359    0.034241    0.700801    
#> 188: 0.407949    0.993779    3.424974    0.548384    0.082244    0.031110    0.703478    
#> 189: 0.422336    0.992014    3.444707    0.495690    0.076480    0.028505    0.701283    
#> 190: 0.425575    0.988364    3.445687    0.471602    0.072654    0.029790    0.669237    
#> 191: 0.404980    1.006761    3.430892    0.465003    0.083562    0.025075    0.668952    
#> 192: 0.406009    1.004419    3.431905    0.482859    0.085147    0.020820    0.682019    
#> 193: 0.448294    1.006054    3.438361    0.533148    0.084360    0.015384    0.684437    
#> 194: 0.440197    0.996669    3.430307    0.538760    0.096597    0.012198    0.705877    
#> 195: 0.388483    1.009542    3.420367    0.491253    0.102917    0.013150    0.684029    
#> 196: 0.410980    0.988439    3.430717    0.486146    0.112882    0.011636    0.701729    
#> 197: 0.397910    0.991092    3.448447    0.446095    0.100904    0.015166    0.700068    
#> 198: 0.479953    0.960193    3.446456    0.520377    0.099518    0.016108    0.684919    
#> 199: 0.465141    0.964833    3.450862    0.456041    0.106867    0.012699    0.695532    
#> 200: 0.434561    0.967293    3.444203    0.453296    0.106094    0.014741    0.715978    
#> 201: 0.436953    0.969140    3.446491    0.439171    0.108814    0.015413    0.700930    
#> 202: 0.433513    0.977720    3.443644    0.438232    0.104475    0.016042    0.699971    
#> 203: 0.437950    0.981239    3.438859    0.449185    0.101279    0.017003    0.698104    
#> 204: 0.436132    0.975600    3.440533    0.447149    0.101815    0.016964    0.702015    
#> 205: 0.435562    0.980708    3.441151    0.445459    0.103578    0.017074    0.708102    
#> 206: 0.437681    0.984209    3.442059    0.451816    0.104663    0.016981    0.713285    
#> 207: 0.434746    0.985643    3.440062    0.445859    0.103530    0.016952    0.714050    
#> 208: 0.432458    0.986244    3.439508    0.434053    0.101468    0.016813    0.712641    
#> 209: 0.434763    0.984761    3.438575    0.438031    0.099978    0.016879    0.709672    
#> 210: 0.435061    0.984768    3.438696    0.439848    0.099140    0.016780    0.706644    
#> 211: 0.438670    0.986645    3.438622    0.440523    0.099114    0.016753    0.704924    
#> 212: 0.441357    0.986531    3.438646    0.447047    0.099774    0.016676    0.702942    
#> 213: 0.440461    0.984178    3.438806    0.445335    0.100043    0.016602    0.703076    
#> 214: 0.441343    0.983235    3.438597    0.444236    0.100614    0.016488    0.702301    
#> 215: 0.440633    0.983040    3.438701    0.441983    0.101209    0.016495    0.702201    
#> 216: 0.444556    0.982464    3.439131    0.449076    0.102509    0.016556    0.703321    
#> 217: 0.444548    0.984426    3.439187    0.451105    0.102579    0.016580    0.703321    
#> 218: 0.445710    0.985284    3.439002    0.452287    0.101908    0.016645    0.702741    
#> 219: 0.445468    0.985882    3.438408    0.455166    0.101297    0.016729    0.702277    
#> 220: 0.443296    0.986576    3.438027    0.454590    0.100812    0.016691    0.702169    
#> 221: 0.441307    0.987664    3.437046    0.453816    0.100520    0.016587    0.702146    
#> 222: 0.439750    0.988087    3.436274    0.455473    0.101076    0.016530    0.702626    
#> 223: 0.440651    0.987984    3.435974    0.457708    0.101173    0.016626    0.702155    
#> 224: 0.442385    0.988970    3.435955    0.460733    0.101293    0.016783    0.701189    
#> 225: 0.443402    0.987821    3.436177    0.463191    0.100724    0.016994    0.700071    
#> 226: 0.443866    0.986628    3.435966    0.468305    0.100573    0.017165    0.699327    
#> 227: 0.445029    0.986392    3.436240    0.471358    0.100234    0.017274    0.697843    
#> 228: 0.444801    0.986721    3.435949    0.472768    0.100585    0.017351    0.696840    
#> 229: 0.444149    0.986796    3.435727    0.473791    0.100626    0.017440    0.695606    
#> 230: 0.443804    0.986649    3.435588    0.473687    0.100799    0.017503    0.694881    
#> 231: 0.443179    0.986664    3.435988    0.471741    0.101302    0.017563    0.694351    
#> 232: 0.442803    0.986507    3.436331    0.472077    0.101645    0.017600    0.693695    
#> 233: 0.442545    0.985662    3.436356    0.474828    0.101614    0.017487    0.693719    
#> 234: 0.440909    0.985742    3.435917    0.475769    0.101434    0.017635    0.693265    
#> 235: 0.440200    0.986204    3.435457    0.476314    0.101085    0.017690    0.692914    
#> 236: 0.440044    0.986514    3.435174    0.476071    0.101120    0.017766    0.693175    
#> 237: 0.440694    0.986729    3.435096    0.477904    0.101047    0.017897    0.693578    
#> 238: 0.440871    0.986381    3.435233    0.478591    0.100812    0.017906    0.694490    
#> 239: 0.440800    0.986691    3.435326    0.479805    0.100604    0.017963    0.694265    
#> 240: 0.441129    0.986134    3.435585    0.481047    0.100601    0.018074    0.693781    
#> 241: 0.441909    0.985141    3.435838    0.481815    0.100391    0.018081    0.693645    
#> 242: 0.442111    0.984617    3.436043    0.479863    0.100656    0.018096    0.693941    
#> 243: 0.442477    0.984842    3.436271    0.479360    0.101025    0.018107    0.694497    
#> 244: 0.441884    0.984833    3.436629    0.476896    0.101336    0.018138    0.694819    
#> 245: 0.442483    0.984204    3.436931    0.475284    0.100902    0.018137    0.695316    
#> 246: 0.442395    0.983920    3.437202    0.474716    0.100508    0.018231    0.695533    
#> 247: 0.442268    0.983685    3.437334    0.473684    0.100217    0.018225    0.695316    
#> 248: 0.442328    0.984002    3.437278    0.473011    0.099768    0.018286    0.694810    
#> 249: 0.441817    0.983956    3.437309    0.473935    0.099282    0.018349    0.694419    
#> 250: 0.442693    0.984154    3.437531    0.474719    0.098948    0.018491    0.693888    
#> 251: 0.443460    0.984423    3.437906    0.475449    0.098778    0.018546    0.693410    
#> 252: 0.444417    0.984481    3.438212    0.476828    0.098465    0.018575    0.693178    
#> 253: 0.444860    0.984392    3.438365    0.476570    0.098118    0.018623    0.693167    
#> 254: 0.444727    0.984644    3.438524    0.476103    0.097954    0.018594    0.693077    
#> 255: 0.444805    0.984934    3.438723    0.474530    0.097667    0.018680    0.693140    
#> 256: 0.444880    0.985001    3.438714    0.474293    0.097341    0.018773    0.692595    
#> 257: 0.444645    0.984654    3.438710    0.475482    0.097073    0.018767    0.692367    
#> 258: 0.444515    0.984817    3.438611    0.476284    0.097110    0.018772    0.691948    
#> 259: 0.444293    0.984690    3.438480    0.476603    0.097054    0.018772    0.691876    
#> 260: 0.443809    0.984831    3.438386    0.476481    0.096879    0.018732    0.691743    
#> 261: 0.443700    0.984840    3.438334    0.475979    0.096781    0.018731    0.691487    
#> 262: 0.443712    0.985034    3.438260    0.476280    0.096940    0.018753    0.691333    
#> 263: 0.443809    0.985468    3.438202    0.477651    0.096687    0.018819    0.691125    
#> 264: 0.443335    0.985730    3.438042    0.479579    0.096159    0.018838    0.691357    
#> 265: 0.443387    0.986057    3.437859    0.481679    0.095794    0.018863    0.691371    
#> 266: 0.443749    0.986200    3.437809    0.483336    0.095637    0.018844    0.691047    
#> 267: 0.444243    0.986075    3.438052    0.484487    0.095553    0.018862    0.690873    
#> 268: 0.444216    0.985640    3.438090    0.485376    0.095412    0.018906    0.690862    
#> 269: 0.444931    0.985511    3.438145    0.485823    0.095394    0.018961    0.690977    
#> 270: 0.445498    0.985760    3.438140    0.487176    0.095450    0.018966    0.690703    
#> 271: 0.445772    0.985829    3.438086    0.487692    0.095355    0.019005    0.690643    
#> 272: 0.446282    0.985756    3.438015    0.487721    0.095400    0.018962    0.691156    
#> 273: 0.445998    0.985956    3.437940    0.487588    0.095431    0.018949    0.691203    
#> 274: 0.446208    0.986257    3.438017    0.486582    0.095452    0.018887    0.691016    
#> 275: 0.446024    0.986429    3.437787    0.486254    0.095444    0.018865    0.690829    
#> 276: 0.445933    0.986874    3.437657    0.486866    0.095539    0.018858    0.690738    
#> 277: 0.445313    0.987195    3.437567    0.487313    0.095484    0.018850    0.690778    
#> 278: 0.444778    0.987395    3.437454    0.488233    0.095401    0.018829    0.690779    
#> 279: 0.444191    0.987181    3.437300    0.489503    0.095415    0.018830    0.690767    
#> 280: 0.443644    0.987472    3.437122    0.489502    0.095325    0.018875    0.690521    
#> 281: 0.443447    0.987767    3.437070    0.489575    0.095168    0.018912    0.690313    
#> 282: 0.443673    0.988049    3.437125    0.490323    0.095071    0.018879    0.690329    
#> 283: 0.443664    0.988027    3.437164    0.491223    0.095086    0.018880    0.690595    
#> 284: 0.443664    0.987971    3.437133    0.492689    0.095048    0.018914    0.690525    
#> 285: 0.443556    0.987818    3.437059    0.493030    0.095120    0.018932    0.690629    
#> 286: 0.443091    0.987728    3.436964    0.492853    0.095196    0.018913    0.690753    
#> 287: 0.442562    0.987764    3.436810    0.493090    0.095325    0.018864    0.690783    
#> 288: 0.442490    0.987576    3.436758    0.492399    0.095255    0.018876    0.690966    
#> 289: 0.442739    0.987461    3.436791    0.491931    0.095179    0.018912    0.690984    
#> 290: 0.443176    0.987403    3.436815    0.492010    0.095272    0.018895    0.691029    
#> 291: 0.443406    0.987527    3.436898    0.492695    0.095382    0.018919    0.690732    
#> 292: 0.443081    0.987471    3.436835    0.492508    0.095534    0.018935    0.690548    
#> 293: 0.442637    0.987542    3.436648    0.492100    0.095439    0.018959    0.690578    
#> 294: 0.441935    0.987718    3.436320    0.492288    0.095380    0.018970    0.690652    
#> 295: 0.441669    0.987442    3.436262    0.492450    0.095403    0.018971    0.690751    
#> 296: 0.441351    0.987363    3.436183    0.491717    0.095498    0.019010    0.690855    
#> 297: 0.441432    0.987495    3.436140    0.491638    0.095559    0.019049    0.690828    
#> 298: 0.441379    0.987401    3.436045    0.491295    0.095365    0.019048    0.690880    
#> 299: 0.441254    0.987502    3.435918    0.491129    0.095278    0.019042    0.690690    
#> 300: 0.441450    0.987302    3.436005    0.491207    0.095212    0.019033    0.690536    
#> 301: 0.441715    0.987145    3.436026    0.490251    0.095188    0.019009    0.690565    
#> 302: 0.442146    0.987069    3.436101    0.489668    0.095087    0.018988    0.690513    
#> 303: 0.442300    0.987060    3.436137    0.489472    0.094973    0.019008    0.690258    
#> 304: 0.442121    0.987303    3.436035    0.489972    0.094896    0.019065    0.690191    
#> 305: 0.441887    0.987230    3.435949    0.489830    0.094842    0.019099    0.690059    
#> 306: 0.441302    0.987142    3.435818    0.489193    0.094731    0.019114    0.690048    
#> 307: 0.441088    0.987052    3.435701    0.488855    0.094631    0.019148    0.690123    
#> 308: 0.440422    0.986966    3.435490    0.488954    0.094672    0.019174    0.690236    
#> 309: 0.439746    0.987004    3.435402    0.488680    0.094591    0.019201    0.690423    
#> 310: 0.439674    0.987091    3.435190    0.489393    0.094650    0.019219    0.690582    
#> 311: 0.439476    0.987182    3.435114    0.489610    0.094714    0.019250    0.690427    
#> 312: 0.439362    0.987237    3.434958    0.490756    0.094902    0.019321    0.690184    
#> 313: 0.439344    0.987190    3.434806    0.491269    0.094946    0.019377    0.690071    
#> 314: 0.438945    0.987472    3.434629    0.491474    0.094941    0.019433    0.689955    
#> 315: 0.438612    0.987767    3.434499    0.491484    0.094909    0.019456    0.689773    
#> 316: 0.438330    0.988030    3.434327    0.491663    0.094897    0.019497    0.689568    
#> 317: 0.438202    0.988170    3.434284    0.491874    0.094902    0.019538    0.689716    
#> 318: 0.438180    0.988333    3.434110    0.491763    0.094757    0.019584    0.689614    
#> 319: 0.437945    0.988472    3.434048    0.491446    0.094620    0.019621    0.689563    
#> 320: 0.437336    0.988464    3.433911    0.491272    0.094673    0.019669    0.689519    
#> 321: 0.437001    0.988661    3.433666    0.491789    0.094637    0.019709    0.689483    
#> 322: 0.436879    0.988797    3.433469    0.492074    0.094631    0.019710    0.689295    
#> 323: 0.436383    0.988826    3.433347    0.492333    0.094565    0.019708    0.689092    
#> 324: 0.436200    0.988891    3.433283    0.492563    0.094610    0.019673    0.688897    
#> 325: 0.436241    0.988950    3.433200    0.492352    0.094649    0.019661    0.688731    
#> 326: 0.436406    0.988839    3.433171    0.492672    0.094749    0.019674    0.688548    
#> 327: 0.436732    0.988762    3.433230    0.493167    0.094874    0.019707    0.688385    
#> 328: 0.436943    0.988667    3.433288    0.493356    0.094863    0.019710    0.688319    
#> 329: 0.437431    0.988608    3.433486    0.493337    0.094979    0.019728    0.688324    
#> 330: 0.437552    0.988550    3.433593    0.492936    0.094846    0.019739    0.688438    
#> 331: 0.437686    0.988610    3.433649    0.493103    0.094675    0.019778    0.688386    
#> 332: 0.437775    0.988488    3.433729    0.492838    0.094544    0.019804    0.688500    
#> 333: 0.437928    0.988464    3.433593    0.493516    0.094425    0.019819    0.688538    
#> 334: 0.437861    0.988376    3.433500    0.493785    0.094354    0.019844    0.688525    
#> 335: 0.437766    0.988447    3.433370    0.494323    0.094277    0.019867    0.688370    
#> 336: 0.437303    0.988712    3.433278    0.493942    0.094203    0.019893    0.688376    
#> 337: 0.437015    0.989022    3.433124    0.494007    0.094229    0.019905    0.688299    
#> 338: 0.436947    0.989078    3.433086    0.494179    0.094306    0.019914    0.688171    
#> 339: 0.436847    0.989161    3.433053    0.494337    0.094286    0.019912    0.688046    
#> 340: 0.436929    0.988862    3.433051    0.494781    0.094286    0.019909    0.688021    
#> 341: 0.437155    0.988791    3.433150    0.495176    0.094310    0.019922    0.687931    
#> 342: 0.437121    0.988492    3.433176    0.495163    0.094266    0.019954    0.687783    
#> 343: 0.437039    0.988450    3.433188    0.494794    0.094237    0.019961    0.687608    
#> 344: 0.437236    0.988411    3.433297    0.494618    0.094220    0.019977    0.687528    
#> 345: 0.437367    0.988355    3.433382    0.494681    0.094171    0.020017    0.687494    
#> 346: 0.437388    0.988449    3.433330    0.494873    0.094233    0.020019    0.687396    
#> 347: 0.437311    0.988425    3.433250    0.495216    0.094263    0.020023    0.687317    
#> 348: 0.437001    0.988569    3.433139    0.495588    0.094317    0.020026    0.687294    
#> 349: 0.436833    0.988534    3.433082    0.495960    0.094291    0.020015    0.687253    
#> 350: 0.436613    0.988569    3.432978    0.496173    0.094226    0.019997    0.687234    
#> 351: 0.436775    0.988674    3.432924    0.496489    0.094144    0.019989    0.687299    
#> 352: 0.436899    0.988754    3.432966    0.496723    0.094088    0.020005    0.687312    
#> 353: 0.437221    0.988863    3.432976    0.497221    0.093861    0.020031    0.687253    
#> 354: 0.437275    0.988802    3.432874    0.498071    0.093662    0.020062    0.687244    
#> 355: 0.437534    0.988709    3.432828    0.498770    0.093641    0.020058    0.687338    
#> 356: 0.437603    0.988655    3.432819    0.498553    0.093689    0.020053    0.687434    
#> 357: 0.437779    0.988704    3.432866    0.498785    0.093641    0.020034    0.687371    
#> 358: 0.437862    0.988792    3.432943    0.498311    0.093584    0.020045    0.687347    
#> 359: 0.437614    0.988883    3.432948    0.497835    0.093587    0.020020    0.687328    
#> 360: 0.437459    0.988929    3.432885    0.497423    0.093592    0.019996    0.687203    
#> 361: 0.437290    0.988957    3.432864    0.496827    0.093475    0.019992    0.687165    
#> 362: 0.437328    0.988859    3.432890    0.496858    0.093438    0.019993    0.687057    
#> 363: 0.437510    0.988856    3.432963    0.496766    0.093399    0.019988    0.686908    
#> 364: 0.437709    0.988762    3.433006    0.496694    0.093496    0.020005    0.686841    
#> 365: 0.437805    0.988508    3.433152    0.496686    0.093398    0.020069    0.686800    
#> 366: 0.438027    0.988367    3.433196    0.496328    0.093266    0.020125    0.686898    
#> 367: 0.438104    0.988259    3.433302    0.496005    0.093238    0.020165    0.686844    
#> 368: 0.438310    0.988366    3.433318    0.496030    0.093172    0.020208    0.686803    
#> 369: 0.438427    0.988376    3.433302    0.496695    0.093171    0.020235    0.686738    
#> 370: 0.438515    0.988424    3.433253    0.497146    0.093116    0.020306    0.686706    
#> 371: 0.438545    0.988461    3.433190    0.497648    0.093048    0.020338    0.686543    
#> 372: 0.438501    0.988543    3.433143    0.498062    0.093034    0.020382    0.686447    
#> 373: 0.438081    0.988767    3.432986    0.498369    0.092992    0.020404    0.686440    
#> 374: 0.437898    0.988949    3.432856    0.498279    0.092921    0.020430    0.686320    
#> 375: 0.437649    0.989093    3.432771    0.498147    0.092872    0.020467    0.686281    
#> 376: 0.437457    0.989228    3.432698    0.498268    0.092822    0.020500    0.686163    
#> 377: 0.437178    0.989419    3.432565    0.498470    0.092863    0.020542    0.686040    
#> 378: 0.436788    0.989547    3.432401    0.498590    0.092832    0.020550    0.686083    
#> 379: 0.436581    0.989543    3.432315    0.499065    0.092783    0.020552    0.686078    
#> 380: 0.436392    0.989620    3.432212    0.499174    0.092834    0.020578    0.686038    
#> 381: 0.436113    0.989730    3.432096    0.499421    0.092777    0.020611    0.686126    
#> 382: 0.435674    0.989860    3.431956    0.499388    0.092756    0.020616    0.686017    
#> 383: 0.435611    0.989870    3.431898    0.499681    0.092710    0.020623    0.685966    
#> 384: 0.435540    0.989820    3.431909    0.499671    0.092707    0.020637    0.685920    
#> 385: 0.435792    0.989734    3.431949    0.500236    0.092682    0.020659    0.685906    
#> 386: 0.436129    0.989771    3.432056    0.500547    0.092613    0.020685    0.685967    
#> 387: 0.436504    0.989823    3.432190    0.500727    0.092519    0.020712    0.685949    
#> 388: 0.436673    0.989746    3.432223    0.501060    0.092478    0.020752    0.685818    
#> 389: 0.436787    0.989604    3.432228    0.501193    0.092533    0.020779    0.685840    
#> 390: 0.436611    0.989740    3.432179    0.501145    0.092548    0.020787    0.685800    
#> 391: 0.436580    0.989704    3.432148    0.501026    0.092537    0.020786    0.685711    
#> 392: 0.436660    0.989684    3.432189    0.500997    0.092508    0.020774    0.685663    
#> 393: 0.436834    0.989604    3.432194    0.501371    0.092520    0.020770    0.685582    
#> 394: 0.436954    0.989450    3.432201    0.501295    0.092484    0.020762    0.685629    
#> 395: 0.436985    0.989466    3.432213    0.501156    0.092485    0.020763    0.685679    
#> 396: 0.437040    0.989477    3.432224    0.501372    0.092574    0.020751    0.685640    
#> 397: 0.437211    0.989455    3.432288    0.501588    0.092596    0.020764    0.685628    
#> 398: 0.437413    0.989375    3.432373    0.501737    0.092625    0.020764    0.685634    
#> 399: 0.437597    0.989264    3.432484    0.501532    0.092610    0.020761    0.685620    
#> 400: 0.437803    0.989208    3.432602    0.501480    0.092554    0.020766    0.685575    
#> 401: 0.437915    0.989257    3.432691    0.501340    0.092572    0.020815    0.685546    
#> 402: 0.438076    0.989303    3.432780    0.501227    0.092539    0.020862    0.685585    
#> 403: 0.438425    0.989130    3.432875    0.501435    0.092533    0.020866    0.685608    
#> 404: 0.438556    0.989131    3.432860    0.501399    0.092494    0.020865    0.685544    
#> 405: 0.438465    0.989134    3.432863    0.501623    0.092425    0.020865    0.685541    
#> 406: 0.438423    0.989184    3.432829    0.501711    0.092343    0.020916    0.685527    
#> 407: 0.438352    0.989229    3.432847    0.501809    0.092309    0.020930    0.685539    
#> 408: 0.438479    0.989312    3.432868    0.501783    0.092358    0.020940    0.685554    
#> 409: 0.438515    0.989256    3.432866    0.501664    0.092334    0.020950    0.685516    
#> 410: 0.438519    0.989379    3.432821    0.501632    0.092295    0.020956    0.685595    
#> 411: 0.438452    0.989294    3.432779    0.501862    0.092260    0.020957    0.685613    
#> 412: 0.438331    0.989404    3.432726    0.501823    0.092218    0.020960    0.685693    
#> 413: 0.438014    0.989426    3.432653    0.501308    0.092188    0.020971    0.685823    
#> 414: 0.437709    0.989484    3.432656    0.501139    0.092145    0.020990    0.685851    
#> 415: 0.437668    0.989427    3.432624    0.501245    0.092107    0.021016    0.685863    
#> 416: 0.437640    0.989489    3.432617    0.501198    0.092069    0.021056    0.685851    
#> 417: 0.437640    0.989443    3.432580    0.501514    0.092072    0.021070    0.685875    
#> 418: 0.437522    0.989505    3.432577    0.501735    0.092149    0.021073    0.685798    
#> 419: 0.437541    0.989547    3.432577    0.501882    0.092188    0.021054    0.685820    
#> 420: 0.437671    0.989517    3.432562    0.501908    0.092268    0.021024    0.685796    
#> 421: 0.437635    0.989458    3.432626    0.501549    0.092264    0.021008    0.685853    
#> 422: 0.437766    0.989311    3.432684    0.501702    0.092314    0.020985    0.685883    
#> 423: 0.437947    0.989196    3.432738    0.501736    0.092466    0.020988    0.685870    
#> 424: 0.437877    0.989078    3.432717    0.501719    0.092505    0.020982    0.685822    
#> 425: 0.438003    0.989053    3.432666    0.502075    0.092472    0.020987    0.685812    
#> 426: 0.438062    0.989142    3.432645    0.502288    0.092444    0.021007    0.685753    
#> 427: 0.437926    0.989138    3.432639    0.502211    0.092444    0.021010    0.685697    
#> 428: 0.437830    0.989172    3.432640    0.502148    0.092459    0.021029    0.685596    
#> 429: 0.437898    0.989216    3.432666    0.502080    0.092434    0.021034    0.685576    
#> 430: 0.437960    0.989215    3.432684    0.501831    0.092430    0.021043    0.685660    
#> 431: 0.437928    0.989188    3.432715    0.501459    0.092429    0.021054    0.685699    
#> 432: 0.437934    0.989239    3.432748    0.501450    0.092389    0.021070    0.685638    
#> 433: 0.438088    0.989285    3.432839    0.501568    0.092357    0.021082    0.685637    
#> 434: 0.438112    0.989191    3.432911    0.501558    0.092373    0.021091    0.685589    
#> 435: 0.438155    0.989088    3.432948    0.501336    0.092368    0.021092    0.685545    
#> 436: 0.438263    0.989004    3.433015    0.501308    0.092361    0.021089    0.685577    
#> 437: 0.438229    0.988917    3.433081    0.501224    0.092358    0.021073    0.685582    
#> 438: 0.438235    0.988930    3.433142    0.500998    0.092331    0.021079    0.685573    
#> 439: 0.438459    0.988964    3.433197    0.500948    0.092315    0.021063    0.685549    
#> 440: 0.438709    0.988927    3.433303    0.500645    0.092305    0.021068    0.685571    
#> 441: 0.438854    0.988830    3.433365    0.500561    0.092298    0.021055    0.685571    
#> 442: 0.438790    0.988857    3.433429    0.500552    0.092333    0.021058    0.685484    
#> 443: 0.438925    0.988879    3.433450    0.500541    0.092342    0.021039    0.685418    
#> 444: 0.438907    0.988917    3.433407    0.500708    0.092355    0.021005    0.685376    
#> 445: 0.438915    0.988944    3.433380    0.500997    0.092336    0.020987    0.685362    
#> 446: 0.438801    0.988967    3.433354    0.501095    0.092305    0.020977    0.685288    
#> 447: 0.438684    0.989056    3.433347    0.500920    0.092323    0.020972    0.685248    
#> 448: 0.438535    0.989061    3.433353    0.500512    0.092313    0.020963    0.685251    
#> 449: 0.438524    0.989061    3.433449    0.500195    0.092301    0.020978    0.685351    
#> 450: 0.438381    0.988944    3.433480    0.499882    0.092254    0.020998    0.685423    
#> 451: 0.438535    0.988866    3.433493    0.500297    0.092243    0.020999    0.685390    
#> 452: 0.438570    0.988800    3.433513    0.500305    0.092187    0.020993    0.685354    
#> 453: 0.438491    0.988790    3.433486    0.500123    0.092174    0.020983    0.685309    
#> 454: 0.438477    0.988977    3.433483    0.500053    0.092171    0.020974    0.685195    
#> 455: 0.438590    0.989013    3.433499    0.500174    0.092182    0.020966    0.685127    
#> 456: 0.438629    0.988934    3.433507    0.500047    0.092188    0.020971    0.685114    
#> 457: 0.438727    0.988876    3.433560    0.500151    0.092194    0.020965    0.685068    
#> 458: 0.438902    0.988959    3.433604    0.500447    0.092191    0.020947    0.685024    
#> 459: 0.438892    0.989078    3.433622    0.500511    0.092225    0.020933    0.685044    
#> 460: 0.438694    0.989076    3.433611    0.500063    0.092266    0.020916    0.685026    
#> 461: 0.438583    0.989102    3.433616    0.499980    0.092309    0.020908    0.684997    
#> 462: 0.438380    0.989172    3.433629    0.499900    0.092373    0.020906    0.684995    
#> 463: 0.438263    0.989271    3.433612    0.499785    0.092376    0.020899    0.685021    
#> 464: 0.438210    0.989281    3.433577    0.499771    0.092385    0.020894    0.684993    
#> 465: 0.438289    0.989153    3.433619    0.499753    0.092364    0.020885    0.684975    
#> 466: 0.438387    0.989209    3.433605    0.499680    0.092394    0.020875    0.684970    
#> 467: 0.438271    0.989183    3.433618    0.499393    0.092404    0.020853    0.684950    
#> 468: 0.438319    0.989250    3.433627    0.499555    0.092381    0.020837    0.684953    
#> 469: 0.438396    0.989338    3.433581    0.499810    0.092358    0.020838    0.684956    
#> 470: 0.438369    0.989387    3.433494    0.500062    0.092380    0.020842    0.684919    
#> 471: 0.438305    0.989326    3.433461    0.500186    0.092401    0.020846    0.684919    
#> 472: 0.438334    0.989275    3.433493    0.500281    0.092391    0.020857    0.684926    
#> 473: 0.438205    0.989214    3.433499    0.500118    0.092413    0.020846    0.684899    
#> 474: 0.438155    0.989189    3.433488    0.500188    0.092423    0.020842    0.684944    
#> 475: 0.438281    0.989266    3.433543    0.500059    0.092416    0.020823    0.684923    
#> 476: 0.438355    0.989210    3.433578    0.500151    0.092385    0.020807    0.684868    
#> 477: 0.438413    0.989124    3.433628    0.500355    0.092347    0.020804    0.684765    
#> 478: 0.438479    0.989085    3.433655    0.500469    0.092317    0.020807    0.684747    
#> 479: 0.438551    0.989140    3.433642    0.500446    0.092339    0.020799    0.684780    
#> 480: 0.438538    0.989190    3.433642    0.500245    0.092373    0.020784    0.684830    
#> 481: 0.438393    0.989258    3.433598    0.499977    0.092358    0.020771    0.684845    
#> 482: 0.438361    0.989326    3.433563    0.499887    0.092378    0.020752    0.684911    
#> 483: 0.438161    0.989382    3.433517    0.499848    0.092460    0.020720    0.684964    
#> 484: 0.438097    0.989299    3.433499    0.499892    0.092530    0.020699    0.684963    
#> 485: 0.438058    0.989332    3.433465    0.500170    0.092493    0.020689    0.684973    
#> 486: 0.438005    0.989377    3.433467    0.500194    0.092481    0.020677    0.684954    
#> 487: 0.438130    0.989395    3.433495    0.500320    0.092473    0.020677    0.684915    
#> 488: 0.438143    0.989423    3.433498    0.500414    0.092501    0.020672    0.684873    
#> 489: 0.438317    0.989424    3.433492    0.500672    0.092468    0.020677    0.684825    
#> 490: 0.438555    0.989410    3.433538    0.501023    0.092424    0.020684    0.684737    
#> 491: 0.438616    0.989465    3.433599    0.500889    0.092397    0.020694    0.684676    
#> 492: 0.438695    0.989495    3.433615    0.500813    0.092431    0.020696    0.684757    
#> 493: 0.438637    0.989531    3.433619    0.500890    0.092430    0.020702    0.684779    
#> 494: 0.438725    0.989536    3.433621    0.500665    0.092417    0.020703    0.684756    
#> 495: 0.438753    0.989561    3.433608    0.500908    0.092366    0.020713    0.684687    
#> 496: 0.438845    0.989675    3.433565    0.500950    0.092284    0.020718    0.684691    
#> 497: 0.438788    0.989709    3.433553    0.500988    0.092216    0.020731    0.684677    
#> 498: 0.438821    0.989769    3.433520    0.501029    0.092170    0.020736    0.684625    
#> 499: 0.438811    0.989841    3.433478    0.500929    0.092171    0.020735    0.684523    
#> 500: 0.438789    0.989816    3.433439    0.500893    0.092198    0.020741    0.684396    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.284655    0.973382    3.455675    0.392401    0.088514    0.016800    1.500777    
#> 002: 0.410463    1.072284    3.504394    0.372781    0.084088    0.015960    1.035935    
#> 003: 0.462703    1.080702    3.513110    0.354142    0.079884    0.015162    0.859338    
#> 004: 0.467897    1.114538    3.510537    0.336435    0.075890    0.014404    0.836672    
#> 005: 0.558200    1.090710    3.510061    0.319613    0.072095    0.013684    0.814453    
#> 006: 0.530401    1.103828    3.510118    0.303633    0.068491    0.013000    0.792723    
#> 007: 0.512165    1.104109    3.500308    0.288451    0.065066    0.012350    0.814340    
#> 008: 0.435415    1.115294    3.476899    0.274029    0.061813    0.011732    0.812723    
#> 009: 0.397919    1.098789    3.472393    0.260327    0.058722    0.011146    0.815585    
#> 010: 0.436141    1.112523    3.483401    0.247311    0.055786    0.010588    0.804000    
#> 011: 0.491208    1.123832    3.478710    0.234945    0.052997    0.010059    0.818889    
#> 012: 0.475482    1.119528    3.479920    0.223198    0.050347    0.009556    0.802428    
#> 013: 0.398112    1.120701    3.478016    0.212038    0.047829    0.009078    0.813093    
#> 014: 0.460096    1.112471    3.484135    0.201436    0.045438    0.008624    0.843298    
#> 015: 0.468667    1.108128    3.492982    0.191364    0.043166    0.008193    0.808911    
#> 016: 0.462202    1.143135    3.496430    0.181796    0.041008    0.007783    0.823105    
#> 017: 0.464636    1.138996    3.494869    0.172706    0.038957    0.007394    0.805716    
#> 018: 0.474130    1.120976    3.476930    0.164071    0.037010    0.007025    0.814021    
#> 019: 0.438961    1.115195    3.484432    0.162162    0.035159    0.006673    0.805842    
#> 020: 0.471387    1.112405    3.491438    0.183408    0.033401    0.006340    0.793064    
#> 021: 0.454056    1.114362    3.493003    0.174237    0.031731    0.006023    0.778878    
#> 022: 0.445194    1.097973    3.493177    0.217692    0.030144    0.005722    0.786325    
#> 023: 0.537222    1.100143    3.512608    0.206807    0.028637    0.005436    0.830992    
#> 024: 0.535061    1.126018    3.513213    0.196467    0.027205    0.005164    0.833998    
#> 025: 0.507889    1.106483    3.514426    0.186644    0.031213    0.004906    0.818855    
#> 026: 0.485058    1.127464    3.503979    0.177311    0.029652    0.004746    0.793675    
#> 027: 0.480852    1.131049    3.503377    0.168446    0.028170    0.004509    0.811795    
#> 028: 0.517456    1.121305    3.510825    0.160024    0.026761    0.004283    0.807554    
#> 029: 0.525750    1.117651    3.503323    0.172381    0.025423    0.004069    0.841764    
#> 030: 0.499193    1.104789    3.502180    0.176856    0.024152    0.004852    0.805131    
#> 031: 0.465908    1.095707    3.496480    0.168013    0.027488    0.004791    0.814519    
#> 032: 0.438159    1.101366    3.495595    0.159612    0.026114    0.005384    0.804502    
#> 033: 0.456385    1.146796    3.486621    0.151632    0.024808    0.005178    0.837118    
#> 034: 0.486313    1.150533    3.490886    0.157414    0.023568    0.005524    0.810834    
#> 035: 0.432710    1.126978    3.483645    0.149543    0.022389    0.005248    0.797855    
#> 036: 0.431378    1.132220    3.483670    0.142066    0.021270    0.005519    0.819781    
#> 037: 0.424792    1.121493    3.486397    0.142197    0.026435    0.006136    0.830613    
#> 038: 0.487399    1.114247    3.482531    0.158002    0.025113    0.005829    0.828409    
#> 039: 0.479016    1.113814    3.495992    0.150101    0.023858    0.005677    0.812058    
#> 040: 0.461510    1.134099    3.487355    0.160912    0.022665    0.005602    0.789091    
#> 041: 0.449716    1.126666    3.489489    0.152866    0.021532    0.006237    0.794901    
#> 042: 0.462832    1.120863    3.484786    0.151494    0.023145    0.005925    0.792322    
#> 043: 0.430651    1.138368    3.473204    0.143919    0.021988    0.006051    0.798105    
#> 044: 0.420266    1.146031    3.479027    0.136723    0.020889    0.005939    0.803540    
#> 045: 0.403659    1.148078    3.467274    0.129887    0.019844    0.006284    0.815555    
#> 046: 0.424108    1.149502    3.472082    0.144437    0.023313    0.005970    0.805777    
#> 047: 0.427996    1.153771    3.462278    0.143787    0.022147    0.005671    0.794723    
#> 048: 0.444546    1.119079    3.475679    0.140181    0.025572    0.005388    0.812931    
#> 049: 0.437600    1.116089    3.480553    0.133172    0.027501    0.005118    0.823823    
#> 050: 0.522866    1.084030    3.499500    0.135806    0.026882    0.005276    0.859350    
#> 051: 0.532543    1.084946    3.501933    0.159241    0.025538    0.006846    0.835971    
#> 052: 0.502159    1.112430    3.501612    0.159239    0.024261    0.006504    0.827384    
#> 053: 0.516177    1.114273    3.501740    0.180462    0.023048    0.006179    0.807656    
#> 054: 0.444873    1.121579    3.504047    0.171439    0.021896    0.007417    0.815842    
#> 055: 0.465792    1.105096    3.498471    0.162867    0.020801    0.007046    0.801988    
#> 056: 0.493995    1.109876    3.499296    0.154724    0.019761    0.006694    0.812289    
#> 057: 0.493476    1.101615    3.516210    0.146988    0.018773    0.006359    0.838709    
#> 058: 0.525487    1.117295    3.505727    0.139638    0.017834    0.006041    0.823923    
#> 059: 0.519690    1.101515    3.513822    0.159986    0.020531    0.005920    0.835118    
#> 060: 0.505618    1.087957    3.518395    0.153130    0.020377    0.005787    0.820379    
#> 061: 0.506138    1.079232    3.504883    0.145474    0.022916    0.005498    0.812583    
#> 062: 0.511801    1.098399    3.513364    0.138200    0.022788    0.006798    0.826072    
#> 063: 0.536493    1.088192    3.513687    0.131290    0.024591    0.006458    0.818100    
#> 064: 0.531458    1.093846    3.514556    0.142195    0.023362    0.006135    0.820975    
#> 065: 0.526120    1.075818    3.514557    0.135085    0.026264    0.005828    0.805384    
#> 066: 0.485746    1.100470    3.503159    0.136125    0.024951    0.005537    0.798473    
#> 067: 0.475004    1.114818    3.498209    0.129319    0.023703    0.005260    0.824413    
#> 068: 0.439034    1.120490    3.507470    0.122853    0.022518    0.005602    0.849931    
#> 069: 0.443212    1.134350    3.491516    0.141970    0.021392    0.006674    0.810780    
#> 070: 0.480867    1.126977    3.498912    0.146371    0.020323    0.006340    0.814560    
#> 071: 0.465355    1.152200    3.491517    0.141808    0.019307    0.006756    0.834495    
#> 072: 0.451265    1.133576    3.493780    0.143790    0.018341    0.008671    0.807398    
#> 073: 0.512804    1.137300    3.519413    0.136600    0.017424    0.008961    0.828253    
#> 074: 0.466225    1.115852    3.518849    0.129770    0.016553    0.008513    0.829611    
#> 075: 0.507414    1.095221    3.540314    0.123282    0.019427    0.008400    0.810161    
#> 076: 0.528916    1.105862    3.543494    0.134818    0.020133    0.008820    0.818590    
#> 077: 0.568081    1.089158    3.524573    0.161580    0.019126    0.008379    0.799767    
#> 078: 0.553117    1.076787    3.540458    0.153501    0.018170    0.007960    0.809129    
#> 079: 0.561453    1.107996    3.532932    0.195518    0.017261    0.008950    0.826712    
#> 080: 0.549127    1.098302    3.523074    0.189968    0.016398    0.009409    0.835096    
#> 081: 0.536735    1.082714    3.525629    0.180470    0.015578    0.008938    0.810362    
#> 082: 0.548908    1.069774    3.540822    0.185096    0.014799    0.008598    0.820790    
#> 083: 0.557390    1.062258    3.544134    0.175841    0.016601    0.008168    0.827834    
#> 084: 0.508498    1.087643    3.521682    0.176318    0.015771    0.007759    0.809581    
#> 085: 0.509137    1.085198    3.521283    0.167503    0.014982    0.007705    0.836238    
#> 086: 0.493239    1.082155    3.518833    0.176652    0.014233    0.007320    0.803675    
#> 087: 0.493519    1.077337    3.514236    0.167819    0.013521    0.006954    0.831438    
#> 088: 0.465780    1.086899    3.520909    0.159428    0.013809    0.007722    0.832306    
#> 089: 0.509920    1.106336    3.505111    0.151457    0.014347    0.007336    0.818351    
#> 090: 0.501767    1.110686    3.513356    0.176525    0.013745    0.006969    0.805167    
#> 091: 0.472883    1.104236    3.491721    0.173795    0.013058    0.007710    0.799403    
#> 092: 0.481481    1.122525    3.492719    0.200111    0.012405    0.007324    0.777463    
#> 093: 0.460015    1.124676    3.488001    0.190105    0.012606    0.007767    0.799693    
#> 094: 0.455583    1.132876    3.477233    0.182183    0.012430    0.007379    0.801514    
#> 095: 0.449090    1.140659    3.491843    0.205879    0.013244    0.007973    0.816902    
#> 096: 0.455555    1.147214    3.489657    0.195585    0.013755    0.007575    0.808475    
#> 097: 0.465885    1.156463    3.488028    0.185806    0.015248    0.008019    0.811180    
#> 098: 0.424634    1.142031    3.478766    0.196313    0.017752    0.007618    0.834118    
#> 099: 0.426265    1.133268    3.469747    0.186497    0.018540    0.008327    0.813012    
#> 100: 0.439276    1.129111    3.475084    0.177172    0.017613    0.007911    0.791658    
#> 101: 0.420798    1.122736    3.462839    0.185220    0.016733    0.007515    0.785863    
#> 102: 0.412173    1.118739    3.452438    0.179415    0.015896    0.007139    0.799539    
#> 103: 0.459690    1.123478    3.474702    0.171589    0.015101    0.006782    0.796416    
#> 104: 0.469075    1.116500    3.481950    0.163009    0.018630    0.006443    0.807020    
#> 105: 0.458588    1.117090    3.483050    0.163993    0.021337    0.006121    0.810567    
#> 106: 0.473290    1.127575    3.478810    0.159194    0.020270    0.005824    0.809420    
#> 107: 0.465788    1.150491    3.476020    0.156721    0.026737    0.005915    0.826264    
#> 108: 0.463333    1.134700    3.477821    0.150659    0.025400    0.005619    0.821795    
#> 109: 0.451624    1.132640    3.483549    0.143126    0.024517    0.005338    0.812346    
#> 110: 0.435657    1.138717    3.469281    0.174860    0.026200    0.006286    0.795148    
#> 111: 0.436632    1.147980    3.473793    0.169712    0.024890    0.005971    0.796155    
#> 112: 0.416600    1.134533    3.465516    0.161227    0.023645    0.005673    0.804693    
#> 113: 0.406729    1.147526    3.461708    0.157552    0.022463    0.005389    0.806868    
#> 114: 0.427279    1.153173    3.471354    0.149675    0.023182    0.005120    0.800407    
#> 115: 0.483163    1.119653    3.482117    0.184288    0.022022    0.005062    0.815050    
#> 116: 0.480666    1.137962    3.490530    0.187596    0.020921    0.004809    0.834195    
#> 117: 0.430623    1.138759    3.487990    0.178217    0.019875    0.004568    0.813061    
#> 118: 0.464289    1.143990    3.493627    0.169306    0.020701    0.004526    0.803263    
#> 119: 0.504607    1.127021    3.500375    0.164669    0.019666    0.005736    0.821596    
#> 120: 0.488202    1.115883    3.491227    0.157887    0.018683    0.007999    0.792955    
#> 121: 0.465977    1.151974    3.478544    0.149992    0.020271    0.007642    0.800448    
#> 122: 0.454014    1.119075    3.495005    0.142493    0.023380    0.007260    0.801050    
#> 123: 0.490139    1.126103    3.498980    0.139539    0.023606    0.006897    0.809254    
#> 124: 0.514296    1.142029    3.502116    0.134439    0.023701    0.006552    0.798540    
#> 125: 0.521939    1.125425    3.497297    0.149546    0.024352    0.006225    0.824583    
#> 126: 0.478589    1.122629    3.481362    0.176457    0.026675    0.005980    0.817679    
#> 127: 0.454541    1.108024    3.475529    0.167635    0.025341    0.005681    0.815215    
#> 128: 0.445897    1.105683    3.493414    0.165896    0.024074    0.005397    0.828069    
#> 129: 0.497998    1.106248    3.503408    0.159245    0.022870    0.005128    0.829632    
#> 130: 0.497866    1.126869    3.502789    0.175130    0.022840    0.004894    0.800479    
#> 131: 0.479722    1.124240    3.491235    0.166373    0.021698    0.004649    0.804134    
#> 132: 0.414738    1.113816    3.478290    0.158055    0.020613    0.004417    0.817442    
#> 133: 0.457965    1.127351    3.483856    0.150152    0.020677    0.004196    0.828784    
#> 134: 0.461856    1.121255    3.487995    0.142644    0.020447    0.004659    0.815649    
#> 135: 0.431362    1.122902    3.479611    0.148618    0.019425    0.004426    0.816462    
#> 136: 0.440131    1.121884    3.469854    0.168953    0.018610    0.005129    0.797075    
#> 137: 0.432638    1.119645    3.467789    0.197929    0.020959    0.004873    0.812244    
#> 138: 0.461927    1.118859    3.475053    0.192817    0.021296    0.005181    0.802424    
#> 139: 0.470346    1.127368    3.504003    0.183176    0.020231    0.005221    0.814399    
#> 140: 0.506436    1.127445    3.515802    0.181424    0.019220    0.006871    0.815136    
#> 141: 0.493143    1.105389    3.514940    0.184786    0.018259    0.007104    0.796930    
#> 142: 0.520877    1.102536    3.521132    0.175547    0.021317    0.006749    0.799274    
#> 143: 0.475733    1.112213    3.521300    0.166769    0.020251    0.008762    0.808874    
#> 144: 0.524655    1.112082    3.530584    0.158431    0.019239    0.008324    0.806339    
#> 145: 0.536036    1.117916    3.518936    0.159684    0.018277    0.007908    0.804023    
#> 146: 0.489395    1.111548    3.513545    0.189358    0.017363    0.007513    0.804977    
#> 147: 0.451168    1.111871    3.496475    0.179890    0.016495    0.007137    0.805642    
#> 148: 0.435083    1.120108    3.497512    0.170896    0.015670    0.007008    0.810742    
#> 149: 0.458058    1.115516    3.491652    0.162351    0.014886    0.006657    0.814083    
#> 150: 0.467472    1.119155    3.490857    0.154234    0.016454    0.006324    0.822166    
#> 151: 0.423123    1.138963    3.481006    0.146522    0.015631    0.006008    0.858690    
#> 152: 0.483489    1.129887    3.482442    0.140867    0.009767    0.003854    0.848128    
#> 153: 0.444336    1.147461    3.488282    0.142032    0.009989    0.005492    0.829773    
#> 154: 0.485980    1.156709    3.492599    0.117079    0.010680    0.007133    0.822593    
#> 155: 0.482871    1.139024    3.492658    0.171486    0.008587    0.007316    0.815824    
#> 156: 0.430738    1.157718    3.494360    0.144579    0.010103    0.006921    0.808833    
#> 157: 0.480655    1.163927    3.507432    0.130107    0.009828    0.006064    0.817800    
#> 158: 0.510330    1.157631    3.504249    0.134993    0.009977    0.006428    0.822626    
#> 159: 0.452233    1.163964    3.492742    0.161419    0.009182    0.006027    0.812042    
#> 160: 0.498240    1.137737    3.493856    0.131387    0.012366    0.005439    0.845832    
#> 161: 0.478603    1.117738    3.499163    0.188471    0.009653    0.007900    0.831153    
#> 162: 0.481899    1.123503    3.487116    0.185340    0.007770    0.008856    0.820116    
#> 163: 0.524998    1.105973    3.492287    0.149003    0.007112    0.007432    0.829052    
#> 164: 0.508612    1.108283    3.504918    0.114053    0.006052    0.008645    0.831048    
#> 165: 0.529057    1.110709    3.520901    0.139843    0.006122    0.006700    0.817218    
#> 166: 0.556695    1.133195    3.519458    0.168062    0.005709    0.007526    0.831360    
#> 167: 0.516328    1.135911    3.514352    0.167908    0.006438    0.007322    0.804809    
#> 168: 0.474656    1.153360    3.504554    0.188815    0.005455    0.008040    0.809544    
#> 169: 0.506108    1.167215    3.498242    0.179085    0.007301    0.005194    0.815142    
#> 170: 0.485353    1.155886    3.490827    0.128953    0.008069    0.005993    0.807713    
#> 171: 0.437178    1.160883    3.487323    0.138861    0.007939    0.005408    0.809507    
#> 172: 0.421039    1.163549    3.474967    0.150063    0.009320    0.005927    0.809792    
#> 173: 0.422897    1.168243    3.461863    0.104550    0.009380    0.007228    0.810966    
#> 174: 0.431736    1.156506    3.469944    0.094640    0.011392    0.006629    0.825628    
#> 175: 0.425211    1.149741    3.465620    0.120604    0.009273    0.008699    0.843513    
#> 176: 0.421932    1.151563    3.474291    0.118269    0.008140    0.005893    0.839746    
#> 177: 0.422906    1.150482    3.483462    0.109751    0.008316    0.007758    0.817413    
#> 178: 0.450467    1.148895    3.483885    0.122528    0.010569    0.007980    0.812736    
#> 179: 0.464356    1.134299    3.487810    0.159648    0.015973    0.006981    0.800702    
#> 180: 0.434669    1.120813    3.485216    0.115033    0.013789    0.005294    0.836999    
#> 181: 0.435366    1.112156    3.467866    0.110117    0.014072    0.004438    0.837420    
#> 182: 0.391810    1.129250    3.462681    0.132573    0.014949    0.004087    0.839484    
#> 183: 0.403598    1.148207    3.465802    0.120005    0.017107    0.004077    0.818074    
#> 184: 0.415414    1.123864    3.465911    0.132498    0.019337    0.004112    0.815221    
#> 185: 0.425164    1.150935    3.465335    0.115418    0.019082    0.004436    0.808967    
#> 186: 0.427010    1.141496    3.471053    0.117724    0.018909    0.005196    0.805537    
#> 187: 0.416226    1.129819    3.481542    0.154720    0.019183    0.007344    0.812283    
#> 188: 0.403607    1.154602    3.471723    0.155095    0.021691    0.008081    0.813135    
#> 189: 0.449919    1.166034    3.478198    0.174195    0.023629    0.007786    0.813935    
#> 190: 0.418120    1.139997    3.480566    0.170820    0.019925    0.006640    0.815272    
#> 191: 0.438585    1.148624    3.480337    0.166115    0.019569    0.003815    0.815161    
#> 192: 0.415408    1.158158    3.477956    0.154195    0.021574    0.003959    0.808491    
#> 193: 0.432008    1.164380    3.476558    0.173605    0.021752    0.004055    0.791676    
#> 194: 0.402149    1.160548    3.460937    0.157582    0.019846    0.003804    0.839675    
#> 195: 0.383224    1.168328    3.456814    0.140809    0.018945    0.004168    0.846845    
#> 196: 0.386541    1.168185    3.461677    0.147660    0.025603    0.003382    0.845136    
#> 197: 0.377550    1.183993    3.462574    0.105967    0.018058    0.003714    0.831615    
#> 198: 0.439161    1.170808    3.454238    0.138005    0.018120    0.003708    0.821526    
#> 199: 0.417639    1.153654    3.460916    0.117458    0.017610    0.002757    0.825495    
#> 200: 0.382007    1.153575    3.459295    0.110558    0.014455    0.003038    0.839705    
#> 201: 0.396898    1.146752    3.464923    0.105845    0.015768    0.003978    0.830734    
#> 202: 0.404485    1.146811    3.466370    0.113244    0.016321    0.004111    0.830540    
#> 203: 0.418957    1.144478    3.468556    0.119391    0.016477    0.004249    0.826339    
#> 204: 0.428953    1.138734    3.470832    0.126364    0.018280    0.004138    0.821473    
#> 205: 0.427166    1.140169    3.471627    0.127435    0.019767    0.004305    0.820934    
#> 206: 0.430770    1.142395    3.472994    0.131130    0.020103    0.004386    0.821829    
#> 207: 0.429756    1.140581    3.473187    0.131738    0.020303    0.004424    0.822746    
#> 208: 0.432122    1.139322    3.474344    0.130896    0.019792    0.004356    0.822905    
#> 209: 0.434847    1.137122    3.474732    0.130445    0.019871    0.004351    0.821962    
#> 210: 0.438131    1.136044    3.475332    0.130271    0.019666    0.004327    0.821061    
#> 211: 0.439356    1.136683    3.476167    0.131155    0.019942    0.004298    0.820174    
#> 212: 0.440796    1.134982    3.477415    0.130156    0.020299    0.004231    0.820276    
#> 213: 0.441155    1.132630    3.477165    0.128663    0.021031    0.004120    0.820676    
#> 214: 0.442432    1.131907    3.477203    0.128784    0.021500    0.003990    0.820582    
#> 215: 0.443425    1.131469    3.477979    0.129654    0.021415    0.003956    0.820234    
#> 216: 0.445465    1.129339    3.478413    0.132576    0.021312    0.003906    0.819487    
#> 217: 0.446645    1.129805    3.478519    0.133535    0.021307    0.003906    0.818211    
#> 218: 0.447044    1.130586    3.477880    0.134939    0.021042    0.003960    0.817657    
#> 219: 0.446429    1.130251    3.477353    0.136808    0.020683    0.004060    0.817313    
#> 220: 0.444929    1.130799    3.477660    0.137705    0.020559    0.004085    0.816249    
#> 221: 0.444061    1.130366    3.477446    0.138216    0.020514    0.004064    0.815048    
#> 222: 0.443725    1.130333    3.477341    0.138918    0.020433    0.004059    0.814049    
#> 223: 0.446013    1.130103    3.477815    0.139835    0.020375    0.004061    0.813453    
#> 224: 0.446686    1.129994    3.478275    0.141655    0.020303    0.004100    0.813083    
#> 225: 0.447291    1.129322    3.478829    0.141815    0.020261    0.004167    0.812846    
#> 226: 0.447880    1.128440    3.478930    0.142941    0.020150    0.004256    0.812495    
#> 227: 0.447023    1.128488    3.479148    0.144130    0.020146    0.004250    0.812065    
#> 228: 0.446823    1.129276    3.478978    0.143983    0.020167    0.004271    0.812707    
#> 229: 0.447478    1.129550    3.478851    0.144091    0.020154    0.004295    0.812234    
#> 230: 0.448260    1.129781    3.478714    0.143416    0.020295    0.004328    0.812139    
#> 231: 0.448747    1.130013    3.478895    0.143078    0.020210    0.004321    0.812411    
#> 232: 0.447433    1.129967    3.479268    0.142936    0.019994    0.004325    0.812866    
#> 233: 0.447987    1.129128    3.479862    0.143768    0.019905    0.004367    0.813315    
#> 234: 0.447424    1.129197    3.480178    0.144092    0.019766    0.004446    0.813500    
#> 235: 0.446998    1.129144    3.480182    0.143971    0.019642    0.004483    0.813666    
#> 236: 0.447003    1.129593    3.480076    0.143605    0.019540    0.004490    0.814052    
#> 237: 0.448044    1.129594    3.480305    0.144695    0.019505    0.004481    0.814431    
#> 238: 0.448728    1.130077    3.480486    0.146087    0.019445    0.004494    0.814252    
#> 239: 0.449124    1.130754    3.480598    0.146474    0.019479    0.004497    0.814122    
#> 240: 0.449883    1.130730    3.481036    0.146761    0.019410    0.004493    0.814031    
#> 241: 0.450914    1.130573    3.481459    0.147523    0.019534    0.004474    0.814366    
#> 242: 0.451132    1.130453    3.481472    0.147982    0.019782    0.004464    0.814688    
#> 243: 0.450517    1.130703    3.481478    0.148293    0.020091    0.004447    0.814944    
#> 244: 0.449966    1.129875    3.481652    0.147921    0.020224    0.004432    0.815651    
#> 245: 0.450417    1.129385    3.481787    0.147507    0.020312    0.004438    0.815717    
#> 246: 0.450476    1.129076    3.481934    0.147780    0.020290    0.004474    0.815754    
#> 247: 0.450181    1.128679    3.482178    0.147492    0.020341    0.004493    0.815558    
#> 248: 0.450297    1.128518    3.482386    0.147050    0.020252    0.004485    0.815259    
#> 249: 0.450453    1.128345    3.482579    0.147755    0.020175    0.004471    0.815329    
#> 250: 0.451653    1.128213    3.482727    0.148181    0.020251    0.004480    0.815275    
#> 251: 0.452014    1.128194    3.482940    0.148460    0.020312    0.004479    0.814981    
#> 252: 0.452670    1.128418    3.483306    0.149207    0.020237    0.004486    0.814889    
#> 253: 0.453226    1.128598    3.483525    0.149634    0.020078    0.004496    0.814816    
#> 254: 0.454186    1.128721    3.483982    0.150058    0.020026    0.004478    0.815164    
#> 255: 0.454237    1.128854    3.484468    0.149741    0.020013    0.004475    0.815394    
#> 256: 0.454792    1.128478    3.484819    0.149623    0.020067    0.004454    0.815268    
#> 257: 0.455120    1.127876    3.485044    0.149510    0.020047    0.004462    0.815405    
#> 258: 0.455331    1.127572    3.485193    0.149237    0.019968    0.004458    0.815280    
#> 259: 0.455230    1.127316    3.485177    0.149111    0.019835    0.004459    0.815701    
#> 260: 0.454935    1.127584    3.485284    0.148407    0.019749    0.004464    0.815961    
#> 261: 0.455068    1.127588    3.485374    0.148307    0.019729    0.004456    0.816260    
#> 262: 0.455582    1.127546    3.485483    0.148175    0.019756    0.004464    0.816643    
#> 263: 0.456228    1.127765    3.485558    0.148262    0.019652    0.004469    0.816681    
#> 264: 0.456471    1.127978    3.485525    0.148402    0.019724    0.004497    0.816698    
#> 265: 0.456673    1.127886    3.485623    0.148442    0.019847    0.004489    0.816799    
#> 266: 0.457106    1.128261    3.485554    0.148888    0.019866    0.004515    0.817073    
#> 267: 0.457490    1.128389    3.485680    0.149516    0.019887    0.004524    0.817028    
#> 268: 0.457437    1.128414    3.485559    0.149630    0.019841    0.004520    0.817271    
#> 269: 0.457788    1.128116    3.485521    0.149249    0.019851    0.004536    0.817313    
#> 270: 0.458611    1.128086    3.485513    0.149416    0.019753    0.004523    0.817179    
#> 271: 0.458736    1.128018    3.485375    0.149503    0.019677    0.004522    0.817401    
#> 272: 0.459079    1.127727    3.485451    0.149813    0.019654    0.004525    0.817599    
#> 273: 0.459422    1.127675    3.485545    0.149628    0.019732    0.004527    0.817544    
#> 274: 0.459008    1.127773    3.485526    0.149338    0.019759    0.004509    0.817340    
#> 275: 0.458894    1.127517    3.485486    0.149153    0.019737    0.004499    0.817068    
#> 276: 0.459033    1.127382    3.485748    0.148961    0.019772    0.004510    0.817078    
#> 277: 0.458904    1.127421    3.485966    0.148940    0.019745    0.004527    0.817187    
#> 278: 0.459172    1.127463    3.486152    0.148917    0.019669    0.004527    0.817235    
#> 279: 0.459120    1.127608    3.486174    0.149401    0.019562    0.004523    0.817386    
#> 280: 0.459377    1.127961    3.486294    0.149385    0.019466    0.004522    0.817373    
#> 281: 0.459238    1.128153    3.486481    0.149353    0.019458    0.004525    0.817279    
#> 282: 0.459053    1.128407    3.486597    0.149482    0.019438    0.004520    0.817476    
#> 283: 0.459483    1.128378    3.486727    0.149772    0.019444    0.004513    0.817614    
#> 284: 0.459465    1.128367    3.486817    0.150046    0.019431    0.004502    0.817461    
#> 285: 0.459701    1.128096    3.486774    0.150519    0.019400    0.004519    0.817644    
#> 286: 0.459872    1.127953    3.486761    0.150635    0.019438    0.004529    0.817403    
#> 287: 0.460005    1.127980    3.486661    0.150537    0.019431    0.004531    0.817471    
#> 288: 0.460332    1.127717    3.486744    0.150707    0.019423    0.004548    0.817250    
#> 289: 0.460443    1.127522    3.486812    0.150791    0.019450    0.004558    0.817153    
#> 290: 0.460539    1.127449    3.486865    0.150886    0.019489    0.004556    0.817088    
#> 291: 0.460639    1.127618    3.486937    0.150830    0.019473    0.004547    0.816960    
#> 292: 0.460502    1.127781    3.486958    0.150902    0.019430    0.004541    0.816910    
#> 293: 0.460196    1.127918    3.486825    0.150862    0.019344    0.004541    0.817046    
#> 294: 0.459996    1.128047    3.486711    0.150868    0.019300    0.004537    0.817131    
#> 295: 0.460091    1.127880    3.486685    0.150992    0.019228    0.004542    0.817054    
#> 296: 0.460242    1.127749    3.486772    0.151083    0.019242    0.004556    0.817098    
#> 297: 0.460909    1.127737    3.486848    0.151178    0.019185    0.004572    0.817085    
#> 298: 0.461167    1.127699    3.486984    0.151245    0.019123    0.004575    0.817076    
#> 299: 0.461410    1.127753    3.486987    0.151421    0.019038    0.004550    0.817112    
#> 300: 0.461577    1.127745    3.487081    0.151472    0.018976    0.004531    0.816998    
#> 301: 0.461497    1.127799    3.487048    0.151167    0.018958    0.004530    0.816974    
#> 302: 0.461426    1.127930    3.487011    0.151049    0.018965    0.004526    0.816958    
#> 303: 0.461438    1.127946    3.487044    0.150917    0.018948    0.004536    0.816710    
#> 304: 0.461683    1.128106    3.487022    0.150712    0.018984    0.004545    0.816704    
#> 305: 0.461610    1.127940    3.487098    0.150463    0.019013    0.004550    0.816680    
#> 306: 0.461457    1.127764    3.487110    0.150233    0.019016    0.004559    0.816812    
#> 307: 0.461704    1.127602    3.487093    0.149897    0.018982    0.004553    0.817089    
#> 308: 0.461710    1.127342    3.487134    0.149950    0.018946    0.004552    0.817164    
#> 309: 0.462077    1.127112    3.487158    0.149942    0.019025    0.004553    0.817157    
#> 310: 0.462510    1.126943    3.487045    0.150163    0.019103    0.004559    0.817328    
#> 311: 0.462773    1.127012    3.486998    0.149813    0.019165    0.004565    0.817324    
#> 312: 0.462799    1.126869    3.486910    0.149655    0.019188    0.004559    0.817331    
#> 313: 0.462472    1.126752    3.486861    0.149477    0.019205    0.004566    0.817498    
#> 314: 0.461970    1.126909    3.486746    0.149352    0.019176    0.004578    0.817578    
#> 315: 0.461828    1.126866    3.486765    0.149273    0.019161    0.004567    0.817701    
#> 316: 0.461947    1.126808    3.486828    0.149291    0.019141    0.004561    0.817733    
#> 317: 0.462022    1.126618    3.486942    0.149022    0.019140    0.004545    0.817879    
#> 318: 0.462010    1.126531    3.486892    0.149055    0.019137    0.004539    0.817735    
#> 319: 0.462067    1.126467    3.486903    0.149238    0.019130    0.004549    0.817638    
#> 320: 0.461793    1.126517    3.486818    0.149164    0.019113    0.004544    0.817562    
#> 321: 0.461316    1.126606    3.486763    0.149235    0.019057    0.004544    0.817620    
#> 322: 0.461121    1.126666    3.486677    0.149532    0.019003    0.004548    0.817510    
#> 323: 0.460589    1.126700    3.486615    0.149773    0.019006    0.004556    0.817435    
#> 324: 0.460706    1.126750    3.486691    0.149752    0.018989    0.004554    0.817275    
#> 325: 0.460580    1.126790    3.486703    0.149640    0.018946    0.004552    0.817306    
#> 326: 0.460689    1.126697    3.486682    0.149670    0.018937    0.004555    0.817157    
#> 327: 0.460753    1.126683    3.486703    0.149925    0.018917    0.004566    0.817049    
#> 328: 0.460564    1.126894    3.486640    0.150019    0.018900    0.004565    0.816934    
#> 329: 0.460462    1.126890    3.486612    0.149965    0.018882    0.004561    0.816936    
#> 330: 0.460222    1.126817    3.486581    0.150004    0.018889    0.004547    0.816998    
#> 331: 0.460150    1.127023    3.486532    0.150023    0.018914    0.004537    0.817084    
#> 332: 0.460239    1.126948    3.486546    0.149956    0.018936    0.004535    0.817049    
#> 333: 0.460026    1.126949    3.486492    0.149993    0.018936    0.004539    0.817023    
#> 334: 0.459983    1.126924    3.486459    0.150019    0.018925    0.004536    0.816857    
#> 335: 0.459935    1.126869    3.486438    0.150096    0.018894    0.004524    0.816854    
#> 336: 0.459767    1.127046    3.486367    0.149990    0.018881    0.004533    0.816790    
#> 337: 0.459661    1.127144    3.486278    0.150165    0.018902    0.004538    0.816630    
#> 338: 0.459959    1.127159    3.486327    0.150282    0.018942    0.004539    0.816587    
#> 339: 0.460000    1.127175    3.486335    0.150264    0.018981    0.004534    0.816491    
#> 340: 0.460116    1.127099    3.486431    0.150234    0.018989    0.004535    0.816392    
#> 341: 0.460208    1.127113    3.486450    0.150138    0.018980    0.004535    0.816497    
#> 342: 0.459986    1.127033    3.486412    0.150161    0.018953    0.004540    0.816439    
#> 343: 0.459659    1.127035    3.486447    0.150002    0.018932    0.004534    0.816441    
#> 344: 0.459714    1.126983    3.486450    0.149826    0.018919    0.004543    0.816529    
#> 345: 0.459581    1.126990    3.486465    0.149719    0.018894    0.004545    0.816435    
#> 346: 0.459577    1.127115    3.486445    0.149838    0.018895    0.004538    0.816405    
#> 347: 0.459737    1.127032    3.486417    0.149949    0.018920    0.004536    0.816313    
#> 348: 0.459495    1.127100    3.486336    0.150017    0.018939    0.004538    0.816301    
#> 349: 0.459458    1.127248    3.486272    0.150302    0.018940    0.004539    0.816257    
#> 350: 0.459314    1.127343    3.486220    0.150419    0.018919    0.004543    0.816306    
#> 351: 0.459132    1.127562    3.486136    0.150584    0.018898    0.004544    0.816206    
#> 352: 0.458767    1.127632    3.486117    0.150659    0.018931    0.004554    0.816344    
#> 353: 0.458830    1.127570    3.486174    0.150805    0.018921    0.004560    0.816330    
#> 354: 0.459042    1.127560    3.486115    0.151023    0.018901    0.004569    0.816213    
#> 355: 0.459552    1.127449    3.486132    0.150912    0.018857    0.004569    0.816333    
#> 356: 0.459343    1.127390    3.486172    0.150733    0.018867    0.004570    0.816496    
#> 357: 0.459613    1.127382    3.486232    0.150663    0.018878    0.004563    0.816562    
#> 358: 0.459554    1.127366    3.486315    0.150515    0.018879    0.004556    0.816553    
#> 359: 0.459455    1.127387    3.486311    0.150470    0.018861    0.004544    0.816475    
#> 360: 0.459332    1.127421    3.486231    0.150450    0.018834    0.004535    0.816451    
#> 361: 0.459183    1.127419    3.486204    0.150446    0.018810    0.004532    0.816430    
#> 362: 0.459382    1.127407    3.486197    0.150396    0.018776    0.004530    0.816403    
#> 363: 0.459474    1.127193    3.486213    0.150343    0.018762    0.004533    0.816427    
#> 364: 0.459593    1.126993    3.486235    0.150347    0.018731    0.004529    0.816540    
#> 365: 0.459486    1.126941    3.486254    0.150174    0.018744    0.004534    0.816515    
#> 366: 0.459451    1.126948    3.486228    0.150135    0.018730    0.004538    0.816524    
#> 367: 0.459430    1.126948    3.486267    0.150129    0.018709    0.004543    0.816415    
#> 368: 0.459717    1.126979    3.486298    0.150145    0.018725    0.004543    0.816356    
#> 369: 0.459924    1.126971    3.486362    0.150332    0.018721    0.004541    0.816242    
#> 370: 0.459982    1.127073    3.486487    0.150375    0.018739    0.004553    0.816105    
#> 371: 0.459963    1.127095    3.486519    0.150397    0.018740    0.004556    0.815960    
#> 372: 0.459784    1.127202    3.486472    0.150526    0.018798    0.004556    0.815957    
#> 373: 0.459629    1.127321    3.486422    0.150508    0.018825    0.004555    0.816025    
#> 374: 0.459693    1.127370    3.486394    0.150434    0.018832    0.004555    0.816081    
#> 375: 0.459537    1.127347    3.486373    0.150403    0.018808    0.004555    0.816070    
#> 376: 0.459372    1.127334    3.486380    0.150301    0.018809    0.004553    0.816046    
#> 377: 0.459516    1.127362    3.486461    0.150076    0.018835    0.004554    0.816075    
#> 378: 0.459250    1.127373    3.486425    0.150054    0.018842    0.004552    0.816142    
#> 379: 0.459023    1.127325    3.486440    0.150087    0.018831    0.004552    0.816114    
#> 380: 0.458763    1.127352    3.486376    0.150040    0.018835    0.004548    0.816013    
#> 381: 0.458622    1.127327    3.486327    0.149941    0.018871    0.004539    0.816004    
#> 382: 0.458665    1.127314    3.486292    0.149941    0.018868    0.004536    0.816019    
#> 383: 0.458782    1.127254    3.486308    0.149841    0.018866    0.004531    0.815949    
#> 384: 0.458657    1.127181    3.486339    0.149765    0.018851    0.004529    0.816024    
#> 385: 0.458708    1.127208    3.486358    0.149774    0.018845    0.004529    0.816007    
#> 386: 0.458922    1.127225    3.486432    0.149716    0.018857    0.004526    0.815905    
#> 387: 0.459005    1.127157    3.486472    0.149549    0.018853    0.004524    0.815927    
#> 388: 0.458926    1.127207    3.486506    0.149515    0.018845    0.004525    0.815809    
#> 389: 0.459043    1.127019    3.486551    0.149555    0.018848    0.004524    0.815805    
#> 390: 0.458806    1.126988    3.486522    0.149526    0.018876    0.004521    0.815825    
#> 391: 0.458719    1.126978    3.486498    0.149503    0.018871    0.004524    0.815728    
#> 392: 0.458917    1.127000    3.486584    0.149616    0.018860    0.004524    0.815739    
#> 393: 0.458905    1.126944    3.486565    0.149891    0.018860    0.004522    0.815705    
#> 394: 0.458916    1.127014    3.486492    0.149891    0.018854    0.004522    0.815649    
#> 395: 0.459110    1.127121    3.486469    0.149956    0.018866    0.004525    0.815590    
#> 396: 0.459365    1.127200    3.486465    0.150046    0.018872    0.004522    0.815516    
#> 397: 0.459558    1.127174    3.486480    0.150213    0.018888    0.004527    0.815488    
#> 398: 0.459590    1.127084    3.486534    0.150487    0.018876    0.004537    0.815460    
#> 399: 0.459739    1.127002    3.486644    0.150632    0.018858    0.004548    0.815378    
#> 400: 0.459917    1.127053    3.486705    0.150807    0.018850    0.004558    0.815370    
#> 401: 0.459953    1.127107    3.486714    0.150817    0.018837    0.004563    0.815320    
#> 402: 0.459900    1.127159    3.486696    0.150764    0.018838    0.004568    0.815294    
#> 403: 0.460065    1.127147    3.486721    0.150747    0.018846    0.004567    0.815479    
#> 404: 0.460220    1.127261    3.486767    0.150655    0.018843    0.004559    0.815606    
#> 405: 0.460256    1.127398    3.486845    0.150770    0.018838    0.004562    0.815612    
#> 406: 0.460392    1.127490    3.486844    0.150776    0.018836    0.004571    0.815632    
#> 407: 0.460500    1.127579    3.486898    0.150825    0.018810    0.004578    0.815543    
#> 408: 0.460698    1.127657    3.486944    0.150705    0.018828    0.004578    0.815663    
#> 409: 0.460640    1.127662    3.486921    0.150528    0.018820    0.004575    0.815701    
#> 410: 0.460600    1.127681    3.486858    0.150391    0.018805    0.004578    0.815657    
#> 411: 0.460588    1.127526    3.486829    0.150446    0.018818    0.004578    0.815668    
#> 412: 0.460657    1.127399    3.486826    0.150411    0.018816    0.004571    0.815698    
#> 413: 0.460641    1.127443    3.486781    0.150249    0.018813    0.004568    0.815760    
#> 414: 0.460535    1.127464    3.486772    0.150271    0.018798    0.004568    0.815796    
#> 415: 0.460586    1.127461    3.486783    0.150254    0.018793    0.004570    0.815742    
#> 416: 0.460669    1.127507    3.486808    0.150155    0.018776    0.004570    0.815715    
#> 417: 0.460678    1.127469    3.486769    0.150025    0.018776    0.004570    0.815708    
#> 418: 0.460586    1.127458    3.486719    0.150011    0.018769    0.004572    0.815756    
#> 419: 0.460588    1.127532    3.486710    0.150191    0.018754    0.004575    0.815831    
#> 420: 0.460496    1.127567    3.486698    0.150298    0.018749    0.004575    0.815731    
#> 421: 0.460441    1.127630    3.486752    0.150347    0.018741    0.004578    0.815625    
#> 422: 0.460677    1.127571    3.486808    0.150470    0.018728    0.004587    0.815583    
#> 423: 0.460890    1.127518    3.486864    0.150501    0.018733    0.004593    0.815558    
#> 424: 0.460853    1.127513    3.486872    0.150517    0.018741    0.004594    0.815576    
#> 425: 0.461099    1.127641    3.486885    0.150634    0.018770    0.004591    0.815686    
#> 426: 0.461165    1.127658    3.486913    0.150749    0.018790    0.004591    0.815651    
#> 427: 0.461094    1.127510    3.486933    0.150657    0.018799    0.004589    0.815630    
#> 428: 0.460916    1.127509    3.486923    0.150624    0.018779    0.004595    0.815624    
#> 429: 0.460989    1.127495    3.486924    0.150579    0.018759    0.004601    0.815621    
#> 430: 0.461010    1.127478    3.486938    0.150466    0.018769    0.004603    0.815611    
#> 431: 0.460969    1.127474    3.486922    0.150360    0.018768    0.004599    0.815678    
#> 432: 0.460926    1.127520    3.486931    0.150303    0.018773    0.004596    0.815678    
#> 433: 0.460917    1.127667    3.486915    0.150343    0.018794    0.004597    0.815611    
#> 434: 0.460696    1.127794    3.486877    0.150450    0.018808    0.004609    0.815510    
#> 435: 0.460635    1.127906    3.486828    0.150484    0.018804    0.004613    0.815483    
#> 436: 0.460528    1.127870    3.486792    0.150423    0.018842    0.004607    0.815479    
#> 437: 0.460357    1.127906    3.486740    0.150395    0.018859    0.004604    0.815438    
#> 438: 0.460377    1.128045    3.486732    0.150479    0.018849    0.004608    0.815387    
#> 439: 0.460284    1.128106    3.486709    0.150584    0.018862    0.004611    0.815247    
#> 440: 0.460028    1.128157    3.486698    0.150564    0.018857    0.004612    0.815216    
#> 441: 0.460070    1.128215    3.486719    0.150503    0.018876    0.004610    0.815158    
#> 442: 0.459950    1.128254    3.486727    0.150388    0.018867    0.004608    0.815130    
#> 443: 0.460001    1.128333    3.486737    0.150461    0.018870    0.004604    0.815157    
#> 444: 0.460072    1.128393    3.486771    0.150521    0.018879    0.004599    0.815177    
#> 445: 0.460107    1.128394    3.486774    0.150664    0.018877    0.004598    0.815139    
#> 446: 0.460001    1.128430    3.486740    0.150745    0.018858    0.004594    0.815199    
#> 447: 0.460208    1.128513    3.486745    0.150829    0.018850    0.004596    0.815210    
#> 448: 0.460223    1.128555    3.486751    0.150760    0.018853    0.004598    0.815179    
#> 449: 0.460202    1.128681    3.486815    0.150723    0.018851    0.004605    0.815147    
#> 450: 0.460165    1.128712    3.486820    0.150654    0.018838    0.004612    0.815138    
#> 451: 0.460237    1.128784    3.486800    0.150766    0.018826    0.004619    0.815122    
#> 452: 0.460084    1.128905    3.486700    0.150643    0.018804    0.004621    0.815133    
#> 453: 0.460017    1.128953    3.486699    0.150496    0.018808    0.004621    0.815130    
#> 454: 0.459918    1.129077    3.486667    0.150435    0.018809    0.004621    0.815045    
#> 455: 0.459854    1.129153    3.486644    0.150407    0.018805    0.004622    0.815071    
#> 456: 0.459733    1.129191    3.486613    0.150435    0.018799    0.004622    0.815052    
#> 457: 0.459651    1.129203    3.486613    0.150516    0.018798    0.004622    0.815018    
#> 458: 0.459632    1.129319    3.486656    0.150587    0.018796    0.004628    0.815014    
#> 459: 0.459604    1.129432    3.486673    0.150508    0.018791    0.004628    0.815114    
#> 460: 0.459611    1.129429    3.486651    0.150405    0.018779    0.004632    0.815116    
#> 461: 0.459594    1.129466    3.486669    0.150425    0.018771    0.004639    0.815073    
#> 462: 0.459515    1.129533    3.486678    0.150546    0.018760    0.004647    0.815075    
#> 463: 0.459539    1.129532    3.486697    0.150480    0.018758    0.004647    0.815147    
#> 464: 0.459567    1.129530    3.486711    0.150428    0.018752    0.004645    0.815137    
#> 465: 0.459470    1.129482    3.486688    0.150356    0.018766    0.004644    0.815228    
#> 466: 0.459570    1.129442    3.486650    0.150333    0.018765    0.004642    0.815202    
#> 467: 0.459543    1.129472    3.486645    0.150258    0.018766    0.004648    0.815161    
#> 468: 0.459695    1.129512    3.486689    0.150270    0.018758    0.004653    0.815155    
#> 469: 0.459727    1.129649    3.486692    0.150284    0.018771    0.004651    0.815177    
#> 470: 0.459727    1.129738    3.486675    0.150287    0.018757    0.004653    0.815120    
#> 471: 0.459592    1.129738    3.486660    0.150265    0.018753    0.004649    0.815147    
#> 472: 0.459619    1.129732    3.486700    0.150263    0.018750    0.004645    0.815183    
#> 473: 0.459480    1.129733    3.486718    0.150227    0.018755    0.004646    0.815232    
#> 474: 0.459483    1.129730    3.486740    0.150237    0.018728    0.004658    0.815260    
#> 475: 0.459601    1.129799    3.486765    0.150258    0.018719    0.004658    0.815237    
#> 476: 0.459683    1.129786    3.486768    0.150347    0.018713    0.004661    0.815285    
#> 477: 0.459620    1.129874    3.486781    0.150342    0.018706    0.004661    0.815262    
#> 478: 0.459600    1.129834    3.486772    0.150268    0.018690    0.004664    0.815248    
#> 479: 0.459670    1.129820    3.486762    0.150326    0.018695    0.004661    0.815293    
#> 480: 0.459741    1.129844    3.486801    0.150388    0.018701    0.004668    0.815345    
#> 481: 0.459730    1.129894    3.486802    0.150300    0.018692    0.004668    0.815339    
#> 482: 0.459799    1.129838    3.486814    0.150290    0.018682    0.004667    0.815357    
#> 483: 0.459720    1.129826    3.486806    0.150342    0.018702    0.004665    0.815338    
#> 484: 0.459696    1.129788    3.486790    0.150293    0.018712    0.004664    0.815294    
#> 485: 0.459778    1.129876    3.486814    0.150326    0.018714    0.004661    0.815251    
#> 486: 0.459835    1.129915    3.486819    0.150261    0.018716    0.004657    0.815218    
#> 487: 0.460034    1.129962    3.486860    0.150264    0.018719    0.004655    0.815211    
#> 488: 0.460072    1.129931    3.486869    0.150182    0.018718    0.004653    0.815209    
#> 489: 0.460158    1.129864    3.486895    0.150206    0.018713    0.004658    0.815263    
#> 490: 0.460260    1.129831    3.486960    0.150269    0.018712    0.004662    0.815312    
#> 491: 0.460332    1.129814    3.486996    0.150183    0.018703    0.004662    0.815368    
#> 492: 0.460439    1.129799    3.487036    0.150103    0.018708    0.004663    0.815395    
#> 493: 0.460338    1.129790    3.487050    0.149988    0.018730    0.004665    0.815515    
#> 494: 0.460379    1.129831    3.487039    0.149817    0.018755    0.004666    0.815516    
#> 495: 0.460568    1.129877    3.487072    0.149859    0.018775    0.004671    0.815497    
#> 496: 0.460683    1.129917    3.487077    0.149839    0.018789    0.004674    0.815466    
#> 497: 0.460623    1.129866    3.487085    0.149919    0.018791    0.004675    0.815433    
#> 498: 0.460571    1.129854    3.487065    0.149847    0.018784    0.004675    0.815388    
#> 499: 0.460622    1.129861    3.487032    0.149899    0.018805    0.004672    0.815322    
#> 500: 0.460596    1.129855    3.486993    0.149804    0.018821    0.004668    0.815300    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.321393    0.986219    3.449194    0.392401    0.082519    0.016800    1.828773    
#> 002: 0.322850    1.046422    3.459970    0.372781    0.078393    0.015960    1.158629    
#> 003: 0.477447    0.981147    3.493591    0.354142    0.074474    0.015162    0.912331    
#> 004: 0.430483    1.025309    3.486865    0.336435    0.070750    0.014404    0.832488    
#> 005: 0.512548    1.035025    3.492838    0.331578    0.067213    0.013684    0.739706    
#> 006: 0.509412    1.031640    3.473711    0.380312    0.063852    0.013000    0.694354    
#> 007: 0.450965    1.056809    3.463654    0.361422    0.060659    0.012350    0.703987    
#> 008: 0.451487    1.038434    3.458271    0.426015    0.057626    0.011732    0.686783    
#> 009: 0.463747    1.030463    3.457080    0.500752    0.054745    0.014565    0.673300    
#> 010: 0.447947    1.036021    3.447439    0.537986    0.052008    0.017398    0.685179    
#> 011: 0.506833    1.040689    3.460042    0.560978    0.053100    0.016528    0.684418    
#> 012: 0.544701    1.038222    3.455450    0.622635    0.050748    0.015702    0.648055    
#> 013: 0.454857    1.043956    3.447422    0.591504    0.048211    0.015514    0.656333    
#> 014: 0.525705    1.028218    3.465983    0.561928    0.054687    0.014738    0.646320    
#> 015: 0.493597    1.030986    3.464821    0.566847    0.051952    0.014001    0.629294    
#> 016: 0.509065    1.048282    3.472678    0.576260    0.049355    0.016013    0.632293    
#> 017: 0.513050    1.054986    3.472196    0.582012    0.046887    0.015523    0.629230    
#> 018: 0.512883    1.060849    3.460172    0.552911    0.044543    0.015473    0.631839    
#> 019: 0.477646    1.060534    3.463035    0.525265    0.042315    0.016389    0.627709    
#> 020: 0.468617    1.055873    3.460351    0.499002    0.042037    0.017626    0.645903    
#> 021: 0.515154    1.038332    3.473119    0.495146    0.039935    0.019707    0.631348    
#> 022: 0.517437    1.034095    3.485569    0.543619    0.037938    0.021231    0.617809    
#> 023: 0.608779    1.044597    3.489981    0.645958    0.037568    0.022600    0.639465    
#> 024: 0.586256    1.068526    3.485916    0.641026    0.035690    0.025413    0.625857    
#> 025: 0.532621    1.060702    3.459168    0.745644    0.033905    0.024143    0.631890    
#> 026: 0.471384    1.091059    3.441604    0.708362    0.034355    0.022935    0.650477    
#> 027: 0.449729    1.092998    3.445020    0.672944    0.037554    0.021789    0.657210    
#> 028: 0.486098    1.074591    3.451894    0.639297    0.035676    0.020699    0.644242    
#> 029: 0.486862    1.066326    3.452451    0.617981    0.046861    0.025004    0.637058    
#> 030: 0.518226    1.070114    3.447241    0.721127    0.044518    0.023786    0.633785    
#> 031: 0.506100    1.066613    3.462114    0.763172    0.042292    0.022766    0.628828    
#> 032: 0.455317    1.066401    3.455223    0.725014    0.040178    0.022662    0.631229    
#> 033: 0.473478    1.096788    3.450816    0.688763    0.050595    0.021529    0.645350    
#> 034: 0.517965    1.091648    3.458338    0.654325    0.048065    0.020453    0.645868    
#> 035: 0.480668    1.053458    3.457907    0.621609    0.045662    0.019430    0.628553    
#> 036: 0.505014    1.054853    3.458187    0.604660    0.043379    0.018459    0.645986    
#> 037: 0.530285    1.073084    3.464742    0.576958    0.042566    0.017536    0.649930    
#> 038: 0.520199    1.062205    3.462262    0.548110    0.041014    0.016659    0.637999    
#> 039: 0.485419    1.068249    3.467530    0.520705    0.049520    0.015826    0.646804    
#> 040: 0.511244    1.064887    3.475375    0.494670    0.047044    0.015035    0.661232    
#> 041: 0.522776    1.049021    3.478807    0.542404    0.044692    0.015118    0.640946    
#> 042: 0.521965    1.053091    3.469116    0.598075    0.042457    0.015560    0.653251    
#> 043: 0.475831    1.071191    3.446192    0.568172    0.040334    0.018130    0.651819    
#> 044: 0.479735    1.078177    3.456547    0.570509    0.038431    0.017224    0.640025    
#> 045: 0.468010    1.099973    3.440868    0.554012    0.041878    0.016363    0.643623    
#> 046: 0.476207    1.064539    3.450348    0.531859    0.039785    0.017193    0.633928    
#> 047: 0.505962    1.065737    3.453424    0.557410    0.046101    0.016333    0.627599    
#> 048: 0.474057    1.061939    3.451704    0.529540    0.052780    0.015516    0.643695    
#> 049: 0.483535    1.067880    3.457115    0.503063    0.050812    0.014740    0.651667    
#> 050: 0.500018    1.058484    3.454151    0.578201    0.054013    0.014003    0.658656    
#> 051: 0.497016    1.064786    3.453081    0.570969    0.057191    0.013303    0.667422    
#> 052: 0.513071    1.058470    3.469690    0.542421    0.054331    0.013164    0.640081    
#> 053: 0.500469    1.048358    3.467555    0.515300    0.051615    0.012506    0.649953    
#> 054: 0.477690    1.058299    3.469817    0.489535    0.049034    0.016492    0.661553    
#> 055: 0.475087    1.060900    3.473342    0.465058    0.046582    0.016428    0.659032    
#> 056: 0.537638    1.052366    3.479345    0.474690    0.044253    0.016746    0.672709    
#> 057: 0.495178    1.049997    3.472531    0.478655    0.050069    0.016009    0.677121    
#> 058: 0.465668    1.049448    3.457131    0.459796    0.048784    0.015208    0.666457    
#> 059: 0.454989    1.035100    3.459702    0.507715    0.046344    0.016067    0.671356    
#> 060: 0.496894    1.046432    3.476271    0.482329    0.044027    0.019315    0.677464    
#> 061: 0.525374    1.044783    3.474856    0.568742    0.041826    0.019920    0.685924    
#> 062: 0.505110    1.055487    3.468252    0.540305    0.039779    0.021531    0.689879    
#> 063: 0.537272    1.041389    3.469580    0.550605    0.037790    0.022392    0.694301    
#> 064: 0.487073    1.038616    3.468454    0.566496    0.035901    0.022539    0.681578    
#> 065: 0.526101    1.051029    3.466131    0.552301    0.034106    0.023285    0.645626    
#> 066: 0.517533    1.054552    3.466488    0.557455    0.032400    0.022121    0.647633    
#> 067: 0.474976    1.040347    3.457055    0.529583    0.032241    0.024816    0.649260    
#> 068: 0.442276    1.064544    3.456581    0.503103    0.031053    0.023575    0.668945    
#> 069: 0.452836    1.082949    3.445806    0.545324    0.034707    0.022396    0.655895    
#> 070: 0.417024    1.080885    3.453110    0.518058    0.032972    0.021277    0.659016    
#> 071: 0.415400    1.099996    3.421607    0.492155    0.035532    0.020213    0.667731    
#> 072: 0.411864    1.065947    3.435585    0.536991    0.033755    0.019202    0.643313    
#> 073: 0.464328    1.065547    3.447298    0.766599    0.035217    0.018242    0.645045    
#> 074: 0.462664    1.065031    3.447165    0.728269    0.037602    0.018770    0.646768    
#> 075: 0.461093    1.061382    3.467832    0.691855    0.036672    0.017832    0.661855    
#> 076: 0.529756    1.083424    3.479673    0.657263    0.034838    0.019271    0.659134    
#> 077: 0.520143    1.051091    3.466034    0.624400    0.033096    0.018307    0.666360    
#> 078: 0.502339    1.033012    3.470749    0.593180    0.033215    0.017949    0.656979    
#> 079: 0.486883    1.044841    3.457627    0.589773    0.038693    0.017051    0.652581    
#> 080: 0.522300    1.042579    3.461764    0.560285    0.038854    0.018731    0.673103    
#> 081: 0.507650    1.053873    3.453301    0.610816    0.038766    0.020698    0.647788    
#> 082: 0.496483    1.049662    3.458768    0.580275    0.041376    0.019663    0.653452    
#> 083: 0.496896    1.071516    3.450389    0.642837    0.039307    0.018680    0.652615    
#> 084: 0.471627    1.070588    3.448160    0.610696    0.041304    0.017746    0.639167    
#> 085: 0.468190    1.078868    3.456132    0.580161    0.039239    0.016859    0.639156    
#> 086: 0.494416    1.075961    3.459405    0.551153    0.040004    0.016153    0.637943    
#> 087: 0.468205    1.052559    3.457978    0.523595    0.041564    0.017577    0.642512    
#> 088: 0.443594    1.058840    3.455587    0.502078    0.039486    0.016698    0.660448    
#> 089: 0.474566    1.068520    3.458486    0.476974    0.047954    0.018110    0.651266    
#> 090: 0.496174    1.073951    3.451310    0.478733    0.050155    0.017204    0.658946    
#> 091: 0.444365    1.069146    3.438144    0.479989    0.049751    0.016460    0.655015    
#> 092: 0.440957    1.085288    3.428667    0.580248    0.047264    0.018017    0.658448    
#> 093: 0.400988    1.067365    3.428282    0.551236    0.044900    0.017116    0.671043    
#> 094: 0.431297    1.078740    3.427627    0.523674    0.044320    0.018878    0.667278    
#> 095: 0.453833    1.071325    3.458270    0.504225    0.042104    0.025007    0.653810    
#> 096: 0.429408    1.070895    3.447862    0.530896    0.039999    0.023756    0.654057    
#> 097: 0.492708    1.064152    3.469901    0.504351    0.044387    0.022569    0.650080    
#> 098: 0.515098    1.077548    3.473215    0.535610    0.042168    0.021440    0.652952    
#> 099: 0.505699    1.045238    3.461561    0.508830    0.040059    0.020368    0.659293    
#> 100: 0.482901    1.045726    3.471317    0.483388    0.042238    0.019350    0.646786    
#> 101: 0.442310    1.043284    3.447707    0.459219    0.042523    0.018382    0.653440    
#> 102: 0.464089    1.044916    3.450044    0.459905    0.040692    0.017463    0.648174    
#> 103: 0.480509    1.055388    3.470182    0.436910    0.042317    0.016590    0.644888    
#> 104: 0.507206    1.053459    3.475794    0.510631    0.040201    0.015760    0.662887    
#> 105: 0.512689    1.053255    3.467064    0.547875    0.038191    0.014972    0.663515    
#> 106: 0.497273    1.058182    3.463909    0.591956    0.036551    0.015625    0.641500    
#> 107: 0.516490    1.064555    3.468599    0.562358    0.038632    0.017604    0.637516    
#> 108: 0.507202    1.070417    3.459689    0.537242    0.036818    0.019136    0.649716    
#> 109: 0.483636    1.059154    3.471721    0.510380    0.034977    0.021227    0.638231    
#> 110: 0.531440    1.060785    3.467812    0.528456    0.033973    0.022412    0.635183    
#> 111: 0.496519    1.059052    3.471264    0.502033    0.034632    0.021291    0.629026    
#> 112: 0.482603    1.036972    3.459688    0.479374    0.035160    0.020226    0.630472    
#> 113: 0.500099    1.050461    3.471373    0.527326    0.034193    0.019215    0.642139    
#> 114: 0.524137    1.054419    3.474650    0.584715    0.044618    0.018254    0.636693    
#> 115: 0.553144    1.041018    3.466113    0.642517    0.042387    0.020901    0.647096    
#> 116: 0.525311    1.056244    3.460285    0.610391    0.040267    0.019856    0.657039    
#> 117: 0.487888    1.069759    3.473600    0.579871    0.038254    0.019769    0.656357    
#> 118: 0.535473    1.057371    3.471182    0.550878    0.041674    0.018781    0.652723    
#> 119: 0.515550    1.063540    3.467845    0.529784    0.048726    0.019049    0.664441    
#> 120: 0.467750    1.064602    3.457221    0.596147    0.046290    0.018097    0.655100    
#> 121: 0.475627    1.078427    3.455619    0.566340    0.043976    0.017192    0.658791    
#> 122: 0.500758    1.066703    3.454720    0.538023    0.041777    0.016332    0.655844    
#> 123: 0.490766    1.091183    3.452340    0.511122    0.039688    0.015953    0.658746    
#> 124: 0.486920    1.108629    3.445886    0.566500    0.037704    0.016857    0.654661    
#> 125: 0.488903    1.103813    3.452345    0.538175    0.037875    0.016891    0.647628    
#> 126: 0.458777    1.095870    3.444252    0.511266    0.041320    0.016528    0.650014    
#> 127: 0.472065    1.066428    3.447835    0.485703    0.039254    0.015701    0.653729    
#> 128: 0.475076    1.062535    3.460601    0.476180    0.043089    0.016297    0.650187    
#> 129: 0.512884    1.068085    3.468149    0.507006    0.047848    0.018709    0.634698    
#> 130: 0.537073    1.070247    3.465225    0.582492    0.046479    0.017774    0.631483    
#> 131: 0.510570    1.059901    3.448189    0.553367    0.052456    0.017238    0.627592    
#> 132: 0.452746    1.076143    3.442878    0.550842    0.049833    0.021428    0.634624    
#> 133: 0.405060    1.064267    3.442438    0.523300    0.047341    0.021679    0.664701    
#> 134: 0.489384    1.045612    3.464586    0.602959    0.044974    0.023186    0.647166    
#> 135: 0.530987    1.041068    3.465090    0.631675    0.042726    0.022027    0.635656    
#> 136: 0.504935    1.039172    3.467700    0.600091    0.040589    0.021272    0.630401    
#> 137: 0.552032    1.047860    3.467540    0.648842    0.038560    0.021198    0.639461    
#> 138: 0.512374    1.059569    3.466639    0.616400    0.037893    0.020138    0.641235    
#> 139: 0.487081    1.051693    3.473258    0.585580    0.037278    0.019131    0.643886    
#> 140: 0.501624    1.068691    3.468404    0.556301    0.042919    0.018175    0.661786    
#> 141: 0.504195    1.038636    3.477016    0.528486    0.040773    0.017266    0.659151    
#> 142: 0.523788    1.024836    3.483638    0.517412    0.038734    0.017423    0.650028    
#> 143: 0.501453    1.033603    3.485085    0.491542    0.048122    0.019674    0.651079    
#> 144: 0.542264    1.046077    3.487455    0.547350    0.045716    0.019216    0.639896    
#> 145: 0.498893    1.060067    3.465283    0.524997    0.043430    0.018255    0.646774    
#> 146: 0.470661    1.060635    3.471247    0.542048    0.041259    0.020633    0.654366    
#> 147: 0.448125    1.061225    3.448815    0.579469    0.039196    0.020218    0.640643    
#> 148: 0.489780    1.065516    3.465378    0.550496    0.040727    0.021466    0.644532    
#> 149: 0.472616    1.053326    3.460248    0.548861    0.038690    0.024222    0.658608    
#> 150: 0.486113    1.056086    3.447909    0.593699    0.036756    0.023701    0.661336    
#> 151: 0.449427    1.073932    3.445107    0.575656    0.034918    0.022516    0.638595    
#> 152: 0.447723    1.072497    3.440597    0.543936    0.032322    0.018203    0.637844    
#> 153: 0.425723    1.086975    3.450295    0.564055    0.035975    0.019508    0.662176    
#> 154: 0.499739    1.085255    3.456298    0.495006    0.035001    0.022137    0.649908    
#> 155: 0.482365    1.058939    3.457341    0.495739    0.035637    0.019422    0.644859    
#> 156: 0.516218    1.079095    3.468283    0.496607    0.027734    0.022513    0.672192    
#> 157: 0.509310    1.067507    3.477409    0.511921    0.025738    0.022645    0.660155    
#> 158: 0.526785    1.071928    3.464762    0.561108    0.025418    0.021104    0.653228    
#> 159: 0.479091    1.080698    3.468568    0.525322    0.034790    0.019156    0.645895    
#> 160: 0.505837    1.036564    3.489246    0.511517    0.029574    0.019770    0.656505    
#> 161: 0.501715    1.036616    3.472888    0.534868    0.031628    0.021559    0.651862    
#> 162: 0.491042    1.059365    3.473741    0.478338    0.031693    0.022660    0.658293    
#> 163: 0.510129    1.035186    3.463257    0.493624    0.030007    0.021667    0.636933    
#> 164: 0.494149    1.059655    3.468530    0.463365    0.033772    0.018643    0.623773    
#> 165: 0.516372    1.049810    3.471844    0.484493    0.039095    0.018504    0.642843    
#> 166: 0.515885    1.082195    3.461821    0.440078    0.035978    0.018592    0.665711    
#> 167: 0.515220    1.076815    3.487627    0.428791    0.034711    0.014312    0.661766    
#> 168: 0.513735    1.089885    3.472231    0.514299    0.034041    0.015227    0.649383    
#> 169: 0.494132    1.097731    3.466449    0.429586    0.038002    0.018306    0.661533    
#> 170: 0.506635    1.075427    3.457486    0.503609    0.043010    0.020237    0.650458    
#> 171: 0.464529    1.069338    3.461324    0.452731    0.038730    0.016329    0.635090    
#> 172: 0.441416    1.077944    3.452703    0.432605    0.044731    0.015805    0.639087    
#> 173: 0.450587    1.083152    3.433206    0.502711    0.040724    0.012295    0.647015    
#> 174: 0.490284    1.084946    3.442733    0.574362    0.042906    0.013592    0.638967    
#> 175: 0.423224    1.092150    3.431041    0.558501    0.047008    0.011797    0.656124    
#> 176: 0.456131    1.094172    3.446540    0.604680    0.045734    0.011745    0.640308    
#> 177: 0.471521    1.070772    3.456980    0.530888    0.041001    0.012898    0.652492    
#> 178: 0.499681    1.053889    3.458800    0.446664    0.051521    0.012551    0.642118    
#> 179: 0.499744    1.079305    3.456644    0.492757    0.041809    0.014232    0.662677    
#> 180: 0.461271    1.071592    3.458436    0.476846    0.045028    0.014489    0.652067    
#> 181: 0.449410    1.064498    3.447922    0.410524    0.041310    0.014357    0.659571    
#> 182: 0.469462    1.074819    3.445180    0.446567    0.044330    0.011001    0.657130    
#> 183: 0.466433    1.089582    3.445808    0.469124    0.047612    0.009703    0.651736    
#> 184: 0.473878    1.057561    3.459279    0.469973    0.042113    0.010726    0.643613    
#> 185: 0.459821    1.080338    3.456500    0.487509    0.047419    0.012835    0.636370    
#> 186: 0.454477    1.110036    3.451408    0.501166    0.060148    0.014502    0.659848    
#> 187: 0.475370    1.067198    3.456587    0.501726    0.041844    0.011355    0.671165    
#> 188: 0.450360    1.084495    3.449606    0.426469    0.043217    0.013629    0.681178    
#> 189: 0.431891    1.093455    3.446715    0.518613    0.044130    0.013716    0.665648    
#> 190: 0.437254    1.075803    3.450237    0.466860    0.038530    0.010892    0.667651    
#> 191: 0.461524    1.072982    3.449088    0.449623    0.039125    0.011031    0.645892    
#> 192: 0.424425    1.079796    3.445970    0.498383    0.037512    0.012730    0.645939    
#> 193: 0.483969    1.092202    3.450733    0.505519    0.041740    0.013636    0.642436    
#> 194: 0.447726    1.094470    3.438592    0.464236    0.037727    0.017050    0.658149    
#> 195: 0.438975    1.094305    3.436892    0.511265    0.038541    0.016248    0.657473    
#> 196: 0.441217    1.081605    3.445243    0.478780    0.037952    0.017337    0.654851    
#> 197: 0.424633    1.087710    3.457063    0.461763    0.038225    0.022552    0.654102    
#> 198: 0.498642    1.074135    3.461650    0.440037    0.033117    0.018847    0.641535    
#> 199: 0.501832    1.062528    3.459689    0.511847    0.034750    0.020855    0.638043    
#> 200: 0.485236    1.060324    3.460872    0.516153    0.027646    0.018062    0.650269    
#> 201: 0.488033    1.057751    3.466247    0.513160    0.027970    0.017646    0.651298    
#> 202: 0.493662    1.057163    3.466790    0.538892    0.027798    0.016832    0.653155    
#> 203: 0.504758    1.055686    3.463307    0.573956    0.028085    0.017183    0.655342    
#> 204: 0.513077    1.052095    3.464709    0.589538    0.030243    0.017229    0.654551    
#> 205: 0.519972    1.056708    3.465989    0.588400    0.031404    0.017920    0.652023    
#> 206: 0.516810    1.060516    3.465926    0.586850    0.031372    0.017606    0.650969    
#> 207: 0.517251    1.059206    3.464603    0.593409    0.031289    0.017266    0.648748    
#> 208: 0.519970    1.058809    3.465037    0.595786    0.031767    0.017113    0.647160    
#> 209: 0.523937    1.056986    3.465434    0.600334    0.032459    0.016774    0.646627    
#> 210: 0.527648    1.056245    3.466269    0.605611    0.032776    0.016550    0.645364    
#> 211: 0.527858    1.057017    3.467409    0.600505    0.033214    0.016300    0.645186    
#> 212: 0.527267    1.056842    3.468167    0.590842    0.033456    0.016445    0.646035    
#> 213: 0.528180    1.054510    3.468848    0.585669    0.034149    0.016412    0.647374    
#> 214: 0.529467    1.052908    3.469808    0.580830    0.034211    0.016358    0.647322    
#> 215: 0.530382    1.052622    3.470695    0.577813    0.034557    0.016499    0.648175    
#> 216: 0.533015    1.051565    3.471209    0.580008    0.034719    0.016520    0.648900    
#> 217: 0.533034    1.051499    3.471717    0.576778    0.034697    0.016521    0.649077    
#> 218: 0.533014    1.051785    3.471435    0.577199    0.034884    0.016555    0.648645    
#> 219: 0.530192    1.051638    3.470516    0.573470    0.034939    0.016547    0.648476    
#> 220: 0.526540    1.052328    3.469776    0.574104    0.035043    0.016603    0.648347    
#> 221: 0.525038    1.052809    3.469314    0.571463    0.035082    0.016603    0.647446    
#> 222: 0.523317    1.052361    3.469065    0.566501    0.034835    0.016569    0.646952    
#> 223: 0.523375    1.052095    3.469021    0.567697    0.034962    0.016604    0.646266    
#> 224: 0.524234    1.052322    3.468963    0.568562    0.035103    0.016588    0.645708    
#> 225: 0.523251    1.051383    3.469007    0.568533    0.035162    0.016529    0.645491    
#> 226: 0.523263    1.050188    3.468925    0.564506    0.035185    0.016490    0.645968    
#> 227: 0.522918    1.050019    3.468832    0.564922    0.035455    0.016426    0.645265    
#> 228: 0.521410    1.050497    3.468395    0.563692    0.035643    0.016515    0.645195    
#> 229: 0.519412    1.050986    3.467706    0.561574    0.035562    0.016504    0.645073    
#> 230: 0.518081    1.051087    3.467314    0.560279    0.035406    0.016470    0.645197    
#> 231: 0.515757    1.052138    3.466849    0.559475    0.035672    0.016548    0.645162    
#> 232: 0.513589    1.052411    3.466582    0.556804    0.035885    0.016568    0.645508    
#> 233: 0.512699    1.051909    3.466649    0.556782    0.035949    0.016637    0.645537    
#> 234: 0.512190    1.051630    3.466561    0.555672    0.036002    0.016683    0.645755    
#> 235: 0.512024    1.050965    3.466522    0.554874    0.036139    0.016688    0.645945    
#> 236: 0.511696    1.051340    3.466327    0.554737    0.036255    0.016739    0.646279    
#> 237: 0.512130    1.051338    3.466148    0.555786    0.036183    0.016790    0.646813    
#> 238: 0.512492    1.051780    3.466007    0.557962    0.036255    0.016865    0.647181    
#> 239: 0.510845    1.052332    3.465733    0.555853    0.036232    0.016891    0.647482    
#> 240: 0.509529    1.052306    3.465853    0.551494    0.036061    0.016878    0.648110    
#> 241: 0.509603    1.052055    3.465939    0.551185    0.036115    0.016919    0.648452    
#> 242: 0.508720    1.052115    3.465514    0.551716    0.036205    0.016972    0.648792    
#> 243: 0.507845    1.052536    3.465300    0.551204    0.036225    0.017004    0.648975    
#> 244: 0.507147    1.052351    3.465202    0.552802    0.036124    0.017087    0.649011    
#> 245: 0.507099    1.052140    3.465207    0.552621    0.036030    0.017170    0.649427    
#> 246: 0.507841    1.051695    3.465371    0.552517    0.035921    0.017183    0.649973    
#> 247: 0.508379    1.051087    3.465842    0.550790    0.035803    0.017186    0.650093    
#> 248: 0.508683    1.051233    3.465999    0.549637    0.035682    0.017211    0.650235    
#> 249: 0.508291    1.051290    3.466029    0.548551    0.035760    0.017205    0.650106    
#> 250: 0.508215    1.051609    3.465973    0.548217    0.035683    0.017278    0.650039    
#> 251: 0.508789    1.051949    3.466156    0.547587    0.035572    0.017306    0.650252    
#> 252: 0.510012    1.051924    3.466648    0.549029    0.035526    0.017265    0.650370    
#> 253: 0.510813    1.051850    3.466955    0.550480    0.035539    0.017346    0.650284    
#> 254: 0.511867    1.052222    3.467209    0.552209    0.035547    0.017480    0.650539    
#> 255: 0.511957    1.052533    3.467144    0.554072    0.035489    0.017624    0.650728    
#> 256: 0.512013    1.052511    3.467117    0.554420    0.035346    0.017777    0.650910    
#> 257: 0.511391    1.052277    3.467049    0.553359    0.035323    0.017877    0.651028    
#> 258: 0.510514    1.051982    3.466970    0.551562    0.035298    0.017928    0.651336    
#> 259: 0.510225    1.051907    3.466895    0.550803    0.035325    0.017990    0.651451    
#> 260: 0.509715    1.052102    3.466942    0.549963    0.035403    0.017954    0.651559    
#> 261: 0.510052    1.051984    3.467004    0.551044    0.035434    0.017942    0.651696    
#> 262: 0.509114    1.052075    3.466933    0.548820    0.035361    0.017907    0.651875    
#> 263: 0.508644    1.052203    3.466860    0.547628    0.035358    0.017853    0.651989    
#> 264: 0.508182    1.052508    3.466754    0.546451    0.035368    0.017847    0.652012    
#> 265: 0.508390    1.052580    3.466736    0.545436    0.035383    0.017832    0.652199    
#> 266: 0.508740    1.052968    3.466645    0.545015    0.035374    0.017776    0.652280    
#> 267: 0.508653    1.053002    3.466731    0.545856    0.035386    0.017771    0.652339    
#> 268: 0.508271    1.053015    3.466786    0.544525    0.035401    0.017764    0.652288    
#> 269: 0.508034    1.052935    3.466806    0.543470    0.035390    0.017725    0.652234    
#> 270: 0.507603    1.053015    3.466708    0.543007    0.035378    0.017700    0.652129    
#> 271: 0.507760    1.052917    3.466780    0.543058    0.035307    0.017714    0.652357    
#> 272: 0.507963    1.052798    3.466854    0.542655    0.035237    0.017785    0.652606    
#> 273: 0.507499    1.053060    3.466776    0.542281    0.035290    0.017803    0.652779    
#> 274: 0.507276    1.053340    3.466716    0.543340    0.035264    0.017796    0.652615    
#> 275: 0.507057    1.053317    3.466505    0.543089    0.035322    0.017801    0.652594    
#> 276: 0.506492    1.053439    3.466476    0.543215    0.035224    0.017803    0.652481    
#> 277: 0.506286    1.053839    3.466570    0.543752    0.035198    0.017851    0.652473    
#> 278: 0.505649    1.053972    3.466577    0.543853    0.035236    0.017864    0.652425    
#> 279: 0.505456    1.053923    3.466641    0.543860    0.035181    0.017875    0.652354    
#> 280: 0.505354    1.053916    3.466692    0.543472    0.035174    0.017887    0.652212    
#> 281: 0.504665    1.054045    3.466617    0.542472    0.035130    0.017874    0.652305    
#> 282: 0.504623    1.054180    3.466546    0.542390    0.035104    0.017884    0.652489    
#> 283: 0.504922    1.054215    3.466717    0.542994    0.035095    0.017915    0.652710    
#> 284: 0.504795    1.054017    3.466717    0.542955    0.035090    0.017969    0.652548    
#> 285: 0.504747    1.054090    3.466578    0.543579    0.035101    0.018008    0.652497    
#> 286: 0.504735    1.054380    3.466451    0.543767    0.035150    0.018042    0.652649    
#> 287: 0.504152    1.054716    3.466183    0.544324    0.035111    0.018121    0.652846    
#> 288: 0.503788    1.054874    3.465934    0.544573    0.035150    0.018134    0.653031    
#> 289: 0.503640    1.054921    3.465758    0.544377    0.035172    0.018106    0.653205    
#> 290: 0.503344    1.055107    3.465664    0.543819    0.035164    0.018092    0.653302    
#> 291: 0.503027    1.055231    3.465617    0.543430    0.035163    0.018100    0.653257    
#> 292: 0.502446    1.055374    3.465489    0.542666    0.035184    0.018083    0.653399    
#> 293: 0.502031    1.055574    3.465233    0.541960    0.035209    0.018093    0.653448    
#> 294: 0.501411    1.055970    3.464938    0.542040    0.035352    0.018078    0.653530    
#> 295: 0.500938    1.055833    3.464733    0.542809    0.035377    0.018087    0.653528    
#> 296: 0.500757    1.055666    3.464552    0.543799    0.035335    0.018144    0.653681    
#> 297: 0.500413    1.055718    3.464473    0.544118    0.035372    0.018181    0.653535    
#> 298: 0.500473    1.055626    3.464443    0.545146    0.035389    0.018221    0.653352    
#> 299: 0.500306    1.055775    3.464324    0.545751    0.035422    0.018230    0.653101    
#> 300: 0.500467    1.055844    3.464392    0.546107    0.035482    0.018233    0.652870    
#> 301: 0.500585    1.055882    3.464293    0.546730    0.035492    0.018243    0.652708    
#> 302: 0.500460    1.056075    3.464164    0.546798    0.035519    0.018266    0.652483    
#> 303: 0.500228    1.056311    3.464003    0.547132    0.035525    0.018288    0.652308    
#> 304: 0.500135    1.056562    3.463824    0.547498    0.035572    0.018315    0.652106    
#> 305: 0.499648    1.056543    3.463693    0.546840    0.035615    0.018357    0.652026    
#> 306: 0.499167    1.056549    3.463493    0.546215    0.035594    0.018352    0.652018    
#> 307: 0.498591    1.056560    3.463208    0.547088    0.035596    0.018344    0.652072    
#> 308: 0.498169    1.056506    3.463051    0.547609    0.035720    0.018308    0.652137    
#> 309: 0.498109    1.056314    3.462988    0.548615    0.035755    0.018293    0.652403    
#> 310: 0.498222    1.056225    3.462813    0.550103    0.035775    0.018285    0.652593    
#> 311: 0.498202    1.056290    3.462782    0.551147    0.035779    0.018298    0.652386    
#> 312: 0.497813    1.056329    3.462642    0.551591    0.035746    0.018294    0.652387    
#> 313: 0.497201    1.056236    3.462444    0.551575    0.035781    0.018302    0.652370    
#> 314: 0.496668    1.056285    3.462238    0.551361    0.035778    0.018328    0.652483    
#> 315: 0.496092    1.056400    3.462014    0.550527    0.035820    0.018344    0.652513    
#> 316: 0.495735    1.056576    3.461798    0.549888    0.035858    0.018331    0.652606    
#> 317: 0.495809    1.056623    3.461813    0.549537    0.035895    0.018330    0.652760    
#> 318: 0.495960    1.056600    3.461804    0.549480    0.035894    0.018335    0.652770    
#> 319: 0.496189    1.056570    3.461840    0.549547    0.035925    0.018314    0.653056    
#> 320: 0.496128    1.056537    3.461865    0.549730    0.035870    0.018289    0.653319    
#> 321: 0.496045    1.056601    3.461806    0.549677    0.035900    0.018287    0.653421    
#> 322: 0.496046    1.056584    3.461719    0.548955    0.035917    0.018241    0.653655    
#> 323: 0.495685    1.056630    3.461605    0.548377    0.035913    0.018244    0.653724    
#> 324: 0.495562    1.056669    3.461568    0.548371    0.035888    0.018244    0.653736    
#> 325: 0.495302    1.056782    3.461468    0.548122    0.035867    0.018280    0.653644    
#> 326: 0.494943    1.056721    3.461423    0.548046    0.035888    0.018335    0.653605    
#> 327: 0.495056    1.056771    3.461519    0.547572    0.035853    0.018375    0.653593    
#> 328: 0.495284    1.056718    3.461608    0.547242    0.035769    0.018405    0.653447    
#> 329: 0.495456    1.056752    3.461691    0.547217    0.035712    0.018427    0.653255    
#> 330: 0.495257    1.056828    3.461659    0.547151    0.035662    0.018440    0.653243    
#> 331: 0.495261    1.057005    3.461678    0.546959    0.035672    0.018427    0.653263    
#> 332: 0.495067    1.057074    3.461650    0.546370    0.035671    0.018440    0.653300    
#> 333: 0.494862    1.057171    3.461580    0.545679    0.035768    0.018415    0.653184    
#> 334: 0.494590    1.057145    3.461422    0.545534    0.035847    0.018383    0.653106    
#> 335: 0.494508    1.057137    3.461341    0.545138    0.035929    0.018358    0.653073    
#> 336: 0.494259    1.057354    3.461251    0.545001    0.036041    0.018343    0.653113    
#> 337: 0.494117    1.057672    3.461213    0.545308    0.036088    0.018316    0.653134    
#> 338: 0.494041    1.057745    3.461193    0.544934    0.036124    0.018281    0.653126    
#> 339: 0.493823    1.057830    3.461183    0.544906    0.036133    0.018269    0.653032    
#> 340: 0.493682    1.057753    3.461193    0.544747    0.036148    0.018273    0.653143    
#> 341: 0.493779    1.057695    3.461238    0.544719    0.036147    0.018278    0.653183    
#> 342: 0.493403    1.057606    3.461198    0.544618    0.036136    0.018283    0.653140    
#> 343: 0.493110    1.057674    3.461168    0.544276    0.036168    0.018268    0.653102    
#> 344: 0.492955    1.057788    3.461115    0.543573    0.036201    0.018280    0.653187    
#> 345: 0.492818    1.057901    3.461067    0.543395    0.036217    0.018288    0.653100    
#> 346: 0.492710    1.057984    3.460981    0.543432    0.036248    0.018282    0.652937    
#> 347: 0.492905    1.057967    3.460836    0.545010    0.036252    0.018295    0.652883    
#> 348: 0.492754    1.058127    3.460771    0.545189    0.036261    0.018306    0.652908    
#> 349: 0.492563    1.058148    3.460715    0.545435    0.036269    0.018313    0.652920    
#> 350: 0.492426    1.058198    3.460651    0.545781    0.036296    0.018301    0.652920    
#> 351: 0.492418    1.058427    3.460585    0.545897    0.036324    0.018285    0.652925    
#> 352: 0.492121    1.058523    3.460516    0.546302    0.036325    0.018302    0.652992    
#> 353: 0.492193    1.058641    3.460521    0.546337    0.036362    0.018312    0.652895    
#> 354: 0.492417    1.058627    3.460479    0.546415    0.036364    0.018330    0.652731    
#> 355: 0.492646    1.058551    3.460423    0.546809    0.036354    0.018365    0.652651    
#> 356: 0.492744    1.058470    3.460390    0.547488    0.036299    0.018383    0.652753    
#> 357: 0.492862    1.058516    3.460427    0.547750    0.036245    0.018376    0.652654    
#> 358: 0.492818    1.058558    3.460417    0.548002    0.036238    0.018379    0.652484    
#> 359: 0.492712    1.058702    3.460342    0.547945    0.036255    0.018399    0.652402    
#> 360: 0.492732    1.058734    3.460303    0.548366    0.036212    0.018411    0.652333    
#> 361: 0.492627    1.058903    3.460222    0.548255    0.036249    0.018418    0.652151    
#> 362: 0.492792    1.058934    3.460185    0.548039    0.036261    0.018423    0.652038    
#> 363: 0.492832    1.058835    3.460206    0.548363    0.036207    0.018430    0.651946    
#> 364: 0.492997    1.058881    3.460227    0.548769    0.036171    0.018437    0.651979    
#> 365: 0.493020    1.058858    3.460251    0.548695    0.036181    0.018431    0.652072    
#> 366: 0.493116    1.058844    3.460189    0.548519    0.036162    0.018423    0.652209    
#> 367: 0.493268    1.058791    3.460230    0.548350    0.036147    0.018406    0.652240    
#> 368: 0.493460    1.058905    3.460220    0.548423    0.036158    0.018391    0.652215    
#> 369: 0.493387    1.058959    3.460219    0.547984    0.036143    0.018387    0.652236    
#> 370: 0.493301    1.059012    3.460274    0.547311    0.036189    0.018380    0.652202    
#> 371: 0.493101    1.059119    3.460210    0.547041    0.036192    0.018358    0.652191    
#> 372: 0.492655    1.059274    3.460093    0.547314    0.036181    0.018340    0.652172    
#> 373: 0.492215    1.059516    3.459908    0.547865    0.036229    0.018330    0.652101    
#> 374: 0.492109    1.059626    3.459833    0.548248    0.036254    0.018317    0.652055    
#> 375: 0.492056    1.059686    3.459786    0.548642    0.036333    0.018304    0.651984    
#> 376: 0.491928    1.059841    3.459701    0.549411    0.036391    0.018287    0.651914    
#> 377: 0.491947    1.059940    3.459648    0.549905    0.036426    0.018302    0.651918    
#> 378: 0.491773    1.059944    3.459574    0.549896    0.036404    0.018332    0.651968    
#> 379: 0.491596    1.059816    3.459582    0.549867    0.036407    0.018339    0.651931    
#> 380: 0.491648    1.059691    3.459591    0.550074    0.036377    0.018327    0.651968    
#> 381: 0.491355    1.059606    3.459593    0.549814    0.036341    0.018336    0.651994    
#> 382: 0.491306    1.059621    3.459570    0.550044    0.036288    0.018333    0.651973    
#> 383: 0.491223    1.059617    3.459560    0.549930    0.036256    0.018349    0.651890    
#> 384: 0.491115    1.059627    3.459552    0.549766    0.036225    0.018347    0.651849    
#> 385: 0.491399    1.059670    3.459598    0.550250    0.036215    0.018359    0.651827    
#> 386: 0.491877    1.059800    3.459722    0.550599    0.036256    0.018383    0.651890    
#> 387: 0.492221    1.059841    3.459849    0.550639    0.036280    0.018391    0.651913    
#> 388: 0.492358    1.059847    3.459935    0.550575    0.036306    0.018386    0.651897    
#> 389: 0.492536    1.059619    3.459972    0.550715    0.036322    0.018393    0.651952    
#> 390: 0.492703    1.059456    3.460009    0.550800    0.036284    0.018406    0.651897    
#> 391: 0.492981    1.059320    3.460056    0.550553    0.036247    0.018397    0.651900    
#> 392: 0.493091    1.059289    3.460135    0.550878    0.036218    0.018399    0.651837    
#> 393: 0.493097    1.059283    3.460139    0.550893    0.036195    0.018396    0.651795    
#> 394: 0.493065    1.059341    3.460092    0.550891    0.036180    0.018380    0.651733    
#> 395: 0.493117    1.059499    3.460054    0.550900    0.036178    0.018391    0.651737    
#> 396: 0.493021    1.059606    3.459993    0.550698    0.036186    0.018400    0.651703    
#> 397: 0.492881    1.059659    3.459945    0.550689    0.036175    0.018400    0.651717    
#> 398: 0.492943    1.059649    3.459958    0.550660    0.036140    0.018395    0.651751    
#> 399: 0.493015    1.059683    3.460012    0.550808    0.036143    0.018399    0.651731    
#> 400: 0.492976    1.059724    3.460016    0.550719    0.036172    0.018389    0.651740    
#> 401: 0.492938    1.059795    3.459979    0.550549    0.036221    0.018375    0.651804    
#> 402: 0.493020    1.059925    3.459976    0.550303    0.036224    0.018377    0.651783    
#> 403: 0.493166    1.059953    3.459982    0.549896    0.036227    0.018381    0.651791    
#> 404: 0.493082    1.060067    3.459869    0.549805    0.036244    0.018383    0.651780    
#> 405: 0.492844    1.060141    3.459810    0.549961    0.036290    0.018376    0.651766    
#> 406: 0.493055    1.060143    3.459805    0.550326    0.036351    0.018376    0.651746    
#> 407: 0.493245    1.060203    3.459894    0.550348    0.036375    0.018364    0.651800    
#> 408: 0.493499    1.060217    3.459938    0.550307    0.036362    0.018369    0.651831    
#> 409: 0.493618    1.060163    3.459951    0.550325    0.036360    0.018366    0.651776    
#> 410: 0.493455    1.060194    3.459851    0.550345    0.036382    0.018384    0.651685    
#> 411: 0.493281    1.060098    3.459783    0.550399    0.036373    0.018387    0.651710    
#> 412: 0.493237    1.060125    3.459784    0.550696    0.036348    0.018407    0.651689    
#> 413: 0.493069    1.060142    3.459717    0.550822    0.036316    0.018418    0.651684    
#> 414: 0.492854    1.060112    3.459683    0.550591    0.036277    0.018424    0.651711    
#> 415: 0.492842    1.060122    3.459642    0.550439    0.036234    0.018437    0.651707    
#> 416: 0.492949    1.060114    3.459673    0.550398    0.036229    0.018430    0.651646    
#> 417: 0.492996    1.060083    3.459694    0.550677    0.036209    0.018431    0.651565    
#> 418: 0.492963    1.060074    3.459736    0.550776    0.036179    0.018433    0.651540    
#> 419: 0.493073    1.060166    3.459763    0.551090    0.036188    0.018434    0.651480    
#> 420: 0.493195    1.060181    3.459786    0.550999    0.036162    0.018429    0.651439    
#> 421: 0.493101    1.060183    3.459799    0.550992    0.036149    0.018419    0.651415    
#> 422: 0.493197    1.060145    3.459820    0.551032    0.036156    0.018428    0.651460    
#> 423: 0.493369    1.060107    3.459897    0.550902    0.036152    0.018441    0.651453    
#> 424: 0.493295    1.060100    3.459842    0.550928    0.036165    0.018441    0.651437    
#> 425: 0.493242    1.060209    3.459765    0.551063    0.036232    0.018436    0.651470    
#> 426: 0.493215    1.060330    3.459711    0.551200    0.036286    0.018421    0.651458    
#> 427: 0.492941    1.060382    3.459697    0.551179    0.036292    0.018418    0.651405    
#> 428: 0.492891    1.060414    3.459769    0.551052    0.036286    0.018419    0.651414    
#> 429: 0.492950    1.060449    3.459817    0.550849    0.036268    0.018417    0.651393    
#> 430: 0.492849    1.060422    3.459871    0.550622    0.036268    0.018437    0.651412    
#> 431: 0.492782    1.060374    3.459874    0.550536    0.036263    0.018448    0.651344    
#> 432: 0.492649    1.060374    3.459852    0.550317    0.036252    0.018463    0.651310    
#> 433: 0.492588    1.060431    3.459809    0.550166    0.036277    0.018456    0.651359    
#> 434: 0.492442    1.060388    3.459782    0.549851    0.036249    0.018478    0.651350    
#> 435: 0.492359    1.060414    3.459763    0.549643    0.036227    0.018485    0.651359    
#> 436: 0.492306    1.060384    3.459810    0.549422    0.036198    0.018496    0.651375    
#> 437: 0.492228    1.060398    3.459802    0.549183    0.036172    0.018525    0.651352    
#> 438: 0.492185    1.060536    3.459769    0.549010    0.036158    0.018518    0.651408    
#> 439: 0.492170    1.060611    3.459775    0.548849    0.036172    0.018512    0.651422    
#> 440: 0.492250    1.060602    3.459786    0.548837    0.036159    0.018518    0.651381    
#> 441: 0.492251    1.060494    3.459832    0.548700    0.036144    0.018522    0.651352    
#> 442: 0.492213    1.060462    3.459840    0.548396    0.036120    0.018535    0.651323    
#> 443: 0.492192    1.060437    3.459787    0.548088    0.036111    0.018543    0.651333    
#> 444: 0.491942    1.060475    3.459670    0.548253    0.036098    0.018551    0.651250    
#> 445: 0.491682    1.060555    3.459562    0.548276    0.036124    0.018566    0.651308    
#> 446: 0.491556    1.060639    3.459507    0.548109    0.036137    0.018570    0.651281    
#> 447: 0.491676    1.060718    3.459496    0.548334    0.036150    0.018578    0.651284    
#> 448: 0.491584    1.060721    3.459486    0.548393    0.036128    0.018572    0.651261    
#> 449: 0.491724    1.060807    3.459558    0.548400    0.036149    0.018567    0.651286    
#> 450: 0.491676    1.060808    3.459571    0.548035    0.036149    0.018552    0.651344    
#> 451: 0.491840    1.060829    3.459617    0.547934    0.036149    0.018561    0.651373    
#> 452: 0.491914    1.060817    3.459634    0.547716    0.036129    0.018548    0.651433    
#> 453: 0.491891    1.060835    3.459636    0.547657    0.036109    0.018541    0.651451    
#> 454: 0.491841    1.060898    3.459618    0.547652    0.036109    0.018534    0.651445    
#> 455: 0.491787    1.060899    3.459620    0.547552    0.036107    0.018553    0.651498    
#> 456: 0.491812    1.060825    3.459686    0.547223    0.036125    0.018561    0.651526    
#> 457: 0.491789    1.060768    3.459742    0.546989    0.036117    0.018567    0.651492    
#> 458: 0.491742    1.060828    3.459758    0.546747    0.036100    0.018571    0.651477    
#> 459: 0.491496    1.060911    3.459755    0.546606    0.036080    0.018585    0.651451    
#> 460: 0.491371    1.060915    3.459714    0.546490    0.036079    0.018600    0.651429    
#> 461: 0.491290    1.060957    3.459721    0.546266    0.036083    0.018609    0.651414    
#> 462: 0.491128    1.060948    3.459735    0.546313    0.036079    0.018620    0.651370    
#> 463: 0.491046    1.060956    3.459747    0.546291    0.036080    0.018629    0.651336    
#> 464: 0.491082    1.061007    3.459719    0.546072    0.036083    0.018631    0.651248    
#> 465: 0.491071    1.060948    3.459717    0.545874    0.036071    0.018623    0.651180    
#> 466: 0.491058    1.060927    3.459703    0.545710    0.036044    0.018616    0.651183    
#> 467: 0.491005    1.060936    3.459700    0.545590    0.036028    0.018616    0.651085    
#> 468: 0.491127    1.060960    3.459726    0.545611    0.036008    0.018621    0.651060    
#> 469: 0.491144    1.061073    3.459763    0.545362    0.036011    0.018634    0.651116    
#> 470: 0.491199    1.061151    3.459735    0.545618    0.036030    0.018647    0.651146    
#> 471: 0.491127    1.061191    3.459708    0.545646    0.036036    0.018648    0.651137    
#> 472: 0.491230    1.061184    3.459700    0.545990    0.036037    0.018655    0.651105    
#> 473: 0.491285    1.061200    3.459718    0.546158    0.035997    0.018671    0.651065    
#> 474: 0.491315    1.061169    3.459736    0.546344    0.035989    0.018670    0.651052    
#> 475: 0.491468    1.061147    3.459775    0.546565    0.035974    0.018679    0.651000    
#> 476: 0.491448    1.061077    3.459777    0.546683    0.036010    0.018677    0.651078    
#> 477: 0.491494    1.061023    3.459828    0.546834    0.036039    0.018672    0.651035    
#> 478: 0.491398    1.060984    3.459820    0.547073    0.036058    0.018655    0.651098    
#> 479: 0.491419    1.061037    3.459819    0.547106    0.036100    0.018651    0.651123    
#> 480: 0.491390    1.061047    3.459768    0.547333    0.036121    0.018659    0.651137    
#> 481: 0.491308    1.061064    3.459721    0.547732    0.036138    0.018660    0.651137    
#> 482: 0.491170    1.061111    3.459647    0.547924    0.036147    0.018659    0.651169    
#> 483: 0.490971    1.061153    3.459620    0.547835    0.036139    0.018663    0.651169    
#> 484: 0.490954    1.061109    3.459596    0.547975    0.036105    0.018662    0.651191    
#> 485: 0.490872    1.061145    3.459585    0.547768    0.036104    0.018666    0.651198    
#> 486: 0.490971    1.061245    3.459597    0.547936    0.036103    0.018667    0.651201    
#> 487: 0.491142    1.061250    3.459646    0.548337    0.036073    0.018674    0.651159    
#> 488: 0.491032    1.061269    3.459659    0.548340    0.036071    0.018686    0.651096    
#> 489: 0.491149    1.061244    3.459631    0.548703    0.036069    0.018705    0.651081    
#> 490: 0.491240    1.061311    3.459617    0.549003    0.036080    0.018711    0.651041    
#> 491: 0.491322    1.061396    3.459639    0.549175    0.036094    0.018729    0.651021    
#> 492: 0.491155    1.061515    3.459594    0.549127    0.036107    0.018728    0.651063    
#> 493: 0.491030    1.061563    3.459588    0.548819    0.036124    0.018731    0.651095    
#> 494: 0.491080    1.061535    3.459595    0.548496    0.036140    0.018726    0.651089    
#> 495: 0.491169    1.061555    3.459604    0.548355    0.036146    0.018717    0.651107    
#> 496: 0.491202    1.061608    3.459598    0.548296    0.036176    0.018709    0.651089    
#> 497: 0.491217    1.061596    3.459617    0.548516    0.036182    0.018703    0.651087    
#> 498: 0.491377    1.061499    3.459630    0.548866    0.036203    0.018694    0.651030    
#> 499: 0.491498    1.061517    3.459642    0.549088    0.036175    0.018690    0.651036    
#> 500: 0.491713    1.061504    3.459627    0.549318    0.036158    0.018686    0.651085    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.320266    0.970352    3.449136    0.392401    0.075158    0.016800    1.547641    
#> 002: 0.402639    1.060142    3.475945    0.372781    0.071400    0.015960    1.076112    
#> 003: 0.486522    1.041325    3.483067    0.354142    0.067830    0.017701    0.886507    
#> 004: 0.476549    1.039482    3.485691    0.336435    0.064438    0.016816    0.856643    
#> 005: 0.528467    1.090671    3.480091    0.319613    0.062768    0.016034    0.794869    
#> 006: 0.492523    1.093601    3.464082    0.303633    0.061372    0.015360    0.767558    
#> 007: 0.438791    1.116529    3.445721    0.359099    0.060552    0.018316    0.766367    
#> 008: 0.395080    1.109759    3.433351    0.347022    0.057524    0.020376    0.786319    
#> 009: 0.424893    1.103159    3.439845    0.329671    0.054648    0.022182    0.782060    
#> 010: 0.470440    1.085377    3.446279    0.347211    0.051916    0.024938    0.776711    
#> 011: 0.509607    1.100842    3.455278    0.340098    0.049320    0.031282    0.800092    
#> 012: 0.540784    1.074444    3.465799    0.376578    0.046854    0.029718    0.773591    
#> 013: 0.493395    1.089354    3.456714    0.357749    0.044511    0.031086    0.757665    
#> 014: 0.514674    1.098530    3.470680    0.339861    0.042286    0.030384    0.771171    
#> 015: 0.513662    1.100331    3.477872    0.322868    0.040171    0.028865    0.755522    
#> 016: 0.479607    1.108995    3.478082    0.367512    0.038163    0.027422    0.755679    
#> 017: 0.513992    1.110561    3.464504    0.440483    0.036255    0.026051    0.732075    
#> 018: 0.500888    1.112688    3.447021    0.418459    0.034442    0.024748    0.755499    
#> 019: 0.490429    1.118319    3.445540    0.406271    0.035255    0.025306    0.734625    
#> 020: 0.482310    1.097477    3.452302    0.397265    0.033492    0.029349    0.763988    
#> 021: 0.484718    1.084139    3.464946    0.415294    0.031817    0.031769    0.753678    
#> 022: 0.481812    1.085726    3.474458    0.394530    0.031678    0.030181    0.754441    
#> 023: 0.622517    1.087220    3.499236    0.447304    0.033679    0.028672    0.757013    
#> 024: 0.606498    1.089992    3.488649    0.513622    0.031995    0.027238    0.746330    
#> 025: 0.562973    1.060979    3.486433    0.577537    0.030396    0.027451    0.751720    
#> 026: 0.567868    1.082336    3.478250    0.548660    0.028876    0.034017    0.752201    
#> 027: 0.526414    1.094219    3.468752    0.521227    0.027432    0.034583    0.776083    
#> 028: 0.606258    1.090985    3.483278    0.495165    0.026060    0.036127    0.754580    
#> 029: 0.616201    1.090307    3.485235    0.502635    0.027147    0.035613    0.774416    
#> 030: 0.657125    1.109866    3.488178    0.531572    0.025789    0.041040    0.779024    
#> 031: 0.598518    1.069092    3.503247    0.581272    0.029251    0.038988    0.739819    
#> 032: 0.530813    1.075261    3.490516    0.552208    0.027789    0.037039    0.743635    
#> 033: 0.520754    1.082280    3.479198    0.524598    0.026399    0.035187    0.748338    
#> 034: 0.545473    1.073604    3.491442    0.498368    0.025079    0.034490    0.740850    
#> 035: 0.550532    1.060333    3.484713    0.473450    0.023825    0.036258    0.729277    
#> 036: 0.568061    1.072958    3.484563    0.449777    0.022634    0.034445    0.730671    
#> 037: 0.522827    1.079801    3.482530    0.427288    0.026438    0.032723    0.745254    
#> 038: 0.514141    1.083670    3.473964    0.437439    0.030511    0.033382    0.742502    
#> 039: 0.530505    1.086663    3.472386    0.415567    0.030708    0.031713    0.741495    
#> 040: 0.517322    1.081435    3.472202    0.466597    0.029172    0.030127    0.770382    
#> 041: 0.489235    1.092576    3.449510    0.578526    0.027714    0.033534    0.733716    
#> 042: 0.539002    1.091101    3.463077    0.573398    0.026328    0.031857    0.747957    
#> 043: 0.456554    1.104918    3.439112    0.544728    0.025012    0.030270    0.773839    
#> 044: 0.471522    1.111067    3.455267    0.517492    0.023761    0.030116    0.761911    
#> 045: 0.512929    1.108881    3.454424    0.540007    0.022573    0.028610    0.764471    
#> 046: 0.557832    1.102815    3.461014    0.513007    0.023153    0.029479    0.763125    
#> 047: 0.534493    1.118688    3.446070    0.506547    0.023809    0.038037    0.750112    
#> 048: 0.515709    1.099892    3.458453    0.481219    0.028347    0.039444    0.754681    
#> 049: 0.469983    1.092111    3.454169    0.457158    0.035750    0.037472    0.759434    
#> 050: 0.538639    1.067060    3.474964    0.573222    0.033963    0.035598    0.792577    
#> 051: 0.499941    1.089212    3.457550    0.544561    0.032265    0.033818    0.763498    
#> 052: 0.553705    1.097982    3.466846    0.517333    0.030651    0.032128    0.731916    
#> 053: 0.503969    1.096698    3.463508    0.491466    0.033349    0.030521    0.741132    
#> 054: 0.492744    1.107890    3.466493    0.466893    0.032323    0.030799    0.748825    
#> 055: 0.467423    1.110219    3.453996    0.443548    0.030707    0.029259    0.760654    
#> 056: 0.481318    1.110067    3.456543    0.421371    0.030182    0.027796    0.777757    
#> 057: 0.505743    1.097191    3.469569    0.404409    0.028673    0.036576    0.764811    
#> 058: 0.496169    1.103723    3.456104    0.395589    0.027239    0.038028    0.748460    
#> 059: 0.482187    1.086581    3.462895    0.430220    0.027542    0.046753    0.741729    
#> 060: 0.495241    1.067900    3.465705    0.408709    0.032865    0.044416    0.751468    
#> 061: 0.551455    1.066462    3.494670    0.397417    0.031222    0.042195    0.770831    
#> 062: 0.467076    1.090579    3.480593    0.453032    0.030631    0.040085    0.754147    
#> 063: 0.544325    1.073160    3.476723    0.431089    0.032372    0.038081    0.765331    
#> 064: 0.522969    1.076639    3.480795    0.419694    0.030753    0.036177    0.749664    
#> 065: 0.550679    1.083572    3.461086    0.439877    0.029215    0.034368    0.760708    
#> 066: 0.543662    1.085326    3.472512    0.424922    0.027755    0.032650    0.749898    
#> 067: 0.514531    1.092796    3.458141    0.459999    0.026367    0.031017    0.744024    
#> 068: 0.493242    1.103767    3.463860    0.441266    0.026638    0.029466    0.751709    
#> 069: 0.475605    1.113500    3.448735    0.419203    0.025306    0.029030    0.770061    
#> 070: 0.444610    1.123625    3.457037    0.398242    0.029947    0.032699    0.760289    
#> 071: 0.498247    1.129588    3.452942    0.380231    0.028450    0.031064    0.762286    
#> 072: 0.480966    1.111990    3.451064    0.370877    0.027027    0.030387    0.733379    
#> 073: 0.535925    1.117456    3.460655    0.544368    0.025676    0.033321    0.729291    
#> 074: 0.479867    1.118613    3.452286    0.517150    0.032014    0.035564    0.734428    
#> 075: 0.505681    1.125010    3.461461    0.491293    0.035925    0.034679    0.757812    
#> 076: 0.501112    1.114017    3.469323    0.466728    0.034129    0.036860    0.768926    
#> 077: 0.541647    1.098376    3.468558    0.443392    0.032423    0.036410    0.752085    
#> 078: 0.510113    1.101696    3.478561    0.421222    0.030801    0.036512    0.749599    
#> 079: 0.571859    1.104445    3.471777    0.444436    0.029261    0.039551    0.757268    
#> 080: 0.560905    1.091049    3.479693    0.469520    0.032498    0.039231    0.772905    
#> 081: 0.550252    1.079884    3.474855    0.503616    0.030873    0.046482    0.751662    
#> 082: 0.544314    1.067660    3.482550    0.502117    0.029329    0.050288    0.775119    
#> 083: 0.578292    1.069575    3.473865    0.543811    0.027863    0.047773    0.777238    
#> 084: 0.511640    1.084017    3.466850    0.516621    0.026470    0.045385    0.768361    
#> 085: 0.520521    1.072386    3.487808    0.490790    0.025146    0.043115    0.756179    
#> 086: 0.519155    1.068882    3.474290    0.466250    0.023889    0.040960    0.756101    
#> 087: 0.513461    1.072641    3.473958    0.442938    0.023253    0.038912    0.751738    
#> 088: 0.504632    1.077462    3.479320    0.420791    0.025636    0.036966    0.758987    
#> 089: 0.482636    1.091365    3.460037    0.399751    0.026491    0.039436    0.750226    
#> 090: 0.487013    1.088140    3.463509    0.381470    0.031606    0.037464    0.734613    
#> 091: 0.506830    1.069898    3.465602    0.362397    0.033414    0.035591    0.753656    
#> 092: 0.533339    1.081832    3.474932    0.363685    0.034024    0.033812    0.749270    
#> 093: 0.503009    1.085839    3.471599    0.345853    0.032416    0.032121    0.750834    
#> 094: 0.478171    1.094853    3.461518    0.337771    0.036778    0.031252    0.754710    
#> 095: 0.495819    1.100174    3.467487    0.422724    0.035179    0.031107    0.767105    
#> 096: 0.480967    1.111697    3.452327    0.480512    0.041179    0.030502    0.746167    
#> 097: 0.491395    1.129864    3.451893    0.487029    0.039120    0.029063    0.735548    
#> 098: 0.516064    1.143472    3.454059    0.462677    0.037164    0.031245    0.743852    
#> 099: 0.484036    1.123873    3.435760    0.439544    0.040809    0.029683    0.729121    
#> 100: 0.467219    1.132322    3.440144    0.430942    0.044307    0.028199    0.722380    
#> 101: 0.417530    1.122561    3.421281    0.444816    0.042092    0.026789    0.733139    
#> 102: 0.417750    1.125567    3.417177    0.428397    0.039987    0.025449    0.746553    
#> 103: 0.426112    1.130447    3.428966    0.406977    0.037988    0.024195    0.727085    
#> 104: 0.452173    1.129986    3.450149    0.426396    0.040330    0.028824    0.739133    
#> 105: 0.537378    1.101521    3.469918    0.471674    0.049496    0.030238    0.734145    
#> 106: 0.548117    1.107031    3.465308    0.448090    0.048977    0.028726    0.745722    
#> 107: 0.543775    1.124536    3.453844    0.536599    0.046734    0.027289    0.743626    
#> 108: 0.500297    1.128063    3.454259    0.536606    0.044398    0.025925    0.757175    
#> 109: 0.515359    1.110870    3.478231    0.509776    0.042178    0.024629    0.775667    
#> 110: 0.557648    1.090189    3.464386    0.484287    0.040069    0.023397    0.776977    
#> 111: 0.535241    1.108350    3.473234    0.460072    0.038066    0.023448    0.754234    
#> 112: 0.482122    1.085057    3.455917    0.437069    0.036162    0.022552    0.760854    
#> 113: 0.461617    1.114936    3.456916    0.415215    0.034354    0.023064    0.741853    
#> 114: 0.523619    1.106399    3.459453    0.454216    0.032636    0.023271    0.754503    
#> 115: 0.552568    1.079095    3.453055    0.538477    0.031005    0.024984    0.776537    
#> 116: 0.548651    1.085762    3.467280    0.511553    0.032607    0.027869    0.753670    
#> 117: 0.484284    1.114333    3.464691    0.485976    0.030977    0.030212    0.743204    
#> 118: 0.521696    1.116242    3.467005    0.461677    0.029428    0.028701    0.744016    
#> 119: 0.523459    1.100185    3.474548    0.514273    0.027956    0.027266    0.763180    
#> 120: 0.500616    1.094041    3.465495    0.488559    0.026558    0.034103    0.754913    
#> 121: 0.518477    1.104417    3.466990    0.464131    0.033587    0.035494    0.758829    
#> 122: 0.522372    1.095721    3.470640    0.440925    0.044921    0.033719    0.750048    
#> 123: 0.487760    1.125685    3.440125    0.418879    0.042675    0.032033    0.761449    
#> 124: 0.514651    1.136444    3.448281    0.502174    0.040542    0.032252    0.745114    
#> 125: 0.590779    1.117732    3.467483    0.481146    0.038514    0.031567    0.751449    
#> 126: 0.506806    1.110014    3.458331    0.457089    0.036589    0.035651    0.752995    
#> 127: 0.519911    1.104169    3.453302    0.448168    0.034759    0.033869    0.779885    
#> 128: 0.469969    1.095004    3.466992    0.425760    0.033021    0.032304    0.747604    
#> 129: 0.502244    1.107411    3.478731    0.404472    0.031370    0.031034    0.769528    
#> 130: 0.543319    1.123711    3.462937    0.421365    0.029802    0.031718    0.734359    
#> 131: 0.512732    1.100772    3.447759    0.425459    0.029447    0.030132    0.735094    
#> 132: 0.504118    1.106868    3.440462    0.465479    0.028390    0.032680    0.737965    
#> 133: 0.476115    1.106233    3.452509    0.442205    0.026971    0.037496    0.749898    
#> 134: 0.526853    1.072676    3.483462    0.468724    0.026223    0.036841    0.755206    
#> 135: 0.557957    1.067365    3.482952    0.512432    0.029197    0.034999    0.744160    
#> 136: 0.549143    1.071047    3.473866    0.486810    0.030538    0.034370    0.736586    
#> 137: 0.567300    1.062923    3.481326    0.490510    0.031609    0.032651    0.746920    
#> 138: 0.515883    1.071564    3.466675    0.486761    0.033410    0.031019    0.754013    
#> 139: 0.493883    1.096175    3.470885    0.504292    0.031740    0.029468    0.743486    
#> 140: 0.480520    1.115419    3.475060    0.479078    0.032111    0.032741    0.770922    
#> 141: 0.488546    1.102215    3.466126    0.455124    0.032086    0.031104    0.738649    
#> 142: 0.545613    1.078210    3.477775    0.517747    0.031961    0.029549    0.749114    
#> 143: 0.507123    1.085970    3.475208    0.491860    0.030363    0.029416    0.756578    
#> 144: 0.563952    1.085755    3.488325    0.467267    0.028845    0.036760    0.752825    
#> 145: 0.509642    1.095473    3.471339    0.443903    0.027402    0.034922    0.728120    
#> 146: 0.530104    1.094640    3.475159    0.480564    0.026032    0.033176    0.750256    
#> 147: 0.477827    1.095041    3.457228    0.456536    0.024731    0.033391    0.736624    
#> 148: 0.501799    1.111113    3.468828    0.433709    0.023877    0.031721    0.743133    
#> 149: 0.516824    1.085300    3.477041    0.412024    0.026956    0.030135    0.763066    
#> 150: 0.516732    1.073365    3.466677    0.391423    0.031795    0.028629    0.768233    
#> 151: 0.457057    1.105203    3.462566    0.371851    0.030205    0.027197    0.754199    
#> 152: 0.484754    1.102771    3.466403    0.388210    0.019706    0.022543    0.770314    
#> 153: 0.507734    1.118048    3.475595    0.351818    0.021416    0.024846    0.776491    
#> 154: 0.537893    1.128041    3.463313    0.353870    0.021387    0.030254    0.769683    
#> 155: 0.468363    1.101423    3.455935    0.377662    0.020184    0.028580    0.764317    
#> 156: 0.509347    1.110256    3.456060    0.392596    0.022319    0.028819    0.771227    
#> 157: 0.527045    1.100784    3.474972    0.409517    0.033194    0.028915    0.760077    
#> 158: 0.543416    1.104847    3.476990    0.385874    0.032312    0.027438    0.742763    
#> 159: 0.491623    1.114052    3.475613    0.420342    0.038831    0.020011    0.747047    
#> 160: 0.539951    1.081742    3.485334    0.419116    0.043340    0.024013    0.744305    
#> 161: 0.524846    1.090127    3.467469    0.469258    0.039673    0.022743    0.748743    
#> 162: 0.516423    1.106189    3.460197    0.400750    0.039144    0.024329    0.744693    
#> 163: 0.538518    1.096986    3.458177    0.371887    0.052890    0.029119    0.748348    
#> 164: 0.514525    1.099558    3.467790    0.362439    0.038737    0.030017    0.766678    
#> 165: 0.546282    1.083564    3.487146    0.365368    0.036334    0.032861    0.731094    
#> 166: 0.538830    1.115904    3.478245    0.379042    0.038446    0.032214    0.742312    
#> 167: 0.533592    1.143074    3.473750    0.378184    0.036267    0.025084    0.769456    
#> 168: 0.559513    1.144051    3.464554    0.463712    0.040340    0.021947    0.755440    
#> 169: 0.519226    1.155257    3.463043    0.378691    0.038810    0.022192    0.786243    
#> 170: 0.546841    1.120221    3.470125    0.401691    0.039278    0.029028    0.740564    
#> 171: 0.465205    1.104829    3.462927    0.334721    0.032596    0.026341    0.755407    
#> 172: 0.471954    1.119730    3.471143    0.296451    0.038373    0.020838    0.762432    
#> 173: 0.508455    1.112327    3.456592    0.367558    0.041873    0.020908    0.758124    
#> 174: 0.514711    1.107112    3.464985    0.361826    0.032576    0.023673    0.758782    
#> 175: 0.501197    1.117973    3.456534    0.335713    0.031199    0.022024    0.781880    
#> 176: 0.503176    1.129027    3.469384    0.396470    0.030053    0.023848    0.774367    
#> 177: 0.481296    1.131432    3.467358    0.412154    0.026494    0.024225    0.760987    
#> 178: 0.491185    1.106329    3.467834    0.345949    0.029439    0.022179    0.770786    
#> 179: 0.522601    1.111361    3.463534    0.473503    0.027521    0.029162    0.743976    
#> 180: 0.511519    1.095348    3.469383    0.322759    0.019843    0.027074    0.753347    
#> 181: 0.488246    1.080018    3.457112    0.349488    0.016736    0.030452    0.757927    
#> 182: 0.500058    1.080565    3.448104    0.438745    0.015784    0.032126    0.781672    
#> 183: 0.496774    1.086149    3.455344    0.397583    0.018651    0.035927    0.757485    
#> 184: 0.518770    1.068922    3.476411    0.396707    0.025117    0.038801    0.748682    
#> 185: 0.488169    1.096989    3.465670    0.386238    0.028756    0.034774    0.744723    
#> 186: 0.504634    1.128515    3.465063    0.415175    0.030668    0.036007    0.742460    
#> 187: 0.542913    1.093282    3.472293    0.420284    0.035958    0.032164    0.761116    
#> 188: 0.526160    1.116089    3.463330    0.374125    0.042433    0.029966    0.788291    
#> 189: 0.539167    1.132911    3.475553    0.406041    0.039259    0.030726    0.781357    
#> 190: 0.495024    1.136163    3.474153    0.358371    0.030327    0.031756    0.771052    
#> 191: 0.494459    1.134925    3.454125    0.376318    0.024881    0.031630    0.765949    
#> 192: 0.451530    1.133857    3.442418    0.411302    0.022934    0.033486    0.745393    
#> 193: 0.501512    1.128944    3.445869    0.502390    0.017446    0.033526    0.749033    
#> 194: 0.471224    1.115311    3.448405    0.508239    0.021822    0.036844    0.762334    
#> 195: 0.450238    1.104001    3.449629    0.469901    0.017747    0.037664    0.754836    
#> 196: 0.444783    1.103048    3.458081    0.394048    0.020244    0.031675    0.761139    
#> 197: 0.425648    1.103794    3.467034    0.333561    0.019423    0.033043    0.767038    
#> 198: 0.515111    1.091197    3.470215    0.380966    0.017057    0.033416    0.747226    
#> 199: 0.511967    1.089673    3.465385    0.382118    0.016500    0.029086    0.753522    
#> 200: 0.538631    1.085178    3.466707    0.494964    0.026709    0.034446    0.743267    
#> 201: 0.546147    1.081495    3.474369    0.530155    0.025964    0.036374    0.738381    
#> 202: 0.550404    1.079987    3.475920    0.539227    0.024246    0.036052    0.736045    
#> 203: 0.560452    1.079799    3.472714    0.559809    0.022633    0.034960    0.738585    
#> 204: 0.560309    1.079213    3.472164    0.569717    0.022685    0.034899    0.738304    
#> 205: 0.558139    1.083696    3.471140    0.573503    0.022270    0.033817    0.742047    
#> 206: 0.548814    1.087405    3.470468    0.575265    0.022638    0.033010    0.743132    
#> 207: 0.540804    1.089679    3.467630    0.567531    0.024336    0.031792    0.742442    
#> 208: 0.537935    1.090797    3.466402    0.557552    0.024744    0.031115    0.742616    
#> 209: 0.541636    1.090726    3.465816    0.556418    0.025119    0.030859    0.743624    
#> 210: 0.544630    1.090442    3.466854    0.556170    0.025246    0.030718    0.742286    
#> 211: 0.546304    1.091142    3.467980    0.549576    0.026189    0.030459    0.741469    
#> 212: 0.547591    1.091694    3.469066    0.534529    0.026345    0.030725    0.742373    
#> 213: 0.548893    1.089457    3.469579    0.522229    0.026730    0.030739    0.743236    
#> 214: 0.549037    1.088353    3.470096    0.516634    0.026821    0.030972    0.743370    
#> 215: 0.550505    1.087724    3.471513    0.508711    0.026664    0.031305    0.744231    
#> 216: 0.553487    1.086011    3.472830    0.506398    0.027198    0.031633    0.745728    
#> 217: 0.553969    1.085144    3.473504    0.502654    0.027418    0.031876    0.745240    
#> 218: 0.552515    1.085156    3.473351    0.502563    0.027807    0.031914    0.744730    
#> 219: 0.551890    1.084584    3.472576    0.502174    0.027762    0.031683    0.744698    
#> 220: 0.549566    1.084919    3.471983    0.505534    0.027396    0.031695    0.745055    
#> 221: 0.548810    1.084910    3.471651    0.506171    0.027371    0.031619    0.744321    
#> 222: 0.548099    1.084788    3.471085    0.503759    0.027376    0.031775    0.744129    
#> 223: 0.547781    1.084796    3.470770    0.502122    0.027292    0.031803    0.743981    
#> 224: 0.548311    1.085688    3.470597    0.500297    0.027162    0.031632    0.743491    
#> 225: 0.547171    1.085062    3.471094    0.497733    0.026902    0.031548    0.743581    
#> 226: 0.545665    1.084894    3.470731    0.495116    0.026767    0.031334    0.743819    
#> 227: 0.543584    1.084866    3.470531    0.492287    0.026704    0.031410    0.743089    
#> 228: 0.542493    1.085902    3.469970    0.490142    0.026766    0.031367    0.742778    
#> 229: 0.539429    1.086375    3.469244    0.486580    0.026747    0.031316    0.742516    
#> 230: 0.539199    1.086828    3.469087    0.485693    0.026791    0.031110    0.742782    
#> 231: 0.538392    1.087180    3.468959    0.483963    0.026802    0.030944    0.742856    
#> 232: 0.536794    1.087453    3.469178    0.481436    0.026845    0.030828    0.743144    
#> 233: 0.536055    1.087028    3.469560    0.481062    0.027115    0.030947    0.743471    
#> 234: 0.536204    1.087281    3.469902    0.480625    0.027386    0.031024    0.743403    
#> 235: 0.535663    1.086846    3.469688    0.478529    0.027447    0.030928    0.743846    
#> 236: 0.535185    1.087513    3.469503    0.476934    0.027526    0.030894    0.744102    
#> 237: 0.535897    1.087161    3.469849    0.476403    0.027528    0.030745    0.745010    
#> 238: 0.537977    1.087252    3.470358    0.477906    0.027610    0.030642    0.745531    
#> 239: 0.538033    1.087497    3.470692    0.477114    0.027910    0.030618    0.745229    
#> 240: 0.537707    1.087517    3.470824    0.477138    0.028096    0.030466    0.745231    
#> 241: 0.538433    1.087177    3.470957    0.478654    0.028346    0.030311    0.745507    
#> 242: 0.537557    1.087193    3.470503    0.477733    0.028861    0.030251    0.745983    
#> 243: 0.536498    1.087538    3.470571    0.475952    0.029351    0.030199    0.746729    
#> 244: 0.536165    1.087296    3.470704    0.476023    0.029373    0.030302    0.747181    
#> 245: 0.536055    1.087293    3.470709    0.475312    0.029426    0.030366    0.747477    
#> 246: 0.535975    1.087127    3.470771    0.475460    0.029255    0.030391    0.747723    
#> 247: 0.535689    1.086746    3.471121    0.474503    0.029287    0.030386    0.747981    
#> 248: 0.534793    1.087279    3.470840    0.472552    0.029330    0.030308    0.747914    
#> 249: 0.533919    1.087713    3.470725    0.471035    0.029389    0.030273    0.748086    
#> 250: 0.533729    1.088029    3.470859    0.469291    0.029533    0.030301    0.747850    
#> 251: 0.534162    1.088512    3.471004    0.467992    0.029569    0.030278    0.747806    
#> 252: 0.534364    1.088879    3.471193    0.468029    0.029759    0.030176    0.747639    
#> 253: 0.534043    1.089285    3.471320    0.467549    0.029955    0.030143    0.747751    
#> 254: 0.533776    1.089883    3.471433    0.467552    0.030132    0.029996    0.747763    
#> 255: 0.533466    1.090150    3.471484    0.467573    0.030221    0.029857    0.747860    
#> 256: 0.534064    1.089997    3.471653    0.466449    0.030240    0.029777    0.748011    
#> 257: 0.533909    1.089742    3.471583    0.465522    0.030270    0.029706    0.748021    
#> 258: 0.533287    1.089415    3.471672    0.464183    0.030140    0.029756    0.748018    
#> 259: 0.533040    1.089218    3.471759    0.462999    0.029985    0.029782    0.748511    
#> 260: 0.532496    1.089388    3.471802    0.461318    0.029983    0.029735    0.748417    
#> 261: 0.532339    1.089464    3.471694    0.461137    0.029951    0.029686    0.748281    
#> 262: 0.531958    1.089811    3.471707    0.459837    0.029918    0.029719    0.748437    
#> 263: 0.531680    1.090212    3.471666    0.457952    0.029995    0.029742    0.748336    
#> 264: 0.530765    1.090550    3.471406    0.457141    0.030074    0.029716    0.748514    
#> 265: 0.530390    1.090792    3.471252    0.457839    0.030181    0.029720    0.748512    
#> 266: 0.530418    1.091101    3.470948    0.459153    0.030182    0.029726    0.748421    
#> 267: 0.530246    1.091245    3.470936    0.461762    0.030218    0.029797    0.747993    
#> 268: 0.530120    1.091318    3.470714    0.462064    0.030211    0.029823    0.747831    
#> 269: 0.530433    1.091367    3.470691    0.462671    0.030183    0.029859    0.747530    
#> 270: 0.530329    1.091539    3.470623    0.462681    0.030070    0.029865    0.747366    
#> 271: 0.529934    1.091600    3.470402    0.461917    0.029983    0.029902    0.747329    
#> 272: 0.529372    1.091783    3.470327    0.460460    0.029938    0.029918    0.747940    
#> 273: 0.528747    1.092186    3.470143    0.460879    0.029875    0.029934    0.747879    
#> 274: 0.528618    1.092484    3.470122    0.460741    0.029818    0.029967    0.747658    
#> 275: 0.528055    1.092742    3.469907    0.459938    0.029662    0.029988    0.747576    
#> 276: 0.528165    1.092798    3.470023    0.459999    0.029638    0.030082    0.747502    
#> 277: 0.528022    1.092858    3.470341    0.459710    0.029537    0.030301    0.747362    
#> 278: 0.528146    1.092795    3.470571    0.459266    0.029492    0.030393    0.747342    
#> 279: 0.527921    1.092715    3.470647    0.459110    0.029443    0.030522    0.747511    
#> 280: 0.528268    1.092816    3.470754    0.458942    0.029392    0.030664    0.747250    
#> 281: 0.528106    1.092871    3.470808    0.457337    0.029405    0.030753    0.747127    
#> 282: 0.527829    1.093052    3.470901    0.456328    0.029464    0.030776    0.747127    
#> 283: 0.528287    1.092993    3.471244    0.455472    0.029507    0.030855    0.747250    
#> 284: 0.528348    1.092682    3.471459    0.454457    0.029452    0.030872    0.747306    
#> 285: 0.528438    1.092619    3.471407    0.453313    0.029439    0.030871    0.747386    
#> 286: 0.528367    1.092770    3.471371    0.452640    0.029365    0.030912    0.747600    
#> 287: 0.527836    1.092951    3.471175    0.451599    0.029241    0.030937    0.747995    
#> 288: 0.527664    1.092758    3.471129    0.451287    0.029177    0.030989    0.748010    
#> 289: 0.528115    1.092699    3.471113    0.451888    0.029099    0.031042    0.747948    
#> 290: 0.528312    1.092743    3.471181    0.451960    0.029073    0.031050    0.747934    
#> 291: 0.528202    1.092982    3.471281    0.451288    0.029003    0.031044    0.747775    
#> 292: 0.528156    1.093105    3.471308    0.450816    0.028927    0.031044    0.747506    
#> 293: 0.527819    1.093137    3.471194    0.450366    0.028834    0.031087    0.747292    
#> 294: 0.527546    1.093390    3.470990    0.450171    0.028764    0.031057    0.747453    
#> 295: 0.527451    1.093336    3.470896    0.450361    0.028715    0.031054    0.747252    
#> 296: 0.527756    1.093275    3.471014    0.451214    0.028703    0.031087    0.747290    
#> 297: 0.528254    1.093156    3.471171    0.451344    0.028602    0.031099    0.747485    
#> 298: 0.528660    1.093083    3.471204    0.452158    0.028559    0.031099    0.747440    
#> 299: 0.528572    1.093161    3.471048    0.452605    0.028526    0.031121    0.747223    
#> 300: 0.528535    1.093184    3.471012    0.452683    0.028514    0.031138    0.747107    
#> 301: 0.528427    1.093261    3.470884    0.452771    0.028510    0.031147    0.747105    
#> 302: 0.528443    1.093313    3.470794    0.452250    0.028518    0.031089    0.746949    
#> 303: 0.527906    1.093491    3.470589    0.451448    0.028483    0.031050    0.746910    
#> 304: 0.527852    1.093664    3.470445    0.450868    0.028504    0.031014    0.747103    
#> 305: 0.527284    1.093518    3.470366    0.449836    0.028528    0.030989    0.747375    
#> 306: 0.526401    1.093253    3.470166    0.449692    0.028539    0.030975    0.747717    
#> 307: 0.525813    1.093018    3.469899    0.449668    0.028542    0.030971    0.748041    
#> 308: 0.525110    1.092827    3.469650    0.449910    0.028578    0.030965    0.748393    
#> 309: 0.524892    1.092579    3.469581    0.449951    0.028606    0.030962    0.748774    
#> 310: 0.524798    1.092371    3.469384    0.450321    0.028662    0.031029    0.748942    
#> 311: 0.524506    1.092312    3.469304    0.450196    0.028671    0.031074    0.748908    
#> 312: 0.524396    1.092245    3.469139    0.450182    0.028675    0.031070    0.748902    
#> 313: 0.524277    1.092015    3.469075    0.449914    0.028670    0.031115    0.748854    
#> 314: 0.523828    1.091966    3.468997    0.449378    0.028660    0.031122    0.748916    
#> 315: 0.523289    1.091965    3.468922    0.448895    0.028696    0.031150    0.748962    
#> 316: 0.523283    1.092010    3.468931    0.448346    0.028753    0.031119    0.749038    
#> 317: 0.523087    1.092057    3.468986    0.447957    0.028825    0.031094    0.749248    
#> 318: 0.523579    1.092121    3.469001    0.447876    0.028807    0.031086    0.749128    
#> 319: 0.523467    1.092109    3.469075    0.447977    0.028763    0.031109    0.749279    
#> 320: 0.523248    1.092015    3.469060    0.448019    0.028787    0.031120    0.749476    
#> 321: 0.522671    1.092202    3.468871    0.447365    0.028836    0.031098    0.749593    
#> 322: 0.522578    1.092247    3.468763    0.446957    0.028835    0.031099    0.749679    
#> 323: 0.521836    1.092387    3.468591    0.447045    0.028794    0.031131    0.749705    
#> 324: 0.521599    1.092489    3.468508    0.447599    0.028756    0.031152    0.749713    
#> 325: 0.521236    1.092559    3.468314    0.447708    0.028719    0.031102    0.749734    
#> 326: 0.520807    1.092572    3.468084    0.447622    0.028766    0.031055    0.749626    
#> 327: 0.520637    1.092662    3.468061    0.447377    0.028798    0.031016    0.749531    
#> 328: 0.520499    1.092791    3.468019    0.446558    0.028835    0.030967    0.749539    
#> 329: 0.520448    1.092850    3.468051    0.445785    0.028835    0.030928    0.749466    
#> 330: 0.520189    1.092901    3.468075    0.444870    0.028808    0.030910    0.749435    
#> 331: 0.520330    1.093027    3.468097    0.445004    0.028800    0.030925    0.749384    
#> 332: 0.520198    1.093008    3.468202    0.445181    0.028798    0.030963    0.749402    
#> 333: 0.520208    1.093080    3.468238    0.444930    0.028742    0.030994    0.749352    
#> 334: 0.519945    1.093057    3.468096    0.444989    0.028721    0.030990    0.749390    
#> 335: 0.519620    1.093059    3.467961    0.445420    0.028705    0.031014    0.749435    
#> 336: 0.519177    1.093259    3.467774    0.445792    0.028732    0.031063    0.749442    
#> 337: 0.518960    1.093512    3.467505    0.446695    0.028710    0.031105    0.749586    
#> 338: 0.518835    1.093661    3.467504    0.446517    0.028717    0.031167    0.749517    
#> 339: 0.518347    1.093892    3.467442    0.446299    0.028751    0.031217    0.749405    
#> 340: 0.518103    1.093911    3.467392    0.445926    0.028775    0.031259    0.749257    
#> 341: 0.517952    1.094020    3.467401    0.445464    0.028805    0.031284    0.749227    
#> 342: 0.517720    1.093981    3.467417    0.445145    0.028806    0.031299    0.749211    
#> 343: 0.517498    1.094126    3.467449    0.444349    0.028850    0.031275    0.749232    
#> 344: 0.517615    1.094080    3.467560    0.443608    0.028882    0.031286    0.749274    
#> 345: 0.517650    1.094111    3.467555    0.443229    0.028904    0.031265    0.749267    
#> 346: 0.517558    1.094210    3.467571    0.442781    0.028883    0.031258    0.749306    
#> 347: 0.517872    1.094060    3.467502    0.443984    0.028934    0.031262    0.749409    
#> 348: 0.517717    1.094062    3.467494    0.444402    0.029005    0.031277    0.749391    
#> 349: 0.517669    1.094052    3.467445    0.444650    0.029044    0.031263    0.749400    
#> 350: 0.517346    1.093982    3.467275    0.444909    0.029059    0.031249    0.749355    
#> 351: 0.517325    1.094222    3.467138    0.445558    0.029090    0.031233    0.749343    
#> 352: 0.517118    1.094418    3.467106    0.445851    0.029123    0.031252    0.749398    
#> 353: 0.517551    1.094455    3.467165    0.446124    0.029099    0.031248    0.749503    
#> 354: 0.517790    1.094522    3.467037    0.446872    0.029072    0.031236    0.749495    
#> 355: 0.517990    1.094461    3.466993    0.446647    0.029058    0.031233    0.749575    
#> 356: 0.518151    1.094413    3.467024    0.446533    0.029093    0.031228    0.749608    
#> 357: 0.518319    1.094446    3.467098    0.446327    0.029100    0.031246    0.749493    
#> 358: 0.518183    1.094549    3.467102    0.446331    0.029143    0.031243    0.749356    
#> 359: 0.517865    1.094655    3.466995    0.446046    0.029117    0.031246    0.749251    
#> 360: 0.517568    1.094816    3.466783    0.446013    0.029139    0.031220    0.749115    
#> 361: 0.517259    1.094912    3.466667    0.445432    0.029137    0.031178    0.748968    
#> 362: 0.517040    1.094945    3.466593    0.445095    0.029134    0.031152    0.748777    
#> 363: 0.517026    1.094904    3.466599    0.445103    0.029099    0.031132    0.748650    
#> 364: 0.517290    1.094904    3.466706    0.444849    0.029091    0.031107    0.748746    
#> 365: 0.517233    1.094890    3.466723    0.444572    0.029166    0.031097    0.748870    
#> 366: 0.517282    1.094957    3.466615    0.444225    0.029145    0.031109    0.748945    
#> 367: 0.517394    1.094997    3.466583    0.443975    0.029116    0.031097    0.748934    
#> 368: 0.517485    1.095108    3.466516    0.443549    0.029101    0.031107    0.748843    
#> 369: 0.517557    1.095156    3.466534    0.443145    0.029079    0.031128    0.748861    
#> 370: 0.517224    1.095332    3.466454    0.442780    0.029082    0.031147    0.748852    
#> 371: 0.517069    1.095504    3.466313    0.442702    0.029058    0.031136    0.748826    
#> 372: 0.516746    1.095642    3.466188    0.442966    0.029040    0.031150    0.748793    
#> 373: 0.516315    1.095905    3.466039    0.443023    0.029033    0.031161    0.748793    
#> 374: 0.516225    1.095914    3.466007    0.442703    0.029011    0.031168    0.748806    
#> 375: 0.516126    1.095948    3.465954    0.442285    0.028999    0.031139    0.748877    
#> 376: 0.516274    1.096015    3.465935    0.442716    0.029034    0.031135    0.748758    
#> 377: 0.516275    1.096141    3.465923    0.443186    0.029061    0.031131    0.748814    
#> 378: 0.516077    1.096115    3.465872    0.443471    0.029065    0.031115    0.748884    
#> 379: 0.516030    1.095992    3.465913    0.443194    0.029064    0.031121    0.748915    
#> 380: 0.515986    1.095958    3.465987    0.442874    0.029099    0.031121    0.748835    
#> 381: 0.515916    1.095901    3.465999    0.442409    0.029144    0.031092    0.748789    
#> 382: 0.515876    1.095801    3.465983    0.442464    0.029113    0.031123    0.748697    
#> 383: 0.515633    1.095741    3.465877    0.442438    0.029146    0.031095    0.748556    
#> 384: 0.515342    1.095739    3.465792    0.442511    0.029130    0.031082    0.748564    
#> 385: 0.515380    1.095828    3.465708    0.442974    0.029140    0.031069    0.748635    
#> 386: 0.515660    1.095989    3.465719    0.443617    0.029140    0.031068    0.748767    
#> 387: 0.516026    1.096077    3.465845    0.443757    0.029142    0.031068    0.748793    
#> 388: 0.516177    1.096088    3.465933    0.443540    0.029115    0.031072    0.748839    
#> 389: 0.516262    1.095907    3.466022    0.443380    0.029127    0.031076    0.748921    
#> 390: 0.516122    1.095882    3.466019    0.443385    0.029117    0.031090    0.748997    
#> 391: 0.516109    1.095820    3.466018    0.443244    0.029078    0.031104    0.748997    
#> 392: 0.516091    1.095818    3.466030    0.443593    0.029056    0.031106    0.748948    
#> 393: 0.516087    1.095764    3.465966    0.443652    0.029028    0.031128    0.748896    
#> 394: 0.516081    1.095769    3.465918    0.443646    0.029001    0.031116    0.748885    
#> 395: 0.516111    1.095896    3.465885    0.443813    0.029015    0.031122    0.748842    
#> 396: 0.516060    1.095962    3.465950    0.443820    0.029066    0.031108    0.748746    
#> 397: 0.516143    1.095979    3.466016    0.444256    0.029078    0.031101    0.748733    
#> 398: 0.516311    1.095943    3.466109    0.444609    0.029073    0.031124    0.748667    
#> 399: 0.516406    1.095920    3.466154    0.444664    0.029064    0.031152    0.748684    
#> 400: 0.516362    1.095994    3.466142    0.444468    0.029073    0.031176    0.748665    
#> 401: 0.516389    1.096087    3.466092    0.444427    0.029096    0.031190    0.748680    
#> 402: 0.516487    1.096178    3.466086    0.444325    0.029099    0.031207    0.748566    
#> 403: 0.516593    1.096201    3.466078    0.444204    0.029078    0.031212    0.748543    
#> 404: 0.516528    1.096256    3.466022    0.443984    0.029046    0.031199    0.748473    
#> 405: 0.516679    1.096260    3.466072    0.444133    0.029038    0.031191    0.748460    
#> 406: 0.516763    1.096255    3.466032    0.444395    0.029034    0.031194    0.748506    
#> 407: 0.517023    1.096277    3.466087    0.444709    0.029064    0.031176    0.748452    
#> 408: 0.517531    1.096290    3.466200    0.444841    0.029081    0.031155    0.748484    
#> 409: 0.517649    1.096251    3.466195    0.444852    0.029052    0.031147    0.748408    
#> 410: 0.517616    1.096238    3.466184    0.444933    0.029052    0.031164    0.748315    
#> 411: 0.517621    1.096082    3.466132    0.445340    0.029035    0.031149    0.748369    
#> 412: 0.517632    1.096027    3.466117    0.445448    0.029022    0.031126    0.748383    
#> 413: 0.517368    1.096002    3.466069    0.445345    0.029022    0.031102    0.748420    
#> 414: 0.517204    1.096002    3.466125    0.445286    0.028993    0.031096    0.748364    
#> 415: 0.517341    1.096009    3.466120    0.445073    0.028955    0.031082    0.748304    
#> 416: 0.517377    1.096087    3.466174    0.444978    0.028942    0.031114    0.748252    
#> 417: 0.517474    1.096061    3.466172    0.444837    0.028928    0.031105    0.748197    
#> 418: 0.517172    1.096123    3.466136    0.444690    0.028945    0.031089    0.748142    
#> 419: 0.517122    1.096217    3.466068    0.444850    0.028952    0.031073    0.748120    
#> 420: 0.517102    1.096291    3.466037    0.444775    0.028974    0.031052    0.748074    
#> 421: 0.516879    1.096364    3.466017    0.444805    0.028992    0.031030    0.748049    
#> 422: 0.516888    1.096372    3.465938    0.444970    0.029003    0.031014    0.748025    
#> 423: 0.517028    1.096308    3.465956    0.444656    0.028985    0.031018    0.748080    
#> 424: 0.516937    1.096253    3.465918    0.444564    0.028994    0.031011    0.748025    
#> 425: 0.516920    1.096293    3.465849    0.444671    0.028984    0.031036    0.748033    
#> 426: 0.516833    1.096326    3.465809    0.444535    0.028970    0.031037    0.748032    
#> 427: 0.516700    1.096280    3.465832    0.444168    0.028926    0.031025    0.748034    
#> 428: 0.516579    1.096286    3.465918    0.444194    0.028913    0.031013    0.748064    
#> 429: 0.516625    1.096272    3.465964    0.443998    0.028893    0.030987    0.748172    
#> 430: 0.516538    1.096239    3.466014    0.443503    0.028866    0.030957    0.748344    
#> 431: 0.516441    1.096229    3.466043    0.442935    0.028859    0.030941    0.748381    
#> 432: 0.516331    1.096246    3.466112    0.442346    0.028859    0.030949    0.748428    
#> 433: 0.516413    1.096312    3.466186    0.442084    0.028853    0.030951    0.748423    
#> 434: 0.516430    1.096240    3.466217    0.441956    0.028822    0.030945    0.748477    
#> 435: 0.516466    1.096227    3.466209    0.441786    0.028784    0.030949    0.748437    
#> 436: 0.516447    1.096168    3.466263    0.441526    0.028769    0.030928    0.748488    
#> 437: 0.516503    1.096192    3.466307    0.441396    0.028790    0.030920    0.748433    
#> 438: 0.516471    1.096316    3.466300    0.441337    0.028789    0.030915    0.748376    
#> 439: 0.516466    1.096363    3.466313    0.441282    0.028799    0.030902    0.748252    
#> 440: 0.516470    1.096380    3.466372    0.441111    0.028805    0.030876    0.748178    
#> 441: 0.516419    1.096364    3.466406    0.440948    0.028834    0.030863    0.748114    
#> 442: 0.516309    1.096395    3.466448    0.440723    0.028872    0.030862    0.748059    
#> 443: 0.516372    1.096483    3.466445    0.440512    0.028859    0.030867    0.748084    
#> 444: 0.516390    1.096573    3.466399    0.440769    0.028892    0.030886    0.748024    
#> 445: 0.516250    1.096637    3.466354    0.440912    0.028862    0.030916    0.748050    
#> 446: 0.516111    1.096716    3.466319    0.440836    0.028865    0.030924    0.748054    
#> 447: 0.516176    1.096746    3.466308    0.440763    0.028848    0.030961    0.748014    
#> 448: 0.516198    1.096763    3.466330    0.440899    0.028826    0.030973    0.748008    
#> 449: 0.516385    1.096802    3.466411    0.441177    0.028823    0.030966    0.747955    
#> 450: 0.516404    1.096881    3.466418    0.441199    0.028849    0.030970    0.747907    
#> 451: 0.516504    1.096960    3.466397    0.441510    0.028870    0.030969    0.747880    
#> 452: 0.516363    1.097026    3.466307    0.441940    0.028871    0.030957    0.747911    
#> 453: 0.516294    1.097019    3.466264    0.442144    0.028885    0.030938    0.747856    
#> 454: 0.516197    1.097091    3.466231    0.442196    0.028884    0.030923    0.747854    
#> 455: 0.516117    1.097112    3.466213    0.441973    0.028886    0.030927    0.747893    
#> 456: 0.515927    1.097035    3.466213    0.441792    0.028897    0.030936    0.748008    
#> 457: 0.515915    1.096993    3.466264    0.441597    0.028898    0.030938    0.748002    
#> 458: 0.516013    1.097080    3.466362    0.441284    0.028913    0.030943    0.748038    
#> 459: 0.515884    1.097201    3.466358    0.441087    0.028915    0.030947    0.748022    
#> 460: 0.515731    1.097264    3.466307    0.440806    0.028903    0.030947    0.747988    
#> 461: 0.515757    1.097335    3.466361    0.440608    0.028918    0.030950    0.747958    
#> 462: 0.515687    1.097378    3.466424    0.440440    0.028924    0.030950    0.747929    
#> 463: 0.515604    1.097388    3.466434    0.440147    0.028917    0.030938    0.747966    
#> 464: 0.515612    1.097403    3.466444    0.440117    0.028894    0.030930    0.747985    
#> 465: 0.515587    1.097277    3.466472    0.440021    0.028894    0.030905    0.747991    
#> 466: 0.515597    1.097231    3.466450    0.439965    0.028894    0.030894    0.747922    
#> 467: 0.515491    1.097248    3.466463    0.439784    0.028896    0.030895    0.747825    
#> 468: 0.515678    1.097246    3.466535    0.439818    0.028896    0.030905    0.747846    
#> 469: 0.515893    1.097288    3.466599    0.439980    0.028898    0.030922    0.747914    
#> 470: 0.516016    1.097320    3.466609    0.440284    0.028899    0.030944    0.747862    
#> 471: 0.516018    1.097278    3.466599    0.440226    0.028886    0.030956    0.747851    
#> 472: 0.516005    1.097241    3.466602    0.440118    0.028888    0.030966    0.747848    
#> 473: 0.515947    1.097262    3.466607    0.439985    0.028905    0.030954    0.747799    
#> 474: 0.515982    1.097268    3.466602    0.439842    0.028915    0.030950    0.747837    
#> 475: 0.516106    1.097342    3.466622    0.439738    0.028914    0.030932    0.747841    
#> 476: 0.516226    1.097307    3.466614    0.439827    0.028913    0.030929    0.747896    
#> 477: 0.516240    1.097310    3.466659    0.439842    0.028911    0.030924    0.747868    
#> 478: 0.516272    1.097252    3.466711    0.439881    0.028889    0.030930    0.747890    
#> 479: 0.516503    1.097216    3.466777    0.440100    0.028877    0.030942    0.747917    
#> 480: 0.516595    1.097160    3.466813    0.440202    0.028862    0.030943    0.748014    
#> 481: 0.516628    1.097089    3.466789    0.440436    0.028855    0.030936    0.748010    
#> 482: 0.516557    1.097090    3.466695    0.440683    0.028880    0.030933    0.748064    
#> 483: 0.516584    1.097079    3.466724    0.440698    0.028933    0.030943    0.748081    
#> 484: 0.516538    1.096996    3.466714    0.440912    0.028962    0.030933    0.748064    
#> 485: 0.516501    1.097030    3.466679    0.440789    0.028987    0.030927    0.748125    
#> 486: 0.516385    1.097103    3.466657    0.440860    0.028986    0.030909    0.748141    
#> 487: 0.516459    1.097150    3.466698    0.440872    0.028991    0.030892    0.748181    
#> 488: 0.516451    1.097140    3.466710    0.440727    0.029021    0.030874    0.748174    
#> 489: 0.516637    1.097127    3.466666    0.440723    0.029061    0.030851    0.748182    
#> 490: 0.516707    1.097179    3.466670    0.440606    0.029062    0.030849    0.748175    
#> 491: 0.516764    1.097290    3.466696    0.440560    0.029086    0.030861    0.748128    
#> 492: 0.516734    1.097379    3.466687    0.440873    0.029099    0.030867    0.748167    
#> 493: 0.516734    1.097466    3.466714    0.440760    0.029150    0.030863    0.748206    
#> 494: 0.516881    1.097576    3.466693    0.440510    0.029198    0.030850    0.748196    
#> 495: 0.516978    1.097606    3.466718    0.440515    0.029199    0.030848    0.748180    
#> 496: 0.517082    1.097660    3.466672    0.440364    0.029188    0.030832    0.748206    
#> 497: 0.517102    1.097644    3.466673    0.440514    0.029217    0.030831    0.748260    
#> 498: 0.517082    1.097640    3.466624    0.440692    0.029247    0.030812    0.748275    
#> 499: 0.516960    1.097677    3.466567    0.440637    0.029286    0.030805    0.748282    
#> 500: 0.516834    1.097682    3.466504    0.440394    0.029289    0.030801    0.748306    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.314194    0.965188    3.434071    0.392401    0.078130    0.016800    1.907804    
#> 002: 0.411252    1.001879    3.442898    0.372781    0.074223    0.015960    1.281205    
#> 003: 0.556226    0.960671    3.443246    0.424967    0.070512    0.015162    0.904826    
#> 004: 0.572480    0.969421    3.447323    0.502381    0.066986    0.014404    0.776435    
#> 005: 0.629162    1.003134    3.427351    0.554275    0.063637    0.013684    0.742162    
#> 006: 0.623410    1.013104    3.433630    0.652397    0.060455    0.013000    0.691706    
#> 007: 0.612337    1.025802    3.437399    0.619777    0.071318    0.012350    0.709580    
#> 008: 0.648812    1.014990    3.438648    0.699070    0.068614    0.015161    0.704706    
#> 009: 0.650060    0.999262    3.450294    0.684748    0.065183    0.015747    0.699557    
#> 010: 0.665797    0.991142    3.452957    0.658418    0.061924    0.014959    0.702739    
#> 011: 0.735941    1.002403    3.449461    0.833344    0.058828    0.015237    0.712269    
#> 012: 0.676515    0.999379    3.441259    0.791677    0.055887    0.014475    0.700239    
#> 013: 0.587074    1.004679    3.442017    0.752093    0.054317    0.013751    0.719103    
#> 014: 0.675950    0.999896    3.448480    0.714488    0.051601    0.014459    0.749398    
#> 015: 0.749861    1.007137    3.466018    0.837910    0.054357    0.013736    0.720937    
#> 016: 0.728488    1.004817    3.470215    0.796015    0.062442    0.013049    0.723499    
#> 017: 0.715176    1.004574    3.465070    0.756214    0.061742    0.012396    0.696375    
#> 018: 0.749183    1.006929    3.455073    0.824581    0.058655    0.011777    0.703353    
#> 019: 0.737224    1.000657    3.459090    0.792830    0.060763    0.011188    0.679964    
#> 020: 0.750238    0.997812    3.466004    0.811581    0.062623    0.011921    0.692497    
#> 021: 0.687614    0.987005    3.459983    0.771002    0.061845    0.012563    0.685405    
#> 022: 0.739974    0.997443    3.469044    0.732452    0.058752    0.014215    0.681782    
#> 023: 0.799567    0.993206    3.477412    0.796894    0.055815    0.013505    0.695868    
#> 024: 0.762159    1.009075    3.472153    0.806500    0.056616    0.013470    0.678017    
#> 025: 0.710284    0.983761    3.457618    0.766175    0.061303    0.013891    0.700510    
#> 026: 0.706473    1.010791    3.470146    0.756448    0.064387    0.013744    0.702442    
#> 027: 0.745907    1.018892    3.477278    0.718626    0.061167    0.015306    0.697736    
#> 028: 0.778459    1.002947    3.474473    0.754548    0.067844    0.014541    0.683361    
#> 029: 0.774253    0.998350    3.470352    0.785225    0.064452    0.013814    0.702615    
#> 030: 0.720917    1.003474    3.459154    0.747457    0.061229    0.013123    0.683777    
#> 031: 0.692817    0.996928    3.469677    0.710084    0.061630    0.012467    0.696964    
#> 032: 0.703631    0.979915    3.474818    0.752009    0.058548    0.011843    0.693520    
#> 033: 0.700994    1.002250    3.465053    0.714408    0.055621    0.011251    0.702884    
#> 034: 0.736096    1.023438    3.458738    0.782498    0.060294    0.013572    0.697777    
#> 035: 0.687867    0.999684    3.456945    0.743373    0.060522    0.012893    0.688615    
#> 036: 0.711469    1.005023    3.460644    0.785977    0.057496    0.012248    0.690930    
#> 037: 0.768200    1.022715    3.458689    0.947884    0.058959    0.011636    0.712320    
#> 038: 0.801167    0.995789    3.465170    1.018373    0.060574    0.011054    0.693369    
#> 039: 0.760193    0.997346    3.475571    0.967454    0.057545    0.011115    0.681139    
#> 040: 0.744338    0.993100    3.474584    0.919081    0.054668    0.013212    0.683586    
#> 041: 0.715334    0.975349    3.469871    0.873127    0.051935    0.012551    0.686004    
#> 042: 0.716641    0.985831    3.466785    0.829471    0.057459    0.012065    0.693925    
#> 043: 0.697718    1.005313    3.455482    0.787997    0.060736    0.011462    0.702657    
#> 044: 0.734919    1.009315    3.461093    0.757313    0.057700    0.010888    0.707671    
#> 045: 0.746286    1.016326    3.459610    0.775829    0.061597    0.010557    0.687292    
#> 046: 0.748934    1.009005    3.458399    0.890742    0.058517    0.010029    0.681198    
#> 047: 0.749956    1.013078    3.452376    0.927058    0.062567    0.009527    0.676469    
#> 048: 0.750264    0.998459    3.454442    1.040668    0.060296    0.009742    0.680353    
#> 049: 0.769278    0.997398    3.465664    1.048673    0.058281    0.012185    0.695640    
#> 050: 0.783246    0.973197    3.477098    0.996239    0.055367    0.013546    0.717960    
#> 051: 0.764793    0.987706    3.474340    0.987936    0.052598    0.014607    0.714752    
#> 052: 0.813159    0.985583    3.476570    0.938539    0.055355    0.013877    0.700193    
#> 053: 0.806841    0.990200    3.475807    0.891612    0.058663    0.014188    0.689238    
#> 054: 0.756370    0.998309    3.464394    0.880967    0.068552    0.013479    0.702001    
#> 055: 0.737179    1.002183    3.463671    0.951993    0.069529    0.012805    0.688487    
#> 056: 0.751209    0.974890    3.466622    0.904393    0.066052    0.012164    0.709963    
#> 057: 0.731441    0.988549    3.464184    0.859174    0.062750    0.012481    0.681760    
#> 058: 0.751423    0.960490    3.458056    0.869241    0.059612    0.011857    0.697204    
#> 059: 0.737814    0.958601    3.464097    0.898494    0.060174    0.011264    0.699617    
#> 060: 0.766141    0.963952    3.473279    0.853569    0.072138    0.010701    0.714766    
#> 061: 0.838232    0.989447    3.470702    1.018519    0.075306    0.011380    0.691187    
#> 062: 0.771952    1.001855    3.472489    0.967593    0.094147    0.010811    0.692750    
#> 063: 0.768851    0.959819    3.481806    0.919214    0.089440    0.010271    0.695223    
#> 064: 0.790707    0.975867    3.489100    0.873253    0.084968    0.009757    0.709880    
#> 065: 0.757949    0.956112    3.471198    0.829590    0.087536    0.009269    0.712769    
#> 066: 0.733953    0.994560    3.463831    0.788111    0.083159    0.008806    0.696338    
#> 067: 0.736765    0.983900    3.460949    0.748705    0.079001    0.008627    0.675145    
#> 068: 0.719029    0.973573    3.473520    0.738453    0.075051    0.008196    0.715273    
#> 069: 0.720051    0.980140    3.461104    0.792849    0.071298    0.007786    0.719732    
#> 070: 0.713235    0.988249    3.465110    0.912891    0.093904    0.007397    0.711052    
#> 071: 0.696353    1.018219    3.442823    0.880101    0.101069    0.007027    0.708518    
#> 072: 0.652745    0.988719    3.439689    0.836096    0.096015    0.006676    0.716017    
#> 073: 0.676947    1.002049    3.463261    0.794291    0.091214    0.006342    0.716421    
#> 074: 0.699944    0.992100    3.458310    0.822483    0.086654    0.006025    0.694597    
#> 075: 0.716298    0.988318    3.470769    0.781358    0.082321    0.005724    0.706074    
#> 076: 0.746698    0.992517    3.475407    0.869742    0.078205    0.005437    0.718048    
#> 077: 0.735453    0.985702    3.459175    0.826255    0.074295    0.005420    0.703295    
#> 078: 0.725683    0.993179    3.468806    0.784942    0.070580    0.005982    0.686159    
#> 079: 0.748071    1.004747    3.481424    0.754155    0.076393    0.006394    0.735151    
#> 080: 0.707005    0.996640    3.470618    0.716447    0.081381    0.006074    0.734620    
#> 081: 0.693139    0.998589    3.462721    0.680625    0.077312    0.005771    0.745615    
#> 082: 0.735389    0.988745    3.470285    0.794831    0.078279    0.005482    0.734582    
#> 083: 0.759072    0.998353    3.479034    0.803138    0.079829    0.005208    0.742778    
#> 084: 0.735742    1.023820    3.472249    0.765672    0.075837    0.005283    0.747798    
#> 085: 0.694657    1.030818    3.470078    0.727388    0.085045    0.005019    0.725188    
#> 086: 0.659331    1.017000    3.459585    0.691019    0.080793    0.004976    0.717683    
#> 087: 0.703015    1.014139    3.450975    0.676764    0.076753    0.004727    0.694466    
#> 088: 0.669566    1.006133    3.461879    0.711025    0.077593    0.005017    0.700751    
#> 089: 0.700524    1.036373    3.444098    0.804677    0.083977    0.004766    0.700426    
#> 090: 0.666696    1.012683    3.442818    0.772833    0.083463    0.004675    0.711707    
#> 091: 0.672684    1.002569    3.432729    0.788835    0.079290    0.005440    0.713656    
#> 092: 0.676273    1.034445    3.430383    0.799730    0.078002    0.006134    0.698699    
#> 093: 0.638064    1.011800    3.434372    0.759743    0.074323    0.005827    0.715864    
#> 094: 0.669109    1.030108    3.431617    0.785156    0.084463    0.006032    0.709536    
#> 095: 0.657784    1.035278    3.436779    0.865793    0.080240    0.005730    0.724516    
#> 096: 0.646522    1.018609    3.432646    0.822503    0.076228    0.005444    0.720778    
#> 097: 0.651024    1.060526    3.423730    0.785621    0.075596    0.005172    0.718336    
#> 098: 0.703675    1.048008    3.437607    0.767438    0.080840    0.005025    0.711501    
#> 099: 0.706222    0.997498    3.433632    0.746012    0.076798    0.005256    0.710547    
#> 100: 0.656596    1.018738    3.433733    0.708711    0.092709    0.005170    0.705277    
#> 101: 0.620070    1.006554    3.422509    0.673276    0.088074    0.004911    0.714338    
#> 102: 0.659654    1.002837    3.423691    0.703464    0.088828    0.004690    0.722986    
#> 103: 0.687882    1.017582    3.424118    0.905584    0.084386    0.005677    0.707842    
#> 104: 0.679533    1.032159    3.435376    0.957078    0.087114    0.005393    0.711214    
#> 105: 0.699101    1.025526    3.433811    1.012571    0.093595    0.006710    0.703671    
#> 106: 0.748505    1.000702    3.439195    0.961942    0.088915    0.006759    0.694150    
#> 107: 0.754359    1.012739    3.449067    0.948757    0.084470    0.006421    0.702584    
#> 108: 0.693853    1.022551    3.446665    0.901319    0.080246    0.006100    0.731297    
#> 109: 0.714733    1.012702    3.456698    0.856253    0.076234    0.005795    0.730681    
#> 110: 0.743224    1.008966    3.444204    0.836046    0.079100    0.005505    0.722723    
#> 111: 0.709136    1.003835    3.445879    0.794243    0.075705    0.005230    0.699208    
#> 112: 0.698844    0.992604    3.445084    0.772199    0.089257    0.004968    0.704223    
#> 113: 0.711467    1.026778    3.449404    0.848215    0.084794    0.004816    0.690127    
#> 114: 0.718021    1.029488    3.446854    0.817450    0.080554    0.004575    0.699400    
#> 115: 0.753755    0.980652    3.448739    0.946377    0.076527    0.004347    0.711473    
#> 116: 0.801335    0.996610    3.458169    1.086782    0.072700    0.004129    0.720203    
#> 117: 0.693871    1.022598    3.449896    1.032443    0.080362    0.003923    0.717424    
#> 118: 0.740475    0.997144    3.451151    0.980821    0.076344    0.004637    0.720518    
#> 119: 0.746640    1.001380    3.451737    0.931780    0.074133    0.005238    0.723722    
#> 120: 0.721841    0.997928    3.450387    0.885191    0.083809    0.006107    0.729700    
#> 121: 0.719346    1.025802    3.447553    0.840931    0.079619    0.005802    0.731847    
#> 122: 0.718439    1.010179    3.456420    0.798885    0.075638    0.006467    0.720799    
#> 123: 0.775154    1.028738    3.459417    0.892071    0.084587    0.006935    0.710045    
#> 124: 0.788583    1.047511    3.453164    0.847468    0.080358    0.006588    0.718749    
#> 125: 0.720144    1.048192    3.440472    0.805094    0.076340    0.007333    0.704164    
#> 126: 0.724250    1.042364    3.436195    0.820362    0.072523    0.007964    0.692821    
#> 127: 0.715737    1.007262    3.446326    0.779344    0.068897    0.008639    0.708737    
#> 128: 0.693191    1.011645    3.456899    0.777400    0.065452    0.010137    0.712851    
#> 129: 0.748615    1.007963    3.467551    0.934743    0.062179    0.011412    0.709714    
#> 130: 0.795514    0.998149    3.471551    0.894612    0.059071    0.012279    0.706650    
#> 131: 0.788253    0.988458    3.468800    0.875877    0.061598    0.012640    0.707003    
#> 132: 0.705456    1.004414    3.455416    0.832083    0.059567    0.012008    0.689546    
#> 133: 0.734574    0.989828    3.460924    0.790479    0.070857    0.011408    0.713857    
#> 134: 0.713328    0.974835    3.467580    0.750955    0.067314    0.010837    0.718722    
#> 135: 0.759969    0.976823    3.481476    0.743351    0.078603    0.010295    0.714117    
#> 136: 0.695948    0.968839    3.480450    0.706183    0.075315    0.009781    0.698977    
#> 137: 0.757596    0.973214    3.481113    0.801313    0.071549    0.010438    0.711812    
#> 138: 0.767624    0.977645    3.472685    0.761248    0.067972    0.009916    0.697977    
#> 139: 0.716981    0.987809    3.469010    0.817189    0.071182    0.013530    0.687435    
#> 140: 0.773696    1.004239    3.469442    0.858593    0.076752    0.013578    0.701254    
#> 141: 0.756554    0.981942    3.470725    0.882116    0.078728    0.013365    0.686075    
#> 142: 0.780021    0.952135    3.483429    0.838011    0.074792    0.012697    0.714153    
#> 143: 0.711093    0.969370    3.480342    0.796110    0.071052    0.014864    0.698956    
#> 144: 0.800636    0.983719    3.482927    0.803837    0.067500    0.014121    0.680332    
#> 145: 0.750004    0.999703    3.464590    0.763645    0.064125    0.013415    0.685036    
#> 146: 0.760595    1.016948    3.477416    0.778936    0.060919    0.013985    0.698090    
#> 147: 0.703311    1.005896    3.461570    0.743109    0.060116    0.014014    0.684737    
#> 148: 0.700088    1.000644    3.469385    0.706248    0.057110    0.013313    0.693550    
#> 149: 0.739324    0.989916    3.467576    0.752288    0.058667    0.012648    0.692592    
#> 150: 0.758167    0.989296    3.451786    0.897712    0.062561    0.012015    0.715159    
#> 151: 0.708201    1.009756    3.447987    0.852827    0.063710    0.011414    0.686205    
#> 152: 0.710885    1.030769    3.457138    0.855306    0.061091    0.011417    0.706093    
#> 153: 0.701954    1.028492    3.457809    0.868476    0.079395    0.009651    0.703397    
#> 154: 0.744272    1.017299    3.453759    0.871035    0.077233    0.009799    0.703969    
#> 155: 0.707692    0.981273    3.454163    0.866464    0.074666    0.009959    0.691268    
#> 156: 0.722678    0.995372    3.466233    0.850198    0.077136    0.011171    0.707648    
#> 157: 0.742976    0.991030    3.473096    0.796551    0.089034    0.010433    0.704243    
#> 158: 0.811224    1.005366    3.476232    0.870874    0.075305    0.009781    0.698201    
#> 159: 0.742227    0.998459    3.479417    0.695757    0.057122    0.009232    0.702168    
#> 160: 0.785677    0.979464    3.478019    0.842700    0.066167    0.007991    0.700623    
#> 161: 0.734185    0.989488    3.470672    0.679008    0.081408    0.007752    0.703868    
#> 162: 0.750781    1.000632    3.471058    0.720375    0.078974    0.007039    0.708335    
#> 163: 0.785283    0.989141    3.469352    0.818270    0.073085    0.005610    0.701105    
#> 164: 0.780779    0.996864    3.470336    0.709507    0.064769    0.004960    0.711207    
#> 165: 0.779278    0.976383    3.481202    0.778464    0.065224    0.006853    0.692822    
#> 166: 0.836761    0.997145    3.478379    0.909332    0.072111    0.007252    0.701760    
#> 167: 0.793350    1.006760    3.479113    0.821675    0.073713    0.006923    0.707795    
#> 168: 0.793388    0.991792    3.485027    0.816856    0.077541    0.007492    0.694950    
#> 169: 0.779651    1.020276    3.472150    0.787008    0.076574    0.007165    0.700079    
#> 170: 0.793897    0.996616    3.473441    0.790276    0.077776    0.008375    0.694054    
#> 171: 0.752541    0.986417    3.468180    0.803830    0.070110    0.007414    0.690848    
#> 172: 0.729835    1.020352    3.459575    0.875584    0.060426    0.008408    0.697618    
#> 173: 0.732564    1.022957    3.451757    0.835616    0.062340    0.009318    0.681560    
#> 174: 0.754425    1.009389    3.457467    0.808447    0.057766    0.008388    0.671315    
#> 175: 0.743938    1.025620    3.448251    0.884891    0.072516    0.008778    0.693732    
#> 176: 0.696811    1.020929    3.454061    0.784270    0.063814    0.007311    0.685900    
#> 177: 0.729332    1.020123    3.459074    0.799421    0.073791    0.007757    0.697376    
#> 178: 0.739766    1.006920    3.462477    0.638384    0.076990    0.009341    0.704965    
#> 179: 0.749427    1.000332    3.467148    0.652894    0.080365    0.007127    0.710928    
#> 180: 0.704670    1.005750    3.463187    0.704305    0.064480    0.008636    0.693677    
#> 181: 0.712409    0.990422    3.457244    0.681041    0.074709    0.008292    0.683286    
#> 182: 0.707361    1.002690    3.453156    0.603242    0.073021    0.010165    0.692185    
#> 183: 0.730143    1.002075    3.454656    0.703234    0.050278    0.010827    0.697889    
#> 184: 0.763334    0.999193    3.455969    0.846392    0.051696    0.009316    0.703238    
#> 185: 0.698581    1.023306    3.452311    0.725754    0.044556    0.010265    0.705948    
#> 186: 0.695211    1.034458    3.460261    0.587962    0.049215    0.012914    0.720107    
#> 187: 0.719500    0.993991    3.478588    0.602381    0.057190    0.012862    0.704467    
#> 188: 0.750385    1.010245    3.472845    0.786031    0.061214    0.013145    0.707673    
#> 189: 0.783623    1.006303    3.477868    0.784567    0.070392    0.013011    0.705278    
#> 190: 0.759272    1.000462    3.482363    0.622906    0.049748    0.014297    0.686789    
#> 191: 0.763045    1.008594    3.470705    0.741571    0.051608    0.011458    0.681060    
#> 192: 0.709737    0.996554    3.473800    0.666856    0.050737    0.011522    0.689162    
#> 193: 0.787401    1.001632    3.475172    0.749511    0.047188    0.011782    0.693788    
#> 194: 0.735109    0.990172    3.466254    0.723096    0.067344    0.009404    0.690191    
#> 195: 0.671342    1.000206    3.457923    0.654070    0.076647    0.006390    0.704966    
#> 196: 0.734474    1.011087    3.463287    0.773107    0.080402    0.008971    0.711452    
#> 197: 0.689152    1.012022    3.476323    0.707829    0.076088    0.010474    0.705288    
#> 198: 0.754700    0.987531    3.461675    0.860828    0.063309    0.012697    0.691734    
#> 199: 0.708220    0.972614    3.464166    0.828053    0.067736    0.008942    0.712982    
#> 200: 0.675437    1.002778    3.451005    0.695905    0.075339    0.007144    0.734963    
#> 201: 0.675923    0.993793    3.458746    0.630916    0.068336    0.008617    0.723813    
#> 202: 0.673990    0.993187    3.460961    0.632023    0.066662    0.009203    0.721388    
#> 203: 0.693363    0.993316    3.459982    0.660673    0.065015    0.009499    0.725753    
#> 204: 0.698368    0.987721    3.461792    0.677018    0.065113    0.009507    0.726886    
#> 205: 0.714435    0.990443    3.462633    0.718894    0.065473    0.009789    0.725806    
#> 206: 0.727742    0.994322    3.463582    0.766282    0.066822    0.009754    0.726437    
#> 207: 0.727636    0.995928    3.463402    0.761231    0.065484    0.009612    0.727346    
#> 208: 0.728325    0.995314    3.464362    0.762883    0.063865    0.009418    0.725703    
#> 209: 0.734380    0.993270    3.464538    0.779061    0.063936    0.009333    0.723819    
#> 210: 0.738492    0.992262    3.465276    0.780105    0.064196    0.009333    0.722231    
#> 211: 0.744267    0.991827    3.466126    0.784541    0.064193    0.009314    0.720322    
#> 212: 0.746191    0.990823    3.466884    0.788983    0.064233    0.009289    0.719219    
#> 213: 0.748520    0.988396    3.467589    0.794053    0.063621    0.009448    0.718768    
#> 214: 0.750729    0.987796    3.468415    0.800887    0.063452    0.009479    0.717480    
#> 215: 0.754300    0.988189    3.469082    0.806511    0.062930    0.009524    0.716512    
#> 216: 0.760667    0.987547    3.469626    0.821677    0.063729    0.009522    0.716168    
#> 217: 0.763481    0.988419    3.469890    0.828664    0.064646    0.009498    0.714322    
#> 218: 0.764678    0.989302    3.469992    0.827896    0.065230    0.009453    0.713962    
#> 219: 0.764387    0.988679    3.469506    0.826073    0.065765    0.009371    0.714027    
#> 220: 0.760865    0.988414    3.469578    0.816657    0.066093    0.009320    0.714528    
#> 221: 0.758986    0.987498    3.469635    0.809776    0.066770    0.009253    0.714261    
#> 222: 0.759922    0.987758    3.469266    0.810401    0.067158    0.009303    0.713755    
#> 223: 0.761172    0.987736    3.469277    0.813263    0.067412    0.009339    0.713010    
#> 224: 0.764579    0.987753    3.469589    0.821134    0.067603    0.009386    0.711661    
#> 225: 0.763536    0.986331    3.469978    0.818643    0.067529    0.009376    0.711339    
#> 226: 0.762890    0.985291    3.469956    0.819264    0.067422    0.009361    0.711158    
#> 227: 0.761677    0.984938    3.470238    0.816065    0.067481    0.009335    0.710919    
#> 228: 0.761743    0.985424    3.470122    0.812301    0.067819    0.009321    0.710425    
#> 229: 0.762685    0.984881    3.470112    0.816936    0.067959    0.009282    0.710022    
#> 230: 0.764132    0.984185    3.470203    0.816918    0.068176    0.009289    0.709743    
#> 231: 0.764739    0.984603    3.470255    0.818878    0.068287    0.009291    0.709142    
#> 232: 0.763598    0.984713    3.470391    0.819363    0.068374    0.009306    0.709245    
#> 233: 0.764254    0.983457    3.470758    0.823938    0.068327    0.009265    0.709431    
#> 234: 0.764021    0.983209    3.471036    0.822528    0.068505    0.009197    0.709235    
#> 235: 0.761944    0.982329    3.470933    0.818282    0.068461    0.009151    0.709041    
#> 236: 0.761420    0.982392    3.471000    0.816691    0.068755    0.009085    0.708951    
#> 237: 0.761858    0.982482    3.470907    0.820265    0.069241    0.009050    0.709021    
#> 238: 0.762366    0.982827    3.470955    0.820897    0.070093    0.008981    0.709829    
#> 239: 0.762181    0.983517    3.470842    0.823380    0.070538    0.008967    0.709701    
#> 240: 0.762579    0.983757    3.470828    0.820241    0.070474    0.008948    0.709351    
#> 241: 0.762867    0.983061    3.471028    0.819613    0.070356    0.008904    0.709282    
#> 242: 0.763494    0.982699    3.470983    0.822360    0.070378    0.008926    0.709327    
#> 243: 0.763248    0.983287    3.470858    0.821804    0.070381    0.008951    0.709239    
#> 244: 0.762451    0.983522    3.470738    0.821891    0.070074    0.008965    0.709625    
#> 245: 0.762656    0.983501    3.470640    0.820421    0.070252    0.008929    0.710279    
#> 246: 0.762902    0.983718    3.470623    0.819862    0.070109    0.008947    0.710652    
#> 247: 0.762809    0.983705    3.470785    0.820066    0.070295    0.008933    0.710635    
#> 248: 0.762275    0.984195    3.470666    0.821865    0.070436    0.008947    0.710397    
#> 249: 0.760961    0.984437    3.470563    0.818989    0.070665    0.008955    0.710318    
#> 250: 0.761870    0.984751    3.470615    0.820148    0.070832    0.008969    0.710136    
#> 251: 0.763460    0.985061    3.470866    0.820893    0.070937    0.008933    0.710041    
#> 252: 0.764528    0.984823    3.471220    0.822364    0.071082    0.008922    0.709812    
#> 253: 0.764246    0.984611    3.471344    0.822632    0.071170    0.008910    0.709769    
#> 254: 0.763743    0.985024    3.471426    0.820863    0.071314    0.008882    0.709491    
#> 255: 0.763184    0.985399    3.471517    0.820262    0.071231    0.008915    0.709305    
#> 256: 0.762607    0.985721    3.471479    0.818815    0.071244    0.008940    0.708956    
#> 257: 0.761917    0.985467    3.471382    0.817640    0.071224    0.008941    0.709065    
#> 258: 0.761496    0.985036    3.471348    0.817534    0.071132    0.008913    0.709014    
#> 259: 0.760782    0.984984    3.471356    0.816743    0.071173    0.008878    0.709020    
#> 260: 0.760578    0.985292    3.471417    0.814757    0.071268    0.008833    0.708735    
#> 261: 0.760577    0.985344    3.471585    0.814364    0.071288    0.008797    0.708638    
#> 262: 0.759681    0.985670    3.471527    0.813087    0.071570    0.008758    0.708380    
#> 263: 0.758978    0.985923    3.471342    0.811684    0.071508    0.008765    0.708209    
#> 264: 0.758080    0.986118    3.471163    0.810442    0.071556    0.008760    0.708576    
#> 265: 0.758243    0.986167    3.471128    0.812190    0.071706    0.008757    0.708780    
#> 266: 0.758875    0.986204    3.470956    0.815669    0.071674    0.008759    0.708536    
#> 267: 0.758912    0.986069    3.470925    0.817372    0.071838    0.008765    0.708417    
#> 268: 0.759224    0.985796    3.470714    0.819011    0.071776    0.008734    0.708235    
#> 269: 0.759507    0.985727    3.470589    0.820044    0.071761    0.008710    0.708015    
#> 270: 0.759933    0.986014    3.470389    0.822635    0.071831    0.008669    0.707734    
#> 271: 0.759458    0.986157    3.470062    0.823640    0.072094    0.008661    0.707814    
#> 272: 0.759833    0.986007    3.469939    0.823618    0.072128    0.008656    0.707986    
#> 273: 0.759773    0.986413    3.470002    0.824128    0.072228    0.008662    0.708004    
#> 274: 0.759669    0.986561    3.470185    0.823138    0.072077    0.008649    0.707922    
#> 275: 0.760476    0.986632    3.470126    0.825146    0.071913    0.008648    0.707731    
#> 276: 0.760846    0.986803    3.470237    0.827256    0.072066    0.008616    0.707884    
#> 277: 0.760752    0.986951    3.470416    0.828219    0.072183    0.008588    0.707860    
#> 278: 0.760705    0.986696    3.470522    0.826512    0.072267    0.008563    0.708028    
#> 279: 0.760330    0.986432    3.470573    0.826086    0.072502    0.008529    0.708178    
#> 280: 0.759678    0.986707    3.470600    0.824544    0.072446    0.008511    0.708230    
#> 281: 0.758471    0.986952    3.470517    0.823985    0.072405    0.008496    0.708278    
#> 282: 0.758471    0.987264    3.470453    0.826611    0.072272    0.008500    0.708025    
#> 283: 0.757946    0.987714    3.470353    0.827370    0.072056    0.008509    0.707999    
#> 284: 0.756841    0.988057    3.470146    0.826297    0.071922    0.008514    0.707840    
#> 285: 0.756350    0.988201    3.469858    0.826838    0.071828    0.008550    0.707817    
#> 286: 0.756175    0.988626    3.469660    0.827998    0.071809    0.008557    0.707681    
#> 287: 0.756017    0.988905    3.469371    0.830704    0.071829    0.008569    0.707709    
#> 288: 0.756138    0.989070    3.469163    0.833219    0.071781    0.008606    0.707835    
#> 289: 0.756269    0.989126    3.469009    0.834154    0.071671    0.008635    0.707831    
#> 290: 0.755993    0.989138    3.468821    0.834370    0.071488    0.008663    0.707988    
#> 291: 0.756267    0.989452    3.468808    0.835325    0.071342    0.008710    0.707825    
#> 292: 0.756147    0.989584    3.468701    0.835442    0.071266    0.008721    0.707794    
#> 293: 0.755745    0.989613    3.468576    0.834930    0.071225    0.008706    0.707620    
#> 294: 0.755553    0.989698    3.468507    0.834662    0.071138    0.008705    0.707413    
#> 295: 0.755517    0.989346    3.468437    0.834766    0.071048    0.008699    0.707330    
#> 296: 0.755425    0.989196    3.468372    0.834071    0.071054    0.008713    0.707264    
#> 297: 0.755262    0.989347    3.468251    0.834680    0.070929    0.008720    0.707149    
#> 298: 0.754987    0.989375    3.468180    0.834089    0.070738    0.008716    0.707116    
#> 299: 0.754919    0.989505    3.468102    0.835024    0.070606    0.008707    0.706905    
#> 300: 0.754974    0.989354    3.468174    0.835616    0.070608    0.008711    0.706724    
#> 301: 0.754854    0.989164    3.468116    0.834245    0.070720    0.008690    0.706865    
#> 302: 0.754912    0.989240    3.467990    0.834350    0.070724    0.008673    0.706872    
#> 303: 0.754808    0.989361    3.467890    0.834752    0.070678    0.008663    0.706824    
#> 304: 0.754649    0.989729    3.467696    0.835432    0.070545    0.008651    0.706694    
#> 305: 0.754518    0.989676    3.467602    0.836302    0.070520    0.008644    0.706674    
#> 306: 0.754237    0.989733    3.467464    0.836904    0.070530    0.008636    0.706562    
#> 307: 0.753926    0.989859    3.467375    0.836693    0.070723    0.008623    0.706645    
#> 308: 0.754450    0.989696    3.467353    0.839893    0.070893    0.008618    0.706783    
#> 309: 0.754525    0.989425    3.467288    0.842104    0.071058    0.008614    0.707075    
#> 310: 0.754539    0.989293    3.467140    0.843126    0.071211    0.008606    0.707172    
#> 311: 0.755060    0.989309    3.467033    0.845930    0.071204    0.008603    0.707169    
#> 312: 0.755713    0.989327    3.466890    0.850145    0.071238    0.008595    0.707023    
#> 313: 0.755603    0.989154    3.466722    0.851625    0.071262    0.008586    0.707036    
#> 314: 0.754656    0.989143    3.466485    0.851085    0.071297    0.008578    0.707096    
#> 315: 0.753654    0.989319    3.466330    0.850517    0.071269    0.008559    0.707112    
#> 316: 0.753746    0.989341    3.466180    0.851888    0.071243    0.008536    0.707133    
#> 317: 0.753795    0.989200    3.466148    0.851122    0.071172    0.008531    0.707423    
#> 318: 0.753564    0.989257    3.466081    0.850358    0.071087    0.008530    0.707395    
#> 319: 0.753475    0.989281    3.466081    0.850125    0.071040    0.008542    0.707387    
#> 320: 0.753068    0.989271    3.465994    0.849914    0.071114    0.008565    0.707361    
#> 321: 0.752969    0.989372    3.465884    0.850557    0.071149    0.008566    0.707398    
#> 322: 0.752932    0.989436    3.465683    0.851789    0.071122    0.008557    0.707382    
#> 323: 0.752574    0.989471    3.465503    0.852052    0.071068    0.008546    0.707428    
#> 324: 0.752523    0.989627    3.465502    0.851863    0.071102    0.008552    0.707331    
#> 325: 0.752614    0.989819    3.465490    0.852008    0.071118    0.008546    0.707101    
#> 326: 0.752493    0.989757    3.465404    0.851560    0.071093    0.008535    0.707010    
#> 327: 0.752767    0.989732    3.465396    0.852265    0.071219    0.008532    0.706868    
#> 328: 0.752889    0.989806    3.465357    0.852075    0.071215    0.008522    0.706794    
#> 329: 0.752887    0.989846    3.465438    0.851270    0.071203    0.008532    0.706744    
#> 330: 0.752915    0.989865    3.465524    0.851296    0.071181    0.008547    0.706589    
#> 331: 0.753339    0.990024    3.465623    0.850579    0.071175    0.008556    0.706528    
#> 332: 0.753413    0.990026    3.465734    0.849484    0.071070    0.008560    0.706618    
#> 333: 0.753516    0.990061    3.465720    0.848923    0.071011    0.008575    0.706709    
#> 334: 0.753627    0.990053    3.465677    0.849036    0.070942    0.008583    0.706646    
#> 335: 0.753702    0.990111    3.465552    0.848995    0.070883    0.008579    0.706715    
#> 336: 0.753346    0.990349    3.465436    0.849035    0.070877    0.008576    0.706804    
#> 337: 0.753349    0.990737    3.465326    0.849723    0.070871    0.008585    0.706875    
#> 338: 0.753090    0.990802    3.465330    0.849884    0.070806    0.008592    0.706952    
#> 339: 0.752775    0.990967    3.465343    0.848681    0.070754    0.008596    0.706942    
#> 340: 0.752425    0.990796    3.465372    0.848274    0.070869    0.008608    0.706935    
#> 341: 0.752227    0.990763    3.465462    0.847416    0.070849    0.008622    0.706829    
#> 342: 0.751738    0.990690    3.465482    0.846210    0.070885    0.008631    0.706786    
#> 343: 0.751712    0.990776    3.465502    0.845716    0.070920    0.008635    0.706617    
#> 344: 0.752098    0.990807    3.465492    0.847247    0.070898    0.008636    0.706562    
#> 345: 0.751775    0.990867    3.465427    0.847065    0.070953    0.008644    0.706577    
#> 346: 0.751661    0.990968    3.465287    0.847525    0.070930    0.008654    0.706463    
#> 347: 0.751099    0.990971    3.465146    0.846996    0.070874    0.008688    0.706391    
#> 348: 0.750434    0.991211    3.465026    0.846272    0.070954    0.008712    0.706421    
#> 349: 0.750150    0.991241    3.464928    0.846691    0.071009    0.008733    0.706383    
#> 350: 0.749682    0.991194    3.464863    0.845728    0.070961    0.008753    0.706354    
#> 351: 0.749317    0.991383    3.464800    0.844780    0.070950    0.008759    0.706306    
#> 352: 0.748892    0.991484    3.464803    0.843767    0.070922    0.008758    0.706428    
#> 353: 0.749164    0.991561    3.464850    0.844336    0.070856    0.008768    0.706453    
#> 354: 0.749264    0.991618    3.464796    0.844440    0.070746    0.008771    0.706416    
#> 355: 0.749899    0.991393    3.464790    0.845585    0.070684    0.008760    0.706468    
#> 356: 0.750009    0.991285    3.464833    0.845087    0.070750    0.008750    0.706620    
#> 357: 0.750135    0.991377    3.464853    0.845360    0.070777    0.008744    0.706507    
#> 358: 0.750097    0.991591    3.464867    0.845532    0.070757    0.008738    0.706391    
#> 359: 0.750078    0.991822    3.464818    0.846161    0.070801    0.008733    0.706208    
#> 360: 0.749936    0.991940    3.464679    0.846311    0.070874    0.008721    0.706088    
#> 361: 0.749655    0.992005    3.464580    0.845953    0.070837    0.008716    0.706008    
#> 362: 0.749655    0.992116    3.464512    0.845350    0.070723    0.008704    0.705903    
#> 363: 0.749539    0.992160    3.464445    0.845717    0.070634    0.008703    0.705774    
#> 364: 0.749774    0.992314    3.464396    0.846733    0.070703    0.008703    0.705708    
#> 365: 0.749970    0.992217    3.464397    0.847704    0.070618    0.008715    0.705656    
#> 366: 0.749949    0.992201    3.464345    0.847690    0.070669    0.008715    0.705596    
#> 367: 0.749880    0.992205    3.464299    0.847493    0.070712    0.008710    0.705498    
#> 368: 0.749780    0.992331    3.464243    0.847353    0.070666    0.008711    0.705328    
#> 369: 0.749546    0.992411    3.464170    0.846993    0.070700    0.008708    0.705244    
#> 370: 0.749228    0.992505    3.464155    0.845902    0.070665    0.008713    0.705189    
#> 371: 0.748981    0.992568    3.464103    0.845153    0.070616    0.008714    0.705243    
#> 372: 0.748575    0.992703    3.464067    0.844668    0.070544    0.008725    0.705179    
#> 373: 0.748098    0.992864    3.464010    0.843557    0.070547    0.008733    0.705083    
#> 374: 0.748050    0.992961    3.463911    0.843341    0.070546    0.008735    0.704955    
#> 375: 0.747765    0.993020    3.463869    0.843210    0.070480    0.008734    0.704962    
#> 376: 0.747283    0.993069    3.463873    0.842521    0.070411    0.008747    0.704947    
#> 377: 0.747039    0.993148    3.463904    0.841404    0.070386    0.008761    0.704909    
#> 378: 0.746857    0.993131    3.463933    0.840602    0.070406    0.008757    0.704854    
#> 379: 0.746604    0.993016    3.463987    0.839863    0.070409    0.008754    0.704813    
#> 380: 0.746466    0.993103    3.463995    0.839231    0.070459    0.008753    0.704721    
#> 381: 0.746201    0.993190    3.463992    0.838798    0.070488    0.008744    0.704721    
#> 382: 0.746187    0.993322    3.463947    0.838499    0.070495    0.008733    0.704626    
#> 383: 0.746271    0.993384    3.463936    0.838428    0.070520    0.008732    0.704498    
#> 384: 0.746067    0.993406    3.464005    0.837696    0.070473    0.008739    0.704451    
#> 385: 0.746150    0.993404    3.464062    0.837164    0.070366    0.008758    0.704322    
#> 386: 0.746271    0.993560    3.464114    0.836640    0.070230    0.008774    0.704356    
#> 387: 0.746123    0.993753    3.464171    0.835701    0.070182    0.008784    0.704265    
#> 388: 0.746257    0.993865    3.464219    0.835674    0.070116    0.008803    0.704151    
#> 389: 0.746375    0.993764    3.464241    0.836026    0.070055    0.008817    0.704192    
#> 390: 0.746471    0.993794    3.464238    0.836044    0.070035    0.008825    0.704167    
#> 391: 0.746770    0.993611    3.464266    0.836123    0.070005    0.008833    0.704088    
#> 392: 0.746864    0.993585    3.464352    0.835980    0.069957    0.008843    0.704102    
#> 393: 0.747138    0.993536    3.464389    0.836348    0.069918    0.008853    0.704094    
#> 394: 0.747520    0.993512    3.464433    0.836996    0.069876    0.008857    0.704028    
#> 395: 0.747998    0.993521    3.464507    0.838255    0.069828    0.008856    0.704011    
#> 396: 0.748580    0.993545    3.464573    0.839968    0.069820    0.008855    0.704030    
#> 397: 0.748793    0.993534    3.464638    0.839966    0.069793    0.008849    0.704098    
#> 398: 0.749168    0.993466    3.464695    0.840317    0.069815    0.008842    0.704129    
#> 399: 0.749217    0.993438    3.464795    0.840060    0.069857    0.008838    0.704147    
#> 400: 0.749209    0.993565    3.464822    0.839527    0.069905    0.008835    0.704117    
#> 401: 0.748912    0.993606    3.464816    0.838488    0.069906    0.008839    0.704104    
#> 402: 0.748769    0.993743    3.464807    0.838037    0.069804    0.008854    0.704079    
#> 403: 0.748701    0.993815    3.464771    0.837551    0.069740    0.008860    0.704015    
#> 404: 0.748497    0.993868    3.464680    0.836909    0.069653    0.008866    0.703951    
#> 405: 0.748194    0.993970    3.464611    0.836762    0.069546    0.008883    0.703928    
#> 406: 0.747923    0.994094    3.464534    0.835980    0.069455    0.008905    0.703992    
#> 407: 0.747726    0.994203    3.464501    0.835830    0.069404    0.008912    0.704048    
#> 408: 0.747609    0.994351    3.464451    0.835103    0.069413    0.008902    0.704023    
#> 409: 0.747255    0.994408    3.464366    0.834299    0.069418    0.008889    0.704006    
#> 410: 0.746750    0.994553    3.464209    0.833622    0.069485    0.008873    0.704081    
#> 411: 0.746699    0.994499    3.464112    0.833814    0.069592    0.008869    0.704119    
#> 412: 0.746409    0.994632    3.463995    0.833155    0.069622    0.008869    0.704020    
#> 413: 0.746079    0.994764    3.463846    0.833163    0.069628    0.008866    0.704039    
#> 414: 0.745833    0.994937    3.463720    0.834149    0.069629    0.008868    0.704039    
#> 415: 0.745554    0.995036    3.463624    0.834205    0.069605    0.008864    0.703995    
#> 416: 0.745377    0.995219    3.463555    0.833925    0.069596    0.008860    0.703959    
#> 417: 0.745452    0.995251    3.463528    0.834439    0.069605    0.008859    0.703883    
#> 418: 0.745296    0.995329    3.463496    0.834489    0.069658    0.008861    0.703836    
#> 419: 0.745291    0.995396    3.463485    0.834455    0.069646    0.008867    0.703761    
#> 420: 0.745187    0.995484    3.463470    0.834351    0.069650    0.008861    0.703670    
#> 421: 0.745096    0.995529    3.463496    0.834077    0.069694    0.008856    0.703604    
#> 422: 0.745302    0.995478    3.463472    0.834387    0.069708    0.008857    0.703634    
#> 423: 0.745346    0.995453    3.463441    0.834543    0.069772    0.008845    0.703669    
#> 424: 0.745117    0.995452    3.463378    0.834349    0.069782    0.008843    0.703702    
#> 425: 0.745028    0.995529    3.463315    0.834601    0.069757    0.008849    0.703747    
#> 426: 0.745060    0.995649    3.463267    0.834939    0.069742    0.008848    0.703781    
#> 427: 0.744938    0.995675    3.463207    0.835265    0.069751    0.008844    0.703735    
#> 428: 0.744676    0.995709    3.463175    0.834781    0.069709    0.008842    0.703732    
#> 429: 0.744630    0.995749    3.463172    0.834739    0.069714    0.008837    0.703693    
#> 430: 0.744603    0.995768    3.463184    0.834165    0.069689    0.008836    0.703708    
#> 431: 0.744410    0.995712    3.463139    0.833523    0.069679    0.008823    0.703629    
#> 432: 0.744441    0.995823    3.463122    0.833854    0.069699    0.008813    0.703602    
#> 433: 0.744561    0.995939    3.463141    0.833815    0.069670    0.008810    0.703581    
#> 434: 0.744225    0.995922    3.463142    0.833207    0.069680    0.008800    0.703539    
#> 435: 0.744035    0.996011    3.463113    0.832990    0.069725    0.008788    0.703444    
#> 436: 0.744071    0.996019    3.463096    0.833273    0.069778    0.008782    0.703414    
#> 437: 0.744013    0.996060    3.463049    0.833184    0.069790    0.008775    0.703492    
#> 438: 0.743911    0.996236    3.462989    0.833692    0.069843    0.008763    0.703516    
#> 439: 0.743634    0.996467    3.462897    0.833490    0.069854    0.008755    0.703465    
#> 440: 0.743449    0.996623    3.462872    0.832827    0.069865    0.008746    0.703414    
#> 441: 0.743575    0.996617    3.462870    0.832859    0.069863    0.008743    0.703382    
#> 442: 0.743497    0.996695    3.462891    0.832442    0.069906    0.008730    0.703359    
#> 443: 0.743519    0.996837    3.462852    0.832716    0.069939    0.008716    0.703383    
#> 444: 0.743413    0.996923    3.462789    0.832987    0.069958    0.008709    0.703390    
#> 445: 0.743368    0.997023    3.462668    0.833813    0.069967    0.008704    0.703497    
#> 446: 0.743473    0.997102    3.462581    0.834626    0.069961    0.008695    0.703530    
#> 447: 0.743707    0.997180    3.462581    0.835062    0.069952    0.008699    0.703552    
#> 448: 0.743591    0.997191    3.462615    0.834460    0.069923    0.008707    0.703559    
#> 449: 0.743414    0.997176    3.462719    0.833571    0.069911    0.008721    0.703576    
#> 450: 0.743238    0.997154    3.462749    0.832737    0.069886    0.008740    0.703584    
#> 451: 0.743156    0.997120    3.462757    0.832374    0.069872    0.008747    0.703569    
#> 452: 0.742919    0.997141    3.462709    0.831550    0.069889    0.008746    0.703527    
#> 453: 0.742697    0.997204    3.462658    0.831165    0.069907    0.008741    0.703484    
#> 454: 0.742507    0.997320    3.462624    0.830793    0.069893    0.008736    0.703386    
#> 455: 0.742414    0.997307    3.462592    0.830751    0.069895    0.008731    0.703288    
#> 456: 0.742535    0.997265    3.462557    0.831405    0.069829    0.008732    0.703318    
#> 457: 0.742670    0.997275    3.462581    0.832434    0.069812    0.008732    0.703273    
#> 458: 0.742946    0.997341    3.462615    0.833459    0.069816    0.008730    0.703264    
#> 459: 0.742720    0.997405    3.462627    0.833237    0.069814    0.008734    0.703276    
#> 460: 0.742352    0.997443    3.462574    0.832579    0.069771    0.008739    0.703277    
#> 461: 0.742123    0.997515    3.462528    0.831846    0.069774    0.008748    0.703275    
#> 462: 0.742021    0.997583    3.462523    0.831654    0.069761    0.008759    0.703248    
#> 463: 0.742148    0.997678    3.462545    0.831930    0.069727    0.008769    0.703253    
#> 464: 0.742306    0.997666    3.462604    0.831629    0.069683    0.008785    0.703198    
#> 465: 0.742461    0.997531    3.462637    0.831321    0.069659    0.008792    0.703223    
#> 466: 0.742551    0.997478    3.462622    0.830917    0.069614    0.008795    0.703274    
#> 467: 0.742393    0.997460    3.462643    0.830237    0.069620    0.008799    0.703256    
#> 468: 0.742426    0.997454    3.462658    0.830036    0.069568    0.008802    0.703335    
#> 469: 0.742523    0.997581    3.462664    0.830001    0.069520    0.008800    0.703378    
#> 470: 0.742542    0.997623    3.462668    0.830099    0.069527    0.008797    0.703398    
#> 471: 0.742464    0.997593    3.462643    0.830066    0.069505    0.008791    0.703459    
#> 472: 0.742480    0.997634    3.462679    0.830143    0.069491    0.008785    0.703517    
#> 473: 0.742351    0.997586    3.462699    0.829457    0.069468    0.008781    0.703542    
#> 474: 0.742307    0.997536    3.462711    0.829058    0.069483    0.008781    0.703583    
#> 475: 0.742446    0.997582    3.462721    0.829026    0.069506    0.008785    0.703547    
#> 476: 0.742726    0.997568    3.462706    0.829654    0.069519    0.008782    0.703589    
#> 477: 0.742767    0.997608    3.462727    0.829374    0.069522    0.008787    0.703543    
#> 478: 0.742686    0.997561    3.462755    0.829022    0.069453    0.008793    0.703578    
#> 479: 0.742934    0.997594    3.462794    0.829334    0.069419    0.008796    0.703607    
#> 480: 0.743021    0.997562    3.462845    0.829334    0.069431    0.008802    0.703566    
#> 481: 0.743088    0.997547    3.462848    0.829224    0.069413    0.008798    0.703515    
#> 482: 0.743223    0.997550    3.462829    0.829608    0.069399    0.008801    0.703488    
#> 483: 0.743233    0.997509    3.462777    0.830328    0.069429    0.008798    0.703485    
#> 484: 0.743212    0.997438    3.462727    0.830766    0.069439    0.008794    0.703451    
#> 485: 0.743132    0.997506    3.462702    0.831043    0.069451    0.008792    0.703463    
#> 486: 0.742986    0.997576    3.462684    0.831022    0.069455    0.008783    0.703459    
#> 487: 0.743001    0.997654    3.462701    0.831109    0.069496    0.008774    0.703446    
#> 488: 0.742861    0.997707    3.462686    0.831144    0.069468    0.008767    0.703407    
#> 489: 0.742920    0.997707    3.462654    0.831558    0.069472    0.008765    0.703415    
#> 490: 0.743047    0.997791    3.462629    0.832174    0.069476    0.008761    0.703431    
#> 491: 0.742899    0.997946    3.462604    0.832209    0.069500    0.008759    0.703413    
#> 492: 0.742601    0.998057    3.462552    0.831881    0.069510    0.008759    0.703454    
#> 493: 0.742318    0.998118    3.462488    0.831601    0.069485    0.008769    0.703455    
#> 494: 0.742217    0.998247    3.462405    0.831394    0.069520    0.008770    0.703418    
#> 495: 0.742430    0.998356    3.462367    0.832297    0.069506    0.008774    0.703356    
#> 496: 0.742446    0.998434    3.462307    0.832235    0.069492    0.008771    0.703399    
#> 497: 0.742314    0.998427    3.462259    0.832356    0.069473    0.008771    0.703423    
#> 498: 0.742240    0.998425    3.462199    0.832254    0.069459    0.008769    0.703408    
#> 499: 0.742301    0.998520    3.462167    0.832526    0.069492    0.008764    0.703408    
#> 500: 0.742383    0.998457    3.462142    0.832941    0.069525    0.008759    0.703382    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.282499    0.962464    3.434977    0.392401    0.072721    0.016800    1.606219    
#> 002: 0.257563    0.931725    3.452959    0.372781    0.069085    0.015960    1.130611    
#> 003: 0.356060    0.849849    3.465358    0.354142    0.065631    0.015162    0.900314    
#> 004: 0.319736    0.863618    3.448167    0.336435    0.069482    0.014404    0.830101    
#> 005: 0.389685    0.867425    3.436822    0.362482    0.086572    0.013684    0.755903    
#> 006: 0.359580    0.899969    3.428932    0.344358    0.086284    0.013000    0.727663    
#> 007: 0.324192    0.907631    3.417964    0.332139    0.104745    0.012350    0.717875    
#> 008: 0.316653    0.905574    3.403486    0.386015    0.099508    0.014362    0.716047    
#> 009: 0.327535    0.902195    3.413206    0.400458    0.094532    0.015776    0.723273    
#> 010: 0.283923    0.898471    3.406875    0.380435    0.089806    0.014987    0.748864    
#> 011: 0.340322    0.911064    3.410305    0.361413    0.085315    0.014965    0.748403    
#> 012: 0.343379    0.900340    3.404132    0.364473    0.081050    0.014592    0.722457    
#> 013: 0.265265    0.900423    3.393961    0.346250    0.076997    0.016772    0.742384    
#> 014: 0.324153    0.898354    3.411765    0.361998    0.073147    0.019888    0.726238    
#> 015: 0.347164    0.900349    3.422003    0.343898    0.073474    0.018894    0.722606    
#> 016: 0.367488    0.917514    3.434496    0.367516    0.069800    0.021678    0.732124    
#> 017: 0.353690    0.913498    3.434158    0.349140    0.068601    0.020594    0.713856    
#> 018: 0.344637    0.916347    3.411171    0.331683    0.071490    0.019565    0.741763    
#> 019: 0.320938    0.923845    3.410126    0.315099    0.087488    0.018586    0.731126    
#> 020: 0.333656    0.913205    3.419510    0.365824    0.083114    0.018269    0.725691    
#> 021: 0.339660    0.900919    3.435240    0.347533    0.078958    0.017565    0.717360    
#> 022: 0.375062    0.902110    3.433481    0.399856    0.075010    0.017457    0.709032    
#> 023: 0.454008    0.891089    3.449438    0.426299    0.074198    0.019266    0.748725    
#> 024: 0.423891    0.911564    3.434441    0.426426    0.079302    0.018302    0.716794    
#> 025: 0.359738    0.893872    3.428807    0.405105    0.075337    0.017387    0.720963    
#> 026: 0.365515    0.931227    3.414038    0.384849    0.075488    0.016518    0.701729    
#> 027: 0.332497    0.944662    3.411054    0.375213    0.071714    0.015692    0.734954    
#> 028: 0.328352    0.927089    3.403339    0.412169    0.084465    0.014907    0.711938    
#> 029: 0.340314    0.921441    3.393479    0.425384    0.080375    0.014490    0.742240    
#> 030: 0.340321    0.930819    3.398771    0.404115    0.081958    0.015959    0.718147    
#> 031: 0.320941    0.904395    3.408937    0.435569    0.089229    0.015161    0.721640    
#> 032: 0.309777    0.912219    3.400768    0.435599    0.107476    0.014403    0.717626    
#> 033: 0.312878    0.929423    3.399924    0.423832    0.105666    0.013683    0.726607    
#> 034: 0.375640    0.935757    3.407748    0.462302    0.107685    0.012999    0.720557    
#> 035: 0.307549    0.909988    3.401499    0.439187    0.109121    0.012349    0.704596    
#> 036: 0.309662    0.925836    3.399548    0.417228    0.103665    0.011732    0.734794    
#> 037: 0.313187    0.936740    3.400543    0.396367    0.098481    0.011145    0.743191    
#> 038: 0.315052    0.932286    3.396930    0.376548    0.093557    0.010588    0.738179    
#> 039: 0.310371    0.926507    3.407172    0.357721    0.088879    0.010338    0.743296    
#> 040: 0.283438    0.957032    3.401093    0.339835    0.093187    0.009821    0.752602    
#> 041: 0.262292    0.926366    3.395171    0.322843    0.107456    0.009330    0.734283    
#> 042: 0.274747    0.920517    3.390433    0.313870    0.102083    0.008864    0.725274    
#> 043: 0.238591    0.939694    3.382716    0.306410    0.102797    0.008421    0.741626    
#> 044: 0.243086    0.936465    3.386697    0.291090    0.097658    0.008000    0.757522    
#> 045: 0.244302    0.965615    3.380587    0.291547    0.099274    0.007600    0.752486    
#> 046: 0.263224    0.942232    3.393064    0.276970    0.094310    0.007220    0.747768    
#> 047: 0.257760    0.964664    3.385639    0.263121    0.091233    0.006859    0.735851    
#> 048: 0.280988    0.946725    3.389490    0.249965    0.086810    0.006850    0.749269    
#> 049: 0.270554    0.949484    3.394992    0.246538    0.093250    0.006508    0.727787    
#> 050: 0.355405    0.909793    3.408157    0.314572    0.098391    0.009344    0.743525    
#> 051: 0.311214    0.919185    3.408514    0.298843    0.093472    0.011987    0.741208    
#> 052: 0.337846    0.929418    3.417887    0.295155    0.088798    0.011804    0.731553    
#> 053: 0.359665    0.916429    3.416807    0.295638    0.090605    0.011214    0.741712    
#> 054: 0.297475    0.903714    3.419942    0.280856    0.094544    0.015358    0.747090    
#> 055: 0.296002    0.919514    3.418002    0.271404    0.100863    0.014590    0.746752    
#> 056: 0.318772    0.892823    3.422201    0.341984    0.095819    0.013861    0.746105    
#> 057: 0.358045    0.884110    3.431640    0.356812    0.094645    0.013168    0.735813    
#> 058: 0.334435    0.884997    3.423374    0.338971    0.089913    0.012509    0.763412    
#> 059: 0.323870    0.849126    3.428008    0.322023    0.085417    0.012120    0.766783    
#> 060: 0.359104    0.863299    3.438890    0.305921    0.081146    0.015820    0.748428    
#> 061: 0.431400    0.884545    3.451471    0.333223    0.078712    0.018983    0.748642    
#> 062: 0.359896    0.918185    3.438478    0.344508    0.081935    0.022590    0.760463    
#> 063: 0.395751    0.881807    3.437001    0.327282    0.077839    0.021460    0.761048    
#> 064: 0.365194    0.900541    3.440142    0.310918    0.082436    0.020387    0.757915    
#> 065: 0.395930    0.891067    3.427895    0.324303    0.085323    0.021310    0.735019    
#> 066: 0.363187    0.890190    3.436173    0.351375    0.081057    0.021680    0.707434    
#> 067: 0.363644    0.875335    3.431247    0.381096    0.077004    0.020814    0.716347    
#> 068: 0.331354    0.904262    3.433190    0.373198    0.073154    0.019773    0.717435    
#> 069: 0.356694    0.926902    3.418322    0.408378    0.069496    0.018784    0.734781    
#> 070: 0.375842    0.913203    3.425804    0.387959    0.088469    0.017979    0.714190    
#> 071: 0.348829    0.929415    3.407629    0.371678    0.084046    0.017080    0.719296    
#> 072: 0.299396    0.898497    3.412025    0.366220    0.079843    0.016226    0.707400    
#> 073: 0.327888    0.918320    3.423364    0.357675    0.081282    0.015415    0.724386    
#> 074: 0.323155    0.897510    3.421825    0.339791    0.090221    0.015815    0.709184    
#> 075: 0.333564    0.902410    3.434951    0.322802    0.091455    0.016721    0.723587    
#> 076: 0.360792    0.927169    3.430630    0.353117    0.086882    0.015885    0.741609    
#> 077: 0.395381    0.896324    3.424734    0.342772    0.096379    0.015091    0.747069    
#> 078: 0.391523    0.911973    3.433798    0.368509    0.099628    0.014779    0.716147    
#> 079: 0.363492    0.911087    3.431864    0.350084    0.094646    0.017062    0.742750    
#> 080: 0.355354    0.912102    3.426702    0.332942    0.094451    0.016209    0.743072    
#> 081: 0.318112    0.923675    3.407552    0.316504    0.089729    0.015398    0.730552    
#> 082: 0.316344    0.919440    3.413211    0.362461    0.088467    0.014628    0.750573    
#> 083: 0.321568    0.961986    3.411617    0.356917    0.084044    0.013897    0.724685    
#> 084: 0.364001    0.929508    3.419768    0.390130    0.091278    0.013202    0.717323    
#> 085: 0.350944    0.909293    3.429823    0.370623    0.104525    0.012542    0.718916    
#> 086: 0.356035    0.906288    3.430059    0.352092    0.099299    0.011915    0.713376    
#> 087: 0.308251    0.907183    3.411090    0.334487    0.094334    0.011976    0.716367    
#> 088: 0.303472    0.911455    3.417039    0.337161    0.089617    0.011839    0.717961    
#> 089: 0.314533    0.919561    3.404727    0.320303    0.085137    0.014747    0.720656    
#> 090: 0.295412    0.921257    3.412852    0.304288    0.099638    0.014571    0.734758    
#> 091: 0.317817    0.901246    3.400574    0.348878    0.094656    0.013843    0.743579    
#> 092: 0.294212    0.935758    3.396570    0.331434    0.089923    0.013151    0.737071    
#> 093: 0.279605    0.929007    3.392107    0.340727    0.096869    0.012493    0.740043    
#> 094: 0.295394    0.942856    3.395441    0.323691    0.093024    0.013857    0.743970    
#> 095: 0.315247    0.950796    3.409863    0.322562    0.088373    0.014266    0.737282    
#> 096: 0.300454    0.930536    3.409866    0.374796    0.083954    0.015233    0.701383    
#> 097: 0.309910    0.955391    3.408933    0.356056    0.082325    0.015837    0.695864    
#> 098: 0.339128    0.966046    3.409704    0.381776    0.078209    0.015045    0.730884    
#> 099: 0.296419    0.930268    3.396117    0.362688    0.074298    0.014292    0.734610    
#> 100: 0.255055    0.952925    3.396504    0.344553    0.082402    0.014165    0.718582    
#> 101: 0.276419    0.908884    3.390247    0.345642    0.078282    0.015513    0.715115    
#> 102: 0.292865    0.924286    3.392863    0.335658    0.087199    0.014737    0.716245    
#> 103: 0.303219    0.927619    3.403391    0.344539    0.087701    0.014000    0.715910    
#> 104: 0.276309    0.932101    3.409354    0.350240    0.088400    0.013300    0.731135    
#> 105: 0.302102    0.917151    3.404302    0.382445    0.096410    0.014367    0.715522    
#> 106: 0.328920    0.919195    3.407250    0.363323    0.091589    0.013648    0.723926    
#> 107: 0.331420    0.928482    3.405182    0.345157    0.087010    0.013064    0.726666    
#> 108: 0.340430    0.919400    3.406341    0.327899    0.089732    0.012411    0.743715    
#> 109: 0.313209    0.915435    3.418608    0.311504    0.085246    0.011790    0.725762    
#> 110: 0.284540    0.919371    3.396847    0.295929    0.080983    0.011201    0.736633    
#> 111: 0.304695    0.924034    3.405531    0.335552    0.078166    0.010641    0.724787    
#> 112: 0.287356    0.918254    3.392510    0.318774    0.092179    0.010219    0.742847    
#> 113: 0.289945    0.947821    3.392161    0.360492    0.097478    0.009708    0.709666    
#> 114: 0.295466    0.935117    3.394053    0.342467    0.092604    0.009223    0.716067    
#> 115: 0.316874    0.915435    3.398544    0.325344    0.091897    0.010098    0.732341    
#> 116: 0.338165    0.930869    3.409711    0.309077    0.092052    0.009593    0.730513    
#> 117: 0.311353    0.926932    3.407484    0.320769    0.087449    0.009113    0.740128    
#> 118: 0.346264    0.900278    3.411436    0.401603    0.083077    0.009354    0.733920    
#> 119: 0.328130    0.923794    3.401439    0.381523    0.078923    0.011019    0.723204    
#> 120: 0.272248    0.937457    3.396742    0.362447    0.084354    0.012426    0.726749    
#> 121: 0.297957    0.960505    3.398773    0.344324    0.080208    0.014259    0.728123    
#> 122: 0.312968    0.938469    3.401191    0.348086    0.076198    0.013546    0.720949    
#> 123: 0.359121    0.965545    3.401035    0.420921    0.080404    0.012868    0.718031    
#> 124: 0.321513    0.975744    3.397558    0.399875    0.076384    0.013027    0.742898    
#> 125: 0.347332    0.962487    3.391050    0.411483    0.072565    0.012943    0.729650    
#> 126: 0.293327    0.954353    3.384413    0.390909    0.073811    0.014406    0.747909    
#> 127: 0.315252    0.932137    3.385019    0.371364    0.085242    0.013686    0.751230    
#> 128: 0.289800    0.913827    3.416855    0.387205    0.080980    0.016419    0.746157    
#> 129: 0.296168    0.932729    3.414301    0.367845    0.076931    0.017241    0.751757    
#> 130: 0.362552    0.907400    3.420607    0.370044    0.073084    0.024722    0.708586    
#> 131: 0.326933    0.909840    3.405101    0.395953    0.069430    0.023486    0.731823    
#> 132: 0.270987    0.919383    3.388666    0.376155    0.081582    0.022311    0.714514    
#> 133: 0.239088    0.931473    3.392888    0.357347    0.083901    0.021196    0.720740    
#> 134: 0.261803    0.928553    3.396089    0.386384    0.079798    0.020136    0.733797    
#> 135: 0.288538    0.912785    3.402703    0.367065    0.081544    0.019129    0.714136    
#> 136: 0.304254    0.901978    3.409244    0.348712    0.077466    0.018173    0.712618    
#> 137: 0.342462    0.901985    3.421568    0.371515    0.073593    0.019552    0.724510    
#> 138: 0.313533    0.905458    3.411856    0.352939    0.078477    0.018575    0.712729    
#> 139: 0.293277    0.916109    3.419977    0.335292    0.074553    0.020013    0.716244    
#> 140: 0.336675    0.926765    3.419178    0.364708    0.070826    0.020104    0.723977    
#> 141: 0.329474    0.916909    3.429932    0.350686    0.074649    0.019099    0.727135    
#> 142: 0.349790    0.902579    3.433854    0.341945    0.070916    0.018976    0.741901    
#> 143: 0.319889    0.920630    3.422536    0.324848    0.067371    0.018658    0.733318    
#> 144: 0.358151    0.920106    3.438206    0.309583    0.070859    0.017725    0.715764    
#> 145: 0.325176    0.925196    3.415497    0.325443    0.078271    0.016838    0.720317    
#> 146: 0.306036    0.916168    3.426055    0.322329    0.085937    0.015997    0.725316    
#> 147: 0.294696    0.910068    3.407596    0.345791    0.081640    0.015197    0.701187    
#> 148: 0.298229    0.922805    3.413918    0.375254    0.086919    0.014437    0.700374    
#> 149: 0.303081    0.904017    3.416019    0.356491    0.100061    0.013715    0.720382    
#> 150: 0.346807    0.904234    3.413448    0.338666    0.110180    0.013029    0.727096    
#> 151: 0.284965    0.934767    3.406222    0.321733    0.104671    0.012378    0.732762    
#> 152: 0.279640    0.931097    3.409511    0.332028    0.089040    0.011326    0.731267    
#> 153: 0.303788    0.924252    3.421202    0.294825    0.110214    0.009095    0.733334    
#> 154: 0.331281    0.918434    3.416583    0.326667    0.099546    0.009976    0.740336    
#> 155: 0.309809    0.911618    3.413355    0.284217    0.107349    0.008006    0.740323    
#> 156: 0.334692    0.912401    3.422056    0.292847    0.107865    0.006730    0.744481    
#> 157: 0.343915    0.902076    3.434471    0.324788    0.128400    0.005834    0.743005    
#> 158: 0.395903    0.910539    3.434855    0.271148    0.113846    0.005619    0.729201    
#> 159: 0.331657    0.920738    3.432735    0.301526    0.092373    0.004983    0.736303    
#> 160: 0.357176    0.885540    3.430003    0.308294    0.097600    0.005571    0.756440    
#> 161: 0.359756    0.909533    3.420080    0.323602    0.115999    0.005723    0.729896    
#> 162: 0.325287    0.929279    3.404573    0.306332    0.111888    0.004651    0.749518    
#> 163: 0.358006    0.908187    3.410468    0.318392    0.122417    0.005157    0.731835    
#> 164: 0.331311    0.906783    3.414485    0.313320    0.119714    0.006416    0.732187    
#> 165: 0.348777    0.887952    3.425257    0.322744    0.115917    0.007193    0.720519    
#> 166: 0.373391    0.935194    3.419882    0.323876    0.108987    0.007053    0.741872    
#> 167: 0.339977    0.930379    3.426128    0.323866    0.112627    0.004894    0.750756    
#> 168: 0.378340    0.915093    3.433006    0.286221    0.100485    0.004933    0.744307    
#> 169: 0.367151    0.938735    3.425958    0.274241    0.106479    0.005811    0.760012    
#> 170: 0.376353    0.920429    3.421128    0.324344    0.098166    0.006233    0.741642    
#> 171: 0.324627    0.907784    3.419665    0.272729    0.118156    0.005228    0.733441    
#> 172: 0.321424    0.924641    3.416057    0.308680    0.110794    0.003749    0.744866    
#> 173: 0.349416    0.923768    3.417750    0.299326    0.099680    0.004192    0.739482    
#> 174: 0.351025    0.909676    3.422994    0.256835    0.117541    0.004196    0.728068    
#> 175: 0.301779    0.911445    3.412387    0.249060    0.126520    0.003658    0.749387    
#> 176: 0.346007    0.921773    3.416760    0.292394    0.131705    0.003292    0.755036    
#> 177: 0.348750    0.900433    3.428467    0.264394    0.121070    0.003480    0.748029    
#> 178: 0.372060    0.891538    3.428813    0.268525    0.112519    0.003669    0.759312    
#> 179: 0.391133    0.919611    3.427349    0.269980    0.104515    0.004211    0.781110    
#> 180: 0.329293    0.904999    3.423978    0.251309    0.098894    0.004332    0.764923    
#> 181: 0.348117    0.906213    3.411299    0.302949    0.098402    0.003665    0.745020    
#> 182: 0.283751    0.927236    3.402068    0.330602    0.106074    0.003458    0.758088    
#> 183: 0.287775    0.945310    3.396752    0.248627    0.101550    0.003396    0.746907    
#> 184: 0.300107    0.922637    3.400934    0.297137    0.097838    0.004150    0.736681    
#> 185: 0.269240    0.929338    3.401492    0.241334    0.095616    0.003603    0.756846    
#> 186: 0.294831    0.953073    3.406932    0.232618    0.110152    0.003557    0.754973    
#> 187: 0.302149    0.911864    3.413100    0.264721    0.109193    0.003988    0.749525    
#> 188: 0.275314    0.952163    3.397947    0.263433    0.122328    0.004895    0.765656    
#> 189: 0.327309    0.941904    3.403114    0.290952    0.114161    0.005070    0.745514    
#> 190: 0.293555    0.941854    3.405737    0.295805    0.105286    0.004057    0.728974    
#> 191: 0.298650    0.936066    3.398480    0.336371    0.087172    0.004363    0.721949    
#> 192: 0.282946    0.946455    3.404225    0.385276    0.102023    0.004569    0.725857    
#> 193: 0.342022    0.952698    3.408062    0.371087    0.087785    0.004184    0.739473    
#> 194: 0.283488    0.934646    3.398540    0.321200    0.105223    0.005491    0.736712    
#> 195: 0.258287    0.927211    3.387572    0.280259    0.119300    0.005451    0.756984    
#> 196: 0.260345    0.945587    3.391887    0.253833    0.111359    0.004763    0.760434    
#> 197: 0.267013    0.926374    3.410284    0.236215    0.110286    0.004884    0.757970    
#> 198: 0.318923    0.894783    3.400784    0.250394    0.104204    0.005264    0.747377    
#> 199: 0.306386    0.907655    3.406118    0.279836    0.121309    0.004632    0.753951    
#> 200: 0.282908    0.925782    3.402085    0.242845    0.111183    0.003479    0.763781    
#> 201: 0.286428    0.921669    3.402442    0.257919    0.105301    0.003749    0.749684    
#> 202: 0.293430    0.926971    3.403820    0.282991    0.106079    0.003889    0.748397    
#> 203: 0.296542    0.920306    3.403299    0.285996    0.103935    0.004053    0.749673    
#> 204: 0.298555    0.915608    3.403338    0.291018    0.107297    0.004229    0.752345    
#> 205: 0.296348    0.919050    3.404156    0.291995    0.108008    0.004338    0.754082    
#> 206: 0.297179    0.923957    3.404670    0.299262    0.110351    0.004210    0.757613    
#> 207: 0.298773    0.925065    3.402953    0.298759    0.110799    0.004041    0.757628    
#> 208: 0.297597    0.927488    3.402050    0.295071    0.108311    0.003945    0.757450    
#> 209: 0.300236    0.925189    3.402297    0.291379    0.107920    0.003852    0.756343    
#> 210: 0.302790    0.921878    3.402951    0.289907    0.109277    0.003774    0.754900    
#> 211: 0.305240    0.921406    3.403356    0.289203    0.109282    0.003711    0.752779    
#> 212: 0.308652    0.919641    3.404066    0.287771    0.109884    0.003707    0.751408    
#> 213: 0.311879    0.918629    3.404135    0.292499    0.108611    0.003854    0.750759    
#> 214: 0.313576    0.919530    3.403872    0.295122    0.108059    0.003997    0.749592    
#> 215: 0.315235    0.919707    3.404067    0.297234    0.107970    0.004070    0.749590    
#> 216: 0.317288    0.919400    3.404141    0.298363    0.109271    0.004075    0.749942    
#> 217: 0.317205    0.920266    3.404215    0.296723    0.109632    0.004091    0.749217    
#> 218: 0.317250    0.920546    3.403843    0.294797    0.109997    0.004135    0.748496    
#> 219: 0.315749    0.919865    3.402941    0.293193    0.110282    0.004128    0.748979    
#> 220: 0.312736    0.920868    3.402584    0.294720    0.110461    0.004112    0.749791    
#> 221: 0.311609    0.921517    3.402456    0.295342    0.110426    0.004086    0.749604    
#> 222: 0.312114    0.921125    3.402451    0.296484    0.111245    0.004110    0.749938    
#> 223: 0.313356    0.920697    3.402891    0.297419    0.111816    0.004121    0.749266    
#> 224: 0.315095    0.920790    3.403599    0.297523    0.112254    0.004116    0.749436    
#> 225: 0.317091    0.918497    3.404487    0.298372    0.112410    0.004147    0.748862    
#> 226: 0.318889    0.917198    3.404814    0.297520    0.112115    0.004139    0.749675    
#> 227: 0.319382    0.916342    3.405174    0.297886    0.112499    0.004133    0.750761    
#> 228: 0.318742    0.917057    3.405201    0.296543    0.113083    0.004153    0.750508    
#> 229: 0.317923    0.916673    3.405051    0.296038    0.112981    0.004144    0.750708    
#> 230: 0.317559    0.916046    3.404751    0.295345    0.112339    0.004120    0.751338    
#> 231: 0.317291    0.916337    3.404910    0.294813    0.111902    0.004078    0.751707    
#> 232: 0.316976    0.916569    3.405164    0.294638    0.111476    0.004063    0.751784    
#> 233: 0.316545    0.915894    3.405345    0.293822    0.111508    0.004086    0.752097    
#> 234: 0.315329    0.916388    3.405367    0.293592    0.111623    0.004129    0.752067    
#> 235: 0.314973    0.916564    3.405319    0.291846    0.111712    0.004124    0.752452    
#> 236: 0.315842    0.916757    3.405284    0.292182    0.112175    0.004100    0.752749    
#> 237: 0.316503    0.917003    3.405216    0.292409    0.112706    0.004108    0.752913    
#> 238: 0.316925    0.917353    3.405223    0.292645    0.113269    0.004109    0.753198    
#> 239: 0.316211    0.917541    3.405161    0.291892    0.113474    0.004122    0.752899    
#> 240: 0.316373    0.917046    3.405392    0.291574    0.113428    0.004114    0.752570    
#> 241: 0.316637    0.916101    3.405671    0.290856    0.113322    0.004123    0.752532    
#> 242: 0.316403    0.915514    3.405603    0.289459    0.113704    0.004109    0.752917    
#> 243: 0.315696    0.915722    3.405626    0.287982    0.113620    0.004084    0.753575    
#> 244: 0.315003    0.915686    3.405738    0.288921    0.113422    0.004072    0.753361    
#> 245: 0.315072    0.915095    3.405802    0.287986    0.113317    0.004072    0.753649    
#> 246: 0.315450    0.914630    3.406107    0.287241    0.113035    0.004115    0.753309    
#> 247: 0.315361    0.914252    3.406459    0.286730    0.113065    0.004163    0.753418    
#> 248: 0.315255    0.914844    3.406611    0.287132    0.113200    0.004168    0.753318    
#> 249: 0.315142    0.914996    3.406715    0.287962    0.113338    0.004157    0.753165    
#> 250: 0.315998    0.915358    3.406816    0.288181    0.113346    0.004158    0.753148    
#> 251: 0.316759    0.915790    3.407034    0.289382    0.113470    0.004158    0.753050    
#> 252: 0.317450    0.915915    3.407319    0.290034    0.114035    0.004161    0.752991    
#> 253: 0.317727    0.916365    3.407413    0.290335    0.114336    0.004173    0.753094    
#> 254: 0.317557    0.916837    3.407548    0.291299    0.114669    0.004165    0.753021    
#> 255: 0.317872    0.917178    3.407804    0.292289    0.114724    0.004185    0.752963    
#> 256: 0.318930    0.917098    3.407903    0.292821    0.114824    0.004196    0.752769    
#> 257: 0.318670    0.916673    3.407975    0.292214    0.114645    0.004216    0.752665    
#> 258: 0.318639    0.916443    3.407935    0.292277    0.114601    0.004211    0.752661    
#> 259: 0.318672    0.916531    3.407940    0.293572    0.114643    0.004200    0.752540    
#> 260: 0.318846    0.916737    3.408067    0.293092    0.114790    0.004178    0.752564    
#> 261: 0.319412    0.916479    3.408223    0.292797    0.114774    0.004176    0.752458    
#> 262: 0.319979    0.916475    3.408395    0.291903    0.114907    0.004177    0.752224    
#> 263: 0.319588    0.916848    3.408375    0.291494    0.115059    0.004193    0.752099    
#> 264: 0.318924    0.916787    3.408233    0.290831    0.115208    0.004195    0.752113    
#> 265: 0.318512    0.917009    3.408034    0.290954    0.115696    0.004208    0.752104    
#> 266: 0.318310    0.916941    3.407970    0.290353    0.115704    0.004224    0.752003    
#> 267: 0.317713    0.917200    3.407850    0.290421    0.115709    0.004240    0.751848    
#> 268: 0.317188    0.917284    3.407539    0.290612    0.115580    0.004232    0.751803    
#> 269: 0.317126    0.917475    3.407292    0.291189    0.115312    0.004239    0.751938    
#> 270: 0.317288    0.917579    3.407099    0.291716    0.115222    0.004232    0.751802    
#> 271: 0.317386    0.917745    3.406953    0.291842    0.115253    0.004224    0.752321    
#> 272: 0.317513    0.917712    3.406808    0.291776    0.115161    0.004210    0.752848    
#> 273: 0.317315    0.917805    3.406726    0.292241    0.115235    0.004196    0.753383    
#> 274: 0.317119    0.918009    3.406775    0.291219    0.115203    0.004193    0.753611    
#> 275: 0.316873    0.918449    3.406592    0.290809    0.115094    0.004198    0.753765    
#> 276: 0.316540    0.918559    3.406666    0.290666    0.115051    0.004211    0.753818    
#> 277: 0.316340    0.918683    3.406811    0.290801    0.115201    0.004217    0.753781    
#> 278: 0.316113    0.918522    3.406907    0.290763    0.115391    0.004225    0.753658    
#> 279: 0.315843    0.918459    3.406938    0.290445    0.115504    0.004228    0.753683    
#> 280: 0.315793    0.918415    3.407027    0.290343    0.115355    0.004243    0.753508    
#> 281: 0.315787    0.918530    3.407154    0.289887    0.115197    0.004261    0.753280    
#> 282: 0.315759    0.918630    3.407268    0.289242    0.115049    0.004275    0.753109    
#> 283: 0.316182    0.918682    3.407391    0.289294    0.114745    0.004287    0.753178    
#> 284: 0.316212    0.918490    3.407459    0.289278    0.114545    0.004290    0.753081    
#> 285: 0.316222    0.918574    3.407361    0.289136    0.114278    0.004292    0.753112    
#> 286: 0.316408    0.918851    3.407221    0.289647    0.114083    0.004298    0.752964    
#> 287: 0.315825    0.919212    3.407087    0.289976    0.113919    0.004300    0.752824    
#> 288: 0.315740    0.919254    3.407006    0.289619    0.113673    0.004308    0.752752    
#> 289: 0.315977    0.919232    3.406994    0.289515    0.113486    0.004316    0.752579    
#> 290: 0.315802    0.919198    3.406920    0.289249    0.113305    0.004318    0.752608    
#> 291: 0.315979    0.919130    3.407026    0.289494    0.113318    0.004327    0.752215    
#> 292: 0.315955    0.919236    3.406971    0.290011    0.113136    0.004333    0.752172    
#> 293: 0.315727    0.919275    3.406918    0.290306    0.113114    0.004346    0.751900    
#> 294: 0.315570    0.919460    3.406818    0.291055    0.113023    0.004352    0.751675    
#> 295: 0.315746    0.919290    3.406750    0.291356    0.112861    0.004343    0.751599    
#> 296: 0.315628    0.919167    3.406765    0.291176    0.112788    0.004352    0.751683    
#> 297: 0.315745    0.919288    3.406749    0.291612    0.112589    0.004355    0.751786    
#> 298: 0.315891    0.919275    3.406770    0.292131    0.112391    0.004350    0.751735    
#> 299: 0.315881    0.919383    3.406791    0.292510    0.112237    0.004349    0.751322    
#> 300: 0.316249    0.919206    3.406925    0.292603    0.112198    0.004350    0.751077    
#> 301: 0.316426    0.919012    3.406949    0.292687    0.112272    0.004352    0.750910    
#> 302: 0.316448    0.918992    3.406955    0.292733    0.112339    0.004346    0.750835    
#> 303: 0.316373    0.919051    3.406994    0.292462    0.112475    0.004340    0.750824    
#> 304: 0.316671    0.919160    3.406978    0.292803    0.112418    0.004341    0.750744    
#> 305: 0.316668    0.918913    3.407021    0.293109    0.112399    0.004344    0.750562    
#> 306: 0.316354    0.918845    3.406957    0.292984    0.112479    0.004350    0.750361    
#> 307: 0.316102    0.918989    3.406904    0.292701    0.112672    0.004339    0.750344    
#> 308: 0.315947    0.918828    3.406898    0.293044    0.112899    0.004345    0.750247    
#> 309: 0.316176    0.918600    3.406900    0.293241    0.112824    0.004354    0.750136    
#> 310: 0.316404    0.918665    3.406819    0.293336    0.112708    0.004355    0.750115    
#> 311: 0.316183    0.918818    3.406703    0.293435    0.112606    0.004354    0.750031    
#> 312: 0.315816    0.918867    3.406569    0.293351    0.112587    0.004359    0.750004    
#> 313: 0.315429    0.918851    3.406419    0.293181    0.112538    0.004378    0.749904    
#> 314: 0.314918    0.919037    3.406274    0.293170    0.112482    0.004384    0.749819    
#> 315: 0.314543    0.919168    3.406203    0.292714    0.112414    0.004396    0.749753    
#> 316: 0.314535    0.919336    3.406152    0.292517    0.112346    0.004400    0.749787    
#> 317: 0.314506    0.919345    3.406158    0.292856    0.112226    0.004397    0.749852    
#> 318: 0.314617    0.919373    3.406137    0.293086    0.112217    0.004400    0.749743    
#> 319: 0.314918    0.919263    3.406217    0.293371    0.112213    0.004397    0.749689    
#> 320: 0.314852    0.918997    3.406320    0.292661    0.112143    0.004405    0.749883    
#> 321: 0.315096    0.918894    3.406303    0.292622    0.112017    0.004404    0.749994    
#> 322: 0.315514    0.918722    3.406302    0.292663    0.111916    0.004408    0.749900    
#> 323: 0.315240    0.918653    3.406325    0.292526    0.111850    0.004411    0.749989    
#> 324: 0.315238    0.918630    3.406413    0.292483    0.111940    0.004422    0.749858    
#> 325: 0.315076    0.918825    3.406362    0.292345    0.111859    0.004426    0.749720    
#> 326: 0.314908    0.918660    3.406320    0.292228    0.111856    0.004433    0.749586    
#> 327: 0.315148    0.918803    3.406262    0.292755    0.112056    0.004438    0.749513    
#> 328: 0.315286    0.919082    3.406154    0.293267    0.111934    0.004446    0.749312    
#> 329: 0.315375    0.919187    3.406135    0.293453    0.111918    0.004451    0.749192    
#> 330: 0.315262    0.919262    3.406090    0.294119    0.111889    0.004449    0.749062    
#> 331: 0.315427    0.919475    3.406035    0.294640    0.111878    0.004446    0.748965    
#> 332: 0.315481    0.919560    3.406009    0.295149    0.111800    0.004445    0.748952    
#> 333: 0.315324    0.919611    3.405951    0.295107    0.111699    0.004453    0.748949    
#> 334: 0.315183    0.919636    3.405884    0.295312    0.111668    0.004459    0.748828    
#> 335: 0.314816    0.919856    3.405764    0.295251    0.111662    0.004457    0.748757    
#> 336: 0.314274    0.920191    3.405629    0.295314    0.111670    0.004450    0.748800    
#> 337: 0.313965    0.920716    3.405507    0.295360    0.111632    0.004447    0.748877    
#> 338: 0.313885    0.920725    3.405500    0.295593    0.111438    0.004451    0.748904    
#> 339: 0.313621    0.920884    3.405475    0.295680    0.111374    0.004454    0.748731    
#> 340: 0.313514    0.920893    3.405473    0.295373    0.111392    0.004463    0.748674    
#> 341: 0.313469    0.920876    3.405510    0.295140    0.111302    0.004467    0.748717    
#> 342: 0.313325    0.920839    3.405492    0.295003    0.111408    0.004465    0.748602    
#> 343: 0.313050    0.920921    3.405506    0.294969    0.111393    0.004456    0.748494    
#> 344: 0.312992    0.920850    3.405529    0.294587    0.111299    0.004453    0.748511    
#> 345: 0.313057    0.920712    3.405584    0.294736    0.111211    0.004452    0.748471    
#> 346: 0.313126    0.920629    3.405589    0.295024    0.111080    0.004468    0.748270    
#> 347: 0.313192    0.920561    3.405541    0.294656    0.110897    0.004482    0.748289    
#> 348: 0.313152    0.920595    3.405522    0.294577    0.110886    0.004495    0.748204    
#> 349: 0.313060    0.920438    3.405471    0.294500    0.110815    0.004501    0.748183    
#> 350: 0.312716    0.920392    3.405392    0.294445    0.110768    0.004511    0.748215    
#> 351: 0.312491    0.920545    3.405330    0.294409    0.110784    0.004519    0.748233    
#> 352: 0.312194    0.920807    3.405322    0.294232    0.110862    0.004541    0.748255    
#> 353: 0.312429    0.920899    3.405341    0.294242    0.110749    0.004542    0.748167    
#> 354: 0.312713    0.921031    3.405316    0.294292    0.110672    0.004554    0.748110    
#> 355: 0.313219    0.920927    3.405317    0.294613    0.110590    0.004565    0.748006    
#> 356: 0.313338    0.920785    3.405384    0.294770    0.110535    0.004564    0.747905    
#> 357: 0.313507    0.920861    3.405371    0.294974    0.110493    0.004570    0.747865    
#> 358: 0.313571    0.920872    3.405410    0.295127    0.110364    0.004574    0.747886    
#> 359: 0.313416    0.921030    3.405405    0.295138    0.110262    0.004577    0.748007    
#> 360: 0.313299    0.920993    3.405361    0.295417    0.110096    0.004581    0.748068    
#> 361: 0.313196    0.921019    3.405341    0.295601    0.109930    0.004579    0.748143    
#> 362: 0.313265    0.920972    3.405308    0.295898    0.109775    0.004577    0.748175    
#> 363: 0.313235    0.921007    3.405256    0.295859    0.109837    0.004581    0.747997    
#> 364: 0.313170    0.921062    3.405181    0.295734    0.109905    0.004579    0.748018    
#> 365: 0.312886    0.921018    3.405163    0.295648    0.109955    0.004571    0.747983    
#> 366: 0.312892    0.921006    3.405145    0.295574    0.109963    0.004563    0.748104    
#> 367: 0.313136    0.920979    3.405166    0.295975    0.110068    0.004555    0.748102    
#> 368: 0.313385    0.921017    3.405184    0.295963    0.109927    0.004554    0.748056    
#> 369: 0.313371    0.921015    3.405207    0.295727    0.109843    0.004555    0.748063    
#> 370: 0.313212    0.921057    3.405239    0.295426    0.109768    0.004559    0.748071    
#> 371: 0.313093    0.921117    3.405185    0.295204    0.109725    0.004558    0.748012    
#> 372: 0.312968    0.921214    3.405144    0.295021    0.109768    0.004554    0.748049    
#> 373: 0.312904    0.921370    3.405105    0.295194    0.109763    0.004556    0.747982    
#> 374: 0.313023    0.921388    3.405063    0.295726    0.109798    0.004559    0.747895    
#> 375: 0.313112    0.921480    3.405055    0.296532    0.109853    0.004556    0.747826    
#> 376: 0.313208    0.921499    3.405078    0.296587    0.109918    0.004551    0.747768    
#> 377: 0.313217    0.921522    3.405093    0.296621    0.109889    0.004545    0.747783    
#> 378: 0.313234    0.921562    3.405086    0.296559    0.109850    0.004544    0.747797    
#> 379: 0.313189    0.921424    3.405102    0.296128    0.109802    0.004553    0.747764    
#> 380: 0.313112    0.921383    3.405110    0.295889    0.109702    0.004565    0.747703    
#> 381: 0.312970    0.921448    3.405081    0.295935    0.109843    0.004563    0.747618    
#> 382: 0.312995    0.921451    3.405079    0.295874    0.109856    0.004569    0.747476    
#> 383: 0.313146    0.921452    3.405076    0.295898    0.109843    0.004565    0.747486    
#> 384: 0.313163    0.921362    3.405114    0.295902    0.109823    0.004562    0.747496    
#> 385: 0.313331    0.921311    3.405159    0.295829    0.109768    0.004563    0.747435    
#> 386: 0.313463    0.921479    3.405188    0.295843    0.109659    0.004559    0.747560    
#> 387: 0.313619    0.921540    3.405238    0.295766    0.109608    0.004564    0.747564    
#> 388: 0.313688    0.921632    3.405259    0.295793    0.109610    0.004565    0.747554    
#> 389: 0.313561    0.921569    3.405251    0.295535    0.109521    0.004563    0.747591    
#> 390: 0.313472    0.921633    3.405217    0.295400    0.109493    0.004558    0.747632    
#> 391: 0.313444    0.921583    3.405187    0.295289    0.109436    0.004553    0.747577    
#> 392: 0.313526    0.921609    3.405207    0.295573    0.109428    0.004557    0.747517    
#> 393: 0.313538    0.921604    3.405199    0.295629    0.109465    0.004564    0.747407    
#> 394: 0.313535    0.921618    3.405172    0.295802    0.109484    0.004566    0.747305    
#> 395: 0.313720    0.921705    3.405141    0.296072    0.109430    0.004566    0.747327    
#> 396: 0.313879    0.921761    3.405159    0.296109    0.109400    0.004565    0.747199    
#> 397: 0.313811    0.921698    3.405199    0.296009    0.109281    0.004567    0.747162    
#> 398: 0.313950    0.921603    3.405259    0.295942    0.109304    0.004567    0.747213    
#> 399: 0.314119    0.921578    3.405336    0.296024    0.109284    0.004567    0.747231    
#> 400: 0.314239    0.921625    3.405395    0.295950    0.109428    0.004567    0.747182    
#> 401: 0.314271    0.921716    3.405408    0.295846    0.109518    0.004568    0.747258    
#> 402: 0.314265    0.921786    3.405420    0.295672    0.109469    0.004567    0.747339    
#> 403: 0.314394    0.921814    3.405431    0.295748    0.109420    0.004564    0.747354    
#> 404: 0.314486    0.921903    3.405395    0.295856    0.109312    0.004566    0.747299    
#> 405: 0.314524    0.921919    3.405435    0.296104    0.109321    0.004570    0.747338    
#> 406: 0.314608    0.921953    3.405458    0.296122    0.109253    0.004573    0.747421    
#> 407: 0.314563    0.921993    3.405481    0.296215    0.109285    0.004568    0.747426    
#> 408: 0.314607    0.922051    3.405463    0.296107    0.109369    0.004562    0.747505    
#> 409: 0.314536    0.922031    3.405405    0.296050    0.109404    0.004561    0.747459    
#> 410: 0.314345    0.922097    3.405317    0.296064    0.109438    0.004559    0.747550    
#> 411: 0.314294    0.921910    3.405293    0.296038    0.109461    0.004560    0.747676    
#> 412: 0.314378    0.921906    3.405292    0.295985    0.109505    0.004558    0.747686    
#> 413: 0.314430    0.921872    3.405295    0.296151    0.109519    0.004558    0.747681    
#> 414: 0.314318    0.921868    3.405328    0.296136    0.109552    0.004558    0.747679    
#> 415: 0.314433    0.921803    3.405350    0.296248    0.109552    0.004562    0.747660    
#> 416: 0.314601    0.921802    3.405409    0.296258    0.109605    0.004565    0.747578    
#> 417: 0.314535    0.921805    3.405420    0.296136    0.109606    0.004563    0.747602    
#> 418: 0.314291    0.921796    3.405425    0.296010    0.109687    0.004561    0.747665    
#> 419: 0.314295    0.921893    3.405416    0.295905    0.109681    0.004563    0.747738    
#> 420: 0.314498    0.921942    3.405436    0.295985    0.109691    0.004562    0.747690    
#> 421: 0.314482    0.921941    3.405470    0.295936    0.109750    0.004557    0.747674    
#> 422: 0.314616    0.921885    3.405479    0.295862    0.109741    0.004555    0.747720    
#> 423: 0.314738    0.921757    3.405493    0.295979    0.109649    0.004552    0.747763    
#> 424: 0.314744    0.921745    3.405472    0.296185    0.109557    0.004550    0.747782    
#> 425: 0.314978    0.921826    3.405466    0.296231    0.109492    0.004553    0.747915    
#> 426: 0.315228    0.921931    3.405493    0.296301    0.109478    0.004546    0.747975    
#> 427: 0.315120    0.921920    3.405460    0.296150    0.109473    0.004549    0.747860    
#> 428: 0.314951    0.921975    3.405399    0.296230    0.109394    0.004549    0.747911    
#> 429: 0.314895    0.922078    3.405385    0.296080    0.109414    0.004545    0.747955    
#> 430: 0.314747    0.922162    3.405336    0.295898    0.109362    0.004546    0.747953    
#> 431: 0.314577    0.922153    3.405274    0.295990    0.109340    0.004544    0.747929    
#> 432: 0.314372    0.922237    3.405241    0.296026    0.109311    0.004544    0.747845    
#> 433: 0.314463    0.922316    3.405257    0.295957    0.109237    0.004543    0.747924    
#> 434: 0.314347    0.922265    3.405294    0.295742    0.109185    0.004541    0.747977    
#> 435: 0.314383    0.922226    3.405304    0.295662    0.109180    0.004540    0.747941    
#> 436: 0.314383    0.922141    3.405308    0.295554    0.109210    0.004534    0.748003    
#> 437: 0.314434    0.922008    3.405302    0.295788    0.109183    0.004534    0.747960    
#> 438: 0.314343    0.922142    3.405293    0.295838    0.109251    0.004533    0.747850    
#> 439: 0.314354    0.922296    3.405274    0.296068    0.109309    0.004534    0.747829    
#> 440: 0.314262    0.922370    3.405273    0.296143    0.109334    0.004532    0.747838    
#> 441: 0.314136    0.922332    3.405274    0.296269    0.109311    0.004534    0.747783    
#> 442: 0.314009    0.922330    3.405275    0.296342    0.109343    0.004532    0.747736    
#> 443: 0.313963    0.922418    3.405245    0.296366    0.109461    0.004533    0.747700    
#> 444: 0.313865    0.922539    3.405191    0.296576    0.109570    0.004537    0.747660    
#> 445: 0.313718    0.922596    3.405104    0.296805    0.109582    0.004543    0.747578    
#> 446: 0.313385    0.922686    3.404999    0.296993    0.109547    0.004545    0.747568    
#> 447: 0.313430    0.922728    3.404936    0.297264    0.109546    0.004548    0.747535    
#> 448: 0.313432    0.922719    3.404915    0.297529    0.109515    0.004551    0.747458    
#> 449: 0.313568    0.922786    3.404976    0.297650    0.109520    0.004550    0.747472    
#> 450: 0.313651    0.922739    3.405001    0.297607    0.109522    0.004551    0.747509    
#> 451: 0.313667    0.922727    3.404995    0.297640    0.109542    0.004554    0.747520    
#> 452: 0.313512    0.922817    3.404955    0.297719    0.109578    0.004552    0.747483    
#> 453: 0.313414    0.922849    3.404923    0.297700    0.109551    0.004549    0.747409    
#> 454: 0.313434    0.923038    3.404852    0.298111    0.109552    0.004545    0.747368    
#> 455: 0.313384    0.923117    3.404799    0.298280    0.109574    0.004545    0.747308    
#> 456: 0.313220    0.923090    3.404750    0.298287    0.109497    0.004544    0.747360    
#> 457: 0.313125    0.923165    3.404749    0.298387    0.109458    0.004546    0.747278    
#> 458: 0.313099    0.923272    3.404818    0.298296    0.109476    0.004553    0.747208    
#> 459: 0.313218    0.923352    3.404887    0.298261    0.109509    0.004559    0.747183    
#> 460: 0.313189    0.923374    3.404901    0.298168    0.109455    0.004568    0.747145    
#> 461: 0.313273    0.923395    3.404953    0.298070    0.109443    0.004577    0.747095    
#> 462: 0.313289    0.923397    3.405000    0.298066    0.109418    0.004577    0.746976    
#> 463: 0.313398    0.923396    3.405044    0.298123    0.109421    0.004575    0.746851    
#> 464: 0.313532    0.923380    3.405076    0.298374    0.109445    0.004573    0.746741    
#> 465: 0.313677    0.923167    3.405096    0.298742    0.109461    0.004568    0.746731    
#> 466: 0.313800    0.923115    3.405084    0.298677    0.109419    0.004563    0.746760    
#> 467: 0.313750    0.923075    3.405066    0.298977    0.109362    0.004565    0.746686    
#> 468: 0.313864    0.923009    3.405078    0.299217    0.109349    0.004571    0.746633    
#> 469: 0.314014    0.923034    3.405104    0.299132    0.109317    0.004579    0.746628    
#> 470: 0.314083    0.923012    3.405115    0.299161    0.109285    0.004589    0.746553    
#> 471: 0.313995    0.922970    3.405110    0.299089    0.109198    0.004597    0.746492    
#> 472: 0.313995    0.922977    3.405134    0.299168    0.109139    0.004608    0.746346    
#> 473: 0.313914    0.922948    3.405161    0.299171    0.109070    0.004614    0.746262    
#> 474: 0.313853    0.922969    3.405172    0.299101    0.109053    0.004622    0.746285    
#> 475: 0.313878    0.923062    3.405135    0.299112    0.109039    0.004624    0.746209    
#> 476: 0.313868    0.923019    3.405109    0.299090    0.109072    0.004624    0.746274    
#> 477: 0.313829    0.923012    3.405120    0.299251    0.109070    0.004629    0.746172    
#> 478: 0.313720    0.922953    3.405126    0.299354    0.109041    0.004632    0.746171    
#> 479: 0.313699    0.923014    3.405143    0.299426    0.109006    0.004639    0.746095    
#> 480: 0.313722    0.922945    3.405176    0.299423    0.109012    0.004638    0.746079    
#> 481: 0.313746    0.922916    3.405207    0.299468    0.109012    0.004636    0.746075    
#> 482: 0.313875    0.922900    3.405218    0.299631    0.109017    0.004633    0.746142    
#> 483: 0.313868    0.922913    3.405206    0.299671    0.109015    0.004629    0.746117    
#> 484: 0.313816    0.922826    3.405187    0.299668    0.108977    0.004627    0.746084    
#> 485: 0.313759    0.922858    3.405185    0.299694    0.108975    0.004628    0.746067    
#> 486: 0.313689    0.922864    3.405184    0.299612    0.108984    0.004628    0.745979    
#> 487: 0.313809    0.922819    3.405219    0.299732    0.109007    0.004630    0.745910    
#> 488: 0.313718    0.922825    3.405259    0.299610    0.108986    0.004632    0.745957    
#> 489: 0.313841    0.922799    3.405301    0.299398    0.108974    0.004636    0.745999    
#> 490: 0.313951    0.922724    3.405369    0.299135    0.109018    0.004638    0.746044    
#> 491: 0.313970    0.922797    3.405432    0.299054    0.109010    0.004635    0.746079    
#> 492: 0.314031    0.922804    3.405470    0.299096    0.108993    0.004634    0.746175    
#> 493: 0.314088    0.922777    3.405505    0.299181    0.109026    0.004636    0.746201    
#> 494: 0.314152    0.922797    3.405505    0.299134    0.109009    0.004633    0.746178    
#> 495: 0.314203    0.922845    3.405517    0.299117    0.108993    0.004631    0.746155    
#> 496: 0.314330    0.922936    3.405517    0.299051    0.108942    0.004628    0.746176    
#> 497: 0.314337    0.922958    3.405513    0.298973    0.108959    0.004625    0.746227    
#> 498: 0.314354    0.922931    3.405503    0.298934    0.108955    0.004622    0.746226    
#> 499: 0.314373    0.922941    3.405490    0.298801    0.108954    0.004622    0.746181    
#> 500: 0.314313    0.922916    3.405465    0.298663    0.108928    0.004619    0.746139    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.313290    0.974409    3.449318    0.392401    0.094660    0.016800    1.708176    
#> 002: 0.442573    1.038112    3.461556    0.372781    0.089927    0.015960    1.179878    
#> 003: 0.664498    1.033033    3.489711    0.354142    0.085431    0.015162    0.946703    
#> 004: 0.686754    1.086597    3.488387    0.336435    0.081159    0.014404    0.801382    
#> 005: 0.782283    1.088942    3.481189    0.319613    0.077101    0.013684    0.739632    
#> 006: 0.746467    1.089088    3.493185    0.309322    0.073246    0.013000    0.686953    
#> 007: 0.739050    1.089625    3.493551    0.350418    0.069584    0.012350    0.710537    
#> 008: 0.740521    1.096828    3.480661    0.417348    0.066105    0.011732    0.704965    
#> 009: 0.728218    1.086624    3.473379    0.497195    0.062799    0.011146    0.690625    
#> 010: 0.685304    1.089820    3.471295    0.472336    0.059659    0.010588    0.707458    
#> 011: 0.803102    1.077485    3.490533    0.498092    0.056676    0.010059    0.684218    
#> 012: 0.806340    1.067451    3.492765    0.492652    0.053843    0.009556    0.660508    
#> 013: 0.751931    1.061125    3.487615    0.541144    0.051150    0.009078    0.684118    
#> 014: 0.861972    1.054112    3.509654    0.604516    0.048593    0.008624    0.681022    
#> 015: 0.816120    1.072620    3.516365    0.574290    0.046163    0.008193    0.668658    
#> 016: 0.841560    1.087014    3.522237    0.545576    0.043855    0.007783    0.672771    
#> 017: 0.833348    1.060110    3.520002    0.549037    0.041662    0.007810    0.663271    
#> 018: 0.825033    1.064352    3.503981    0.547315    0.039579    0.009547    0.655772    
#> 019: 0.786538    1.065134    3.502132    0.519949    0.037600    0.009070    0.663347    
#> 020: 0.803894    1.079622    3.497000    0.528168    0.035720    0.008616    0.660048    
#> 021: 0.796761    1.063697    3.502021    0.501759    0.039360    0.008950    0.652619    
#> 022: 0.810896    1.075370    3.508539    0.554392    0.037392    0.008503    0.643702    
#> 023: 0.893935    1.076729    3.517682    0.532717    0.043598    0.009307    0.663390    
#> 024: 0.874799    1.096142    3.514777    0.560339    0.041418    0.009635    0.655548    
#> 025: 0.822218    1.090419    3.501816    0.606398    0.039347    0.009153    0.656254    
#> 026: 0.817147    1.092648    3.498699    0.576078    0.037380    0.008695    0.668510    
#> 027: 0.797532    1.103657    3.498311    0.547274    0.035511    0.008261    0.675911    
#> 028: 0.869046    1.091153    3.505578    0.549101    0.033735    0.009501    0.673026    
#> 029: 0.879555    1.089349    3.493732    0.607880    0.035494    0.010120    0.692689    
#> 030: 0.814372    1.109604    3.493704    0.577486    0.033720    0.010253    0.685065    
#> 031: 0.822204    1.094754    3.501720    0.626815    0.032034    0.012372    0.660615    
#> 032: 0.806568    1.103808    3.493071    0.644229    0.030432    0.012705    0.658370    
#> 033: 0.784612    1.122788    3.481049    0.656431    0.028910    0.012070    0.643899    
#> 034: 0.835245    1.105564    3.494546    0.629386    0.027465    0.011466    0.647379    
#> 035: 0.820531    1.090561    3.495200    0.597917    0.026092    0.010893    0.640812    
#> 036: 0.828318    1.079262    3.504830    0.571968    0.027962    0.010986    0.659146    
#> 037: 0.808103    1.074973    3.508106    0.543370    0.029621    0.010555    0.677063    
#> 038: 0.843917    1.064742    3.507459    0.516201    0.028140    0.010027    0.684223    
#> 039: 0.867303    1.065262    3.524891    0.502810    0.032233    0.009526    0.664914    
#> 040: 0.813170    1.074799    3.514947    0.488513    0.030621    0.009050    0.660031    
#> 041: 0.788659    1.072262    3.505598    0.464087    0.029291    0.008597    0.661706    
#> 042: 0.800559    1.061307    3.499981    0.471277    0.033955    0.008167    0.662640    
#> 043: 0.791008    1.090040    3.493026    0.538158    0.032460    0.009053    0.650694    
#> 044: 0.822888    1.096452    3.502032    0.511250    0.032826    0.008600    0.657900    
#> 045: 0.806544    1.098115    3.497914    0.485688    0.031847    0.008600    0.668478    
#> 046: 0.805241    1.076639    3.508888    0.461403    0.031868    0.008170    0.654402    
#> 047: 0.785585    1.085809    3.497993    0.451306    0.030281    0.008910    0.661763    
#> 048: 0.760897    1.078725    3.496169    0.438164    0.038250    0.008465    0.662202    
#> 049: 0.807018    1.068051    3.508897    0.546383    0.036337    0.008041    0.669205    
#> 050: 0.857811    1.059762    3.502540    0.564094    0.044438    0.008695    0.667287    
#> 051: 0.787379    1.074126    3.500426    0.535889    0.045813    0.008261    0.681114    
#> 052: 0.825344    1.083283    3.510085    0.509095    0.043522    0.007848    0.665288    
#> 053: 0.851202    1.068573    3.514088    0.536901    0.041346    0.007455    0.655308    
#> 054: 0.768416    1.070518    3.505578    0.510056    0.039938    0.007515    0.664812    
#> 055: 0.769453    1.084722    3.497271    0.495253    0.037941    0.008935    0.662293    
#> 056: 0.838843    1.088426    3.502350    0.612224    0.036044    0.008489    0.671977    
#> 057: 0.814979    1.100100    3.501423    0.585737    0.037376    0.008818    0.676281    
#> 058: 0.831671    1.091842    3.486710    0.628828    0.042369    0.008699    0.668666    
#> 059: 0.799765    1.054641    3.510825    0.597387    0.044119    0.012005    0.671641    
#> 060: 0.836982    1.026959    3.518450    0.567517    0.041913    0.011405    0.692725    
#> 061: 0.861797    1.036109    3.526600    0.539142    0.039817    0.010835    0.690521    
#> 062: 0.866299    1.064814    3.523862    0.556692    0.038561    0.010293    0.705662    
#> 063: 0.903669    1.042091    3.527349    0.596017    0.036633    0.011823    0.701770    
#> 064: 0.868443    1.054335    3.532465    0.566216    0.035007    0.011232    0.689894    
#> 065: 0.870802    1.057572    3.508527    0.538747    0.043352    0.010671    0.682931    
#> 066: 0.838918    1.076344    3.505884    0.594097    0.041184    0.010137    0.648692    
#> 067: 0.829632    1.080907    3.497960    0.594790    0.039125    0.009630    0.652475    
#> 068: 0.781436    1.101376    3.494629    0.595578    0.037169    0.009149    0.670386    
#> 069: 0.849774    1.099873    3.489104    0.714547    0.035310    0.008873    0.671002    
#> 070: 0.842657    1.090909    3.498462    0.757833    0.033545    0.008816    0.657333    
#> 071: 0.810752    1.117311    3.479630    0.719941    0.032660    0.008990    0.661279    
#> 072: 0.752543    1.094398    3.485699    0.683944    0.032562    0.008540    0.656712    
#> 073: 0.773913    1.100871    3.501734    0.649747    0.030933    0.010876    0.658856    
#> 074: 0.803278    1.089806    3.497626    0.617260    0.032366    0.010503    0.653144    
#> 075: 0.797345    1.087989    3.506583    0.586397    0.036884    0.009978    0.663137    
#> 076: 0.844919    1.104295    3.518352    0.557077    0.043314    0.009479    0.658690    
#> 077: 0.893906    1.078178    3.515608    0.596865    0.041148    0.009005    0.662309    
#> 078: 0.869013    1.075968    3.520938    0.683934    0.039091    0.008555    0.655350    
#> 079: 0.842200    1.102800    3.517696    0.649738    0.039214    0.008328    0.667879    
#> 080: 0.835732    1.072275    3.510751    0.617251    0.037254    0.008334    0.660220    
#> 081: 0.847092    1.069017    3.507830    0.586388    0.035391    0.010042    0.654356    
#> 082: 0.829279    1.062655    3.505107    0.568049    0.033621    0.009540    0.670139    
#> 083: 0.813990    1.076495    3.501615    0.632322    0.031940    0.009063    0.669324    
#> 084: 0.825573    1.085316    3.502146    0.600706    0.032589    0.008610    0.674544    
#> 085: 0.842120    1.091356    3.513216    0.570671    0.030960    0.008179    0.670837    
#> 086: 0.879983    1.083762    3.514530    0.588130    0.033214    0.007770    0.676177    
#> 087: 0.842822    1.080132    3.503922    0.596317    0.031972    0.007382    0.656120    
#> 088: 0.768964    1.071338    3.500575    0.566501    0.030373    0.007604    0.672901    
#> 089: 0.803981    1.091921    3.488956    0.563684    0.031615    0.007224    0.677285    
#> 090: 0.766275    1.088129    3.491534    0.535500    0.035096    0.008144    0.686158    
#> 091: 0.774478    1.074965    3.473942    0.547405    0.033419    0.007737    0.683126    
#> 092: 0.780862    1.095531    3.487106    0.520454    0.037012    0.009056    0.663534    
#> 093: 0.754512    1.081702    3.493074    0.494431    0.035239    0.010011    0.663399    
#> 094: 0.790469    1.074815    3.489559    0.469710    0.038046    0.009510    0.676630    
#> 095: 0.795291    1.075654    3.507381    0.464021    0.037691    0.009034    0.678659    
#> 096: 0.739588    1.066506    3.494000    0.475866    0.035806    0.008592    0.667216    
#> 097: 0.796208    1.090332    3.493038    0.466782    0.038391    0.008163    0.650601    
#> 098: 0.795471    1.107351    3.498734    0.465073    0.040330    0.007821    0.667021    
#> 099: 0.768943    1.077375    3.488043    0.477533    0.038314    0.008013    0.666841    
#> 100: 0.809639    1.083759    3.488271    0.515431    0.036398    0.007612    0.661532    
#> 101: 0.785794    1.069634    3.476393    0.535232    0.038625    0.007231    0.673597    
#> 102: 0.765697    1.063809    3.475751    0.508471    0.036694    0.006870    0.692657    
#> 103: 0.823865    1.076108    3.495561    0.565413    0.034859    0.006526    0.673668    
#> 104: 0.822562    1.075840    3.504168    0.537142    0.033116    0.006200    0.677961    
#> 105: 0.807414    1.074029    3.500844    0.510285    0.036340    0.005890    0.669602    
#> 106: 0.819310    1.071813    3.504591    0.484771    0.043079    0.005596    0.652090    
#> 107: 0.865770    1.073488    3.517222    0.504209    0.053698    0.006307    0.664185    
#> 108: 0.813514    1.076839    3.508577    0.513591    0.051013    0.006169    0.683614    
#> 109: 0.836678    1.060260    3.517141    0.534357    0.052055    0.005942    0.671882    
#> 110: 0.816135    1.077883    3.495234    0.529447    0.051051    0.005908    0.671655    
#> 111: 0.817925    1.074031    3.498023    0.554321    0.048499    0.005612    0.672045    
#> 112: 0.807094    1.069300    3.490920    0.526605    0.046074    0.005332    0.676520    
#> 113: 0.835007    1.098788    3.491893    0.612911    0.043770    0.005065    0.646990    
#> 114: 0.856506    1.097559    3.491657    0.621839    0.043591    0.004812    0.669041    
#> 115: 0.796650    1.071848    3.494353    0.590747    0.054290    0.004928    0.662986    
#> 116: 0.814915    1.075108    3.504123    0.561210    0.051576    0.004839    0.669389    
#> 117: 0.824309    1.074107    3.509518    0.533150    0.048997    0.004947    0.659446    
#> 118: 0.844453    1.065921    3.513056    0.602827    0.046547    0.005221    0.682764    
#> 119: 0.847546    1.069949    3.510341    0.597438    0.045704    0.005102    0.684338    
#> 120: 0.789217    1.065176    3.508495    0.567566    0.043419    0.006015    0.667216    
#> 121: 0.837453    1.074936    3.505550    0.539187    0.046849    0.005714    0.676640    
#> 122: 0.843146    1.054311    3.515603    0.512228    0.044507    0.005428    0.674242    
#> 123: 0.856461    1.082480    3.514817    0.528678    0.042281    0.005157    0.672255    
#> 124: 0.847165    1.101993    3.505228    0.502244    0.042336    0.005149    0.673117    
#> 125: 0.843907    1.102346    3.496946    0.508725    0.040219    0.005526    0.665055    
#> 126: 0.812205    1.114067    3.492291    0.483288    0.042960    0.005250    0.682197    
#> 127: 0.821852    1.095115    3.493620    0.460441    0.043144    0.004987    0.679586    
#> 128: 0.784785    1.087009    3.504731    0.505199    0.040987    0.005569    0.675324    
#> 129: 0.797730    1.074528    3.506646    0.495451    0.038937    0.006056    0.682992    
#> 130: 0.822205    1.088406    3.502447    0.470679    0.036991    0.005769    0.666351    
#> 131: 0.839931    1.070267    3.504383    0.469673    0.039540    0.006846    0.664242    
#> 132: 0.795216    1.076592    3.491981    0.446189    0.037563    0.007157    0.667374    
#> 133: 0.817189    1.072882    3.492698    0.576293    0.041180    0.006799    0.657808    
#> 134: 0.835067    1.079916    3.496140    0.614934    0.039470    0.010468    0.656579    
#> 135: 0.832107    1.075267    3.501712    0.608512    0.037496    0.011418    0.657651    
#> 136: 0.832059    1.078587    3.506342    0.578087    0.037233    0.010847    0.651185    
#> 137: 0.861453    1.073319    3.515515    0.549182    0.035372    0.010304    0.674846    
#> 138: 0.814739    1.071379    3.517633    0.521723    0.033603    0.010843    0.670988    
#> 139: 0.776603    1.077577    3.518007    0.495637    0.031923    0.010477    0.679256    
#> 140: 0.826648    1.092921    3.509707    0.544491    0.031855    0.009953    0.680049    
#> 141: 0.826283    1.067319    3.513836    0.517267    0.030262    0.009455    0.687271    
#> 142: 0.855987    1.051810    3.524041    0.523855    0.039034    0.009688    0.681450    
#> 143: 0.814405    1.062202    3.523801    0.499508    0.040601    0.009204    0.668122    
#> 144: 0.858789    1.055667    3.527214    0.517701    0.038571    0.008744    0.650288    
#> 145: 0.831010    1.067401    3.515208    0.491816    0.036642    0.008306    0.657748    
#> 146: 0.801130    1.081112    3.515270    0.467225    0.034996    0.008508    0.671835    
#> 147: 0.778998    1.062833    3.503890    0.513807    0.033246    0.008082    0.669520    
#> 148: 0.810898    1.087583    3.506909    0.639297    0.031584    0.007907    0.656205    
#> 149: 0.815223    1.073051    3.504297    0.607332    0.030004    0.009462    0.670045    
#> 150: 0.839808    1.071467    3.498919    0.576966    0.028504    0.010073    0.684524    
#> 151: 0.766761    1.099350    3.492426    0.548117    0.028819    0.009569    0.656860    
#> 152: 0.772621    1.094935    3.500335    0.538040    0.029851    0.006532    0.663585    
#> 153: 0.806685    1.100526    3.503118    0.491392    0.033014    0.009938    0.662232    
#> 154: 0.833905    1.103366    3.500633    0.565316    0.033913    0.010157    0.659703    
#> 155: 0.786601    1.084733    3.493600    0.452412    0.030409    0.010004    0.660680    
#> 156: 0.794014    1.084940    3.502887    0.427025    0.036620    0.008778    0.672742    
#> 157: 0.828371    1.098386    3.506197    0.511754    0.035859    0.009103    0.662461    
#> 158: 0.856305    1.087297    3.500504    0.537413    0.024880    0.008723    0.655873    
#> 159: 0.780248    1.097332    3.502189    0.550897    0.027681    0.007487    0.654873    
#> 160: 0.841306    1.059858    3.511434    0.531568    0.024910    0.009368    0.676069    
#> 161: 0.827999    1.066863    3.507481    0.517435    0.020246    0.010078    0.654336    
#> 162: 0.828773    1.087356    3.505210    0.503459    0.019460    0.010965    0.669512    
#> 163: 0.843551    1.071094    3.503532    0.529775    0.018534    0.011137    0.658627    
#> 164: 0.850385    1.080616    3.503930    0.595700    0.029286    0.010731    0.656243    
#> 165: 0.812769    1.080266    3.510996    0.516673    0.033471    0.009580    0.658611    
#> 166: 0.869380    1.105853    3.507858    0.495438    0.035587    0.008673    0.667432    
#> 167: 0.823586    1.108961    3.502369    0.514615    0.040769    0.007514    0.671450    
#> 168: 0.852087    1.093150    3.506591    0.488836    0.040732    0.007309    0.672510    
#> 169: 0.820897    1.097227    3.499615    0.465030    0.037744    0.007423    0.672989    
#> 170: 0.812450    1.082916    3.500947    0.491585    0.035975    0.006991    0.668970    
#> 171: 0.765250    1.095594    3.496282    0.413129    0.035155    0.006870    0.660995    
#> 172: 0.778968    1.115768    3.496957    0.450677    0.031749    0.007840    0.657200    
#> 173: 0.771847    1.108723    3.489774    0.413470    0.037813    0.006534    0.681487    
#> 174: 0.779917    1.090328    3.494774    0.424304    0.037377    0.005759    0.670634    
#> 175: 0.781433    1.100139    3.482493    0.455003    0.044383    0.006737    0.673196    
#> 176: 0.804637    1.125327    3.490355    0.471551    0.038013    0.005916    0.667827    
#> 177: 0.797130    1.099156    3.500803    0.427846    0.040362    0.004544    0.674413    
#> 178: 0.810877    1.090352    3.497540    0.476042    0.043162    0.004831    0.658305    
#> 179: 0.843297    1.116904    3.491221    0.451689    0.047467    0.006105    0.672654    
#> 180: 0.829003    1.093064    3.501514    0.500121    0.043817    0.005330    0.650836    
#> 181: 0.819966    1.073524    3.494301    0.497008    0.032656    0.004543    0.663422    
#> 182: 0.768105    1.086330    3.485286    0.456348    0.042264    0.004541    0.675624    
#> 183: 0.742472    1.101713    3.479904    0.435350    0.046101    0.004530    0.671267    
#> 184: 0.766359    1.073714    3.487462    0.488224    0.036489    0.004217    0.654683    
#> 185: 0.768797    1.102623    3.482849    0.457508    0.043785    0.004438    0.667746    
#> 186: 0.756388    1.125567    3.487099    0.393994    0.047761    0.005151    0.688534    
#> 187: 0.764886    1.074551    3.497258    0.423649    0.042652    0.005514    0.682482    
#> 188: 0.764574    1.101806    3.496082    0.389326    0.045725    0.004782    0.686770    
#> 189: 0.803014    1.123185    3.504216    0.454495    0.048747    0.004987    0.695588    
#> 190: 0.816825    1.098148    3.513340    0.449014    0.041499    0.004712    0.682096    
#> 191: 0.810388    1.094891    3.499429    0.466510    0.042254    0.004402    0.678478    
#> 192: 0.800688    1.096282    3.501522    0.570978    0.048781    0.004317    0.664957    
#> 193: 0.861611    1.103352    3.504248    0.544432    0.042577    0.005185    0.678697    
#> 194: 0.818527    1.101225    3.494594    0.506799    0.042049    0.005389    0.693404    
#> 195: 0.779228    1.104752    3.490850    0.483212    0.037832    0.004491    0.683984    
#> 196: 0.819474    1.085583    3.497256    0.520227    0.045198    0.004327    0.683576    
#> 197: 0.760536    1.094922    3.513280    0.416918    0.033656    0.004864    0.700137    
#> 198: 0.783136    1.084444    3.497126    0.406832    0.040442    0.004725    0.699607    
#> 199: 0.763121    1.082609    3.498246    0.433132    0.044323    0.003661    0.683260    
#> 200: 0.799216    1.098121    3.494547    0.499295    0.041079    0.004270    0.677168    
#> 201: 0.802881    1.087600    3.495170    0.490633    0.043285    0.004852    0.674362    
#> 202: 0.804633    1.087748    3.496338    0.495128    0.043296    0.004694    0.681968    
#> 203: 0.806189    1.085904    3.495442    0.477164    0.044022    0.004698    0.683544    
#> 204: 0.806298    1.080381    3.496451    0.482362    0.044288    0.004695    0.683431    
#> 205: 0.805845    1.083424    3.497815    0.476012    0.044582    0.004797    0.681662    
#> 206: 0.804208    1.085322    3.499445    0.469397    0.043671    0.005095    0.682163    
#> 207: 0.802643    1.085845    3.498359    0.468725    0.043477    0.005374    0.681251    
#> 208: 0.801728    1.086238    3.499025    0.467782    0.042589    0.005691    0.679636    
#> 209: 0.803770    1.084440    3.500017    0.469394    0.042250    0.006096    0.677394    
#> 210: 0.807195    1.082377    3.501405    0.472121    0.041336    0.006261    0.675570    
#> 211: 0.811328    1.082124    3.503174    0.467191    0.041034    0.006336    0.674825    
#> 212: 0.816194    1.080913    3.504521    0.465880    0.041181    0.006341    0.674022    
#> 213: 0.820175    1.077622    3.505132    0.471152    0.041845    0.006387    0.675369    
#> 214: 0.821099    1.076971    3.505446    0.468049    0.042588    0.006378    0.675624    
#> 215: 0.820804    1.077838    3.505631    0.467841    0.042721    0.006416    0.675439    
#> 216: 0.822806    1.076628    3.505732    0.466329    0.042591    0.006467    0.676191    
#> 217: 0.819526    1.076596    3.505283    0.464141    0.042382    0.006411    0.676431    
#> 218: 0.819155    1.077001    3.504433    0.467693    0.042236    0.006381    0.675827    
#> 219: 0.817485    1.076561    3.503754    0.467072    0.041692    0.006408    0.675757    
#> 220: 0.816733    1.077006    3.503360    0.473556    0.041558    0.006519    0.674449    
#> 221: 0.815456    1.077413    3.503034    0.474615    0.041211    0.006612    0.674085    
#> 222: 0.815447    1.077812    3.502681    0.476613    0.040684    0.006745    0.673882    
#> 223: 0.815328    1.078615    3.502133    0.476414    0.040113    0.006815    0.673050    
#> 224: 0.815539    1.079651    3.501994    0.476643    0.039905    0.006900    0.672128    
#> 225: 0.813709    1.079071    3.501894    0.476086    0.039482    0.006930    0.672787    
#> 226: 0.811505    1.077851    3.501496    0.475093    0.039434    0.006922    0.672739    
#> 227: 0.810710    1.077443    3.501467    0.474721    0.039558    0.006870    0.672890    
#> 228: 0.809095    1.077806    3.501029    0.475927    0.039535    0.006888    0.672976    
#> 229: 0.807591    1.077526    3.500697    0.476866    0.039529    0.006869    0.672421    
#> 230: 0.808454    1.077290    3.500682    0.478114    0.039522    0.006859    0.672011    
#> 231: 0.809244    1.077695    3.500847    0.481588    0.039545    0.006836    0.671986    
#> 232: 0.808821    1.077583    3.501217    0.483034    0.039516    0.006823    0.671892    
#> 233: 0.808006    1.077102    3.501321    0.482699    0.039414    0.006812    0.671761    
#> 234: 0.807362    1.077663    3.501465    0.482867    0.039329    0.006793    0.671611    
#> 235: 0.807123    1.077672    3.501361    0.481351    0.039315    0.006767    0.671342    
#> 236: 0.807006    1.077890    3.501273    0.482059    0.039336    0.006798    0.670851    
#> 237: 0.807794    1.077459    3.501483    0.481438    0.039461    0.006835    0.670887    
#> 238: 0.808216    1.077240    3.501667    0.480535    0.039524    0.006863    0.671267    
#> 239: 0.808021    1.077451    3.501724    0.481116    0.039546    0.006869    0.671212    
#> 240: 0.807752    1.077276    3.501739    0.481250    0.039567    0.006850    0.671022    
#> 241: 0.808086    1.076969    3.501971    0.481278    0.039513    0.006878    0.671125    
#> 242: 0.808820    1.076507    3.502082    0.481236    0.039760    0.006900    0.671262    
#> 243: 0.808788    1.076548    3.502120    0.481039    0.040081    0.006907    0.671630    
#> 244: 0.808060    1.076848    3.501944    0.483557    0.040142    0.006979    0.671926    
#> 245: 0.808183    1.076876    3.502003    0.483725    0.039971    0.006991    0.672496    
#> 246: 0.808111    1.076720    3.502111    0.484052    0.039750    0.007041    0.672683    
#> 247: 0.808595    1.076451    3.502268    0.483808    0.039614    0.007047    0.672409    
#> 248: 0.808715    1.076747    3.502277    0.484141    0.039443    0.007034    0.671859    
#> 249: 0.808379    1.077065    3.502268    0.485905    0.039222    0.007027    0.671802    
#> 250: 0.809277    1.077453    3.502282    0.486670    0.039207    0.007024    0.671620    
#> 251: 0.810065    1.077906    3.502439    0.487199    0.039180    0.007017    0.671723    
#> 252: 0.810300    1.077997    3.502781    0.486340    0.038965    0.007019    0.671721    
#> 253: 0.810459    1.078081    3.502863    0.486019    0.038809    0.007033    0.671936    
#> 254: 0.810404    1.078774    3.502978    0.484969    0.038772    0.007063    0.672209    
#> 255: 0.810697    1.078863    3.503181    0.485009    0.038671    0.007088    0.672497    
#> 256: 0.811119    1.078834    3.503066    0.485403    0.038589    0.007112    0.672524    
#> 257: 0.810680    1.078832    3.503000    0.486417    0.038614    0.007093    0.672329    
#> 258: 0.810022    1.078648    3.502930    0.485818    0.038668    0.007070    0.672520    
#> 259: 0.809823    1.078600    3.502893    0.487089    0.038641    0.007060    0.672673    
#> 260: 0.809704    1.078770    3.502936    0.486516    0.038533    0.007039    0.672717    
#> 261: 0.809431    1.078757    3.503001    0.485558    0.038499    0.007016    0.672567    
#> 262: 0.809583    1.078964    3.503090    0.484529    0.038432    0.006994    0.672771    
#> 263: 0.808855    1.079354    3.502995    0.484809    0.038397    0.006991    0.672963    
#> 264: 0.808167    1.079395    3.502907    0.485274    0.038279    0.006989    0.673411    
#> 265: 0.808194    1.079440    3.502926    0.484962    0.038252    0.006984    0.673807    
#> 266: 0.808394    1.079453    3.502980    0.483638    0.038172    0.007001    0.674068    
#> 267: 0.808006    1.079698    3.502994    0.483998    0.038223    0.007002    0.674188    
#> 268: 0.807840    1.079708    3.502779    0.484093    0.038210    0.006983    0.674189    
#> 269: 0.808471    1.079500    3.502768    0.485910    0.038194    0.006988    0.674126    
#> 270: 0.808413    1.079365    3.502563    0.486976    0.038106    0.006989    0.674036    
#> 271: 0.808604    1.079190    3.502370    0.487944    0.037999    0.006976    0.674123    
#> 272: 0.808599    1.079030    3.502204    0.489229    0.037960    0.006961    0.674229    
#> 273: 0.808001    1.079178    3.502126    0.489009    0.038134    0.006947    0.674255    
#> 274: 0.807263    1.079411    3.502057    0.487600    0.038151    0.006927    0.674358    
#> 275: 0.806886    1.079459    3.501921    0.486572    0.038151    0.006904    0.674164    
#> 276: 0.806565    1.079582    3.501983    0.486307    0.038097    0.006916    0.674028    
#> 277: 0.806220    1.079819    3.502080    0.487014    0.038085    0.006951    0.673902    
#> 278: 0.806006    1.079887    3.502105    0.487556    0.037984    0.006964    0.673893    
#> 279: 0.806246    1.079811    3.502155    0.487876    0.037837    0.006971    0.674041    
#> 280: 0.806099    1.080071    3.502236    0.487038    0.037813    0.006988    0.674107    
#> 281: 0.805845    1.080244    3.502372    0.485635    0.037778    0.006978    0.674398    
#> 282: 0.805454    1.080572    3.502356    0.484998    0.037813    0.006992    0.674587    
#> 283: 0.805434    1.080770    3.502416    0.485281    0.037849    0.007010    0.674716    
#> 284: 0.805327    1.080684    3.502482    0.485422    0.037786    0.007016    0.674471    
#> 285: 0.805577    1.080804    3.502314    0.486430    0.037760    0.007044    0.674303    
#> 286: 0.805631    1.081001    3.502242    0.486585    0.037803    0.007052    0.674438    
#> 287: 0.805621    1.081151    3.502109    0.487188    0.037815    0.007067    0.674471    
#> 288: 0.805852    1.081030    3.502096    0.486798    0.037809    0.007081    0.674483    
#> 289: 0.806303    1.080918    3.502162    0.486297    0.037818    0.007095    0.674553    
#> 290: 0.806301    1.080985    3.502178    0.485338    0.037926    0.007096    0.674674    
#> 291: 0.806683    1.081170    3.502277    0.484424    0.037951    0.007072    0.674771    
#> 292: 0.806421    1.081348    3.502220    0.484775    0.038015    0.007064    0.674641    
#> 293: 0.806443    1.081511    3.502075    0.485243    0.037956    0.007053    0.674390    
#> 294: 0.806249    1.081809    3.501961    0.485563    0.037943    0.007032    0.674387    
#> 295: 0.806609    1.081624    3.501916    0.486566    0.037952    0.007033    0.674299    
#> 296: 0.806794    1.081579    3.501916    0.486613    0.037936    0.007025    0.674454    
#> 297: 0.806867    1.081537    3.501924    0.486597    0.037947    0.007029    0.674350    
#> 298: 0.807158    1.081493    3.501950    0.487404    0.037948    0.007044    0.674116    
#> 299: 0.807401    1.081657    3.501926    0.487634    0.037939    0.007045    0.674021    
#> 300: 0.807663    1.081733    3.502008    0.488019    0.037925    0.007034    0.674001    
#> 301: 0.807800    1.081772    3.501947    0.488200    0.037825    0.007031    0.674014    
#> 302: 0.807758    1.081931    3.501856    0.488343    0.037754    0.007023    0.674013    
#> 303: 0.807691    1.082148    3.501791    0.487906    0.037653    0.007036    0.673878    
#> 304: 0.807587    1.082357    3.501697    0.487825    0.037582    0.007052    0.673763    
#> 305: 0.807564    1.082079    3.501706    0.488391    0.037555    0.007073    0.673625    
#> 306: 0.807127    1.081881    3.501567    0.488731    0.037543    0.007086    0.673566    
#> 307: 0.806855    1.081587    3.501467    0.488532    0.037502    0.007082    0.673604    
#> 308: 0.806590    1.081463    3.501325    0.489058    0.037465    0.007092    0.673591    
#> 309: 0.806901    1.081299    3.501301    0.489489    0.037492    0.007109    0.673621    
#> 310: 0.807754    1.081147    3.501293    0.490817    0.037490    0.007132    0.673705    
#> 311: 0.807894    1.080982    3.501274    0.491336    0.037490    0.007126    0.673644    
#> 312: 0.807593    1.080923    3.501189    0.490755    0.037542    0.007116    0.673643    
#> 313: 0.807086    1.080858    3.501135    0.490343    0.037543    0.007117    0.673758    
#> 314: 0.806704    1.080866    3.501040    0.490454    0.037507    0.007114    0.673726    
#> 315: 0.806569    1.081041    3.501004    0.490610    0.037518    0.007113    0.673655    
#> 316: 0.806687    1.081224    3.500992    0.490774    0.037552    0.007096    0.673635    
#> 317: 0.807120    1.081266    3.501030    0.492406    0.037581    0.007078    0.673588    
#> 318: 0.807072    1.081349    3.500975    0.492169    0.037569    0.007077    0.673455    
#> 319: 0.807208    1.081394    3.500982    0.492533    0.037593    0.007068    0.673433    
#> 320: 0.806606    1.081436    3.500862    0.491910    0.037636    0.007064    0.673420    
#> 321: 0.806151    1.081459    3.500738    0.491706    0.037631    0.007061    0.673399    
#> 322: 0.806106    1.081597    3.500662    0.491609    0.037625    0.007049    0.673411    
#> 323: 0.805619    1.081677    3.500568    0.491071    0.037635    0.007059    0.673283    
#> 324: 0.805151    1.081749    3.500526    0.490694    0.037582    0.007064    0.673172    
#> 325: 0.805195    1.081930    3.500451    0.491311    0.037533    0.007053    0.673167    
#> 326: 0.805419    1.081879    3.500408    0.492008    0.037505    0.007048    0.673051    
#> 327: 0.805672    1.081934    3.500431    0.492385    0.037419    0.007060    0.673086    
#> 328: 0.806133    1.081969    3.500491    0.493330    0.037354    0.007072    0.673052    
#> 329: 0.806565    1.081925    3.500523    0.494143    0.037352    0.007075    0.672949    
#> 330: 0.806449    1.081945    3.500506    0.494609    0.037356    0.007061    0.673045    
#> 331: 0.806511    1.082093    3.500453    0.494753    0.037384    0.007052    0.672992    
#> 332: 0.806432    1.082028    3.500434    0.494260    0.037376    0.007041    0.672992    
#> 333: 0.806341    1.081981    3.500452    0.493640    0.037381    0.007036    0.672890    
#> 334: 0.806249    1.082054    3.500342    0.493768    0.037336    0.007031    0.672811    
#> 335: 0.806062    1.082155    3.500210    0.493515    0.037305    0.007032    0.672834    
#> 336: 0.805662    1.082282    3.500110    0.492828    0.037303    0.007046    0.672818    
#> 337: 0.805332    1.082473    3.499990    0.492905    0.037289    0.007055    0.672783    
#> 338: 0.805191    1.082651    3.499902    0.493233    0.037321    0.007059    0.672699    
#> 339: 0.804873    1.082854    3.499821    0.493617    0.037330    0.007063    0.672618    
#> 340: 0.804685    1.082771    3.499834    0.493279    0.037319    0.007070    0.672616    
#> 341: 0.804711    1.082800    3.499862    0.492970    0.037305    0.007067    0.672599    
#> 342: 0.804205    1.082764    3.499830    0.492714    0.037271    0.007059    0.672624    
#> 343: 0.803676    1.082774    3.499817    0.493017    0.037275    0.007064    0.672623    
#> 344: 0.803731    1.082712    3.499836    0.493340    0.037285    0.007075    0.672623    
#> 345: 0.803745    1.082669    3.499851    0.493722    0.037295    0.007087    0.672542    
#> 346: 0.803734    1.082815    3.499752    0.494095    0.037287    0.007083    0.672387    
#> 347: 0.803918    1.082735    3.499687    0.493952    0.037267    0.007094    0.672386    
#> 348: 0.803610    1.082775    3.499566    0.494197    0.037217    0.007115    0.672528    
#> 349: 0.803348    1.082812    3.499465    0.494418    0.037187    0.007128    0.672636    
#> 350: 0.802831    1.082841    3.499344    0.494116    0.037198    0.007133    0.672796    
#> 351: 0.802612    1.082954    3.499279    0.493707    0.037201    0.007138    0.672773    
#> 352: 0.802172    1.083066    3.499236    0.493335    0.037231    0.007147    0.672755    
#> 353: 0.802046    1.083154    3.499176    0.493224    0.037239    0.007138    0.672743    
#> 354: 0.802028    1.083191    3.499071    0.493017    0.037234    0.007149    0.672655    
#> 355: 0.802508    1.083065    3.499051    0.493439    0.037239    0.007164    0.672670    
#> 356: 0.802554    1.082967    3.499068    0.493704    0.037233    0.007169    0.672700    
#> 357: 0.802894    1.083047    3.499027    0.494619    0.037176    0.007162    0.672730    
#> 358: 0.802841    1.083138    3.499058    0.494649    0.037123    0.007161    0.672650    
#> 359: 0.802531    1.083221    3.499016    0.494214    0.037135    0.007157    0.672495    
#> 360: 0.802374    1.083330    3.498902    0.493460    0.037117    0.007152    0.672403    
#> 361: 0.802108    1.083506    3.498790    0.493477    0.037121    0.007153    0.672280    
#> 362: 0.802001    1.083610    3.498686    0.493635    0.037110    0.007150    0.672176    
#> 363: 0.802010    1.083680    3.498697    0.493736    0.037074    0.007160    0.672038    
#> 364: 0.802108    1.083781    3.498699    0.493358    0.037015    0.007163    0.672022    
#> 365: 0.801900    1.083740    3.498701    0.492967    0.037051    0.007168    0.672052    
#> 366: 0.801902    1.083787    3.498643    0.493122    0.037043    0.007163    0.672059    
#> 367: 0.801910    1.083900    3.498612    0.493148    0.037033    0.007159    0.672012    
#> 368: 0.802184    1.083950    3.498613    0.492854    0.036994    0.007158    0.671967    
#> 369: 0.801932    1.083956    3.498642    0.492087    0.036965    0.007160    0.671944    
#> 370: 0.801896    1.084041    3.498643    0.491682    0.036974    0.007168    0.671897    
#> 371: 0.801798    1.084146    3.498587    0.491163    0.036983    0.007165    0.671938    
#> 372: 0.801538    1.084280    3.498552    0.490754    0.036992    0.007160    0.672011    
#> 373: 0.801251    1.084502    3.498446    0.491067    0.037044    0.007153    0.672068    
#> 374: 0.801291    1.084459    3.498426    0.491280    0.037038    0.007140    0.672109    
#> 375: 0.801482    1.084453    3.498423    0.491762    0.037059    0.007129    0.672195    
#> 376: 0.801644    1.084522    3.498451    0.491554    0.037134    0.007111    0.672253    
#> 377: 0.801584    1.084599    3.498448    0.491382    0.037294    0.007095    0.672377    
#> 378: 0.801446    1.084624    3.498382    0.491212    0.037355    0.007086    0.672400    
#> 379: 0.801246    1.084481    3.498356    0.491098    0.037377    0.007078    0.672432    
#> 380: 0.801286    1.084445    3.498365    0.490513    0.037414    0.007070    0.672448    
#> 381: 0.801115    1.084370    3.498392    0.490305    0.037399    0.007061    0.672415    
#> 382: 0.800944    1.084379    3.498402    0.490262    0.037388    0.007064    0.672357    
#> 383: 0.801104    1.084325    3.498416    0.490470    0.037381    0.007066    0.672315    
#> 384: 0.801133    1.084259    3.498448    0.490660    0.037391    0.007067    0.672241    
#> 385: 0.801407    1.084201    3.498477    0.490886    0.037385    0.007060    0.672203    
#> 386: 0.801640    1.084299    3.498537    0.490620    0.037404    0.007058    0.672197    
#> 387: 0.801878    1.084382    3.498622    0.490358    0.037395    0.007064    0.672165    
#> 388: 0.801929    1.084373    3.498688    0.489551    0.037370    0.007059    0.672188    
#> 389: 0.802088    1.084104    3.498776    0.488979    0.037356    0.007056    0.672252    
#> 390: 0.801918    1.083980    3.498811    0.488367    0.037325    0.007066    0.672258    
#> 391: 0.801991    1.083907    3.498842    0.488389    0.037309    0.007070    0.672169    
#> 392: 0.802053    1.083961    3.498909    0.488433    0.037338    0.007070    0.672172    
#> 393: 0.801990    1.083916    3.498919    0.488263    0.037331    0.007076    0.672159    
#> 394: 0.802182    1.083904    3.498916    0.488587    0.037339    0.007072    0.672096    
#> 395: 0.802430    1.083941    3.498951    0.488991    0.037346    0.007070    0.672081    
#> 396: 0.802496    1.083961    3.498987    0.488896    0.037345    0.007067    0.671999    
#> 397: 0.802437    1.083955    3.499019    0.488790    0.037332    0.007068    0.672006    
#> 398: 0.802593    1.083876    3.499053    0.488919    0.037308    0.007081    0.671973    
#> 399: 0.802597    1.083832    3.499151    0.488762    0.037285    0.007089    0.671951    
#> 400: 0.802658    1.083819    3.499222    0.488458    0.037251    0.007093    0.671964    
#> 401: 0.802740    1.083909    3.499245    0.488587    0.037280    0.007081    0.672046    
#> 402: 0.802750    1.083842    3.499302    0.488388    0.037292    0.007074    0.672036    
#> 403: 0.803098    1.083765    3.499358    0.488889    0.037316    0.007069    0.671979    
#> 404: 0.803253    1.083751    3.499319    0.489442    0.037327    0.007066    0.671877    
#> 405: 0.803184    1.083715    3.499331    0.489646    0.037339    0.007059    0.671853    
#> 406: 0.803255    1.083723    3.499347    0.489772    0.037333    0.007059    0.671806    
#> 407: 0.803324    1.083750    3.499375    0.489795    0.037323    0.007058    0.671816    
#> 408: 0.803321    1.083839    3.499374    0.489492    0.037304    0.007055    0.671911    
#> 409: 0.803242    1.083828    3.499311    0.489466    0.037260    0.007057    0.671872    
#> 410: 0.803056    1.083875    3.499233    0.489427    0.037241    0.007062    0.671844    
#> 411: 0.802986    1.083743    3.499218    0.489290    0.037276    0.007060    0.671918    
#> 412: 0.802978    1.083775    3.499195    0.489514    0.037251    0.007068    0.671840    
#> 413: 0.802879    1.083835    3.499104    0.489747    0.037205    0.007075    0.671770    
#> 414: 0.802745    1.083857    3.499084    0.489689    0.037165    0.007081    0.671687    
#> 415: 0.802769    1.083926    3.499073    0.489548    0.037158    0.007091    0.671547    
#> 416: 0.802836    1.084062    3.499082    0.489584    0.037127    0.007101    0.671482    
#> 417: 0.802820    1.084105    3.499065    0.489308    0.037091    0.007103    0.671485    
#> 418: 0.802627    1.084135    3.499049    0.489055    0.037066    0.007100    0.671458    
#> 419: 0.802626    1.084147    3.499041    0.488923    0.037026    0.007097    0.671454    
#> 420: 0.802741    1.084118    3.499068    0.488946    0.037008    0.007094    0.671387    
#> 421: 0.802611    1.084127    3.499074    0.489007    0.037004    0.007087    0.671341    
#> 422: 0.802671    1.084072    3.499053    0.488863    0.037019    0.007083    0.671326    
#> 423: 0.802705    1.083975    3.499074    0.488958    0.037052    0.007086    0.671300    
#> 424: 0.802574    1.083922    3.499042    0.488842    0.037094    0.007077    0.671268    
#> 425: 0.802571    1.083987    3.499039    0.488802    0.037150    0.007072    0.671275    
#> 426: 0.802646    1.084046    3.499029    0.488975    0.037204    0.007065    0.671234    
#> 427: 0.802537    1.084050    3.499012    0.489341    0.037213    0.007066    0.671185    
#> 428: 0.802517    1.084093    3.498981    0.489756    0.037219    0.007067    0.671179    
#> 429: 0.802717    1.084023    3.499008    0.490046    0.037218    0.007061    0.671196    
#> 430: 0.802688    1.084005    3.499010    0.490113    0.037225    0.007065    0.671095    
#> 431: 0.802556    1.083958    3.498977    0.490298    0.037226    0.007068    0.670997    
#> 432: 0.802405    1.084000    3.498940    0.490456    0.037228    0.007073    0.670951    
#> 433: 0.802484    1.084117    3.498955    0.490240    0.037236    0.007077    0.670949    
#> 434: 0.802414    1.084045    3.498955    0.490104    0.037272    0.007084    0.670865    
#> 435: 0.802501    1.083987    3.498967    0.489823    0.037275    0.007084    0.670835    
#> 436: 0.802486    1.083905    3.498984    0.489579    0.037290    0.007082    0.670841    
#> 437: 0.802489    1.083766    3.498984    0.489666    0.037267    0.007088    0.670848    
#> 438: 0.802599    1.083881    3.498984    0.489996    0.037234    0.007083    0.670803    
#> 439: 0.802807    1.083935    3.498992    0.490065    0.037202    0.007079    0.670724    
#> 440: 0.802732    1.084003    3.499001    0.489945    0.037186    0.007070    0.670735    
#> 441: 0.802679    1.083948    3.499018    0.489793    0.037228    0.007064    0.670722    
#> 442: 0.802499    1.083960    3.499027    0.489721    0.037230    0.007055    0.670656    
#> 443: 0.802356    1.084059    3.498977    0.489480    0.037232    0.007053    0.670662    
#> 444: 0.802206    1.084128    3.498922    0.489454    0.037242    0.007054    0.670676    
#> 445: 0.802100    1.084188    3.498868    0.489307    0.037259    0.007056    0.670754    
#> 446: 0.801858    1.084275    3.498785    0.489131    0.037268    0.007060    0.670775    
#> 447: 0.801955    1.084295    3.498772    0.489519    0.037269    0.007076    0.670728    
#> 448: 0.801909    1.084311    3.498763    0.489839    0.037242    0.007091    0.670739    
#> 449: 0.802096    1.084334    3.498863    0.490108    0.037225    0.007096    0.670838    
#> 450: 0.802363    1.084291    3.498914    0.490591    0.037205    0.007099    0.670905    
#> 451: 0.802628    1.084296    3.498947    0.490690    0.037202    0.007102    0.670983    
#> 452: 0.802543    1.084380    3.498922    0.490594    0.037200    0.007094    0.670982    
#> 453: 0.802372    1.084425    3.498887    0.490406    0.037235    0.007084    0.670956    
#> 454: 0.802455    1.084521    3.498852    0.490989    0.037250    0.007078    0.670887    
#> 455: 0.802478    1.084524    3.498813    0.491425    0.037251    0.007081    0.671002    
#> 456: 0.802629    1.084486    3.498805    0.491543    0.037264    0.007081    0.671010    
#> 457: 0.802659    1.084477    3.498828    0.491834    0.037261    0.007080    0.670954    
#> 458: 0.802612    1.084558    3.498871    0.491846    0.037255    0.007080    0.670943    
#> 459: 0.802481    1.084663    3.498874    0.491684    0.037260    0.007082    0.670973    
#> 460: 0.802341    1.084655    3.498876    0.491364    0.037265    0.007097    0.670943    
#> 461: 0.802320    1.084652    3.498907    0.491121    0.037261    0.007114    0.670920    
#> 462: 0.802365    1.084710    3.498954    0.491219    0.037236    0.007123    0.670860    
#> 463: 0.802504    1.084764    3.498971    0.491515    0.037208    0.007125    0.670843    
#> 464: 0.802644    1.084839    3.498975    0.491957    0.037182    0.007133    0.670777    
#> 465: 0.802752    1.084790    3.498968    0.492378    0.037160    0.007132    0.670723    
#> 466: 0.802890    1.084837    3.498944    0.492368    0.037153    0.007132    0.670751    
#> 467: 0.802727    1.084887    3.498922    0.492562    0.037149    0.007136    0.670658    
#> 468: 0.802812    1.084873    3.498939    0.492834    0.037155    0.007137    0.670662    
#> 469: 0.802886    1.084939    3.498961    0.492788    0.037171    0.007134    0.670692    
#> 470: 0.802652    1.085007    3.498938    0.492646    0.037189    0.007134    0.670666    
#> 471: 0.802403    1.084990    3.498915    0.492267    0.037213    0.007133    0.670662    
#> 472: 0.802404    1.084972    3.498946    0.492243    0.037214    0.007134    0.670637    
#> 473: 0.802331    1.084982    3.498970    0.492120    0.037211    0.007142    0.670601    
#> 474: 0.802289    1.084953    3.498956    0.492006    0.037216    0.007145    0.670576    
#> 475: 0.802216    1.085009    3.498954    0.491840    0.037210    0.007154    0.670555    
#> 476: 0.802283    1.084992    3.498966    0.491671    0.037186    0.007159    0.670578    
#> 477: 0.802423    1.084977    3.498999    0.491674    0.037170    0.007160    0.670520    
#> 478: 0.802395    1.084954    3.499020    0.491512    0.037156    0.007159    0.670524    
#> 479: 0.802452    1.084999    3.499036    0.491439    0.037166    0.007158    0.670535    
#> 480: 0.802603    1.085014    3.499078    0.491617    0.037164    0.007162    0.670584    
#> 481: 0.802666    1.085045    3.499120    0.491797    0.037137    0.007166    0.670553    
#> 482: 0.802807    1.085011    3.499134    0.492081    0.037101    0.007169    0.670559    
#> 483: 0.802733    1.084998    3.499135    0.491931    0.037080    0.007170    0.670602    
#> 484: 0.802732    1.084919    3.499147    0.491974    0.037076    0.007172    0.670536    
#> 485: 0.802743    1.084935    3.499163    0.492092    0.037041    0.007175    0.670510    
#> 486: 0.802865    1.084951    3.499156    0.492362    0.037029    0.007184    0.670415    
#> 487: 0.802995    1.085022    3.499189    0.492563    0.037004    0.007185    0.670367    
#> 488: 0.802907    1.085014    3.499214    0.492412    0.037027    0.007185    0.670330    
#> 489: 0.802910    1.084961    3.499237    0.492288    0.037028    0.007193    0.670326    
#> 490: 0.802966    1.084987    3.499258    0.492038    0.037001    0.007194    0.670314    
#> 491: 0.803108    1.085026    3.499315    0.492123    0.036994    0.007197    0.670345    
#> 492: 0.803056    1.085059    3.499352    0.491988    0.037000    0.007193    0.670456    
#> 493: 0.803029    1.085060    3.499373    0.491971    0.037014    0.007191    0.670464    
#> 494: 0.803105    1.085099    3.499385    0.491868    0.037019    0.007190    0.670416    
#> 495: 0.803210    1.085111    3.499434    0.491645    0.037022    0.007188    0.670378    
#> 496: 0.803409    1.085170    3.499457    0.491450    0.037024    0.007190    0.670429    
#> 497: 0.803522    1.085142    3.499486    0.491414    0.037034    0.007188    0.670421    
#> 498: 0.803559    1.085089    3.499473    0.491465    0.037026    0.007185    0.670378    
#> 499: 0.803552    1.085072    3.499442    0.491394    0.037051    0.007182    0.670390    
#> 500: 0.803462    1.085004    3.499407    0.491175    0.037074    0.007177    0.670394    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.295942    0.970220    3.444750    0.392401    0.079275    0.016800    1.754103    
#> 002: 0.509821    1.033045    3.466363    0.372781    0.075311    0.015960    1.171124    
#> 003: 0.632761    1.001953    3.478855    0.354227    0.079996    0.015162    0.895357    
#> 004: 0.656664    1.011091    3.477970    0.369254    0.075997    0.014404    0.832985    
#> 005: 0.774606    0.998794    3.497567    0.376553    0.072197    0.013684    0.780283    
#> 006: 0.741243    1.000845    3.480829    0.425081    0.068587    0.013000    0.750997    
#> 007: 0.706826    1.018232    3.479671    0.419628    0.067765    0.012350    0.711545    
#> 008: 0.695476    1.007869    3.476776    0.463816    0.064377    0.011732    0.713883    
#> 009: 0.684565    0.985501    3.480407    0.440625    0.061158    0.012906    0.713194    
#> 010: 0.705899    0.992627    3.487100    0.441361    0.066614    0.012260    0.715829    
#> 011: 0.780300    0.988218    3.490034    0.491672    0.082338    0.011647    0.709208    
#> 012: 0.789554    0.993720    3.477958    0.505229    0.078221    0.011243    0.708094    
#> 013: 0.721339    1.015851    3.476705    0.541472    0.077501    0.012354    0.699512    
#> 014: 0.704410    1.008728    3.478642    0.514399    0.075702    0.011736    0.701859    
#> 015: 0.753322    1.007550    3.488337    0.488679    0.074213    0.012586    0.678873    
#> 016: 0.754466    1.029674    3.490985    0.468005    0.083979    0.011956    0.692908    
#> 017: 0.777750    1.035845    3.483815    0.586848    0.079780    0.011359    0.675804    
#> 018: 0.778902    1.027269    3.482068    0.557505    0.075791    0.010791    0.680460    
#> 019: 0.754531    1.008724    3.486550    0.529630    0.072317    0.010497    0.678774    
#> 020: 0.791153    1.008956    3.493584    0.504561    0.074527    0.009972    0.687486    
#> 021: 0.829565    0.988535    3.503201    0.552310    0.075932    0.009473    0.679122    
#> 022: 0.817712    0.981754    3.513925    0.524695    0.072136    0.009304    0.690107    
#> 023: 0.873477    0.993197    3.514894    0.532326    0.068980    0.009802    0.729755    
#> 024: 0.871346    1.013141    3.507042    0.578099    0.072744    0.011514    0.704645    
#> 025: 0.810413    0.994014    3.498014    0.549194    0.069107    0.014713    0.702417    
#> 026: 0.812021    1.023808    3.494695    0.521735    0.065651    0.015999    0.702111    
#> 027: 0.804873    1.027072    3.488904    0.598287    0.065792    0.015199    0.704458    
#> 028: 0.819872    1.007586    3.492452    0.589312    0.070863    0.017473    0.677911    
#> 029: 0.822098    1.025246    3.484637    0.619119    0.084197    0.016599    0.686796    
#> 030: 0.830254    1.025873    3.483413    0.595523    0.079987    0.015939    0.690649    
#> 031: 0.789216    0.996077    3.495783    0.621231    0.075988    0.015142    0.677051    
#> 032: 0.764257    0.992603    3.494938    0.590169    0.072188    0.014385    0.689094    
#> 033: 0.719883    1.024895    3.486321    0.560661    0.068579    0.014750    0.676337    
#> 034: 0.751576    1.028857    3.481816    0.532628    0.065150    0.014813    0.692858    
#> 035: 0.728304    0.998114    3.475930    0.509734    0.061893    0.016267    0.678188    
#> 036: 0.750240    1.011176    3.480073    0.484247    0.064151    0.017461    0.682860    
#> 037: 0.740285    1.015336    3.483905    0.460035    0.070649    0.019029    0.689878    
#> 038: 0.783348    1.021351    3.480244    0.574569    0.068568    0.019850    0.700865    
#> 039: 0.786131    1.017696    3.487342    0.545841    0.065139    0.020495    0.692431    
#> 040: 0.770127    1.024905    3.482313    0.646433    0.061882    0.019508    0.692897    
#> 041: 0.731762    1.009272    3.470086    0.695014    0.062604    0.020974    0.678334    
#> 042: 0.705772    1.011744    3.465924    0.660263    0.059474    0.019926    0.672255    
#> 043: 0.674446    1.020289    3.462607    0.627250    0.056501    0.018929    0.684536    
#> 044: 0.694926    1.025787    3.460623    0.595888    0.055590    0.017983    0.683116    
#> 045: 0.761673    1.048741    3.468854    0.596365    0.052810    0.017084    0.676128    
#> 046: 0.744976    1.017990    3.472407    0.594214    0.068122    0.016229    0.656568    
#> 047: 0.713076    1.028811    3.468451    0.564503    0.064716    0.015418    0.670715    
#> 048: 0.730567    1.014089    3.471158    0.536278    0.065951    0.014890    0.667265    
#> 049: 0.748158    1.011213    3.474130    0.509464    0.071724    0.014235    0.680253    
#> 050: 0.764950    1.001471    3.477019    0.518937    0.073854    0.013523    0.698166    
#> 051: 0.764309    1.014482    3.477468    0.506234    0.074449    0.016011    0.682732    
#> 052: 0.799800    1.033976    3.488088    0.549770    0.070726    0.015210    0.666369    
#> 053: 0.782716    1.041633    3.475241    0.698501    0.077427    0.014450    0.668849    
#> 054: 0.734034    1.029316    3.474737    0.663576    0.083674    0.013727    0.697043    
#> 055: 0.728848    1.012939    3.476248    0.630398    0.079491    0.013703    0.685505    
#> 056: 0.742312    0.990516    3.476694    0.598878    0.075516    0.013018    0.688491    
#> 057: 0.730112    1.025275    3.481837    0.568934    0.071740    0.013398    0.705759    
#> 058: 0.768196    1.036587    3.468709    0.601240    0.076723    0.012728    0.699229    
#> 059: 0.759365    0.986595    3.477533    0.666778    0.072886    0.014367    0.704040    
#> 060: 0.771780    0.979674    3.484402    0.633439    0.084796    0.015004    0.718877    
#> 061: 0.789950    1.010195    3.495225    0.601767    0.080556    0.015606    0.720627    
#> 062: 0.785601    1.009910    3.498511    0.573518    0.098282    0.017056    0.724018    
#> 063: 0.825068    0.971743    3.501818    0.546693    0.093368    0.016203    0.729316    
#> 064: 0.817404    0.970625    3.504926    0.608962    0.088699    0.017228    0.726944    
#> 065: 0.843392    0.978483    3.492807    0.665343    0.084265    0.016367    0.712991    
#> 066: 0.816844    1.023367    3.490139    0.632076    0.080051    0.015548    0.703870    
#> 067: 0.745750    0.978246    3.485897    0.652051    0.076049    0.014771    0.707040    
#> 068: 0.728915    1.015519    3.486467    0.619449    0.072246    0.017005    0.689283    
#> 069: 0.720789    1.010507    3.467841    0.588476    0.068634    0.016154    0.690085    
#> 070: 0.755265    1.005141    3.484845    0.580308    0.071202    0.015347    0.693146    
#> 071: 0.723438    1.027343    3.462735    0.553034    0.085617    0.014579    0.686573    
#> 072: 0.705638    1.025863    3.466952    0.588718    0.081337    0.013850    0.689798    
#> 073: 0.760982    1.010949    3.492514    0.574749    0.077270    0.013180    0.699032    
#> 074: 0.763489    1.001833    3.486073    0.577304    0.073406    0.013798    0.689178    
#> 075: 0.746769    1.008885    3.499063    0.571015    0.069736    0.013204    0.687538    
#> 076: 0.790444    1.001637    3.508187    0.625617    0.066249    0.014699    0.685791    
#> 077: 0.829073    0.998646    3.496991    0.650696    0.062937    0.013964    0.679878    
#> 078: 0.775251    1.019413    3.489240    0.618161    0.061776    0.014294    0.670103    
#> 079: 0.800405    1.024458    3.486639    0.672428    0.073631    0.013579    0.692351    
#> 080: 0.794120    1.011085    3.484037    0.652871    0.078461    0.016225    0.711920    
#> 081: 0.766482    1.024435    3.480405    0.625625    0.075551    0.018645    0.687734    
#> 082: 0.773278    1.024340    3.486082    0.628902    0.081246    0.017713    0.689301    
#> 083: 0.733749    1.050540    3.482092    0.597457    0.077184    0.016827    0.690796    
#> 084: 0.745152    1.043735    3.469349    0.593687    0.073324    0.015986    0.680289    
#> 085: 0.731282    1.039728    3.477801    0.564002    0.069658    0.015308    0.682669    
#> 086: 0.737365    1.036535    3.471267    0.556826    0.084048    0.014542    0.691151    
#> 087: 0.699331    1.026067    3.466903    0.528985    0.079845    0.013815    0.682439    
#> 088: 0.665440    1.032707    3.477992    0.502535    0.075853    0.013125    0.692668    
#> 089: 0.699034    1.035080    3.464978    0.505367    0.076757    0.012468    0.711672    
#> 090: 0.695932    1.032069    3.457986    0.557590    0.080805    0.011845    0.710379    
#> 091: 0.679637    1.044656    3.442228    0.529710    0.080684    0.012591    0.699725    
#> 092: 0.649890    1.060444    3.441722    0.506598    0.076649    0.011961    0.694979    
#> 093: 0.654434    1.041274    3.443715    0.553549    0.072817    0.011940    0.707346    
#> 094: 0.743833    1.060621    3.444539    0.739838    0.080086    0.011587    0.699958    
#> 095: 0.716953    1.061849    3.455352    0.702846    0.092807    0.012238    0.697521    
#> 096: 0.725603    1.049731    3.463499    0.667704    0.088167    0.012473    0.693179    
#> 097: 0.798321    1.045864    3.456153    0.770917    0.083758    0.011849    0.683357    
#> 098: 0.741973    1.057773    3.470308    0.732371    0.079570    0.013885    0.686773    
#> 099: 0.712574    1.043237    3.458817    0.695753    0.090150    0.013191    0.694981    
#> 100: 0.701568    1.046683    3.448567    0.660965    0.085642    0.012531    0.662046    
#> 101: 0.660286    1.033803    3.441370    0.627917    0.084835    0.011905    0.674570    
#> 102: 0.712736    1.031195    3.447373    0.633997    0.080594    0.012712    0.671235    
#> 103: 0.723243    1.021556    3.461891    0.602297    0.076564    0.014163    0.668037    
#> 104: 0.723948    1.017352    3.476584    0.600937    0.075584    0.013455    0.690013    
#> 105: 0.726045    1.017042    3.474767    0.570890    0.079584    0.012901    0.704804    
#> 106: 0.765754    1.023397    3.474877    0.599294    0.081370    0.016264    0.670448    
#> 107: 0.811668    1.013942    3.492803    0.573451    0.077302    0.017525    0.678040    
#> 108: 0.801097    1.013337    3.504521    0.556729    0.073437    0.016649    0.696766    
#> 109: 0.802371    1.011168    3.510336    0.641636    0.069765    0.015816    0.696152    
#> 110: 0.825105    0.990523    3.488435    0.662187    0.066277    0.015025    0.681867    
#> 111: 0.817096    0.986638    3.499516    0.676774    0.062963    0.015012    0.669138    
#> 112: 0.806859    0.985881    3.486024    0.642936    0.060629    0.016843    0.683465    
#> 113: 0.753307    1.017516    3.476182    0.610789    0.066689    0.016001    0.670729    
#> 114: 0.750937    1.034580    3.485537    0.580249    0.068572    0.016911    0.689790    
#> 115: 0.792023    0.991939    3.482421    0.551237    0.065143    0.016066    0.710198    
#> 116: 0.784917    0.995008    3.486907    0.541500    0.061886    0.017766    0.708043    
#> 117: 0.741084    1.018082    3.483654    0.627990    0.066272    0.016878    0.712255    
#> 118: 0.753202    1.007231    3.490118    0.596590    0.062958    0.016034    0.701013    
#> 119: 0.775299    1.016947    3.490063    0.611944    0.063104    0.015891    0.686087    
#> 120: 0.755154    1.001073    3.481447    0.581347    0.059949    0.015096    0.689463    
#> 121: 0.793918    1.030944    3.483445    0.627186    0.068705    0.014341    0.678344    
#> 122: 0.771488    1.020605    3.487748    0.595827    0.073002    0.014472    0.687264    
#> 123: 0.805270    1.037611    3.477644    0.600364    0.069352    0.013748    0.692983    
#> 124: 0.741352    1.055582    3.482819    0.570346    0.065884    0.015368    0.687626    
#> 125: 0.760822    1.050782    3.472921    0.545983    0.062590    0.014599    0.694812    
#> 126: 0.756209    1.054962    3.463504    0.585989    0.059461    0.014329    0.707077    
#> 127: 0.764149    1.040061    3.452916    0.556690    0.056488    0.014544    0.735476    
#> 128: 0.708331    1.032764    3.475734    0.528855    0.071682    0.015551    0.690355    
#> 129: 0.755736    1.044711    3.480233    0.616221    0.069284    0.014773    0.699427    
#> 130: 0.750487    1.047333    3.477303    0.585410    0.071520    0.014034    0.692085    
#> 131: 0.772829    1.023979    3.468883    0.663711    0.086898    0.013333    0.676249    
#> 132: 0.730260    1.023949    3.456123    0.630525    0.082553    0.012666    0.679446    
#> 133: 0.752098    1.017936    3.466031    0.694862    0.078426    0.014342    0.699420    
#> 134: 0.805818    1.015981    3.476628    0.783989    0.074505    0.014560    0.685330    
#> 135: 0.773937    1.012223    3.471670    0.744790    0.076740    0.015773    0.676887    
#> 136: 0.811615    1.002901    3.477030    0.817540    0.072903    0.014984    0.671538    
#> 137: 0.829629    1.008152    3.477175    0.834710    0.069614    0.014235    0.689579    
#> 138: 0.797259    1.019703    3.475639    0.847448    0.071372    0.013523    0.678235    
#> 139: 0.765604    1.011354    3.484671    0.805075    0.079717    0.013375    0.711942    
#> 140: 0.714170    1.025054    3.487565    0.764822    0.080128    0.013025    0.728712    
#> 141: 0.740464    0.997495    3.482552    0.726580    0.083834    0.012374    0.699990    
#> 142: 0.795027    0.978740    3.497861    0.690251    0.089289    0.011755    0.702758    
#> 143: 0.750889    1.022096    3.496347    0.655739    0.084825    0.012380    0.710437    
#> 144: 0.797273    1.021176    3.512681    0.622952    0.080583    0.011761    0.690566    
#> 145: 0.791102    1.014793    3.493134    0.591804    0.076554    0.012405    0.679983    
#> 146: 0.779383    1.024930    3.489293    0.562214    0.072726    0.011785    0.711090    
#> 147: 0.695830    1.012800    3.480177    0.534103    0.069090    0.012654    0.677184    
#> 148: 0.697014    1.011151    3.492823    0.507398    0.067949    0.012315    0.691929    
#> 149: 0.723233    0.995574    3.489490    0.559766    0.069338    0.011699    0.718059    
#> 150: 0.778180    1.007593    3.479268    0.560784    0.079840    0.012930    0.708719    
#> 151: 0.727553    1.033718    3.476647    0.532745    0.075848    0.012284    0.688689    
#> 152: 0.712207    1.022550    3.482673    0.559125    0.061567    0.011107    0.694607    
#> 153: 0.732761    1.018218    3.490751    0.538915    0.065283    0.015485    0.699672    
#> 154: 0.767437    1.027475    3.489767    0.586479    0.053078    0.015772    0.700254    
#> 155: 0.768633    0.989555    3.483951    0.624780    0.062516    0.015057    0.689696    
#> 156: 0.771917    1.020942    3.494722    0.594161    0.067273    0.015408    0.686331    
#> 157: 0.802919    1.014759    3.502940    0.522518    0.062298    0.012304    0.696473    
#> 158: 0.802257    1.013324    3.496557    0.494157    0.061314    0.011979    0.691643    
#> 159: 0.748618    1.018243    3.501460    0.456638    0.073559    0.012188    0.686362    
#> 160: 0.759639    0.978646    3.503881    0.435390    0.074103    0.014306    0.688346    
#> 161: 0.780296    1.003797    3.497983    0.553677    0.064425    0.013764    0.701368    
#> 162: 0.770758    1.014053    3.477659    0.622702    0.066609    0.010386    0.698519    
#> 163: 0.763037    1.009745    3.474422    0.576309    0.076373    0.008768    0.688311    
#> 164: 0.713651    1.029815    3.466206    0.587790    0.076609    0.009141    0.677092    
#> 165: 0.770771    1.027332    3.482361    0.670497    0.066362    0.013379    0.690372    
#> 166: 0.838546    1.052111    3.478351    0.894924    0.050881    0.013696    0.703357    
#> 167: 0.861988    1.064408    3.487443    0.862759    0.050928    0.018854    0.698929    
#> 168: 0.872835    1.043102    3.487929    0.764762    0.058158    0.018967    0.690071    
#> 169: 0.859243    1.066047    3.475755    0.954618    0.060082    0.015934    0.692391    
#> 170: 0.908645    1.033996    3.494038    1.001142    0.070959    0.016101    0.688487    
#> 171: 0.821358    1.024616    3.481582    0.810783    0.063437    0.015748    0.651978    
#> 172: 0.782393    1.034427    3.484715    0.786107    0.066455    0.014271    0.654298    
#> 173: 0.814550    1.038352    3.468192    0.778146    0.065473    0.014958    0.650913    
#> 174: 0.839631    1.018882    3.481872    0.800121    0.051164    0.017853    0.671232    
#> 175: 0.875079    1.018673    3.480568    0.851470    0.058458    0.016213    0.687046    
#> 176: 0.782255    1.036181    3.484138    0.679695    0.055975    0.016336    0.671965    
#> 177: 0.795566    1.025529    3.486002    0.639041    0.049720    0.016325    0.688202    
#> 178: 0.775836    1.012569    3.480845    0.592274    0.063960    0.014081    0.688916    
#> 179: 0.830076    1.027930    3.466917    0.845788    0.081414    0.012917    0.690961    
#> 180: 0.787990    1.032471    3.475131    0.730621    0.067323    0.013277    0.685350    
#> 181: 0.765246    1.022632    3.459426    0.609107    0.073344    0.015264    0.685193    
#> 182: 0.716223    1.015946    3.453799    0.644724    0.063702    0.017012    0.697197    
#> 183: 0.729344    1.044840    3.453932    0.611121    0.063745    0.021385    0.677833    
#> 184: 0.715816    1.032194    3.458386    0.631431    0.052591    0.021042    0.681583    
#> 185: 0.729609    1.054561    3.456511    0.597352    0.065601    0.019989    0.680192    
#> 186: 0.734508    1.056915    3.465195    0.612773    0.078691    0.019330    0.685370    
#> 187: 0.750439    1.039139    3.468081    0.666870    0.076683    0.019697    0.672147    
#> 188: 0.711135    1.040511    3.464969    0.576905    0.066049    0.017917    0.690056    
#> 189: 0.746589    1.048210    3.489015    0.530593    0.065032    0.018867    0.695978    
#> 190: 0.758805    1.029083    3.493398    0.590970    0.045848    0.020591    0.678977    
#> 191: 0.747756    1.047553    3.480013    0.502365    0.044494    0.021329    0.678370    
#> 192: 0.677807    1.042489    3.476311    0.473370    0.047541    0.020709    0.692678    
#> 193: 0.739165    1.059481    3.482917    0.486825    0.059474    0.016474    0.668685    
#> 194: 0.741453    1.031900    3.482262    0.552661    0.069358    0.015489    0.700702    
#> 195: 0.716325    1.032123    3.474154    0.565700    0.065727    0.018623    0.680191    
#> 196: 0.748148    1.032994    3.480399    0.510044    0.063689    0.017207    0.687806    
#> 197: 0.696173    1.038324    3.490002    0.452036    0.063942    0.014962    0.705190    
#> 198: 0.770920    1.013449    3.488249    0.416027    0.057065    0.015453    0.694579    
#> 199: 0.754085    1.012062    3.483292    0.459420    0.063820    0.012698    0.696344    
#> 200: 0.786285    1.005735    3.496688    0.523407    0.078471    0.018066    0.698336    
#> 201: 0.796719    1.006728    3.500689    0.548222    0.070674    0.019220    0.686828    
#> 202: 0.795028    1.006981    3.497724    0.567876    0.066115    0.018817    0.681805    
#> 203: 0.801329    1.008232    3.494307    0.580707    0.064761    0.018165    0.682895    
#> 204: 0.796579    1.005856    3.495298    0.578833    0.062893    0.017023    0.686323    
#> 205: 0.793177    1.010577    3.494930    0.571025    0.061227    0.016479    0.692266    
#> 206: 0.790149    1.014772    3.495227    0.573416    0.061163    0.016475    0.693923    
#> 207: 0.787414    1.015145    3.493423    0.566611    0.060356    0.016478    0.693339    
#> 208: 0.784647    1.015782    3.492406    0.563804    0.060828    0.015991    0.691166    
#> 209: 0.779788    1.013575    3.491462    0.562371    0.062079    0.015903    0.690874    
#> 210: 0.777847    1.011832    3.491073    0.563143    0.062645    0.015579    0.689944    
#> 211: 0.777293    1.012377    3.490638    0.562424    0.064238    0.015250    0.688313    
#> 212: 0.778683    1.011957    3.489868    0.566893    0.064680    0.014885    0.688807    
#> 213: 0.780196    1.009701    3.489979    0.569284    0.063773    0.014772    0.690373    
#> 214: 0.781206    1.009520    3.490007    0.568275    0.063170    0.014657    0.690076    
#> 215: 0.781711    1.009836    3.490057    0.566413    0.062276    0.014565    0.690896    
#> 216: 0.781733    1.008978    3.489609    0.568235    0.062795    0.014579    0.691794    
#> 217: 0.778434    1.009972    3.489119    0.565538    0.062751    0.014535    0.690691    
#> 218: 0.776868    1.011549    3.488251    0.565445    0.062961    0.014399    0.689409    
#> 219: 0.776140    1.011310    3.487191    0.571493    0.062682    0.014188    0.688213    
#> 220: 0.774706    1.012379    3.486717    0.574940    0.062685    0.014281    0.687254    
#> 221: 0.773702    1.012875    3.485686    0.578807    0.062657    0.014265    0.686051    
#> 222: 0.774396    1.012778    3.485079    0.582646    0.062614    0.014316    0.685754    
#> 223: 0.775098    1.013480    3.484535    0.585119    0.062271    0.014392    0.685477    
#> 224: 0.776163    1.014247    3.484467    0.583911    0.062171    0.014446    0.685246    
#> 225: 0.775240    1.012983    3.484556    0.585775    0.061866    0.014438    0.685527    
#> 226: 0.774743    1.012240    3.483947    0.586751    0.061774    0.014409    0.685187    
#> 227: 0.774017    1.012645    3.483856    0.587198    0.062092    0.014442    0.685259    
#> 228: 0.773588    1.014362    3.482979    0.592088    0.062562    0.014480    0.684927    
#> 229: 0.770730    1.015252    3.482326    0.592307    0.062926    0.014535    0.684802    
#> 230: 0.770151    1.015806    3.481765    0.592732    0.062894    0.014476    0.685596    
#> 231: 0.768715    1.016530    3.481440    0.595631    0.063016    0.014451    0.685677    
#> 232: 0.766282    1.016790    3.481152    0.592472    0.063306    0.014372    0.685936    
#> 233: 0.763294    1.016417    3.480850    0.588560    0.063353    0.014250    0.686830    
#> 234: 0.762034    1.016691    3.480622    0.590291    0.063581    0.014226    0.687293    
#> 235: 0.761099    1.016787    3.480215    0.591356    0.063441    0.014234    0.687464    
#> 236: 0.759711    1.017298    3.479890    0.589420    0.063436    0.014189    0.687937    
#> 237: 0.760154    1.017264    3.479674    0.591995    0.063464    0.014115    0.688264    
#> 238: 0.761193    1.017512    3.479687    0.595133    0.063651    0.014037    0.688597    
#> 239: 0.760433    1.018167    3.479366    0.596403    0.063901    0.013998    0.688656    
#> 240: 0.760737    1.017935    3.479407    0.597311    0.064198    0.013970    0.688461    
#> 241: 0.761984    1.017279    3.479871    0.597461    0.064554    0.013956    0.688215    
#> 242: 0.761506    1.016637    3.479853    0.596208    0.064484    0.013936    0.688695    
#> 243: 0.760869    1.016557    3.479881    0.595529    0.064610    0.013869    0.689336    
#> 244: 0.761020    1.015979    3.480177    0.594875    0.064540    0.013841    0.689644    
#> 245: 0.761327    1.015226    3.480423    0.596427    0.064882    0.013794    0.690111    
#> 246: 0.762032    1.014935    3.480568    0.595858    0.064975    0.013762    0.690378    
#> 247: 0.761403    1.014440    3.480746    0.594875    0.065206    0.013727    0.690428    
#> 248: 0.760878    1.014918    3.480592    0.594121    0.065385    0.013637    0.690050    
#> 249: 0.759703    1.015250    3.480452    0.594488    0.065411    0.013564    0.690014    
#> 250: 0.759604    1.015506    3.480558    0.592812    0.065578    0.013532    0.690108    
#> 251: 0.760403    1.015971    3.480858    0.592599    0.065809    0.013474    0.690181    
#> 252: 0.760804    1.016281    3.481087    0.593192    0.066021    0.013405    0.689853    
#> 253: 0.760090    1.016316    3.481094    0.590813    0.066219    0.013346    0.689818    
#> 254: 0.759445    1.016689    3.481029    0.589814    0.066422    0.013291    0.689746    
#> 255: 0.758933    1.016826    3.481139    0.587411    0.066209    0.013283    0.690121    
#> 256: 0.759315    1.016589    3.481187    0.587590    0.066254    0.013247    0.690291    
#> 257: 0.758532    1.016118    3.481133    0.588504    0.066487    0.013178    0.690545    
#> 258: 0.758113    1.015864    3.481029    0.586471    0.066500    0.013105    0.690612    
#> 259: 0.757891    1.015726    3.480880    0.587134    0.066605    0.013092    0.690526    
#> 260: 0.757859    1.015890    3.480847    0.587684    0.066939    0.013075    0.690150    
#> 261: 0.758136    1.015883    3.480880    0.588874    0.067194    0.013033    0.689995    
#> 262: 0.758281    1.015984    3.480787    0.589221    0.067280    0.012990    0.689789    
#> 263: 0.758047    1.016089    3.480866    0.589134    0.067556    0.012976    0.689761    
#> 264: 0.758064    1.016095    3.480991    0.588191    0.067771    0.012959    0.689933    
#> 265: 0.758052    1.016069    3.481120    0.586831    0.067845    0.012973    0.689989    
#> 266: 0.758286    1.016061    3.481154    0.586315    0.067943    0.012970    0.689977    
#> 267: 0.758001    1.015829    3.481330    0.585268    0.068110    0.012946    0.690077    
#> 268: 0.758216    1.015583    3.481367    0.584219    0.068161    0.012913    0.690025    
#> 269: 0.758595    1.015375    3.481518    0.583138    0.068401    0.012899    0.689805    
#> 270: 0.758914    1.015408    3.481577    0.582854    0.068400    0.012922    0.689762    
#> 271: 0.759247    1.015304    3.481510    0.583311    0.068438    0.012955    0.689854    
#> 272: 0.759472    1.015159    3.481444    0.584207    0.068344    0.012976    0.690174    
#> 273: 0.758833    1.015451    3.481318    0.583283    0.068402    0.012992    0.690266    
#> 274: 0.758633    1.015657    3.481343    0.582848    0.068345    0.013007    0.690294    
#> 275: 0.758430    1.015950    3.481172    0.582767    0.068404    0.013027    0.690515    
#> 276: 0.758260    1.016018    3.481371    0.581396    0.068498    0.013089    0.690685    
#> 277: 0.758147    1.016160    3.481715    0.580511    0.068404    0.013160    0.690898    
#> 278: 0.758348    1.016220    3.481853    0.580141    0.068405    0.013162    0.690975    
#> 279: 0.758577    1.015993    3.482001    0.581308    0.068433    0.013172    0.691172    
#> 280: 0.758883    1.015989    3.482078    0.581620    0.068534    0.013182    0.691207    
#> 281: 0.758959    1.016011    3.482138    0.581200    0.068696    0.013173    0.691208    
#> 282: 0.758636    1.016391    3.482105    0.579800    0.068937    0.013178    0.691205    
#> 283: 0.758354    1.016584    3.482181    0.579180    0.069052    0.013164    0.691213    
#> 284: 0.758152    1.016382    3.482162    0.578731    0.069034    0.013172    0.691086    
#> 285: 0.758553    1.016351    3.482141    0.578768    0.069044    0.013184    0.691174    
#> 286: 0.758660    1.016620    3.482054    0.578985    0.069299    0.013231    0.691227    
#> 287: 0.758528    1.016596    3.481983    0.578785    0.069279    0.013226    0.691307    
#> 288: 0.759447    1.016464    3.481950    0.579406    0.069454    0.013224    0.691381    
#> 289: 0.759986    1.016207    3.481911    0.580645    0.069573    0.013214    0.691296    
#> 290: 0.760253    1.016169    3.481882    0.581059    0.069555    0.013194    0.691493    
#> 291: 0.760677    1.016335    3.482057    0.581372    0.069552    0.013187    0.691536    
#> 292: 0.760324    1.016348    3.482131    0.580564    0.069541    0.013158    0.691588    
#> 293: 0.760186    1.016379    3.482103    0.579502    0.069411    0.013120    0.691551    
#> 294: 0.759919    1.016608    3.481993    0.578805    0.069468    0.013081    0.691481    
#> 295: 0.759841    1.016411    3.481970    0.579604    0.069424    0.013055    0.691259    
#> 296: 0.759902    1.016332    3.482025    0.579910    0.069266    0.013069    0.691271    
#> 297: 0.760222    1.016374    3.482039    0.580277    0.069112    0.013088    0.691181    
#> 298: 0.760719    1.016219    3.481977    0.582445    0.069016    0.013083    0.691222    
#> 299: 0.761354    1.016208    3.481929    0.584331    0.069014    0.013065    0.691058    
#> 300: 0.761469    1.015985    3.481989    0.584482    0.069029    0.013063    0.690922    
#> 301: 0.761888    1.015857    3.481918    0.584558    0.069044    0.013054    0.691158    
#> 302: 0.762169    1.015973    3.481930    0.584747    0.069120    0.013049    0.691279    
#> 303: 0.762304    1.016088    3.481877    0.585112    0.069126    0.013034    0.691119    
#> 304: 0.762325    1.016330    3.481735    0.584990    0.069103    0.013024    0.691241    
#> 305: 0.761717    1.016353    3.481542    0.584754    0.069200    0.012998    0.691347    
#> 306: 0.761121    1.016344    3.481327    0.584040    0.069188    0.012970    0.691564    
#> 307: 0.760725    1.016295    3.481134    0.583642    0.069253    0.012958    0.691590    
#> 308: 0.759708    1.016218    3.480960    0.582463    0.069260    0.012944    0.691598    
#> 309: 0.759730    1.016014    3.480922    0.582534    0.069229    0.012942    0.691700    
#> 310: 0.760266    1.015986    3.480829    0.584121    0.069305    0.012932    0.691540    
#> 311: 0.760459    1.016020    3.480844    0.584118    0.069409    0.012923    0.691414    
#> 312: 0.760237    1.015903    3.480758    0.584009    0.069547    0.012899    0.691511    
#> 313: 0.760070    1.015617    3.480669    0.583927    0.069619    0.012889    0.691598    
#> 314: 0.759564    1.015720    3.480551    0.583331    0.069660    0.012882    0.691417    
#> 315: 0.759155    1.015835    3.480457    0.583082    0.069824    0.012866    0.691309    
#> 316: 0.758683    1.016019    3.480352    0.582155    0.069905    0.012857    0.691344    
#> 317: 0.758538    1.016128    3.480263    0.582063    0.069927    0.012836    0.691493    
#> 318: 0.758779    1.016235    3.480206    0.582394    0.069840    0.012832    0.691425    
#> 319: 0.758747    1.016202    3.480204    0.582162    0.069769    0.012852    0.691555    
#> 320: 0.758253    1.016248    3.480092    0.581971    0.069808    0.012869    0.691642    
#> 321: 0.757931    1.016418    3.479925    0.582059    0.069855    0.012867    0.691684    
#> 322: 0.757437    1.016613    3.479584    0.581852    0.069938    0.012855    0.691807    
#> 323: 0.756809    1.016780    3.479383    0.581851    0.070011    0.012854    0.691782    
#> 324: 0.756477    1.016919    3.479281    0.581351    0.069910    0.012846    0.691823    
#> 325: 0.756402    1.017164    3.479281    0.580816    0.069816    0.012840    0.691827    
#> 326: 0.756482    1.017058    3.479267    0.580753    0.069816    0.012840    0.691758    
#> 327: 0.756613    1.017125    3.479282    0.580485    0.069856    0.012845    0.691712    
#> 328: 0.756521    1.017207    3.479238    0.579819    0.069795    0.012827    0.691663    
#> 329: 0.756461    1.017291    3.479226    0.579096    0.069732    0.012795    0.691702    
#> 330: 0.756007    1.017344    3.479248    0.577953    0.069649    0.012799    0.691766    
#> 331: 0.755873    1.017520    3.479240    0.577186    0.069630    0.012796    0.691798    
#> 332: 0.755960    1.017502    3.479303    0.576379    0.069495    0.012824    0.691831    
#> 333: 0.755628    1.017496    3.479231    0.576134    0.069389    0.012831    0.691867    
#> 334: 0.755179    1.017493    3.479006    0.575799    0.069374    0.012809    0.691882    
#> 335: 0.754641    1.017732    3.478843    0.575294    0.069343    0.012816    0.691873    
#> 336: 0.754005    1.017963    3.478738    0.574781    0.069397    0.012845    0.691922    
#> 337: 0.753762    1.018207    3.478649    0.574803    0.069410    0.012881    0.692013    
#> 338: 0.753701    1.018356    3.478573    0.575015    0.069438    0.012874    0.692062    
#> 339: 0.753456    1.018581    3.478486    0.575250    0.069477    0.012850    0.692010    
#> 340: 0.753485    1.018428    3.478447    0.575515    0.069640    0.012836    0.691989    
#> 341: 0.753368    1.018456    3.478366    0.576026    0.069828    0.012825    0.691921    
#> 342: 0.752782    1.018451    3.478276    0.575593    0.069911    0.012831    0.691785    
#> 343: 0.752114    1.018445    3.478241    0.574476    0.070041    0.012820    0.691822    
#> 344: 0.751761    1.018488    3.478216    0.573580    0.070107    0.012812    0.691907    
#> 345: 0.751709    1.018455    3.478263    0.572910    0.070210    0.012798    0.691965    
#> 346: 0.751533    1.018531    3.478202    0.572383    0.070285    0.012776    0.691946    
#> 347: 0.751693    1.018583    3.478132    0.572756    0.070348    0.012773    0.691920    
#> 348: 0.751643    1.018735    3.478070    0.573144    0.070377    0.012779    0.691940    
#> 349: 0.751648    1.018694    3.477987    0.573722    0.070392    0.012795    0.691998    
#> 350: 0.751501    1.018646    3.477929    0.574176    0.070421    0.012797    0.692034    
#> 351: 0.751419    1.018791    3.477887    0.573937    0.070458    0.012791    0.692087    
#> 352: 0.751133    1.018825    3.477920    0.573731    0.070510    0.012772    0.692295    
#> 353: 0.750920    1.018998    3.477805    0.573468    0.070508    0.012766    0.692364    
#> 354: 0.750979    1.018991    3.477685    0.573593    0.070493    0.012738    0.692377    
#> 355: 0.751210    1.018868    3.477609    0.573684    0.070476    0.012719    0.692462    
#> 356: 0.750968    1.018891    3.477588    0.573343    0.070466    0.012721    0.692559    
#> 357: 0.751062    1.018922    3.477563    0.573094    0.070434    0.012729    0.692444    
#> 358: 0.751078    1.018963    3.477632    0.573073    0.070441    0.012723    0.692302    
#> 359: 0.750923    1.019101    3.477612    0.572842    0.070449    0.012719    0.692252    
#> 360: 0.750584    1.019176    3.477507    0.572215    0.070447    0.012726    0.692233    
#> 361: 0.750382    1.019357    3.477410    0.571650    0.070504    0.012717    0.692150    
#> 362: 0.750384    1.019453    3.477358    0.571237    0.070539    0.012712    0.691998    
#> 363: 0.750304    1.019460    3.477337    0.570634    0.070435    0.012698    0.691942    
#> 364: 0.750170    1.019588    3.477310    0.570488    0.070470    0.012694    0.691910    
#> 365: 0.750113    1.019541    3.477340    0.570477    0.070499    0.012698    0.691961    
#> 366: 0.750001    1.019520    3.477233    0.570529    0.070498    0.012699    0.692115    
#> 367: 0.750022    1.019657    3.477218    0.570617    0.070477    0.012709    0.692092    
#> 368: 0.750244    1.019787    3.477186    0.571196    0.070439    0.012723    0.691980    
#> 369: 0.750233    1.019772    3.477175    0.571647    0.070453    0.012724    0.691925    
#> 370: 0.750131    1.019746    3.477172    0.571453    0.070525    0.012732    0.691864    
#> 371: 0.749948    1.019747    3.477086    0.571144    0.070606    0.012717    0.691894    
#> 372: 0.749783    1.019877    3.476986    0.571701    0.070561    0.012729    0.691839    
#> 373: 0.749455    1.019995    3.476894    0.572300    0.070523    0.012730    0.691906    
#> 374: 0.749424    1.020135    3.476771    0.573006    0.070470    0.012747    0.691879    
#> 375: 0.749274    1.020172    3.476785    0.573473    0.070441    0.012752    0.691910    
#> 376: 0.749197    1.020238    3.476792    0.573325    0.070421    0.012773    0.691855    
#> 377: 0.749149    1.020318    3.476821    0.573283    0.070451    0.012787    0.691795    
#> 378: 0.749117    1.020359    3.476791    0.572657    0.070409    0.012802    0.691790    
#> 379: 0.748956    1.020239    3.476782    0.572126    0.070360    0.012797    0.691769    
#> 380: 0.748843    1.020180    3.476811    0.571685    0.070348    0.012790    0.691686    
#> 381: 0.748667    1.020205    3.476810    0.571489    0.070343    0.012772    0.691660    
#> 382: 0.748578    1.020330    3.476827    0.571714    0.070333    0.012763    0.691542    
#> 383: 0.748526    1.020465    3.476807    0.571750    0.070357    0.012749    0.691538    
#> 384: 0.748581    1.020394    3.476790    0.572288    0.070355    0.012738    0.691478    
#> 385: 0.748462    1.020432    3.476768    0.572070    0.070373    0.012730    0.691469    
#> 386: 0.748676    1.020623    3.476843    0.572253    0.070392    0.012735    0.691485    
#> 387: 0.748720    1.020881    3.476892    0.572086    0.070445    0.012736    0.691460    
#> 388: 0.748827    1.020902    3.476912    0.572125    0.070439    0.012723    0.691465    
#> 389: 0.748868    1.020741    3.476916    0.571849    0.070444    0.012707    0.691511    
#> 390: 0.748540    1.020704    3.476861    0.571382    0.070460    0.012684    0.691546    
#> 391: 0.748586    1.020575    3.476843    0.571420    0.070441    0.012669    0.691487    
#> 392: 0.748741    1.020559    3.476914    0.571465    0.070450    0.012658    0.691517    
#> 393: 0.748597    1.020480    3.476936    0.571115    0.070417    0.012655    0.691518    
#> 394: 0.748634    1.020456    3.476945    0.570884    0.070365    0.012655    0.691489    
#> 395: 0.748720    1.020591    3.476975    0.570522    0.070366    0.012648    0.691466    
#> 396: 0.748757    1.020611    3.476987    0.569996    0.070329    0.012641    0.691456    
#> 397: 0.748905    1.020506    3.477055    0.570114    0.070284    0.012664    0.691374    
#> 398: 0.749270    1.020371    3.477136    0.570825    0.070203    0.012691    0.691369    
#> 399: 0.749670    1.020340    3.477217    0.571583    0.070178    0.012723    0.691330    
#> 400: 0.750054    1.020364    3.477319    0.572205    0.070152    0.012735    0.691295    
#> 401: 0.750197    1.020376    3.477356    0.572301    0.070153    0.012741    0.691293    
#> 402: 0.750068    1.020459    3.477342    0.571761    0.070144    0.012746    0.691335    
#> 403: 0.750244    1.020496    3.477354    0.571690    0.070192    0.012752    0.691229    
#> 404: 0.750289    1.020588    3.477299    0.571590    0.070180    0.012744    0.691150    
#> 405: 0.750349    1.020675    3.477291    0.572045    0.070115    0.012741    0.691163    
#> 406: 0.750489    1.020705    3.477293    0.572228    0.070080    0.012738    0.691270    
#> 407: 0.750328    1.020874    3.477299    0.571917    0.070084    0.012722    0.691276    
#> 408: 0.750617    1.020934    3.477342    0.571883    0.070031    0.012725    0.691307    
#> 409: 0.750582    1.020828    3.477326    0.571464    0.069997    0.012713    0.691327    
#> 410: 0.750593    1.020785    3.477299    0.571240    0.070002    0.012698    0.691408    
#> 411: 0.750485    1.020626    3.477234    0.571361    0.069984    0.012701    0.691439    
#> 412: 0.750426    1.020640    3.477194    0.571642    0.069953    0.012691    0.691432    
#> 413: 0.750506    1.020736    3.477150    0.571960    0.069963    0.012675    0.691440    
#> 414: 0.750334    1.020765    3.477113    0.571858    0.069959    0.012661    0.691420    
#> 415: 0.750513    1.020738    3.477107    0.572183    0.069962    0.012637    0.691394    
#> 416: 0.750584    1.020742    3.477098    0.572905    0.070023    0.012634    0.691330    
#> 417: 0.750612    1.020742    3.477067    0.573136    0.070107    0.012628    0.691310    
#> 418: 0.750358    1.020760    3.477052    0.572580    0.070188    0.012615    0.691267    
#> 419: 0.750311    1.020872    3.477034    0.572336    0.070258    0.012603    0.691244    
#> 420: 0.750396    1.020996    3.477019    0.572060    0.070334    0.012587    0.691203    
#> 421: 0.750383    1.021100    3.477034    0.571798    0.070391    0.012575    0.691196    
#> 422: 0.750647    1.020991    3.477083    0.571806    0.070430    0.012563    0.691164    
#> 423: 0.750831    1.020895    3.477141    0.571745    0.070478    0.012551    0.691180    
#> 424: 0.750838    1.020884    3.477136    0.571459    0.070535    0.012544    0.691117    
#> 425: 0.750945    1.020950    3.477115    0.571632    0.070538    0.012539    0.691050    
#> 426: 0.750900    1.021001    3.477083    0.571737    0.070512    0.012540    0.691080    
#> 427: 0.750807    1.020955    3.477089    0.571777    0.070449    0.012535    0.691098    
#> 428: 0.750574    1.021023    3.477073    0.571416    0.070414    0.012531    0.691137    
#> 429: 0.750531    1.021019    3.477099    0.571256    0.070404    0.012526    0.691092    
#> 430: 0.750409    1.021054    3.477112    0.571307    0.070362    0.012523    0.691132    
#> 431: 0.750233    1.021104    3.477079    0.570923    0.070334    0.012515    0.691052    
#> 432: 0.750133    1.021189    3.477109    0.570747    0.070349    0.012514    0.690993    
#> 433: 0.750162    1.021286    3.477137    0.570967    0.070386    0.012512    0.690999    
#> 434: 0.750007    1.021243    3.477144    0.571071    0.070338    0.012508    0.690953    
#> 435: 0.750029    1.021259    3.477124    0.570927    0.070300    0.012508    0.690934    
#> 436: 0.749859    1.021260    3.477104    0.570385    0.070350    0.012500    0.690967    
#> 437: 0.749679    1.021323    3.477065    0.570333    0.070425    0.012491    0.691026    
#> 438: 0.749803    1.021464    3.477030    0.570838    0.070440    0.012486    0.690960    
#> 439: 0.749969    1.021545    3.476995    0.571458    0.070462    0.012481    0.690851    
#> 440: 0.749984    1.021624    3.477015    0.571440    0.070489    0.012475    0.690813    
#> 441: 0.749908    1.021595    3.477021    0.571028    0.070511    0.012465    0.690755    
#> 442: 0.749738    1.021688    3.477037    0.570650    0.070524    0.012465    0.690657    
#> 443: 0.749742    1.021791    3.477007    0.570723    0.070497    0.012468    0.690630    
#> 444: 0.749586    1.021899    3.476928    0.570541    0.070462    0.012477    0.690534    
#> 445: 0.749467    1.021897    3.476881    0.570540    0.070470    0.012482    0.690575    
#> 446: 0.749334    1.021988    3.476811    0.570427    0.070523    0.012489    0.690576    
#> 447: 0.749334    1.022074    3.476773    0.570344    0.070518    0.012503    0.690533    
#> 448: 0.749324    1.022178    3.476772    0.570203    0.070532    0.012519    0.690421    
#> 449: 0.749358    1.022260    3.476834    0.570276    0.070562    0.012533    0.690398    
#> 450: 0.749298    1.022274    3.476817    0.570428    0.070550    0.012546    0.690335    
#> 451: 0.749339    1.022340    3.476798    0.570521    0.070547    0.012561    0.690317    
#> 452: 0.749124    1.022436    3.476720    0.570480    0.070541    0.012557    0.690327    
#> 453: 0.748960    1.022465    3.476671    0.570160    0.070544    0.012555    0.690292    
#> 454: 0.748755    1.022605    3.476598    0.569675    0.070562    0.012544    0.690233    
#> 455: 0.748711    1.022656    3.476528    0.569581    0.070585    0.012528    0.690265    
#> 456: 0.748524    1.022623    3.476500    0.569422    0.070628    0.012519    0.690290    
#> 457: 0.748495    1.022538    3.476530    0.569312    0.070628    0.012513    0.690200    
#> 458: 0.748576    1.022565    3.476556    0.569318    0.070634    0.012515    0.690151    
#> 459: 0.748551    1.022627    3.476587    0.569375    0.070574    0.012516    0.690150    
#> 460: 0.748488    1.022670    3.476567    0.569278    0.070545    0.012522    0.690131    
#> 461: 0.748513    1.022746    3.476558    0.569521    0.070554    0.012527    0.690112    
#> 462: 0.748495    1.022921    3.476564    0.569801    0.070577    0.012530    0.690091    
#> 463: 0.748576    1.023001    3.476568    0.570007    0.070573    0.012537    0.690088    
#> 464: 0.748603    1.023093    3.476551    0.570020    0.070570    0.012537    0.690064    
#> 465: 0.748822    1.023037    3.476580    0.570309    0.070542    0.012533    0.690078    
#> 466: 0.748957    1.023115    3.476569    0.570379    0.070543    0.012533    0.690009    
#> 467: 0.748739    1.023097    3.476552    0.570181    0.070546    0.012534    0.689893    
#> 468: 0.748877    1.023187    3.476570    0.570324    0.070549    0.012537    0.689828    
#> 469: 0.748943    1.023322    3.476570    0.570251    0.070534    0.012542    0.689827    
#> 470: 0.748872    1.023262    3.476553    0.570115    0.070507    0.012551    0.689808    
#> 471: 0.748688    1.023252    3.476531    0.569602    0.070499    0.012549    0.689785    
#> 472: 0.748522    1.023249    3.476523    0.569126    0.070514    0.012545    0.689776    
#> 473: 0.748469    1.023232    3.476557    0.569068    0.070514    0.012537    0.689738    
#> 474: 0.748412    1.023219    3.476562    0.569390    0.070535    0.012540    0.689792    
#> 475: 0.748218    1.023259    3.476523    0.569139    0.070520    0.012549    0.689844    
#> 476: 0.748130    1.023279    3.476496    0.569178    0.070522    0.012561    0.689904    
#> 477: 0.747978    1.023295    3.476509    0.569085    0.070507    0.012570    0.689850    
#> 478: 0.747927    1.023256    3.476520    0.568988    0.070463    0.012574    0.689878    
#> 479: 0.748025    1.023267    3.476538    0.568919    0.070447    0.012580    0.689891    
#> 480: 0.748114    1.023200    3.476582    0.568968    0.070437    0.012576    0.689936    
#> 481: 0.748025    1.023207    3.476570    0.568739    0.070466    0.012571    0.689908    
#> 482: 0.747951    1.023231    3.476525    0.568445    0.070457    0.012569    0.689894    
#> 483: 0.747872    1.023228    3.476513    0.568177    0.070509    0.012561    0.689875    
#> 484: 0.747868    1.023147    3.476502    0.568103    0.070549    0.012558    0.689871    
#> 485: 0.747868    1.023180    3.476517    0.568128    0.070544    0.012547    0.689912    
#> 486: 0.747870    1.023287    3.476515    0.568089    0.070543    0.012540    0.689858    
#> 487: 0.747978    1.023334    3.476577    0.567947    0.070546    0.012538    0.689814    
#> 488: 0.747930    1.023381    3.476584    0.567573    0.070531    0.012529    0.689812    
#> 489: 0.747990    1.023348    3.476573    0.567451    0.070518    0.012522    0.689762    
#> 490: 0.748090    1.023378    3.476568    0.567444    0.070511    0.012518    0.689694    
#> 491: 0.748089    1.023494    3.476563    0.567420    0.070522    0.012516    0.689640    
#> 492: 0.748102    1.023587    3.476545    0.567439    0.070479    0.012520    0.689704    
#> 493: 0.748054    1.023572    3.476556    0.567403    0.070455    0.012530    0.689716    
#> 494: 0.748253    1.023612    3.476537    0.567350    0.070418    0.012542    0.689660    
#> 495: 0.748340    1.023620    3.476564    0.567532    0.070370    0.012546    0.689676    
#> 496: 0.748470    1.023666    3.476556    0.567617    0.070336    0.012553    0.689645    
#> 497: 0.748459    1.023644    3.476544    0.567872    0.070338    0.012563    0.689569    
#> 498: 0.748447    1.023658    3.476523    0.568088    0.070362    0.012563    0.689494    
#> 499: 0.748519    1.023702    3.476478    0.568390    0.070323    0.012558    0.689471    
#> 500: 0.748560    1.023636    3.476444    0.568549    0.070273    0.012560    0.689521    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.253550    0.984587    3.444557    0.392401    0.082857    0.016800    1.692907    
#> 002: 0.196541    1.021424    3.487307    0.372781    0.078714    0.015960    1.100198    
#> 003: 0.258731    1.013625    3.492727    0.354142    0.103463    0.015162    0.871558    
#> 004: 0.207408    1.054322    3.498514    0.336435    0.130102    0.014404    0.767615    
#> 005: 0.231599    1.084875    3.486494    0.319613    0.143253    0.013684    0.697403    
#> 006: 0.235733    1.090564    3.476477    0.303633    0.136091    0.013000    0.641157    
#> 007: 0.183464    1.108715    3.469725    0.288451    0.129286    0.012350    0.646922    
#> 008: 0.175057    1.091482    3.469373    0.274029    0.122822    0.012349    0.653785    
#> 009: 0.152854    1.081057    3.456854    0.260327    0.116681    0.013338    0.662595    
#> 010: 0.152468    1.103883    3.461525    0.247311    0.117480    0.012671    0.679390    
#> 011: 0.195542    1.113980    3.451810    0.234945    0.111606    0.012392    0.661691    
#> 012: 0.207641    1.100801    3.456886    0.223198    0.116678    0.012206    0.652144    
#> 013: 0.171479    1.119068    3.456394    0.212038    0.112874    0.015247    0.674105    
#> 014: 0.200791    1.105924    3.467365    0.273930    0.125537    0.015621    0.663252    
#> 015: 0.221422    1.098515    3.480573    0.260233    0.119260    0.018401    0.631198    
#> 016: 0.219651    1.108579    3.479716    0.247222    0.113297    0.018176    0.628003    
#> 017: 0.214500    1.112228    3.482909    0.258195    0.107632    0.021685    0.606549    
#> 018: 0.217156    1.105476    3.474799    0.245285    0.102251    0.020648    0.616401    
#> 019: 0.187931    1.105930    3.468589    0.233021    0.097138    0.019615    0.618025    
#> 020: 0.208900    1.119163    3.477222    0.221370    0.110354    0.018634    0.635424    
#> 021: 0.223275    1.101281    3.485217    0.263238    0.104836    0.017769    0.615110    
#> 022: 0.211695    1.121908    3.486568    0.250076    0.100927    0.018593    0.615494    
#> 023: 0.282959    1.103221    3.493979    0.243863    0.095881    0.018508    0.640877    
#> 024: 0.277769    1.113171    3.495760    0.231670    0.091087    0.019086    0.625441    
#> 025: 0.269098    1.074385    3.496263    0.220086    0.086533    0.023453    0.629456    
#> 026: 0.241293    1.104846    3.485907    0.209082    0.082206    0.022281    0.631129    
#> 027: 0.211514    1.123296    3.473852    0.207506    0.080524    0.021167    0.640247    
#> 028: 0.244043    1.105734    3.486307    0.197678    0.077232    0.020108    0.614210    
#> 029: 0.259735    1.112581    3.477424    0.188851    0.093542    0.019103    0.651100    
#> 030: 0.237815    1.127289    3.476661    0.204346    0.105578    0.018148    0.626469    
#> 031: 0.209885    1.109793    3.481602    0.200361    0.100299    0.017542    0.646335    
#> 032: 0.180368    1.085627    3.486339    0.195994    0.100183    0.019160    0.641349    
#> 033: 0.171916    1.112064    3.465181    0.227361    0.101701    0.018202    0.644197    
#> 034: 0.221877    1.105674    3.477680    0.228537    0.106368    0.017484    0.649714    
#> 035: 0.233977    1.089057    3.477635    0.217110    0.106530    0.017391    0.634145    
#> 036: 0.220111    1.096767    3.485644    0.206254    0.101203    0.018775    0.654795    
#> 037: 0.221632    1.118389    3.483226    0.195942    0.107520    0.021964    0.654815    
#> 038: 0.273131    1.094617    3.482397    0.254095    0.102144    0.023208    0.646276    
#> 039: 0.271899    1.095005    3.501205    0.241390    0.097036    0.025758    0.629368    
#> 040: 0.256004    1.079338    3.502979    0.229321    0.092185    0.024470    0.646191    
#> 041: 0.217622    1.089560    3.489823    0.217854    0.097125    0.024927    0.629025    
#> 042: 0.255457    1.090496    3.489942    0.206962    0.092269    0.025750    0.628519    
#> 043: 0.218014    1.089937    3.473195    0.204992    0.087655    0.024463    0.624229    
#> 044: 0.204787    1.103919    3.471192    0.215550    0.085299    0.023239    0.627579    
#> 045: 0.209918    1.130281    3.462439    0.244872    0.083208    0.024330    0.621777    
#> 046: 0.188522    1.113436    3.456737    0.232628    0.084893    0.023113    0.616799    
#> 047: 0.182737    1.123538    3.458848    0.220997    0.080648    0.021958    0.619785    
#> 048: 0.196991    1.117426    3.460253    0.269809    0.076616    0.024090    0.628026    
#> 049: 0.199521    1.113123    3.467733    0.256318    0.078131    0.025398    0.638546    
#> 050: 0.254425    1.086682    3.475732    0.281455    0.077402    0.024128    0.642571    
#> 051: 0.248638    1.096484    3.473391    0.310759    0.082053    0.026623    0.634812    
#> 052: 0.264099    1.103642    3.490547    0.295221    0.077951    0.027441    0.612359    
#> 053: 0.226557    1.084545    3.478075    0.280460    0.074053    0.028963    0.627820    
#> 054: 0.230386    1.088954    3.482322    0.270926    0.070351    0.031116    0.633022    
#> 055: 0.226597    1.101406    3.479933    0.257380    0.080211    0.029560    0.627893    
#> 056: 0.228134    1.076312    3.486734    0.244511    0.076200    0.028759    0.638706    
#> 057: 0.203263    1.088782    3.481336    0.232285    0.072390    0.027321    0.642855    
#> 058: 0.226101    1.101593    3.478883    0.221141    0.071981    0.026938    0.626592    
#> 059: 0.201307    1.087799    3.482722    0.228461    0.068382    0.027844    0.629638    
#> 060: 0.210145    1.085198    3.484745    0.245222    0.064962    0.032902    0.639534    
#> 061: 0.244951    1.099648    3.498396    0.252481    0.061714    0.034121    0.641274    
#> 062: 0.239569    1.112169    3.495857    0.239857    0.067021    0.032415    0.643687    
#> 063: 0.299324    1.084485    3.499327    0.234512    0.082535    0.030794    0.632484    
#> 064: 0.263419    1.095869    3.505294    0.222786    0.078408    0.029254    0.634720    
#> 065: 0.279927    1.089967    3.500242    0.213408    0.074488    0.029208    0.622589    
#> 066: 0.273879    1.114530    3.496143    0.202737    0.072787    0.031835    0.627668    
#> 067: 0.262210    1.070901    3.490904    0.192600    0.072207    0.031661    0.627413    
#> 068: 0.212283    1.071244    3.501648    0.190932    0.068597    0.037144    0.632533    
#> 069: 0.196246    1.080005    3.486235    0.215371    0.065167    0.038951    0.636814    
#> 070: 0.254942    1.083124    3.495980    0.229865    0.061909    0.037003    0.633933    
#> 071: 0.222934    1.100475    3.479475    0.220284    0.062888    0.035153    0.641350    
#> 072: 0.212957    1.070761    3.493375    0.244834    0.059744    0.039353    0.633007    
#> 073: 0.259229    1.084039    3.505050    0.262227    0.061106    0.037385    0.622251    
#> 074: 0.247975    1.070714    3.485069    0.278594    0.058544    0.035516    0.607836    
#> 075: 0.280585    1.057251    3.519423    0.279902    0.062535    0.038076    0.628613    
#> 076: 0.309779    1.076245    3.515765    0.265907    0.059916    0.040325    0.621214    
#> 077: 0.305286    1.069040    3.520324    0.252612    0.067978    0.038308    0.626459    
#> 078: 0.282598    1.094257    3.508139    0.247262    0.064579    0.036393    0.606865    
#> 079: 0.269981    1.093184    3.501743    0.295781    0.061350    0.034573    0.610141    
#> 080: 0.289232    1.089523    3.503045    0.314584    0.064876    0.032845    0.621886    
#> 081: 0.275210    1.104331    3.501954    0.298855    0.073851    0.032798    0.603342    
#> 082: 0.258416    1.090001    3.498838    0.283912    0.071300    0.033965    0.615041    
#> 083: 0.230147    1.113877    3.488837    0.269717    0.073768    0.032266    0.622393    
#> 084: 0.235910    1.102893    3.491074    0.256231    0.073822    0.030876    0.607377    
#> 085: 0.243805    1.111140    3.501606    0.243419    0.071420    0.029332    0.622140    
#> 086: 0.253564    1.117955    3.498787    0.231248    0.086874    0.027950    0.625539    
#> 087: 0.224568    1.103098    3.483875    0.219686    0.100306    0.026552    0.635361    
#> 088: 0.156989    1.119403    3.475131    0.208702    0.096451    0.025224    0.653624    
#> 089: 0.211361    1.098232    3.476020    0.198267    0.091629    0.023963    0.634158    
#> 090: 0.193287    1.095589    3.467447    0.207227    0.093394    0.025202    0.635021    
#> 091: 0.194048    1.096366    3.461039    0.242128    0.088724    0.028679    0.629531    
#> 092: 0.186782    1.141002    3.451336    0.248204    0.087451    0.027245    0.630441    
#> 093: 0.168697    1.113208    3.461403    0.235998    0.093206    0.025883    0.639240    
#> 094: 0.189897    1.112724    3.453910    0.224198    0.088545    0.024589    0.645931    
#> 095: 0.199504    1.106626    3.474182    0.247451    0.084118    0.024951    0.638100    
#> 096: 0.181307    1.100389    3.475502    0.251143    0.079912    0.027858    0.631387    
#> 097: 0.214792    1.113124    3.466433    0.247644    0.080652    0.026466    0.634089    
#> 098: 0.177062    1.132675    3.470323    0.235262    0.076620    0.025142    0.642818    
#> 099: 0.205738    1.108013    3.467168    0.239337    0.077168    0.028594    0.621201    
#> 100: 0.216385    1.114024    3.474391    0.227371    0.073309    0.028131    0.610487    
#> 101: 0.200888    1.098775    3.459919    0.218142    0.072319    0.026725    0.614487    
#> 102: 0.211847    1.099170    3.470384    0.207235    0.084259    0.025389    0.620898    
#> 103: 0.230683    1.099176    3.481520    0.217857    0.082706    0.027371    0.611415    
#> 104: 0.205799    1.110790    3.482384    0.232769    0.078571    0.028650    0.635162    
#> 105: 0.238449    1.110209    3.486979    0.250186    0.074642    0.027547    0.626603    
#> 106: 0.224084    1.101725    3.477820    0.263126    0.078459    0.030875    0.616339    
#> 107: 0.234191    1.105878    3.488399    0.264830    0.087185    0.029331    0.627859    
#> 108: 0.246221    1.102682    3.488910    0.277308    0.087149    0.029030    0.634100    
#> 109: 0.251399    1.091988    3.504577    0.288076    0.082792    0.031481    0.609778    
#> 110: 0.240663    1.095128    3.482381    0.273673    0.078652    0.033654    0.609839    
#> 111: 0.247254    1.103389    3.489768    0.259989    0.074719    0.034609    0.601159    
#> 112: 0.279414    1.093991    3.490370    0.270308    0.071354    0.033191    0.608485    
#> 113: 0.237915    1.112484    3.486659    0.278577    0.068414    0.034748    0.617673    
#> 114: 0.259242    1.097051    3.496058    0.264648    0.069006    0.036229    0.616571    
#> 115: 0.260749    1.070734    3.481968    0.251416    0.067611    0.034418    0.641933    
#> 116: 0.268782    1.101177    3.487226    0.241826    0.082911    0.032697    0.642050    
#> 117: 0.239228    1.111958    3.490431    0.241479    0.078766    0.031062    0.634495    
#> 118: 0.245934    1.094227    3.484979    0.273709    0.081666    0.029509    0.615386    
#> 119: 0.248180    1.093988    3.494938    0.272466    0.077582    0.034157    0.621376    
#> 120: 0.232679    1.069667    3.493325    0.258843    0.073703    0.032449    0.625588    
#> 121: 0.234167    1.131566    3.488153    0.245900    0.075085    0.030827    0.625908    
#> 122: 0.218929    1.115140    3.475979    0.263130    0.079496    0.029285    0.623734    
#> 123: 0.242974    1.125300    3.475803    0.249974    0.082601    0.027821    0.630751    
#> 124: 0.245018    1.145748    3.475721    0.266001    0.084140    0.026430    0.630010    
#> 125: 0.262134    1.128532    3.479692    0.252701    0.081860    0.025108    0.621526    
#> 126: 0.233725    1.129879    3.463303    0.240066    0.096320    0.026283    0.624190    
#> 127: 0.244544    1.105028    3.469064    0.228062    0.091504    0.024969    0.640427    
#> 128: 0.191204    1.110743    3.480723    0.220329    0.097353    0.025651    0.636149    
#> 129: 0.226720    1.111949    3.485022    0.242519    0.092485    0.024867    0.639700    
#> 130: 0.251187    1.122746    3.478520    0.240478    0.087861    0.029077    0.630910    
#> 131: 0.224911    1.100972    3.474400    0.257747    0.083468    0.027624    0.633992    
#> 132: 0.173239    1.116507    3.454812    0.256708    0.084924    0.026242    0.638686    
#> 133: 0.182475    1.109159    3.456920    0.243873    0.080678    0.027163    0.625426    
#> 134: 0.191397    1.082777    3.482554    0.234424    0.076644    0.032470    0.621723    
#> 135: 0.165382    1.097758    3.475026    0.222703    0.072812    0.034584    0.638897    
#> 136: 0.217998    1.088792    3.474428    0.245726    0.069171    0.044744    0.633249    
#> 137: 0.238587    1.109969    3.483454    0.233440    0.066912    0.042507    0.629594    
#> 138: 0.224399    1.112346    3.490119    0.221768    0.080292    0.040382    0.614305    
#> 139: 0.246243    1.082877    3.510607    0.235650    0.076277    0.038547    0.622382    
#> 140: 0.268773    1.091851    3.507989    0.259351    0.072463    0.037580    0.635019    
#> 141: 0.265743    1.066231    3.510922    0.260561    0.068840    0.038214    0.632298    
#> 142: 0.284166    1.053024    3.520183    0.247533    0.065398    0.043118    0.639170    
#> 143: 0.240275    1.067892    3.501762    0.260026    0.062128    0.043822    0.636016    
#> 144: 0.279910    1.090604    3.512728    0.247025    0.066786    0.041631    0.619353    
#> 145: 0.262285    1.098683    3.485830    0.236060    0.065257    0.039549    0.618602    
#> 146: 0.210311    1.096508    3.486251    0.229709    0.069710    0.037572    0.621777    
#> 147: 0.181681    1.100223    3.468815    0.238924    0.066224    0.035693    0.617245    
#> 148: 0.205608    1.115282    3.483134    0.250098    0.079951    0.033908    0.612393    
#> 149: 0.207485    1.110897    3.469939    0.250124    0.080213    0.032213    0.613598    
#> 150: 0.222085    1.112472    3.463935    0.237618    0.084081    0.032612    0.621603    
#> 151: 0.193177    1.139963    3.467786    0.225737    0.084607    0.030981    0.615819    
#> 152: 0.189182    1.126832    3.472855    0.234116    0.073699    0.029543    0.615191    
#> 153: 0.196399    1.120036    3.479579    0.222947    0.072940    0.032380    0.618361    
#> 154: 0.229589    1.115377    3.484003    0.218369    0.071977    0.030654    0.635919    
#> 155: 0.202935    1.099681    3.472242    0.215677    0.074482    0.035050    0.616299    
#> 156: 0.212937    1.116148    3.474456    0.198116    0.078464    0.029357    0.635639    
#> 157: 0.245721    1.106818    3.482805    0.216423    0.066175    0.034220    0.637787    
#> 158: 0.237392    1.103042    3.491248    0.242884    0.069690    0.031906    0.626462    
#> 159: 0.211928    1.119774    3.493897    0.226837    0.075359    0.032479    0.624155    
#> 160: 0.244470    1.082667    3.498554    0.241355    0.074512    0.034784    0.615865    
#> 161: 0.235697    1.079500    3.499715    0.215680    0.059757    0.041610    0.633722    
#> 162: 0.221398    1.107030    3.489972    0.229808    0.065834    0.037614    0.630488    
#> 163: 0.254852    1.083245    3.492121    0.290292    0.075381    0.034034    0.620001    
#> 164: 0.247720    1.096500    3.489677    0.229579    0.077590    0.032720    0.615764    
#> 165: 0.250280    1.086103    3.492647    0.208258    0.081116    0.028042    0.616178    
#> 166: 0.280679    1.109289    3.498879    0.237589    0.072797    0.030853    0.626109    
#> 167: 0.252202    1.110948    3.498928    0.230273    0.077408    0.035558    0.620373    
#> 168: 0.278347    1.099587    3.498071    0.258614    0.064708    0.034737    0.616104    
#> 169: 0.258538    1.127874    3.486124    0.221623    0.064795    0.037110    0.622135    
#> 170: 0.238612    1.089822    3.496403    0.186314    0.067872    0.031043    0.622493    
#> 171: 0.181411    1.099907    3.469343    0.211623    0.073368    0.029158    0.613691    
#> 172: 0.177064    1.122663    3.465927    0.233096    0.088135    0.025604    0.621143    
#> 173: 0.189689    1.139236    3.462011    0.239333    0.078746    0.029303    0.606100    
#> 174: 0.227078    1.123836    3.481891    0.213502    0.084399    0.029872    0.633075    
#> 175: 0.201895    1.117435    3.465613    0.238734    0.071947    0.031570    0.611507    
#> 176: 0.193493    1.109901    3.485252    0.237055    0.069883    0.031622    0.618750    
#> 177: 0.230580    1.090721    3.490696    0.253417    0.067473    0.037696    0.624411    
#> 178: 0.244329    1.081401    3.491125    0.215990    0.076502    0.034016    0.619413    
#> 179: 0.247713    1.118135    3.486481    0.226779    0.066281    0.028793    0.628582    
#> 180: 0.192713    1.121316    3.473295    0.217686    0.082351    0.025647    0.629758    
#> 181: 0.198504    1.105633    3.463291    0.223526    0.083568    0.027237    0.630977    
#> 182: 0.172622    1.114615    3.461090    0.234685    0.070646    0.031552    0.632867    
#> 183: 0.225036    1.131041    3.476690    0.185410    0.089581    0.029224    0.631631    
#> 184: 0.222146    1.109389    3.486300    0.199523    0.087672    0.031626    0.625247    
#> 185: 0.186113    1.119888    3.466383    0.209068    0.071599    0.029826    0.611224    
#> 186: 0.188029    1.138907    3.466647    0.219524    0.080489    0.031219    0.627931    
#> 187: 0.223687    1.122876    3.471247    0.238305    0.078410    0.032521    0.608233    
#> 188: 0.175016    1.136671    3.463426    0.261928    0.083300    0.033469    0.610409    
#> 189: 0.179610    1.142996    3.461189    0.234386    0.087243    0.027090    0.630924    
#> 190: 0.187127    1.127365    3.468478    0.195424    0.074990    0.031015    0.619508    
#> 191: 0.185475    1.127237    3.464649    0.208236    0.072974    0.028626    0.623428    
#> 192: 0.163103    1.133463    3.460612    0.225276    0.082650    0.025541    0.615336    
#> 193: 0.211604    1.132721    3.467445    0.237806    0.086343    0.025703    0.601841    
#> 194: 0.199783    1.113078    3.462750    0.229393    0.072834    0.027522    0.628014    
#> 195: 0.182259    1.116267    3.467981    0.234515    0.073319    0.029632    0.615399    
#> 196: 0.208787    1.122511    3.470144    0.246375    0.060116    0.033256    0.636245    
#> 197: 0.166085    1.115425    3.483913    0.212095    0.066816    0.033605    0.652478    
#> 198: 0.214115    1.100106    3.470851    0.228899    0.058555    0.040060    0.616284    
#> 199: 0.210646    1.098971    3.475381    0.225401    0.068148    0.041068    0.629320    
#> 200: 0.225815    1.108979    3.482405    0.241437    0.062799    0.040445    0.633565    
#> 201: 0.227516    1.104231    3.493278    0.250307    0.059234    0.043246    0.636196    
#> 202: 0.221533    1.107932    3.491794    0.248814    0.060097    0.042680    0.631776    
#> 203: 0.234828    1.106598    3.489417    0.252967    0.060286    0.042404    0.633345    
#> 204: 0.237111    1.097818    3.491948    0.249325    0.062361    0.040903    0.629551    
#> 205: 0.234127    1.099244    3.491162    0.243369    0.063366    0.039761    0.632314    
#> 206: 0.233722    1.102292    3.491125    0.244728    0.063600    0.039517    0.631799    
#> 207: 0.232989    1.103743    3.489239    0.240403    0.063650    0.039003    0.631501    
#> 208: 0.230360    1.104715    3.488883    0.237521    0.063611    0.038602    0.631813    
#> 209: 0.230325    1.104144    3.488017    0.239796    0.064949    0.037667    0.630795    
#> 210: 0.231702    1.103389    3.487589    0.240647    0.065972    0.037234    0.629565    
#> 211: 0.232322    1.105647    3.487036    0.242559    0.067396    0.036326    0.627839    
#> 212: 0.234714    1.104628    3.487411    0.243469    0.068524    0.035476    0.628105    
#> 213: 0.236147    1.102060    3.488495    0.239522    0.070205    0.034924    0.629301    
#> 214: 0.239785    1.100270    3.489779    0.237850    0.071798    0.034266    0.630605    
#> 215: 0.239641    1.099642    3.490898    0.236865    0.072411    0.033810    0.630080    
#> 216: 0.242056    1.098109    3.491538    0.238742    0.072571    0.033570    0.630533    
#> 217: 0.243778    1.098381    3.492102    0.240884    0.073188    0.033245    0.629109    
#> 218: 0.244538    1.098787    3.492320    0.242370    0.073409    0.032867    0.628742    
#> 219: 0.244575    1.098571    3.491410    0.243613    0.073255    0.032619    0.628441    
#> 220: 0.243230    1.098321    3.491165    0.244972    0.073418    0.032766    0.628405    
#> 221: 0.242144    1.098549    3.490713    0.244964    0.073600    0.032816    0.628599    
#> 222: 0.242133    1.098976    3.489813    0.246327    0.073589    0.033105    0.629281    
#> 223: 0.243143    1.098605    3.489954    0.246318    0.073913    0.033303    0.628785    
#> 224: 0.244244    1.098972    3.489898    0.248308    0.073709    0.033385    0.628622    
#> 225: 0.244288    1.097902    3.490205    0.249280    0.073504    0.033563    0.628852    
#> 226: 0.243738    1.097373    3.489881    0.249637    0.073289    0.033902    0.628185    
#> 227: 0.243345    1.097553    3.489858    0.250808    0.072937    0.034208    0.627425    
#> 228: 0.241640    1.097710    3.489430    0.252306    0.072609    0.034341    0.627165    
#> 229: 0.241092    1.097247    3.489194    0.252725    0.072153    0.034396    0.626524    
#> 230: 0.241308    1.096765    3.489087    0.252472    0.072025    0.034344    0.626535    
#> 231: 0.241130    1.096883    3.489409    0.251397    0.071989    0.034341    0.626757    
#> 232: 0.240565    1.096436    3.489636    0.252279    0.072174    0.034302    0.626588    
#> 233: 0.240638    1.095221    3.489906    0.254026    0.072138    0.034199    0.626466    
#> 234: 0.240199    1.094756    3.489732    0.254745    0.071985    0.034341    0.626482    
#> 235: 0.240298    1.094333    3.489584    0.255184    0.071903    0.034447    0.626144    
#> 236: 0.239539    1.094740    3.489203    0.255694    0.071990    0.034347    0.625944    
#> 237: 0.239537    1.094725    3.489192    0.255508    0.072035    0.034124    0.626383    
#> 238: 0.239535    1.095079    3.489176    0.255204    0.071999    0.033971    0.626629    
#> 239: 0.239281    1.095646    3.488975    0.255004    0.072069    0.033789    0.626424    
#> 240: 0.239666    1.095561    3.489037    0.253982    0.072086    0.033578    0.626648    
#> 241: 0.240250    1.095164    3.489111    0.253118    0.072410    0.033272    0.626815    
#> 242: 0.240430    1.094859    3.489012    0.252753    0.072473    0.032978    0.627170    
#> 243: 0.240179    1.094936    3.489099    0.252453    0.072682    0.032799    0.627700    
#> 244: 0.239862    1.094980    3.489080    0.252092    0.072779    0.032551    0.627973    
#> 245: 0.240323    1.094560    3.489413    0.251349    0.073288    0.032479    0.628426    
#> 246: 0.240707    1.094243    3.489486    0.250742    0.073615    0.032325    0.628680    
#> 247: 0.240855    1.093938    3.489769    0.249349    0.073750    0.032164    0.628850    
#> 248: 0.241017    1.094377    3.489676    0.249006    0.073828    0.031975    0.628737    
#> 249: 0.240578    1.094578    3.489738    0.247972    0.074064    0.031797    0.628891    
#> 250: 0.241075    1.094997    3.489856    0.247895    0.074436    0.031633    0.629059    
#> 251: 0.241332    1.095397    3.490019    0.247208    0.074580    0.031547    0.629189    
#> 252: 0.241397    1.095776    3.490332    0.247449    0.074604    0.031443    0.629080    
#> 253: 0.241392    1.095878    3.490477    0.246994    0.074660    0.031312    0.629215    
#> 254: 0.241259    1.096099    3.490430    0.246721    0.074697    0.031228    0.629012    
#> 255: 0.241167    1.096365    3.490562    0.246371    0.074826    0.031147    0.629046    
#> 256: 0.241228    1.096237    3.490586    0.246239    0.074963    0.031029    0.629076    
#> 257: 0.240932    1.095841    3.490449    0.245948    0.075002    0.030976    0.629019    
#> 258: 0.240896    1.095441    3.490567    0.246351    0.075008    0.031008    0.628771    
#> 259: 0.241137    1.095151    3.490635    0.246547    0.074936    0.031127    0.628486    
#> 260: 0.240983    1.095165    3.490647    0.246365    0.075025    0.031151    0.628086    
#> 261: 0.241289    1.094883    3.490776    0.246341    0.075006    0.031139    0.627771    
#> 262: 0.241798    1.095042    3.490904    0.246801    0.075013    0.031151    0.627609    
#> 263: 0.241889    1.095240    3.490953    0.247065    0.075146    0.031116    0.627726    
#> 264: 0.242021    1.095569    3.491009    0.247105    0.075526    0.031042    0.627624    
#> 265: 0.242335    1.095658    3.491073    0.247866    0.075712    0.031055    0.627496    
#> 266: 0.242817    1.095620    3.491210    0.248235    0.075880    0.031045    0.627380    
#> 267: 0.243068    1.095291    3.491442    0.248305    0.075751    0.030994    0.627195    
#> 268: 0.243244    1.095023    3.491471    0.248170    0.075691    0.030957    0.627329    
#> 269: 0.243838    1.094977    3.491592    0.248255    0.075597    0.031004    0.627285    
#> 270: 0.244033    1.095268    3.491482    0.248041    0.075560    0.030980    0.627186    
#> 271: 0.243795    1.095661    3.491298    0.248594    0.075599    0.030976    0.627431    
#> 272: 0.243311    1.095634    3.491132    0.248638    0.075682    0.031034    0.627659    
#> 273: 0.242688    1.096031    3.490929    0.248332    0.075776    0.031085    0.627826    
#> 274: 0.242230    1.096739    3.490812    0.248160    0.075885    0.031136    0.627906    
#> 275: 0.241444    1.097038    3.490457    0.247703    0.075905    0.031125    0.627866    
#> 276: 0.241030    1.097329    3.490362    0.248263    0.075875    0.031138    0.627889    
#> 277: 0.240620    1.097495    3.490329    0.248539    0.075886    0.031196    0.627731    
#> 278: 0.240345    1.097520    3.490270    0.248767    0.075829    0.031217    0.627590    
#> 279: 0.240050    1.097394    3.490142    0.249383    0.075724    0.031237    0.627721    
#> 280: 0.239807    1.097814    3.490016    0.249584    0.075727    0.031206    0.627518    
#> 281: 0.239495    1.098102    3.490069    0.250032    0.075869    0.031172    0.627427    
#> 282: 0.239293    1.098268    3.489948    0.250214    0.075982    0.031112    0.627600    
#> 283: 0.239147    1.098631    3.489830    0.250512    0.076073    0.031035    0.627736    
#> 284: 0.238479    1.098656    3.489544    0.250557    0.076112    0.030917    0.627679    
#> 285: 0.238117    1.098765    3.489240    0.250666    0.076272    0.030827    0.627799    
#> 286: 0.238002    1.099002    3.489106    0.250314    0.076443    0.030750    0.627765    
#> 287: 0.237918    1.099202    3.488975    0.250295    0.076561    0.030675    0.627693    
#> 288: 0.238312    1.099140    3.488937    0.250235    0.076651    0.030678    0.627799    
#> 289: 0.238329    1.099162    3.488965    0.249865    0.076745    0.030605    0.627965    
#> 290: 0.238699    1.098953    3.489090    0.249917    0.076790    0.030553    0.628223    
#> 291: 0.238942    1.098961    3.489281    0.249865    0.076735    0.030537    0.628203    
#> 292: 0.239026    1.099084    3.489240    0.249850    0.076566    0.030515    0.628217    
#> 293: 0.238946    1.099162    3.489121    0.249564    0.076513    0.030451    0.628093    
#> 294: 0.238789    1.099259    3.488953    0.249487    0.076522    0.030394    0.627946    
#> 295: 0.238494    1.098974    3.488973    0.249313    0.076378    0.030420    0.627825    
#> 296: 0.238342    1.098930    3.488885    0.249007    0.076392    0.030448    0.627834    
#> 297: 0.237987    1.099068    3.488789    0.248500    0.076375    0.030446    0.627870    
#> 298: 0.237866    1.099068    3.488652    0.248091    0.076258    0.030435    0.627738    
#> 299: 0.237824    1.099301    3.488587    0.247991    0.076202    0.030398    0.627559    
#> 300: 0.237950    1.099232    3.488660    0.248220    0.076156    0.030419    0.627475    
#> 301: 0.238048    1.099188    3.488584    0.248578    0.076199    0.030445    0.627502    
#> 302: 0.238241    1.099251    3.488505    0.248623    0.076195    0.030441    0.627413    
#> 303: 0.238053    1.099358    3.488382    0.248529    0.076300    0.030445    0.627289    
#> 304: 0.237867    1.099687    3.488162    0.248602    0.076436    0.030457    0.627255    
#> 305: 0.237551    1.099619    3.487998    0.248873    0.076414    0.030466    0.627185    
#> 306: 0.237245    1.099601    3.487864    0.248828    0.076363    0.030479    0.627007    
#> 307: 0.236911    1.099542    3.487674    0.248923    0.076270    0.030501    0.627059    
#> 308: 0.236467    1.099504    3.487574    0.248896    0.076235    0.030508    0.627073    
#> 309: 0.236465    1.099306    3.487542    0.249332    0.076376    0.030480    0.627227    
#> 310: 0.236671    1.099094    3.487581    0.249979    0.076408    0.030408    0.627336    
#> 311: 0.236685    1.099162    3.487642    0.250183    0.076449    0.030317    0.627455    
#> 312: 0.236770    1.099069    3.487625    0.250356    0.076444    0.030245    0.627588    
#> 313: 0.236702    1.098852    3.487577    0.250294    0.076447    0.030198    0.627712    
#> 314: 0.236449    1.098882    3.487502    0.250304    0.076497    0.030171    0.627653    
#> 315: 0.236325    1.098986    3.487393    0.250270    0.076566    0.030137    0.627612    
#> 316: 0.236585    1.098983    3.487474    0.250132    0.076495    0.030168    0.627713    
#> 317: 0.236717    1.098883    3.487519    0.249829    0.076364    0.030171    0.628040    
#> 318: 0.236964    1.098762    3.487510    0.249669    0.076361    0.030155    0.628082    
#> 319: 0.237139    1.098524    3.487585    0.249532    0.076232    0.030187    0.628078    
#> 320: 0.237078    1.098283    3.487581    0.249311    0.076093    0.030165    0.628102    
#> 321: 0.236698    1.098339    3.487454    0.249302    0.076056    0.030137    0.628140    
#> 322: 0.236536    1.098354    3.487363    0.249159    0.075988    0.030131    0.628035    
#> 323: 0.236138    1.098288    3.487281    0.249193    0.075936    0.030128    0.627917    
#> 324: 0.236294    1.098339    3.487363    0.249333    0.075885    0.030132    0.627727    
#> 325: 0.236290    1.098482    3.487319    0.249355    0.075832    0.030108    0.627772    
#> 326: 0.236223    1.098305    3.487241    0.249241    0.075837    0.030104    0.627674    
#> 327: 0.236453    1.098216    3.487359    0.249334    0.075844    0.030068    0.627635    
#> 328: 0.236707    1.098241    3.487444    0.249459    0.075801    0.030016    0.627564    
#> 329: 0.237132    1.098244    3.487590    0.249621    0.075775    0.029958    0.627457    
#> 330: 0.237050    1.098165    3.487673    0.249284    0.075877    0.029959    0.627480    
#> 331: 0.237046    1.098265    3.487713    0.248960    0.076002    0.029962    0.627307    
#> 332: 0.237160    1.098226    3.487855    0.248522    0.076055    0.029998    0.627341    
#> 333: 0.237125    1.098133    3.487846    0.248433    0.076126    0.030018    0.627256    
#> 334: 0.237103    1.098012    3.487726    0.248624    0.076213    0.030021    0.627221    
#> 335: 0.236853    1.098103    3.487533    0.248855    0.076227    0.029968    0.627211    
#> 336: 0.236295    1.098214    3.487306    0.248775    0.076238    0.029947    0.627266    
#> 337: 0.235848    1.098625    3.487076    0.249049    0.076288    0.029972    0.627261    
#> 338: 0.235515    1.098927    3.486999    0.249176    0.076304    0.029971    0.627288    
#> 339: 0.235098    1.099125    3.486781    0.249267    0.076384    0.029975    0.627236    
#> 340: 0.234850    1.099084    3.486671    0.249476    0.076348    0.030000    0.627173    
#> 341: 0.234800    1.099164    3.486613    0.249872    0.076356    0.030001    0.627154    
#> 342: 0.234602    1.099079    3.486607    0.249754    0.076416    0.029964    0.627191    
#> 343: 0.234301    1.099051    3.486514    0.249532    0.076432    0.029939    0.627195    
#> 344: 0.234314    1.099144    3.486471    0.249361    0.076449    0.029899    0.627251    
#> 345: 0.234403    1.099113    3.486481    0.249089    0.076409    0.029868    0.627376    
#> 346: 0.234320    1.099173    3.486410    0.249027    0.076405    0.029813    0.627393    
#> 347: 0.234274    1.099091    3.486373    0.249162    0.076372    0.029766    0.627553    
#> 348: 0.234121    1.099143    3.486299    0.249161    0.076460    0.029745    0.627709    
#> 349: 0.233867    1.099070    3.486232    0.249123    0.076512    0.029711    0.627707    
#> 350: 0.233540    1.099029    3.486068    0.249347    0.076486    0.029688    0.627622    
#> 351: 0.233572    1.099148    3.485966    0.249637    0.076461    0.029679    0.627626    
#> 352: 0.233356    1.099238    3.485925    0.249727    0.076375    0.029691    0.627763    
#> 353: 0.233358    1.099359    3.485840    0.249951    0.076360    0.029727    0.627764    
#> 354: 0.233273    1.099424    3.485696    0.250251    0.076429    0.029721    0.627808    
#> 355: 0.233265    1.099428    3.485571    0.250561    0.076472    0.029727    0.627767    
#> 356: 0.233075    1.099394    3.485508    0.250430    0.076456    0.029725    0.627937    
#> 357: 0.233063    1.099462    3.485541    0.250304    0.076474    0.029707    0.627950    
#> 358: 0.232912    1.099442    3.485555    0.250193    0.076533    0.029677    0.627921    
#> 359: 0.232844    1.099409    3.485548    0.250007    0.076521    0.029647    0.627841    
#> 360: 0.232909    1.099288    3.485540    0.250020    0.076426    0.029620    0.627768    
#> 361: 0.232872    1.099157    3.485583    0.250007    0.076453    0.029587    0.627653    
#> 362: 0.233057    1.099131    3.485598    0.250078    0.076520    0.029576    0.627509    
#> 363: 0.233224    1.099001    3.485604    0.250089    0.076518    0.029533    0.627423    
#> 364: 0.233403    1.099014    3.485642    0.250166    0.076533    0.029510    0.627377    
#> 365: 0.233336    1.098836    3.485710    0.249948    0.076550    0.029495    0.627356    
#> 366: 0.233455    1.098693    3.485724    0.249671    0.076522    0.029474    0.627422    
#> 367: 0.233474    1.098683    3.485715    0.249730    0.076570    0.029453    0.627342    
#> 368: 0.233478    1.098768    3.485669    0.249948    0.076567    0.029453    0.627193    
#> 369: 0.233407    1.098760    3.485615    0.250069    0.076495    0.029436    0.627200    
#> 370: 0.233370    1.098819    3.485569    0.250063    0.076559    0.029416    0.627219    
#> 371: 0.233214    1.098936    3.485488    0.249971    0.076608    0.029388    0.627216    
#> 372: 0.233111    1.098962    3.485452    0.249786    0.076690    0.029359    0.627248    
#> 373: 0.232862    1.099036    3.485421    0.249790    0.076728    0.029347    0.627274    
#> 374: 0.233002    1.099005    3.485437    0.249799    0.076732    0.029334    0.627186    
#> 375: 0.232991    1.099081    3.485430    0.249743    0.076731    0.029337    0.627219    
#> 376: 0.233036    1.099129    3.485476    0.249613    0.076755    0.029326    0.627136    
#> 377: 0.232879    1.099141    3.485473    0.249523    0.076694    0.029318    0.627102    
#> 378: 0.232671    1.099134    3.485453    0.249428    0.076578    0.029330    0.627124    
#> 379: 0.232622    1.098999    3.485414    0.249504    0.076527    0.029355    0.627021    
#> 380: 0.232638    1.098919    3.485429    0.249483    0.076469    0.029336    0.626948    
#> 381: 0.232543    1.098923    3.485389    0.249589    0.076514    0.029325    0.626833    
#> 382: 0.232350    1.099062    3.485267    0.249485    0.076466    0.029310    0.626741    
#> 383: 0.232462    1.099069    3.485262    0.249194    0.076423    0.029309    0.626676    
#> 384: 0.232268    1.099040    3.485261    0.248937    0.076416    0.029294    0.626690    
#> 385: 0.232433    1.099007    3.485312    0.248757    0.076424    0.029310    0.626602    
#> 386: 0.232706    1.099092    3.485416    0.248576    0.076517    0.029335    0.626582    
#> 387: 0.233055    1.099184    3.485541    0.248479    0.076544    0.029344    0.626580    
#> 388: 0.233244    1.099248    3.485643    0.248189    0.076588    0.029351    0.626600    
#> 389: 0.233306    1.099209    3.485626    0.248049    0.076604    0.029334    0.626651    
#> 390: 0.233044    1.099272    3.485556    0.247740    0.076685    0.029312    0.626715    
#> 391: 0.233109    1.099236    3.485543    0.247566    0.076749    0.029286    0.626761    
#> 392: 0.233242    1.099134    3.485639    0.247667    0.076756    0.029280    0.626843    
#> 393: 0.233351    1.098990    3.485682    0.247603    0.076798    0.029272    0.626835    
#> 394: 0.233482    1.098891    3.485749    0.247447    0.076818    0.029270    0.626805    
#> 395: 0.233738    1.098934    3.485782    0.247262    0.076858    0.029259    0.626784    
#> 396: 0.233987    1.098868    3.485874    0.247201    0.076870    0.029249    0.626715    
#> 397: 0.234056    1.098746    3.485943    0.247143    0.076834    0.029262    0.626724    
#> 398: 0.234209    1.098608    3.486020    0.247186    0.076783    0.029290    0.626700    
#> 399: 0.234377    1.098594    3.486093    0.247294    0.076796    0.029326    0.626628    
#> 400: 0.234447    1.098568    3.486135    0.247305    0.076792    0.029337    0.626668    
#> 401: 0.234380    1.098552    3.486116    0.247302    0.076775    0.029327    0.626790    
#> 402: 0.234349    1.098668    3.486092    0.247228    0.076823    0.029309    0.626831    
#> 403: 0.234532    1.098669    3.486082    0.247214    0.076777    0.029304    0.626902    
#> 404: 0.234602    1.098710    3.485983    0.247215    0.076780    0.029273    0.626952    
#> 405: 0.234598    1.098724    3.485955    0.247187    0.076781    0.029264    0.626979    
#> 406: 0.234629    1.098760    3.485872    0.247315    0.076747    0.029233    0.627086    
#> 407: 0.234508    1.098758    3.485849    0.247263    0.076702    0.029220    0.627165    
#> 408: 0.234585    1.098821    3.485839    0.247186    0.076733    0.029187    0.627176    
#> 409: 0.234610    1.098733    3.485866    0.247149    0.076735    0.029168    0.627155    
#> 410: 0.234567    1.098742    3.485811    0.247160    0.076728    0.029157    0.627160    
#> 411: 0.234621    1.098665    3.485766    0.247181    0.076744    0.029145    0.627140    
#> 412: 0.234416    1.098813    3.485725    0.247129    0.076694    0.029125    0.627225    
#> 413: 0.234286    1.098869    3.485749    0.246900    0.076634    0.029126    0.627342    
#> 414: 0.234133    1.098864    3.485784    0.246879    0.076627    0.029110    0.627334    
#> 415: 0.234305    1.098832    3.485792    0.246880    0.076635    0.029088    0.627367    
#> 416: 0.234402    1.098905    3.485818    0.246706    0.076628    0.029105    0.627444    
#> 417: 0.234551    1.098931    3.485850    0.246570    0.076605    0.029120    0.627425    
#> 418: 0.234524    1.098975    3.485856    0.246511    0.076522    0.029131    0.627332    
#> 419: 0.234435    1.099118    3.485819    0.246290    0.076511    0.029159    0.627265    
#> 420: 0.234367    1.099195    3.485792    0.246145    0.076491    0.029179    0.627140    
#> 421: 0.234225    1.099261    3.485772    0.246070    0.076444    0.029181    0.627090    
#> 422: 0.234363    1.099208    3.485820    0.246134    0.076390    0.029173    0.627062    
#> 423: 0.234515    1.099202    3.485838    0.246092    0.076413    0.029157    0.627082    
#> 424: 0.234474    1.099184    3.485778    0.246132    0.076404    0.029156    0.627052    
#> 425: 0.234445    1.099317    3.485705    0.246283    0.076416    0.029151    0.627004    
#> 426: 0.234292    1.099427    3.485611    0.246325    0.076430    0.029137    0.626906    
#> 427: 0.234093    1.099388    3.485578    0.246405    0.076442    0.029112    0.626836    
#> 428: 0.233985    1.099420    3.485613    0.246381    0.076420    0.029117    0.626787    
#> 429: 0.233909    1.099398    3.485631    0.246453    0.076344    0.029146    0.626720    
#> 430: 0.233869    1.099436    3.485602    0.246479    0.076276    0.029156    0.626730    
#> 431: 0.233719    1.099435    3.485552    0.246418    0.076257    0.029146    0.626676    
#> 432: 0.233636    1.099460    3.485574    0.246324    0.076292    0.029134    0.626643    
#> 433: 0.233602    1.099552    3.485569    0.246152    0.076360    0.029111    0.626614    
#> 434: 0.233532    1.099448    3.485549    0.246062    0.076391    0.029098    0.626563    
#> 435: 0.233441    1.099471    3.485477    0.245974    0.076394    0.029094    0.626547    
#> 436: 0.233318    1.099517    3.485484    0.245992    0.076486    0.029091    0.626540    
#> 437: 0.233319    1.099544    3.485427    0.245962    0.076545    0.029071    0.626497    
#> 438: 0.233199    1.099681    3.485386    0.245910    0.076604    0.029068    0.626464    
#> 439: 0.233183    1.099824    3.485367    0.245864    0.076625    0.029063    0.626349    
#> 440: 0.233066    1.099908    3.485339    0.245822    0.076597    0.029059    0.626287    
#> 441: 0.233044    1.099958    3.485341    0.245845    0.076544    0.029076    0.626176    
#> 442: 0.233023    1.100020    3.485363    0.245823    0.076493    0.029093    0.626105    
#> 443: 0.232999    1.100086    3.485306    0.245917    0.076436    0.029115    0.626037    
#> 444: 0.232899    1.100164    3.485228    0.245969    0.076348    0.029144    0.626032    
#> 445: 0.232668    1.100186    3.485180    0.246026    0.076287    0.029184    0.626077    
#> 446: 0.232500    1.100194    3.485151    0.246214    0.076211    0.029205    0.626052    
#> 447: 0.232610    1.100159    3.485165    0.246446    0.076190    0.029233    0.626019    
#> 448: 0.232665    1.100199    3.485167    0.246497    0.076157    0.029249    0.625959    
#> 449: 0.232737    1.100252    3.485249    0.246470    0.076136    0.029294    0.625927    
#> 450: 0.232770    1.100287    3.485286    0.246502    0.076140    0.029324    0.625878    
#> 451: 0.232937    1.100270    3.485328    0.246498    0.076124    0.029372    0.625853    
#> 452: 0.233038    1.100219    3.485396    0.246427    0.076071    0.029396    0.625835    
#> 453: 0.233062    1.100185    3.485429    0.246419    0.076017    0.029422    0.625797    
#> 454: 0.233030    1.100250    3.485443    0.246233    0.075995    0.029418    0.625784    
#> 455: 0.232960    1.100260    3.485401    0.246290    0.075974    0.029418    0.625808    
#> 456: 0.232851    1.100196    3.485390    0.246375    0.075985    0.029427    0.625847    
#> 457: 0.232776    1.100188    3.485402    0.246374    0.075982    0.029460    0.625793    
#> 458: 0.232669    1.100292    3.485370    0.246385    0.075970    0.029488    0.625775    
#> 459: 0.232580    1.100377    3.485315    0.246477    0.075933    0.029506    0.625778    
#> 460: 0.232459    1.100356    3.485233    0.246466    0.075882    0.029512    0.625768    
#> 461: 0.232279    1.100359    3.485200    0.246444    0.075852    0.029501    0.625757    
#> 462: 0.232165    1.100372    3.485214    0.246346    0.075807    0.029505    0.625746    
#> 463: 0.232130    1.100448    3.485238    0.246254    0.075837    0.029502    0.625743    
#> 464: 0.232170    1.100528    3.485199    0.246186    0.075872    0.029490    0.625709    
#> 465: 0.232148    1.100492    3.485187    0.246190    0.075902    0.029479    0.625684    
#> 466: 0.232151    1.100526    3.485158    0.246180    0.075921    0.029476    0.625632    
#> 467: 0.232088    1.100488    3.485194    0.246100    0.075899    0.029490    0.625523    
#> 468: 0.232240    1.100468    3.485243    0.246016    0.075859    0.029515    0.625480    
#> 469: 0.232320    1.100547    3.485239    0.246029    0.075880    0.029519    0.625493    
#> 470: 0.232193    1.100569    3.485156    0.246232    0.075852    0.029514    0.625479    
#> 471: 0.232067    1.100531    3.485107    0.246405    0.075864    0.029519    0.625479    
#> 472: 0.232022    1.100543    3.485064    0.246304    0.075896    0.029505    0.625594    
#> 473: 0.231792    1.100605    3.485000    0.246163    0.075874    0.029496    0.625584    
#> 474: 0.231705    1.100615    3.484940    0.246146    0.075881    0.029482    0.625594    
#> 475: 0.231618    1.100694    3.484865    0.246273    0.075882    0.029457    0.625573    
#> 476: 0.231444    1.100719    3.484786    0.246221    0.075870    0.029438    0.625562    
#> 477: 0.231341    1.100742    3.484740    0.246166    0.075894    0.029430    0.625481    
#> 478: 0.231168    1.100787    3.484709    0.246097    0.075925    0.029419    0.625521    
#> 479: 0.231155    1.100869    3.484719    0.246088    0.075984    0.029405    0.625507    
#> 480: 0.231114    1.100906    3.484690    0.246007    0.076048    0.029378    0.625512    
#> 481: 0.231184    1.100936    3.484682    0.245989    0.076103    0.029353    0.625468    
#> 482: 0.231192    1.100999    3.484642    0.246021    0.076139    0.029341    0.625510    
#> 483: 0.231131    1.101011    3.484585    0.246033    0.076150    0.029350    0.625504    
#> 484: 0.231041    1.100994    3.484554    0.246060    0.076125    0.029353    0.625503    
#> 485: 0.231056    1.100980    3.484570    0.246140    0.076124    0.029360    0.625571    
#> 486: 0.231062    1.101078    3.484588    0.246175    0.076120    0.029375    0.625577    
#> 487: 0.231167    1.101113    3.484618    0.246267    0.076128    0.029382    0.625538    
#> 488: 0.231168    1.101112    3.484628    0.246291    0.076101    0.029384    0.625459    
#> 489: 0.231317    1.101063    3.484647    0.246323    0.076076    0.029384    0.625447    
#> 490: 0.231430    1.101064    3.484695    0.246348    0.076125    0.029370    0.625376    
#> 491: 0.231502    1.101068    3.484746    0.246364    0.076127    0.029370    0.625313    
#> 492: 0.231607    1.101108    3.484767    0.246509    0.076138    0.029379    0.625335    
#> 493: 0.231588    1.101150    3.484797    0.246406    0.076182    0.029384    0.625335    
#> 494: 0.231705    1.101135    3.484835    0.246305    0.076202    0.029384    0.625310    
#> 495: 0.231799    1.101100    3.484879    0.246176    0.076195    0.029360    0.625361    
#> 496: 0.231897    1.101129    3.484873    0.246207    0.076200    0.029348    0.625449    
#> 497: 0.231905    1.101110    3.484885    0.246304    0.076182    0.029343    0.625540    
#> 498: 0.231894    1.101100    3.484868    0.246287    0.076191    0.029341    0.625503    
#> 499: 0.231876    1.101153    3.484856    0.246241    0.076189    0.029336    0.625453    
#> 500: 0.231913    1.101154    3.484855    0.246148    0.076184    0.029320    0.625411    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.263498    0.963762    3.437910    0.392401    0.086330    0.016800    1.715366    
#> 002: 0.225955    1.020722    3.447226    0.372781    0.082013    0.015960    1.198361    
#> 003: 0.293255    0.949191    3.458326    0.354142    0.077913    0.015162    0.979102    
#> 004: 0.254470    0.973358    3.453547    0.336435    0.074600    0.014404    0.896479    
#> 005: 0.347486    0.974754    3.456059    0.319613    0.070870    0.013684    0.864405    
#> 006: 0.295354    0.974425    3.450736    0.303633    0.077065    0.014037    0.832910    
#> 007: 0.268394    0.988517    3.442486    0.288451    0.086827    0.013335    0.852349    
#> 008: 0.256431    0.992252    3.423645    0.274029    0.107433    0.012668    0.851040    
#> 009: 0.247477    0.961292    3.429188    0.260327    0.102061    0.013198    0.860118    
#> 010: 0.250204    0.972467    3.426548    0.247311    0.096958    0.012648    0.837736    
#> 011: 0.301922    0.974303    3.438570    0.234945    0.092110    0.012206    0.842333    
#> 012: 0.297361    0.977242    3.430072    0.223198    0.096443    0.012770    0.806395    
#> 013: 0.264935    0.978582    3.429872    0.212038    0.091621    0.012131    0.824710    
#> 014: 0.290281    0.977684    3.428275    0.201436    0.087040    0.014739    0.841213    
#> 015: 0.279929    0.987352    3.441640    0.191364    0.082688    0.014002    0.830886    
#> 016: 0.253202    1.013718    3.431435    0.181796    0.078553    0.013551    0.850764    
#> 017: 0.308546    1.005918    3.430334    0.172706    0.082918    0.014590    0.822925    
#> 018: 0.287875    0.981366    3.425775    0.164071    0.084865    0.013861    0.841010    
#> 019: 0.268289    0.990577    3.422295    0.155867    0.080621    0.013168    0.830843    
#> 020: 0.296051    0.992328    3.437603    0.148074    0.078821    0.014629    0.836225    
#> 021: 0.309979    0.972558    3.447408    0.140670    0.083880    0.013897    0.813338    
#> 022: 0.309472    0.958209    3.464684    0.133637    0.079686    0.013202    0.826885    
#> 023: 0.361714    0.967659    3.467623    0.126955    0.093982    0.012542    0.842431    
#> 024: 0.397779    0.966214    3.477145    0.120607    0.089282    0.011915    0.851135    
#> 025: 0.373537    0.933803    3.478696    0.114577    0.107816    0.011319    0.833223    
#> 026: 0.325056    0.959504    3.460130    0.108848    0.102425    0.010753    0.846470    
#> 027: 0.327304    0.973137    3.454271    0.103406    0.097304    0.011486    0.847680    
#> 028: 0.350848    0.970955    3.460894    0.103088    0.092439    0.010912    0.815719    
#> 029: 0.380912    0.980949    3.448368    0.108436    0.087817    0.010367    0.838157    
#> 030: 0.372533    0.984183    3.447833    0.109410    0.083426    0.012357    0.823180    
#> 031: 0.342782    0.975299    3.456694    0.116202    0.079255    0.011739    0.832803    
#> 032: 0.314148    0.963951    3.455641    0.110392    0.088381    0.011152    0.825058    
#> 033: 0.292623    0.988859    3.448910    0.104872    0.103107    0.010595    0.854247    
#> 034: 0.339492    0.989388    3.447011    0.099629    0.097951    0.012543    0.824653    
#> 035: 0.285964    0.974845    3.448465    0.094647    0.095970    0.011916    0.809521    
#> 036: 0.306147    0.993333    3.442252    0.106454    0.091171    0.011320    0.834939    
#> 037: 0.298254    0.983755    3.448061    0.101131    0.086613    0.010754    0.853429    
#> 038: 0.319809    0.982930    3.429752    0.096074    0.084722    0.010216    0.860058    
#> 039: 0.300131    1.000113    3.428286    0.091271    0.084664    0.009706    0.841658    
#> 040: 0.299448    1.007471    3.432603    0.086707    0.084113    0.009727    0.836470    
#> 041: 0.287889    0.982046    3.430267    0.099002    0.098646    0.009240    0.831331    
#> 042: 0.355047    0.971944    3.447172    0.094052    0.102416    0.008778    0.818111    
#> 043: 0.313047    0.980795    3.432551    0.089349    0.101895    0.008339    0.832079    
#> 044: 0.282808    0.990059    3.437150    0.086077    0.096800    0.007922    0.827917    
#> 045: 0.283871    1.024718    3.428682    0.110457    0.100391    0.007526    0.821973    
#> 046: 0.300164    0.978255    3.433565    0.104934    0.095371    0.007150    0.861153    
#> 047: 0.301750    1.003389    3.428622    0.099688    0.093547    0.007818    0.830073    
#> 048: 0.300001    0.981561    3.436500    0.094703    0.088870    0.008733    0.843548    
#> 049: 0.268381    0.999080    3.431809    0.089968    0.084426    0.011244    0.857154    
#> 050: 0.319209    0.955709    3.451944    0.085470    0.092385    0.014862    0.834625    
#> 051: 0.329478    0.958794    3.461409    0.093622    0.087766    0.014140    0.846300    
#> 052: 0.342764    0.975269    3.470289    0.094678    0.083378    0.015621    0.820800    
#> 053: 0.366718    0.971192    3.473687    0.089944    0.079209    0.020823    0.850551    
#> 054: 0.305561    0.949906    3.476197    0.085447    0.075248    0.022530    0.861368    
#> 055: 0.325273    0.938013    3.470205    0.081174    0.077025    0.021404    0.872360    
#> 056: 0.332003    0.939213    3.466893    0.077115    0.079988    0.020334    0.850217    
#> 057: 0.356583    0.946238    3.480657    0.073260    0.087095    0.019317    0.868194    
#> 058: 0.365312    0.936816    3.462618    0.069597    0.082740    0.018351    0.868793    
#> 059: 0.393658    0.918259    3.485198    0.066117    0.078603    0.019756    0.860607    
#> 060: 0.358608    0.915992    3.487189    0.062811    0.074673    0.025878    0.840461    
#> 061: 0.372248    0.929384    3.498080    0.059670    0.070939    0.034343    0.835997    
#> 062: 0.366570    0.955410    3.495212    0.056687    0.067392    0.035640    0.853026    
#> 063: 0.385860    0.930541    3.473602    0.068872    0.064023    0.033858    0.850211    
#> 064: 0.352253    0.975226    3.467883    0.065428    0.066787    0.032165    0.851262    
#> 065: 0.381407    0.965724    3.468190    0.062157    0.068058    0.030557    0.830668    
#> 066: 0.385518    0.970624    3.472790    0.059450    0.064655    0.029029    0.828337    
#> 067: 0.384679    0.957295    3.469656    0.056477    0.061422    0.027577    0.819596    
#> 068: 0.332799    0.959504    3.475946    0.064575    0.071213    0.026198    0.847822    
#> 069: 0.308364    0.960009    3.441108    0.061346    0.076145    0.024888    0.874609    
#> 070: 0.312308    0.977230    3.468094    0.076520    0.085525    0.023644    0.843004    
#> 071: 0.308326    0.992531    3.433852    0.072694    0.081249    0.022462    0.875351    
#> 072: 0.258050    0.940833    3.452572    0.069059    0.077186    0.022636    0.869342    
#> 073: 0.322058    0.965905    3.486229    0.071817    0.073327    0.021504    0.845214    
#> 074: 0.302841    0.948377    3.469696    0.068227    0.069661    0.020429    0.844285    
#> 075: 0.343147    0.950696    3.489437    0.064815    0.066178    0.019407    0.819114    
#> 076: 0.362806    0.943348    3.499019    0.061575    0.062869    0.019244    0.849459    
#> 077: 0.403236    0.923185    3.497137    0.058496    0.059725    0.018946    0.860698    
#> 078: 0.413960    0.916126    3.499915    0.055571    0.056739    0.017998    0.855406    
#> 079: 0.412449    0.927504    3.503111    0.052792    0.055926    0.024655    0.864582    
#> 080: 0.398138    0.926779    3.496347    0.050153    0.053129    0.023422    0.867773    
#> 081: 0.393873    0.918967    3.489403    0.047645    0.050473    0.022251    0.856158    
#> 082: 0.377751    0.902584    3.495310    0.045263    0.047949    0.022582    0.864025    
#> 083: 0.381718    0.938542    3.487783    0.043000    0.047558    0.021851    0.852312    
#> 084: 0.381980    0.968098    3.471324    0.040850    0.056846    0.020759    0.840272    
#> 085: 0.363772    0.978763    3.476409    0.040148    0.061212    0.019721    0.850629    
#> 086: 0.359785    0.956909    3.465475    0.038141    0.058151    0.021183    0.851761    
#> 087: 0.332922    0.963974    3.455594    0.036234    0.055243    0.020124    0.841354    
#> 088: 0.333467    0.961999    3.462872    0.034422    0.052481    0.023006    0.831244    
#> 089: 0.327787    0.969660    3.455613    0.032701    0.049857    0.022911    0.848428    
#> 090: 0.317324    0.986852    3.450049    0.033204    0.047364    0.021766    0.828488    
#> 091: 0.302108    0.958319    3.445958    0.032350    0.044996    0.020677    0.838585    
#> 092: 0.295227    0.968838    3.445717    0.036117    0.051327    0.019644    0.830674    
#> 093: 0.307630    0.957297    3.445433    0.034311    0.057981    0.018661    0.835084    
#> 094: 0.299327    0.966682    3.450776    0.032596    0.055081    0.017728    0.845822    
#> 095: 0.312138    0.965352    3.460639    0.030966    0.052327    0.018090    0.850788    
#> 096: 0.295563    0.980934    3.449484    0.029418    0.051247    0.017185    0.846960    
#> 097: 0.327783    0.999720    3.453161    0.027947    0.048685    0.020385    0.817979    
#> 098: 0.304404    0.996807    3.461135    0.026549    0.061412    0.019718    0.848842    
#> 099: 0.293881    0.978062    3.441911    0.028646    0.058342    0.018732    0.830604    
#> 100: 0.308894    0.976541    3.455244    0.029671    0.056286    0.018954    0.822148    
#> 101: 0.305870    0.948156    3.440780    0.028188    0.053471    0.022052    0.833550    
#> 102: 0.300845    0.963922    3.454168    0.026778    0.057688    0.021287    0.841040    
#> 103: 0.325189    0.955656    3.465891    0.025439    0.064839    0.022139    0.828685    
#> 104: 0.339590    0.968239    3.483235    0.033849    0.061597    0.021479    0.844831    
#> 105: 0.355431    0.954117    3.477170    0.032157    0.067267    0.020405    0.857345    
#> 106: 0.364533    0.935460    3.475355    0.030549    0.063903    0.019385    0.838580    
#> 107: 0.398056    0.962003    3.474809    0.031495    0.068544    0.018835    0.827149    
#> 108: 0.378229    0.965303    3.471116    0.029921    0.065117    0.019053    0.857015    
#> 109: 0.345556    0.961102    3.481680    0.037319    0.061861    0.018100    0.829001    
#> 110: 0.356274    0.960954    3.454953    0.035453    0.060321    0.017195    0.850349    
#> 111: 0.339927    0.973599    3.455492    0.033681    0.064873    0.016336    0.834882    
#> 112: 0.327801    0.945483    3.456906    0.031997    0.066420    0.016497    0.854530    
#> 113: 0.352597    0.986879    3.455971    0.038999    0.063099    0.015673    0.815299    
#> 114: 0.353261    0.969690    3.460072    0.053759    0.060244    0.015169    0.834869    
#> 115: 0.379804    0.934151    3.464443    0.060929    0.087605    0.014411    0.877100    
#> 116: 0.354859    0.938807    3.467233    0.057883    0.083225    0.014244    0.878582    
#> 117: 0.340173    0.984075    3.464239    0.054989    0.079063    0.017672    0.842058    
#> 118: 0.359996    0.933299    3.470621    0.052239    0.075110    0.019703    0.844959    
#> 119: 0.367655    0.928800    3.462989    0.049627    0.071355    0.018718    0.847889    
#> 120: 0.367187    0.919034    3.474527    0.047146    0.077055    0.022515    0.839801    
#> 121: 0.366344    0.959262    3.467858    0.044789    0.073203    0.024699    0.845241    
#> 122: 0.377551    0.930916    3.477550    0.042549    0.069542    0.023950    0.845848    
#> 123: 0.403797    0.956850    3.481435    0.040422    0.070373    0.022753    0.839468    
#> 124: 0.434791    0.968838    3.492688    0.038401    0.066854    0.023666    0.852988    
#> 125: 0.448691    0.951880    3.483835    0.036481    0.063512    0.023740    0.865450    
#> 126: 0.406994    0.957986    3.468822    0.034657    0.060336    0.027577    0.831577    
#> 127: 0.395976    0.946596    3.458963    0.036918    0.058137    0.026591    0.818858    
#> 128: 0.378846    0.960670    3.490676    0.035072    0.055230    0.026717    0.845581    
#> 129: 0.382688    0.964171    3.488850    0.033516    0.052469    0.032178    0.859537    
#> 130: 0.395633    0.973912    3.477976    0.031841    0.049845    0.034665    0.841138    
#> 131: 0.373967    0.939488    3.461822    0.030249    0.047353    0.032932    0.837127    
#> 132: 0.346822    0.948815    3.458281    0.028736    0.058155    0.031285    0.838969    
#> 133: 0.360391    0.939624    3.475918    0.027299    0.083427    0.029721    0.857453    
#> 134: 0.380007    0.935821    3.484406    0.025934    0.079256    0.028425    0.860544    
#> 135: 0.341465    0.954834    3.469321    0.024638    0.075293    0.027003    0.844227    
#> 136: 0.331726    0.940032    3.469499    0.023406    0.071529    0.026091    0.828507    
#> 137: 0.354755    0.928765    3.470573    0.022236    0.067952    0.031200    0.826450    
#> 138: 0.366767    0.940315    3.480801    0.024714    0.066958    0.029640    0.825471    
#> 139: 0.377535    0.946060    3.491505    0.023629    0.067305    0.028158    0.818653    
#> 140: 0.385412    0.981332    3.482095    0.022447    0.063939    0.028128    0.844463    
#> 141: 0.387937    0.946047    3.501606    0.021325    0.060742    0.031418    0.833564    
#> 142: 0.388932    0.943452    3.507434    0.021636    0.057705    0.030835    0.837545    
#> 143: 0.372043    0.944701    3.489475    0.020554    0.061641    0.034162    0.849080    
#> 144: 0.408238    0.931652    3.502044    0.019997    0.062259    0.032454    0.818642    
#> 145: 0.384543    0.966550    3.485206    0.024756    0.065460    0.030831    0.826810    
#> 146: 0.349861    0.972530    3.488432    0.027543    0.062187    0.029290    0.839674    
#> 147: 0.311060    0.949239    3.460831    0.028344    0.059078    0.027825    0.838143    
#> 148: 0.333471    0.958064    3.475450    0.028542    0.056629    0.026434    0.836363    
#> 149: 0.333008    0.960063    3.463265    0.032106    0.053797    0.025469    0.853560    
#> 150: 0.333624    0.946289    3.462846    0.035823    0.058067    0.024196    0.851934    
#> 151: 0.299460    0.978880    3.460323    0.042005    0.055164    0.023657    0.827973    
#> 152: 0.315719    0.984680    3.469585    0.040524    0.055174    0.026675    0.823098    
#> 153: 0.317319    0.991405    3.464200    0.049695    0.069590    0.017451    0.844364    
#> 154: 0.350196    0.966879    3.467582    0.050241    0.085177    0.017009    0.853692    
#> 155: 0.342221    0.946591    3.469534    0.033697    0.079404    0.014661    0.852604    
#> 156: 0.347930    0.967036    3.473739    0.042570    0.084211    0.013990    0.838156    
#> 157: 0.357294    0.964430    3.483398    0.044296    0.071957    0.018826    0.840855    
#> 158: 0.369604    0.983528    3.464798    0.028218    0.076263    0.019620    0.833467    
#> 159: 0.361032    0.980704    3.477532    0.024168    0.054998    0.019087    0.856638    
#> 160: 0.394334    0.953541    3.486304    0.022788    0.050050    0.020784    0.856698    
#> 161: 0.386502    0.954947    3.478575    0.023144    0.055355    0.026649    0.842259    
#> 162: 0.391595    0.976069    3.470535    0.017705    0.056406    0.028205    0.838174    
#> 163: 0.385991    0.964231    3.473830    0.016028    0.043232    0.025022    0.839042    
#> 164: 0.381511    0.965351    3.471280    0.016503    0.046632    0.031941    0.845481    
#> 165: 0.383063    0.947254    3.489281    0.012573    0.052991    0.031004    0.839341    
#> 166: 0.419293    0.978605    3.494933    0.009251    0.057799    0.028271    0.857111    
#> 167: 0.419663    0.973943    3.501071    0.009511    0.041391    0.024251    0.878939    
#> 168: 0.411609    0.952644    3.500811    0.011248    0.051342    0.029724    0.843892    
#> 169: 0.413362    0.964780    3.497575    0.011719    0.048861    0.028581    0.866174    
#> 170: 0.421462    0.917660    3.504310    0.013527    0.051667    0.027215    0.860793    
#> 171: 0.404701    0.952813    3.487403    0.017883    0.055231    0.023852    0.837281    
#> 172: 0.404551    0.969650    3.488050    0.017096    0.052617    0.025467    0.857128    
#> 173: 0.406528    0.971437    3.476379    0.015571    0.048483    0.023686    0.867373    
#> 174: 0.397687    0.993980    3.469769    0.023303    0.067837    0.023582    0.853940    
#> 175: 0.398902    0.982541    3.466987    0.017085    0.065235    0.026942    0.835105    
#> 176: 0.392119    0.992543    3.471772    0.019233    0.049948    0.020169    0.831334    
#> 177: 0.376102    0.981680    3.485425    0.017051    0.060134    0.027800    0.822544    
#> 178: 0.378751    0.960603    3.483521    0.014937    0.052258    0.031450    0.832502    
#> 179: 0.385457    0.954452    3.474488    0.013507    0.047238    0.025549    0.847988    
#> 180: 0.387017    0.955858    3.471788    0.012264    0.049174    0.027128    0.840637    
#> 181: 0.385586    0.952437    3.461100    0.013530    0.047717    0.026545    0.867593    
#> 182: 0.367335    0.962169    3.460899    0.010973    0.060765    0.028939    0.863597    
#> 183: 0.348154    0.979966    3.467377    0.008715    0.060029    0.024445    0.853041    
#> 184: 0.332098    0.955234    3.463373    0.008658    0.051529    0.025884    0.857358    
#> 185: 0.332211    0.980906    3.460646    0.006310    0.039497    0.024278    0.871211    
#> 186: 0.334978    0.988616    3.468548    0.004035    0.044566    0.029323    0.874138    
#> 187: 0.342384    0.954201    3.470997    0.005135    0.050279    0.026957    0.859294    
#> 188: 0.344996    0.988608    3.460421    0.005008    0.066255    0.022120    0.873153    
#> 189: 0.359181    0.986014    3.471676    0.003499    0.058549    0.024641    0.870166    
#> 190: 0.354036    0.971831    3.480345    0.003111    0.046834    0.027034    0.849615    
#> 191: 0.349864    0.965241    3.467925    0.002367    0.044838    0.030369    0.837346    
#> 192: 0.356392    0.964863    3.477440    0.002197    0.058424    0.029263    0.839920    
#> 193: 0.358889    0.972000    3.475894    0.002181    0.039431    0.028993    0.858017    
#> 194: 0.361947    0.961879    3.465028    0.002027    0.046019    0.024456    0.855910    
#> 195: 0.355800    0.955708    3.458193    0.001365    0.049773    0.021038    0.862650    
#> 196: 0.349969    0.948359    3.472923    0.001431    0.053393    0.024601    0.879514    
#> 197: 0.349234    0.955733    3.497372    0.001635    0.052105    0.033067    0.891528    
#> 198: 0.343552    0.938841    3.481173    0.001124    0.045471    0.026261    0.875198    
#> 199: 0.339562    0.931674    3.473281    0.001184    0.042292    0.023669    0.881664    
#> 200: 0.340996    0.938065    3.463436    0.001819    0.049456    0.022465    0.898336    
#> 201: 0.343516    0.930507    3.474728    0.001537    0.043915    0.026298    0.885416    
#> 202: 0.344704    0.938452    3.474705    0.001563    0.043839    0.026612    0.883481    
#> 203: 0.347053    0.935913    3.476572    0.001593    0.041872    0.027477    0.880862    
#> 204: 0.350091    0.925906    3.480708    0.001643    0.042835    0.029409    0.880575    
#> 205: 0.351034    0.927376    3.484033    0.001738    0.045368    0.030743    0.880591    
#> 206: 0.351030    0.932910    3.483179    0.001810    0.046827    0.030403    0.877801    
#> 207: 0.350975    0.933383    3.481420    0.001814    0.047315    0.029553    0.875870    
#> 208: 0.351608    0.935726    3.481564    0.001802    0.047138    0.029446    0.873931    
#> 209: 0.352427    0.936551    3.480194    0.001766    0.047113    0.029706    0.872624    
#> 210: 0.353178    0.937022    3.480235    0.001705    0.046165    0.030180    0.871772    
#> 211: 0.353485    0.939377    3.480790    0.001698    0.045237    0.030752    0.870509    
#> 212: 0.353537    0.940109    3.480293    0.001661    0.045143    0.031515    0.870746    
#> 213: 0.353957    0.937777    3.480375    0.001637    0.046382    0.032038    0.871385    
#> 214: 0.354045    0.936827    3.481014    0.001627    0.046179    0.032420    0.871501    
#> 215: 0.354628    0.937536    3.481132    0.001606    0.046676    0.032307    0.871909    
#> 216: 0.355162    0.937238    3.481068    0.001608    0.046695    0.031741    0.872697    
#> 217: 0.355732    0.938784    3.481016    0.001617    0.046466    0.031611    0.871801    
#> 218: 0.356292    0.940544    3.480008    0.001625    0.045845    0.031743    0.871465    
#> 219: 0.356383    0.940134    3.479230    0.001631    0.045521    0.031861    0.871970    
#> 220: 0.355983    0.938945    3.479670    0.001619    0.045343    0.031567    0.872653    
#> 221: 0.355695    0.937645    3.479643    0.001601    0.044990    0.031573    0.872872    
#> 222: 0.355852    0.937593    3.479511    0.001571    0.044918    0.031505    0.871403    
#> 223: 0.356245    0.938448    3.479404    0.001558    0.044898    0.031426    0.869783    
#> 224: 0.356863    0.939359    3.479412    0.001565    0.045340    0.031340    0.868211    
#> 225: 0.357142    0.938196    3.479978    0.001557    0.045403    0.031308    0.867684    
#> 226: 0.357218    0.937441    3.479693    0.001555    0.045196    0.031404    0.867397    
#> 227: 0.357121    0.937463    3.479707    0.001571    0.045265    0.031361    0.867216    
#> 228: 0.357137    0.938355    3.478975    0.001586    0.045355    0.031275    0.866566    
#> 229: 0.357059    0.937972    3.478684    0.001589    0.045436    0.031202    0.865776    
#> 230: 0.356904    0.937100    3.478329    0.001570    0.045580    0.031228    0.865305    
#> 231: 0.356965    0.937462    3.478145    0.001571    0.045592    0.031117    0.864793    
#> 232: 0.356759    0.936912    3.478581    0.001564    0.045827    0.031010    0.864682    
#> 233: 0.356820    0.935871    3.478913    0.001549    0.045992    0.031079    0.864580    
#> 234: 0.356711    0.936205    3.479035    0.001547    0.045676    0.031016    0.864744    
#> 235: 0.356602    0.935634    3.478986    0.001543    0.045625    0.030957    0.864616    
#> 236: 0.356639    0.936219    3.478980    0.001548    0.045962    0.031071    0.864683    
#> 237: 0.356857    0.936311    3.479194    0.001542    0.046245    0.031280    0.865323    
#> 238: 0.356927    0.936048    3.479193    0.001545    0.046389    0.031324    0.865810    
#> 239: 0.357035    0.937459    3.478839    0.001539    0.046436    0.031483    0.866003    
#> 240: 0.357217    0.938194    3.478889    0.001538    0.046504    0.031532    0.865868    
#> 241: 0.357206    0.937965    3.478812    0.001534    0.046419    0.031408    0.865714    
#> 242: 0.357216    0.938290    3.478535    0.001528    0.046897    0.031364    0.866068    
#> 243: 0.357057    0.938323    3.478496    0.001524    0.047210    0.031357    0.866367    
#> 244: 0.356808    0.938115    3.479039    0.001521    0.047522    0.031349    0.866631    
#> 245: 0.356756    0.937785    3.479179    0.001517    0.047419    0.031219    0.867023    
#> 246: 0.356646    0.937823    3.479155    0.001522    0.047422    0.031312    0.867285    
#> 247: 0.356594    0.937824    3.479363    0.001519    0.047336    0.031360    0.867057    
#> 248: 0.356558    0.938275    3.479211    0.001510    0.047407    0.031387    0.866833    
#> 249: 0.356541    0.938518    3.479126    0.001501    0.047646    0.031480    0.866631    
#> 250: 0.356695    0.939256    3.479360    0.001501    0.047643    0.031537    0.866651    
#> 251: 0.356695    0.939767    3.479652    0.001487    0.047656    0.031481    0.866739    
#> 252: 0.356838    0.940268    3.480130    0.001483    0.047518    0.031490    0.866736    
#> 253: 0.356810    0.940713    3.480473    0.001486    0.047432    0.031465    0.866729    
#> 254: 0.356704    0.941633    3.480533    0.001485    0.047478    0.031473    0.866850    
#> 255: 0.356685    0.942081    3.480591    0.001483    0.047525    0.031557    0.866649    
#> 256: 0.356721    0.941839    3.480534    0.001482    0.047669    0.031528    0.866501    
#> 257: 0.356761    0.940801    3.480700    0.001483    0.047532    0.031596    0.866530    
#> 258: 0.356834    0.940664    3.480499    0.001473    0.047499    0.031601    0.866551    
#> 259: 0.356870    0.940601    3.480480    0.001467    0.047567    0.031524    0.866702    
#> 260: 0.356736    0.940760    3.480633    0.001470    0.047470    0.031441    0.866745    
#> 261: 0.356691    0.940441    3.480618    0.001467    0.047511    0.031405    0.866780    
#> 262: 0.356692    0.940547    3.480384    0.001459    0.047397    0.031344    0.866603    
#> 263: 0.356675    0.940893    3.480324    0.001450    0.047218    0.031431    0.866975    
#> 264: 0.356763    0.941157    3.480150    0.001443    0.047104    0.031414    0.867087    
#> 265: 0.356807    0.941423    3.480076    0.001444    0.047115    0.031379    0.867256    
#> 266: 0.356899    0.942265    3.479953    0.001448    0.047252    0.031385    0.867567    
#> 267: 0.356926    0.942293    3.480303    0.001446    0.047335    0.031505    0.867503    
#> 268: 0.356893    0.942119    3.480342    0.001453    0.047288    0.031540    0.867498    
#> 269: 0.356969    0.941695    3.480399    0.001454    0.047211    0.031541    0.867447    
#> 270: 0.357109    0.941778    3.480235    0.001458    0.047186    0.031442    0.867193    
#> 271: 0.357204    0.941943    3.480158    0.001456    0.047212    0.031423    0.867094    
#> 272: 0.357283    0.941840    3.480144    0.001450    0.047068    0.031377    0.867132    
#> 273: 0.357162    0.942182    3.480106    0.001451    0.047057    0.031392    0.867038    
#> 274: 0.357071    0.942612    3.480024    0.001455    0.046981    0.031356    0.866920    
#> 275: 0.357077    0.942655    3.479891    0.001456    0.046975    0.031349    0.866712    
#> 276: 0.357060    0.943113    3.479912    0.001453    0.046882    0.031289    0.866555    
#> 277: 0.356996    0.943560    3.479971    0.001453    0.046999    0.031183    0.866545    
#> 278: 0.356876    0.943801    3.480001    0.001452    0.046961    0.031124    0.866656    
#> 279: 0.356726    0.943974    3.479954    0.001454    0.047023    0.031108    0.866759    
#> 280: 0.356720    0.944180    3.479932    0.001447    0.047124    0.031046    0.866699    
#> 281: 0.356684    0.944398    3.479993    0.001442    0.047039    0.031033    0.866782    
#> 282: 0.356705    0.944528    3.479926    0.001448    0.046924    0.031001    0.866802    
#> 283: 0.356785    0.944518    3.479874    0.001450    0.046729    0.031058    0.867029    
#> 284: 0.356847    0.944407    3.479870    0.001447    0.046677    0.031013    0.866840    
#> 285: 0.356869    0.944532    3.479773    0.001449    0.046700    0.031028    0.866712    
#> 286: 0.356896    0.944761    3.479700    0.001446    0.046783    0.030954    0.867003    
#> 287: 0.356975    0.945013    3.479583    0.001438    0.046967    0.030917    0.867236    
#> 288: 0.357060    0.945059    3.479571    0.001432    0.047039    0.030943    0.867559    
#> 289: 0.357098    0.944988    3.479477    0.001434    0.046986    0.030901    0.867523    
#> 290: 0.357088    0.945205    3.479563    0.001437    0.046995    0.030912    0.867614    
#> 291: 0.357081    0.945452    3.479619    0.001437    0.047072    0.030907    0.867432    
#> 292: 0.357085    0.945406    3.479607    0.001434    0.047022    0.030904    0.867318    
#> 293: 0.357048    0.945396    3.479447    0.001432    0.046951    0.030898    0.867373    
#> 294: 0.356964    0.945534    3.479250    0.001432    0.046888    0.030934    0.867192    
#> 295: 0.356968    0.945248    3.479183    0.001430    0.046920    0.030929    0.867190    
#> 296: 0.356994    0.945082    3.479251    0.001427    0.047040    0.030936    0.867373    
#> 297: 0.356985    0.945082    3.479193    0.001422    0.047068    0.030937    0.867290    
#> 298: 0.356991    0.945113    3.479139    0.001425    0.046977    0.030945    0.867108    
#> 299: 0.357044    0.945035    3.479096    0.001426    0.046980    0.030967    0.867046    
#> 300: 0.357110    0.945038    3.479240    0.001424    0.046953    0.031000    0.866924    
#> 301: 0.357188    0.945066    3.479175    0.001420    0.046921    0.031009    0.866874    
#> 302: 0.357240    0.945280    3.479075    0.001421    0.046839    0.030968    0.866824    
#> 303: 0.357163    0.945518    3.479006    0.001421    0.046885    0.030957    0.866707    
#> 304: 0.357199    0.945838    3.478847    0.001418    0.046949    0.031008    0.866724    
#> 305: 0.357235    0.945758    3.478869    0.001414    0.046816    0.031041    0.866878    
#> 306: 0.357246    0.945631    3.478799    0.001413    0.046772    0.031010    0.866822    
#> 307: 0.357252    0.945395    3.478883    0.001418    0.046714    0.030998    0.866994    
#> 308: 0.357272    0.945471    3.478818    0.001419    0.046800    0.031008    0.866946    
#> 309: 0.357297    0.945410    3.478873    0.001424    0.046873    0.030967    0.866868    
#> 310: 0.357421    0.945333    3.478745    0.001427    0.046792    0.030929    0.866699    
#> 311: 0.357538    0.945443    3.478857    0.001428    0.046736    0.030917    0.866547    
#> 312: 0.357577    0.945380    3.478871    0.001436    0.046747    0.030919    0.866520    
#> 313: 0.357545    0.945223    3.478870    0.001444    0.046870    0.030919    0.866579    
#> 314: 0.357487    0.945107    3.478837    0.001444    0.046934    0.030853    0.866544    
#> 315: 0.357416    0.944968    3.478909    0.001445    0.046854    0.030853    0.866465    
#> 316: 0.357435    0.945047    3.478910    0.001445    0.046870    0.030814    0.866422    
#> 317: 0.357439    0.945063    3.479026    0.001446    0.046923    0.030840    0.866416    
#> 318: 0.357513    0.945158    3.478923    0.001446    0.046935    0.030866    0.866387    
#> 319: 0.357605    0.945071    3.478967    0.001446    0.047000    0.030889    0.866300    
#> 320: 0.357588    0.945207    3.478866    0.001451    0.047059    0.030870    0.866223    
#> 321: 0.357542    0.945282    3.478724    0.001456    0.047021    0.030859    0.866353    
#> 322: 0.357560    0.945371    3.478611    0.001460    0.046896    0.030868    0.866313    
#> 323: 0.357513    0.945591    3.478573    0.001465    0.046866    0.030838    0.866207    
#> 324: 0.357522    0.945775    3.478492    0.001466    0.046957    0.030786    0.866005    
#> 325: 0.357535    0.945899    3.478400    0.001473    0.046930    0.030797    0.865885    
#> 326: 0.357576    0.945705    3.478349    0.001476    0.046917    0.030799    0.865877    
#> 327: 0.357543    0.945730    3.478434    0.001478    0.046973    0.030824    0.865896    
#> 328: 0.357524    0.945983    3.478472    0.001479    0.046992    0.030875    0.865719    
#> 329: 0.357508    0.945871    3.478552    0.001484    0.046993    0.030872    0.865636    
#> 330: 0.357399    0.945894    3.478506    0.001484    0.047004    0.030837    0.865595    
#> 331: 0.357364    0.946078    3.478539    0.001486    0.047009    0.030818    0.865488    
#> 332: 0.357321    0.945961    3.478602    0.001488    0.046947    0.030757    0.865682    
#> 333: 0.357293    0.946057    3.478529    0.001485    0.046961    0.030775    0.865581    
#> 334: 0.357273    0.946107    3.478321    0.001482    0.046944    0.030806    0.865533    
#> 335: 0.357157    0.946129    3.478235    0.001483    0.047004    0.030817    0.865555    
#> 336: 0.357115    0.946295    3.478066    0.001484    0.046999    0.030802    0.865648    
#> 337: 0.357137    0.946700    3.478067    0.001484    0.046916    0.030793    0.865881    
#> 338: 0.357147    0.946878    3.478163    0.001483    0.046904    0.030822    0.866037    
#> 339: 0.357134    0.946962    3.478261    0.001482    0.046855    0.030863    0.865949    
#> 340: 0.357102    0.946613    3.478436    0.001479    0.046782    0.030933    0.865972    
#> 341: 0.357111    0.946637    3.478471    0.001477    0.046868    0.030944    0.865924    
#> 342: 0.357088    0.946463    3.478473    0.001475    0.046882    0.030915    0.865880    
#> 343: 0.357045    0.946558    3.478451    0.001473    0.046962    0.030876    0.865802    
#> 344: 0.357054    0.946559    3.478464    0.001474    0.046980    0.030855    0.865880    
#> 345: 0.357078    0.946659    3.478443    0.001472    0.046966    0.030847    0.865936    
#> 346: 0.357126    0.946880    3.478390    0.001472    0.046989    0.030867    0.865842    
#> 347: 0.357182    0.946726    3.478384    0.001477    0.046963    0.030888    0.866010    
#> 348: 0.357125    0.946729    3.478408    0.001478    0.046868    0.030936    0.866115    
#> 349: 0.357111    0.946763    3.478449    0.001481    0.046767    0.030950    0.866070    
#> 350: 0.357057    0.946684    3.478492    0.001482    0.046733    0.030983    0.866147    
#> 351: 0.356990    0.946966    3.478395    0.001482    0.046785    0.030979    0.866079    
#> 352: 0.356947    0.947187    3.478387    0.001481    0.046792    0.031007    0.866023    
#> 353: 0.356965    0.947389    3.478368    0.001481    0.046747    0.031063    0.866074    
#> 354: 0.357001    0.947491    3.478203    0.001482    0.046746    0.031121    0.866038    
#> 355: 0.357079    0.947317    3.478202    0.001482    0.046727    0.031119    0.866044    
#> 356: 0.357134    0.947249    3.478160    0.001481    0.046757    0.031111    0.866132    
#> 357: 0.357220    0.947338    3.478151    0.001482    0.046776    0.031095    0.866101    
#> 358: 0.357270    0.947401    3.478201    0.001482    0.046866    0.031102    0.866074    
#> 359: 0.357286    0.947566    3.478166    0.001482    0.046917    0.031099    0.866033    
#> 360: 0.357270    0.947624    3.478088    0.001479    0.046924    0.031067    0.865963    
#> 361: 0.357271    0.947608    3.478111    0.001478    0.046826    0.031035    0.865957    
#> 362: 0.357299    0.947686    3.478072    0.001477    0.046722    0.031031    0.865811    
#> 363: 0.357311    0.947600    3.478075    0.001476    0.046667    0.031034    0.865656    
#> 364: 0.357373    0.947587    3.478076    0.001475    0.046696    0.030997    0.865600    
#> 365: 0.357376    0.947487    3.478064    0.001477    0.046727    0.030974    0.865673    
#> 366: 0.357383    0.947534    3.477961    0.001475    0.046728    0.030908    0.865724    
#> 367: 0.357391    0.947635    3.477838    0.001475    0.046718    0.030888    0.865709    
#> 368: 0.357401    0.947699    3.477761    0.001471    0.046687    0.030885    0.865744    
#> 369: 0.357400    0.947768    3.477724    0.001467    0.046659    0.030889    0.865704    
#> 370: 0.357372    0.947946    3.477669    0.001466    0.046690    0.030888    0.865874    
#> 371: 0.357379    0.948025    3.477602    0.001465    0.046679    0.030906    0.865904    
#> 372: 0.357423    0.948085    3.477581    0.001466    0.046667    0.030899    0.865950    
#> 373: 0.357492    0.948214    3.477610    0.001469    0.046733    0.030894    0.865989    
#> 374: 0.357508    0.948090    3.477627    0.001472    0.046756    0.030882    0.865963    
#> 375: 0.357504    0.947869    3.477655    0.001471    0.046800    0.030861    0.865962    
#> 376: 0.357480    0.947817    3.477713    0.001473    0.046783    0.030872    0.865880    
#> 377: 0.357515    0.947835    3.477763    0.001472    0.046791    0.030874    0.865934    
#> 378: 0.357499    0.947729    3.477794    0.001469    0.046768    0.030870    0.866008    
#> 379: 0.357480    0.947543    3.477874    0.001467    0.046728    0.030888    0.866067    
#> 380: 0.357445    0.947485    3.477883    0.001463    0.046778    0.030933    0.866063    
#> 381: 0.357474    0.947472    3.477884    0.001462    0.046770    0.030941    0.866020    
#> 382: 0.357478    0.947392    3.477895    0.001462    0.046679    0.030955    0.866029    
#> 383: 0.357489    0.947359    3.477962    0.001463    0.046675    0.030982    0.866009    
#> 384: 0.357486    0.947300    3.478030    0.001465    0.046687    0.030999    0.865980    
#> 385: 0.357487    0.947279    3.478081    0.001467    0.046640    0.031048    0.866072    
#> 386: 0.357535    0.947488    3.478095    0.001470    0.046617    0.031059    0.866163    
#> 387: 0.357560    0.947484    3.478171    0.001469    0.046555    0.031073    0.866166    
#> 388: 0.357589    0.947489    3.478188    0.001470    0.046497    0.031097    0.866143    
#> 389: 0.357583    0.947441    3.478154    0.001470    0.046492    0.031107    0.866229    
#> 390: 0.357555    0.947550    3.478103    0.001468    0.046514    0.031082    0.866264    
#> 391: 0.357561    0.947557    3.478125    0.001469    0.046526    0.031078    0.866272    
#> 392: 0.357570    0.947557    3.478162    0.001469    0.046557    0.031061    0.866188    
#> 393: 0.357590    0.947619    3.478060    0.001471    0.046559    0.031064    0.866171    
#> 394: 0.357595    0.947666    3.477985    0.001472    0.046549    0.031040    0.866072    
#> 395: 0.357625    0.947747    3.477924    0.001470    0.046506    0.031033    0.865996    
#> 396: 0.357668    0.947884    3.477963    0.001469    0.046527    0.031011    0.865963    
#> 397: 0.357717    0.947844    3.478032    0.001468    0.046511    0.030969    0.866133    
#> 398: 0.357790    0.947676    3.478099    0.001469    0.046541    0.030932    0.866201    
#> 399: 0.357832    0.947756    3.478112    0.001469    0.046515    0.030912    0.866291    
#> 400: 0.357891    0.947812    3.478154    0.001468    0.046498    0.030913    0.866283    
#> 401: 0.357903    0.947852    3.478151    0.001467    0.046507    0.030912    0.866243    
#> 402: 0.357889    0.947924    3.478139    0.001468    0.046458    0.030931    0.866277    
#> 403: 0.357898    0.947982    3.478063    0.001467    0.046401    0.030904    0.866321    
#> 404: 0.357893    0.948114    3.478015    0.001468    0.046323    0.030908    0.866288    
#> 405: 0.357845    0.948086    3.478071    0.001470    0.046295    0.030891    0.866185    
#> 406: 0.357821    0.948029    3.478094    0.001470    0.046256    0.030903    0.866076    
#> 407: 0.357827    0.948074    3.478102    0.001468    0.046212    0.030913    0.866061    
#> 408: 0.357829    0.948129    3.478092    0.001467    0.046241    0.030894    0.866083    
#> 409: 0.357812    0.948090    3.478030    0.001466    0.046236    0.030906    0.866076    
#> 410: 0.357816    0.948169    3.477888    0.001467    0.046267    0.030876    0.866100    
#> 411: 0.357819    0.947885    3.477893    0.001469    0.046291    0.030867    0.866102    
#> 412: 0.357822    0.947819    3.477853    0.001470    0.046273    0.030846    0.866055    
#> 413: 0.357815    0.947770    3.477843    0.001471    0.046268    0.030838    0.866062    
#> 414: 0.357807    0.947761    3.477866    0.001475    0.046205    0.030838    0.866132    
#> 415: 0.357834    0.947663    3.477885    0.001477    0.046176    0.030867    0.866153    
#> 416: 0.357875    0.947681    3.477893    0.001476    0.046145    0.030855    0.866184    
#> 417: 0.357903    0.947590    3.477853    0.001478    0.046069    0.030844    0.866234    
#> 418: 0.357884    0.947530    3.477889    0.001478    0.046090    0.030829    0.866233    
#> 419: 0.357869    0.947562    3.477885    0.001479    0.046090    0.030816    0.866287    
#> 420: 0.357870    0.947554    3.477884    0.001479    0.046058    0.030820    0.866245    
#> 421: 0.357860    0.947534    3.477916    0.001479    0.046015    0.030821    0.866212    
#> 422: 0.357879    0.947454    3.477859    0.001482    0.045977    0.030822    0.866239    
#> 423: 0.357864    0.947461    3.477829    0.001483    0.045967    0.030801    0.866188    
#> 424: 0.357845    0.947432    3.477813    0.001485    0.045948    0.030789    0.866190    
#> 425: 0.357840    0.947454    3.477785    0.001488    0.045952    0.030809    0.866274    
#> 426: 0.357867    0.947497    3.477752    0.001490    0.045970    0.030792    0.866199    
#> 427: 0.357875    0.947441    3.477772    0.001491    0.046007    0.030808    0.866108    
#> 428: 0.357843    0.947496    3.477798    0.001492    0.045984    0.030816    0.866068    
#> 429: 0.357819    0.947504    3.477823    0.001491    0.045962    0.030824    0.866106    
#> 430: 0.357813    0.947532    3.477837    0.001489    0.045925    0.030848    0.866155    
#> 431: 0.357791    0.947594    3.477735    0.001488    0.045895    0.030827    0.866231    
#> 432: 0.357787    0.947755    3.477707    0.001487    0.045901    0.030812    0.866307    
#> 433: 0.357767    0.947902    3.477712    0.001488    0.045887    0.030801    0.866349    
#> 434: 0.357757    0.947876    3.477692    0.001487    0.045898    0.030829    0.866387    
#> 435: 0.357762    0.947817    3.477693    0.001484    0.045946    0.030842    0.866377    
#> 436: 0.357734    0.947691    3.477723    0.001482    0.045929    0.030836    0.866373    
#> 437: 0.357736    0.947710    3.477704    0.001481    0.045876    0.030851    0.866418    
#> 438: 0.357762    0.947892    3.477645    0.001481    0.045847    0.030864    0.866376    
#> 439: 0.357798    0.947943    3.477657    0.001482    0.045808    0.030870    0.866366    
#> 440: 0.357804    0.947959    3.477657    0.001482    0.045815    0.030865    0.866341    
#> 441: 0.357837    0.947902    3.477723    0.001482    0.045839    0.030858    0.866344    
#> 442: 0.357802    0.947885    3.477733    0.001481    0.045847    0.030849    0.866400    
#> 443: 0.357789    0.948000    3.477702    0.001480    0.045855    0.030821    0.866367    
#> 444: 0.357784    0.948022    3.477672    0.001479    0.045838    0.030826    0.866324    
#> 445: 0.357798    0.948033    3.477659    0.001477    0.045872    0.030836    0.866396    
#> 446: 0.357789    0.948121    3.477612    0.001475    0.045919    0.030805    0.866417    
#> 447: 0.357817    0.948197    3.477626    0.001473    0.045995    0.030804    0.866544    
#> 448: 0.357815    0.948251    3.477650    0.001474    0.045970    0.030809    0.866598    
#> 449: 0.357806    0.948358    3.477717    0.001474    0.046000    0.030806    0.866658    
#> 450: 0.357789    0.948402    3.477724    0.001474    0.046034    0.030812    0.866625    
#> 451: 0.357751    0.948466    3.477684    0.001475    0.046081    0.030805    0.866590    
#> 452: 0.357733    0.948539    3.477701    0.001477    0.046073    0.030791    0.866566    
#> 453: 0.357740    0.948611    3.477677    0.001479    0.046083    0.030789    0.866501    
#> 454: 0.357744    0.948703    3.477677    0.001483    0.046088    0.030796    0.866425    
#> 455: 0.357734    0.948667    3.477701    0.001485    0.046107    0.030806    0.866428    
#> 456: 0.357683    0.948602    3.477689    0.001488    0.046150    0.030794    0.866456    
#> 457: 0.357647    0.948582    3.477753    0.001487    0.046182    0.030802    0.866438    
#> 458: 0.357602    0.948743    3.477798    0.001486    0.046284    0.030781    0.866457    
#> 459: 0.357553    0.948934    3.477783    0.001486    0.046358    0.030760    0.866406    
#> 460: 0.357510    0.948918    3.477732    0.001485    0.046336    0.030772    0.866385    
#> 461: 0.357449    0.948981    3.477716    0.001486    0.046298    0.030774    0.866352    
#> 462: 0.357412    0.949001    3.477758    0.001487    0.046262    0.030786    0.866332    
#> 463: 0.357398    0.949046    3.477776    0.001486    0.046270    0.030807    0.866268    
#> 464: 0.357391    0.949056    3.477740    0.001485    0.046272    0.030794    0.866139    
#> 465: 0.357374    0.948933    3.477704    0.001485    0.046298    0.030781    0.866052    
#> 466: 0.357365    0.949000    3.477624    0.001485    0.046274    0.030768    0.866099    
#> 467: 0.357362    0.948979    3.477611    0.001488    0.046291    0.030760    0.866018    
#> 468: 0.357397    0.948977    3.477628    0.001489    0.046275    0.030757    0.866003    
#> 469: 0.357394    0.949061    3.477656    0.001488    0.046257    0.030773    0.865976    
#> 470: 0.357386    0.949052    3.477656    0.001487    0.046236    0.030764    0.865918    
#> 471: 0.357356    0.948990    3.477671    0.001486    0.046207    0.030756    0.865988    
#> 472: 0.357321    0.948889    3.477722    0.001485    0.046197    0.030763    0.865988    
#> 473: 0.357288    0.948889    3.477712    0.001485    0.046166    0.030771    0.865949    
#> 474: 0.357300    0.948915    3.477713    0.001486    0.046138    0.030781    0.865977    
#> 475: 0.357315    0.949090    3.477695    0.001485    0.046123    0.030786    0.865950    
#> 476: 0.357322    0.949130    3.477648    0.001485    0.046119    0.030787    0.865998    
#> 477: 0.357308    0.949217    3.477651    0.001483    0.046148    0.030771    0.865904    
#> 478: 0.357296    0.949246    3.477632    0.001483    0.046182    0.030774    0.865865    
#> 479: 0.357283    0.949276    3.477620    0.001483    0.046254    0.030760    0.865866    
#> 480: 0.357284    0.949313    3.477607    0.001482    0.046323    0.030765    0.865831    
#> 481: 0.357281    0.949301    3.477626    0.001483    0.046329    0.030773    0.865799    
#> 482: 0.357286    0.949379    3.477553    0.001483    0.046287    0.030773    0.865882    
#> 483: 0.357239    0.949424    3.477518    0.001483    0.046274    0.030764    0.865832    
#> 484: 0.357236    0.949320    3.477530    0.001482    0.046255    0.030779    0.865879    
#> 485: 0.357247    0.949311    3.477564    0.001481    0.046239    0.030798    0.865975    
#> 486: 0.357265    0.949324    3.477590    0.001481    0.046231    0.030783    0.866029    
#> 487: 0.357289    0.949287    3.477640    0.001483    0.046249    0.030769    0.866051    
#> 488: 0.357291    0.949228    3.477658    0.001484    0.046254    0.030765    0.866048    
#> 489: 0.357307    0.949229    3.477648    0.001485    0.046246    0.030762    0.866035    
#> 490: 0.357328    0.949234    3.477662    0.001485    0.046253    0.030763    0.866030    
#> 491: 0.357332    0.949337    3.477676    0.001485    0.046250    0.030779    0.865974    
#> 492: 0.357333    0.949403    3.477636    0.001485    0.046254    0.030766    0.866010    
#> 493: 0.357318    0.949462    3.477628    0.001487    0.046248    0.030775    0.866036    
#> 494: 0.357315    0.949515    3.477594    0.001488    0.046229    0.030765    0.866000    
#> 495: 0.357320    0.949576    3.477584    0.001487    0.046240    0.030763    0.865958    
#> 496: 0.357337    0.949626    3.477533    0.001487    0.046271    0.030739    0.865935    
#> 497: 0.357348    0.949602    3.477522    0.001487    0.046257    0.030743    0.865928    
#> 498: 0.357351    0.949667    3.477491    0.001489    0.046248    0.030758    0.865847    
#> 499: 0.357356    0.949790    3.477416    0.001490    0.046270    0.030746    0.865819    
#> 500: 0.357385    0.949784    3.477407    0.001490    0.046326    0.030754    0.865761    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.316678    0.960908    3.438489    0.392401    0.084474    0.016800    1.654479    
#> 002: 0.367417    0.967757    3.457983    0.372781    0.080250    0.015960    1.075740    
#> 003: 0.442692    0.910823    3.474938    0.354142    0.104572    0.015245    0.708605    
#> 004: 0.425726    0.930096    3.477838    0.336435    0.115533    0.017860    0.593226    
#> 005: 0.485185    0.933975    3.469494    0.321594    0.129500    0.016967    0.544464    
#> 006: 0.445692    0.951887    3.460942    0.305514    0.133410    0.016118    0.523346    
#> 007: 0.421452    0.951223    3.457648    0.290239    0.141209    0.015312    0.535778    
#> 008: 0.430163    0.945351    3.463019    0.276996    0.134148    0.018838    0.526272    
#> 009: 0.431736    0.950316    3.462863    0.292341    0.127441    0.019335    0.522104    
#> 010: 0.427656    0.962467    3.452098    0.295766    0.139057    0.018368    0.535253    
#> 011: 0.451057    0.950718    3.466337    0.305485    0.132104    0.018014    0.528340    
#> 012: 0.451059    0.937875    3.464876    0.295153    0.125499    0.017113    0.517908    
#> 013: 0.439504    0.965683    3.465394    0.280395    0.123814    0.018236    0.515311    
#> 014: 0.482395    0.936325    3.480671    0.299656    0.130062    0.017324    0.523565    
#> 015: 0.506340    0.945089    3.480898    0.299547    0.129851    0.018469    0.501910    
#> 016: 0.492003    0.949851    3.478384    0.308770    0.127537    0.019244    0.506053    
#> 017: 0.489911    0.947732    3.481728    0.305753    0.134771    0.018282    0.512221    
#> 018: 0.476269    0.939569    3.472560    0.314352    0.135516    0.018862    0.527855    
#> 019: 0.461227    0.938827    3.476038    0.324402    0.128740    0.018518    0.501667    
#> 020: 0.477757    0.941937    3.480064    0.308182    0.125080    0.019969    0.511796    
#> 021: 0.485934    0.941664    3.488903    0.292773    0.122873    0.021643    0.506345    
#> 022: 0.491685    0.943348    3.489747    0.289248    0.119420    0.022594    0.500609    
#> 023: 0.559508    0.936648    3.492652    0.314334    0.113449    0.022446    0.525785    
#> 024: 0.530799    0.956809    3.489164    0.303200    0.131257    0.022729    0.519860    
#> 025: 0.504950    0.931915    3.480558    0.288040    0.124694    0.024873    0.519032    
#> 026: 0.478822    0.953961    3.471783    0.273638    0.134697    0.024127    0.510451    
#> 027: 0.464299    0.965416    3.461976    0.261890    0.127963    0.022921    0.533643    
#> 028: 0.475648    0.956088    3.470398    0.251518    0.121564    0.025920    0.525309    
#> 029: 0.490841    0.948952    3.465099    0.301649    0.120105    0.024624    0.534109    
#> 030: 0.486601    0.950174    3.465561    0.294362    0.137370    0.023393    0.526051    
#> 031: 0.427145    0.942489    3.471491    0.279644    0.130502    0.023933    0.529259    
#> 032: 0.449793    0.930961    3.473016    0.276786    0.123976    0.022736    0.520663    
#> 033: 0.456507    0.928500    3.486154    0.278972    0.117778    0.023708    0.543944    
#> 034: 0.506192    0.937908    3.490781    0.265023    0.129057    0.024177    0.547018    
#> 035: 0.459920    0.933223    3.475994    0.284509    0.132097    0.022968    0.525119    
#> 036: 0.471372    0.940306    3.472336    0.274047    0.137208    0.021820    0.542676    
#> 037: 0.448355    0.946048    3.466086    0.260344    0.130347    0.020729    0.539856    
#> 038: 0.471074    0.966283    3.471003    0.267030    0.123830    0.020779    0.523413    
#> 039: 0.485820    0.970571    3.479813    0.270896    0.117639    0.023391    0.506022    
#> 040: 0.487779    0.953562    3.483220    0.311662    0.111757    0.025578    0.522322    
#> 041: 0.461183    0.954630    3.472339    0.296078    0.109273    0.024352    0.518321    
#> 042: 0.512553    0.923817    3.486286    0.281275    0.113111    0.023134    0.527637    
#> 043: 0.488604    0.946574    3.468043    0.287613    0.115884    0.021977    0.509093    
#> 044: 0.451123    0.955902    3.464713    0.273232    0.116112    0.020878    0.512233    
#> 045: 0.446813    0.968540    3.461907    0.284274    0.115500    0.019854    0.508731    
#> 046: 0.461069    0.940514    3.465460    0.291300    0.123474    0.020115    0.513743    
#> 047: 0.476327    0.949010    3.471125    0.278594    0.117494    0.019109    0.509050    
#> 048: 0.473394    0.942059    3.471524    0.286950    0.111619    0.020095    0.513536    
#> 049: 0.471831    0.938606    3.478110    0.272603    0.133706    0.020523    0.512689    
#> 050: 0.508698    0.924172    3.486634    0.259398    0.127020    0.021415    0.516601    
#> 051: 0.523984    0.910419    3.487082    0.292492    0.120669    0.025958    0.514678    
#> 052: 0.528102    0.929843    3.501125    0.277868    0.123476    0.024660    0.496802    
#> 053: 0.518068    0.933536    3.488433    0.300904    0.117752    0.023427    0.493224    
#> 054: 0.487454    0.935321    3.479410    0.285858    0.133678    0.022256    0.509881    
#> 055: 0.480402    0.931903    3.481421    0.320216    0.131418    0.021156    0.510186    
#> 056: 0.491517    0.906270    3.488092    0.304205    0.131080    0.023281    0.528696    
#> 057: 0.482995    0.931324    3.490674    0.288995    0.124526    0.026667    0.526357    
#> 058: 0.484159    0.929944    3.471958    0.274545    0.118300    0.025334    0.534086    
#> 059: 0.475484    0.931931    3.479072    0.260818    0.112385    0.024405    0.536325    
#> 060: 0.472983    0.944530    3.469935    0.247777    0.108587    0.023184    0.533600    
#> 061: 0.480535    0.955105    3.479690    0.291694    0.117830    0.022955    0.520514    
#> 062: 0.470297    0.954717    3.475478    0.303181    0.123843    0.022111    0.533467    
#> 063: 0.491058    0.908751    3.481004    0.313450    0.133910    0.023194    0.525219    
#> 064: 0.479130    0.939834    3.482115    0.297777    0.127214    0.022035    0.525577    
#> 065: 0.488085    0.931191    3.476062    0.282888    0.140403    0.020933    0.512316    
#> 066: 0.494068    0.955028    3.478361    0.281203    0.133383    0.021828    0.514372    
#> 067: 0.497371    0.931839    3.484282    0.288576    0.127121    0.023891    0.526304    
#> 068: 0.464503    0.932600    3.480305    0.282631    0.120765    0.023915    0.521474    
#> 069: 0.469866    0.949728    3.467642    0.305845    0.114726    0.023507    0.530508    
#> 070: 0.469309    0.952156    3.483202    0.290552    0.108990    0.023414    0.528963    
#> 071: 0.462807    0.951183    3.467065    0.289945    0.115334    0.022244    0.513873    
#> 072: 0.444218    0.940355    3.459645    0.282186    0.109567    0.021132    0.512103    
#> 073: 0.459921    0.950670    3.475864    0.294057    0.104509    0.020075    0.518587    
#> 074: 0.464177    0.939910    3.474363    0.279354    0.107257    0.019071    0.510383    
#> 075: 0.468530    0.918816    3.487291    0.265387    0.122438    0.020090    0.499304    
#> 076: 0.487865    0.926464    3.486721    0.283550    0.126480    0.019086    0.508720    
#> 077: 0.499365    0.927660    3.491782    0.291623    0.129605    0.020888    0.506765    
#> 078: 0.496582    0.936227    3.491007    0.277042    0.123124    0.021529    0.494972    
#> 079: 0.494028    0.938256    3.486054    0.263190    0.116968    0.021691    0.503539    
#> 080: 0.507234    0.936501    3.480616    0.304452    0.117357    0.021452    0.511471    
#> 081: 0.491181    0.951937    3.477142    0.297346    0.118117    0.020380    0.508902    
#> 082: 0.515033    0.927415    3.492329    0.282479    0.117249    0.019976    0.515674    
#> 083: 0.508021    0.947411    3.490873    0.268355    0.126599    0.021846    0.515619    
#> 084: 0.500985    0.952095    3.484971    0.254937    0.120269    0.023225    0.516551    
#> 085: 0.503152    0.954554    3.493916    0.247314    0.114255    0.022076    0.530098    
#> 086: 0.487733    0.930271    3.485302    0.259142    0.121682    0.020972    0.504631    
#> 087: 0.505726    0.942053    3.481527    0.314168    0.132059    0.019924    0.514285    
#> 088: 0.461562    0.959616    3.471404    0.312962    0.130369    0.021546    0.505078    
#> 089: 0.464438    0.954253    3.461311    0.312564    0.123850    0.021610    0.507343    
#> 090: 0.471933    0.936346    3.465787    0.303349    0.117658    0.021238    0.516251    
#> 091: 0.465533    0.932164    3.468248    0.311022    0.121808    0.023168    0.514655    
#> 092: 0.459417    0.957638    3.455325    0.323260    0.126730    0.022010    0.507830    
#> 093: 0.455457    0.952195    3.468054    0.307097    0.123428    0.020909    0.524332    
#> 094: 0.461729    0.954807    3.463707    0.305818    0.121442    0.021749    0.512143    
#> 095: 0.461555    0.939200    3.462257    0.290527    0.119415    0.023003    0.520782    
#> 096: 0.450484    0.949004    3.463193    0.276001    0.114308    0.026724    0.503735    
#> 097: 0.464031    0.955847    3.474486    0.262201    0.125452    0.025388    0.513188    
#> 098: 0.478613    0.954295    3.479255    0.260043    0.119179    0.024118    0.513235    
#> 099: 0.464324    0.929628    3.474333    0.290265    0.116595    0.022912    0.504012    
#> 100: 0.481053    0.945449    3.483025    0.275752    0.119019    0.023289    0.495281    
#> 101: 0.468777    0.937582    3.466530    0.263819    0.119527    0.022124    0.498133    
#> 102: 0.483819    0.940472    3.471155    0.266547    0.120374    0.021042    0.510585    
#> 103: 0.503386    0.959487    3.488458    0.312811    0.115530    0.021750    0.509427    
#> 104: 0.472862    0.947242    3.483049    0.297170    0.111017    0.022963    0.521833    
#> 105: 0.520896    0.922478    3.495508    0.282312    0.114414    0.026948    0.527659    
#> 106: 0.512254    0.919436    3.491875    0.290436    0.113383    0.028317    0.517745    
#> 107: 0.501716    0.932858    3.483498    0.275914    0.107714    0.026901    0.522911    
#> 108: 0.499915    0.928644    3.495512    0.271970    0.125264    0.025556    0.509417    
#> 109: 0.481328    0.944673    3.491878    0.266834    0.119000    0.024278    0.522583    
#> 110: 0.493897    0.926934    3.482847    0.260973    0.129397    0.023065    0.518023    
#> 111: 0.482293    0.926002    3.483356    0.253958    0.122928    0.023226    0.517889    
#> 112: 0.456272    0.933794    3.467894    0.266866    0.116781    0.022064    0.511985    
#> 113: 0.453631    0.966523    3.470976    0.269233    0.116170    0.022380    0.492578    
#> 114: 0.464780    0.941391    3.474717    0.273458    0.110361    0.026036    0.504899    
#> 115: 0.504476    0.913651    3.481381    0.275734    0.104926    0.024734    0.525595    
#> 116: 0.507889    0.928192    3.477711    0.271595    0.106964    0.023497    0.516017    
#> 117: 0.488673    0.960206    3.478434    0.258015    0.119454    0.022323    0.519364    
#> 118: 0.516481    0.934210    3.489711    0.278552    0.118326    0.022466    0.519019    
#> 119: 0.483432    0.924023    3.482230    0.278261    0.112410    0.025996    0.532605    
#> 120: 0.432788    0.925172    3.473255    0.287447    0.117113    0.024827    0.507936    
#> 121: 0.483811    0.948350    3.475362    0.273074    0.117233    0.023585    0.509383    
#> 122: 0.511626    0.924483    3.493931    0.303410    0.119574    0.025056    0.500536    
#> 123: 0.545488    0.952862    3.477611    0.347922    0.113596    0.023803    0.517012    
#> 124: 0.512977    0.960813    3.480458    0.330525    0.125416    0.024225    0.518178    
#> 125: 0.502464    0.944407    3.479087    0.313999    0.132914    0.023014    0.518372    
#> 126: 0.499513    0.950392    3.472184    0.298299    0.126384    0.022343    0.526480    
#> 127: 0.486870    0.951176    3.467979    0.283384    0.120420    0.023382    0.521899    
#> 128: 0.481797    0.939272    3.482420    0.269215    0.114781    0.023763    0.529441    
#> 129: 0.489292    0.935595    3.480414    0.278812    0.126101    0.025312    0.514471    
#> 130: 0.511153    0.947426    3.475439    0.293851    0.121821    0.026610    0.499189    
#> 131: 0.485518    0.928886    3.475337    0.325956    0.115730    0.026453    0.504035    
#> 132: 0.468202    0.949060    3.466948    0.309658    0.110162    0.025131    0.513285    
#> 133: 0.455229    0.933684    3.476130    0.313200    0.105408    0.023876    0.508505    
#> 134: 0.477421    0.931578    3.477620    0.326994    0.108080    0.022683    0.523640    
#> 135: 0.478043    0.938330    3.475355    0.310644    0.130094    0.021548    0.510336    
#> 136: 0.478211    0.940827    3.476520    0.295112    0.123589    0.020471    0.511332    
#> 137: 0.510146    0.951052    3.482333    0.282138    0.117410    0.019447    0.525450    
#> 138: 0.488333    0.940870    3.481036    0.268031    0.111539    0.019491    0.524113    
#> 139: 0.465229    0.945457    3.483550    0.283019    0.111349    0.022447    0.520871    
#> 140: 0.461480    0.938714    3.473989    0.318005    0.108082    0.023812    0.504875    
#> 141: 0.448062    0.948520    3.472010    0.306700    0.112695    0.023950    0.508198    
#> 142: 0.477802    0.941120    3.482991    0.300038    0.117774    0.024918    0.516150    
#> 143: 0.474255    0.954831    3.473909    0.317742    0.122464    0.025122    0.526653    
#> 144: 0.480762    0.956087    3.476621    0.336168    0.129872    0.025368    0.515408    
#> 145: 0.487107    0.950368    3.477743    0.319360    0.123378    0.027129    0.515477    
#> 146: 0.469593    0.933179    3.471705    0.323737    0.128494    0.025772    0.527598    
#> 147: 0.469949    0.934539    3.468171    0.330795    0.122069    0.024489    0.507992    
#> 148: 0.455893    0.945986    3.480625    0.328255    0.117337    0.023265    0.517915    
#> 149: 0.480236    0.952177    3.471416    0.327761    0.139610    0.022101    0.514196    
#> 150: 0.490860    0.957638    3.468602    0.340911    0.147931    0.023797    0.518562    
#> 151: 0.471495    0.986530    3.466722    0.330016    0.140534    0.022607    0.513743    
#> 152: 0.440591    0.960934    3.459621    0.334220    0.104162    0.029192    0.506739    
#> 153: 0.449346    0.954353    3.464601    0.344975    0.108789    0.026105    0.512570    
#> 154: 0.466563    0.960983    3.464247    0.355519    0.098453    0.024631    0.515478    
#> 155: 0.462051    0.962149    3.459415    0.333356    0.112015    0.024468    0.512383    
#> 156: 0.451613    0.960902    3.466857    0.338045    0.107895    0.023213    0.527110    
#> 157: 0.448720    0.970166    3.460682    0.340521    0.112840    0.021380    0.517183    
#> 158: 0.459431    0.985047    3.452917    0.314185    0.116061    0.020219    0.516329    
#> 159: 0.413144    0.977849    3.451054    0.290025    0.122041    0.022722    0.520541    
#> 160: 0.451059    0.953226    3.466206    0.335895    0.123506    0.026509    0.528605    
#> 161: 0.477960    0.938377    3.468148    0.328520    0.121445    0.023443    0.531528    
#> 162: 0.441100    0.944402    3.459092    0.351622    0.125174    0.018843    0.541068    
#> 163: 0.445033    0.956838    3.458468    0.341890    0.144765    0.018151    0.539448    
#> 164: 0.464378    0.980636    3.456685    0.331457    0.134382    0.018043    0.527755    
#> 165: 0.467159    0.928557    3.469668    0.313546    0.130473    0.017242    0.518361    
#> 166: 0.475722    0.968614    3.463233    0.301808    0.131484    0.015538    0.517294    
#> 167: 0.457753    0.964873    3.479871    0.270037    0.133455    0.016311    0.530261    
#> 168: 0.489730    0.960631    3.480305    0.297469    0.130676    0.018724    0.524512    
#> 169: 0.499156    0.965115    3.474283    0.311195    0.135652    0.019031    0.519829    
#> 170: 0.510474    0.967738    3.478989    0.306940    0.123667    0.022058    0.522176    
#> 171: 0.469959    0.937824    3.479125    0.311117    0.128195    0.018790    0.507273    
#> 172: 0.462809    0.950275    3.471146    0.333945    0.133280    0.017665    0.499387    
#> 173: 0.444241    0.948559    3.465885    0.297626    0.139191    0.021566    0.495174    
#> 174: 0.454827    0.958998    3.470293    0.316003    0.132696    0.023473    0.489907    
#> 175: 0.445740    0.944160    3.455184    0.354130    0.119364    0.023337    0.504543    
#> 176: 0.438159    0.959953    3.465695    0.324494    0.121289    0.022894    0.506961    
#> 177: 0.466584    0.962621    3.469079    0.302219    0.129571    0.023603    0.510135    
#> 178: 0.491156    0.940756    3.479902    0.316347    0.109540    0.023292    0.518075    
#> 179: 0.494125    0.962941    3.471908    0.262441    0.127257    0.019579    0.535266    
#> 180: 0.446586    0.960331    3.474197    0.303745    0.120154    0.020423    0.521950    
#> 181: 0.499585    0.956325    3.458203    0.331765    0.125196    0.023566    0.526798    
#> 182: 0.445411    0.946874    3.459979    0.279186    0.107460    0.026247    0.514961    
#> 183: 0.462932    0.964580    3.463656    0.280035    0.095436    0.031031    0.529044    
#> 184: 0.452643    0.963716    3.460840    0.280253    0.108989    0.027939    0.521713    
#> 185: 0.433788    0.971673    3.448047    0.294326    0.114930    0.028064    0.513964    
#> 186: 0.427652    0.970845    3.460218    0.263465    0.104770    0.027160    0.520980    
#> 187: 0.463430    0.952795    3.471463    0.285326    0.104148    0.028109    0.514752    
#> 188: 0.450902    0.952427    3.466502    0.270016    0.113897    0.026719    0.517692    
#> 189: 0.467367    0.963893    3.471680    0.274202    0.124603    0.023046    0.512320    
#> 190: 0.472937    0.974030    3.468625    0.279895    0.118705    0.023047    0.505354    
#> 191: 0.487212    0.964207    3.467581    0.267778    0.110354    0.021753    0.515322    
#> 192: 0.443286    0.965550    3.473465    0.261815    0.117225    0.018815    0.524652    
#> 193: 0.489907    0.976110    3.484352    0.255663    0.128742    0.019130    0.537676    
#> 194: 0.453862    0.953141    3.470124    0.255658    0.131627    0.019283    0.523139    
#> 195: 0.455268    0.948025    3.462901    0.261424    0.124946    0.019317    0.523801    
#> 196: 0.452267    0.950261    3.465781    0.272985    0.123831    0.017512    0.523656    
#> 197: 0.457695    0.938274    3.483244    0.293512    0.119413    0.021096    0.538700    
#> 198: 0.496497    0.913213    3.481392    0.276630    0.106025    0.023457    0.537575    
#> 199: 0.477963    0.923443    3.472780    0.322754    0.115898    0.019301    0.524743    
#> 200: 0.469038    0.927063    3.477511    0.293940    0.128442    0.019125    0.519195    
#> 201: 0.470797    0.931309    3.478808    0.296084    0.129284    0.021128    0.515014    
#> 202: 0.463086    0.934279    3.475900    0.299341    0.130210    0.021761    0.517150    
#> 203: 0.470743    0.934542    3.473595    0.297696    0.130647    0.021895    0.519412    
#> 204: 0.471967    0.934329    3.473852    0.298545    0.130917    0.021254    0.522771    
#> 205: 0.472012    0.937510    3.473974    0.290395    0.130764    0.020335    0.526856    
#> 206: 0.471044    0.939532    3.474958    0.286869    0.130431    0.019999    0.528339    
#> 207: 0.467156    0.941575    3.472739    0.285393    0.128879    0.019887    0.527932    
#> 208: 0.465696    0.943290    3.471360    0.287064    0.129275    0.019474    0.527112    
#> 209: 0.466536    0.943516    3.471114    0.287654    0.128783    0.019261    0.525874    
#> 210: 0.467067    0.943091    3.471749    0.282734    0.128324    0.019104    0.524411    
#> 211: 0.469996    0.943635    3.472409    0.280871    0.127687    0.019150    0.523212    
#> 212: 0.471747    0.943193    3.473194    0.280913    0.126003    0.019270    0.523145    
#> 213: 0.473947    0.941678    3.474285    0.283219    0.124735    0.019598    0.523072    
#> 214: 0.475824    0.939901    3.475307    0.284728    0.124033    0.019770    0.522219    
#> 215: 0.476920    0.939602    3.476126    0.283422    0.123338    0.019851    0.522420    
#> 216: 0.479634    0.938535    3.476926    0.282274    0.123008    0.019939    0.523531    
#> 217: 0.480826    0.938961    3.477400    0.280452    0.122536    0.019983    0.523629    
#> 218: 0.479896    0.939167    3.476978    0.280102    0.122295    0.019891    0.523520    
#> 219: 0.478819    0.939776    3.476272    0.277049    0.122680    0.019672    0.523527    
#> 220: 0.476604    0.941255    3.475504    0.275258    0.122834    0.019510    0.523806    
#> 221: 0.476046    0.942629    3.475138    0.273364    0.123424    0.019273    0.524086    
#> 222: 0.476282    0.943281    3.475016    0.271868    0.122962    0.019143    0.524235    
#> 223: 0.477139    0.942377    3.474981    0.271169    0.122920    0.019134    0.523933    
#> 224: 0.477540    0.942897    3.474722    0.270785    0.122584    0.019125    0.524001    
#> 225: 0.476600    0.942323    3.474839    0.269234    0.122107    0.019073    0.524215    
#> 226: 0.475619    0.942505    3.474203    0.268524    0.122200    0.018925    0.524251    
#> 227: 0.474641    0.943257    3.473783    0.266201    0.122951    0.018826    0.524442    
#> 228: 0.473322    0.943871    3.473045    0.264484    0.123003    0.018643    0.524800    
#> 229: 0.472080    0.944451    3.472792    0.263540    0.122915    0.018509    0.525168    
#> 230: 0.471466    0.944875    3.472350    0.263441    0.123104    0.018315    0.525541    
#> 231: 0.470671    0.944980    3.472232    0.263890    0.122788    0.018226    0.525700    
#> 232: 0.469889    0.945182    3.472074    0.264149    0.122486    0.018186    0.525534    
#> 233: 0.469058    0.945221    3.471842    0.264244    0.122859    0.018017    0.525671    
#> 234: 0.467993    0.945199    3.471611    0.264648    0.123368    0.017931    0.525420    
#> 235: 0.467524    0.944828    3.471689    0.265105    0.123009    0.017850    0.525644    
#> 236: 0.467011    0.944877    3.471601    0.265048    0.122918    0.017731    0.525851    
#> 237: 0.467497    0.944983    3.471557    0.265581    0.123159    0.017671    0.526340    
#> 238: 0.468111    0.945421    3.471490    0.264357    0.123610    0.017609    0.527195    
#> 239: 0.467690    0.946041    3.471401    0.263784    0.123470    0.017653    0.526977    
#> 240: 0.468193    0.946008    3.471604    0.263420    0.123515    0.017696    0.526429    
#> 241: 0.469022    0.945211    3.471871    0.263453    0.123452    0.017752    0.526305    
#> 242: 0.468990    0.944980    3.471902    0.263915    0.123617    0.017718    0.526653    
#> 243: 0.469062    0.945457    3.471940    0.264772    0.123505    0.017671    0.526717    
#> 244: 0.468981    0.945406    3.472112    0.265169    0.123638    0.017634    0.526908    
#> 245: 0.469595    0.944954    3.472335    0.266190    0.124001    0.017583    0.526972    
#> 246: 0.470297    0.944564    3.472444    0.266530    0.124086    0.017561    0.526878    
#> 247: 0.470961    0.944475    3.472744    0.267107    0.124194    0.017576    0.527004    
#> 248: 0.471185    0.944805    3.472889    0.267278    0.124722    0.017567    0.526902    
#> 249: 0.471043    0.945042    3.472975    0.267305    0.124609    0.017626    0.526976    
#> 250: 0.471106    0.945022    3.472958    0.268541    0.124372    0.017734    0.526832    
#> 251: 0.471481    0.945552    3.473156    0.269183    0.124350    0.017774    0.527060    
#> 252: 0.471470    0.945893    3.473227    0.269792    0.124230    0.017817    0.527033    
#> 253: 0.471312    0.946338    3.473059    0.270201    0.124231    0.017883    0.526752    
#> 254: 0.471299    0.946583    3.472935    0.270888    0.124100    0.017949    0.526589    
#> 255: 0.471296    0.946968    3.472751    0.272033    0.123998    0.018045    0.526327    
#> 256: 0.471140    0.947268    3.472557    0.272903    0.124376    0.018071    0.526097    
#> 257: 0.470660    0.947348    3.472458    0.272895    0.124466    0.018076    0.525849    
#> 258: 0.470464    0.947396    3.472339    0.273216    0.124351    0.018108    0.525632    
#> 259: 0.470067    0.947352    3.472227    0.273455    0.124287    0.018123    0.525715    
#> 260: 0.469807    0.947509    3.472086    0.273831    0.124301    0.018111    0.525507    
#> 261: 0.469498    0.947376    3.472061    0.274405    0.124275    0.018101    0.525531    
#> 262: 0.469439    0.947559    3.472138    0.274478    0.124346    0.018117    0.525479    
#> 263: 0.469479    0.947614    3.472224    0.274181    0.124511    0.018163    0.525373    
#> 264: 0.469571    0.947673    3.472197    0.274111    0.124632    0.018153    0.525120    
#> 265: 0.469624    0.947702    3.472325    0.274069    0.124781    0.018176    0.525001    
#> 266: 0.469838    0.947799    3.472499    0.273587    0.124762    0.018195    0.524887    
#> 267: 0.470418    0.947672    3.472799    0.272966    0.124774    0.018209    0.525030    
#> 268: 0.470802    0.947177    3.472970    0.272726    0.124799    0.018217    0.525056    
#> 269: 0.471605    0.947004    3.473173    0.272865    0.124807    0.018258    0.524961    
#> 270: 0.471907    0.947127    3.473283    0.272637    0.124769    0.018285    0.524864    
#> 271: 0.471781    0.946902    3.473353    0.273075    0.124770    0.018337    0.524602    
#> 272: 0.471779    0.946614    3.473315    0.273102    0.124843    0.018360    0.524735    
#> 273: 0.471711    0.946723    3.473418    0.272975    0.124944    0.018399    0.524683    
#> 274: 0.471710    0.946724    3.473546    0.272881    0.125160    0.018422    0.524825    
#> 275: 0.471526    0.946855    3.473385    0.272556    0.125379    0.018430    0.524996    
#> 276: 0.471520    0.947012    3.473375    0.272348    0.125456    0.018428    0.525099    
#> 277: 0.471345    0.947315    3.473340    0.272004    0.125463    0.018441    0.525109    
#> 278: 0.471296    0.947323    3.473406    0.271948    0.125504    0.018475    0.525046    
#> 279: 0.471324    0.947369    3.473372    0.272370    0.125580    0.018493    0.525036    
#> 280: 0.471325    0.947491    3.473326    0.272339    0.125613    0.018490    0.524882    
#> 281: 0.471063    0.947691    3.473259    0.272749    0.125737    0.018492    0.524754    
#> 282: 0.471302    0.947728    3.473377    0.272816    0.125942    0.018472    0.524902    
#> 283: 0.471201    0.947768    3.473410    0.272794    0.126026    0.018452    0.525144    
#> 284: 0.471036    0.947714    3.473437    0.272528    0.126171    0.018436    0.525147    
#> 285: 0.470733    0.947723    3.473303    0.272251    0.126281    0.018397    0.525284    
#> 286: 0.470379    0.947604    3.473077    0.272271    0.126268    0.018388    0.525301    
#> 287: 0.469890    0.947727    3.472899    0.271762    0.126158    0.018379    0.525422    
#> 288: 0.469604    0.947649    3.472852    0.271650    0.126145    0.018383    0.525463    
#> 289: 0.469739    0.947530    3.472825    0.271595    0.126007    0.018406    0.525355    
#> 290: 0.469950    0.947486    3.472887    0.271676    0.125920    0.018434    0.525333    
#> 291: 0.470007    0.947564    3.472969    0.271627    0.125815    0.018476    0.525121    
#> 292: 0.469907    0.947619    3.472947    0.271505    0.125678    0.018504    0.525015    
#> 293: 0.469699    0.947861    3.472863    0.271709    0.125694    0.018544    0.524914    
#> 294: 0.469485    0.948157    3.472695    0.271782    0.125714    0.018580    0.524842    
#> 295: 0.469316    0.948157    3.472527    0.271644    0.125685    0.018576    0.524791    
#> 296: 0.469219    0.948294    3.472451    0.271565    0.125755    0.018606    0.524776    
#> 297: 0.469273    0.948398    3.472391    0.271857    0.125619    0.018618    0.524839    
#> 298: 0.469062    0.948474    3.472278    0.271941    0.125539    0.018618    0.524833    
#> 299: 0.469215    0.948682    3.472272    0.272196    0.125415    0.018646    0.524798    
#> 300: 0.469194    0.948828    3.472338    0.272110    0.125197    0.018691    0.524754    
#> 301: 0.469147    0.949018    3.472268    0.272268    0.125011    0.018723    0.524736    
#> 302: 0.469135    0.949144    3.472263    0.272648    0.124819    0.018752    0.524631    
#> 303: 0.469242    0.949249    3.472202    0.272985    0.124689    0.018786    0.524498    
#> 304: 0.469184    0.949595    3.472101    0.273179    0.124568    0.018808    0.524447    
#> 305: 0.468804    0.949564    3.471967    0.273466    0.124376    0.018851    0.524376    
#> 306: 0.468336    0.949607    3.471761    0.273795    0.124331    0.018900    0.524293    
#> 307: 0.467968    0.949807    3.471618    0.273921    0.124357    0.018929    0.524347    
#> 308: 0.467621    0.949890    3.471591    0.274046    0.124118    0.018956    0.524330    
#> 309: 0.467419    0.949779    3.471567    0.274011    0.124021    0.018988    0.524314    
#> 310: 0.467427    0.949795    3.471530    0.274077    0.123865    0.018979    0.524340    
#> 311: 0.467482    0.949869    3.471516    0.274194    0.123807    0.018993    0.524321    
#> 312: 0.467472    0.949761    3.471513    0.274374    0.123576    0.019014    0.524395    
#> 313: 0.467511    0.949463    3.471453    0.274534    0.123455    0.019013    0.524354    
#> 314: 0.467295    0.949565    3.471348    0.274932    0.123458    0.019031    0.524334    
#> 315: 0.467141    0.949712    3.471264    0.275583    0.123435    0.019057    0.524180    
#> 316: 0.467220    0.949870    3.471180    0.276163    0.123416    0.019071    0.524064    
#> 317: 0.467232    0.949965    3.471237    0.276610    0.123312    0.019107    0.524038    
#> 318: 0.467249    0.950085    3.471130    0.276665    0.123248    0.019122    0.524018    
#> 319: 0.467256    0.950145    3.471150    0.276668    0.123184    0.019143    0.524025    
#> 320: 0.466862    0.950021    3.471118    0.276474    0.123125    0.019162    0.524115    
#> 321: 0.466657    0.950045    3.471040    0.276204    0.123050    0.019159    0.524302    
#> 322: 0.466610    0.950116    3.471005    0.275979    0.123162    0.019133    0.524295    
#> 323: 0.466357    0.950157    3.470917    0.275789    0.123155    0.019091    0.524294    
#> 324: 0.466213    0.950169    3.470955    0.275648    0.123167    0.019086    0.524221    
#> 325: 0.466091    0.950287    3.470896    0.275625    0.123112    0.019076    0.524095    
#> 326: 0.466008    0.950238    3.470810    0.275574    0.123094    0.019053    0.523997    
#> 327: 0.465980    0.950269    3.470810    0.275619    0.123153    0.019039    0.523991    
#> 328: 0.466104    0.950345    3.470831    0.275842    0.123218    0.019010    0.523910    
#> 329: 0.466303    0.950195    3.470908    0.276126    0.123232    0.018994    0.523851    
#> 330: 0.466229    0.949954    3.470985    0.276358    0.123284    0.018990    0.523802    
#> 331: 0.466479    0.950014    3.471043    0.276357    0.123287    0.018984    0.523665    
#> 332: 0.466732    0.950123    3.471135    0.276332    0.123181    0.019006    0.523658    
#> 333: 0.466879    0.950055    3.471157    0.276241    0.123121    0.019023    0.523745    
#> 334: 0.466848    0.949966    3.471057    0.276389    0.123156    0.019027    0.523825    
#> 335: 0.466744    0.949992    3.470959    0.276349    0.123177    0.019038    0.523729    
#> 336: 0.466440    0.950140    3.470887    0.276299    0.123225    0.019059    0.523696    
#> 337: 0.466208    0.950423    3.470756    0.276106    0.123370    0.019067    0.523742    
#> 338: 0.466052    0.950519    3.470762    0.275843    0.123421    0.019054    0.523816    
#> 339: 0.465897    0.950623    3.470692    0.275644    0.123548    0.019044    0.523801    
#> 340: 0.465661    0.950590    3.470627    0.275673    0.123655    0.019025    0.523706    
#> 341: 0.465614    0.950631    3.470617    0.275756    0.123771    0.019013    0.523633    
#> 342: 0.465309    0.950562    3.470579    0.275640    0.123830    0.018996    0.523574    
#> 343: 0.465122    0.950564    3.470545    0.275960    0.123831    0.018988    0.523408    
#> 344: 0.465093    0.950645    3.470522    0.276314    0.123870    0.018988    0.523451    
#> 345: 0.465066    0.950606    3.470493    0.276456    0.123904    0.018989    0.523495    
#> 346: 0.464980    0.950490    3.470441    0.276699    0.123821    0.019001    0.523629    
#> 347: 0.464863    0.950375    3.470402    0.276841    0.123758    0.019018    0.523757    
#> 348: 0.464763    0.950408    3.470349    0.276701    0.123839    0.019006    0.523789    
#> 349: 0.464595    0.950326    3.470320    0.276496    0.123925    0.019003    0.523753    
#> 350: 0.464578    0.950273    3.470288    0.276258    0.124091    0.018985    0.523709    
#> 351: 0.464704    0.950368    3.470286    0.276159    0.124214    0.018960    0.523735    
#> 352: 0.464466    0.950471    3.470231    0.276188    0.124287    0.018944    0.523868    
#> 353: 0.464418    0.950562    3.470196    0.276327    0.124390    0.018931    0.523850    
#> 354: 0.464297    0.950607    3.470120    0.276205    0.124376    0.018927    0.523923    
#> 355: 0.464378    0.950511    3.470100    0.276180    0.124429    0.018899    0.523991    
#> 356: 0.464410    0.950458    3.470155    0.276090    0.124470    0.018895    0.524038    
#> 357: 0.464511    0.950522    3.470213    0.275962    0.124442    0.018883    0.524053    
#> 358: 0.464656    0.950456    3.470302    0.275942    0.124454    0.018880    0.524047    
#> 359: 0.464655    0.950423    3.470324    0.275807    0.124445    0.018873    0.524021    
#> 360: 0.464575    0.950419    3.470275    0.275644    0.124408    0.018872    0.523955    
#> 361: 0.464758    0.950356    3.470325    0.275823    0.124482    0.018863    0.523950    
#> 362: 0.464913    0.950266    3.470358    0.275968    0.124454    0.018865    0.523843    
#> 363: 0.465017    0.950185    3.470369    0.276144    0.124458    0.018867    0.523733    
#> 364: 0.465085    0.950165    3.470356    0.276397    0.124429    0.018879    0.523758    
#> 365: 0.465163    0.950042    3.470431    0.276735    0.124441    0.018904    0.523704    
#> 366: 0.465153    0.950059    3.470378    0.277029    0.124455    0.018924    0.523720    
#> 367: 0.465151    0.950110    3.470370    0.277081    0.124531    0.018924    0.523666    
#> 368: 0.465216    0.950272    3.470312    0.276955    0.124552    0.018934    0.523601    
#> 369: 0.465192    0.950374    3.470263    0.276905    0.124535    0.018936    0.523596    
#> 370: 0.465267    0.950463    3.470263    0.277043    0.124469    0.018955    0.523529    
#> 371: 0.465189    0.950530    3.470198    0.277037    0.124449    0.018955    0.523502    
#> 372: 0.465111    0.950636    3.470140    0.276926    0.124469    0.018950    0.523514    
#> 373: 0.464848    0.950720    3.470063    0.276858    0.124488    0.018943    0.523507    
#> 374: 0.464727    0.950804    3.470023    0.276815    0.124438    0.018955    0.523447    
#> 375: 0.464629    0.950885    3.469994    0.276989    0.124325    0.018975    0.523376    
#> 376: 0.464625    0.950914    3.469994    0.277008    0.124258    0.018979    0.523274    
#> 377: 0.464532    0.951015    3.469967    0.277067    0.124320    0.019001    0.523209    
#> 378: 0.464458    0.951040    3.469881    0.277150    0.124324    0.018998    0.523195    
#> 379: 0.464332    0.951042    3.469858    0.277237    0.124349    0.018984    0.523137    
#> 380: 0.464380    0.950990    3.469898    0.277297    0.124373    0.019002    0.523016    
#> 381: 0.464265    0.950978    3.469906    0.277362    0.124393    0.018998    0.523026    
#> 382: 0.464270    0.950989    3.469901    0.277367    0.124442    0.018990    0.523006    
#> 383: 0.464340    0.950962    3.469934    0.277455    0.124531    0.018988    0.522954    
#> 384: 0.464346    0.950849    3.469987    0.277539    0.124664    0.018982    0.522953    
#> 385: 0.464473    0.950722    3.470025    0.277582    0.124731    0.018980    0.522947    
#> 386: 0.464630    0.950736    3.470030    0.277690    0.124696    0.018974    0.522907    
#> 387: 0.464788    0.950906    3.470071    0.277748    0.124709    0.018975    0.522836    
#> 388: 0.465011    0.950899    3.470134    0.277760    0.124830    0.018982    0.522795    
#> 389: 0.465121    0.950734    3.470194    0.277736    0.124814    0.018986    0.522855    
#> 390: 0.465092    0.950719    3.470231    0.277653    0.124912    0.018966    0.522959    
#> 391: 0.465229    0.950692    3.470261    0.277824    0.125029    0.018968    0.522991    
#> 392: 0.465306    0.950648    3.470322    0.277911    0.125097    0.018975    0.522981    
#> 393: 0.465419    0.950523    3.470371    0.277869    0.125148    0.018972    0.522978    
#> 394: 0.465501    0.950498    3.470409    0.278038    0.125178    0.018973    0.522972    
#> 395: 0.465691    0.950538    3.470379    0.278185    0.125208    0.018974    0.523030    
#> 396: 0.465899    0.950586    3.470412    0.278241    0.125157    0.018985    0.523028    
#> 397: 0.465999    0.950553    3.470430    0.278279    0.125115    0.019010    0.522983    
#> 398: 0.466187    0.950442    3.470469    0.278352    0.124994    0.019021    0.522957    
#> 399: 0.466451    0.950301    3.470601    0.278370    0.124979    0.019025    0.522944    
#> 400: 0.466699    0.950228    3.470689    0.278498    0.124928    0.019046    0.522947    
#> 401: 0.466840    0.950216    3.470762    0.278532    0.124821    0.019080    0.523006    
#> 402: 0.466944    0.950274    3.470786    0.278543    0.124764    0.019091    0.522973    
#> 403: 0.467174    0.950235    3.470820    0.278683    0.124785    0.019088    0.522878    
#> 404: 0.467234    0.950227    3.470779    0.278788    0.124805    0.019089    0.522762    
#> 405: 0.467175    0.950231    3.470798    0.278797    0.124779    0.019098    0.522696    
#> 406: 0.467140    0.950214    3.470799    0.278882    0.124795    0.019101    0.522711    
#> 407: 0.467153    0.950188    3.470815    0.278942    0.124775    0.019101    0.522705    
#> 408: 0.467244    0.950176    3.470811    0.279030    0.124739    0.019094    0.522722    
#> 409: 0.467192    0.950094    3.470789    0.279086    0.124700    0.019086    0.522732    
#> 410: 0.467178    0.950214    3.470717    0.279376    0.124689    0.019077    0.522731    
#> 411: 0.467168    0.950188    3.470681    0.279585    0.124703    0.019083    0.522699    
#> 412: 0.467159    0.950343    3.470651    0.279828    0.124752    0.019090    0.522661    
#> 413: 0.467183    0.950482    3.470611    0.280183    0.124753    0.019121    0.522647    
#> 414: 0.466977    0.950593    3.470565    0.280420    0.124798    0.019133    0.522627    
#> 415: 0.466973    0.950592    3.470548    0.280520    0.124777    0.019138    0.522610    
#> 416: 0.466979    0.950612    3.470578    0.280554    0.124774    0.019146    0.522633    
#> 417: 0.466914    0.950572    3.470552    0.280572    0.124738    0.019147    0.522586    
#> 418: 0.466776    0.950593    3.470547    0.280451    0.124739    0.019146    0.522526    
#> 419: 0.466748    0.950547    3.470563    0.280258    0.124780    0.019143    0.522492    
#> 420: 0.466715    0.950513    3.470574    0.280233    0.124848    0.019136    0.522408    
#> 421: 0.466644    0.950514    3.470613    0.280259    0.124946    0.019134    0.522358    
#> 422: 0.466843    0.950486    3.470669    0.280291    0.124939    0.019138    0.522325    
#> 423: 0.466998    0.950386    3.470688    0.280346    0.124978    0.019121    0.522328    
#> 424: 0.466970    0.950278    3.470659    0.280209    0.124984    0.019115    0.522311    
#> 425: 0.466974    0.950315    3.470622    0.280249    0.124948    0.019122    0.522333    
#> 426: 0.466948    0.950409    3.470597    0.280349    0.124957    0.019115    0.522305    
#> 427: 0.466857    0.950484    3.470584    0.280596    0.124948    0.019123    0.522239    
#> 428: 0.466778    0.950628    3.470527    0.280871    0.124925    0.019133    0.522247    
#> 429: 0.466801    0.950666    3.470524    0.281147    0.124913    0.019143    0.522225    
#> 430: 0.466788    0.950675    3.470495    0.281298    0.124899    0.019160    0.522150    
#> 431: 0.466769    0.950680    3.470438    0.281532    0.124846    0.019165    0.522085    
#> 432: 0.466836    0.950732    3.470442    0.281832    0.124839    0.019178    0.522014    
#> 433: 0.466858    0.950792    3.470422    0.281970    0.124835    0.019206    0.521989    
#> 434: 0.466843    0.950797    3.470426    0.282045    0.124812    0.019218    0.521947    
#> 435: 0.466881    0.950824    3.470398    0.282170    0.124735    0.019239    0.521876    
#> 436: 0.466885    0.950780    3.470448    0.282319    0.124713    0.019254    0.521893    
#> 437: 0.466970    0.950724    3.470476    0.282404    0.124725    0.019253    0.521894    
#> 438: 0.466956    0.950754    3.470479    0.282326    0.124705    0.019251    0.521863    
#> 439: 0.466927    0.950855    3.470490    0.282259    0.124690    0.019248    0.521853    
#> 440: 0.466899    0.950943    3.470501    0.282158    0.124695    0.019247    0.521914    
#> 441: 0.466884    0.950934    3.470505    0.282133    0.124676    0.019249    0.521870    
#> 442: 0.466758    0.951020    3.470486    0.282054    0.124696    0.019246    0.521827    
#> 443: 0.466701    0.951148    3.470451    0.282060    0.124679    0.019241    0.521780    
#> 444: 0.466590    0.951267    3.470420    0.281936    0.124696    0.019235    0.521724    
#> 445: 0.466536    0.951254    3.470402    0.281904    0.124672    0.019238    0.521708    
#> 446: 0.466505    0.951265    3.470404    0.281848    0.124644    0.019240    0.521697    
#> 447: 0.466604    0.951252    3.470433    0.281942    0.124595    0.019244    0.521734    
#> 448: 0.466659    0.951168    3.470469    0.282030    0.124570    0.019255    0.521695    
#> 449: 0.466772    0.951150    3.470543    0.282033    0.124511    0.019269    0.521679    
#> 450: 0.466786    0.951079    3.470562    0.281981    0.124434    0.019278    0.521705    
#> 451: 0.466843    0.951032    3.470579    0.281906    0.124373    0.019296    0.521704    
#> 452: 0.466890    0.951026    3.470565    0.281982    0.124365    0.019314    0.521675    
#> 453: 0.466907    0.950998    3.470535    0.282031    0.124394    0.019324    0.521644    
#> 454: 0.466955    0.951113    3.470511    0.282157    0.124382    0.019321    0.521619    
#> 455: 0.466955    0.951126    3.470484    0.282258    0.124372    0.019313    0.521596    
#> 456: 0.466847    0.951060    3.470453    0.282339    0.124332    0.019322    0.521603    
#> 457: 0.466856    0.951036    3.470466    0.282382    0.124345    0.019326    0.521560    
#> 458: 0.466864    0.951134    3.470475    0.282402    0.124328    0.019332    0.521525    
#> 459: 0.466733    0.951241    3.470426    0.282363    0.124308    0.019332    0.521546    
#> 460: 0.466635    0.951321    3.470377    0.282489    0.124268    0.019325    0.521517    
#> 461: 0.466610    0.951319    3.470387    0.282529    0.124261    0.019317    0.521481    
#> 462: 0.466580    0.951333    3.470410    0.282433    0.124219    0.019314    0.521464    
#> 463: 0.466591    0.951438    3.470433    0.282421    0.124218    0.019299    0.521444    
#> 464: 0.466666    0.951468    3.470426    0.282336    0.124232    0.019292    0.521390    
#> 465: 0.466788    0.951420    3.470474    0.282221    0.124256    0.019286    0.521373    
#> 466: 0.466854    0.951438    3.470482    0.282073    0.124282    0.019272    0.521348    
#> 467: 0.466829    0.951440    3.470524    0.282042    0.124274    0.019271    0.521264    
#> 468: 0.466949    0.951416    3.470588    0.282051    0.124299    0.019270    0.521261    
#> 469: 0.467018    0.951396    3.470617    0.282033    0.124296    0.019279    0.521317    
#> 470: 0.466953    0.951453    3.470601    0.281964    0.124239    0.019295    0.521277    
#> 471: 0.466914    0.951397    3.470616    0.282000    0.124217    0.019309    0.521234    
#> 472: 0.466896    0.951311    3.470627    0.282001    0.124163    0.019324    0.521186    
#> 473: 0.466901    0.951287    3.470644    0.282018    0.124151    0.019326    0.521122    
#> 474: 0.466854    0.951261    3.470671    0.281944    0.124106    0.019324    0.521135    
#> 475: 0.466943    0.951227    3.470713    0.281903    0.124079    0.019314    0.521127    
#> 476: 0.467004    0.951196    3.470737    0.281873    0.124032    0.019313    0.521166    
#> 477: 0.467098    0.951176    3.470789    0.281864    0.123996    0.019322    0.521125    
#> 478: 0.467128    0.951182    3.470843    0.281979    0.123935    0.019324    0.521179    
#> 479: 0.467278    0.951143    3.470917    0.282123    0.123861    0.019339    0.521195    
#> 480: 0.467434    0.951094    3.470946    0.282161    0.123790    0.019346    0.521233    
#> 481: 0.467523    0.951092    3.470989    0.282185    0.123747    0.019349    0.521249    
#> 482: 0.467656    0.951056    3.471010    0.282274    0.123726    0.019346    0.521274    
#> 483: 0.467694    0.951032    3.471012    0.282286    0.123676    0.019347    0.521211    
#> 484: 0.467755    0.950968    3.471055    0.282285    0.123620    0.019354    0.521154    
#> 485: 0.467757    0.950994    3.471060    0.282203    0.123652    0.019357    0.521125    
#> 486: 0.467727    0.951040    3.471071    0.282101    0.123660    0.019347    0.521090    
#> 487: 0.467788    0.951050    3.471094    0.282080    0.123698    0.019330    0.521075    
#> 488: 0.467836    0.951071    3.471103    0.282072    0.123715    0.019316    0.521066    
#> 489: 0.467908    0.951074    3.471084    0.282056    0.123734    0.019301    0.521068    
#> 490: 0.467987    0.951034    3.471108    0.282020    0.123715    0.019289    0.521055    
#> 491: 0.468030    0.951042    3.471147    0.281939    0.123734    0.019288    0.520992    
#> 492: 0.467997    0.951088    3.471159    0.281894    0.123743    0.019284    0.521032    
#> 493: 0.467961    0.951097    3.471168    0.281817    0.123689    0.019289    0.521036    
#> 494: 0.468095    0.951134    3.471190    0.281918    0.123629    0.019296    0.521039    
#> 495: 0.468192    0.951120    3.471217    0.281979    0.123587    0.019304    0.521063    
#> 496: 0.468313    0.951160    3.471215    0.281991    0.123514    0.019301    0.521097    
#> 497: 0.468294    0.951124    3.471229    0.281970    0.123524    0.019303    0.521150    
#> 498: 0.468247    0.951087    3.471224    0.281857    0.123525    0.019297    0.521114    
#> 499: 0.468235    0.951018    3.471224    0.281816    0.123514    0.019300    0.521063    
#> 500: 0.468298    0.950985    3.471252    0.281816    0.123500    0.019307    0.520986    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.293600    0.955387    3.435675    0.392401    0.073527    0.016800    1.790475    
#> 002: 0.401711    0.934642    3.436956    0.372781    0.069850    0.015960    1.209650    
#> 003: 0.410473    0.850654    3.404707    0.354142    0.066358    0.015162    0.969404    
#> 004: 0.348636    0.863224    3.390975    0.336435    0.063040    0.014404    0.916127    
#> 005: 0.387527    0.864443    3.375806    0.329395    0.059888    0.013684    0.865883    
#> 006: 0.355498    0.889214    3.358233    0.312926    0.062533    0.013000    0.818342    
#> 007: 0.311726    0.900024    3.362333    0.297352    0.059407    0.012350    0.842038    
#> 008: 0.293637    0.890096    3.352892    0.282484    0.056436    0.011732    0.841219    
#> 009: 0.282835    0.864638    3.347936    0.297210    0.053615    0.012680    0.837441    
#> 010: 0.285213    0.863485    3.342854    0.316796    0.050934    0.013892    0.856931    
#> 011: 0.303770    0.880608    3.346516    0.300956    0.048387    0.013981    0.863009    
#> 012: 0.310655    0.879792    3.345836    0.285908    0.045968    0.013396    0.839945    
#> 013: 0.312701    0.876778    3.348821    0.329899    0.043669    0.015595    0.843368    
#> 014: 0.338603    0.884967    3.356505    0.313404    0.050868    0.014815    0.862066    
#> 015: 0.363989    0.883392    3.372821    0.297734    0.048324    0.014568    0.830382    
#> 016: 0.349129    0.894866    3.379339    0.282847    0.056346    0.013840    0.839630    
#> 017: 0.336202    0.888376    3.371657    0.271495    0.053529    0.013148    0.809094    
#> 018: 0.366162    0.883000    3.366975    0.301107    0.051426    0.012490    0.846923    
#> 019: 0.257089    0.900094    3.345889    0.286052    0.048855    0.013712    0.830003    
#> 020: 0.303489    0.902672    3.349655    0.271749    0.046412    0.013027    0.826856    
#> 021: 0.315822    0.895730    3.356267    0.258162    0.044091    0.015395    0.828815    
#> 022: 0.325126    0.888991    3.370979    0.245253    0.041887    0.014625    0.811787    
#> 023: 0.370204    0.886382    3.373626    0.252690    0.042032    0.013894    0.837165    
#> 024: 0.342527    0.913652    3.360346    0.265102    0.039931    0.017069    0.830113    
#> 025: 0.324408    0.885708    3.355611    0.305812    0.037934    0.017381    0.826808    
#> 026: 0.292525    0.928197    3.335231    0.354113    0.036038    0.017229    0.822366    
#> 027: 0.287572    0.929759    3.332126    0.339502    0.034236    0.019750    0.833968    
#> 028: 0.330667    0.934303    3.344479    0.326044    0.032524    0.022099    0.815392    
#> 029: 0.335027    0.915352    3.344995    0.309742    0.039677    0.023133    0.834694    
#> 030: 0.299374    0.923686    3.343571    0.294255    0.037693    0.022784    0.832326    
#> 031: 0.265430    0.909306    3.342253    0.279542    0.035809    0.024832    0.818057    
#> 032: 0.260103    0.912455    3.343459    0.265565    0.034179    0.023591    0.818241    
#> 033: 0.266945    0.935266    3.339510    0.255014    0.039574    0.023986    0.808157    
#> 034: 0.318025    0.930485    3.353721    0.270687    0.037595    0.022786    0.829881    
#> 035: 0.272124    0.904272    3.342387    0.257153    0.035715    0.021647    0.798780    
#> 036: 0.272942    0.906265    3.347088    0.244295    0.041400    0.020565    0.801762    
#> 037: 0.277201    0.913068    3.348833    0.236998    0.039803    0.019536    0.827609    
#> 038: 0.327793    0.917158    3.348318    0.267594    0.043458    0.018560    0.825678    
#> 039: 0.322801    0.909783    3.354299    0.349956    0.041285    0.021931    0.807931    
#> 040: 0.298348    0.900169    3.363639    0.332459    0.042825    0.020835    0.830272    
#> 041: 0.306478    0.885824    3.368439    0.315836    0.041492    0.019793    0.817210    
#> 042: 0.353705    0.880048    3.365993    0.300044    0.039417    0.019396    0.810199    
#> 043: 0.312283    0.910342    3.347179    0.285042    0.037446    0.019821    0.808782    
#> 044: 0.266659    0.913074    3.344467    0.270790    0.035574    0.021078    0.801690    
#> 045: 0.275544    0.930604    3.334831    0.310097    0.033795    0.020024    0.814112    
#> 046: 0.273063    0.931625    3.337335    0.294592    0.032106    0.021992    0.803447    
#> 047: 0.297078    0.921078    3.342598    0.279862    0.036474    0.020893    0.800661    
#> 048: 0.328776    0.892494    3.357319    0.295725    0.043402    0.019848    0.805250    
#> 049: 0.320218    0.875181    3.365869    0.301405    0.041232    0.018856    0.826309    
#> 050: 0.393087    0.856195    3.382145    0.324313    0.041284    0.017913    0.852475    
#> 051: 0.361730    0.877041    3.364502    0.329760    0.046519    0.022445    0.831650    
#> 052: 0.363373    0.889153    3.368310    0.372058    0.044193    0.021323    0.829153    
#> 053: 0.378699    0.868537    3.369177    0.375742    0.042693    0.020257    0.828921    
#> 054: 0.369153    0.885927    3.378425    0.356955    0.050585    0.019244    0.856197    
#> 055: 0.381518    0.892626    3.377234    0.339107    0.048056    0.018473    0.842146    
#> 056: 0.396255    0.894741    3.375034    0.351637    0.053878    0.021791    0.847415    
#> 057: 0.379403    0.884162    3.383164    0.396452    0.051185    0.022620    0.834469    
#> 058: 0.375608    0.896772    3.359238    0.376629    0.052387    0.021489    0.825738    
#> 059: 0.356601    0.858027    3.370464    0.357798    0.049767    0.021058    0.841157    
#> 060: 0.328366    0.859025    3.372733    0.339908    0.058575    0.020005    0.855118    
#> 061: 0.371373    0.878073    3.367745    0.322912    0.055647    0.019004    0.848516    
#> 062: 0.322997    0.902956    3.372840    0.306767    0.052864    0.018054    0.878473    
#> 063: 0.348603    0.889002    3.358539    0.308614    0.050221    0.017152    0.878522    
#> 064: 0.307903    0.910930    3.357412    0.293183    0.047710    0.016803    0.836564    
#> 065: 0.306474    0.891969    3.342805    0.278524    0.045325    0.015963    0.821111    
#> 066: 0.266852    0.905436    3.332408    0.264598    0.043058    0.015165    0.828077    
#> 067: 0.267146    0.917796    3.325919    0.305421    0.040905    0.016494    0.826252    
#> 068: 0.255040    0.925953    3.345177    0.329225    0.040791    0.019532    0.822832    
#> 069: 0.256595    0.925763    3.339208    0.312764    0.043969    0.018731    0.836091    
#> 070: 0.317729    0.899226    3.359466    0.302027    0.045308    0.018417    0.840570    
#> 071: 0.315688    0.923899    3.338053    0.411775    0.050261    0.017496    0.833632    
#> 072: 0.293500    0.888973    3.350139    0.398248    0.047748    0.016621    0.848917    
#> 073: 0.352125    0.901645    3.370323    0.472054    0.056440    0.015790    0.812808    
#> 074: 0.341800    0.902199    3.358538    0.448451    0.062231    0.015000    0.808590    
#> 075: 0.357012    0.881065    3.383611    0.426029    0.059120    0.014250    0.823990    
#> 076: 0.434560    0.895560    3.393801    0.404727    0.056164    0.013538    0.816198    
#> 077: 0.413929    0.864067    3.381997    0.384491    0.053355    0.017770    0.793168    
#> 078: 0.410684    0.880512    3.381476    0.377066    0.050688    0.017748    0.793318    
#> 079: 0.385427    0.896112    3.366277    0.379726    0.063827    0.016861    0.796943    
#> 080: 0.379055    0.875470    3.378084    0.362160    0.060636    0.016018    0.813016    
#> 081: 0.341158    0.898452    3.373122    0.344052    0.057604    0.018706    0.789366    
#> 082: 0.349195    0.883722    3.374140    0.326849    0.055792    0.017770    0.817286    
#> 083: 0.372373    0.908216    3.365734    0.334286    0.053002    0.016882    0.804189    
#> 084: 0.335833    0.901749    3.353233    0.317572    0.053543    0.016038    0.814012    
#> 085: 0.314322    0.917065    3.362869    0.301693    0.050866    0.015236    0.820283    
#> 086: 0.333018    0.898302    3.363762    0.286608    0.048322    0.015507    0.806695    
#> 087: 0.331251    0.897038    3.349863    0.383534    0.045906    0.018995    0.807059    
#> 088: 0.268744    0.890124    3.349627    0.364358    0.043611    0.021539    0.820706    
#> 089: 0.287737    0.908671    3.330557    0.363035    0.041430    0.020462    0.829187    
#> 090: 0.314440    0.902832    3.349464    0.344883    0.039673    0.019439    0.813065    
#> 091: 0.327885    0.899083    3.325386    0.360996    0.054936    0.019019    0.802770    
#> 092: 0.280624    0.932480    3.321124    0.342947    0.052190    0.019224    0.827016    
#> 093: 0.225987    0.911055    3.326043    0.325799    0.049580    0.019771    0.836192    
#> 094: 0.241991    0.918220    3.326239    0.309509    0.048098    0.018782    0.823601    
#> 095: 0.264199    0.929684    3.341120    0.294034    0.055925    0.018950    0.825635    
#> 096: 0.219288    0.929974    3.326073    0.279332    0.053129    0.018655    0.826410    
#> 097: 0.265416    0.940035    3.327145    0.300294    0.053281    0.017722    0.839655    
#> 098: 0.243698    0.938596    3.339716    0.285279    0.050617    0.016836    0.857513    
#> 099: 0.266283    0.914998    3.318687    0.271015    0.048086    0.015995    0.844024    
#> 100: 0.260321    0.907695    3.326825    0.270149    0.047009    0.015195    0.815318    
#> 101: 0.230491    0.909200    3.311644    0.256641    0.047289    0.014435    0.813781    
#> 102: 0.240756    0.921781    3.308125    0.243809    0.044925    0.013713    0.839275    
#> 103: 0.279939    0.921252    3.331576    0.235905    0.044800    0.013028    0.819161    
#> 104: 0.300929    0.921581    3.344670    0.249348    0.050366    0.012376    0.835792    
#> 105: 0.289469    0.918740    3.348260    0.236880    0.051872    0.011757    0.831624    
#> 106: 0.315241    0.909442    3.352831    0.238606    0.052481    0.011170    0.811860    
#> 107: 0.377186    0.900335    3.363077    0.226675    0.049857    0.010611    0.840199    
#> 108: 0.340256    0.905339    3.351961    0.262481    0.047364    0.010081    0.863020    
#> 109: 0.284344    0.879102    3.359766    0.271243    0.050175    0.010070    0.849386    
#> 110: 0.271567    0.899770    3.340005    0.257681    0.051202    0.009681    0.834171    
#> 111: 0.292204    0.911041    3.348715    0.245843    0.055552    0.009197    0.824747    
#> 112: 0.287453    0.889119    3.327145    0.257106    0.055535    0.009705    0.831787    
#> 113: 0.289585    0.913642    3.338568    0.250723    0.067941    0.009219    0.811275    
#> 114: 0.286513    0.920873    3.341882    0.271111    0.075869    0.008758    0.816219    
#> 115: 0.322569    0.892955    3.346143    0.257556    0.072076    0.008320    0.875802    
#> 116: 0.316554    0.920291    3.352833    0.244678    0.068472    0.010501    0.865734    
#> 117: 0.285974    0.937485    3.345900    0.237800    0.065048    0.009976    0.861417    
#> 118: 0.319975    0.921542    3.337743    0.291398    0.061796    0.010026    0.827397    
#> 119: 0.326308    0.894045    3.350487    0.351103    0.065842    0.009525    0.838970    
#> 120: 0.301641    0.874101    3.355041    0.333548    0.062550    0.009049    0.858033    
#> 121: 0.335978    0.920996    3.348066    0.316870    0.059423    0.008596    0.860063    
#> 122: 0.320562    0.882792    3.358099    0.301027    0.061562    0.008166    0.839767    
#> 123: 0.350691    0.921116    3.353399    0.303349    0.058484    0.007758    0.854101    
#> 124: 0.351766    0.947771    3.346056    0.294980    0.055560    0.007370    0.818604    
#> 125: 0.333848    0.931358    3.339763    0.301431    0.059270    0.007002    0.818279    
#> 126: 0.313647    0.924211    3.333582    0.311725    0.056306    0.008991    0.826156    
#> 127: 0.282677    0.909327    3.325336    0.296139    0.056701    0.009613    0.853361    
#> 128: 0.249134    0.908400    3.337777    0.281332    0.072079    0.009167    0.835012    
#> 129: 0.300642    0.924665    3.338986    0.267266    0.086760    0.008708    0.829863    
#> 130: 0.328711    0.926782    3.346711    0.253902    0.083984    0.008273    0.832099    
#> 131: 0.303979    0.913354    3.346369    0.241207    0.084697    0.007859    0.842623    
#> 132: 0.261394    0.904500    3.329080    0.229147    0.080463    0.007466    0.872859    
#> 133: 0.250655    0.918007    3.327833    0.249628    0.076439    0.008021    0.862554    
#> 134: 0.280834    0.912545    3.335606    0.285274    0.072617    0.007620    0.850268    
#> 135: 0.234830    0.914357    3.320923    0.271011    0.091578    0.007239    0.878757    
#> 136: 0.249191    0.911895    3.326805    0.257460    0.086999    0.006877    0.831156    
#> 137: 0.283581    0.923298    3.328237    0.247702    0.082649    0.006533    0.855023    
#> 138: 0.267383    0.938309    3.324945    0.266185    0.078517    0.006206    0.841263    
#> 139: 0.286292    0.925272    3.328525    0.253284    0.074591    0.005896    0.835955    
#> 140: 0.231851    0.948759    3.321741    0.268166    0.084409    0.007119    0.859123    
#> 141: 0.253185    0.934678    3.337282    0.267858    0.087818    0.006763    0.843016    
#> 142: 0.302086    0.898083    3.343069    0.290347    0.083427    0.006425    0.850046    
#> 143: 0.273623    0.935102    3.346564    0.308023    0.079255    0.007424    0.820103    
#> 144: 0.338037    0.918748    3.358032    0.307007    0.075293    0.007052    0.806482    
#> 145: 0.292112    0.926705    3.350470    0.291657    0.071528    0.007535    0.805697    
#> 146: 0.313780    0.926538    3.353426    0.339490    0.067952    0.007158    0.827754    
#> 147: 0.300455    0.888286    3.347507    0.322516    0.064554    0.009655    0.812755    
#> 148: 0.291457    0.914304    3.357052    0.306390    0.061326    0.009615    0.818119    
#> 149: 0.331410    0.901621    3.355123    0.347690    0.058260    0.009254    0.818150    
#> 150: 0.355659    0.916888    3.351053    0.365173    0.057617    0.008792    0.831037    
#> 151: 0.342617    0.933334    3.347146    0.368292    0.063547    0.008352    0.841254    
#> 152: 0.300665    0.905497    3.341662    0.379300    0.063970    0.007486    0.827455    
#> 153: 0.293529    0.926354    3.340155    0.375096    0.049471    0.009975    0.848244    
#> 154: 0.332990    0.933672    3.353969    0.252544    0.053967    0.009665    0.857874    
#> 155: 0.287072    0.906379    3.344591    0.189349    0.051824    0.009980    0.835653    
#> 156: 0.305807    0.913062    3.353630    0.214836    0.063063    0.010974    0.823683    
#> 157: 0.308011    0.889920    3.357426    0.219010    0.065886    0.007513    0.843256    
#> 158: 0.327629    0.926440    3.349296    0.222275    0.056867    0.007081    0.844446    
#> 159: 0.295092    0.921177    3.352355    0.242436    0.065173    0.007693    0.841363    
#> 160: 0.320329    0.895436    3.354593    0.250477    0.073470    0.006991    0.822799    
#> 161: 0.294130    0.903236    3.354549    0.200632    0.085965    0.005692    0.829984    
#> 162: 0.296178    0.923992    3.338151    0.201057    0.063982    0.003997    0.842197    
#> 163: 0.298659    0.918280    3.336862    0.246427    0.076517    0.004516    0.847263    
#> 164: 0.305149    0.921691    3.335573    0.246894    0.074910    0.004442    0.838476    
#> 165: 0.297035    0.901444    3.349414    0.225717    0.075806    0.004937    0.829086    
#> 166: 0.318175    0.930282    3.349399    0.263529    0.073464    0.005873    0.820732    
#> 167: 0.329932    0.926126    3.352379    0.288043    0.078426    0.005260    0.848521    
#> 168: 0.335284    0.940518    3.357292    0.302788    0.069657    0.005362    0.866082    
#> 169: 0.321033    0.954798    3.345041    0.259043    0.067303    0.005861    0.864819    
#> 170: 0.321146    0.914201    3.355184    0.305893    0.069735    0.005485    0.842966    
#> 171: 0.313577    0.905925    3.353365    0.279689    0.060100    0.005848    0.821514    
#> 172: 0.300203    0.929321    3.349717    0.306753    0.063794    0.005244    0.830342    
#> 173: 0.290551    0.938903    3.339845    0.327595    0.058661    0.006529    0.822906    
#> 174: 0.312599    0.924112    3.343271    0.303908    0.051638    0.009328    0.833081    
#> 175: 0.291962    0.936198    3.327077    0.348551    0.056355    0.008604    0.836546    
#> 176: 0.269879    0.955007    3.336127    0.270195    0.057025    0.010566    0.818190    
#> 177: 0.295882    0.935573    3.339628    0.230540    0.051770    0.007623    0.845231    
#> 178: 0.292188    0.919942    3.338626    0.220039    0.059942    0.005298    0.836024    
#> 179: 0.320869    0.945711    3.343158    0.231887    0.059217    0.006091    0.835451    
#> 180: 0.289754    0.935993    3.342267    0.299088    0.060297    0.004610    0.827975    
#> 181: 0.293421    0.900331    3.327167    0.322924    0.053252    0.006252    0.815039    
#> 182: 0.232711    0.934752    3.311663    0.310010    0.065982    0.007485    0.843003    
#> 183: 0.256586    0.940664    3.317425    0.255146    0.048065    0.010885    0.813478    
#> 184: 0.226415    0.907591    3.326208    0.223543    0.047815    0.010855    0.831752    
#> 185: 0.252756    0.942343    3.328707    0.264211    0.067662    0.009958    0.823521    
#> 186: 0.277125    0.952287    3.338402    0.242925    0.056313    0.012757    0.819692    
#> 187: 0.300021    0.906523    3.351612    0.252104    0.044340    0.008895    0.837687    
#> 188: 0.299634    0.932472    3.347646    0.249273    0.038775    0.010943    0.863428    
#> 189: 0.321047    0.935499    3.348347    0.240913    0.035365    0.009211    0.863621    
#> 190: 0.282620    0.925848    3.355877    0.226753    0.033497    0.009782    0.845656    
#> 191: 0.266798    0.931898    3.330798    0.274096    0.036397    0.006982    0.843949    
#> 192: 0.260575    0.917876    3.337723    0.253385    0.029882    0.006613    0.852618    
#> 193: 0.298413    0.930786    3.341349    0.221024    0.033108    0.005218    0.840008    
#> 194: 0.239455    0.922422    3.324231    0.224617    0.032784    0.006149    0.861506    
#> 195: 0.229096    0.922881    3.319257    0.188401    0.032527    0.007863    0.883436    
#> 196: 0.213423    0.914465    3.325974    0.194926    0.042928    0.007549    0.873897    
#> 197: 0.211970    0.935136    3.340588    0.224426    0.047257    0.007169    0.860715    
#> 198: 0.309807    0.918539    3.335647    0.245332    0.051802    0.010671    0.818810    
#> 199: 0.247574    0.907753    3.336585    0.306584    0.048752    0.010040    0.813824    
#> 200: 0.279503    0.909750    3.338913    0.316280    0.050744    0.011539    0.816912    
#> 201: 0.282347    0.903110    3.344568    0.339366    0.052934    0.011791    0.815200    
#> 202: 0.287922    0.905526    3.344733    0.340949    0.052563    0.011431    0.819746    
#> 203: 0.307880    0.904095    3.345704    0.334855    0.051946    0.011483    0.820680    
#> 204: 0.310891    0.899896    3.347731    0.319812    0.053194    0.011719    0.824906    
#> 205: 0.312129    0.905729    3.348262    0.315306    0.052606    0.011786    0.827800    
#> 206: 0.314070    0.907996    3.349914    0.320842    0.052590    0.011855    0.828586    
#> 207: 0.308473    0.910741    3.347697    0.315278    0.052750    0.012143    0.827206    
#> 208: 0.306521    0.913087    3.346891    0.310335    0.053277    0.012080    0.825518    
#> 209: 0.310770    0.911917    3.346598    0.307273    0.053317    0.012074    0.825312    
#> 210: 0.311446    0.912357    3.346534    0.302511    0.053560    0.011860    0.824674    
#> 211: 0.313895    0.914262    3.347806    0.298922    0.053603    0.011729    0.825175    
#> 212: 0.317347    0.913887    3.348714    0.295632    0.052771    0.011522    0.826578    
#> 213: 0.319400    0.910212    3.349299    0.290023    0.052741    0.011427    0.829427    
#> 214: 0.321184    0.908994    3.349570    0.286146    0.052316    0.011450    0.831903    
#> 215: 0.319473    0.909035    3.349355    0.282939    0.052138    0.011391    0.833505    
#> 216: 0.318884    0.908570    3.349238    0.278889    0.052109    0.011407    0.837055    
#> 217: 0.316597    0.909665    3.348673    0.277754    0.051919    0.011463    0.837504    
#> 218: 0.315538    0.910957    3.347989    0.278341    0.051965    0.011509    0.837000    
#> 219: 0.313645    0.911528    3.346687    0.278001    0.052504    0.011416    0.836661    
#> 220: 0.311728    0.911952    3.346025    0.281198    0.052622    0.011428    0.836778    
#> 221: 0.308300    0.912350    3.345456    0.282384    0.052849    0.011317    0.835990    
#> 222: 0.307437    0.912576    3.345169    0.281971    0.052933    0.011164    0.836249    
#> 223: 0.308132    0.912990    3.345013    0.281652    0.053096    0.011069    0.835113    
#> 224: 0.309529    0.913594    3.345150    0.281498    0.052993    0.010977    0.834807    
#> 225: 0.310420    0.911750    3.345642    0.281335    0.053323    0.010882    0.834416    
#> 226: 0.311051    0.909971    3.345622    0.279757    0.053415    0.010766    0.834840    
#> 227: 0.310513    0.909266    3.345744    0.277643    0.053323    0.010707    0.834431    
#> 228: 0.309152    0.909805    3.345073    0.276727    0.053265    0.010691    0.834761    
#> 229: 0.307309    0.909814    3.344768    0.275147    0.053125    0.010626    0.834275    
#> 230: 0.306862    0.909953    3.344604    0.274539    0.053000    0.010527    0.834319    
#> 231: 0.307558    0.910742    3.344955    0.276152    0.053097    0.010516    0.833995    
#> 232: 0.306767    0.910689    3.345348    0.276291    0.053369    0.010540    0.834118    
#> 233: 0.306102    0.909521    3.345577    0.275921    0.053762    0.010448    0.833922    
#> 234: 0.305656    0.909283    3.345760    0.275374    0.053950    0.010412    0.833811    
#> 235: 0.305931    0.909106    3.345679    0.275261    0.053776    0.010423    0.833178    
#> 236: 0.306529    0.909512    3.345581    0.276707    0.053835    0.010401    0.833254    
#> 237: 0.306220    0.909560    3.345395    0.275985    0.053686    0.010379    0.833494    
#> 238: 0.306808    0.909608    3.345608    0.274483    0.053647    0.010340    0.834527    
#> 239: 0.306667    0.910053    3.345493    0.274702    0.053622    0.010305    0.834526    
#> 240: 0.306893    0.909918    3.345611    0.275764    0.053589    0.010242    0.834269    
#> 241: 0.307452    0.909142    3.345971    0.275821    0.053606    0.010218    0.834082    
#> 242: 0.307474    0.908560    3.345866    0.276185    0.053635    0.010206    0.834970    
#> 243: 0.306074    0.908561    3.345929    0.275421    0.053415    0.010221    0.835820    
#> 244: 0.305324    0.907843    3.346274    0.274867    0.053003    0.010325    0.836011    
#> 245: 0.305779    0.906965    3.346607    0.275372    0.052679    0.010383    0.836337    
#> 246: 0.306081    0.906323    3.347048    0.274978    0.052323    0.010478    0.836353    
#> 247: 0.306473    0.905880    3.347647    0.275690    0.052205    0.010503    0.835998    
#> 248: 0.307100    0.905991    3.347912    0.276031    0.052205    0.010509    0.835469    
#> 249: 0.307456    0.906039    3.348045    0.275322    0.052233    0.010573    0.835207    
#> 250: 0.308287    0.906195    3.348444    0.274944    0.051953    0.010708    0.834827    
#> 251: 0.308241    0.906271    3.348710    0.273822    0.051900    0.010766    0.834892    
#> 252: 0.308569    0.906295    3.349026    0.272538    0.051835    0.010806    0.834761    
#> 253: 0.308401    0.906246    3.349208    0.272035    0.051597    0.010875    0.834543    
#> 254: 0.308061    0.906534    3.349468    0.271395    0.051380    0.010926    0.834252    
#> 255: 0.308545    0.906581    3.349716    0.271530    0.051146    0.010986    0.834183    
#> 256: 0.309142    0.906366    3.349945    0.271300    0.051032    0.010986    0.834083    
#> 257: 0.309088    0.905986    3.350018    0.270856    0.051011    0.010988    0.834265    
#> 258: 0.309705    0.905314    3.350234    0.271730    0.051006    0.010958    0.833908    
#> 259: 0.309964    0.905004    3.350420    0.272143    0.050924    0.010967    0.833766    
#> 260: 0.310266    0.905254    3.350790    0.271910    0.050884    0.010977    0.833479    
#> 261: 0.310873    0.905069    3.351086    0.272477    0.050804    0.010983    0.833229    
#> 262: 0.311581    0.905297    3.351284    0.273659    0.050609    0.010991    0.833222    
#> 263: 0.311054    0.905524    3.351469    0.273229    0.050642    0.011024    0.833177    
#> 264: 0.310703    0.905634    3.351431    0.272466    0.050549    0.011063    0.833365    
#> 265: 0.310561    0.905266    3.351576    0.272351    0.050358    0.011140    0.833670    
#> 266: 0.310897    0.905238    3.351655    0.272086    0.050169    0.011169    0.834098    
#> 267: 0.311301    0.904907    3.351860    0.271105    0.050018    0.011198    0.834453    
#> 268: 0.311325    0.904611    3.351768    0.271176    0.049973    0.011190    0.834293    
#> 269: 0.312009    0.904378    3.351786    0.271396    0.050043    0.011156    0.834136    
#> 270: 0.312626    0.904532    3.351733    0.271518    0.050005    0.011143    0.833915    
#> 271: 0.312313    0.904706    3.351519    0.272230    0.049862    0.011197    0.834315    
#> 272: 0.311853    0.904795    3.351386    0.271552    0.049803    0.011253    0.834684    
#> 273: 0.311481    0.905224    3.351305    0.271883    0.049656    0.011274    0.834943    
#> 274: 0.311376    0.905566    3.351332    0.272139    0.049714    0.011312    0.834869    
#> 275: 0.311343    0.905772    3.351361    0.271860    0.049651    0.011326    0.834852    
#> 276: 0.311057    0.905952    3.351448    0.272918    0.049553    0.011337    0.834937    
#> 277: 0.311026    0.906166    3.351490    0.272646    0.049519    0.011332    0.834670    
#> 278: 0.310822    0.906257    3.351510    0.272551    0.049644    0.011289    0.834760    
#> 279: 0.310145    0.906154    3.351507    0.272581    0.049721    0.011259    0.834980    
#> 280: 0.310143    0.906073    3.351546    0.272743    0.049670    0.011229    0.835121    
#> 281: 0.309936    0.906026    3.351539    0.272823    0.049583    0.011204    0.834947    
#> 282: 0.310214    0.906330    3.351543    0.273026    0.049595    0.011190    0.834966    
#> 283: 0.310482    0.906394    3.351682    0.272478    0.049708    0.011181    0.835496    
#> 284: 0.310346    0.906154    3.351819    0.271491    0.049700    0.011185    0.835524    
#> 285: 0.310396    0.906178    3.351731    0.270769    0.049660    0.011188    0.835651    
#> 286: 0.310096    0.906331    3.351660    0.270430    0.049573    0.011222    0.835635    
#> 287: 0.310296    0.906536    3.351574    0.269991    0.049487    0.011236    0.835845    
#> 288: 0.310680    0.906480    3.351647    0.269862    0.049442    0.011258    0.836135    
#> 289: 0.311459    0.906326    3.351808    0.270192    0.049405    0.011271    0.836419    
#> 290: 0.311674    0.906213    3.351926    0.269961    0.049413    0.011323    0.836652    
#> 291: 0.312105    0.906336    3.352125    0.269780    0.049351    0.011379    0.836554    
#> 292: 0.312014    0.906655    3.352152    0.269506    0.049337    0.011400    0.836403    
#> 293: 0.312210    0.906861    3.352136    0.269553    0.049297    0.011425    0.836058    
#> 294: 0.312090    0.907254    3.352105    0.268869    0.049183    0.011416    0.835995    
#> 295: 0.312062    0.907173    3.352079    0.268680    0.049151    0.011446    0.835760    
#> 296: 0.312065    0.907057    3.352120    0.268694    0.049041    0.011531    0.835702    
#> 297: 0.312310    0.907123    3.352098    0.268684    0.049011    0.011580    0.835693    
#> 298: 0.312049    0.907010    3.352042    0.268405    0.049022    0.011602    0.835522    
#> 299: 0.312197    0.907132    3.352042    0.268032    0.048970    0.011576    0.835380    
#> 300: 0.312341    0.907096    3.352182    0.267602    0.048869    0.011586    0.835311    
#> 301: 0.312534    0.906875    3.352226    0.268321    0.048823    0.011578    0.835400    
#> 302: 0.312759    0.906672    3.352380    0.268693    0.048690    0.011584    0.835130    
#> 303: 0.312782    0.906711    3.352382    0.268385    0.048578    0.011594    0.834956    
#> 304: 0.312858    0.906808    3.352350    0.268263    0.048538    0.011599    0.834754    
#> 305: 0.312702    0.906641    3.352342    0.268112    0.048521    0.011606    0.834570    
#> 306: 0.312106    0.906598    3.352171    0.267843    0.048447    0.011634    0.834570    
#> 307: 0.311995    0.906407    3.352082    0.267628    0.048287    0.011663    0.834834    
#> 308: 0.311730    0.906163    3.352101    0.267523    0.048230    0.011681    0.835077    
#> 309: 0.311703    0.905808    3.352088    0.267543    0.048112    0.011703    0.835310    
#> 310: 0.311772    0.905652    3.351960    0.267713    0.048120    0.011715    0.835348    
#> 311: 0.311878    0.905709    3.351895    0.268140    0.048155    0.011762    0.835224    
#> 312: 0.311569    0.905750    3.351794    0.268119    0.048056    0.011790    0.835105    
#> 313: 0.311430    0.905604    3.351662    0.268400    0.048013    0.011779    0.835301    
#> 314: 0.311040    0.905621    3.351527    0.268919    0.047943    0.011774    0.835296    
#> 315: 0.310786    0.905667    3.351506    0.269724    0.047838    0.011780    0.835405    
#> 316: 0.310588    0.905710    3.351454    0.269766    0.047775    0.011787    0.835421    
#> 317: 0.310656    0.905678    3.351393    0.270240    0.047782    0.011785    0.835294    
#> 318: 0.310804    0.905735    3.351324    0.270340    0.047668    0.011802    0.835235    
#> 319: 0.310943    0.905714    3.351332    0.270446    0.047579    0.011825    0.835194    
#> 320: 0.310528    0.905648    3.351262    0.270273    0.047548    0.011839    0.835278    
#> 321: 0.310576    0.905698    3.351233    0.269885    0.047650    0.011859    0.835374    
#> 322: 0.310389    0.905614    3.351182    0.269598    0.047668    0.011844    0.835336    
#> 323: 0.309811    0.905613    3.351139    0.269253    0.047569    0.011834    0.835412    
#> 324: 0.309518    0.905876    3.351082    0.269035    0.047570    0.011805    0.835322    
#> 325: 0.309097    0.906203    3.350936    0.268888    0.047622    0.011790    0.835181    
#> 326: 0.308841    0.906217    3.350799    0.268816    0.047711    0.011746    0.835248    
#> 327: 0.308790    0.906176    3.350797    0.268438    0.047802    0.011707    0.835486    
#> 328: 0.308904    0.906358    3.350701    0.268188    0.047860    0.011671    0.835627    
#> 329: 0.309328    0.906435    3.350737    0.267946    0.047880    0.011653    0.835696    
#> 330: 0.308967    0.906421    3.350666    0.267752    0.047876    0.011664    0.835954    
#> 331: 0.309186    0.906620    3.350629    0.267662    0.047926    0.011656    0.835882    
#> 332: 0.309351    0.906542    3.350722    0.267657    0.047962    0.011678    0.835742    
#> 333: 0.309442    0.906538    3.350648    0.267472    0.047989    0.011665    0.835712    
#> 334: 0.309140    0.906517    3.350482    0.267236    0.048082    0.011637    0.835638    
#> 335: 0.308780    0.906627    3.350357    0.266812    0.048150    0.011624    0.835618    
#> 336: 0.308230    0.906804    3.350292    0.266703    0.048136    0.011638    0.835829    
#> 337: 0.308032    0.907044    3.350252    0.266038    0.048081    0.011643    0.836066    
#> 338: 0.307918    0.907201    3.350242    0.265707    0.048051    0.011618    0.836117    
#> 339: 0.307786    0.907327    3.350214    0.265369    0.048064    0.011590    0.836188    
#> 340: 0.307877    0.907331    3.350288    0.265078    0.048118    0.011561    0.836232    
#> 341: 0.308065    0.907452    3.350339    0.264812    0.048227    0.011527    0.836186    
#> 342: 0.307780    0.907385    3.350305    0.264237    0.048189    0.011513    0.836122    
#> 343: 0.307665    0.907480    3.350356    0.264358    0.048127    0.011519    0.836139    
#> 344: 0.307609    0.907475    3.350378    0.264494    0.048188    0.011537    0.836021    
#> 345: 0.307637    0.907508    3.350412    0.264331    0.048287    0.011562    0.835895    
#> 346: 0.307643    0.907683    3.350369    0.264010    0.048318    0.011553    0.835800    
#> 347: 0.307674    0.907517    3.350308    0.263834    0.048360    0.011561    0.835843    
#> 348: 0.307557    0.907604    3.350288    0.263754    0.048367    0.011556    0.835865    
#> 349: 0.307516    0.907582    3.350310    0.263451    0.048414    0.011558    0.835780    
#> 350: 0.307331    0.907427    3.350261    0.263694    0.048466    0.011558    0.835722    
#> 351: 0.307258    0.907449    3.350210    0.263935    0.048414    0.011557    0.835808    
#> 352: 0.306752    0.907567    3.350181    0.263805    0.048428    0.011557    0.836050    
#> 353: 0.306716    0.907778    3.350149    0.263650    0.048436    0.011560    0.835980    
#> 354: 0.306804    0.907836    3.350057    0.263508    0.048457    0.011543    0.835972    
#> 355: 0.307028    0.907723    3.350027    0.263607    0.048517    0.011519    0.835889    
#> 356: 0.307266    0.907644    3.350074    0.263826    0.048532    0.011521    0.835916    
#> 357: 0.307586    0.907681    3.350120    0.264115    0.048529    0.011522    0.835901    
#> 358: 0.307557    0.907725    3.350150    0.263995    0.048538    0.011510    0.835722    
#> 359: 0.307489    0.907818    3.350120    0.263704    0.048480    0.011511    0.835693    
#> 360: 0.307502    0.907816    3.350036    0.263656    0.048420    0.011517    0.835648    
#> 361: 0.307598    0.908064    3.349950    0.263619    0.048399    0.011515    0.835616    
#> 362: 0.307659    0.908119    3.349915    0.263846    0.048412    0.011510    0.835485    
#> 363: 0.307601    0.908019    3.349892    0.263744    0.048424    0.011489    0.835363    
#> 364: 0.307638    0.908129    3.349863    0.263907    0.048413    0.011486    0.835194    
#> 365: 0.307665    0.908070    3.349917    0.264239    0.048347    0.011501    0.835159    
#> 366: 0.307581    0.907977    3.349866    0.264218    0.048236    0.011520    0.835153    
#> 367: 0.307776    0.907829    3.349970    0.264137    0.048138    0.011545    0.835125    
#> 368: 0.308055    0.907896    3.350034    0.264119    0.048100    0.011563    0.835021    
#> 369: 0.308105    0.907889    3.350097    0.264083    0.048098    0.011550    0.835130    
#> 370: 0.308101    0.907929    3.350136    0.264333    0.048155    0.011550    0.835093    
#> 371: 0.307990    0.907936    3.350059    0.264202    0.048131    0.011522    0.835237    
#> 372: 0.307965    0.907966    3.350056    0.264148    0.048149    0.011530    0.835326    
#> 373: 0.307902    0.908078    3.350011    0.263947    0.048146    0.011525    0.835358    
#> 374: 0.307948    0.908090    3.349997    0.264175    0.048097    0.011527    0.835228    
#> 375: 0.307815    0.908216    3.349986    0.263955    0.048073    0.011539    0.835207    
#> 376: 0.307635    0.908195    3.349978    0.263786    0.047992    0.011545    0.835240    
#> 377: 0.307654    0.908223    3.350000    0.263653    0.047976    0.011574    0.835230    
#> 378: 0.307419    0.908254    3.349896    0.263597    0.047938    0.011586    0.835305    
#> 379: 0.307199    0.908248    3.349852    0.263291    0.047929    0.011578    0.835399    
#> 380: 0.306916    0.908270    3.349786    0.263017    0.047938    0.011566    0.835471    
#> 381: 0.306768    0.908208    3.349773    0.262871    0.047906    0.011557    0.835470    
#> 382: 0.306736    0.908146    3.349799    0.262710    0.047905    0.011537    0.835372    
#> 383: 0.306869    0.908043    3.349829    0.262792    0.047917    0.011534    0.835299    
#> 384: 0.306739    0.907997    3.349873    0.263067    0.047937    0.011528    0.835279    
#> 385: 0.306638    0.908000    3.349871    0.262847    0.047987    0.011520    0.835299    
#> 386: 0.306563    0.908101    3.349890    0.262886    0.048009    0.011520    0.835250    
#> 387: 0.306619    0.908170    3.349956    0.262797    0.048008    0.011535    0.835190    
#> 388: 0.306693    0.908248    3.349979    0.262777    0.048010    0.011554    0.835140    
#> 389: 0.306769    0.908107    3.349976    0.262831    0.047991    0.011576    0.835169    
#> 390: 0.306645    0.908083    3.349913    0.262501    0.047909    0.011598    0.835258    
#> 391: 0.306653    0.908018    3.349896    0.262291    0.047830    0.011616    0.835326    
#> 392: 0.306564    0.908058    3.349933    0.262238    0.047798    0.011636    0.835405    
#> 393: 0.306391    0.908036    3.349875    0.262217    0.047816    0.011651    0.835420    
#> 394: 0.306419    0.908033    3.349811    0.262394    0.047786    0.011660    0.835384    
#> 395: 0.306715    0.908147    3.349832    0.262600    0.047809    0.011677    0.835301    
#> 396: 0.306843    0.908268    3.349854    0.262628    0.047813    0.011686    0.835273    
#> 397: 0.306898    0.908259    3.349910    0.262765    0.047791    0.011704    0.835219    
#> 398: 0.306980    0.908181    3.349951    0.262724    0.047778    0.011738    0.835269    
#> 399: 0.307089    0.908220    3.350002    0.262941    0.047800    0.011745    0.835201    
#> 400: 0.307232    0.908230    3.350025    0.263051    0.047746    0.011750    0.835167    
#> 401: 0.307387    0.908212    3.350069    0.263070    0.047748    0.011781    0.835167    
#> 402: 0.307476    0.908340    3.350064    0.263090    0.047742    0.011811    0.835094    
#> 403: 0.307626    0.908380    3.350023    0.263550    0.047731    0.011830    0.835005    
#> 404: 0.307715    0.908424    3.349953    0.263866    0.047762    0.011821    0.834820    
#> 405: 0.307548    0.908499    3.349910    0.263636    0.047843    0.011812    0.834907    
#> 406: 0.307497    0.908464    3.349872    0.263810    0.047920    0.011804    0.834905    
#> 407: 0.307531    0.908494    3.349891    0.263807    0.047981    0.011796    0.834781    
#> 408: 0.307697    0.908511    3.349925    0.264163    0.047953    0.011791    0.834828    
#> 409: 0.307816    0.908470    3.349901    0.264212    0.047982    0.011770    0.834775    
#> 410: 0.307790    0.908506    3.349806    0.264393    0.048000    0.011761    0.834751    
#> 411: 0.307863    0.908353    3.349740    0.264775    0.047936    0.011757    0.834792    
#> 412: 0.307960    0.908356    3.349708    0.265120    0.047946    0.011749    0.834775    
#> 413: 0.308004    0.908397    3.349640    0.265683    0.047951    0.011741    0.834770    
#> 414: 0.307799    0.908467    3.349618    0.266060    0.047943    0.011731    0.834659    
#> 415: 0.307753    0.908549    3.349590    0.265983    0.047895    0.011713    0.834671    
#> 416: 0.307769    0.908626    3.349602    0.265788    0.047908    0.011702    0.834575    
#> 417: 0.307894    0.908537    3.349648    0.265470    0.047972    0.011700    0.834655    
#> 418: 0.307928    0.908501    3.349680    0.265220    0.047960    0.011689    0.834694    
#> 419: 0.307937    0.908528    3.349746    0.264713    0.047968    0.011688    0.834758    
#> 420: 0.307995    0.908521    3.349803    0.264449    0.047945    0.011673    0.834752    
#> 421: 0.308050    0.908486    3.349881    0.264234    0.047931    0.011676    0.834696    
#> 422: 0.308311    0.908426    3.349897    0.264312    0.047954    0.011669    0.834725    
#> 423: 0.308691    0.908361    3.349979    0.264347    0.047997    0.011664    0.834723    
#> 424: 0.308770    0.908330    3.350005    0.264265    0.048001    0.011662    0.834713    
#> 425: 0.308770    0.908416    3.349994    0.264021    0.047978    0.011656    0.834782    
#> 426: 0.308675    0.908575    3.349962    0.263815    0.047950    0.011657    0.834775    
#> 427: 0.308536    0.908580    3.349960    0.263831    0.047908    0.011652    0.834765    
#> 428: 0.308455    0.908617    3.349948    0.263939    0.047941    0.011645    0.834731    
#> 429: 0.308502    0.908664    3.349971    0.264004    0.047968    0.011640    0.834697    
#> 430: 0.308451    0.908711    3.349946    0.263984    0.048023    0.011637    0.834671    
#> 431: 0.308417    0.908728    3.349874    0.264030    0.048035    0.011644    0.834544    
#> 432: 0.308189    0.908854    3.349832    0.264081    0.048038    0.011666    0.834459    
#> 433: 0.308143    0.908999    3.349844    0.264001    0.048053    0.011679    0.834398    
#> 434: 0.308167    0.908984    3.349841    0.263929    0.048044    0.011678    0.834284    
#> 435: 0.308272    0.908996    3.349840    0.263956    0.047984    0.011684    0.834264    
#> 436: 0.308313    0.908933    3.349899    0.263911    0.047967    0.011680    0.834314    
#> 437: 0.308452    0.908912    3.349943    0.263826    0.047968    0.011678    0.834325    
#> 438: 0.308479    0.909026    3.349939    0.263774    0.047921    0.011669    0.834389    
#> 439: 0.308571    0.909101    3.349960    0.263798    0.047898    0.011658    0.834358    
#> 440: 0.308528    0.909100    3.349991    0.263784    0.047852    0.011657    0.834377    
#> 441: 0.308552    0.909007    3.349997    0.263795    0.047848    0.011658    0.834345    
#> 442: 0.308498    0.909016    3.350011    0.263869    0.047874    0.011656    0.834209    
#> 443: 0.308412    0.909144    3.349972    0.263853    0.047878    0.011660    0.834105    
#> 444: 0.308288    0.909252    3.349896    0.263726    0.047893    0.011655    0.834031    
#> 445: 0.308046    0.909312    3.349800    0.263507    0.047881    0.011648    0.834057    
#> 446: 0.307793    0.909421    3.349693    0.263342    0.047915    0.011654    0.834025    
#> 447: 0.307795    0.909543    3.349672    0.263240    0.047907    0.011664    0.834023    
#> 448: 0.307779    0.909604    3.349698    0.263358    0.047922    0.011671    0.833917    
#> 449: 0.307825    0.909661    3.349776    0.263355    0.047972    0.011684    0.833933    
#> 450: 0.307824    0.909690    3.349765    0.263645    0.047969    0.011698    0.833929    
#> 451: 0.307945    0.909791    3.349744    0.263679    0.047971    0.011701    0.833987    
#> 452: 0.307925    0.909883    3.349642    0.263945    0.047990    0.011704    0.833917    
#> 453: 0.307875    0.909904    3.349615    0.264095    0.047995    0.011708    0.833880    
#> 454: 0.307747    0.909917    3.349581    0.264043    0.048005    0.011706    0.833842    
#> 455: 0.307711    0.909895    3.349569    0.264056    0.048020    0.011698    0.833891    
#> 456: 0.307604    0.909824    3.349551    0.263849    0.048010    0.011698    0.833932    
#> 457: 0.307494    0.909737    3.349587    0.263728    0.047941    0.011690    0.833934    
#> 458: 0.307369    0.909793    3.349637    0.263514    0.047903    0.011682    0.834031    
#> 459: 0.307217    0.909874    3.349630    0.263441    0.047937    0.011681    0.833971    
#> 460: 0.307106    0.909870    3.349587    0.263351    0.047960    0.011678    0.833966    
#> 461: 0.307029    0.909869    3.349594    0.263334    0.047960    0.011664    0.833974    
#> 462: 0.306937    0.909881    3.349625    0.263338    0.048018    0.011663    0.833969    
#> 463: 0.306944    0.909970    3.349613    0.263334    0.048033    0.011659    0.833955    
#> 464: 0.306991    0.909939    3.349597    0.263251    0.048049    0.011652    0.833891    
#> 465: 0.306982    0.909733    3.349588    0.263188    0.048076    0.011649    0.833882    
#> 466: 0.306900    0.909709    3.349547    0.263165    0.048096    0.011645    0.833834    
#> 467: 0.306790    0.909665    3.349519    0.263273    0.048095    0.011634    0.833766    
#> 468: 0.306830    0.909617    3.349523    0.263166    0.048116    0.011622    0.833867    
#> 469: 0.306868    0.909701    3.349547    0.263171    0.048132    0.011616    0.833935    
#> 470: 0.306849    0.909746    3.349529    0.263307    0.048154    0.011614    0.833910    
#> 471: 0.306699    0.909781    3.349485    0.263469    0.048162    0.011613    0.833897    
#> 472: 0.306511    0.909849    3.349449    0.263465    0.048162    0.011608    0.833940    
#> 473: 0.306352    0.909870    3.349412    0.263550    0.048183    0.011595    0.833938    
#> 474: 0.306333    0.909893    3.349381    0.263595    0.048215    0.011581    0.834023    
#> 475: 0.306295    0.910047    3.349309    0.263717    0.048179    0.011579    0.834025    
#> 476: 0.306146    0.910058    3.349279    0.263639    0.048206    0.011581    0.834076    
#> 477: 0.306131    0.910082    3.349318    0.263530    0.048213    0.011579    0.834031    
#> 478: 0.306051    0.910034    3.349326    0.263686    0.048200    0.011577    0.834011    
#> 479: 0.306218    0.910014    3.349377    0.263922    0.048236    0.011580    0.833934    
#> 480: 0.306339    0.910011    3.349397    0.264012    0.048208    0.011583    0.834023    
#> 481: 0.306428    0.909976    3.349445    0.264233    0.048211    0.011587    0.834083    
#> 482: 0.306529    0.909987    3.349424    0.264378    0.048215    0.011591    0.834107    
#> 483: 0.306426    0.909930    3.349394    0.264364    0.048185    0.011584    0.834204    
#> 484: 0.306242    0.909857    3.349367    0.264269    0.048201    0.011574    0.834325    
#> 485: 0.306328    0.909867    3.349372    0.264234    0.048232    0.011560    0.834383    
#> 486: 0.306388    0.909876    3.349386    0.264309    0.048208    0.011556    0.834338    
#> 487: 0.306622    0.909842    3.349447    0.264509    0.048181    0.011564    0.834312    
#> 488: 0.306713    0.909818    3.349485    0.264722    0.048180    0.011568    0.834235    
#> 489: 0.306901    0.909770    3.349509    0.264604    0.048168    0.011568    0.834240    
#> 490: 0.307073    0.909759    3.349553    0.264399    0.048138    0.011564    0.834286    
#> 491: 0.307109    0.909785    3.349579    0.264390    0.048133    0.011574    0.834204    
#> 492: 0.307142    0.909800    3.349592    0.264467    0.048141    0.011582    0.834201    
#> 493: 0.307119    0.909784    3.349598    0.264532    0.048145    0.011593    0.834198    
#> 494: 0.307236    0.909816    3.349593    0.264692    0.048131    0.011601    0.834119    
#> 495: 0.307389    0.909851    3.349606    0.264742    0.048102    0.011606    0.834101    
#> 496: 0.307597    0.909879    3.349584    0.264933    0.048080    0.011612    0.834079    
#> 497: 0.307581    0.909824    3.349576    0.264893    0.048088    0.011622    0.834085    
#> 498: 0.307710    0.909797    3.349562    0.264912    0.048087    0.011618    0.834087    
#> 499: 0.307786    0.909818    3.349549    0.264746    0.048102    0.011610    0.834082    
#> 500: 0.307820    0.909764    3.349529    0.264782    0.048072    0.011606    0.834023    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.316923    0.976509    3.440948    0.392401    0.089218    0.016800    1.837974    
#> 002: 0.388323    0.988066    3.460569    0.372781    0.084757    0.017992    1.240745    
#> 003: 0.521669    0.943854    3.474344    0.354142    0.080519    0.017092    1.009652    
#> 004: 0.466895    0.973620    3.473643    0.336435    0.076493    0.016237    0.909299    
#> 005: 0.452401    0.982101    3.463061    0.319613    0.084678    0.015425    0.845496    
#> 006: 0.448770    0.973294    3.448757    0.303633    0.087897    0.014654    0.801911    
#> 007: 0.381453    0.985798    3.435361    0.288451    0.083502    0.014629    0.789700    
#> 008: 0.399359    0.989720    3.422184    0.274029    0.099345    0.014756    0.774832    
#> 009: 0.344425    0.990481    3.411115    0.260327    0.096938    0.014411    0.778325    
#> 010: 0.350080    0.983008    3.421196    0.247311    0.092511    0.014632    0.803608    
#> 011: 0.439602    0.993297    3.426388    0.250410    0.088874    0.017563    0.805496    
#> 012: 0.410456    1.001946    3.415872    0.237889    0.094478    0.016684    0.808819    
#> 013: 0.325691    1.015105    3.398941    0.225995    0.089754    0.015850    0.825508    
#> 014: 0.378470    1.009097    3.410873    0.233567    0.085266    0.015058    0.820000    
#> 015: 0.385733    1.014071    3.427605    0.221889    0.081003    0.015286    0.809983    
#> 016: 0.379237    1.039340    3.426633    0.210795    0.076953    0.019254    0.812440    
#> 017: 0.403046    1.037860    3.434991    0.214722    0.076779    0.019429    0.783459    
#> 018: 0.386569    1.028830    3.411267    0.233354    0.072940    0.019428    0.784243    
#> 019: 0.336247    1.022042    3.410083    0.221686    0.069293    0.018456    0.770867    
#> 020: 0.364477    1.035639    3.422440    0.210602    0.074390    0.019293    0.792716    
#> 021: 0.397208    1.019827    3.435982    0.213164    0.070670    0.018473    0.779568    
#> 022: 0.392186    1.033782    3.429851    0.232427    0.072643    0.021006    0.768505    
#> 023: 0.459244    1.024273    3.444933    0.220805    0.084031    0.020949    0.794646    
#> 024: 0.460161    1.025505    3.443406    0.209765    0.079829    0.020418    0.803198    
#> 025: 0.450812    0.987805    3.445931    0.199277    0.081342    0.019397    0.789024    
#> 026: 0.396243    1.013412    3.427139    0.189313    0.077275    0.018457    0.778729    
#> 027: 0.398552    1.030901    3.422646    0.179847    0.073411    0.018988    0.789737    
#> 028: 0.430473    1.012788    3.434679    0.186082    0.069741    0.019871    0.776001    
#> 029: 0.427123    1.008841    3.422394    0.219763    0.069008    0.018877    0.794767    
#> 030: 0.429758    1.027003    3.429538    0.208775    0.071301    0.017934    0.774889    
#> 031: 0.428829    1.007195    3.438810    0.214115    0.070964    0.017037    0.797925    
#> 032: 0.371347    0.986601    3.440526    0.238463    0.078288    0.016185    0.785025    
#> 033: 0.399178    1.019082    3.425496    0.240940    0.076036    0.015376    0.788286    
#> 034: 0.407147    1.042915    3.421600    0.228893    0.072234    0.016974    0.790574    
#> 035: 0.376015    1.025988    3.413256    0.264516    0.087399    0.019506    0.773175    
#> 036: 0.380879    1.029164    3.418316    0.251290    0.083029    0.018753    0.793952    
#> 037: 0.388837    1.038952    3.419204    0.252666    0.078877    0.017815    0.801238    
#> 038: 0.443064    1.030644    3.416599    0.240033    0.074933    0.016925    0.793819    
#> 039: 0.433661    1.001562    3.440761    0.251727    0.071187    0.018189    0.775877    
#> 040: 0.444174    1.018645    3.443084    0.272718    0.075215    0.021412    0.761014    
#> 041: 0.398941    0.999732    3.436477    0.267432    0.081349    0.020342    0.785875    
#> 042: 0.430859    1.004149    3.436358    0.254061    0.077281    0.019325    0.774494    
#> 043: 0.404393    1.037085    3.411815    0.241358    0.086556    0.018358    0.791093    
#> 044: 0.357889    1.043964    3.416100    0.229290    0.086769    0.017440    0.805401    
#> 045: 0.363344    1.045121    3.405331    0.217825    0.083914    0.016568    0.788645    
#> 046: 0.352433    1.031710    3.409255    0.222471    0.079718    0.015740    0.783884    
#> 047: 0.401371    1.021175    3.418814    0.225210    0.079369    0.014953    0.770630    
#> 048: 0.393275    1.019677    3.416667    0.267335    0.087189    0.019000    0.772037    
#> 049: 0.402161    1.034727    3.424270    0.253969    0.089238    0.018050    0.778788    
#> 050: 0.455499    0.994189    3.436527    0.241270    0.088604    0.017148    0.805450    
#> 051: 0.440452    0.992350    3.430978    0.261397    0.084174    0.016290    0.814729    
#> 052: 0.447159    1.003913    3.440781    0.248327    0.079965    0.016987    0.786992    
#> 053: 0.442039    0.992936    3.438958    0.271760    0.075967    0.018533    0.782558    
#> 054: 0.365824    0.998848    3.433740    0.258172    0.072169    0.024467    0.796359    
#> 055: 0.371111    0.991970    3.431855    0.245263    0.075429    0.023244    0.791584    
#> 056: 0.403540    0.990309    3.430642    0.233000    0.081751    0.022336    0.781667    
#> 057: 0.408677    1.007962    3.432833    0.254196    0.078121    0.021686    0.785997    
#> 058: 0.393017    1.006682    3.422215    0.249916    0.074215    0.020601    0.777736    
#> 059: 0.429065    0.960981    3.439781    0.274077    0.070504    0.023753    0.798003    
#> 060: 0.446136    0.971358    3.435418    0.297362    0.066979    0.030057    0.794586    
#> 061: 0.439773    0.973859    3.444476    0.282494    0.063630    0.028616    0.808617    
#> 062: 0.441918    0.988658    3.446518    0.268369    0.060449    0.031326    0.836586    
#> 063: 0.510778    0.961574    3.460717    0.297732    0.057426    0.029760    0.821323    
#> 064: 0.495314    0.966441    3.476813    0.282845    0.057601    0.028272    0.813609    
#> 065: 0.466869    0.962866    3.446506    0.268703    0.064043    0.029929    0.810580    
#> 066: 0.472448    0.981715    3.463821    0.255268    0.060841    0.028432    0.781241    
#> 067: 0.427189    1.010013    3.428067    0.242504    0.072108    0.027011    0.778068    
#> 068: 0.402161    0.993697    3.439260    0.230379    0.071278    0.025660    0.804264    
#> 069: 0.415106    0.994610    3.435301    0.218860    0.073151    0.024377    0.798542    
#> 070: 0.424317    1.015887    3.444427    0.235715    0.076903    0.027528    0.792753    
#> 071: 0.393315    1.032402    3.419154    0.223930    0.073058    0.026152    0.792506    
#> 072: 0.354064    1.013395    3.413313    0.236561    0.069405    0.027412    0.783398    
#> 073: 0.398299    1.003785    3.438770    0.224733    0.079093    0.026042    0.799839    
#> 074: 0.385792    1.014288    3.440666    0.222092    0.082928    0.024740    0.811935    
#> 075: 0.439348    0.985856    3.472485    0.210987    0.085409    0.023503    0.812328    
#> 076: 0.445228    0.998831    3.461153    0.216293    0.081139    0.022328    0.813012    
#> 077: 0.500342    0.984257    3.454708    0.229861    0.085597    0.021211    0.794344    
#> 078: 0.474571    1.005557    3.445416    0.218368    0.081317    0.020151    0.789863    
#> 079: 0.434451    1.013845    3.446674    0.211665    0.077251    0.019143    0.815400    
#> 080: 0.414991    1.003949    3.439259    0.246433    0.073389    0.019655    0.811336    
#> 081: 0.393062    1.025684    3.424336    0.248246    0.069719    0.019617    0.791099    
#> 082: 0.419367    1.005356    3.437856    0.238391    0.066233    0.019285    0.804282    
#> 083: 0.447220    1.031943    3.442864    0.226472    0.068005    0.018321    0.795009    
#> 084: 0.437194    1.014451    3.433899    0.216715    0.081274    0.018873    0.779495    
#> 085: 0.430406    1.015934    3.438938    0.280240    0.079336    0.017929    0.782850    
#> 086: 0.405169    1.013439    3.431795    0.266228    0.075369    0.019079    0.783362    
#> 087: 0.380919    1.009349    3.413833    0.252917    0.071601    0.018125    0.782127    
#> 088: 0.346520    1.019871    3.419201    0.241335    0.069722    0.017218    0.779601    
#> 089: 0.378184    1.046067    3.408068    0.229268    0.074147    0.016358    0.778986    
#> 090: 0.354389    1.025406    3.414148    0.223841    0.079100    0.016400    0.787620    
#> 091: 0.360723    1.012641    3.400988    0.239732    0.080333    0.020455    0.774116    
#> 092: 0.352061    1.049197    3.399277    0.275154    0.079275    0.023792    0.786646    
#> 093: 0.360105    1.028933    3.407632    0.277240    0.091069    0.022603    0.798811    
#> 094: 0.364238    1.036781    3.400649    0.263378    0.086516    0.021473    0.802807    
#> 095: 0.382227    1.040619    3.410830    0.271582    0.082190    0.026583    0.788478    
#> 096: 0.335114    1.050808    3.396325    0.258003    0.078080    0.025254    0.790201    
#> 097: 0.369708    1.061668    3.403144    0.258549    0.084178    0.023992    0.769378    
#> 098: 0.376530    1.066037    3.411681    0.245621    0.081943    0.022862    0.782544    
#> 099: 0.378104    1.040464    3.403269    0.280285    0.077846    0.021719    0.790508    
#> 100: 0.373173    1.050619    3.408993    0.266270    0.073953    0.020633    0.781545    
#> 101: 0.362711    1.032294    3.401262    0.252957    0.070256    0.019601    0.784413    
#> 102: 0.345020    1.030948    3.396656    0.240309    0.066743    0.019682    0.786069    
#> 103: 0.407307    1.028970    3.419079    0.290124    0.071921    0.021655    0.773841    
#> 104: 0.361528    1.016568    3.419771    0.275618    0.069653    0.021608    0.783630    
#> 105: 0.399179    1.012029    3.422236    0.299552    0.069474    0.020528    0.782867    
#> 106: 0.437445    1.001490    3.436141    0.284575    0.066001    0.019501    0.773865    
#> 107: 0.445330    1.005640    3.438271    0.270346    0.070449    0.018526    0.766436    
#> 108: 0.420564    1.018231    3.422025    0.256828    0.073420    0.019179    0.777383    
#> 109: 0.411714    1.013096    3.439502    0.243987    0.083268    0.019809    0.765402    
#> 110: 0.390474    1.000717    3.417007    0.279303    0.079105    0.022021    0.767790    
#> 111: 0.398812    1.015805    3.431656    0.265338    0.075150    0.020920    0.758046    
#> 112: 0.404375    1.003384    3.417260    0.263450    0.072086    0.019874    0.766447    
#> 113: 0.407117    1.027120    3.423615    0.251983    0.068482    0.018881    0.770127    
#> 114: 0.388049    1.019224    3.428429    0.239384    0.065058    0.017937    0.782616    
#> 115: 0.415097    1.009615    3.423565    0.240117    0.078405    0.019605    0.789307    
#> 116: 0.401164    1.019488    3.424476    0.228111    0.074485    0.018625    0.793455    
#> 117: 0.378565    1.038373    3.422194    0.221601    0.070760    0.017694    0.796136    
#> 118: 0.407673    1.024258    3.433031    0.210521    0.075313    0.016957    0.784249    
#> 119: 0.399618    1.026458    3.425539    0.211289    0.077237    0.016797    0.779511    
#> 120: 0.411454    1.002496    3.429410    0.229765    0.076225    0.015957    0.767272    
#> 121: 0.393892    1.031960    3.417969    0.218276    0.072414    0.018100    0.770672    
#> 122: 0.385895    1.005885    3.424214    0.227116    0.068793    0.017195    0.786520    
#> 123: 0.412574    1.038360    3.414432    0.215760    0.072397    0.017193    0.780217    
#> 124: 0.399014    1.068844    3.419980    0.204972    0.068777    0.016813    0.785358    
#> 125: 0.406854    1.073280    3.407897    0.194723    0.080530    0.015972    0.793763    
#> 126: 0.339733    1.053287    3.391424    0.231318    0.090320    0.015921    0.797575    
#> 127: 0.357582    1.027429    3.400733    0.219752    0.094047    0.015124    0.810209    
#> 128: 0.365461    1.022458    3.423683    0.208765    0.089345    0.014368    0.792212    
#> 129: 0.410702    1.026828    3.427012    0.234500    0.084877    0.016626    0.783138    
#> 130: 0.465610    1.013945    3.440415    0.222775    0.080634    0.015795    0.785655    
#> 131: 0.413071    0.997738    3.426415    0.211636    0.076602    0.015169    0.792075    
#> 132: 0.384797    1.001804    3.410151    0.201054    0.079426    0.015597    0.793622    
#> 133: 0.403970    0.998549    3.421664    0.247719    0.080694    0.016368    0.778254    
#> 134: 0.428138    0.980430    3.444594    0.235333    0.076659    0.019851    0.793909    
#> 135: 0.397039    0.993928    3.426921    0.235823    0.072826    0.018858    0.809014    
#> 136: 0.420416    0.985415    3.428933    0.264781    0.069185    0.022935    0.770190    
#> 137: 0.470882    0.983123    3.445221    0.278836    0.065772    0.023782    0.762370    
#> 138: 0.436201    1.004557    3.435464    0.275085    0.070373    0.022593    0.776828    
#> 139: 0.413112    1.012691    3.435877    0.261331    0.069014    0.024429    0.765819    
#> 140: 0.438477    1.033231    3.434609    0.272950    0.066573    0.026540    0.772436    
#> 141: 0.419403    1.013416    3.436157    0.278783    0.063244    0.025213    0.776945    
#> 142: 0.444290    0.986275    3.450707    0.273028    0.060082    0.023952    0.801927    
#> 143: 0.433944    1.009864    3.445514    0.259376    0.067753    0.022754    0.788930    
#> 144: 0.464670    1.011076    3.460798    0.246407    0.064703    0.021617    0.773668    
#> 145: 0.441039    1.019240    3.435580    0.261965    0.070567    0.020536    0.764091    
#> 146: 0.411460    0.999097    3.453693    0.248866    0.072872    0.023294    0.774114    
#> 147: 0.405003    1.002545    3.435797    0.236423    0.069229    0.028219    0.763745    
#> 148: 0.418869    1.008962    3.452181    0.224602    0.069242    0.026808    0.773827    
#> 149: 0.434919    1.007605    3.439862    0.219445    0.065780    0.025468    0.782189    
#> 150: 0.453731    0.994006    3.428610    0.231958    0.062491    0.024194    0.790696    
#> 151: 0.388989    1.012524    3.429413    0.239977    0.065822    0.022984    0.783487    
#> 152: 0.394049    1.019858    3.431169    0.240821    0.076897    0.020799    0.795552    
#> 153: 0.408788    1.024115    3.439385    0.257073    0.077483    0.020459    0.799175    
#> 154: 0.471579    1.027212    3.444839    0.247911    0.077720    0.020544    0.804126    
#> 155: 0.454419    1.012223    3.450537    0.260708    0.071175    0.017425    0.795333    
#> 156: 0.433107    1.027888    3.446543    0.284151    0.068134    0.022191    0.811108    
#> 157: 0.409770    1.009344    3.442197    0.270955    0.059297    0.023559    0.778232    
#> 158: 0.410132    1.032579    3.430042    0.259918    0.069780    0.020588    0.778004    
#> 159: 0.399282    1.026528    3.441569    0.226626    0.069870    0.020441    0.773887    
#> 160: 0.442851    1.000116    3.449215    0.255691    0.062601    0.018293    0.761984    
#> 161: 0.437642    1.005150    3.448050    0.233751    0.055995    0.022168    0.775951    
#> 162: 0.433759    1.020447    3.435432    0.311339    0.052854    0.025458    0.785358    
#> 163: 0.477213    1.004724    3.434783    0.325738    0.046883    0.027709    0.770819    
#> 164: 0.477605    1.019668    3.435688    0.361357    0.049350    0.027429    0.768327    
#> 165: 0.417234    1.009488    3.429180    0.307173    0.061741    0.023080    0.779454    
#> 166: 0.475846    1.045152    3.429468    0.407325    0.063345    0.024518    0.777145    
#> 167: 0.455086    1.040103    3.433968    0.360225    0.073410    0.022553    0.791700    
#> 168: 0.496570    1.029308    3.446969    0.325779    0.069651    0.020289    0.788551    
#> 169: 0.457977    1.043769    3.437743    0.291530    0.068230    0.022530    0.797764    
#> 170: 0.457608    1.014826    3.436433    0.303528    0.057086    0.024374    0.782312    
#> 171: 0.428031    1.014357    3.435200    0.271908    0.071453    0.019458    0.758435    
#> 172: 0.401115    1.057232    3.424322    0.241325    0.072770    0.018396    0.767080    
#> 173: 0.383565    1.045954    3.410576    0.210968    0.060285    0.016377    0.794969    
#> 174: 0.404873    1.039445    3.419441    0.220508    0.087784    0.014733    0.779488    
#> 175: 0.394649    1.036914    3.414420    0.217658    0.080575    0.016965    0.788523    
#> 176: 0.401948    1.066196    3.421016    0.195516    0.075573    0.013045    0.788824    
#> 177: 0.421784    1.043047    3.430337    0.253433    0.095213    0.017348    0.765937    
#> 178: 0.414938    1.028360    3.431671    0.240262    0.087834    0.016921    0.766240    
#> 179: 0.444761    1.032197    3.427962    0.252166    0.062431    0.014744    0.785734    
#> 180: 0.399509    1.015021    3.426779    0.262219    0.070037    0.021113    0.778503    
#> 181: 0.400555    0.986452    3.407286    0.237629    0.062903    0.019360    0.772274    
#> 182: 0.366114    1.038450    3.391459    0.215560    0.076151    0.018473    0.796331    
#> 183: 0.381829    1.049365    3.398330    0.239030    0.084163    0.017617    0.789516    
#> 184: 0.402930    1.017072    3.418664    0.293972    0.081192    0.021005    0.774665    
#> 185: 0.366600    1.027901    3.413879    0.275967    0.061405    0.020718    0.793316    
#> 186: 0.352081    1.060799    3.407484    0.266043    0.063250    0.018350    0.809570    
#> 187: 0.360782    1.027842    3.407230    0.311273    0.056005    0.016917    0.796697    
#> 188: 0.349718    1.048115    3.409058    0.284784    0.069681    0.020888    0.791595    
#> 189: 0.397992    1.051974    3.427853    0.222717    0.086668    0.022432    0.799439    
#> 190: 0.414254    1.038122    3.430061    0.235397    0.078046    0.020548    0.792508    
#> 191: 0.374139    1.025795    3.413668    0.192299    0.067111    0.017531    0.770304    
#> 192: 0.375400    1.050835    3.410978    0.193588    0.067553    0.019362    0.765048    
#> 193: 0.407059    1.056186    3.414688    0.211111    0.056170    0.020501    0.767846    
#> 194: 0.380525    1.042732    3.407929    0.239129    0.064550    0.020474    0.786754    
#> 195: 0.358137    1.042531    3.402605    0.239273    0.067673    0.019479    0.782019    
#> 196: 0.356785    1.033759    3.410632    0.255590    0.079980    0.017946    0.780032    
#> 197: 0.333216    1.046418    3.422357    0.256104    0.077439    0.018830    0.796971    
#> 198: 0.417827    1.016535    3.419738    0.253713    0.072646    0.019259    0.776555    
#> 199: 0.402845    1.009620    3.422894    0.226597    0.073003    0.017039    0.791941    
#> 200: 0.405815    1.006391    3.435611    0.237725    0.072614    0.014504    0.828312    
#> 201: 0.403070    0.999981    3.437991    0.222335    0.068565    0.013928    0.820049    
#> 202: 0.404309    1.005763    3.438175    0.211429    0.073871    0.013160    0.813906    
#> 203: 0.408489    1.008430    3.434426    0.199523    0.076510    0.012530    0.815391    
#> 204: 0.411009    1.000398    3.434336    0.199752    0.082181    0.012078    0.814831    
#> 205: 0.407433    1.006994    3.431746    0.197102    0.086394    0.012014    0.815243    
#> 206: 0.405784    1.012316    3.431505    0.191995    0.086145    0.012052    0.817852    
#> 207: 0.403229    1.011430    3.429847    0.187673    0.085106    0.011730    0.819647    
#> 208: 0.398681    1.009411    3.429942    0.185293    0.083748    0.011756    0.819226    
#> 209: 0.400590    1.008043    3.428841    0.185403    0.083514    0.011419    0.818622    
#> 210: 0.400356    1.007288    3.428718    0.181200    0.084515    0.011306    0.817750    
#> 211: 0.401139    1.007607    3.429367    0.178026    0.083545    0.011070    0.815838    
#> 212: 0.401415    1.007160    3.429661    0.177320    0.083547    0.011101    0.815111    
#> 213: 0.401928    1.005079    3.429630    0.175820    0.084681    0.011292    0.815632    
#> 214: 0.403206    1.004467    3.429593    0.175946    0.085194    0.011596    0.815081    
#> 215: 0.404265    1.004965    3.431062    0.177186    0.085220    0.011959    0.814245    
#> 216: 0.405234    1.005007    3.431487    0.179000    0.084937    0.012117    0.814462    
#> 217: 0.405191    1.006355    3.431553    0.180910    0.084322    0.012271    0.813142    
#> 218: 0.406293    1.007585    3.431222    0.183523    0.084052    0.012409    0.810737    
#> 219: 0.406952    1.007738    3.430616    0.187367    0.084123    0.012531    0.808938    
#> 220: 0.406377    1.008612    3.431047    0.186516    0.083729    0.012559    0.808827    
#> 221: 0.407035    1.008875    3.430862    0.186741    0.083340    0.012566    0.808093    
#> 222: 0.408718    1.008617    3.431168    0.188973    0.082792    0.012717    0.806880    
#> 223: 0.411023    1.008640    3.431429    0.189705    0.083243    0.012732    0.805916    
#> 224: 0.413297    1.008897    3.431972    0.190763    0.083616    0.012641    0.805362    
#> 225: 0.413793    1.007349    3.432568    0.191271    0.083905    0.012742    0.805171    
#> 226: 0.414500    1.006036    3.432466    0.194113    0.084037    0.012765    0.804568    
#> 227: 0.414151    1.006109    3.432651    0.195785    0.084204    0.012779    0.804367    
#> 228: 0.413383    1.007445    3.431978    0.199050    0.084043    0.012851    0.803892    
#> 229: 0.412677    1.007254    3.431402    0.200812    0.083766    0.012946    0.803137    
#> 230: 0.412628    1.006797    3.430986    0.201773    0.083496    0.012948    0.803018    
#> 231: 0.413116    1.007897    3.430899    0.203414    0.083394    0.013039    0.802895    
#> 232: 0.412368    1.008153    3.430960    0.204782    0.083049    0.013184    0.802700    
#> 233: 0.411423    1.008040    3.430860    0.205926    0.082986    0.013330    0.802356    
#> 234: 0.410548    1.008402    3.430877    0.207239    0.082831    0.013458    0.801873    
#> 235: 0.410343    1.008686    3.430763    0.208399    0.082916    0.013545    0.801198    
#> 236: 0.410036    1.009331    3.430655    0.208361    0.083144    0.013588    0.801201    
#> 237: 0.410408    1.009405    3.430671    0.209089    0.083450    0.013629    0.801277    
#> 238: 0.410147    1.009536    3.430767    0.209770    0.083902    0.013732    0.801372    
#> 239: 0.409340    1.010237    3.430488    0.209610    0.084061    0.013787    0.801139    
#> 240: 0.409469    1.010025    3.430357    0.209366    0.084021    0.013750    0.800773    
#> 241: 0.409591    1.009558    3.430379    0.209121    0.083756    0.013719    0.800384    
#> 242: 0.409045    1.009414    3.430193    0.208946    0.084106    0.013741    0.800279    
#> 243: 0.408205    1.009584    3.430146    0.209023    0.084106    0.013825    0.800011    
#> 244: 0.407715    1.009474    3.430345    0.208739    0.084113    0.013924    0.800161    
#> 245: 0.408032    1.009155    3.430387    0.209202    0.084225    0.014014    0.800302    
#> 246: 0.408317    1.009268    3.430517    0.210090    0.084066    0.014068    0.800440    
#> 247: 0.408162    1.009270    3.430633    0.210332    0.083530    0.014108    0.800616    
#> 248: 0.407521    1.009569    3.430595    0.210037    0.083160    0.014110    0.800244    
#> 249: 0.406995    1.009671    3.430548    0.210260    0.083202    0.014128    0.800264    
#> 250: 0.407675    1.009722    3.430738    0.210588    0.083172    0.014121    0.800278    
#> 251: 0.408696    1.010061    3.430993    0.210811    0.082944    0.014127    0.800519    
#> 252: 0.409646    1.009802    3.431643    0.210755    0.082984    0.014132    0.800908    
#> 253: 0.410066    1.009801    3.432101    0.210643    0.082951    0.014134    0.801136    
#> 254: 0.410476    1.009936    3.432406    0.210441    0.082754    0.014151    0.800880    
#> 255: 0.410329    1.010242    3.432680    0.209574    0.082622    0.014178    0.801109    
#> 256: 0.410726    1.010086    3.432853    0.209095    0.082511    0.014184    0.801396    
#> 257: 0.410318    1.009766    3.432923    0.209324    0.082362    0.014231    0.801481    
#> 258: 0.410059    1.009658    3.432879    0.208768    0.082426    0.014296    0.801406    
#> 259: 0.409853    1.009827    3.432714    0.208263    0.082549    0.014352    0.801333    
#> 260: 0.409751    1.010343    3.432592    0.208589    0.082780    0.014348    0.800997    
#> 261: 0.409999    1.010452    3.432638    0.208913    0.082785    0.014377    0.800789    
#> 262: 0.410238    1.010574    3.432765    0.208557    0.082922    0.014369    0.800897    
#> 263: 0.410346    1.010981    3.432842    0.208829    0.083010    0.014362    0.800685    
#> 264: 0.410252    1.010861    3.432941    0.209364    0.083001    0.014362    0.800678    
#> 265: 0.410594    1.010937    3.432993    0.209200    0.083098    0.014331    0.800767    
#> 266: 0.411041    1.011056    3.432979    0.209323    0.082973    0.014312    0.800872    
#> 267: 0.411383    1.011008    3.433148    0.209203    0.082874    0.014315    0.800790    
#> 268: 0.411343    1.010663    3.432961    0.209738    0.083014    0.014330    0.800840    
#> 269: 0.411452    1.010496    3.432836    0.209448    0.082883    0.014343    0.800950    
#> 270: 0.411455    1.010709    3.432540    0.209381    0.082847    0.014332    0.800744    
#> 271: 0.411514    1.010652    3.432383    0.209342    0.082752    0.014336    0.800976    
#> 272: 0.411598    1.010448    3.432322    0.210089    0.082748    0.014328    0.801127    
#> 273: 0.411121    1.010775    3.432194    0.210010    0.082763    0.014357    0.801124    
#> 274: 0.411045    1.011203    3.432130    0.209763    0.082872    0.014336    0.801098    
#> 275: 0.410611    1.011624    3.431865    0.209602    0.082980    0.014331    0.801073    
#> 276: 0.410136    1.011798    3.431983    0.209340    0.082796    0.014336    0.801060    
#> 277: 0.409723    1.012123    3.432001    0.208993    0.082944    0.014370    0.801004    
#> 278: 0.409561    1.012024    3.432143    0.208674    0.083068    0.014362    0.800876    
#> 279: 0.409361    1.011844    3.432202    0.208849    0.083234    0.014351    0.800880    
#> 280: 0.409424    1.012066    3.432305    0.208866    0.083325    0.014332    0.800554    
#> 281: 0.409365    1.012238    3.432408    0.209526    0.083312    0.014315    0.800583    
#> 282: 0.409565    1.012438    3.432425    0.210006    0.083155    0.014313    0.800677    
#> 283: 0.409950    1.012477    3.432567    0.210584    0.083059    0.014321    0.800841    
#> 284: 0.410395    1.012361    3.432563    0.211346    0.082847    0.014344    0.800574    
#> 285: 0.410225    1.012605    3.432351    0.212298    0.082672    0.014376    0.800597    
#> 286: 0.409914    1.012832    3.432101    0.212675    0.082416    0.014425    0.800419    
#> 287: 0.409423    1.013045    3.431892    0.213040    0.082427    0.014520    0.800291    
#> 288: 0.409284    1.013117    3.431719    0.213144    0.082319    0.014527    0.800369    
#> 289: 0.409362    1.013075    3.431671    0.212974    0.082335    0.014535    0.800422    
#> 290: 0.409394    1.013023    3.431668    0.213168    0.082323    0.014515    0.800639    
#> 291: 0.409477    1.013077    3.431751    0.213402    0.082152    0.014507    0.800404    
#> 292: 0.409421    1.013034    3.431835    0.213483    0.081982    0.014540    0.800280    
#> 293: 0.409674    1.012910    3.431887    0.213320    0.081921    0.014570    0.800182    
#> 294: 0.409771    1.012915    3.431837    0.213039    0.081808    0.014615    0.799952    
#> 295: 0.409900    1.012568    3.431834    0.213530    0.081712    0.014669    0.799561    
#> 296: 0.409725    1.012530    3.431792    0.213730    0.081585    0.014723    0.799429    
#> 297: 0.409782    1.012573    3.431762    0.213935    0.081469    0.014736    0.799070    
#> 298: 0.410025    1.012665    3.431733    0.214185    0.081440    0.014732    0.798815    
#> 299: 0.410104    1.012853    3.431673    0.214322    0.081488    0.014751    0.798664    
#> 300: 0.410183    1.012650    3.431769    0.214368    0.081464    0.014781    0.798459    
#> 301: 0.410235    1.012606    3.431792    0.214119    0.081437    0.014782    0.798518    
#> 302: 0.410028    1.012864    3.431672    0.214179    0.081374    0.014776    0.798345    
#> 303: 0.409836    1.013118    3.431505    0.214149    0.081376    0.014758    0.798135    
#> 304: 0.410055    1.013287    3.431405    0.214421    0.081343    0.014741    0.798272    
#> 305: 0.410022    1.013126    3.431323    0.214445    0.081307    0.014764    0.798254    
#> 306: 0.409455    1.013181    3.431068    0.214342    0.081319    0.014783    0.798109    
#> 307: 0.409085    1.013184    3.430915    0.213922    0.081398    0.014786    0.798255    
#> 308: 0.408790    1.012966    3.430842    0.213808    0.081621    0.014781    0.798428    
#> 309: 0.409015    1.012767    3.430783    0.213659    0.081603    0.014778    0.798713    
#> 310: 0.409414    1.012710    3.430613    0.214159    0.081469    0.014814    0.798787    
#> 311: 0.409373    1.012789    3.430537    0.214305    0.081319    0.014863    0.798696    
#> 312: 0.409334    1.012811    3.430392    0.214689    0.081213    0.014908    0.798549    
#> 313: 0.409028    1.012539    3.430318    0.214816    0.081225    0.014951    0.798591    
#> 314: 0.408816    1.012637    3.430207    0.214856    0.081220    0.014998    0.798735    
#> 315: 0.408587    1.012875    3.430159    0.215349    0.081219    0.015036    0.798748    
#> 316: 0.408577    1.013121    3.430079    0.215755    0.081189    0.015068    0.798607    
#> 317: 0.408416    1.013251    3.430101    0.215750    0.081149    0.015095    0.798595    
#> 318: 0.408335    1.013349    3.430051    0.215856    0.081189    0.015103    0.798279    
#> 319: 0.408462    1.013361    3.430005    0.215840    0.081288    0.015092    0.798250    
#> 320: 0.408017    1.013386    3.429817    0.216094    0.081205    0.015072    0.798318    
#> 321: 0.407551    1.013664    3.429564    0.216368    0.081217    0.015070    0.798407    
#> 322: 0.407472    1.013914    3.429333    0.216925    0.081160    0.015082    0.798251    
#> 323: 0.407033    1.014024    3.429168    0.217290    0.081056    0.015091    0.798175    
#> 324: 0.406947    1.014298    3.429092    0.217355    0.081055    0.015108    0.797973    
#> 325: 0.406882    1.014628    3.429026    0.217292    0.081044    0.015112    0.797843    
#> 326: 0.406837    1.014697    3.428932    0.217288    0.080987    0.015101    0.797615    
#> 327: 0.407099    1.014643    3.428996    0.217552    0.080881    0.015107    0.797633    
#> 328: 0.407214    1.014772    3.428988    0.217551    0.080781    0.015127    0.797561    
#> 329: 0.407269    1.014862    3.429008    0.217716    0.080647    0.015156    0.797591    
#> 330: 0.407145    1.014933    3.429063    0.217497    0.080596    0.015185    0.797687    
#> 331: 0.407198    1.015106    3.429073    0.217059    0.080528    0.015210    0.797752    
#> 332: 0.407478    1.015080    3.429173    0.216617    0.080449    0.015219    0.797771    
#> 333: 0.407287    1.014979    3.429122    0.216689    0.080448    0.015232    0.797560    
#> 334: 0.406963    1.014839    3.428930    0.216778    0.080447    0.015235    0.797480    
#> 335: 0.406567    1.014980    3.428752    0.216891    0.080519    0.015215    0.797483    
#> 336: 0.406187    1.015315    3.428610    0.216645    0.080539    0.015204    0.797577    
#> 337: 0.406102    1.015602    3.428501    0.216757    0.080488    0.015202    0.797460    
#> 338: 0.406022    1.015747    3.428481    0.216777    0.080342    0.015215    0.797469    
#> 339: 0.405773    1.015890    3.428384    0.216889    0.080175    0.015236    0.797427    
#> 340: 0.405580    1.015724    3.428368    0.217194    0.080010    0.015291    0.797226    
#> 341: 0.405570    1.015796    3.428407    0.217558    0.079787    0.015356    0.797094    
#> 342: 0.405239    1.015742    3.428369    0.217689    0.079710    0.015375    0.796970    
#> 343: 0.404798    1.015915    3.428274    0.217810    0.079623    0.015404    0.796928    
#> 344: 0.404690    1.015940    3.428181    0.218112    0.079550    0.015424    0.796958    
#> 345: 0.404457    1.015943    3.428166    0.218279    0.079474    0.015434    0.796843    
#> 346: 0.404403    1.015982    3.428074    0.218381    0.079401    0.015440    0.796762    
#> 347: 0.404438    1.015931    3.427997    0.218485    0.079444    0.015443    0.796870    
#> 348: 0.404208    1.015962    3.427913    0.218561    0.079395    0.015429    0.796825    
#> 349: 0.404041    1.015970    3.427819    0.218772    0.079377    0.015433    0.796775    
#> 350: 0.403938    1.015821    3.427724    0.218739    0.079378    0.015425    0.796892    
#> 351: 0.404024    1.015903    3.427670    0.218669    0.079380    0.015412    0.796882    
#> 352: 0.403723    1.016076    3.427593    0.218809    0.079382    0.015435    0.796895    
#> 353: 0.403652    1.016317    3.427498    0.219138    0.079405    0.015473    0.796766    
#> 354: 0.403489    1.016526    3.427332    0.219407    0.079403    0.015507    0.796502    
#> 355: 0.403599    1.016517    3.427225    0.219613    0.079386    0.015543    0.796445    
#> 356: 0.403460    1.016478    3.427207    0.219472    0.079316    0.015552    0.796650    
#> 357: 0.403692    1.016655    3.427158    0.219840    0.079208    0.015557    0.796715    
#> 358: 0.403689    1.016760    3.427145    0.219898    0.079099    0.015572    0.796528    
#> 359: 0.403504    1.016866    3.427072    0.219963    0.079019    0.015581    0.796361    
#> 360: 0.403275    1.016862    3.426944    0.219773    0.078928    0.015573    0.796243    
#> 361: 0.402952    1.016934    3.426832    0.219512    0.078880    0.015577    0.796235    
#> 362: 0.402871    1.016913    3.426747    0.219422    0.078861    0.015562    0.796058    
#> 363: 0.402676    1.016916    3.426663    0.219336    0.078878    0.015556    0.795943    
#> 364: 0.402538    1.016967    3.426629    0.219488    0.078834    0.015551    0.795951    
#> 365: 0.402603    1.016819    3.426670    0.219377    0.078842    0.015550    0.796028    
#> 366: 0.402651    1.016880    3.426620    0.219381    0.078825    0.015545    0.796100    
#> 367: 0.402885    1.016864    3.426596    0.219410    0.078902    0.015525    0.796232    
#> 368: 0.403052    1.016932    3.426562    0.219561    0.078895    0.015523    0.796236    
#> 369: 0.403177    1.016946    3.426566    0.219726    0.078857    0.015535    0.796267    
#> 370: 0.403202    1.017057    3.426498    0.219953    0.078875    0.015525    0.796279    
#> 371: 0.402995    1.017162    3.426370    0.219965    0.078789    0.015526    0.796265    
#> 372: 0.402793    1.017182    3.426304    0.219969    0.078745    0.015499    0.796425    
#> 373: 0.402545    1.017396    3.426197    0.220175    0.078740    0.015490    0.796519    
#> 374: 0.402429    1.017501    3.426155    0.220063    0.078832    0.015469    0.796470    
#> 375: 0.402284    1.017663    3.426118    0.219965    0.078852    0.015465    0.796419    
#> 376: 0.402133    1.017781    3.426074    0.219812    0.078878    0.015450    0.796311    
#> 377: 0.401981    1.017839    3.426032    0.219691    0.078806    0.015439    0.796306    
#> 378: 0.401704    1.017899    3.425899    0.219709    0.078749    0.015444    0.796369    
#> 379: 0.401496    1.017832    3.425835    0.219786    0.078711    0.015465    0.796295    
#> 380: 0.401308    1.017844    3.425804    0.219696    0.078739    0.015478    0.796317    
#> 381: 0.401089    1.017789    3.425745    0.219657    0.078783    0.015490    0.796345    
#> 382: 0.401114    1.017735    3.425754    0.219505    0.078745    0.015493    0.796208    
#> 383: 0.401237    1.017719    3.425775    0.219177    0.078748    0.015501    0.796203    
#> 384: 0.400939    1.017653    3.425759    0.218907    0.078765    0.015495    0.796182    
#> 385: 0.400947    1.017743    3.425778    0.218776    0.078835    0.015498    0.796123    
#> 386: 0.401087    1.017939    3.425839    0.218625    0.078868    0.015492    0.796155    
#> 387: 0.401372    1.018058    3.425948    0.218650    0.078882    0.015492    0.796092    
#> 388: 0.401491    1.018124    3.426003    0.218579    0.078872    0.015512    0.796080    
#> 389: 0.401501    1.018042    3.425973    0.218530    0.078802    0.015527    0.796233    
#> 390: 0.401485    1.018042    3.426005    0.218566    0.078719    0.015532    0.796296    
#> 391: 0.401540    1.017963    3.426030    0.218738    0.078725    0.015524    0.796271    
#> 392: 0.401609    1.017942    3.426074    0.218844    0.078746    0.015524    0.796383    
#> 393: 0.401525    1.017941    3.426067    0.218786    0.078764    0.015524    0.796391    
#> 394: 0.401480    1.017964    3.426046    0.218863    0.078727    0.015555    0.796289    
#> 395: 0.401555    1.018016    3.426067    0.218836    0.078687    0.015566    0.796256    
#> 396: 0.401786    1.018065    3.426138    0.218817    0.078661    0.015578    0.796122    
#> 397: 0.401990    1.017973    3.426221    0.218867    0.078675    0.015564    0.796203    
#> 398: 0.402132    1.017871    3.426249    0.218814    0.078658    0.015550    0.796226    
#> 399: 0.402224    1.017815    3.426285    0.218917    0.078620    0.015551    0.796181    
#> 400: 0.402208    1.017831    3.426297    0.218948    0.078697    0.015554    0.796145    
#> 401: 0.402193    1.017933    3.426288    0.218971    0.078719    0.015557    0.796249    
#> 402: 0.402170    1.017967    3.426329    0.218803    0.078666    0.015569    0.796297    
#> 403: 0.402455    1.017920    3.426328    0.218768    0.078583    0.015575    0.796288    
#> 404: 0.402559    1.017934    3.426305    0.218741    0.078553    0.015585    0.796248    
#> 405: 0.402578    1.018006    3.426284    0.218884    0.078601    0.015595    0.796274    
#> 406: 0.402627    1.018064    3.426260    0.218924    0.078658    0.015589    0.796401    
#> 407: 0.402816    1.018116    3.426277    0.218891    0.078674    0.015584    0.796472    
#> 408: 0.402895    1.018160    3.426307    0.218729    0.078742    0.015566    0.796523    
#> 409: 0.402725    1.018063    3.426250    0.218565    0.078751    0.015558    0.796473    
#> 410: 0.402443    1.018056    3.426151    0.218389    0.078751    0.015561    0.796509    
#> 411: 0.402489    1.017999    3.426088    0.218397    0.078764    0.015565    0.796473    
#> 412: 0.402449    1.018076    3.426054    0.218347    0.078754    0.015577    0.796528    
#> 413: 0.402540    1.018129    3.426025    0.218263    0.078737    0.015567    0.796615    
#> 414: 0.402477    1.018105    3.426049    0.218208    0.078800    0.015542    0.796525    
#> 415: 0.402627    1.017986    3.426066    0.218343    0.078857    0.015536    0.796455    
#> 416: 0.402824    1.018021    3.426124    0.218412    0.078914    0.015527    0.796467    
#> 417: 0.402830    1.017945    3.426096    0.218476    0.078926    0.015516    0.796487    
#> 418: 0.402633    1.017944    3.426114    0.218440    0.078971    0.015491    0.796508    
#> 419: 0.402668    1.018112    3.426108    0.218520    0.078978    0.015486    0.796494    
#> 420: 0.402781    1.018102    3.426106    0.218457    0.078938    0.015497    0.796381    
#> 421: 0.402753    1.018145    3.426142    0.218285    0.078885    0.015505    0.796304    
#> 422: 0.402815    1.018072    3.426142    0.218273    0.078834    0.015526    0.796219    
#> 423: 0.402918    1.018014    3.426166    0.218191    0.078761    0.015533    0.796250    
#> 424: 0.402797    1.017954    3.426100    0.218184    0.078705    0.015530    0.796289    
#> 425: 0.402784    1.018007    3.426066    0.218149    0.078701    0.015523    0.796318    
#> 426: 0.402766    1.018075    3.426013    0.218273    0.078746    0.015534    0.796286    
#> 427: 0.402653    1.018074    3.425983    0.218344    0.078777    0.015552    0.796163    
#> 428: 0.402395    1.018131    3.425947    0.218109    0.078727    0.015555    0.796228    
#> 429: 0.402248    1.018216    3.425897    0.218007    0.078693    0.015565    0.796185    
#> 430: 0.402111    1.018285    3.425859    0.218133    0.078661    0.015570    0.796145    
#> 431: 0.401861    1.018361    3.425707    0.218119    0.078645    0.015560    0.796165    
#> 432: 0.401618    1.018463    3.425634    0.218050    0.078622    0.015551    0.796170    
#> 433: 0.401480    1.018642    3.425566    0.217965    0.078657    0.015530    0.796185    
#> 434: 0.401230    1.018590    3.425528    0.218068    0.078665    0.015534    0.796151    
#> 435: 0.401075    1.018583    3.425475    0.218055    0.078721    0.015535    0.796053    
#> 436: 0.400900    1.018596    3.425453    0.217983    0.078703    0.015549    0.796057    
#> 437: 0.400948    1.018573    3.425450    0.218063    0.078672    0.015562    0.795937    
#> 438: 0.400933    1.018678    3.425427    0.218144    0.078675    0.015549    0.795788    
#> 439: 0.401042    1.018726    3.425423    0.218125    0.078647    0.015546    0.795690    
#> 440: 0.400989    1.018785    3.425457    0.218043    0.078645    0.015552    0.795713    
#> 441: 0.401026    1.018756    3.425513    0.217864    0.078674    0.015554    0.795712    
#> 442: 0.401042    1.018833    3.425594    0.217954    0.078697    0.015556    0.795686    
#> 443: 0.401074    1.018955    3.425588    0.218139    0.078745    0.015567    0.795609    
#> 444: 0.401064    1.019013    3.425550    0.218084    0.078815    0.015574    0.795613    
#> 445: 0.400916    1.019018    3.425477    0.218257    0.078850    0.015584    0.795701    
#> 446: 0.400675    1.018977    3.425416    0.218403    0.078770    0.015589    0.795632    
#> 447: 0.400688    1.019004    3.425415    0.218456    0.078778    0.015593    0.795550    
#> 448: 0.400626    1.018934    3.425399    0.218270    0.078752    0.015582    0.795489    
#> 449: 0.400722    1.018956    3.425498    0.218217    0.078776    0.015576    0.795390    
#> 450: 0.400762    1.018908    3.425520    0.218202    0.078768    0.015567    0.795332    
#> 451: 0.400882    1.018933    3.425514    0.218382    0.078782    0.015576    0.795223    
#> 452: 0.400856    1.019015    3.425489    0.218234    0.078771    0.015566    0.795204    
#> 453: 0.400694    1.019102    3.425409    0.218120    0.078733    0.015569    0.795124    
#> 454: 0.400571    1.019277    3.425358    0.217903    0.078734    0.015571    0.795121    
#> 455: 0.400602    1.019316    3.425378    0.217701    0.078706    0.015573    0.795137    
#> 456: 0.400610    1.019305    3.425390    0.217580    0.078747    0.015579    0.795099    
#> 457: 0.400731    1.019342    3.425451    0.217513    0.078765    0.015598    0.795005    
#> 458: 0.400844    1.019438    3.425540    0.217597    0.078750    0.015611    0.794932    
#> 459: 0.400786    1.019565    3.425542    0.217545    0.078763    0.015616    0.794882    
#> 460: 0.400616    1.019599    3.425470    0.217502    0.078779    0.015615    0.794874    
#> 461: 0.400496    1.019709    3.425428    0.217612    0.078768    0.015619    0.794857    
#> 462: 0.400423    1.019815    3.425417    0.217740    0.078756    0.015628    0.794785    
#> 463: 0.400504    1.019891    3.425456    0.217907    0.078745    0.015637    0.794762    
#> 464: 0.400585    1.019904    3.425473    0.218082    0.078711    0.015643    0.794715    
#> 465: 0.400631    1.019777    3.425502    0.218180    0.078735    0.015646    0.794654    
#> 466: 0.400593    1.019851    3.425460    0.218189    0.078686    0.015642    0.794652    
#> 467: 0.400554    1.019887    3.425465    0.218156    0.078653    0.015639    0.794534    
#> 468: 0.400720    1.019929    3.425508    0.218294    0.078646    0.015636    0.794525    
#> 469: 0.400753    1.020057    3.425518    0.218373    0.078686    0.015640    0.794507    
#> 470: 0.400627    1.020137    3.425440    0.218309    0.078693    0.015647    0.794506    
#> 471: 0.400457    1.020070    3.425401    0.218159    0.078669    0.015638    0.794499    
#> 472: 0.400433    1.020141    3.425393    0.218114    0.078695    0.015642    0.794507    
#> 473: 0.400331    1.020155    3.425390    0.218076    0.078641    0.015654    0.794445    
#> 474: 0.400289    1.020110    3.425413    0.218054    0.078659    0.015657    0.794446    
#> 475: 0.400343    1.020169    3.425435    0.218038    0.078638    0.015647    0.794393    
#> 476: 0.400353    1.020175    3.425409    0.218208    0.078649    0.015653    0.794355    
#> 477: 0.400335    1.020134    3.425431    0.218086    0.078675    0.015653    0.794273    
#> 478: 0.400254    1.020075    3.425411    0.217935    0.078749    0.015656    0.794293    
#> 479: 0.400347    1.020056    3.425430    0.217839    0.078785    0.015648    0.794360    
#> 480: 0.400306    1.020051    3.425426    0.217685    0.078865    0.015647    0.794456    
#> 481: 0.400319    1.020059    3.425406    0.217693    0.078885    0.015650    0.794535    
#> 482: 0.400483    1.020083    3.425385    0.217638    0.078879    0.015660    0.794583    
#> 483: 0.400442    1.020108    3.425368    0.217692    0.078801    0.015668    0.794585    
#> 484: 0.400483    1.019936    3.425390    0.217850    0.078723    0.015682    0.794550    
#> 485: 0.400568    1.019907    3.425411    0.217974    0.078716    0.015698    0.794525    
#> 486: 0.400704    1.019955    3.425461    0.218103    0.078676    0.015705    0.794468    
#> 487: 0.401016    1.019981    3.425539    0.218129    0.078680    0.015707    0.794431    
#> 488: 0.401155    1.019953    3.425596    0.218096    0.078662    0.015709    0.794400    
#> 489: 0.401276    1.019933    3.425613    0.218098    0.078617    0.015721    0.794362    
#> 490: 0.401476    1.019910    3.425690    0.218315    0.078590    0.015726    0.794333    
#> 491: 0.401607    1.019903    3.425780    0.218465    0.078566    0.015739    0.794274    
#> 492: 0.401676    1.019975    3.425792    0.218486    0.078572    0.015727    0.794276    
#> 493: 0.401606    1.019948    3.425802    0.218505    0.078597    0.015744    0.794225    
#> 494: 0.401695    1.020010    3.425786    0.218450    0.078610    0.015754    0.794145    
#> 495: 0.401712    1.019998    3.425791    0.218522    0.078585    0.015764    0.794070    
#> 496: 0.401734    1.020047    3.425734    0.218590    0.078615    0.015775    0.794002    
#> 497: 0.401607    1.020042    3.425691    0.218774    0.078588    0.015773    0.794005    
#> 498: 0.401597    1.020042    3.425617    0.218887    0.078548    0.015792    0.793980    
#> 499: 0.401542    1.020136    3.425541    0.218918    0.078539    0.015816    0.793934    
#> 500: 0.401571    1.020172    3.425499    0.218926    0.078528    0.015822    0.793832    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.292248    0.953902    3.435668    0.392401    0.074834    0.016800    1.705136    
#> 002: 0.417030    0.893063    3.424029    0.372781    0.071092    0.015960    1.216430    
#> 003: 0.495164    0.745726    3.412696    0.354142    0.067538    0.015162    0.968871    
#> 004: 0.405547    0.727184    3.392474    0.336435    0.064161    0.014404    0.875100    
#> 005: 0.425743    0.713180    3.385248    0.319613    0.060953    0.013684    0.844348    
#> 006: 0.414175    0.725495    3.373045    0.303633    0.058310    0.013000    0.791131    
#> 007: 0.366500    0.722101    3.364469    0.288451    0.055395    0.012350    0.809428    
#> 008: 0.365431    0.736080    3.366087    0.274029    0.052625    0.011732    0.810771    
#> 009: 0.338778    0.716705    3.361483    0.260327    0.049994    0.011146    0.793253    
#> 010: 0.376772    0.711305    3.371728    0.247311    0.047494    0.010588    0.816276    
#> 011: 0.447322    0.724421    3.373654    0.234945    0.045600    0.010059    0.818317    
#> 012: 0.437344    0.708200    3.372503    0.223198    0.043320    0.009556    0.793024    
#> 013: 0.415284    0.696873    3.375652    0.212038    0.044192    0.009078    0.792712    
#> 014: 0.423607    0.689819    3.379989    0.201436    0.055207    0.008624    0.807766    
#> 015: 0.428742    0.719563    3.386728    0.191364    0.058814    0.008193    0.779353    
#> 016: 0.411489    0.741190    3.381149    0.181796    0.070819    0.008124    0.781616    
#> 017: 0.397017    0.736620    3.382047    0.172706    0.067278    0.007718    0.765788    
#> 018: 0.419988    0.731565    3.370516    0.164071    0.064123    0.007332    0.783783    
#> 019: 0.358345    0.731043    3.366967    0.155867    0.060917    0.006965    0.771063    
#> 020: 0.376905    0.749250    3.371564    0.148074    0.057871    0.006617    0.794840    
#> 021: 0.371931    0.724080    3.376786    0.140670    0.057234    0.006286    0.775090    
#> 022: 0.381170    0.734116    3.378538    0.133637    0.061032    0.005972    0.770703    
#> 023: 0.441727    0.723417    3.387647    0.126955    0.067796    0.005673    0.797889    
#> 024: 0.438306    0.733226    3.379703    0.120607    0.064406    0.005390    0.815178    
#> 025: 0.416752    0.710459    3.376861    0.114577    0.061186    0.005120    0.799146    
#> 026: 0.389947    0.743338    3.371385    0.108848    0.058127    0.004864    0.797160    
#> 027: 0.362813    0.771544    3.368570    0.103406    0.055220    0.004621    0.797639    
#> 028: 0.406710    0.753050    3.368361    0.098235    0.056398    0.004390    0.776481    
#> 029: 0.406888    0.742006    3.365529    0.118438    0.064359    0.004205    0.778723    
#> 030: 0.411966    0.763393    3.361877    0.112516    0.061141    0.003994    0.792314    
#> 031: 0.410203    0.735385    3.371562    0.106890    0.058084    0.003795    0.788755    
#> 032: 0.377669    0.737567    3.366836    0.101545    0.055180    0.003605    0.777625    
#> 033: 0.370246    0.756345    3.362592    0.096468    0.066942    0.003425    0.772972    
#> 034: 0.404083    0.758378    3.361284    0.103257    0.063595    0.003825    0.792446    
#> 035: 0.382063    0.732704    3.365083    0.104393    0.060415    0.003633    0.771148    
#> 036: 0.377049    0.737104    3.362712    0.104786    0.063504    0.003452    0.775357    
#> 037: 0.360919    0.739457    3.367815    0.099547    0.068220    0.003279    0.790093    
#> 038: 0.380564    0.735451    3.360293    0.094569    0.070752    0.003115    0.805074    
#> 039: 0.399011    0.738164    3.371496    0.106738    0.067214    0.002959    0.794412    
#> 040: 0.395167    0.744392    3.372451    0.101401    0.063854    0.002811    0.799144    
#> 041: 0.381138    0.739660    3.368896    0.096331    0.060661    0.002896    0.782391    
#> 042: 0.408567    0.731903    3.370060    0.091515    0.058988    0.002829    0.767657    
#> 043: 0.369146    0.741126    3.362976    0.107385    0.056039    0.003557    0.764477    
#> 044: 0.351443    0.782806    3.353381    0.102016    0.053237    0.003379    0.788691    
#> 045: 0.319593    0.782923    3.345709    0.103308    0.050575    0.003210    0.804169    
#> 046: 0.368126    0.768169    3.350165    0.098142    0.056929    0.003050    0.818584    
#> 047: 0.370952    0.774374    3.348493    0.093235    0.064206    0.003832    0.784195    
#> 048: 0.367317    0.747428    3.348570    0.088573    0.066073    0.003822    0.799366    
#> 049: 0.365717    0.736065    3.366668    0.092766    0.066325    0.003631    0.812479    
#> 050: 0.445120    0.724000    3.371853    0.096373    0.068298    0.003449    0.824066    
#> 051: 0.389382    0.744771    3.369578    0.091554    0.073524    0.003868    0.798527    
#> 052: 0.414481    0.753288    3.379293    0.094936    0.069848    0.003675    0.786208    
#> 053: 0.427888    0.717978    3.386244    0.090189    0.075556    0.003528    0.794400    
#> 054: 0.374281    0.717320    3.386300    0.085679    0.071778    0.003894    0.811926    
#> 055: 0.398556    0.725668    3.381427    0.090571    0.068189    0.003854    0.797833    
#> 056: 0.398320    0.708271    3.375677    0.090130    0.076296    0.004120    0.808462    
#> 057: 0.373667    0.723848    3.382094    0.085623    0.072481    0.004549    0.824907    
#> 058: 0.381606    0.714528    3.367569    0.081342    0.068857    0.004322    0.810858    
#> 059: 0.362175    0.715844    3.373026    0.081462    0.065414    0.004639    0.803372    
#> 060: 0.364132    0.705206    3.373847    0.077389    0.072622    0.004407    0.796858    
#> 061: 0.390252    0.700076    3.372994    0.080377    0.070222    0.004187    0.816023    
#> 062: 0.383781    0.742952    3.376461    0.084208    0.079025    0.003977    0.836308    
#> 063: 0.403344    0.714183    3.373873    0.087892    0.075073    0.003778    0.828291    
#> 064: 0.394648    0.731054    3.371298    0.083498    0.071320    0.003590    0.818052    
#> 065: 0.409379    0.710553    3.370172    0.079323    0.067754    0.003410    0.815917    
#> 066: 0.384999    0.743702    3.368774    0.075357    0.064366    0.003240    0.818465    
#> 067: 0.367478    0.732076    3.358787    0.071589    0.061148    0.003078    0.799738    
#> 068: 0.329516    0.768417    3.366190    0.081339    0.062140    0.002924    0.823064    
#> 069: 0.336756    0.753261    3.356572    0.098911    0.061381    0.002778    0.802838    
#> 070: 0.370564    0.737486    3.359125    0.093966    0.067247    0.002639    0.798430    
#> 071: 0.370645    0.743233    3.354600    0.089806    0.075746    0.002643    0.828025    
#> 072: 0.335572    0.718722    3.357974    0.085316    0.071958    0.002511    0.811024    
#> 073: 0.365720    0.743076    3.369453    0.092584    0.068360    0.002710    0.801327    
#> 074: 0.338277    0.751671    3.368908    0.087954    0.068973    0.002781    0.791129    
#> 075: 0.371914    0.726654    3.383308    0.083557    0.065524    0.002642    0.789888    
#> 076: 0.400915    0.749848    3.386674    0.097935    0.064594    0.002510    0.802813    
#> 077: 0.431177    0.730100    3.381791    0.093038    0.061364    0.002927    0.807765    
#> 078: 0.415705    0.730736    3.384757    0.088387    0.058296    0.002911    0.802075    
#> 079: 0.442315    0.746937    3.393994    0.083967    0.081573    0.002863    0.824348    
#> 080: 0.442697    0.732757    3.390134    0.079769    0.079788    0.003234    0.832023    
#> 081: 0.422662    0.734388    3.386797    0.082517    0.075798    0.003613    0.795971    
#> 082: 0.404535    0.726259    3.392575    0.080539    0.087029    0.003433    0.827347    
#> 083: 0.403033    0.731208    3.392758    0.084295    0.082678    0.003261    0.810633    
#> 084: 0.427593    0.722442    3.389886    0.091140    0.078544    0.003098    0.791841    
#> 085: 0.399055    0.744264    3.384229    0.086583    0.074617    0.003775    0.808095    
#> 086: 0.391142    0.723155    3.377423    0.082254    0.070886    0.004132    0.794645    
#> 087: 0.378829    0.732104    3.371185    0.097336    0.069526    0.004481    0.799052    
#> 088: 0.336884    0.725562    3.370835    0.096434    0.073814    0.005475    0.801202    
#> 089: 0.385907    0.736183    3.365348    0.101099    0.070124    0.005535    0.780491    
#> 090: 0.363856    0.746015    3.369419    0.096044    0.075092    0.005258    0.795512    
#> 091: 0.360269    0.738702    3.354848    0.094967    0.075460    0.004995    0.776890    
#> 092: 0.339105    0.771575    3.351646    0.099783    0.077218    0.004746    0.787999    
#> 093: 0.344099    0.735650    3.353246    0.094794    0.073357    0.004868    0.798083    
#> 094: 0.342535    0.748728    3.351778    0.090054    0.069828    0.004624    0.805442    
#> 095: 0.354847    0.758582    3.364595    0.085551    0.078128    0.004393    0.798204    
#> 096: 0.338327    0.745269    3.359757    0.081274    0.079613    0.004174    0.789558    
#> 097: 0.356919    0.762941    3.363124    0.077210    0.078231    0.003965    0.787663    
#> 098: 0.353384    0.771788    3.365587    0.084566    0.074320    0.003767    0.810274    
#> 099: 0.365151    0.739853    3.353601    0.089521    0.078501    0.003578    0.793708    
#> 100: 0.345631    0.760319    3.348322    0.093910    0.074576    0.003487    0.798816    
#> 101: 0.328288    0.748094    3.335763    0.089214    0.070847    0.003313    0.801728    
#> 102: 0.310604    0.751893    3.328254    0.092168    0.067305    0.003147    0.807728    
#> 103: 0.331707    0.766162    3.339927    0.098204    0.069906    0.002990    0.803077    
#> 104: 0.356713    0.761284    3.352434    0.101171    0.070637    0.002840    0.791987    
#> 105: 0.374849    0.733596    3.360199    0.096112    0.067753    0.002698    0.813394    
#> 106: 0.398549    0.750686    3.367134    0.091307    0.064365    0.002563    0.804078    
#> 107: 0.398470    0.745593    3.367565    0.086741    0.061147    0.002435    0.812601    
#> 108: 0.376661    0.741192    3.361013    0.082404    0.061474    0.002313    0.801428    
#> 109: 0.339081    0.747397    3.367217    0.078284    0.058400    0.002198    0.815273    
#> 110: 0.343305    0.732911    3.358733    0.074370    0.071701    0.002088    0.790968    
#> 111: 0.363118    0.756108    3.361774    0.070651    0.068115    0.001983    0.787268    
#> 112: 0.352917    0.736982    3.361108    0.067119    0.064710    0.001884    0.800253    
#> 113: 0.356023    0.764057    3.358791    0.076016    0.065261    0.001790    0.768718    
#> 114: 0.349780    0.764148    3.358134    0.090791    0.061998    0.001701    0.796798    
#> 115: 0.404826    0.733219    3.363616    0.088547    0.058898    0.001616    0.828258    
#> 116: 0.383431    0.746855    3.361241    0.084120    0.068495    0.001999    0.828395    
#> 117: 0.372374    0.771366    3.357808    0.081231    0.079213    0.001900    0.815060    
#> 118: 0.374721    0.762426    3.352842    0.077170    0.084383    0.001805    0.827031    
#> 119: 0.363916    0.750488    3.356804    0.073311    0.080164    0.001714    0.823320    
#> 120: 0.371228    0.740917    3.353961    0.069646    0.076156    0.001629    0.821029    
#> 121: 0.365871    0.799152    3.352479    0.066163    0.075941    0.001547    0.816294    
#> 122: 0.368389    0.736563    3.356319    0.062855    0.083081    0.001470    0.810291    
#> 123: 0.383641    0.752118    3.357545    0.076429    0.078927    0.001396    0.812950    
#> 124: 0.373450    0.763743    3.356158    0.072608    0.079501    0.001326    0.815712    
#> 125: 0.383369    0.781517    3.348653    0.068978    0.075526    0.001260    0.794181    
#> 126: 0.350708    0.762484    3.346511    0.065529    0.071750    0.001293    0.794666    
#> 127: 0.358938    0.753859    3.346010    0.072414    0.068162    0.001229    0.796370    
#> 128: 0.347196    0.763846    3.352240    0.068794    0.072481    0.001167    0.810784    
#> 129: 0.370617    0.777026    3.350399    0.065354    0.075967    0.001121    0.831085    
#> 130: 0.357800    0.785919    3.346497    0.062086    0.081351    0.001065    0.804861    
#> 131: 0.342305    0.756360    3.342209    0.068081    0.077283    0.001012    0.802574    
#> 132: 0.307287    0.761440    3.336739    0.064677    0.073419    0.000961    0.831531    
#> 133: 0.323209    0.744100    3.339789    0.070085    0.069748    0.000913    0.842602    
#> 134: 0.334330    0.742039    3.342313    0.066581    0.069598    0.001116    0.828096    
#> 135: 0.326128    0.747659    3.340685    0.063252    0.086756    0.001060    0.825178    
#> 136: 0.309430    0.742999    3.341495    0.060089    0.082418    0.001007    0.810516    
#> 137: 0.325500    0.749307    3.347889    0.060197    0.078297    0.000957    0.822585    
#> 138: 0.357622    0.760193    3.353073    0.063506    0.074382    0.000909    0.809679    
#> 139: 0.342872    0.763613    3.352522    0.064518    0.070663    0.001082    0.802626    
#> 140: 0.358544    0.764849    3.357831    0.073417    0.067130    0.001363    0.813444    
#> 141: 0.343961    0.742422    3.358377    0.069746    0.072661    0.001295    0.815933    
#> 142: 0.356921    0.720488    3.362012    0.066259    0.081519    0.001230    0.824266    
#> 143: 0.361640    0.756626    3.364104    0.062946    0.077443    0.001263    0.831022    
#> 144: 0.393899    0.742004    3.366147    0.066467    0.073571    0.001200    0.805423    
#> 145: 0.365883    0.750748    3.366078    0.063143    0.069892    0.001293    0.800848    
#> 146: 0.362830    0.746766    3.368265    0.059986    0.073839    0.001228    0.799342    
#> 147: 0.328520    0.747714    3.369384    0.063521    0.070147    0.001167    0.801998    
#> 148: 0.352616    0.740914    3.366937    0.062405    0.066640    0.001108    0.793565    
#> 149: 0.362323    0.729901    3.368616    0.072727    0.063308    0.001053    0.793152    
#> 150: 0.394836    0.727624    3.370905    0.069783    0.069711    0.001000    0.824004    
#> 151: 0.340494    0.773884    3.363204    0.083197    0.066225    0.000950    0.825817    
#> 152: 0.365917    0.765692    3.363904    0.082182    0.057249    0.000655    0.805211    
#> 153: 0.374759    0.766011    3.362749    0.089076    0.058307    0.000529    0.805734    
#> 154: 0.394627    0.746610    3.366135    0.080190    0.063800    0.000497    0.804292    
#> 155: 0.364631    0.744177    3.363742    0.057144    0.080678    0.000570    0.795413    
#> 156: 0.372434    0.740934    3.370117    0.059356    0.083361    0.000494    0.799619    
#> 157: 0.382589    0.699216    3.374974    0.068977    0.096187    0.000362    0.812312    
#> 158: 0.392963    0.748027    3.374389    0.051893    0.066158    0.000351    0.810122    
#> 159: 0.370561    0.745296    3.374917    0.060395    0.070335    0.000319    0.807821    
#> 160: 0.396572    0.715347    3.378997    0.070197    0.062831    0.000276    0.811666    
#> 161: 0.367382    0.733930    3.379789    0.058026    0.076527    0.000269    0.807036    
#> 162: 0.384371    0.755639    3.376499    0.067427    0.077925    0.000182    0.801659    
#> 163: 0.409596    0.732055    3.376603    0.070650    0.083426    0.000145    0.804809    
#> 164: 0.390749    0.714546    3.374846    0.068251    0.085013    0.000135    0.806722    
#> 165: 0.410991    0.705744    3.379294    0.062224    0.081811    0.000123    0.809183    
#> 166: 0.417888    0.742731    3.378496    0.066916    0.079726    0.000113    0.804319    
#> 167: 0.407390    0.743443    3.380046    0.059629    0.071716    0.000093    0.801667    
#> 168: 0.420977    0.739124    3.381793    0.060774    0.074461    0.000086    0.805234    
#> 169: 0.400313    0.783104    3.379918    0.062565    0.078763    0.000059    0.852890    
#> 170: 0.399274    0.732061    3.378785    0.062427    0.080820    0.000039    0.815912    
#> 171: 0.390672    0.726727    3.378734    0.062270    0.070071    0.000026    0.799432    
#> 172: 0.377950    0.741949    3.378999    0.046486    0.076664    0.000015    0.818427    
#> 173: 0.372545    0.749014    3.379005    0.054201    0.065842    0.000016    0.809134    
#> 174: 0.391589    0.713056    3.379298    0.075555    0.055384    0.000017    0.819474    
#> 175: 0.385383    0.728952    3.378496    0.065122    0.064141    0.000016    0.810441    
#> 176: 0.407285    0.744498    3.377400    0.063408    0.077482    0.000012    0.806916    
#> 177: 0.396031    0.729272    3.377446    0.059536    0.053879    0.000010    0.803097    
#> 178: 0.399873    0.713336    3.377794    0.054433    0.062234    0.000013    0.804476    
#> 179: 0.402005    0.749744    3.377365    0.042611    0.074397    0.000009    0.817005    
#> 180: 0.393533    0.744088    3.377852    0.052096    0.069689    0.000006    0.815817    
#> 181: 0.385688    0.715999    3.377414    0.058773    0.068326    0.000005    0.814424    
#> 182: 0.365315    0.725571    3.376886    0.053720    0.065684    0.000005    0.828691    
#> 183: 0.374394    0.745324    3.376476    0.063437    0.061148    0.000004    0.815778    
#> 184: 0.371238    0.720993    3.376391    0.059760    0.086549    0.000004    0.809809    
#> 185: 0.367875    0.744656    3.376062    0.058046    0.088800    0.000004    0.785482    
#> 186: 0.382457    0.746697    3.376606    0.046133    0.090652    0.000005    0.827203    
#> 187: 0.384924    0.708175    3.377024    0.052995    0.081740    0.000004    0.829217    
#> 188: 0.370639    0.755755    3.376405    0.044650    0.076064    0.000005    0.821002    
#> 189: 0.409275    0.778286    3.376149    0.054476    0.064049    0.000005    0.819720    
#> 190: 0.388406    0.743171    3.376247    0.060268    0.060412    0.000005    0.824655    
#> 191: 0.367867    0.745727    3.375787    0.069955    0.062425    0.000005    0.813482    
#> 192: 0.377659    0.731949    3.376137    0.068426    0.053380    0.000004    0.808767    
#> 193: 0.395517    0.737436    3.376254    0.068092    0.064252    0.000003    0.794228    
#> 194: 0.374760    0.714831    3.375791    0.061901    0.061269    0.000004    0.810223    
#> 195: 0.362997    0.721956    3.375663    0.051414    0.062387    0.000005    0.815359    
#> 196: 0.392602    0.726159    3.375881    0.051999    0.066797    0.000005    0.828438    
#> 197: 0.376110    0.745299    3.376633    0.059378    0.070564    0.000005    0.802640    
#> 198: 0.408128    0.712340    3.376168    0.052553    0.082794    0.000006    0.794700    
#> 199: 0.376761    0.731045    3.376147    0.053344    0.071380    0.000005    0.809977    
#> 200: 0.377070    0.731557    3.375898    0.058708    0.075354    0.000004    0.809034    
#> 201: 0.384171    0.718642    3.376057    0.062096    0.075203    0.000005    0.802278    
#> 202: 0.385238    0.723052    3.376144    0.060280    0.072614    0.000005    0.802122    
#> 203: 0.389090    0.722523    3.376191    0.057312    0.073850    0.000005    0.807246    
#> 204: 0.395866    0.720631    3.376241    0.055803    0.074990    0.000005    0.807558    
#> 205: 0.398588    0.724188    3.376226    0.058674    0.072653    0.000006    0.810094    
#> 206: 0.399693    0.728008    3.376244    0.061335    0.072314    0.000006    0.813102    
#> 207: 0.397648    0.727525    3.376192    0.062244    0.074538    0.000006    0.813982    
#> 208: 0.398053    0.728785    3.376132    0.062349    0.075625    0.000006    0.811975    
#> 209: 0.398958    0.727726    3.376102    0.062472    0.075006    0.000006    0.810973    
#> 210: 0.400318    0.726897    3.376132    0.061847    0.075064    0.000006    0.809541    
#> 211: 0.399847    0.729704    3.376152    0.061585    0.075670    0.000005    0.810697    
#> 212: 0.399065    0.729720    3.376150    0.062046    0.075915    0.000005    0.810239    
#> 213: 0.400830    0.728280    3.376116    0.063001    0.075427    0.000005    0.811651    
#> 214: 0.402464    0.728506    3.376063    0.063496    0.074743    0.000005    0.811057    
#> 215: 0.402380    0.729217    3.376040    0.063425    0.074930    0.000005    0.810311    
#> 216: 0.402517    0.728561    3.376032    0.062495    0.076009    0.000005    0.811873    
#> 217: 0.402372    0.729668    3.375995    0.061278    0.076462    0.000005    0.811961    
#> 218: 0.402343    0.730129    3.375958    0.061274    0.077230    0.000005    0.811401    
#> 219: 0.402293    0.729065    3.375915    0.061461    0.077474    0.000005    0.811070    
#> 220: 0.400765    0.728742    3.375907    0.061560    0.077886    0.000005    0.810638    
#> 221: 0.400206    0.729761    3.375879    0.061080    0.078403    0.000005    0.810005    
#> 222: 0.399629    0.729662    3.375856    0.061189    0.079170    0.000005    0.809819    
#> 223: 0.400666    0.729311    3.375838    0.060911    0.078904    0.000005    0.809981    
#> 224: 0.401686    0.729714    3.375836    0.061255    0.078444    0.000005    0.810535    
#> 225: 0.402472    0.727809    3.375842    0.060791    0.078115    0.000005    0.810957    
#> 226: 0.402828    0.726851    3.375827    0.060337    0.078112    0.000005    0.811311    
#> 227: 0.401551    0.726554    3.375824    0.060281    0.078475    0.000005    0.811457    
#> 228: 0.400353    0.727571    3.375811    0.059607    0.078253    0.000005    0.811942    
#> 229: 0.400063    0.727640    3.375814    0.059276    0.077979    0.000005    0.811442    
#> 230: 0.399789    0.727083    3.375815    0.059017    0.077896    0.000005    0.811227    
#> 231: 0.399927    0.727376    3.375815    0.059352    0.078330    0.000005    0.811300    
#> 232: 0.398453    0.727426    3.375817    0.059242    0.078696    0.000005    0.811344    
#> 233: 0.398138    0.727392    3.375821    0.059305    0.078887    0.000004    0.811310    
#> 234: 0.397060    0.727932    3.375829    0.059114    0.078568    0.000004    0.811524    
#> 235: 0.396577    0.727582    3.375829    0.059017    0.078383    0.000004    0.811608    
#> 236: 0.395901    0.728098    3.375833    0.059253    0.078313    0.000004    0.811964    
#> 237: 0.396109    0.728068    3.375840    0.058941    0.078111    0.000004    0.812931    
#> 238: 0.396188    0.728259    3.375845    0.058634    0.077951    0.000004    0.813225    
#> 239: 0.395899    0.729019    3.375841    0.058406    0.077634    0.000004    0.813194    
#> 240: 0.396126    0.728669    3.375845    0.058150    0.077594    0.000004    0.813439    
#> 241: 0.396249    0.727632    3.375850    0.057989    0.077555    0.000004    0.813561    
#> 242: 0.396145    0.727626    3.375850    0.058061    0.077538    0.000004    0.813606    
#> 243: 0.395686    0.727946    3.375853    0.057881    0.077479    0.000004    0.813817    
#> 244: 0.395399    0.727944    3.375855    0.058300    0.077103    0.000004    0.813709    
#> 245: 0.395412    0.727693    3.375847    0.058477    0.076788    0.000004    0.813918    
#> 246: 0.395082    0.727591    3.375854    0.058762    0.076757    0.000004    0.813719    
#> 247: 0.394262    0.727011    3.375865    0.058866    0.076756    0.000004    0.813924    
#> 248: 0.393880    0.727511    3.375868    0.058872    0.076587    0.000004    0.813713    
#> 249: 0.393605    0.728178    3.375876    0.058805    0.076603    0.000004    0.813821    
#> 250: 0.394225    0.728733    3.375875    0.058857    0.076585    0.000004    0.813899    
#> 251: 0.394461    0.729301    3.375873    0.058898    0.076533    0.000004    0.814016    
#> 252: 0.394839    0.729742    3.375879    0.058597    0.076474    0.000004    0.814396    
#> 253: 0.394611    0.729765    3.375889    0.058578    0.076196    0.000004    0.814571    
#> 254: 0.394675    0.730016    3.375898    0.058675    0.075917    0.000004    0.814362    
#> 255: 0.394480    0.730279    3.375907    0.058909    0.075730    0.000004    0.814013    
#> 256: 0.394705    0.730111    3.375912    0.058825    0.075549    0.000004    0.814076    
#> 257: 0.394407    0.729838    3.375906    0.058877    0.075667    0.000004    0.813974    
#> 258: 0.394580    0.729314    3.375899    0.058792    0.075769    0.000004    0.813912    
#> 259: 0.394728    0.729048    3.375893    0.059084    0.075642    0.000004    0.813926    
#> 260: 0.394333    0.729278    3.375897    0.059338    0.075704    0.000004    0.813511    
#> 261: 0.394124    0.729035    3.375900    0.059483    0.075576    0.000004    0.813302    
#> 262: 0.394705    0.728934    3.375899    0.059397    0.075466    0.000004    0.813508    
#> 263: 0.394354    0.729298    3.375896    0.059139    0.075641    0.000004    0.813734    
#> 264: 0.394701    0.729256    3.375892    0.059118    0.075688    0.000004    0.814119    
#> 265: 0.395033    0.729150    3.375891    0.059220    0.075556    0.000004    0.814259    
#> 266: 0.395567    0.729428    3.375885    0.059266    0.075473    0.000004    0.814341    
#> 267: 0.395306    0.729460    3.375883    0.059151    0.075529    0.000004    0.814556    
#> 268: 0.395096    0.729170    3.375870    0.059312    0.075571    0.000004    0.814970    
#> 269: 0.395401    0.729025    3.375862    0.059411    0.075658    0.000004    0.814850    
#> 270: 0.396153    0.729261    3.375851    0.059564    0.075506    0.000004    0.814759    
#> 271: 0.396395    0.729266    3.375845    0.059705    0.075314    0.000004    0.814806    
#> 272: 0.396801    0.729084    3.375839    0.059879    0.075228    0.000004    0.814787    
#> 273: 0.397075    0.729437    3.375836    0.060036    0.075095    0.000004    0.814861    
#> 274: 0.396982    0.729542    3.375837    0.060038    0.075242    0.000004    0.814870    
#> 275: 0.396962    0.729792    3.375829    0.060111    0.075267    0.000004    0.814960    
#> 276: 0.396925    0.729434    3.375838    0.060197    0.075264    0.000004    0.814916    
#> 277: 0.396609    0.729513    3.375846    0.060180    0.075211    0.000004    0.814744    
#> 278: 0.396474    0.729448    3.375851    0.060141    0.075092    0.000004    0.814838    
#> 279: 0.396015    0.729419    3.375854    0.059962    0.075113    0.000004    0.815099    
#> 280: 0.395681    0.729676    3.375858    0.059896    0.074950    0.000004    0.815094    
#> 281: 0.395002    0.729716    3.375861    0.059724    0.074861    0.000004    0.815214    
#> 282: 0.394957    0.730079    3.375867    0.059741    0.074813    0.000004    0.815465    
#> 283: 0.395033    0.730261    3.375874    0.059706    0.074782    0.000004    0.815607    
#> 284: 0.394854    0.729907    3.375878    0.059635    0.074763    0.000004    0.815446    
#> 285: 0.394995    0.729871    3.375874    0.059654    0.074649    0.000004    0.815330    
#> 286: 0.395186    0.730113    3.375875    0.059667    0.074508    0.000004    0.815079    
#> 287: 0.395178    0.730139    3.375872    0.059693    0.074310    0.000004    0.815023    
#> 288: 0.395112    0.730265    3.375868    0.059690    0.074449    0.000004    0.814939    
#> 289: 0.395310    0.730197    3.375863    0.059820    0.074394    0.000004    0.814980    
#> 290: 0.395198    0.730329    3.375858    0.059861    0.074436    0.000004    0.815116    
#> 291: 0.395340    0.730524    3.375858    0.059779    0.074511    0.000004    0.815037    
#> 292: 0.395303    0.730549    3.375856    0.059831    0.074477    0.000004    0.815005    
#> 293: 0.395339    0.730503    3.375853    0.059847    0.074485    0.000004    0.814997    
#> 294: 0.394950    0.730464    3.375846    0.059840    0.074488    0.000004    0.814863    
#> 295: 0.395023    0.730182    3.375837    0.059746    0.074480    0.000004    0.814783    
#> 296: 0.395095    0.729855    3.375834    0.059725    0.074436    0.000004    0.814885    
#> 297: 0.395137    0.729928    3.375837    0.059712    0.074323    0.000004    0.814920    
#> 298: 0.395250    0.729759    3.375839    0.059805    0.074275    0.000004    0.814908    
#> 299: 0.395313    0.729885    3.375838    0.059937    0.074159    0.000004    0.814815    
#> 300: 0.395154    0.729910    3.375838    0.060030    0.073961    0.000004    0.814705    
#> 301: 0.395243    0.730001    3.375835    0.060030    0.073848    0.000004    0.814466    
#> 302: 0.395196    0.730203    3.375827    0.060172    0.073808    0.000004    0.814443    
#> 303: 0.395098    0.730383    3.375826    0.060202    0.073741    0.000004    0.814333    
#> 304: 0.395187    0.730560    3.375823    0.060153    0.073761    0.000004    0.814283    
#> 305: 0.395131    0.730302    3.375823    0.060115    0.073769    0.000004    0.814241    
#> 306: 0.394947    0.730403    3.375822    0.060245    0.073678    0.000004    0.814246    
#> 307: 0.394941    0.730362    3.375817    0.060219    0.073516    0.000004    0.814530    
#> 308: 0.394754    0.730200    3.375816    0.060416    0.073483    0.000004    0.814676    
#> 309: 0.394877    0.729936    3.375812    0.060597    0.073441    0.000004    0.814601    
#> 310: 0.395072    0.729713    3.375807    0.060599    0.073546    0.000004    0.814585    
#> 311: 0.395236    0.729611    3.375803    0.060603    0.073480    0.000004    0.814541    
#> 312: 0.395198    0.729493    3.375799    0.060564    0.073400    0.000004    0.814491    
#> 313: 0.394963    0.729341    3.375795    0.060617    0.073418    0.000004    0.814361    
#> 314: 0.394734    0.729498    3.375792    0.060661    0.073510    0.000004    0.814155    
#> 315: 0.394471    0.729554    3.375791    0.060671    0.073565    0.000004    0.814213    
#> 316: 0.394419    0.729650    3.375790    0.060661    0.073628    0.000004    0.814109    
#> 317: 0.394311    0.729739    3.375788    0.060678    0.073665    0.000004    0.814220    
#> 318: 0.394325    0.729786    3.375785    0.060680    0.073567    0.000004    0.814332    
#> 319: 0.394247    0.729807    3.375784    0.060649    0.073452    0.000004    0.814457    
#> 320: 0.393900    0.729787    3.375781    0.060586    0.073484    0.000004    0.814497    
#> 321: 0.393707    0.729787    3.375775    0.060590    0.073489    0.000004    0.814532    
#> 322: 0.393816    0.729788    3.375771    0.060596    0.073635    0.000004    0.814396    
#> 323: 0.393571    0.729756    3.375766    0.060614    0.073655    0.000004    0.814468    
#> 324: 0.393709    0.729805    3.375766    0.060626    0.073605    0.000004    0.814551    
#> 325: 0.393587    0.730051    3.375763    0.060629    0.073552    0.000004    0.814491    
#> 326: 0.393456    0.729757    3.375758    0.060633    0.073554    0.000004    0.814493    
#> 327: 0.393391    0.729839    3.375757    0.060644    0.073610    0.000004    0.814463    
#> 328: 0.393371    0.729919    3.375755    0.060713    0.073539    0.000004    0.814369    
#> 329: 0.393383    0.729994    3.375754    0.060870    0.073542    0.000004    0.814351    
#> 330: 0.393137    0.729993    3.375752    0.060903    0.073551    0.000004    0.814491    
#> 331: 0.393149    0.730018    3.375749    0.060897    0.073583    0.000004    0.814530    
#> 332: 0.393180    0.729916    3.375752    0.060875    0.073614    0.000004    0.814454    
#> 333: 0.393218    0.729842    3.375756    0.060855    0.073597    0.000004    0.814478    
#> 334: 0.393143    0.729758    3.375758    0.060798    0.073638    0.000004    0.814514    
#> 335: 0.392953    0.729820    3.375758    0.060754    0.073564    0.000004    0.814509    
#> 336: 0.392847    0.729825    3.375757    0.060801    0.073522    0.000004    0.814380    
#> 337: 0.392846    0.730125    3.375755    0.060783    0.073511    0.000004    0.814336    
#> 338: 0.393020    0.730222    3.375757    0.060766    0.073546    0.000004    0.814352    
#> 339: 0.393066    0.730260    3.375757    0.060832    0.073524    0.000004    0.814356    
#> 340: 0.393128    0.730127    3.375760    0.060830    0.073594    0.000004    0.814531    
#> 341: 0.393278    0.730210    3.375762    0.060801    0.073625    0.000004    0.814596    
#> 342: 0.393208    0.730169    3.375761    0.060723    0.073578    0.000004    0.814461    
#> 343: 0.392995    0.730254    3.375763    0.060818    0.073493    0.000004    0.814321    
#> 344: 0.393099    0.730262    3.375766    0.060900    0.073631    0.000004    0.814116    
#> 345: 0.393121    0.730317    3.375770    0.060914    0.073773    0.000004    0.814090    
#> 346: 0.393163    0.730481    3.375771    0.060992    0.073833    0.000004    0.813991    
#> 347: 0.393054    0.730546    3.375769    0.060957    0.073871    0.000004    0.814026    
#> 348: 0.392810    0.730567    3.375769    0.060933    0.073879    0.000004    0.813988    
#> 349: 0.392801    0.730527    3.375766    0.060851    0.073959    0.000004    0.813944    
#> 350: 0.392677    0.730442    3.375765    0.060868    0.073997    0.000004    0.813962    
#> 351: 0.392644    0.730545    3.375763    0.060814    0.073939    0.000004    0.813934    
#> 352: 0.392425    0.730642    3.375764    0.060794    0.073915    0.000004    0.813856    
#> 353: 0.392449    0.730806    3.375765    0.060801    0.073813    0.000004    0.813806    
#> 354: 0.392526    0.730892    3.375763    0.060729    0.073767    0.000004    0.813907    
#> 355: 0.392890    0.730768    3.375759    0.060753    0.073785    0.000004    0.813971    
#> 356: 0.392886    0.730711    3.375757    0.060853    0.073793    0.000004    0.814047    
#> 357: 0.393094    0.730765    3.375755    0.060872    0.073819    0.000004    0.813949    
#> 358: 0.393126    0.730813    3.375758    0.060887    0.073869    0.000004    0.813878    
#> 359: 0.393091    0.731001    3.375758    0.060871    0.073884    0.000004    0.813885    
#> 360: 0.393021    0.731084    3.375757    0.060921    0.073884    0.000004    0.813837    
#> 361: 0.392822    0.731093    3.375755    0.061025    0.073911    0.000004    0.813706    
#> 362: 0.392887    0.731127    3.375755    0.061100    0.073925    0.000004    0.813636    
#> 363: 0.392855    0.731074    3.375755    0.061089    0.073881    0.000004    0.813638    
#> 364: 0.392899    0.731184    3.375754    0.061059    0.073949    0.000004    0.813650    
#> 365: 0.392783    0.731245    3.375755    0.061126    0.073934    0.000004    0.813707    
#> 366: 0.392705    0.731188    3.375753    0.061102    0.073804    0.000004    0.813730    
#> 367: 0.392681    0.731192    3.375752    0.061144    0.073701    0.000004    0.813762    
#> 368: 0.392754    0.731256    3.375751    0.061088    0.073741    0.000004    0.813665    
#> 369: 0.392683    0.731306    3.375751    0.060995    0.073795    0.000004    0.813688    
#> 370: 0.392686    0.731422    3.375752    0.060995    0.073893    0.000004    0.813730    
#> 371: 0.392753    0.731438    3.375751    0.060977    0.073894    0.000004    0.813725    
#> 372: 0.392667    0.731465    3.375752    0.060974    0.073906    0.000004    0.813732    
#> 373: 0.392492    0.731543    3.375750    0.060966    0.073914    0.000004    0.813760    
#> 374: 0.392433    0.731582    3.375746    0.060984    0.073897    0.000004    0.813735    
#> 375: 0.392407    0.731616    3.375745    0.061026    0.073938    0.000004    0.813728    
#> 376: 0.392380    0.731677    3.375744    0.061001    0.073947    0.000004    0.813617    
#> 377: 0.392446    0.731748    3.375741    0.060908    0.073965    0.000004    0.813611    
#> 378: 0.392253    0.731630    3.375738    0.060849    0.073929    0.000004    0.813605    
#> 379: 0.392157    0.731485    3.375740    0.060741    0.073888    0.000004    0.813597    
#> 380: 0.391921    0.731473    3.375740    0.060720    0.073873    0.000004    0.813533    
#> 381: 0.391789    0.731463    3.375739    0.060739    0.073870    0.000004    0.813452    
#> 382: 0.391802    0.731365    3.375741    0.060784    0.073896    0.000004    0.813406    
#> 383: 0.391871    0.731379    3.375742    0.060744    0.073957    0.000004    0.813363    
#> 384: 0.391912    0.731300    3.375743    0.060700    0.073930    0.000004    0.813400    
#> 385: 0.391902    0.731282    3.375744    0.060670    0.073901    0.000004    0.813455    
#> 386: 0.392171    0.731425    3.375746    0.060659    0.073941    0.000004    0.813530    
#> 387: 0.392117    0.731523    3.375749    0.060657    0.073950    0.000004    0.813432    
#> 388: 0.392085    0.731570    3.375752    0.060655    0.073964    0.000004    0.813465    
#> 389: 0.392062    0.731398    3.375754    0.060672    0.074055    0.000004    0.813489    
#> 390: 0.391899    0.731377    3.375754    0.060651    0.074009    0.000004    0.813553    
#> 391: 0.391928    0.731369    3.375754    0.060701    0.073972    0.000004    0.813599    
#> 392: 0.391971    0.731457    3.375756    0.060724    0.073954    0.000004    0.813572    
#> 393: 0.391981    0.731433    3.375756    0.060718    0.073958    0.000004    0.813587    
#> 394: 0.391990    0.731452    3.375757    0.060794    0.073932    0.000004    0.813522    
#> 395: 0.392120    0.731480    3.375759    0.060823    0.073971    0.000004    0.813431    
#> 396: 0.392166    0.731567    3.375759    0.060781    0.074002    0.000004    0.813389    
#> 397: 0.392174    0.731532    3.375758    0.060742    0.073991    0.000004    0.813351    
#> 398: 0.392231    0.731377    3.375758    0.060680    0.073925    0.000004    0.813403    
#> 399: 0.392283    0.731410    3.375760    0.060643    0.073961    0.000004    0.813427    
#> 400: 0.392336    0.731565    3.375762    0.060569    0.073940    0.000004    0.813485    
#> 401: 0.392371    0.731728    3.375763    0.060550    0.073947    0.000004    0.813550    
#> 402: 0.392413    0.731850    3.375765    0.060554    0.073984    0.000004    0.813707    
#> 403: 0.392549    0.731856    3.375767    0.060548    0.074007    0.000004    0.813792    
#> 404: 0.392658    0.731901    3.375769    0.060621    0.074014    0.000004    0.813708    
#> 405: 0.392579    0.731965    3.375771    0.060591    0.074031    0.000004    0.813693    
#> 406: 0.392594    0.732010    3.375771    0.060622    0.074035    0.000004    0.813761    
#> 407: 0.392596    0.732033    3.375772    0.060596    0.074003    0.000004    0.813853    
#> 408: 0.392631    0.732041    3.375773    0.060564    0.073956    0.000004    0.813931    
#> 409: 0.392516    0.731911    3.375772    0.060549    0.073932    0.000004    0.813882    
#> 410: 0.392488    0.731957    3.375768    0.060516    0.073912    0.000004    0.813883    
#> 411: 0.392454    0.731796    3.375764    0.060477    0.073882    0.000004    0.813993    
#> 412: 0.392455    0.731836    3.375761    0.060472    0.073862    0.000004    0.814000    
#> 413: 0.392378    0.731868    3.375758    0.060512    0.073915    0.000004    0.814005    
#> 414: 0.392382    0.731962    3.375756    0.060533    0.073910    0.000004    0.813979    
#> 415: 0.392489    0.732003    3.375756    0.060578    0.073867    0.000004    0.813889    
#> 416: 0.392539    0.732071    3.375757    0.060599    0.073844    0.000004    0.813809    
#> 417: 0.392529    0.732061    3.375757    0.060583    0.073849    0.000004    0.813772    
#> 418: 0.392454    0.732027    3.375757    0.060602    0.073894    0.000004    0.813819    
#> 419: 0.392484    0.732130    3.375757    0.060617    0.073900    0.000004    0.813857    
#> 420: 0.392647    0.732206    3.375758    0.060573    0.073925    0.000004    0.813844    
#> 421: 0.392549    0.732275    3.375759    0.060570    0.073927    0.000004    0.813760    
#> 422: 0.392576    0.732257    3.375759    0.060515    0.073901    0.000004    0.813776    
#> 423: 0.392516    0.732148    3.375759    0.060515    0.073901    0.000004    0.813813    
#> 424: 0.392471    0.732093    3.375759    0.060526    0.073927    0.000004    0.813750    
#> 425: 0.392589    0.732076    3.375758    0.060484    0.073943    0.000004    0.813813    
#> 426: 0.392609    0.732151    3.375760    0.060473    0.073919    0.000004    0.813916    
#> 427: 0.392464    0.732126    3.375759    0.060456    0.073806    0.000004    0.813922    
#> 428: 0.392311    0.732173    3.375758    0.060451    0.073781    0.000004    0.813889    
#> 429: 0.392234    0.732190    3.375757    0.060378    0.073809    0.000004    0.813915    
#> 430: 0.392249    0.732237    3.375756    0.060350    0.073831    0.000004    0.813881    
#> 431: 0.392232    0.732208    3.375753    0.060345    0.073782    0.000004    0.813881    
#> 432: 0.392274    0.732337    3.375753    0.060345    0.073792    0.000004    0.813940    
#> 433: 0.392338    0.732481    3.375753    0.060301    0.073825    0.000004    0.813958    
#> 434: 0.392208    0.732437    3.375754    0.060255    0.073796    0.000004    0.814001    
#> 435: 0.392229    0.732503    3.375754    0.060253    0.073727    0.000004    0.813994    
#> 436: 0.392218    0.732468    3.375754    0.060222    0.073750    0.000004    0.814006    
#> 437: 0.392193    0.732433    3.375753    0.060232    0.073723    0.000004    0.814022    
#> 438: 0.392260    0.732515    3.375753    0.060275    0.073652    0.000004    0.814020    
#> 439: 0.392263    0.732635    3.375752    0.060300    0.073677    0.000004    0.813975    
#> 440: 0.392174    0.732664    3.375752    0.060325    0.073641    0.000004    0.814043    
#> 441: 0.392111    0.732656    3.375751    0.060422    0.073664    0.000004    0.814032    
#> 442: 0.392025    0.732817    3.375752    0.060451    0.073650    0.000004    0.814095    
#> 443: 0.391970    0.732944    3.375752    0.060450    0.073604    0.000004    0.814198    
#> 444: 0.391933    0.733030    3.375752    0.060443    0.073650    0.000004    0.814224    
#> 445: 0.391974    0.733097    3.375752    0.060423    0.073589    0.000004    0.814374    
#> 446: 0.391986    0.733122    3.375751    0.060389    0.073619    0.000004    0.814411    
#> 447: 0.392015    0.733057    3.375752    0.060388    0.073587    0.000004    0.814384    
#> 448: 0.392025    0.732979    3.375752    0.060439    0.073612    0.000004    0.814322    
#> 449: 0.392009    0.733046    3.375754    0.060444    0.073651    0.000004    0.814278    
#> 450: 0.392030    0.733007    3.375755    0.060420    0.073651    0.000004    0.814284    
#> 451: 0.391979    0.733006    3.375755    0.060415    0.073630    0.000004    0.814286    
#> 452: 0.391925    0.733087    3.375753    0.060445    0.073613    0.000004    0.814250    
#> 453: 0.391952    0.733108    3.375753    0.060457    0.073591    0.000004    0.814221    
#> 454: 0.391935    0.733190    3.375754    0.060441    0.073596    0.000004    0.814188    
#> 455: 0.391942    0.733233    3.375755    0.060399    0.073601    0.000004    0.814216    
#> 456: 0.391931    0.733242    3.375757    0.060401    0.073633    0.000004    0.814238    
#> 457: 0.391942    0.733216    3.375759    0.060393    0.073612    0.000004    0.814216    
#> 458: 0.391992    0.733368    3.375761    0.060369    0.073605    0.000004    0.814266    
#> 459: 0.391860    0.733446    3.375763    0.060355    0.073622    0.000004    0.814289    
#> 460: 0.391792    0.733458    3.375765    0.060320    0.073661    0.000004    0.814257    
#> 461: 0.391745    0.733476    3.375767    0.060294    0.073690    0.000004    0.814243    
#> 462: 0.391732    0.733528    3.375769    0.060274    0.073695    0.000004    0.814264    
#> 463: 0.391838    0.733534    3.375770    0.060268    0.073667    0.000004    0.814304    
#> 464: 0.391977    0.733522    3.375771    0.060299    0.073640    0.000004    0.814257    
#> 465: 0.391968    0.733396    3.375771    0.060335    0.073645    0.000004    0.814244    
#> 466: 0.391948    0.733443    3.375769    0.060330    0.073668    0.000004    0.814201    
#> 467: 0.391951    0.733371    3.375767    0.060413    0.073627    0.000004    0.814167    
#> 468: 0.392069    0.733384    3.375765    0.060435    0.073621    0.000004    0.814155    
#> 469: 0.392141    0.733513    3.375765    0.060422    0.073630    0.000004    0.814170    
#> 470: 0.392182    0.733631    3.375764    0.060430    0.073610    0.000004    0.814158    
#> 471: 0.392033    0.733596    3.375762    0.060450    0.073602    0.000004    0.814173    
#> 472: 0.392119    0.733556    3.375762    0.060453    0.073607    0.000004    0.814151    
#> 473: 0.392018    0.733560    3.375763    0.060483    0.073606    0.000004    0.814114    
#> 474: 0.391979    0.733541    3.375764    0.060462    0.073654    0.000004    0.814099    
#> 475: 0.392019    0.733606    3.375764    0.060434    0.073623    0.000004    0.814102    
#> 476: 0.391987    0.733550    3.375763    0.060364    0.073669    0.000004    0.814156    
#> 477: 0.391951    0.733531    3.375761    0.060343    0.073727    0.000004    0.814081    
#> 478: 0.391906    0.733548    3.375761    0.060353    0.073714    0.000004    0.814017    
#> 479: 0.391958    0.733585    3.375762    0.060380    0.073722    0.000004    0.814026    
#> 480: 0.392035    0.733594    3.375762    0.060380    0.073682    0.000004    0.814124    
#> 481: 0.392029    0.733559    3.375763    0.060427    0.073686    0.000004    0.814107    
#> 482: 0.392131    0.733538    3.375763    0.060441    0.073728    0.000004    0.814122    
#> 483: 0.392170    0.733483    3.375763    0.060412    0.073756    0.000004    0.814171    
#> 484: 0.392247    0.733392    3.375762    0.060352    0.073763    0.000004    0.814243    
#> 485: 0.392235    0.733422    3.375763    0.060363    0.073775    0.000004    0.814275    
#> 486: 0.392290    0.733405    3.375763    0.060403    0.073784    0.000004    0.814192    
#> 487: 0.392426    0.733524    3.375763    0.060403    0.073761    0.000004    0.814157    
#> 488: 0.392451    0.733509    3.375762    0.060416    0.073765    0.000004    0.814088    
#> 489: 0.392530    0.733486    3.375763    0.060406    0.073801    0.000004    0.814060    
#> 490: 0.392516    0.733503    3.375764    0.060357    0.073803    0.000004    0.814159    
#> 491: 0.392433    0.733610    3.375765    0.060296    0.073852    0.000004    0.814225    
#> 492: 0.392422    0.733600    3.375765    0.060261    0.073848    0.000004    0.814278    
#> 493: 0.392379    0.733617    3.375764    0.060231    0.073891    0.000004    0.814259    
#> 494: 0.392399    0.733631    3.375764    0.060239    0.073863    0.000004    0.814206    
#> 495: 0.392493    0.733599    3.375764    0.060265    0.073841    0.000004    0.814209    
#> 496: 0.392613    0.733650    3.375764    0.060249    0.073805    0.000004    0.814210    
#> 497: 0.392634    0.733632    3.375764    0.060287    0.073778    0.000004    0.814192    
#> 498: 0.392655    0.733591    3.375764    0.060353    0.073800    0.000004    0.814164    
#> 499: 0.392723    0.733652    3.375763    0.060326    0.073798    0.000004    0.814211    
#> 500: 0.392791    0.733582    3.375762    0.060347    0.073764    0.000004    0.814221    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.241612    0.983737    3.455042    0.392401    0.087250    0.016800    1.523216    
#> 002: 0.107982    1.012073    3.500891    0.372781    0.082888    0.016697    1.027087    
#> 003: 0.171397    0.979983    3.508597    0.354142    0.078744    0.016466    0.839784    
#> 004: 0.112493    1.020421    3.485356    0.336435    0.074806    0.015643    0.802092    
#> 005: 0.117624    1.033288    3.464152    0.319613    0.071066    0.014861    0.747665    
#> 006: 0.061779    1.037880    3.451784    0.303633    0.067513    0.014118    0.698119    
#> 007: 0.071407    1.043744    3.444217    0.288451    0.064137    0.014067    0.705496    
#> 008: 0.029849    1.058245    3.429632    0.274029    0.060930    0.013363    0.720273    
#> 009: -0.019425   1.060060    3.413369    0.260327    0.057884    0.012695    0.706770    
#> 010: -0.046779   1.066353    3.403571    0.247311    0.054990    0.013973    0.695874    
#> 011: 0.009856    1.082854    3.408082    0.234945    0.052240    0.017276    0.719627    
#> 012: -0.016672   1.080612    3.403398    0.223198    0.049628    0.016412    0.700097    
#> 013: -0.054548   1.087271    3.400091    0.212038    0.047147    0.017091    0.686718    
#> 014: 0.012378    1.082758    3.404491    0.201436    0.044789    0.019070    0.708621    
#> 015: 0.022281    1.077872    3.423150    0.191364    0.042550    0.020949    0.686704    
#> 016: 0.025808    1.087524    3.443832    0.181796    0.040422    0.019902    0.711843    
#> 017: 0.035535    1.072483    3.438793    0.172706    0.038401    0.025070    0.680380    
#> 018: 0.007597    1.091209    3.407711    0.164071    0.036481    0.023817    0.699858    
#> 019: -0.038283   1.100158    3.398161    0.155867    0.034657    0.022626    0.694644    
#> 020: -0.017794   1.092106    3.415804    0.148074    0.032924    0.021495    0.688169    
#> 021: 0.007896    1.080252    3.425670    0.140670    0.034129    0.021588    0.676402    
#> 022: 0.017456    1.059886    3.444413    0.140427    0.032423    0.020509    0.681119    
#> 023: 0.090365    1.056658    3.453458    0.156820    0.030801    0.019483    0.711104    
#> 024: 0.119642    1.080841    3.459524    0.148979    0.029261    0.018509    0.715688    
#> 025: 0.093496    1.053972    3.460881    0.141530    0.034967    0.018462    0.704793    
#> 026: 0.036651    1.083829    3.433387    0.134454    0.033219    0.018564    0.702850    
#> 027: 0.033875    1.089774    3.426232    0.127731    0.032282    0.018831    0.711853    
#> 028: 0.045374    1.079678    3.428816    0.124470    0.030668    0.018022    0.707229    
#> 029: 0.036553    1.065488    3.412659    0.132355    0.029134    0.017121    0.736310    
#> 030: 0.010522    1.081635    3.415480    0.155171    0.027678    0.020566    0.703909    
#> 031: 0.015079    1.076825    3.427640    0.161217    0.026294    0.019537    0.682944    
#> 032: 0.004257    1.073012    3.434384    0.153156    0.025397    0.021600    0.671530    
#> 033: 0.005191    1.084757    3.417008    0.145498    0.025304    0.020520    0.695383    
#> 034: 0.019814    1.089244    3.422966    0.153207    0.025051    0.020589    0.693377    
#> 035: -0.023807   1.057854    3.413392    0.145547    0.023799    0.020354    0.678761    
#> 036: -0.024117   1.076888    3.405702    0.155492    0.022609    0.019337    0.693762    
#> 037: -0.009139   1.076851    3.416031    0.147718    0.026507    0.020505    0.687478    
#> 038: 0.012155    1.086643    3.413707    0.140332    0.028926    0.022878    0.693276    
#> 039: 0.019702    1.074559    3.433156    0.133315    0.027479    0.024176    0.687616    
#> 040: 0.015556    1.076235    3.427597    0.139220    0.026105    0.028376    0.685443    
#> 041: -0.005723   1.075492    3.416041    0.146619    0.024800    0.026958    0.691830    
#> 042: 0.024026    1.063278    3.419109    0.139288    0.023560    0.025610    0.691500    
#> 043: 0.022171    1.073093    3.417882    0.132324    0.024202    0.024329    0.704403    
#> 044: 0.007705    1.080561    3.426162    0.125707    0.022992    0.023113    0.692951    
#> 045: -0.001144   1.091785    3.427033    0.119422    0.023278    0.023161    0.694452    
#> 046: 0.034856    1.073622    3.439803    0.113451    0.029433    0.022003    0.699728    
#> 047: 0.039863    1.072302    3.423569    0.116780    0.027962    0.020903    0.702676    
#> 048: 0.046772    1.053664    3.444015    0.110941    0.033166    0.025001    0.699906    
#> 049: 0.031353    1.045854    3.444942    0.105394    0.034551    0.023751    0.710772    
#> 050: 0.073662    1.043684    3.445276    0.111253    0.032823    0.027561    0.713057    
#> 051: 0.064692    1.045244    3.445339    0.105690    0.036668    0.026183    0.712769    
#> 052: 0.085063    1.052496    3.459232    0.100406    0.034834    0.024874    0.712563    
#> 053: 0.061689    1.051945    3.437361    0.095534    0.033093    0.025343    0.719500    
#> 054: 0.026787    1.059162    3.444818    0.090757    0.031438    0.028998    0.714424    
#> 055: 0.053214    1.053530    3.452757    0.086219    0.029866    0.027549    0.715880    
#> 056: 0.060294    1.049138    3.451923    0.083195    0.028373    0.026171    0.703337    
#> 057: 0.063898    1.042991    3.457141    0.099611    0.026954    0.024863    0.712142    
#> 058: 0.035942    1.043562    3.440657    0.094631    0.025607    0.025108    0.710762    
#> 059: 0.041030    1.047783    3.430762    0.092501    0.027443    0.024115    0.710518    
#> 060: 0.037102    1.033957    3.446448    0.096889    0.027000    0.027658    0.718704    
#> 061: 0.091501    1.036401    3.466513    0.100086    0.026997    0.034055    0.727728    
#> 062: 0.103562    1.047941    3.470915    0.095082    0.027140    0.036450    0.738238    
#> 063: 0.091270    1.031332    3.455681    0.090328    0.025783    0.034628    0.724862    
#> 064: 0.072218    1.039469    3.458563    0.085812    0.024493    0.035248    0.725893    
#> 065: 0.079688    1.044089    3.436345    0.087831    0.023269    0.033485    0.713709    
#> 066: 0.052732    1.044289    3.454422    0.083440    0.022105    0.031811    0.695283    
#> 067: 0.063571    1.048233    3.448261    0.085155    0.021000    0.030220    0.706160    
#> 068: 0.036951    1.050333    3.448272    0.099152    0.019950    0.031220    0.731573    
#> 069: 0.050832    1.065178    3.437665    0.118200    0.018953    0.037257    0.710934    
#> 070: 0.048915    1.071320    3.445373    0.117169    0.018005    0.035394    0.714460    
#> 071: 0.022187    1.079953    3.421351    0.111311    0.017105    0.034282    0.740242    
#> 072: -0.015361   1.074103    3.415747    0.105745    0.021365    0.032568    0.723924    
#> 073: 0.049194    1.074542    3.448642    0.100458    0.020297    0.030940    0.716606    
#> 074: 0.012511    1.064736    3.436948    0.095435    0.019468    0.029393    0.718630    
#> 075: 0.053902    1.052195    3.463973    0.092785    0.020452    0.027923    0.698531    
#> 076: 0.060873    1.054730    3.463815    0.088145    0.020323    0.030360    0.709587    
#> 077: 0.064836    1.056184    3.450812    0.102373    0.019759    0.028842    0.694626    
#> 078: 0.103035    1.045173    3.468479    0.097254    0.021219    0.027400    0.702683    
#> 079: 0.130517    1.063178    3.463649    0.092391    0.020158    0.029161    0.727246    
#> 080: 0.114738    1.044021    3.473330    0.087772    0.019150    0.029881    0.731879    
#> 081: 0.119339    1.017451    3.476128    0.092357    0.018193    0.028387    0.708969    
#> 082: 0.101518    1.023396    3.461944    0.128293    0.017283    0.030679    0.702070    
#> 083: 0.083554    1.013284    3.469493    0.128440    0.016419    0.031504    0.710296    
#> 084: 0.080797    1.027040    3.467040    0.122018    0.016369    0.029929    0.701558    
#> 085: 0.093526    1.031994    3.469968    0.115917    0.017883    0.028543    0.704964    
#> 086: 0.069886    1.040632    3.455178    0.116325    0.017231    0.031917    0.682059    
#> 087: 0.055770    1.049362    3.447425    0.128961    0.016369    0.030322    0.710772    
#> 088: -0.000030   1.047450    3.445479    0.146995    0.015690    0.028806    0.713727    
#> 089: 0.013597    1.069177    3.425008    0.139645    0.014905    0.027365    0.714369    
#> 090: 0.019247    1.063686    3.432640    0.132663    0.015139    0.026663    0.715275    
#> 091: 0.018815    1.049649    3.420411    0.126030    0.015008    0.025330    0.707483    
#> 092: 0.022649    1.057774    3.417957    0.134071    0.017520    0.025243    0.678268    
#> 093: 0.015043    1.058923    3.413508    0.137295    0.020429    0.026733    0.700188    
#> 094: 0.004324    1.066309    3.405352    0.164735    0.019408    0.025561    0.702806    
#> 095: 0.038632    1.069499    3.436664    0.156499    0.018437    0.025546    0.708766    
#> 096: -0.002743   1.071204    3.421585    0.148674    0.017515    0.024269    0.705781    
#> 097: 0.020955    1.083237    3.422293    0.141240    0.016640    0.028479    0.700261    
#> 098: 0.013156    1.079424    3.432938    0.135641    0.015808    0.027839    0.710519    
#> 099: 0.009284    1.075063    3.413912    0.128859    0.015017    0.031543    0.706639    
#> 100: 0.003945    1.070338    3.421688    0.122416    0.016297    0.029965    0.714996    
#> 101: 0.003257    1.054884    3.404880    0.126863    0.018909    0.028467    0.692893    
#> 102: 0.017704    1.043429    3.419845    0.126566    0.017964    0.027044    0.708584    
#> 103: 0.070708    1.042996    3.448268    0.120237    0.018850    0.028724    0.694660    
#> 104: 0.081275    1.036270    3.465658    0.114226    0.024924    0.027287    0.696966    
#> 105: 0.083235    1.026449    3.474545    0.108514    0.024486    0.025923    0.702928    
#> 106: 0.076902    1.042611    3.455417    0.103089    0.023261    0.025018    0.702892    
#> 107: 0.089087    1.060961    3.445978    0.111686    0.022098    0.023767    0.687336    
#> 108: 0.060284    1.052903    3.448772    0.106102    0.020993    0.023995    0.707811    
#> 109: 0.030138    1.055091    3.454862    0.100797    0.023054    0.026126    0.703602    
#> 110: 0.063127    1.063301    3.443861    0.095757    0.021901    0.024820    0.682891    
#> 111: 0.053709    1.070022    3.442768    0.094095    0.021019    0.023579    0.687246    
#> 112: 0.057604    1.050016    3.427253    0.098598    0.023229    0.022400    0.688464    
#> 113: 0.056285    1.076712    3.437060    0.106335    0.025510    0.021280    0.684593    
#> 114: 0.035968    1.078958    3.445657    0.115844    0.025372    0.022714    0.686774    
#> 115: 0.026238    1.057799    3.432099    0.110052    0.026578    0.022079    0.705692    
#> 116: 0.014701    1.074902    3.423902    0.106378    0.025249    0.021413    0.694406    
#> 117: -0.005240   1.082150    3.425605    0.101060    0.023986    0.023460    0.702655    
#> 118: 0.005880    1.073775    3.417942    0.096007    0.022787    0.030799    0.698497    
#> 119: 0.028884    1.061717    3.428529    0.104579    0.021648    0.032626    0.711850    
#> 120: 0.006477    1.056047    3.417707    0.118240    0.020565    0.038668    0.708814    
#> 121: 0.027540    1.069538    3.433952    0.112328    0.019537    0.037966    0.714699    
#> 122: 0.027131    1.050898    3.449992    0.106711    0.018560    0.036067    0.715658    
#> 123: 0.046329    1.057861    3.433876    0.129904    0.017707    0.034264    0.700622    
#> 124: 0.039251    1.079892    3.435220    0.153472    0.016822    0.032551    0.698733    
#> 125: 0.036211    1.080161    3.425010    0.145798    0.015981    0.030923    0.698549    
#> 126: 0.004756    1.102629    3.420214    0.138508    0.017932    0.032965    0.719717    
#> 127: 0.041189    1.083997    3.418637    0.131583    0.020269    0.032509    0.720949    
#> 128: 0.040821    1.067075    3.440833    0.125580    0.019256    0.030884    0.703361    
#> 129: 0.057827    1.089353    3.433104    0.119301    0.018293    0.029339    0.713088    
#> 130: 0.061105    1.085189    3.424584    0.133489    0.019681    0.029129    0.679317    
#> 131: 0.032893    1.082643    3.424849    0.139423    0.018697    0.028424    0.694823    
#> 132: 0.012769    1.067732    3.404316    0.137043    0.024159    0.027003    0.707245    
#> 133: 0.043442    1.062462    3.423274    0.130191    0.025886    0.025653    0.715302    
#> 134: 0.067255    1.050384    3.454318    0.123681    0.024592    0.024370    0.705940    
#> 135: 0.043666    1.036908    3.458505    0.135732    0.023362    0.028880    0.689044    
#> 136: 0.079829    1.037918    3.463126    0.128946    0.022194    0.029507    0.692216    
#> 137: 0.079766    1.033684    3.453982    0.148752    0.021084    0.028032    0.688972    
#> 138: 0.054801    1.027431    3.452531    0.141314    0.023659    0.026630    0.686832    
#> 139: 0.062529    1.052947    3.462679    0.134248    0.025104    0.025299    0.686233    
#> 140: 0.062815    1.057743    3.450964    0.127536    0.024495    0.026133    0.712045    
#> 141: 0.031565    1.048052    3.449963    0.121159    0.026453    0.025315    0.696534    
#> 142: 0.048205    1.038673    3.451654    0.123427    0.025130    0.024049    0.709681    
#> 143: 0.045202    1.056259    3.438664    0.117256    0.023873    0.026103    0.705490    
#> 144: 0.069926    1.054305    3.455247    0.111393    0.022680    0.026721    0.692451    
#> 145: 0.054728    1.065253    3.432844    0.114502    0.022960    0.025385    0.681603    
#> 146: 0.038785    1.081438    3.435232    0.113153    0.024279    0.024116    0.680739    
#> 147: 0.004656    1.064438    3.430148    0.107495    0.025493    0.022910    0.696389    
#> 148: 0.023953    1.061692    3.444163    0.102120    0.025166    0.025405    0.685886    
#> 149: 0.024932    1.054676    3.430136    0.097014    0.027488    0.025538    0.699494    
#> 150: 0.023171    1.042088    3.429484    0.092164    0.026114    0.025295    0.708961    
#> 151: -0.019789   1.081611    3.419885    0.100507    0.024808    0.026868    0.701088    
#> 152: 0.007992    1.071366    3.429478    0.140248    0.020427    0.026099    0.705056    
#> 153: 0.052251    1.088127    3.450648    0.116350    0.019988    0.034638    0.715732    
#> 154: 0.066045    1.085288    3.455412    0.106710    0.021920    0.032441    0.699650    
#> 155: 0.052706    1.057358    3.452620    0.113337    0.014162    0.029376    0.700815    
#> 156: 0.038927    1.071380    3.439567    0.112727    0.019958    0.029102    0.694762    
#> 157: 0.043973    1.060054    3.437907    0.109756    0.019713    0.031217    0.696576    
#> 158: 0.078812    1.061971    3.451057    0.099322    0.015463    0.033185    0.697837    
#> 159: 0.023929    1.080570    3.445840    0.100906    0.008959    0.031491    0.706228    
#> 160: 0.060265    1.055526    3.450103    0.090515    0.008854    0.028281    0.715359    
#> 161: 0.022863    1.050226    3.436684    0.102509    0.008354    0.030476    0.712369    
#> 162: 0.017918    1.059414    3.432587    0.102865    0.007960    0.033560    0.709581    
#> 163: 0.007128    1.052486    3.425404    0.079075    0.007924    0.030704    0.710208    
#> 164: 0.038069    1.057964    3.445711    0.058286    0.006937    0.037703    0.725513    
#> 165: 0.080220    1.063698    3.449879    0.063322    0.006589    0.035703    0.722951    
#> 166: 0.107085    1.081839    3.456538    0.064860    0.008343    0.040255    0.725565    
#> 167: 0.076455    1.076771    3.452879    0.054638    0.010036    0.037482    0.733928    
#> 168: 0.086914    1.084420    3.450277    0.077765    0.010857    0.035024    0.718712    
#> 169: 0.048245    1.086935    3.431578    0.077219    0.015027    0.028511    0.721774    
#> 170: 0.047966    1.058471    3.436014    0.094292    0.015247    0.028631    0.692678    
#> 171: 0.020513    1.076630    3.441375    0.087386    0.013442    0.031619    0.685483    
#> 172: 0.023396    1.098542    3.433817    0.095413    0.015173    0.029653    0.688267    
#> 173: 0.023348    1.114911    3.418549    0.089261    0.015855    0.029672    0.697516    
#> 174: 0.010727    1.108517    3.420706    0.091521    0.019353    0.025263    0.703874    
#> 175: 0.005285    1.093208    3.412419    0.091787    0.021752    0.026723    0.706072    
#> 176: -0.028493   1.096765    3.418347    0.109338    0.019980    0.025360    0.700856    
#> 177: -0.008096   1.084565    3.430908    0.106369    0.023852    0.033290    0.669208    
#> 178: 0.022188    1.067099    3.435165    0.093302    0.023982    0.029397    0.682972    
#> 179: 0.059368    1.071950    3.433783    0.093276    0.019795    0.027061    0.703888    
#> 180: 0.027588    1.069425    3.432014    0.061443    0.022006    0.021326    0.723491    
#> 181: 0.004104    1.050968    3.415559    0.070972    0.015972    0.021338    0.729433    
#> 182: -0.023738   1.064346    3.412324    0.086231    0.018426    0.024119    0.719982    
#> 183: -0.018841   1.077776    3.412699    0.084345    0.019549    0.020498    0.705689    
#> 184: -0.026747   1.068118    3.417643    0.093051    0.016646    0.022689    0.714497    
#> 185: -0.021945   1.083406    3.426915    0.087447    0.015528    0.028127    0.734399    
#> 186: 0.000850    1.084124    3.433598    0.073402    0.009598    0.036851    0.752016    
#> 187: 0.003975    1.078349    3.432993    0.079086    0.012534    0.031089    0.752454    
#> 188: -0.031718   1.101624    3.415395    0.071695    0.017474    0.030186    0.756974    
#> 189: 0.001897    1.108229    3.415715    0.085401    0.016995    0.023321    0.717865    
#> 190: -0.024902   1.093430    3.418226    0.084127    0.020742    0.022855    0.708805    
#> 191: -0.020523   1.089886    3.421383    0.104903    0.024072    0.022938    0.713216    
#> 192: -0.010879   1.092534    3.418465    0.105239    0.025126    0.023752    0.687683    
#> 193: 0.013893    1.107329    3.418806    0.119306    0.024291    0.022463    0.679508    
#> 194: 0.005880    1.100376    3.408744    0.109339    0.022735    0.018956    0.707275    
#> 195: -0.020287   1.101053    3.403642    0.105109    0.019489    0.022059    0.715499    
#> 196: -0.007531   1.095215    3.420174    0.101622    0.025025    0.025045    0.717575    
#> 197: 0.004150    1.094434    3.435087    0.100293    0.019739    0.028872    0.708068    
#> 198: 0.087704    1.071096    3.444532    0.098522    0.018790    0.027905    0.706228    
#> 199: 0.053265    1.063197    3.440161    0.104122    0.019468    0.025127    0.705068    
#> 200: 0.072457    1.044172    3.452882    0.084268    0.015978    0.024473    0.732806    
#> 201: 0.069018    1.043056    3.460618    0.077913    0.015780    0.025176    0.726571    
#> 202: 0.071114    1.043536    3.461520    0.084482    0.015295    0.026006    0.725357    
#> 203: 0.086164    1.041245    3.461988    0.091024    0.014907    0.027539    0.722012    
#> 204: 0.093371    1.038200    3.463660    0.096055    0.016087    0.027418    0.716943    
#> 205: 0.089905    1.041808    3.463910    0.100718    0.016672    0.027826    0.715250    
#> 206: 0.085967    1.046112    3.462034    0.103043    0.016803    0.027980    0.713359    
#> 207: 0.077444    1.048917    3.458769    0.105080    0.016684    0.027930    0.711463    
#> 208: 0.073098    1.049050    3.457643    0.106731    0.016599    0.028132    0.709512    
#> 209: 0.074496    1.048102    3.456226    0.107953    0.016433    0.028254    0.707737    
#> 210: 0.077623    1.048323    3.456531    0.107566    0.015919    0.028206    0.706528    
#> 211: 0.077702    1.048789    3.457130    0.107946    0.016096    0.028454    0.705348    
#> 212: 0.077437    1.048057    3.456973    0.108041    0.016236    0.028587    0.705817    
#> 213: 0.077940    1.045163    3.457829    0.106918    0.016884    0.027967    0.706643    
#> 214: 0.077912    1.044445    3.458403    0.107771    0.017434    0.027424    0.706051    
#> 215: 0.078104    1.044815    3.458686    0.106705    0.017801    0.026918    0.706213    
#> 216: 0.079529    1.043942    3.458568    0.106839    0.018052    0.026583    0.706486    
#> 217: 0.079268    1.044536    3.458658    0.105969    0.018486    0.026459    0.705045    
#> 218: 0.079510    1.045328    3.458385    0.105724    0.018496    0.026457    0.704121    
#> 219: 0.077972    1.045099    3.457316    0.106225    0.018417    0.026814    0.703767    
#> 220: 0.077267    1.045552    3.457094    0.106401    0.018160    0.027025    0.703870    
#> 221: 0.077809    1.046063    3.457517    0.106101    0.018166    0.027331    0.703621    
#> 222: 0.078162    1.046348    3.457534    0.106108    0.018294    0.027369    0.702886    
#> 223: 0.080257    1.046013    3.457808    0.106550    0.018254    0.027243    0.701987    
#> 224: 0.081408    1.045899    3.457916    0.107027    0.018214    0.027428    0.701302    
#> 225: 0.081178    1.044874    3.458208    0.106496    0.018300    0.027741    0.701681    
#> 226: 0.080470    1.044178    3.457753    0.105933    0.018247    0.027974    0.701262    
#> 227: 0.079337    1.044036    3.457736    0.105723    0.017992    0.028290    0.701387    
#> 228: 0.077871    1.044724    3.457132    0.105043    0.017739    0.028658    0.701593    
#> 229: 0.078135    1.045033    3.457007    0.104315    0.017641    0.028862    0.701269    
#> 230: 0.078297    1.044950    3.456808    0.103735    0.017617    0.029073    0.701072    
#> 231: 0.078328    1.044891    3.457157    0.103120    0.017515    0.029363    0.700899    
#> 232: 0.077522    1.044765    3.457382    0.102937    0.017434    0.029632    0.700886    
#> 233: 0.077556    1.044441    3.457322    0.102588    0.017346    0.029849    0.700729    
#> 234: 0.077615    1.044971    3.457292    0.102178    0.017251    0.030187    0.700879    
#> 235: 0.077677    1.045303    3.457006    0.101502    0.017368    0.030312    0.700853    
#> 236: 0.076764    1.046205    3.456427    0.101401    0.017508    0.030361    0.701158    
#> 237: 0.077585    1.046247    3.456326    0.102413    0.017491    0.030529    0.701862    
#> 238: 0.078072    1.046176    3.456194    0.103932    0.017411    0.030769    0.702530    
#> 239: 0.077616    1.046377    3.455889    0.104298    0.017361    0.030934    0.702795    
#> 240: 0.077801    1.046568    3.455925    0.104424    0.017322    0.030923    0.703248    
#> 241: 0.077638    1.046177    3.456071    0.104723    0.017398    0.030896    0.703817    
#> 242: 0.077485    1.045775    3.456025    0.104837    0.017718    0.030855    0.704198    
#> 243: 0.077226    1.046048    3.456093    0.104573    0.017928    0.030754    0.704404    
#> 244: 0.077112    1.045893    3.456366    0.104661    0.018124    0.030591    0.704408    
#> 245: 0.077931    1.045504    3.456817    0.104528    0.018137    0.030554    0.704430    
#> 246: 0.077763    1.045414    3.456822    0.104377    0.018134    0.030586    0.704556    
#> 247: 0.077199    1.045545    3.456946    0.104564    0.018173    0.030606    0.704417    
#> 248: 0.077273    1.045872    3.456747    0.104260    0.018145    0.030687    0.704383    
#> 249: 0.076846    1.046067    3.456766    0.104421    0.018195    0.030673    0.704194    
#> 250: 0.077033    1.046319    3.456765    0.104779    0.018363    0.030645    0.704456    
#> 251: 0.076740    1.046648    3.456801    0.105162    0.018527    0.030504    0.704385    
#> 252: 0.077303    1.046793    3.457171    0.105638    0.018525    0.030515    0.704212    
#> 253: 0.076560    1.047145    3.456949    0.106172    0.018432    0.030436    0.704029    
#> 254: 0.075778    1.047560    3.456897    0.106673    0.018384    0.030385    0.703985    
#> 255: 0.074927    1.047560    3.456586    0.106975    0.018331    0.030328    0.703664    
#> 256: 0.074541    1.047366    3.456401    0.106859    0.018318    0.030363    0.703277    
#> 257: 0.074164    1.047165    3.456169    0.106679    0.018212    0.030375    0.703370    
#> 258: 0.073808    1.046900    3.456204    0.106422    0.018162    0.030400    0.703272    
#> 259: 0.073557    1.046788    3.456013    0.106118    0.018086    0.030348    0.703576    
#> 260: 0.073292    1.046931    3.456002    0.106151    0.018094    0.030278    0.703820    
#> 261: 0.073389    1.046898    3.455910    0.106222    0.018040    0.030249    0.703781    
#> 262: 0.073402    1.046819    3.455698    0.106023    0.017994    0.030230    0.703863    
#> 263: 0.073352    1.047009    3.455618    0.105555    0.017875    0.030192    0.703892    
#> 264: 0.072950    1.047169    3.455494    0.105305    0.017853    0.030141    0.703825    
#> 265: 0.073080    1.047167    3.455377    0.105466    0.017901    0.030056    0.703864    
#> 266: 0.073333    1.047458    3.455365    0.105696    0.017933    0.029954    0.703837    
#> 267: 0.073122    1.047608    3.455574    0.106191    0.017982    0.029888    0.703728    
#> 268: 0.072704    1.047373    3.455424    0.106156    0.018024    0.029784    0.703911    
#> 269: 0.072958    1.047098    3.455498    0.105905    0.018062    0.029766    0.704082    
#> 270: 0.073531    1.046949    3.455571    0.106005    0.018028    0.029719    0.704066    
#> 271: 0.073644    1.046590    3.455661    0.105744    0.018030    0.029628    0.704230    
#> 272: 0.073390    1.046294    3.455574    0.105708    0.018027    0.029534    0.704617    
#> 273: 0.073382    1.046306    3.455720    0.105953    0.018078    0.029477    0.704573    
#> 274: 0.072806    1.046548    3.455678    0.106015    0.018096    0.029384    0.704410    
#> 275: 0.072400    1.046753    3.455480    0.105969    0.018043    0.029375    0.704185    
#> 276: 0.072339    1.046968    3.455475    0.105766    0.018010    0.029312    0.704196    
#> 277: 0.071902    1.047041    3.455543    0.105877    0.018017    0.029270    0.704023    
#> 278: 0.071610    1.047083    3.455592    0.105989    0.018038    0.029211    0.704123    
#> 279: 0.070971    1.047065    3.455462    0.106000    0.018011    0.029242    0.704388    
#> 280: 0.070764    1.047245    3.455525    0.105942    0.017983    0.029258    0.704252    
#> 281: 0.070468    1.047409    3.455557    0.105778    0.017979    0.029255    0.704232    
#> 282: 0.070558    1.047658    3.455473    0.105953    0.017999    0.029235    0.704282    
#> 283: 0.070701    1.047763    3.455415    0.106045    0.017963    0.029236    0.704755    
#> 284: 0.070297    1.047760    3.455311    0.106040    0.017920    0.029166    0.704725    
#> 285: 0.070399    1.047672    3.455179    0.106065    0.017892    0.029273    0.704663    
#> 286: 0.070282    1.047622    3.455168    0.106268    0.017942    0.029349    0.704522    
#> 287: 0.070127    1.047808    3.455067    0.106377    0.017948    0.029380    0.704561    
#> 288: 0.070191    1.047713    3.455182    0.106437    0.017904    0.029428    0.704791    
#> 289: 0.070273    1.047693    3.455162    0.106577    0.017955    0.029403    0.704844    
#> 290: 0.070337    1.047613    3.455251    0.106725    0.017969    0.029412    0.704921    
#> 291: 0.070566    1.047798    3.455411    0.106725    0.017972    0.029378    0.704885    
#> 292: 0.070588    1.047849    3.455490    0.106563    0.017996    0.029361    0.704941    
#> 293: 0.070741    1.047723    3.455497    0.106398    0.017925    0.029317    0.704991    
#> 294: 0.070604    1.047639    3.455429    0.106445    0.017885    0.029332    0.704923    
#> 295: 0.070645    1.047341    3.455497    0.106606    0.017832    0.029398    0.704785    
#> 296: 0.070582    1.047086    3.455469    0.106720    0.017854    0.029475    0.704799    
#> 297: 0.070915    1.047071    3.455534    0.106891    0.017854    0.029486    0.704820    
#> 298: 0.071034    1.047122    3.455503    0.107254    0.017794    0.029476    0.704589    
#> 299: 0.071088    1.047289    3.455445    0.107640    0.017753    0.029457    0.704453    
#> 300: 0.071241    1.047463    3.455472    0.107735    0.017688    0.029487    0.704327    
#> 301: 0.071240    1.047557    3.455329    0.107901    0.017652    0.029545    0.704317    
#> 302: 0.071034    1.047599    3.455131    0.108078    0.017591    0.029600    0.704250    
#> 303: 0.070742    1.047794    3.454989    0.108104    0.017543    0.029628    0.704014    
#> 304: 0.070860    1.048070    3.454843    0.108197    0.017526    0.029649    0.704008    
#> 305: 0.070541    1.048050    3.454763    0.108104    0.017511    0.029698    0.703899    
#> 306: 0.070016    1.048092    3.454576    0.108177    0.017511    0.029779    0.703875    
#> 307: 0.069832    1.048100    3.454396    0.108266    0.017505    0.029777    0.704060    
#> 308: 0.069658    1.048128    3.454291    0.108549    0.017525    0.029771    0.704157    
#> 309: 0.069676    1.048233    3.454130    0.108840    0.017578    0.029746    0.704215    
#> 310: 0.069888    1.048249    3.454099    0.109051    0.017590    0.029742    0.704190    
#> 311: 0.070009    1.048340    3.454106    0.109206    0.017613    0.029729    0.704125    
#> 312: 0.069878    1.048311    3.453942    0.109452    0.017633    0.029732    0.704066    
#> 313: 0.069577    1.048214    3.453843    0.109546    0.017631    0.029721    0.704071    
#> 314: 0.069135    1.048167    3.453713    0.109564    0.017591    0.029699    0.704162    
#> 315: 0.068876    1.048185    3.453684    0.109443    0.017567    0.029656    0.704206    
#> 316: 0.068756    1.048244    3.453669    0.109295    0.017555    0.029621    0.704262    
#> 317: 0.068736    1.048305    3.453765    0.109054    0.017581    0.029592    0.704438    
#> 318: 0.068618    1.048355    3.453687    0.108995    0.017586    0.029548    0.704183    
#> 319: 0.068537    1.048344    3.453684    0.109102    0.017614    0.029556    0.704045    
#> 320: 0.068260    1.048420    3.453593    0.109058    0.017658    0.029562    0.704088    
#> 321: 0.067844    1.048503    3.453412    0.108835    0.017652    0.029573    0.704177    
#> 322: 0.067411    1.048613    3.453181    0.108722    0.017624    0.029593    0.704282    
#> 323: 0.066769    1.048704    3.452942    0.108797    0.017614    0.029599    0.704204    
#> 324: 0.066704    1.048894    3.452847    0.108976    0.017670    0.029597    0.703940    
#> 325: 0.066114    1.049195    3.452645    0.109142    0.017688    0.029589    0.703818    
#> 326: 0.065818    1.049217    3.452451    0.109154    0.017670    0.029590    0.703763    
#> 327: 0.065638    1.049230    3.452464    0.109232    0.017673    0.029613    0.703622    
#> 328: 0.065534    1.049246    3.452465    0.109221    0.017677    0.029606    0.703466    
#> 329: 0.065729    1.049124    3.452612    0.109190    0.017635    0.029606    0.703484    
#> 330: 0.065676    1.048971    3.452747    0.109206    0.017623    0.029570    0.703550    
#> 331: 0.065835    1.048929    3.452861    0.109293    0.017620    0.029525    0.703672    
#> 332: 0.065757    1.048774    3.452929    0.109301    0.017596    0.029502    0.703764    
#> 333: 0.065637    1.048712    3.452922    0.109293    0.017557    0.029511    0.703738    
#> 334: 0.065461    1.048690    3.452687    0.109275    0.017531    0.029522    0.703629    
#> 335: 0.065248    1.048648    3.452561    0.109486    0.017492    0.029510    0.703675    
#> 336: 0.064834    1.048784    3.452393    0.109703    0.017466    0.029493    0.703614    
#> 337: 0.064573    1.049045    3.452200    0.109925    0.017455    0.029491    0.703498    
#> 338: 0.064364    1.049336    3.452172    0.109935    0.017455    0.029557    0.703341    
#> 339: 0.064107    1.049517    3.452068    0.109852    0.017452    0.029608    0.703397    
#> 340: 0.063871    1.049476    3.451981    0.109779    0.017444    0.029655    0.703358    
#> 341: 0.063861    1.049483    3.451980    0.109707    0.017446    0.029659    0.703283    
#> 342: 0.063682    1.049321    3.451989    0.109773    0.017444    0.029650    0.703188    
#> 343: 0.063315    1.049312    3.451895    0.109824    0.017441    0.029640    0.703115    
#> 344: 0.063419    1.049231    3.451915    0.109759    0.017437    0.029655    0.703203    
#> 345: 0.063449    1.049223    3.451933    0.109778    0.017402    0.029672    0.703153    
#> 346: 0.063304    1.049359    3.451847    0.109755    0.017388    0.029680    0.703136    
#> 347: 0.063256    1.049279    3.451761    0.109715    0.017403    0.029680    0.703174    
#> 348: 0.062982    1.049360    3.451624    0.109642    0.017412    0.029736    0.703337    
#> 349: 0.062794    1.049337    3.451519    0.109710    0.017391    0.029715    0.703422    
#> 350: 0.062525    1.049385    3.451340    0.109867    0.017408    0.029707    0.703388    
#> 351: 0.062398    1.049618    3.451176    0.109983    0.017421    0.029719    0.703306    
#> 352: 0.062240    1.049748    3.451144    0.110230    0.017431    0.029776    0.703506    
#> 353: 0.062316    1.049947    3.451062    0.110503    0.017440    0.029825    0.703580    
#> 354: 0.062360    1.050036    3.450946    0.110640    0.017416    0.029893    0.703608    
#> 355: 0.062567    1.049875    3.450927    0.110526    0.017392    0.029916    0.703705    
#> 356: 0.062466    1.049862    3.450961    0.110518    0.017383    0.029920    0.703798    
#> 357: 0.062522    1.049922    3.450902    0.110557    0.017369    0.029880    0.703854    
#> 358: 0.062457    1.050001    3.450886    0.110581    0.017407    0.029866    0.703721    
#> 359: 0.062260    1.050029    3.450771    0.110684    0.017388    0.029851    0.703735    
#> 360: 0.061988    1.050082    3.450563    0.110879    0.017375    0.029850    0.703620    
#> 361: 0.061574    1.050150    3.450417    0.111002    0.017349    0.029839    0.703700    
#> 362: 0.061456    1.050137    3.450281    0.110912    0.017343    0.029829    0.703679    
#> 363: 0.061339    1.050084    3.450286    0.111066    0.017358    0.029829    0.703605    
#> 364: 0.061398    1.050074    3.450223    0.111293    0.017360    0.029803    0.703648    
#> 365: 0.061366    1.049997    3.450248    0.111326    0.017374    0.029840    0.703724    
#> 366: 0.061329    1.050015    3.450185    0.111319    0.017373    0.029850    0.703764    
#> 367: 0.061187    1.050026    3.450108    0.111178    0.017388    0.029833    0.703846    
#> 368: 0.061245    1.050050    3.450079    0.111047    0.017373    0.029839    0.703815    
#> 369: 0.061194    1.050062    3.450098    0.110901    0.017359    0.029872    0.703833    
#> 370: 0.061012    1.050124    3.450045    0.110774    0.017330    0.029924    0.703851    
#> 371: 0.060829    1.050233    3.449937    0.110719    0.017316    0.029935    0.703768    
#> 372: 0.060640    1.050309    3.449803    0.110742    0.017339    0.029931    0.703667    
#> 373: 0.060421    1.050420    3.449693    0.110730    0.017327    0.029911    0.703795    
#> 374: 0.060288    1.050368    3.449619    0.110617    0.017298    0.029885    0.704001    
#> 375: 0.060220    1.050367    3.449611    0.110468    0.017257    0.029882    0.704016    
#> 376: 0.060140    1.050414    3.449602    0.110445    0.017240    0.029871    0.703961    
#> 377: 0.060134    1.050456    3.449582    0.110372    0.017234    0.029850    0.704019    
#> 378: 0.060015    1.050414    3.449525    0.110304    0.017224    0.029826    0.704077    
#> 379: 0.059875    1.050323    3.449550    0.110248    0.017201    0.029850    0.704115    
#> 380: 0.059702    1.050300    3.449535    0.110197    0.017189    0.029877    0.704053    
#> 381: 0.059673    1.050287    3.449531    0.110060    0.017210    0.029906    0.703979    
#> 382: 0.059637    1.050251    3.449502    0.109981    0.017213    0.029905    0.703918    
#> 383: 0.059616    1.050209    3.449476    0.109929    0.017240    0.029872    0.703796    
#> 384: 0.059486    1.050172    3.449471    0.109970    0.017234    0.029887    0.703777    
#> 385: 0.059552    1.050146    3.449497    0.109941    0.017226    0.029886    0.703733    
#> 386: 0.059681    1.050220    3.449624    0.109854    0.017222    0.029888    0.703738    
#> 387: 0.060018    1.050191    3.449838    0.109705    0.017230    0.029884    0.703701    
#> 388: 0.060225    1.050206    3.449942    0.109654    0.017224    0.029877    0.703682    
#> 389: 0.060253    1.050084    3.449935    0.109578    0.017252    0.029859    0.703718    
#> 390: 0.060121    1.050121    3.449898    0.109549    0.017269    0.029859    0.703645    
#> 391: 0.060073    1.050187    3.449823    0.109544    0.017264    0.029867    0.703659    
#> 392: 0.060153    1.050173    3.449914    0.109640    0.017254    0.029878    0.703660    
#> 393: 0.060110    1.050107    3.449867    0.109668    0.017259    0.029868    0.703628    
#> 394: 0.060044    1.050127    3.449801    0.109731    0.017250    0.029847    0.703591    
#> 395: 0.060084    1.050250    3.449775    0.109870    0.017269    0.029834    0.703579    
#> 396: 0.060167    1.050370    3.449756    0.109936    0.017298    0.029838    0.703512    
#> 397: 0.060325    1.050344    3.449805    0.110003    0.017309    0.029848    0.703488    
#> 398: 0.060550    1.050283    3.449872    0.110098    0.017297    0.029872    0.703437    
#> 399: 0.060749    1.050293    3.449933    0.110007    0.017296    0.029891    0.703473    
#> 400: 0.060820    1.050362    3.449927    0.109963    0.017272    0.029890    0.703473    
#> 401: 0.060765    1.050399    3.449875    0.109952    0.017274    0.029892    0.703488    
#> 402: 0.060627    1.050484    3.449847    0.109949    0.017276    0.029886    0.703433    
#> 403: 0.060776    1.050499    3.449800    0.109868    0.017242    0.029851    0.703512    
#> 404: 0.060911    1.050555    3.449785    0.109712    0.017216    0.029841    0.703577    
#> 405: 0.060875    1.050556    3.449813    0.109713    0.017213    0.029875    0.703533    
#> 406: 0.061000    1.050604    3.449820    0.109765    0.017226    0.029914    0.703526    
#> 407: 0.061103    1.050657    3.449841    0.109826    0.017247    0.029906    0.703447    
#> 408: 0.061233    1.050725    3.449883    0.109832    0.017298    0.029868    0.703484    
#> 409: 0.061173    1.050754    3.449844    0.109835    0.017313    0.029840    0.703479    
#> 410: 0.061090    1.050791    3.449770    0.109856    0.017318    0.029841    0.703458    
#> 411: 0.061199    1.050682    3.449781    0.109921    0.017329    0.029842    0.703498    
#> 412: 0.061141    1.050682    3.449707    0.109948    0.017338    0.029828    0.703500    
#> 413: 0.061048    1.050730    3.449667    0.109964    0.017336    0.029819    0.703488    
#> 414: 0.060777    1.050733    3.449605    0.109992    0.017336    0.029818    0.703421    
#> 415: 0.060736    1.050666    3.449555    0.110038    0.017339    0.029800    0.703331    
#> 416: 0.060792    1.050672    3.449603    0.109974    0.017334    0.029773    0.703351    
#> 417: 0.060789    1.050613    3.449596    0.110062    0.017333    0.029754    0.703362    
#> 418: 0.060484    1.050613    3.449580    0.110054    0.017346    0.029743    0.703379    
#> 419: 0.060353    1.050709    3.449483    0.110042    0.017336    0.029749    0.703321    
#> 420: 0.060275    1.050705    3.449431    0.109965    0.017337    0.029737    0.703259    
#> 421: 0.060101    1.050694    3.449451    0.109964    0.017313    0.029759    0.703239    
#> 422: 0.060238    1.050627    3.449472    0.110014    0.017295    0.029754    0.703245    
#> 423: 0.060346    1.050557    3.449503    0.110011    0.017303    0.029752    0.703213    
#> 424: 0.060211    1.050579    3.449389    0.110058    0.017307    0.029737    0.703229    
#> 425: 0.060384    1.050556    3.449372    0.110073    0.017308    0.029762    0.703297    
#> 426: 0.060407    1.050600    3.449359    0.110113    0.017301    0.029769    0.703223    
#> 427: 0.060389    1.050570    3.449421    0.110118    0.017299    0.029765    0.703135    
#> 428: 0.060326    1.050563    3.449471    0.110098    0.017292    0.029789    0.703142    
#> 429: 0.060363    1.050507    3.449541    0.110006    0.017285    0.029810    0.703222    
#> 430: 0.060387    1.050514    3.449524    0.109978    0.017286    0.029795    0.703334    
#> 431: 0.060316    1.050611    3.449470    0.109914    0.017294    0.029774    0.703369    
#> 432: 0.060258    1.050692    3.449456    0.109834    0.017293    0.029754    0.703451    
#> 433: 0.060154    1.050758    3.449490    0.109747    0.017298    0.029742    0.703483    
#> 434: 0.060043    1.050736    3.449464    0.109677    0.017300    0.029738    0.703440    
#> 435: 0.060118    1.050749    3.449510    0.109645    0.017302    0.029707    0.703378    
#> 436: 0.060156    1.050650    3.449604    0.109610    0.017339    0.029670    0.703337    
#> 437: 0.060243    1.050542    3.449683    0.109535    0.017347    0.029675    0.703272    
#> 438: 0.060318    1.050600    3.449755    0.109527    0.017335    0.029678    0.703206    
#> 439: 0.060431    1.050568    3.449807    0.109597    0.017327    0.029698    0.703180    
#> 440: 0.060522    1.050509    3.449938    0.109621    0.017314    0.029696    0.703182    
#> 441: 0.060516    1.050449    3.449941    0.109711    0.017316    0.029682    0.703088    
#> 442: 0.060457    1.050482    3.449951    0.109734    0.017332    0.029674    0.703026    
#> 443: 0.060386    1.050552    3.449899    0.109840    0.017351    0.029658    0.703021    
#> 444: 0.060333    1.050575    3.449830    0.109975    0.017364    0.029634    0.702945    
#> 445: 0.060335    1.050576    3.449845    0.110041    0.017356    0.029647    0.702953    
#> 446: 0.060219    1.050608    3.449818    0.110143    0.017356    0.029626    0.702909    
#> 447: 0.060267    1.050582    3.449837    0.110095    0.017371    0.029615    0.702921    
#> 448: 0.060191    1.050570    3.449847    0.110040    0.017375    0.029586    0.702957    
#> 449: 0.060220    1.050630    3.449943    0.109974    0.017367    0.029578    0.702980    
#> 450: 0.060291    1.050646    3.449982    0.109881    0.017383    0.029565    0.702964    
#> 451: 0.060447    1.050695    3.449991    0.109826    0.017404    0.029568    0.703000    
#> 452: 0.060424    1.050730    3.449940    0.109774    0.017397    0.029557    0.703006    
#> 453: 0.060400    1.050734    3.449922    0.109784    0.017390    0.029558    0.702961    
#> 454: 0.060326    1.050846    3.449882    0.109784    0.017377    0.029559    0.702938    
#> 455: 0.060263    1.050944    3.449807    0.109794    0.017370    0.029559    0.703013    
#> 456: 0.060057    1.051002    3.449725    0.109810    0.017361    0.029558    0.702958    
#> 457: 0.059899    1.051059    3.449701    0.109795    0.017364    0.029565    0.702897    
#> 458: 0.059773    1.051186    3.449678    0.109791    0.017387    0.029552    0.702871    
#> 459: 0.059596    1.051331    3.449622    0.109738    0.017414    0.029539    0.702860    
#> 460: 0.059545    1.051395    3.449569    0.109768    0.017424    0.029524    0.702796    
#> 461: 0.059408    1.051507    3.449499    0.109833    0.017431    0.029545    0.702816    
#> 462: 0.059228    1.051628    3.449450    0.109835    0.017440    0.029562    0.702767    
#> 463: 0.059143    1.051704    3.449430    0.109780    0.017444    0.029566    0.702839    
#> 464: 0.059229    1.051754    3.449425    0.109760    0.017433    0.029557    0.702854    
#> 465: 0.059217    1.051697    3.449452    0.109728    0.017440    0.029545    0.702852    
#> 466: 0.059232    1.051785    3.449361    0.109556    0.017441    0.029543    0.702868    
#> 467: 0.058926    1.051864    3.449288    0.109559    0.017460    0.029520    0.702798    
#> 468: 0.058939    1.051885    3.449330    0.109511    0.017484    0.029482    0.702866    
#> 469: 0.058816    1.052005    3.449289    0.109430    0.017518    0.029451    0.702968    
#> 470: 0.058626    1.052148    3.449207    0.109450    0.017524    0.029436    0.702997    
#> 471: 0.058408    1.052231    3.449141    0.109454    0.017525    0.029405    0.703104    
#> 472: 0.058342    1.052235    3.449099    0.109493    0.017520    0.029373    0.703187    
#> 473: 0.058220    1.052250    3.449059    0.109526    0.017522    0.029346    0.703180    
#> 474: 0.058226    1.052232    3.449052    0.109530    0.017514    0.029350    0.703214    
#> 475: 0.058295    1.052275    3.449000    0.109479    0.017513    0.029335    0.703203    
#> 476: 0.058285    1.052281    3.448951    0.109478    0.017510    0.029331    0.703249    
#> 477: 0.058204    1.052305    3.448965    0.109472    0.017506    0.029333    0.703206    
#> 478: 0.058152    1.052271    3.449006    0.109457    0.017497    0.029337    0.703202    
#> 479: 0.058238    1.052245    3.449026    0.109493    0.017506    0.029332    0.703218    
#> 480: 0.058353    1.052255    3.449092    0.109491    0.017540    0.029332    0.703244    
#> 481: 0.058346    1.052246    3.449092    0.109482    0.017548    0.029330    0.703254    
#> 482: 0.058478    1.052195    3.449077    0.109563    0.017555    0.029322    0.703282    
#> 483: 0.058425    1.052183    3.449083    0.109666    0.017568    0.029329    0.703268    
#> 484: 0.058470    1.052103    3.449105    0.109754    0.017572    0.029356    0.703234    
#> 485: 0.058583    1.052091    3.449145    0.109786    0.017561    0.029390    0.703214    
#> 486: 0.058560    1.052153    3.449182    0.109787    0.017551    0.029399    0.703133    
#> 487: 0.058650    1.052213    3.449211    0.109785    0.017547    0.029396    0.703020    
#> 488: 0.058623    1.052181    3.449194    0.109736    0.017549    0.029401    0.702986    
#> 489: 0.058760    1.052105    3.449201    0.109795    0.017549    0.029413    0.703005    
#> 490: 0.058911    1.052101    3.449231    0.109745    0.017535    0.029414    0.703061    
#> 491: 0.059021    1.052136    3.449275    0.109637    0.017518    0.029428    0.703103    
#> 492: 0.058987    1.052183    3.449224    0.109555    0.017521    0.029441    0.703076    
#> 493: 0.058853    1.052219    3.449226    0.109414    0.017527    0.029447    0.703148    
#> 494: 0.058822    1.052233    3.449241    0.109264    0.017527    0.029461    0.703182    
#> 495: 0.058875    1.052261    3.449260    0.109292    0.017524    0.029470    0.703142    
#> 496: 0.058885    1.052382    3.449195    0.109307    0.017525    0.029494    0.703152    
#> 497: 0.058803    1.052407    3.449173    0.109368    0.017516    0.029517    0.703226    
#> 498: 0.058735    1.052417    3.449118    0.109438    0.017518    0.029522    0.703165    
#> 499: 0.058835    1.052445    3.449092    0.109434    0.017535    0.029525    0.703145    
#> 500: 0.058882    1.052428    3.449074    0.109379    0.017526    0.029532    0.703106    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.269304    0.972968    3.449215    0.392401    0.073848    0.016800    1.547865    
#> 002: 0.270155    1.066753    3.465192    0.372781    0.070156    0.015960    1.069723    
#> 003: 0.365763    1.050187    3.494243    0.354142    0.066648    0.015162    0.840168    
#> 004: 0.369918    1.082910    3.496335    0.336435    0.063316    0.014404    0.775880    
#> 005: 0.453179    1.067266    3.505625    0.319613    0.060150    0.013684    0.708779    
#> 006: 0.429126    1.088636    3.496388    0.303633    0.057142    0.013000    0.656226    
#> 007: 0.388951    1.118192    3.484387    0.325383    0.054285    0.012350    0.638343    
#> 008: 0.384210    1.122674    3.466939    0.393574    0.056355    0.011732    0.624432    
#> 009: 0.372379    1.096426    3.467842    0.440084    0.054546    0.011146    0.630054    
#> 010: 0.361927    1.102998    3.469866    0.418080    0.051819    0.010800    0.635189    
#> 011: 0.414641    1.098426    3.486899    0.397176    0.058189    0.011062    0.636721    
#> 012: 0.407070    1.074738    3.484988    0.377317    0.055279    0.011640    0.623613    
#> 013: 0.403308    1.089657    3.483420    0.362065    0.052515    0.013471    0.620823    
#> 014: 0.433161    1.095161    3.497879    0.414962    0.054737    0.014324    0.628263    
#> 015: 0.433315    1.085517    3.502121    0.424850    0.052001    0.013608    0.618807    
#> 016: 0.420947    1.110248    3.492924    0.412897    0.049401    0.013966    0.623781    
#> 017: 0.419268    1.107600    3.491360    0.402510    0.046930    0.014096    0.605457    
#> 018: 0.417050    1.099621    3.479633    0.423488    0.056298    0.015433    0.619279    
#> 019: 0.421258    1.098520    3.485145    0.436411    0.053483    0.014661    0.602555    
#> 020: 0.477141    1.092626    3.497611    0.460789    0.050898    0.013928    0.596479    
#> 021: 0.467451    1.077290    3.508241    0.437750    0.048353    0.013232    0.608735    
#> 022: 0.474164    1.081999    3.516290    0.416604    0.045935    0.012570    0.606472    
#> 023: 0.575915    1.070965    3.526328    0.469625    0.043639    0.014999    0.636086    
#> 024: 0.539302    1.092734    3.517836    0.499807    0.044737    0.014249    0.607903    
#> 025: 0.496900    1.078586    3.503742    0.507331    0.044955    0.014957    0.616766    
#> 026: 0.471245    1.110688    3.496385    0.481965    0.050773    0.014209    0.610960    
#> 027: 0.432572    1.125396    3.491383    0.457866    0.055343    0.016090    0.626045    
#> 028: 0.482307    1.074582    3.508670    0.498863    0.052576    0.019425    0.610454    
#> 029: 0.477507    1.090149    3.486349    0.513154    0.051500    0.018454    0.623103    
#> 030: 0.414800    1.112893    3.477040    0.487497    0.049278    0.017531    0.606241    
#> 031: 0.420527    1.107697    3.482359    0.492747    0.055928    0.016654    0.597125    
#> 032: 0.422084    1.097647    3.485347    0.509699    0.053132    0.016690    0.591168    
#> 033: 0.408145    1.112173    3.482053    0.484214    0.050475    0.018414    0.595425    
#> 034: 0.450539    1.115420    3.482598    0.524957    0.047951    0.017493    0.606759    
#> 035: 0.417020    1.096206    3.487385    0.498709    0.045554    0.016619    0.597102    
#> 036: 0.432229    1.099892    3.484324    0.473773    0.046415    0.017700    0.606233    
#> 037: 0.416709    1.098405    3.489363    0.450085    0.044249    0.017583    0.622863    
#> 038: 0.421654    1.093982    3.483353    0.427581    0.048965    0.017572    0.634281    
#> 039: 0.445265    1.089728    3.497283    0.420246    0.046517    0.020577    0.601622    
#> 040: 0.439949    1.099443    3.501091    0.399233    0.044191    0.019548    0.607442    
#> 041: 0.402075    1.093323    3.489373    0.379272    0.041982    0.024215    0.604603    
#> 042: 0.429785    1.100370    3.489081    0.434376    0.039883    0.026120    0.595178    
#> 043: 0.398220    1.117889    3.467582    0.489356    0.037889    0.024814    0.593390    
#> 044: 0.391297    1.129315    3.468330    0.488351    0.036284    0.023574    0.591138    
#> 045: 0.389840    1.125007    3.466653    0.471867    0.035465    0.022395    0.586327    
#> 046: 0.405697    1.106786    3.480359    0.448274    0.035630    0.021275    0.592102    
#> 047: 0.408643    1.111168    3.474215    0.446530    0.033848    0.020211    0.608193    
#> 048: 0.413425    1.113461    3.480497    0.424203    0.034215    0.019201    0.610627    
#> 049: 0.412960    1.114639    3.481785    0.409131    0.043211    0.018241    0.610408    
#> 050: 0.432606    1.090690    3.485478    0.458799    0.043394    0.019475    0.601076    
#> 051: 0.460049    1.094792    3.490288    0.455764    0.041539    0.020809    0.604338    
#> 052: 0.444857    1.118358    3.499020    0.432976    0.044220    0.019769    0.595393    
#> 053: 0.464214    1.106675    3.491225    0.455875    0.042009    0.018780    0.593715    
#> 054: 0.409515    1.093511    3.492058    0.433081    0.043323    0.019313    0.615723    
#> 055: 0.426558    1.100363    3.487056    0.411427    0.041157    0.019621    0.611612    
#> 056: 0.440054    1.108744    3.480127    0.489599    0.043497    0.018640    0.613184    
#> 057: 0.414970    1.118506    3.481354    0.465119    0.042546    0.018564    0.621887    
#> 058: 0.411007    1.108861    3.471654    0.441863    0.041504    0.017636    0.617562    
#> 059: 0.402617    1.073040    3.485804    0.419770    0.044781    0.022199    0.616882    
#> 060: 0.418181    1.067019    3.501229    0.398781    0.042542    0.025301    0.633774    
#> 061: 0.456725    1.090330    3.503310    0.405169    0.046542    0.024036    0.639369    
#> 062: 0.452528    1.106974    3.513107    0.425720    0.048460    0.022834    0.637739    
#> 063: 0.490115    1.082995    3.504537    0.427603    0.054826    0.021905    0.631561    
#> 064: 0.478669    1.087980    3.511271    0.421846    0.052085    0.021503    0.620724    
#> 065: 0.463815    1.092045    3.494561    0.433050    0.049481    0.020428    0.617085    
#> 066: 0.464212    1.093401    3.504474    0.457508    0.049546    0.019406    0.599740    
#> 067: 0.444934    1.095903    3.491234    0.446629    0.047069    0.018436    0.606262    
#> 068: 0.404728    1.102158    3.498291    0.446977    0.050176    0.017556    0.609344    
#> 069: 0.400286    1.106499    3.476344    0.508305    0.047667    0.020508    0.632267    
#> 070: 0.432869    1.105908    3.484825    0.514545    0.045284    0.020753    0.620463    
#> 071: 0.433357    1.132075    3.468796    0.522998    0.049106    0.023318    0.623412    
#> 072: 0.401123    1.108738    3.469604    0.496848    0.046651    0.023253    0.609594    
#> 073: 0.443121    1.106306    3.499909    0.472006    0.044318    0.025865    0.617917    
#> 074: 0.410229    1.093882    3.489543    0.448405    0.042103    0.024571    0.629320    
#> 075: 0.429652    1.084453    3.517764    0.425985    0.040923    0.023343    0.615980    
#> 076: 0.490986    1.085735    3.517477    0.450257    0.038877    0.022176    0.610143    
#> 077: 0.537665    1.065097    3.521981    0.518049    0.036933    0.021067    0.604130    
#> 078: 0.496880    1.068676    3.523255    0.492147    0.041103    0.020014    0.607045    
#> 079: 0.452591    1.081980    3.513532    0.467539    0.039048    0.019013    0.644871    
#> 080: 0.446441    1.087715    3.495471    0.444162    0.045285    0.018062    0.634306    
#> 081: 0.451721    1.099092    3.497706    0.421954    0.043020    0.017159    0.616699    
#> 082: 0.455943    1.088420    3.494156    0.448378    0.042767    0.016301    0.609881    
#> 083: 0.443732    1.108716    3.495566    0.542117    0.040629    0.015966    0.597526    
#> 084: 0.450668    1.109400    3.488462    0.515011    0.044308    0.015327    0.604576    
#> 085: 0.433203    1.111212    3.501516    0.489261    0.042093    0.014594    0.615441    
#> 086: 0.472305    1.097496    3.502207    0.464798    0.047477    0.014994    0.603631    
#> 087: 0.445948    1.093696    3.490555    0.445054    0.045103    0.015987    0.604047    
#> 088: 0.396424    1.090028    3.495736    0.422801    0.042848    0.015462    0.618477    
#> 089: 0.408365    1.103465    3.484672    0.401661    0.043809    0.018226    0.606254    
#> 090: 0.377554    1.099916    3.473904    0.381578    0.042793    0.019940    0.617829    
#> 091: 0.396411    1.096490    3.469547    0.428221    0.040653    0.018952    0.614869    
#> 092: 0.399862    1.114795    3.469708    0.407171    0.038621    0.018239    0.613500    
#> 093: 0.381562    1.097671    3.471721    0.388539    0.039886    0.019701    0.623516    
#> 094: 0.399078    1.111664    3.478561    0.391401    0.043661    0.018716    0.608717    
#> 095: 0.420526    1.111609    3.483105    0.392617    0.046683    0.017780    0.618154    
#> 096: 0.369897    1.113572    3.485173    0.435075    0.044349    0.016891    0.613721    
#> 097: 0.450050    1.115025    3.495800    0.436487    0.042131    0.016803    0.589187    
#> 098: 0.449835    1.123530    3.494030    0.492470    0.040025    0.017407    0.608358    
#> 099: 0.404769    1.095147    3.482706    0.467847    0.042072    0.018784    0.587390    
#> 100: 0.418032    1.099909    3.488867    0.444454    0.046979    0.017844    0.592075    
#> 101: 0.420908    1.092083    3.482683    0.422232    0.047113    0.016952    0.589597    
#> 102: 0.411475    1.079567    3.484179    0.425459    0.050722    0.016105    0.619901    
#> 103: 0.435890    1.077217    3.498057    0.443251    0.048186    0.018327    0.615310    
#> 104: 0.423668    1.092095    3.506699    0.421088    0.045777    0.020893    0.621619    
#> 105: 0.494943    1.080509    3.506571    0.451305    0.050904    0.019848    0.617049    
#> 106: 0.455061    1.091025    3.505493    0.428739    0.048726    0.018856    0.605769    
#> 107: 0.481104    1.096833    3.517298    0.407302    0.053091    0.018405    0.608423    
#> 108: 0.481869    1.077368    3.516482    0.397305    0.054024    0.020987    0.625415    
#> 109: 0.445546    1.072876    3.516764    0.377440    0.051323    0.019938    0.633234    
#> 110: 0.427510    1.074007    3.493895    0.358568    0.048757    0.018941    0.614851    
#> 111: 0.440505    1.084566    3.497516    0.355289    0.046319    0.017994    0.591830    
#> 112: 0.399131    1.082966    3.474250    0.376088    0.044003    0.017094    0.609692    
#> 113: 0.407812    1.108085    3.485207    0.499114    0.041803    0.016720    0.594406    
#> 114: 0.432036    1.117551    3.489838    0.474158    0.041780    0.019974    0.607073    
#> 115: 0.438785    1.090595    3.491249    0.450450    0.039691    0.018976    0.621922    
#> 116: 0.441252    1.090106    3.491518    0.427928    0.037707    0.018027    0.606377    
#> 117: 0.428973    1.112700    3.493393    0.421111    0.041893    0.017126    0.613347    
#> 118: 0.435940    1.094918    3.492956    0.464934    0.039799    0.016269    0.601284    
#> 119: 0.445304    1.091863    3.490584    0.441688    0.042008    0.021360    0.612505    
#> 120: 0.399597    1.073531    3.495598    0.419603    0.039907    0.022422    0.616049    
#> 121: 0.441966    1.113626    3.492311    0.405202    0.044803    0.021642    0.617607    
#> 122: 0.405238    1.089072    3.488894    0.473180    0.048800    0.020560    0.606677    
#> 123: 0.464202    1.118446    3.487082    0.560011    0.046360    0.021024    0.603786    
#> 124: 0.423639    1.138442    3.486147    0.532011    0.044042    0.021685    0.620108    
#> 125: 0.438360    1.121232    3.478709    0.505410    0.041840    0.021582    0.592197    
#> 126: 0.406256    1.141810    3.467267    0.480140    0.043616    0.022567    0.627065    
#> 127: 0.442753    1.117672    3.477643    0.456133    0.041435    0.021438    0.631855    
#> 128: 0.387845    1.110235    3.489180    0.433326    0.039363    0.024616    0.624184    
#> 129: 0.401449    1.108773    3.496503    0.411660    0.037395    0.023386    0.621324    
#> 130: 0.473467    1.109697    3.496959    0.392426    0.035525    0.027253    0.623232    
#> 131: 0.433396    1.093774    3.478646    0.415582    0.046893    0.025890    0.611107    
#> 132: 0.409080    1.107888    3.471729    0.394803    0.053724    0.024595    0.613131    
#> 133: 0.443172    1.094181    3.485929    0.460568    0.051038    0.025821    0.620531    
#> 134: 0.449883    1.086945    3.497296    0.544873    0.048486    0.029925    0.609342    
#> 135: 0.432493    1.094823    3.482346    0.517629    0.046062    0.032086    0.611757    
#> 136: 0.463118    1.090439    3.495449    0.491748    0.043759    0.030482    0.623099    
#> 137: 0.466203    1.077327    3.502030    0.467161    0.041571    0.030393    0.633455    
#> 138: 0.464691    1.080310    3.500203    0.443802    0.039492    0.028873    0.618597    
#> 139: 0.428591    1.113155    3.506431    0.421612    0.037518    0.031519    0.622615    
#> 140: 0.468217    1.099296    3.504897    0.469520    0.035844    0.029943    0.630010    
#> 141: 0.421249    1.092010    3.502379    0.449044    0.034052    0.028446    0.617687    
#> 142: 0.459117    1.085517    3.513945    0.426591    0.034769    0.027023    0.614609    
#> 143: 0.397580    1.098127    3.498157    0.405262    0.041379    0.025672    0.629864    
#> 144: 0.463104    1.095790    3.514219    0.384999    0.039310    0.024389    0.611211    
#> 145: 0.405428    1.114153    3.481119    0.365749    0.037345    0.023169    0.611921    
#> 146: 0.406477    1.116603    3.489607    0.389439    0.035477    0.022011    0.618518    
#> 147: 0.380113    1.107918    3.471768    0.396310    0.035984    0.020910    0.610375    
#> 148: 0.392762    1.112164    3.485971    0.467952    0.034185    0.019865    0.600097    
#> 149: 0.385228    1.107174    3.471091    0.488169    0.036687    0.019804    0.602395    
#> 150: 0.404485    1.112103    3.467449    0.463760    0.039839    0.018814    0.622976    
#> 151: 0.343683    1.123110    3.468530    0.440572    0.037847    0.017873    0.629068    
#> 152: 0.372498    1.129804    3.477333    0.453760    0.036247    0.017342    0.621119    
#> 153: 0.399820    1.123344    3.491390    0.391017    0.039546    0.022169    0.620646    
#> 154: 0.450256    1.121787    3.488356    0.399192    0.035513    0.021525    0.617791    
#> 155: 0.461751    1.104358    3.498938    0.396707    0.038364    0.021838    0.608104    
#> 156: 0.454824    1.091644    3.511055    0.417118    0.043114    0.020155    0.621057    
#> 157: 0.451811    1.091156    3.501500    0.433528    0.042420    0.019287    0.614459    
#> 158: 0.458312    1.109960    3.498206    0.413677    0.040678    0.018934    0.594260    
#> 159: 0.453291    1.104718    3.508677    0.469789    0.049229    0.016607    0.595987    
#> 160: 0.476220    1.083301    3.512449    0.442411    0.054128    0.017023    0.602718    
#> 161: 0.467368    1.102703    3.508647    0.436098    0.040191    0.020476    0.597849    
#> 162: 0.436166    1.102158    3.502982    0.434823    0.038514    0.021810    0.608842    
#> 163: 0.467823    1.094359    3.490788    0.433192    0.041980    0.020419    0.596533    
#> 164: 0.474251    1.095418    3.498103    0.430305    0.038110    0.022521    0.592842    
#> 165: 0.475181    1.079632    3.500772    0.473167    0.031843    0.024251    0.599509    
#> 166: 0.484368    1.104819    3.501842    0.496284    0.026300    0.027016    0.603648    
#> 167: 0.475556    1.119214    3.504050    0.459396    0.028144    0.029181    0.608384    
#> 168: 0.460125    1.115466    3.504526    0.441358    0.030779    0.028088    0.602067    
#> 169: 0.452696    1.119960    3.489634    0.450192    0.038081    0.023058    0.601730    
#> 170: 0.445373    1.104491    3.499193    0.451995    0.034792    0.019998    0.594496    
#> 171: 0.411719    1.099648    3.492133    0.445585    0.035533    0.021028    0.596882    
#> 172: 0.398094    1.108008    3.485006    0.466292    0.030540    0.019018    0.600593    
#> 173: 0.395649    1.132361    3.472009    0.454692    0.032030    0.023078    0.598920    
#> 174: 0.433654    1.113560    3.492590    0.441181    0.031326    0.023156    0.601025    
#> 175: 0.420957    1.112666    3.481181    0.397345    0.031045    0.026329    0.605166    
#> 176: 0.442318    1.111936    3.502062    0.424609    0.030000    0.025861    0.603497    
#> 177: 0.448595    1.108325    3.496634    0.429735    0.036753    0.021491    0.597698    
#> 178: 0.455834    1.086003    3.509035    0.390578    0.034609    0.024593    0.602862    
#> 179: 0.488999    1.108820    3.500531    0.409485    0.044691    0.020018    0.625366    
#> 180: 0.449175    1.077799    3.507358    0.416780    0.040048    0.019688    0.607615    
#> 181: 0.439105    1.069162    3.484697    0.449970    0.033553    0.020007    0.602015    
#> 182: 0.406037    1.082085    3.477432    0.494069    0.034370    0.021761    0.619228    
#> 183: 0.425028    1.104734    3.479419    0.441620    0.038614    0.020195    0.613980    
#> 184: 0.409853    1.099495    3.483296    0.505880    0.033227    0.018307    0.611946    
#> 185: 0.413818    1.092505    3.488976    0.462999    0.024454    0.021284    0.617520    
#> 186: 0.413660    1.114756    3.478933    0.446511    0.029810    0.024727    0.625371    
#> 187: 0.412888    1.089877    3.486681    0.447556    0.029753    0.024361    0.606534    
#> 188: 0.375396    1.116485    3.475489    0.414365    0.034261    0.021179    0.619239    
#> 189: 0.404552    1.114677    3.495900    0.456548    0.032332    0.020929    0.620305    
#> 190: 0.447965    1.102916    3.511154    0.439025    0.029850    0.026029    0.616428    
#> 191: 0.446805    1.098786    3.496684    0.504644    0.029461    0.024349    0.608921    
#> 192: 0.432166    1.109680    3.489432    0.462269    0.030660    0.026080    0.589306    
#> 193: 0.453711    1.108454    3.501686    0.456085    0.033526    0.026217    0.594147    
#> 194: 0.451395    1.080735    3.494842    0.419349    0.036279    0.020337    0.606276    
#> 195: 0.421241    1.080098    3.485528    0.384602    0.035884    0.018016    0.601262    
#> 196: 0.404687    1.089534    3.493660    0.421062    0.042179    0.019503    0.609187    
#> 197: 0.390725    1.094759    3.505382    0.397090    0.037359    0.016609    0.629248    
#> 198: 0.444401    1.090772    3.492535    0.434274    0.032885    0.020322    0.609686    
#> 199: 0.415727    1.089309    3.481307    0.437450    0.041792    0.015768    0.598237    
#> 200: 0.406987    1.101261    3.487350    0.410722    0.045845    0.018887    0.603626    
#> 201: 0.416895    1.095061    3.495635    0.413825    0.043590    0.021698    0.598923    
#> 202: 0.422613    1.092809    3.498599    0.418570    0.041517    0.022403    0.603568    
#> 203: 0.434707    1.089663    3.499116    0.405318    0.039831    0.021874    0.602639    
#> 204: 0.440044    1.086252    3.502661    0.402610    0.038155    0.022248    0.604102    
#> 205: 0.441804    1.089872    3.503732    0.400410    0.037322    0.022862    0.607383    
#> 206: 0.445650    1.094752    3.504628    0.408063    0.037313    0.023267    0.607741    
#> 207: 0.445544    1.094793    3.503424    0.402256    0.036833    0.023122    0.608826    
#> 208: 0.444756    1.095517    3.501823    0.399570    0.036477    0.022958    0.606699    
#> 209: 0.444329    1.094303    3.500404    0.399643    0.036511    0.022919    0.605341    
#> 210: 0.444061    1.093373    3.500044    0.400215    0.036028    0.022720    0.605008    
#> 211: 0.448636    1.091776    3.501163    0.399252    0.035931    0.022886    0.605976    
#> 212: 0.451143    1.090958    3.502793    0.398031    0.035650    0.022929    0.606551    
#> 213: 0.454516    1.088691    3.504002    0.401672    0.035638    0.022967    0.606965    
#> 214: 0.456520    1.087420    3.504953    0.405358    0.036102    0.023221    0.606424    
#> 215: 0.455494    1.086743    3.505911    0.404755    0.035707    0.023479    0.607127    
#> 216: 0.458353    1.085823    3.506393    0.403299    0.035522    0.023455    0.608658    
#> 217: 0.457727    1.086419    3.506351    0.403385    0.035487    0.023192    0.609592    
#> 218: 0.455960    1.087345    3.505155    0.406847    0.035256    0.023298    0.609604    
#> 219: 0.454608    1.087244    3.503645    0.408922    0.034683    0.023499    0.609867    
#> 220: 0.454082    1.086921    3.503462    0.412759    0.034140    0.023875    0.609296    
#> 221: 0.453031    1.087060    3.503203    0.414006    0.033879    0.023912    0.609367    
#> 222: 0.452367    1.087280    3.502174    0.417788    0.033897    0.024064    0.609200    
#> 223: 0.452233    1.087864    3.502144    0.416798    0.033899    0.024333    0.609333    
#> 224: 0.453149    1.088117    3.502293    0.416550    0.033825    0.024378    0.609275    
#> 225: 0.452608    1.087189    3.502423    0.418559    0.033642    0.024433    0.609515    
#> 226: 0.452448    1.086049    3.502124    0.418635    0.033713    0.024314    0.609987    
#> 227: 0.452007    1.086323    3.502007    0.418896    0.033917    0.024167    0.610248    
#> 228: 0.450611    1.087361    3.501299    0.416909    0.034111    0.024009    0.609870    
#> 229: 0.449737    1.087814    3.500767    0.417447    0.034227    0.023822    0.609343    
#> 230: 0.449070    1.088312    3.500484    0.416166    0.034423    0.023562    0.608732    
#> 231: 0.449018    1.088741    3.500429    0.415760    0.034464    0.023375    0.608385    
#> 232: 0.448710    1.088627    3.500518    0.417268    0.034467    0.023203    0.607909    
#> 233: 0.447787    1.088159    3.500128    0.416433    0.034407    0.023153    0.607536    
#> 234: 0.448041    1.088127    3.499960    0.416382    0.034319    0.023094    0.607380    
#> 235: 0.447515    1.088022    3.499866    0.414817    0.034233    0.023115    0.607560    
#> 236: 0.447010    1.088435    3.499725    0.414175    0.034154    0.023147    0.607933    
#> 237: 0.447210    1.088626    3.499809    0.414709    0.034190    0.023155    0.608495    
#> 238: 0.447949    1.088878    3.500034    0.414103    0.034290    0.023156    0.608931    
#> 239: 0.448459    1.089222    3.500173    0.414790    0.034574    0.023297    0.609075    
#> 240: 0.449206    1.089065    3.500578    0.414999    0.034735    0.023328    0.609286    
#> 241: 0.449938    1.088373    3.500981    0.414776    0.034931    0.023248    0.609245    
#> 242: 0.450085    1.088052    3.500986    0.413466    0.035144    0.023142    0.609624    
#> 243: 0.449955    1.088217    3.500898    0.412312    0.035405    0.023039    0.609984    
#> 244: 0.449428    1.087973    3.501077    0.414311    0.035494    0.022930    0.609839    
#> 245: 0.449989    1.087477    3.501388    0.414389    0.035666    0.022935    0.609841    
#> 246: 0.449831    1.087320    3.501346    0.415506    0.035776    0.022880    0.609536    
#> 247: 0.449244    1.087340    3.501171    0.416160    0.035850    0.022901    0.609513    
#> 248: 0.448822    1.087893    3.501004    0.417538    0.035907    0.022833    0.609087    
#> 249: 0.448290    1.087751    3.501004    0.418330    0.035987    0.022838    0.609087    
#> 250: 0.448584    1.087888    3.501260    0.417435    0.036131    0.022710    0.609313    
#> 251: 0.449302    1.088223    3.501584    0.418406    0.036220    0.022636    0.609395    
#> 252: 0.450338    1.088340    3.501950    0.418918    0.036273    0.022636    0.609463    
#> 253: 0.450996    1.088669    3.501999    0.419671    0.036379    0.022623    0.609568    
#> 254: 0.451238    1.088967    3.502197    0.420047    0.036540    0.022589    0.609606    
#> 255: 0.451359    1.089320    3.502119    0.421039    0.036605    0.022529    0.609823    
#> 256: 0.451249    1.089095    3.501982    0.420172    0.036610    0.022468    0.610164    
#> 257: 0.450806    1.088712    3.501897    0.420104    0.036554    0.022446    0.610321    
#> 258: 0.450275    1.088505    3.501946    0.419633    0.036459    0.022369    0.610383    
#> 259: 0.450490    1.088302    3.501945    0.420232    0.036462    0.022345    0.610428    
#> 260: 0.450463    1.088268    3.501965    0.420843    0.036463    0.022346    0.610268    
#> 261: 0.450815    1.088142    3.501912    0.421282    0.036557    0.022345    0.610202    
#> 262: 0.450554    1.088632    3.501762    0.420857    0.036681    0.022268    0.610097    
#> 263: 0.450288    1.088935    3.501708    0.420319    0.036620    0.022225    0.610045    
#> 264: 0.449891    1.089204    3.501646    0.419608    0.036667    0.022184    0.610044    
#> 265: 0.450098    1.089262    3.501556    0.420238    0.036653    0.022214    0.610141    
#> 266: 0.450162    1.089305    3.501576    0.419712    0.036572    0.022218    0.610117    
#> 267: 0.450003    1.089319    3.501650    0.420306    0.036564    0.022269    0.610178    
#> 268: 0.450146    1.089211    3.501563    0.421351    0.036490    0.022306    0.610075    
#> 269: 0.451036    1.089002    3.501684    0.422949    0.036482    0.022354    0.609928    
#> 270: 0.451651    1.088995    3.501770    0.424003    0.036447    0.022395    0.609726    
#> 271: 0.451713    1.088916    3.501711    0.424214    0.036425    0.022392    0.609750    
#> 272: 0.451751    1.088755    3.501591    0.424596    0.036424    0.022395    0.609946    
#> 273: 0.451829    1.088803    3.501636    0.425170    0.036518    0.022361    0.610157    
#> 274: 0.452264    1.088688    3.501843    0.424304    0.036436    0.022355    0.610316    
#> 275: 0.452224    1.088676    3.501798    0.424493    0.036364    0.022374    0.610190    
#> 276: 0.452317    1.088687    3.501893    0.424469    0.036353    0.022390    0.610096    
#> 277: 0.452187    1.088854    3.501858    0.424905    0.036361    0.022393    0.610228    
#> 278: 0.451875    1.088896    3.501875    0.424803    0.036392    0.022359    0.610436    
#> 279: 0.451741    1.088658    3.501864    0.424608    0.036437    0.022325    0.610898    
#> 280: 0.451451    1.088847    3.501840    0.425042    0.036484    0.022279    0.610734    
#> 281: 0.451105    1.088989    3.501923    0.424935    0.036496    0.022243    0.610744    
#> 282: 0.450829    1.089149    3.501930    0.424739    0.036637    0.022212    0.610824    
#> 283: 0.450452    1.089223    3.501879    0.424181    0.036672    0.022186    0.611135    
#> 284: 0.450532    1.088914    3.501918    0.423634    0.036684    0.022154    0.611202    
#> 285: 0.450381    1.088918    3.501805    0.423616    0.036774    0.022108    0.611222    
#> 286: 0.450426    1.089112    3.501641    0.424618    0.036968    0.022077    0.611257    
#> 287: 0.449950    1.089314    3.501436    0.425263    0.036996    0.022068    0.611218    
#> 288: 0.449959    1.089259    3.501384    0.425369    0.036974    0.022025    0.611326    
#> 289: 0.450477    1.089040    3.501447    0.425209    0.036958    0.022038    0.611216    
#> 290: 0.450776    1.088987    3.501413    0.425171    0.036952    0.021990    0.611158    
#> 291: 0.450796    1.089204    3.501423    0.424985    0.036951    0.021962    0.610949    
#> 292: 0.450635    1.089366    3.501332    0.424678    0.036959    0.021931    0.610904    
#> 293: 0.450255    1.089513    3.501153    0.424933    0.036910    0.021911    0.610694    
#> 294: 0.449896    1.089683    3.500943    0.424840    0.036914    0.021917    0.610589    
#> 295: 0.449714    1.089693    3.500809    0.425129    0.036846    0.021903    0.610385    
#> 296: 0.449472    1.089660    3.500684    0.424577    0.036780    0.021897    0.610474    
#> 297: 0.449658    1.089667    3.500645    0.424967    0.036754    0.021911    0.610549    
#> 298: 0.449930    1.089612    3.500601    0.425404    0.036787    0.021877    0.610412    
#> 299: 0.450165    1.089786    3.500551    0.425959    0.036800    0.021827    0.610230    
#> 300: 0.450299    1.089693    3.500496    0.426320    0.036875    0.021770    0.610145    
#> 301: 0.450656    1.089486    3.500423    0.426590    0.036882    0.021716    0.610151    
#> 302: 0.450821    1.089532    3.500379    0.426858    0.036919    0.021665    0.610108    
#> 303: 0.450529    1.089687    3.500316    0.426312    0.037001    0.021636    0.610023    
#> 304: 0.450096    1.090133    3.500105    0.425836    0.036995    0.021596    0.610198    
#> 305: 0.449772    1.090108    3.499945    0.425631    0.037038    0.021548    0.610132    
#> 306: 0.449326    1.090046    3.499777    0.425296    0.037060    0.021500    0.610109    
#> 307: 0.449037    1.090036    3.499589    0.425330    0.037164    0.021475    0.610264    
#> 308: 0.448572    1.090072    3.499453    0.425385    0.037262    0.021467    0.610282    
#> 309: 0.448240    1.089993    3.499400    0.425140    0.037294    0.021442    0.610476    
#> 310: 0.448367    1.089978    3.499342    0.425019    0.037302    0.021425    0.610582    
#> 311: 0.448035    1.089989    3.499299    0.424552    0.037336    0.021387    0.610528    
#> 312: 0.447877    1.089892    3.499219    0.424419    0.037364    0.021344    0.610572    
#> 313: 0.447749    1.089671    3.499170    0.424760    0.037358    0.021311    0.610717    
#> 314: 0.447478    1.089672    3.499009    0.425023    0.037346    0.021284    0.610619    
#> 315: 0.447274    1.089793    3.498900    0.425430    0.037310    0.021255    0.610582    
#> 316: 0.447142    1.089945    3.498750    0.425441    0.037309    0.021242    0.610541    
#> 317: 0.447458    1.090000    3.498789    0.426574    0.037282    0.021224    0.610563    
#> 318: 0.447708    1.090027    3.498795    0.426925    0.037204    0.021256    0.610407    
#> 319: 0.447891    1.090002    3.498835    0.427695    0.037154    0.021289    0.610472    
#> 320: 0.447577    1.089997    3.498786    0.427352    0.037113    0.021305    0.610621    
#> 321: 0.447312    1.090157    3.498699    0.426891    0.037038    0.021265    0.610790    
#> 322: 0.447187    1.090253    3.498602    0.426484    0.036968    0.021278    0.610775    
#> 323: 0.446830    1.090413    3.498526    0.425841    0.036988    0.021269    0.610657    
#> 324: 0.446667    1.090578    3.498487    0.425448    0.036985    0.021260    0.610614    
#> 325: 0.446703    1.090786    3.498415    0.425284    0.036981    0.021255    0.610659    
#> 326: 0.446616    1.090744    3.498367    0.424981    0.036990    0.021266    0.610662    
#> 327: 0.446728    1.090814    3.498356    0.424806    0.036962    0.021271    0.610829    
#> 328: 0.446962    1.090896    3.498322    0.425270    0.036889    0.021299    0.610832    
#> 329: 0.447034    1.091009    3.498349    0.425464    0.036841    0.021308    0.610763    
#> 330: 0.446722    1.090973    3.498289    0.425857    0.036788    0.021285    0.610844    
#> 331: 0.446801    1.091093    3.498220    0.426869    0.036755    0.021306    0.610750    
#> 332: 0.447014    1.091099    3.498229    0.427427    0.036692    0.021281    0.610830    
#> 333: 0.446785    1.091196    3.498087    0.427272    0.036649    0.021315    0.610766    
#> 334: 0.446440    1.091208    3.497864    0.427869    0.036582    0.021369    0.610793    
#> 335: 0.446067    1.091314    3.497657    0.428208    0.036503    0.021385    0.610864    
#> 336: 0.445747    1.091575    3.497554    0.428448    0.036543    0.021385    0.610940    
#> 337: 0.445400    1.091847    3.497455    0.428596    0.036572    0.021379    0.610998    
#> 338: 0.445343    1.091977    3.497466    0.429401    0.036629    0.021367    0.610995    
#> 339: 0.445231    1.092018    3.497426    0.429972    0.036631    0.021364    0.610924    
#> 340: 0.444991    1.091978    3.497412    0.429595    0.036691    0.021349    0.610948    
#> 341: 0.445101    1.091923    3.497481    0.429167    0.036797    0.021335    0.610966    
#> 342: 0.444866    1.091858    3.497479    0.428920    0.036834    0.021304    0.611009    
#> 343: 0.444694    1.091788    3.497473    0.429197    0.036895    0.021269    0.610999    
#> 344: 0.444671    1.091654    3.497576    0.429112    0.036870    0.021230    0.611069    
#> 345: 0.444768    1.091481    3.497701    0.429001    0.036849    0.021202    0.611099    
#> 346: 0.444815    1.091417    3.497725    0.429026    0.036863    0.021158    0.611103    
#> 347: 0.444797    1.091247    3.497735    0.428687    0.036931    0.021146    0.611280    
#> 348: 0.444732    1.091210    3.497746    0.428634    0.037009    0.021124    0.611327    
#> 349: 0.444585    1.091145    3.497729    0.428500    0.037012    0.021108    0.611251    
#> 350: 0.444401    1.091084    3.497723    0.428113    0.037055    0.021120    0.611207    
#> 351: 0.444393    1.091210    3.497662    0.427849    0.037111    0.021116    0.611225    
#> 352: 0.444096    1.091302    3.497631    0.427375    0.037145    0.021116    0.611360    
#> 353: 0.444152    1.091472    3.497525    0.427180    0.037180    0.021113    0.611323    
#> 354: 0.444086    1.091503    3.497444    0.426963    0.037172    0.021152    0.611212    
#> 355: 0.444315    1.091414    3.497427    0.426964    0.037146    0.021175    0.611182    
#> 356: 0.444475    1.091352    3.497498    0.426816    0.037185    0.021155    0.611326    
#> 357: 0.444626    1.091431    3.497471    0.426929    0.037190    0.021137    0.611260    
#> 358: 0.444607    1.091390    3.497510    0.426876    0.037162    0.021144    0.611204    
#> 359: 0.444541    1.091495    3.497487    0.426470    0.037179    0.021142    0.611191    
#> 360: 0.444455    1.091545    3.497364    0.426355    0.037228    0.021127    0.611111    
#> 361: 0.444382    1.091558    3.497352    0.426391    0.037236    0.021110    0.611081    
#> 362: 0.444548    1.091564    3.497314    0.426650    0.037254    0.021086    0.610920    
#> 363: 0.444555    1.091530    3.497338    0.426353    0.037244    0.021046    0.610862    
#> 364: 0.444890    1.091591    3.497338    0.426458    0.037291    0.021008    0.610835    
#> 365: 0.444757    1.091522    3.497365    0.426458    0.037342    0.021004    0.610927    
#> 366: 0.444608    1.091587    3.497239    0.426583    0.037440    0.020996    0.610928    
#> 367: 0.444710    1.091705    3.497148    0.427198    0.037519    0.020982    0.610901    
#> 368: 0.444643    1.091804    3.497047    0.426895    0.037497    0.020963    0.610842    
#> 369: 0.444378    1.091866    3.496946    0.426624    0.037516    0.020952    0.610889    
#> 370: 0.444214    1.091902    3.496895    0.426571    0.037487    0.020972    0.610874    
#> 371: 0.443962    1.091959    3.496756    0.426491    0.037487    0.020981    0.610805    
#> 372: 0.443751    1.092056    3.496700    0.426482    0.037506    0.020960    0.610812    
#> 373: 0.443762    1.092133    3.496678    0.426333    0.037529    0.020941    0.610878    
#> 374: 0.443870    1.092080    3.496713    0.426398    0.037535    0.020914    0.610911    
#> 375: 0.444074    1.092036    3.496764    0.426814    0.037510    0.020890    0.611103    
#> 376: 0.444449    1.092089    3.496852    0.427100    0.037528    0.020908    0.611088    
#> 377: 0.444549    1.091996    3.496936    0.427138    0.037571    0.020877    0.611138    
#> 378: 0.444658    1.091803    3.496992    0.427269    0.037624    0.020849    0.611111    
#> 379: 0.444697    1.091655    3.497028    0.426983    0.037641    0.020815    0.611061    
#> 380: 0.444654    1.091621    3.497000    0.426796    0.037688    0.020788    0.610990    
#> 381: 0.444307    1.091612    3.496960    0.426587    0.037714    0.020751    0.610996    
#> 382: 0.444165    1.091665    3.496949    0.426638    0.037729    0.020732    0.610901    
#> 383: 0.444107    1.091720    3.496945    0.426651    0.037739    0.020724    0.610818    
#> 384: 0.444087    1.091763    3.496935    0.426676    0.037752    0.020729    0.610747    
#> 385: 0.444135    1.091782    3.496896    0.426767    0.037778    0.020749    0.610669    
#> 386: 0.444241    1.091838    3.496937    0.426558    0.037846    0.020756    0.610706    
#> 387: 0.444398    1.091840    3.497048    0.426300    0.037869    0.020778    0.610709    
#> 388: 0.444482    1.091894    3.497091    0.426028    0.037845    0.020778    0.610656    
#> 389: 0.444314    1.091780    3.497076    0.425650    0.037823    0.020777    0.610739    
#> 390: 0.444123    1.091818    3.497030    0.425265    0.037842    0.020759    0.610783    
#> 391: 0.444186    1.091838    3.496972    0.425236    0.037850    0.020759    0.610779    
#> 392: 0.444431    1.091886    3.497041    0.425524    0.037819    0.020762    0.610933    
#> 393: 0.444485    1.091766    3.497063    0.425416    0.037792    0.020769    0.611031    
#> 394: 0.444480    1.091778    3.497050    0.425512    0.037797    0.020772    0.611040    
#> 395: 0.444832    1.091818    3.497108    0.425727    0.037789    0.020796    0.611077    
#> 396: 0.444980    1.091745    3.497177    0.425700    0.037761    0.020817    0.611079    
#> 397: 0.445073    1.091649    3.497265    0.425477    0.037746    0.020826    0.611089    
#> 398: 0.445281    1.091565    3.497358    0.425532    0.037723    0.020835    0.611122    
#> 399: 0.445470    1.091523    3.497475    0.425668    0.037742    0.020846    0.611125    
#> 400: 0.445471    1.091527    3.497505    0.425441    0.037712    0.020838    0.611107    
#> 401: 0.445437    1.091625    3.497459    0.425477    0.037724    0.020835    0.611146    
#> 402: 0.445363    1.091748    3.497410    0.425540    0.037728    0.020844    0.611112    
#> 403: 0.445475    1.091850    3.497375    0.425896    0.037742    0.020854    0.611002    
#> 404: 0.445461    1.092002    3.497255    0.426204    0.037724    0.020841    0.610948    
#> 405: 0.445392    1.092071    3.497209    0.426604    0.037672    0.020834    0.611007    
#> 406: 0.445186    1.092150    3.497109    0.426719    0.037628    0.020824    0.611114    
#> 407: 0.445166    1.092238    3.497117    0.426899    0.037650    0.020808    0.611149    
#> 408: 0.445182    1.092405    3.497112    0.426983    0.037680    0.020789    0.611106    
#> 409: 0.445174    1.092455    3.497096    0.426949    0.037633    0.020796    0.610980    
#> 410: 0.444854    1.092625    3.496995    0.426872    0.037604    0.020797    0.610957    
#> 411: 0.444661    1.092648    3.496924    0.426740    0.037562    0.020794    0.610910    
#> 412: 0.444589    1.092771    3.496840    0.426847    0.037548    0.020805    0.610867    
#> 413: 0.444592    1.092936    3.496737    0.427175    0.037542    0.020819    0.610788    
#> 414: 0.444314    1.093020    3.496688    0.427168    0.037504    0.020827    0.610742    
#> 415: 0.444313    1.093063    3.496654    0.427012    0.037494    0.020855    0.610731    
#> 416: 0.444366    1.093114    3.496692    0.426827    0.037485    0.020891    0.610810    
#> 417: 0.444395    1.093180    3.496688    0.426677    0.037474    0.020904    0.610812    
#> 418: 0.444160    1.093226    3.496678    0.426510    0.037459    0.020912    0.610816    
#> 419: 0.444083    1.093309    3.496674    0.426589    0.037428    0.020923    0.610828    
#> 420: 0.444183    1.093365    3.496710    0.426889    0.037433    0.020932    0.610735    
#> 421: 0.444184    1.093441    3.496760    0.427069    0.037416    0.020934    0.610716    
#> 422: 0.444420    1.093368    3.496813    0.427146    0.037417    0.020924    0.610727    
#> 423: 0.444705    1.093262    3.496895    0.427510    0.037455    0.020921    0.610715    
#> 424: 0.444780    1.093190    3.496917    0.427667    0.037503    0.020896    0.610634    
#> 425: 0.444891    1.093164    3.496933    0.427535    0.037504    0.020898    0.610706    
#> 426: 0.444939    1.093178    3.496900    0.427671    0.037489    0.020881    0.610693    
#> 427: 0.445017    1.093144    3.496940    0.428014    0.037487    0.020861    0.610643    
#> 428: 0.445212    1.093168    3.496959    0.428245    0.037500    0.020844    0.610664    
#> 429: 0.445303    1.093170    3.496964    0.428499    0.037512    0.020834    0.610653    
#> 430: 0.445235    1.093200    3.496978    0.428510    0.037506    0.020825    0.610700    
#> 431: 0.445214    1.093183    3.496924    0.428458    0.037511    0.020808    0.610648    
#> 432: 0.445156    1.093236    3.496933    0.428472    0.037513    0.020810    0.610584    
#> 433: 0.445068    1.093368    3.496923    0.428380    0.037518    0.020801    0.610569    
#> 434: 0.444834    1.093305    3.496913    0.428004    0.037539    0.020787    0.610576    
#> 435: 0.444879    1.093300    3.496911    0.428195    0.037579    0.020775    0.610538    
#> 436: 0.444973    1.093265    3.496955    0.428114    0.037620    0.020758    0.610496    
#> 437: 0.444998    1.093245    3.496926    0.428080    0.037650    0.020743    0.610562    
#> 438: 0.445024    1.093400    3.496893    0.428116    0.037680    0.020729    0.610532    
#> 439: 0.445017    1.093497    3.496884    0.428006    0.037704    0.020722    0.610453    
#> 440: 0.444879    1.093590    3.496857    0.427995    0.037722    0.020709    0.610420    
#> 441: 0.444881    1.093608    3.496869    0.428086    0.037734    0.020704    0.610393    
#> 442: 0.444873    1.093615    3.496885    0.428264    0.037740    0.020689    0.610357    
#> 443: 0.444961    1.093632    3.496854    0.428332    0.037730    0.020679    0.610346    
#> 444: 0.445073    1.093656    3.496849    0.428448    0.037729    0.020676    0.610362    
#> 445: 0.444982    1.093708    3.496811    0.428292    0.037784    0.020651    0.610417    
#> 446: 0.444836    1.093799    3.496795    0.428010    0.037833    0.020624    0.610435    
#> 447: 0.444800    1.093847    3.496783    0.427957    0.037874    0.020606    0.610390    
#> 448: 0.444756    1.093795    3.496822    0.427976    0.037880    0.020612    0.610366    
#> 449: 0.444948    1.093802    3.496901    0.428268    0.037850    0.020611    0.610388    
#> 450: 0.445004    1.093811    3.496881    0.428521    0.037843    0.020624    0.610331    
#> 451: 0.445100    1.093930    3.496860    0.428474    0.037844    0.020636    0.610370    
#> 452: 0.445034    1.094026    3.496852    0.428506    0.037838    0.020643    0.610344    
#> 453: 0.445021    1.094106    3.496842    0.428623    0.037829    0.020644    0.610299    
#> 454: 0.445166    1.094205    3.496828    0.429195    0.037819    0.020654    0.610294    
#> 455: 0.445196    1.094266    3.496799    0.429453    0.037813    0.020658    0.610290    
#> 456: 0.445085    1.094277    3.496750    0.429609    0.037839    0.020651    0.610293    
#> 457: 0.444968    1.094343    3.496739    0.429490    0.037871    0.020644    0.610252    
#> 458: 0.444886    1.094460    3.496732    0.429311    0.037883    0.020637    0.610234    
#> 459: 0.444765    1.094615    3.496702    0.429196    0.037862    0.020621    0.610300    
#> 460: 0.444609    1.094648    3.496655    0.429139    0.037825    0.020616    0.610301    
#> 461: 0.444514    1.094715    3.496621    0.429107    0.037797    0.020625    0.610303    
#> 462: 0.444407    1.094813    3.496583    0.429250    0.037771    0.020639    0.610309    
#> 463: 0.444423    1.094930    3.496587    0.429480    0.037778    0.020636    0.610306    
#> 464: 0.444473    1.094986    3.496551    0.429576    0.037748    0.020626    0.610297    
#> 465: 0.444524    1.094886    3.496555    0.429781    0.037718    0.020618    0.610289    
#> 466: 0.444537    1.094868    3.496523    0.429752    0.037722    0.020613    0.610312    
#> 467: 0.444514    1.094840    3.496534    0.429891    0.037753    0.020619    0.610240    
#> 468: 0.444626    1.094840    3.496579    0.429987    0.037750    0.020634    0.610182    
#> 469: 0.444627    1.094887    3.496602    0.429825    0.037759    0.020651    0.610220    
#> 470: 0.444461    1.094890    3.496558    0.429813    0.037755    0.020677    0.610230    
#> 471: 0.444309    1.094875    3.496508    0.429584    0.037734    0.020673    0.610260    
#> 472: 0.444192    1.094868    3.496497    0.429530    0.037719    0.020675    0.610223    
#> 473: 0.444034    1.094914    3.496442    0.429488    0.037724    0.020678    0.610187    
#> 474: 0.443866    1.094921    3.496383    0.429422    0.037717    0.020699    0.610183    
#> 475: 0.443756    1.094983    3.496352    0.429489    0.037702    0.020714    0.610150    
#> 476: 0.443655    1.095034    3.496313    0.429462    0.037668    0.020722    0.610217    
#> 477: 0.443513    1.095115    3.496298    0.429406    0.037646    0.020733    0.610201    
#> 478: 0.443449    1.095111    3.496289    0.429558    0.037639    0.020750    0.610246    
#> 479: 0.443511    1.095133    3.496271    0.430141    0.037602    0.020769    0.610270    
#> 480: 0.443437    1.095227    3.496235    0.430489    0.037601    0.020780    0.610342    
#> 481: 0.443489    1.095294    3.496193    0.430920    0.037616    0.020792    0.610326    
#> 482: 0.443504    1.095329    3.496159    0.431314    0.037607    0.020793    0.610372    
#> 483: 0.443486    1.095335    3.496146    0.431268    0.037618    0.020807    0.610348    
#> 484: 0.443364    1.095245    3.496138    0.431145    0.037612    0.020815    0.610309    
#> 485: 0.443420    1.095248    3.496159    0.431234    0.037593    0.020818    0.610338    
#> 486: 0.443487    1.095253    3.496212    0.431191    0.037588    0.020814    0.610315    
#> 487: 0.443626    1.095296    3.496278    0.431310    0.037590    0.020820    0.610243    
#> 488: 0.443598    1.095240    3.496301    0.431283    0.037571    0.020821    0.610176    
#> 489: 0.443700    1.095177    3.496319    0.431165    0.037556    0.020819    0.610180    
#> 490: 0.443703    1.095234    3.496338    0.430975    0.037558    0.020823    0.610113    
#> 491: 0.443825    1.095269    3.496383    0.431000    0.037547    0.020822    0.610040    
#> 492: 0.443869    1.095336    3.496376    0.431155    0.037525    0.020819    0.610078    
#> 493: 0.443784    1.095385    3.496342    0.431329    0.037506    0.020824    0.610018    
#> 494: 0.443776    1.095436    3.496278    0.431172    0.037506    0.020838    0.610013    
#> 495: 0.443879    1.095494    3.496284    0.431087    0.037532    0.020844    0.610037    
#> 496: 0.443911    1.095546    3.496244    0.430966    0.037524    0.020846    0.610059    
#> 497: 0.443792    1.095576    3.496194    0.430839    0.037550    0.020834    0.610071    
#> 498: 0.443739    1.095536    3.496158    0.430770    0.037568    0.020833    0.610044    
#> 499: 0.443681    1.095554    3.496132    0.430616    0.037618    0.020830    0.610037    
#> 500: 0.443634    1.095543    3.496077    0.430516    0.037644    0.020817    0.610054    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.338146    0.966937    3.447682    0.392401    0.077832    0.016800    1.680075    
#> 002: 0.538855    1.035190    3.464062    0.372781    0.073941    0.015960    1.070730    
#> 003: 0.717191    1.042297    3.475971    0.354142    0.070244    0.015162    0.894283    
#> 004: 0.670783    1.092705    3.471955    0.336435    0.066731    0.014404    0.845924    
#> 005: 0.752240    1.106894    3.471301    0.319613    0.063395    0.013684    0.822441    
#> 006: 0.757625    1.086657    3.466998    0.375062    0.060225    0.013000    0.772441    
#> 007: 0.737497    1.096695    3.471409    0.356309    0.057214    0.012350    0.774304    
#> 008: 0.711058    1.090475    3.474997    0.338493    0.054353    0.011732    0.781050    
#> 009: 0.690112    1.076152    3.463154    0.346890    0.051636    0.011146    0.779044    
#> 010: 0.691255    1.073699    3.466716    0.353427    0.049054    0.010588    0.780107    
#> 011: 0.785590    1.073298    3.473143    0.383782    0.046601    0.010059    0.798143    
#> 012: 0.789829    1.046885    3.478862    0.364593    0.044271    0.009556    0.773314    
#> 013: 0.713090    1.083662    3.476640    0.346363    0.042057    0.011148    0.764466    
#> 014: 0.786343    1.076720    3.489505    0.367871    0.039955    0.010591    0.777835    
#> 015: 0.797574    1.067412    3.502865    0.349478    0.037957    0.010061    0.767774    
#> 016: 0.795989    1.072799    3.505453    0.371092    0.036059    0.009678    0.777181    
#> 017: 0.775696    1.076780    3.500380    0.398218    0.034256    0.009194    0.766302    
#> 018: 0.825902    1.078736    3.486188    0.430220    0.032543    0.008734    0.781688    
#> 019: 0.787758    1.082047    3.483233    0.408709    0.030916    0.008298    0.777426    
#> 020: 0.789569    1.075332    3.493467    0.397088    0.029370    0.010110    0.771366    
#> 021: 0.790678    1.071776    3.500723    0.404172    0.027902    0.009605    0.767827    
#> 022: 0.791648    1.074994    3.503308    0.401437    0.026507    0.009124    0.757207    
#> 023: 0.881569    1.081256    3.515069    0.417451    0.025537    0.008668    0.769734    
#> 024: 0.863609    1.095810    3.520489    0.396579    0.026423    0.008235    0.781711    
#> 025: 0.843196    1.061344    3.510611    0.376750    0.025102    0.009025    0.777060    
#> 026: 0.804998    1.080149    3.503727    0.357912    0.023847    0.009182    0.777393    
#> 027: 0.755740    1.088783    3.484589    0.386582    0.022654    0.009882    0.797065    
#> 028: 0.816937    1.083243    3.498879    0.367253    0.021522    0.009387    0.762795    
#> 029: 0.827858    1.066649    3.490048    0.405557    0.020445    0.009145    0.766773    
#> 030: 0.804902    1.086128    3.488015    0.385279    0.019423    0.009962    0.761068    
#> 031: 0.826783    1.083090    3.502068    0.434260    0.018452    0.009463    0.758156    
#> 032: 0.774777    1.084395    3.494137    0.479521    0.018518    0.008990    0.760148    
#> 033: 0.776822    1.088689    3.485645    0.460695    0.023592    0.008541    0.753892    
#> 034: 0.808835    1.097535    3.491560    0.437660    0.022412    0.008121    0.745856    
#> 035: 0.787589    1.078322    3.484035    0.455238    0.021292    0.008410    0.746145    
#> 036: 0.784155    1.087362    3.474327    0.437933    0.021524    0.007989    0.753950    
#> 037: 0.784735    1.100405    3.482267    0.416036    0.029161    0.007590    0.784844    
#> 038: 0.804323    1.081544    3.472001    0.487244    0.032281    0.007210    0.767801    
#> 039: 0.775207    1.078869    3.481020    0.462882    0.034427    0.006850    0.759860    
#> 040: 0.772612    1.080767    3.482003    0.506188    0.032706    0.006507    0.759141    
#> 041: 0.765324    1.081897    3.482883    0.514728    0.031070    0.007066    0.764032    
#> 042: 0.831100    1.081592    3.480495    0.494701    0.029517    0.006792    0.767682    
#> 043: 0.732341    1.093947    3.468809    0.469966    0.028041    0.007535    0.758985    
#> 044: 0.743035    1.100283    3.477389    0.446467    0.026639    0.007158    0.784345    
#> 045: 0.739146    1.090914    3.477389    0.424144    0.025307    0.006800    0.769399    
#> 046: 0.747389    1.094944    3.479852    0.402937    0.024042    0.006460    0.772695    
#> 047: 0.752129    1.094828    3.468998    0.382790    0.022840    0.006892    0.762039    
#> 048: 0.767435    1.081687    3.475632    0.399075    0.021698    0.008913    0.757882    
#> 049: 0.768986    1.075910    3.483726    0.421376    0.023295    0.008467    0.762673    
#> 050: 0.818312    1.063574    3.492294    0.400307    0.022130    0.008044    0.786542    
#> 051: 0.805749    1.068779    3.491270    0.391993    0.021024    0.008300    0.769013    
#> 052: 0.866687    1.075905    3.501113    0.539584    0.019973    0.007885    0.745078    
#> 053: 0.847231    1.060939    3.505813    0.512605    0.018974    0.007491    0.754002    
#> 054: 0.792807    1.064581    3.508777    0.486975    0.018025    0.008217    0.768645    
#> 055: 0.816028    1.065830    3.498501    0.462626    0.017124    0.007806    0.756834    
#> 056: 0.824163    1.056855    3.501481    0.439494    0.016268    0.007416    0.779951    
#> 057: 0.792750    1.059142    3.499859    0.426288    0.016298    0.007394    0.778718    
#> 058: 0.837378    1.067022    3.485577    0.437426    0.015483    0.007894    0.772860    
#> 059: 0.842940    1.063333    3.492886    0.496397    0.016351    0.009646    0.770500    
#> 060: 0.814267    1.043819    3.493682    0.471577    0.021236    0.010875    0.780903    
#> 061: 0.836439    1.060983    3.483075    0.501627    0.020174    0.010331    0.794664    
#> 062: 0.805440    1.071877    3.500982    0.476546    0.019165    0.009821    0.758927    
#> 063: 0.820628    1.054219    3.499689    0.452719    0.018207    0.009476    0.775665    
#> 064: 0.843283    1.054408    3.507566    0.503935    0.017297    0.009972    0.770256    
#> 065: 0.843511    1.047522    3.489629    0.478738    0.016432    0.010739    0.770389    
#> 066: 0.867576    1.044508    3.495320    0.501825    0.015610    0.010202    0.764520    
#> 067: 0.819044    1.062563    3.491774    0.476734    0.014830    0.010667    0.757952    
#> 068: 0.777721    1.063280    3.497697    0.452897    0.014088    0.010134    0.766792    
#> 069: 0.756934    1.060594    3.494684    0.430252    0.013384    0.009627    0.799109    
#> 070: 0.806111    1.067235    3.503649    0.492386    0.014512    0.009644    0.792477    
#> 071: 0.766966    1.093740    3.486491    0.467767    0.014652    0.009161    0.755592    
#> 072: 0.763995    1.060855    3.482214    0.444378    0.013919    0.008703    0.766842    
#> 073: 0.839329    1.075412    3.498200    0.424615    0.013572    0.009336    0.755573    
#> 074: 0.795275    1.088362    3.492591    0.419813    0.015823    0.008869    0.766716    
#> 075: 0.799668    1.072318    3.509232    0.398823    0.018094    0.008425    0.782335    
#> 076: 0.790799    1.092849    3.514559    0.378882    0.017189    0.010769    0.802489    
#> 077: 0.867204    1.083890    3.509139    0.403038    0.016330    0.010231    0.801904    
#> 078: 0.843246    1.080794    3.508990    0.389915    0.015513    0.009719    0.784448    
#> 079: 0.817973    1.072504    3.509951    0.371528    0.014738    0.010321    0.795305    
#> 080: 0.799405    1.057941    3.499288    0.426962    0.014740    0.009805    0.802249    
#> 081: 0.830568    1.060671    3.503303    0.425493    0.014003    0.009498    0.775360    
#> 082: 0.819620    1.068530    3.510681    0.442629    0.016826    0.009227    0.792318    
#> 083: 0.803169    1.079510    3.509830    0.420497    0.015985    0.008766    0.795364    
#> 084: 0.824140    1.103682    3.490034    0.399472    0.016860    0.008327    0.790929    
#> 085: 0.774591    1.113110    3.495376    0.420359    0.017974    0.008397    0.780969    
#> 086: 0.765122    1.101221    3.492147    0.399341    0.017075    0.008899    0.770521    
#> 087: 0.780891    1.092490    3.486382    0.379374    0.016221    0.009823    0.762266    
#> 088: 0.702606    1.084937    3.489808    0.360406    0.015410    0.009332    0.796479    
#> 089: 0.713642    1.093048    3.466385    0.364358    0.014640    0.010640    0.766876    
#> 090: 0.712445    1.107092    3.469850    0.360678    0.018481    0.010108    0.755691    
#> 091: 0.733017    1.081869    3.464008    0.365192    0.017557    0.009602    0.773591    
#> 092: 0.767187    1.103424    3.464867    0.396397    0.016679    0.010412    0.763954    
#> 093: 0.719133    1.105201    3.465492    0.384302    0.015845    0.009891    0.750973    
#> 094: 0.741453    1.106560    3.457858    0.453094    0.015053    0.009712    0.760272    
#> 095: 0.769947    1.099197    3.476657    0.459825    0.014300    0.010883    0.757262    
#> 096: 0.715549    1.094052    3.473504    0.436833    0.018376    0.010339    0.752186    
#> 097: 0.791952    1.105608    3.475082    0.483891    0.017691    0.009822    0.754360    
#> 098: 0.789222    1.116467    3.477509    0.468822    0.016807    0.009331    0.763132    
#> 099: 0.765507    1.100715    3.459098    0.533395    0.018058    0.008864    0.753508    
#> 100: 0.777885    1.095574    3.466845    0.506726    0.020587    0.008421    0.758287    
#> 101: 0.727250    1.074904    3.464345    0.481389    0.019558    0.009539    0.744752    
#> 102: 0.748638    1.067992    3.466786    0.457320    0.018580    0.009062    0.764990    
#> 103: 0.771493    1.071657    3.475829    0.530945    0.017651    0.008609    0.739997    
#> 104: 0.806964    1.085440    3.484588    0.573377    0.016768    0.010033    0.742664    
#> 105: 0.813355    1.088566    3.479944    0.544708    0.017449    0.009532    0.751046    
#> 106: 0.795437    1.082988    3.482777    0.517473    0.016576    0.010860    0.760234    
#> 107: 0.845625    1.094656    3.491694    0.491599    0.016685    0.011192    0.760807    
#> 108: 0.786987    1.091118    3.487646    0.467019    0.015851    0.012421    0.771308    
#> 109: 0.790307    1.090675    3.493888    0.443668    0.015671    0.011800    0.757811    
#> 110: 0.808546    1.084662    3.474451    0.470280    0.014888    0.011210    0.760792    
#> 111: 0.779583    1.099696    3.477715    0.446766    0.014143    0.010649    0.766775    
#> 112: 0.756086    1.089267    3.467593    0.424428    0.013436    0.010117    0.770974    
#> 113: 0.789630    1.100902    3.478803    0.458571    0.012764    0.009793    0.749468    
#> 114: 0.770053    1.104297    3.482090    0.435643    0.014011    0.009303    0.775371    
#> 115: 0.808208    1.080148    3.484988    0.413861    0.015524    0.008838    0.769843    
#> 116: 0.805819    1.093687    3.486605    0.401648    0.023699    0.009673    0.759148    
#> 117: 0.839451    1.099303    3.491612    0.454908    0.022514    0.009189    0.775429    
#> 118: 0.828445    1.095286    3.482638    0.461445    0.021388    0.008730    0.775626    
#> 119: 0.824926    1.086307    3.485448    0.554433    0.020319    0.008293    0.779509    
#> 120: 0.764206    1.081466    3.485137    0.526711    0.019303    0.011243    0.779560    
#> 121: 0.843560    1.091850    3.497523    0.500376    0.018597    0.011960    0.779865    
#> 122: 0.800298    1.075308    3.500409    0.475357    0.023356    0.011362    0.766610    
#> 123: 0.829416    1.084387    3.490583    0.451589    0.022188    0.010794    0.781666    
#> 124: 0.797671    1.100720    3.485852    0.429010    0.021079    0.010255    0.790646    
#> 125: 0.791312    1.081110    3.480383    0.407559    0.020025    0.010887    0.781039    
#> 126: 0.777881    1.101072    3.473816    0.469516    0.019024    0.011136    0.790516    
#> 127: 0.837348    1.111454    3.477089    0.478410    0.018072    0.010766    0.787304    
#> 128: 0.824361    1.104477    3.488429    0.474537    0.017340    0.010420    0.755134    
#> 129: 0.837373    1.096900    3.494790    0.461256    0.016473    0.013343    0.764038    
#> 130: 0.880937    1.097114    3.498100    0.458873    0.015650    0.013934    0.744281    
#> 131: 0.821148    1.083740    3.486511    0.496589    0.016164    0.013237    0.736312    
#> 132: 0.750536    1.072818    3.479758    0.471759    0.016467    0.012575    0.741833    
#> 133: 0.841588    1.070475    3.491545    0.538768    0.017403    0.011946    0.747868    
#> 134: 0.840090    1.061404    3.493255    0.511830    0.016533    0.011812    0.740033    
#> 135: 0.820467    1.055717    3.505470    0.486238    0.015706    0.011938    0.754873    
#> 136: 0.850765    1.041121    3.505175    0.561792    0.017042    0.011341    0.755255    
#> 137: 0.879425    1.057217    3.512535    0.533703    0.019512    0.010774    0.772437    
#> 138: 0.843970    1.059835    3.510103    0.507018    0.022774    0.010360    0.757176    
#> 139: 0.810092    1.072366    3.498092    0.481667    0.021635    0.009842    0.759802    
#> 140: 0.829293    1.081158    3.495064    0.457583    0.020554    0.012316    0.762655    
#> 141: 0.806874    1.066923    3.501949    0.489491    0.019526    0.011700    0.754154    
#> 142: 0.830612    1.052741    3.510272    0.465016    0.018550    0.012592    0.752755    
#> 143: 0.763441    1.061717    3.505806    0.441765    0.017622    0.014190    0.772778    
#> 144: 0.800282    1.079335    3.497121    0.450106    0.016741    0.013932    0.739918    
#> 145: 0.768357    1.079932    3.484612    0.427601    0.015904    0.013236    0.739454    
#> 146: 0.791361    1.091563    3.503286    0.406221    0.015109    0.012574    0.762966    
#> 147: 0.760510    1.071851    3.492884    0.385910    0.014353    0.012615    0.765145    
#> 148: 0.778543    1.079255    3.509691    0.366614    0.015370    0.011985    0.749468    
#> 149: 0.776381    1.062359    3.503963    0.412864    0.014601    0.011385    0.779247    
#> 150: 0.829700    1.051290    3.495120    0.392221    0.013871    0.010816    0.786642    
#> 151: 0.784094    1.070331    3.503378    0.436093    0.013178    0.011121    0.775143    
#> 152: 0.791531    1.073870    3.495431    0.445412    0.010511    0.009155    0.798450    
#> 153: 0.785122    1.089347    3.501370    0.415499    0.013711    0.008962    0.786324    
#> 154: 0.865524    1.089986    3.508584    0.436167    0.012718    0.009460    0.803092    
#> 155: 0.832232    1.081536    3.494696    0.413205    0.013433    0.007819    0.786766    
#> 156: 0.803245    1.095342    3.502756    0.356042    0.014113    0.006448    0.782929    
#> 157: 0.836347    1.086184    3.503320    0.394102    0.016950    0.007180    0.770304    
#> 158: 0.827195    1.103281    3.500646    0.392541    0.012210    0.008545    0.762171    
#> 159: 0.770202    1.091082    3.495859    0.401868    0.012109    0.009471    0.757187    
#> 160: 0.811769    1.070305    3.504810    0.426545    0.011338    0.009642    0.760287    
#> 161: 0.793684    1.057588    3.496550    0.447773    0.011477    0.012766    0.772672    
#> 162: 0.792661    1.080017    3.479787    0.437347    0.011926    0.011362    0.762451    
#> 163: 0.811546    1.065502    3.483398    0.487140    0.011786    0.010234    0.740886    
#> 164: 0.815129    1.088188    3.484104    0.487120    0.012186    0.010025    0.752671    
#> 165: 0.839531    1.081752    3.490697    0.462691    0.014034    0.013118    0.760045    
#> 166: 0.854419    1.097652    3.487045    0.616034    0.013892    0.013049    0.748674    
#> 167: 0.853426    1.108288    3.499480    0.573073    0.014106    0.010575    0.757614    
#> 168: 0.882267    1.106994    3.498359    0.571144    0.015431    0.007313    0.757178    
#> 169: 0.867657    1.114114    3.482294    0.666766    0.020198    0.006995    0.769721    
#> 170: 0.878903    1.088410    3.485302    0.687295    0.023012    0.006965    0.772125    
#> 171: 0.810932    1.097412    3.481261    0.567624    0.020439    0.005590    0.754079    
#> 172: 0.743645    1.097773    3.480106    0.503325    0.025673    0.006221    0.767003    
#> 173: 0.730780    1.113933    3.463284    0.449356    0.018595    0.006937    0.761182    
#> 174: 0.778282    1.114889    3.468701    0.470546    0.016013    0.006721    0.763660    
#> 175: 0.730055    1.116946    3.460642    0.412164    0.020220    0.006319    0.763540    
#> 176: 0.730705    1.128503    3.473136    0.329343    0.018302    0.005180    0.782264    
#> 177: 0.775438    1.133833    3.480328    0.449277    0.016311    0.004967    0.781006    
#> 178: 0.798907    1.112830    3.478993    0.418369    0.021617    0.006394    0.771741    
#> 179: 0.835075    1.116412    3.477420    0.536050    0.017413    0.008025    0.788040    
#> 180: 0.793392    1.098143    3.481024    0.529333    0.016944    0.009730    0.765559    
#> 181: 0.777219    1.078110    3.466625    0.474875    0.016292    0.007668    0.764947    
#> 182: 0.756365    1.097373    3.461546    0.510820    0.018088    0.009482    0.782367    
#> 183: 0.745306    1.108775    3.458673    0.438608    0.020321    0.009240    0.760037    
#> 184: 0.764413    1.096277    3.469529    0.498229    0.018735    0.007903    0.767402    
#> 185: 0.742851    1.121041    3.468236    0.409854    0.017237    0.007852    0.778350    
#> 186: 0.735454    1.128402    3.466008    0.402499    0.018118    0.009219    0.786817    
#> 187: 0.766403    1.127184    3.474824    0.499176    0.018467    0.007969    0.769311    
#> 188: 0.770276    1.151021    3.473106    0.490120    0.021955    0.008318    0.780159    
#> 189: 0.804558    1.153514    3.476758    0.489435    0.022262    0.007649    0.785835    
#> 190: 0.808335    1.130099    3.485785    0.449045    0.013222    0.007132    0.783450    
#> 191: 0.742451    1.125086    3.470773    0.463292    0.013004    0.007946    0.780707    
#> 192: 0.786012    1.131910    3.471424    0.485837    0.014543    0.009154    0.773248    
#> 193: 0.802421    1.139038    3.473552    0.527662    0.011683    0.009520    0.769784    
#> 194: 0.752343    1.114301    3.460687    0.536298    0.012168    0.009298    0.771624    
#> 195: 0.722159    1.110102    3.452321    0.472018    0.015286    0.009086    0.767258    
#> 196: 0.745036    1.107462    3.462658    0.491671    0.015752    0.009931    0.768428    
#> 197: 0.707485    1.117168    3.472420    0.416800    0.012489    0.010040    0.766866    
#> 198: 0.763199    1.112105    3.465439    0.469103    0.009569    0.012434    0.745960    
#> 199: 0.730720    1.109350    3.472065    0.396438    0.011264    0.012732    0.757340    
#> 200: 0.765261    1.108885    3.479375    0.419715    0.013027    0.009986    0.769755    
#> 201: 0.758652    1.100021    3.479793    0.406446    0.012823    0.010910    0.768129    
#> 202: 0.774550    1.101976    3.481831    0.400098    0.012986    0.011179    0.766828    
#> 203: 0.779813    1.097041    3.481641    0.414065    0.012781    0.010972    0.766020    
#> 204: 0.792010    1.094337    3.484545    0.422315    0.013214    0.011319    0.764866    
#> 205: 0.790133    1.097796    3.484046    0.424073    0.013131    0.011394    0.765305    
#> 206: 0.797160    1.098408    3.485989    0.445682    0.013216    0.011688    0.765719    
#> 207: 0.793162    1.096461    3.484579    0.434966    0.013277    0.011545    0.765914    
#> 208: 0.787331    1.095800    3.484435    0.421483    0.013350    0.011442    0.765626    
#> 209: 0.789979    1.094832    3.485051    0.419472    0.013666    0.011138    0.766140    
#> 210: 0.788958    1.092288    3.485085    0.414166    0.013517    0.010820    0.766450    
#> 211: 0.789167    1.091377    3.485635    0.407298    0.013373    0.010540    0.766267    
#> 212: 0.789993    1.091172    3.486200    0.399975    0.013311    0.010488    0.766426    
#> 213: 0.790449    1.088572    3.486298    0.394689    0.013607    0.010432    0.768052    
#> 214: 0.791486    1.086822    3.486663    0.392892    0.013649    0.010356    0.769264    
#> 215: 0.792463    1.085809    3.487796    0.391901    0.013623    0.010394    0.770620    
#> 216: 0.796216    1.084863    3.488266    0.394678    0.013715    0.010304    0.770998    
#> 217: 0.796941    1.084539    3.488381    0.397331    0.013806    0.010122    0.769876    
#> 218: 0.798127    1.085167    3.487691    0.400827    0.013905    0.010112    0.768876    
#> 219: 0.799221    1.084507    3.486802    0.406364    0.013817    0.010213    0.769365    
#> 220: 0.797790    1.084350    3.486901    0.407327    0.013556    0.010285    0.770280    
#> 221: 0.798993    1.084372    3.487110    0.410636    0.013421    0.010195    0.769671    
#> 222: 0.799251    1.084137    3.487036    0.414996    0.013400    0.010087    0.769705    
#> 223: 0.802017    1.083727    3.487524    0.414849    0.013466    0.009948    0.769412    
#> 224: 0.804400    1.083026    3.488400    0.415214    0.013471    0.009877    0.769155    
#> 225: 0.804214    1.081742    3.489093    0.417128    0.013555    0.009824    0.768826    
#> 226: 0.806638    1.080148    3.489292    0.423187    0.013761    0.009770    0.768362    
#> 227: 0.806984    1.079460    3.489580    0.426432    0.013782    0.009780    0.767504    
#> 228: 0.807674    1.080003    3.489545    0.429426    0.013775    0.009812    0.767203    
#> 229: 0.807913    1.079579    3.489263    0.433077    0.013825    0.009765    0.766710    
#> 230: 0.808559    1.078786    3.489339    0.433499    0.013938    0.009737    0.766554    
#> 231: 0.809402    1.078456    3.489675    0.435026    0.014010    0.009702    0.766451    
#> 232: 0.808670    1.077531    3.489903    0.436487    0.014145    0.009722    0.766151    
#> 233: 0.808676    1.076775    3.490092    0.437633    0.014264    0.009776    0.765953    
#> 234: 0.806369    1.076886    3.489915    0.435858    0.014283    0.009761    0.766147    
#> 235: 0.806105    1.076493    3.489723    0.436379    0.014289    0.009706    0.766049    
#> 236: 0.804608    1.076552    3.489287    0.435780    0.014241    0.009657    0.765798    
#> 237: 0.805217    1.076645    3.489213    0.435115    0.014134    0.009650    0.765923    
#> 238: 0.805516    1.076682    3.489233    0.434119    0.014060    0.009679    0.765826    
#> 239: 0.805984    1.076838    3.489198    0.434686    0.014077    0.009637    0.765657    
#> 240: 0.806201    1.076643    3.489335    0.434335    0.014026    0.009585    0.765656    
#> 241: 0.806344    1.076664    3.489579    0.433649    0.014026    0.009569    0.765715    
#> 242: 0.805258    1.076863    3.489255    0.430864    0.014061    0.009570    0.766099    
#> 243: 0.803947    1.077324    3.488991    0.429148    0.014085    0.009586    0.766254    
#> 244: 0.803610    1.077349    3.488911    0.429285    0.014125    0.009615    0.766545    
#> 245: 0.804016    1.077360    3.489027    0.428325    0.014137    0.009643    0.766500    
#> 246: 0.804237    1.077273    3.489015    0.427516    0.014212    0.009662    0.766727    
#> 247: 0.803399    1.077259    3.489138    0.427390    0.014261    0.009616    0.766520    
#> 248: 0.802900    1.076975    3.489166    0.426988    0.014212    0.009594    0.766193    
#> 249: 0.802569    1.076575    3.489279    0.426875    0.014297    0.009609    0.765987    
#> 250: 0.802289    1.076605    3.489204    0.426135    0.014301    0.009615    0.765880    
#> 251: 0.802364    1.076583    3.489356    0.426445    0.014304    0.009582    0.765564    
#> 252: 0.803299    1.076407    3.489681    0.426716    0.014342    0.009572    0.765458    
#> 253: 0.803062    1.076377    3.489754    0.425873    0.014346    0.009609    0.765534    
#> 254: 0.803462    1.076648    3.489991    0.424691    0.014317    0.009617    0.765880    
#> 255: 0.803261    1.076644    3.490284    0.423167    0.014287    0.009630    0.766499    
#> 256: 0.803242    1.076427    3.490316    0.423929    0.014279    0.009608    0.766934    
#> 257: 0.803597    1.075922    3.490411    0.425435    0.014297    0.009606    0.766775    
#> 258: 0.803217    1.075422    3.490410    0.424926    0.014341    0.009575    0.766613    
#> 259: 0.803129    1.075398    3.490368    0.424674    0.014322    0.009573    0.766488    
#> 260: 0.802955    1.075504    3.490410    0.425861    0.014270    0.009579    0.766393    
#> 261: 0.803801    1.075337    3.490645    0.427816    0.014246    0.009577    0.766339    
#> 262: 0.804175    1.075248    3.490782    0.428826    0.014197    0.009580    0.766619    
#> 263: 0.803972    1.075319    3.490944    0.429739    0.014130    0.009566    0.767035    
#> 264: 0.804373    1.075240    3.491052    0.431346    0.014098    0.009567    0.767152    
#> 265: 0.804127    1.075165    3.491148    0.431211    0.014136    0.009557    0.767255    
#> 266: 0.804012    1.075484    3.491056    0.431457    0.014193    0.009537    0.767190    
#> 267: 0.803873    1.075730    3.491188    0.431815    0.014184    0.009561    0.767179    
#> 268: 0.803803    1.075799    3.491131    0.432423    0.014167    0.009524    0.767467    
#> 269: 0.804866    1.075865    3.491174    0.433063    0.014142    0.009533    0.767464    
#> 270: 0.805474    1.075946    3.490979    0.434407    0.014108    0.009507    0.767406    
#> 271: 0.805927    1.075972    3.490813    0.435822    0.014039    0.009494    0.767451    
#> 272: 0.806345    1.075983    3.490722    0.436748    0.013959    0.009523    0.767740    
#> 273: 0.806086    1.076372    3.490752    0.436603    0.013927    0.009569    0.767657    
#> 274: 0.805641    1.076595    3.490708    0.435723    0.013885    0.009577    0.767553    
#> 275: 0.805174    1.076776    3.490530    0.435523    0.013818    0.009574    0.767568    
#> 276: 0.805090    1.076847    3.490696    0.435614    0.013755    0.009597    0.767694    
#> 277: 0.805147    1.076908    3.490972    0.435578    0.013747    0.009634    0.767575    
#> 278: 0.805153    1.076942    3.491183    0.435756    0.013759    0.009643    0.767461    
#> 279: 0.805258    1.076896    3.491227    0.435810    0.013783    0.009656    0.767375    
#> 280: 0.805033    1.077036    3.491215    0.435440    0.013844    0.009661    0.767215    
#> 281: 0.804145    1.077292    3.491147    0.435221    0.013878    0.009655    0.767298    
#> 282: 0.803912    1.077642    3.491084    0.435683    0.013872    0.009655    0.767423    
#> 283: 0.803999    1.077799    3.491024    0.436059    0.013892    0.009670    0.767718    
#> 284: 0.804117    1.077782    3.490956    0.435907    0.013933    0.009650    0.767710    
#> 285: 0.803733    1.077827    3.490670    0.435758    0.013987    0.009662    0.767636    
#> 286: 0.803208    1.077968    3.490446    0.435201    0.014066    0.009671    0.767786    
#> 287: 0.802969    1.077995    3.490378    0.435244    0.014076    0.009666    0.768028    
#> 288: 0.803116    1.077848    3.490360    0.435102    0.014141    0.009660    0.768064    
#> 289: 0.803113    1.077834    3.490328    0.434768    0.014147    0.009658    0.768149    
#> 290: 0.803079    1.077910    3.490294    0.435375    0.014121    0.009672    0.768182    
#> 291: 0.803221    1.078047    3.490309    0.436008    0.014093    0.009694    0.768047    
#> 292: 0.802927    1.078217    3.490155    0.436396    0.014076    0.009705    0.767827    
#> 293: 0.802654    1.078444    3.489934    0.436626    0.014041    0.009711    0.767715    
#> 294: 0.802204    1.078739    3.489672    0.436927    0.014029    0.009726    0.767626    
#> 295: 0.802100    1.078789    3.489529    0.437938    0.013992    0.009715    0.767690    
#> 296: 0.802182    1.078748    3.489502    0.438365    0.013985    0.009709    0.767987    
#> 297: 0.802191    1.078841    3.489424    0.438070    0.013974    0.009712    0.768097    
#> 298: 0.802591    1.078845    3.489330    0.438870    0.013962    0.009707    0.767958    
#> 299: 0.802579    1.078915    3.489376    0.439476    0.013933    0.009729    0.767725    
#> 300: 0.803147    1.078897    3.489513    0.439404    0.013970    0.009712    0.767595    
#> 301: 0.803123    1.078824    3.489512    0.439407    0.013972    0.009681    0.767636    
#> 302: 0.803362    1.078701    3.489494    0.439689    0.013970    0.009669    0.767551    
#> 303: 0.803182    1.078840    3.489379    0.439333    0.013972    0.009644    0.767366    
#> 304: 0.803353    1.078931    3.489318    0.440026    0.013960    0.009635    0.767211    
#> 305: 0.803595    1.078920    3.489354    0.439988    0.013950    0.009617    0.767029    
#> 306: 0.803099    1.078821    3.489298    0.439074    0.013923    0.009610    0.766924    
#> 307: 0.802396    1.078708    3.489163    0.438179    0.013903    0.009596    0.767042    
#> 308: 0.801701    1.078692    3.489062    0.438014    0.013894    0.009580    0.767051    
#> 309: 0.801523    1.078604    3.488989    0.437589    0.013913    0.009550    0.767070    
#> 310: 0.801588    1.078482    3.488876    0.437923    0.013928    0.009551    0.767128    
#> 311: 0.801648    1.078490    3.488895    0.437908    0.013934    0.009551    0.767049    
#> 312: 0.801361    1.078421    3.488730    0.438359    0.013952    0.009538    0.767041    
#> 313: 0.800901    1.078375    3.488623    0.438868    0.013995    0.009542    0.766976    
#> 314: 0.800665    1.078342    3.488464    0.438904    0.014032    0.009503    0.767047    
#> 315: 0.800760    1.078362    3.488491    0.438768    0.014072    0.009501    0.767055    
#> 316: 0.800890    1.078395    3.488598    0.438479    0.014083    0.009485    0.767090    
#> 317: 0.801074    1.078341    3.488729    0.438096    0.014112    0.009466    0.767252    
#> 318: 0.801044    1.078279    3.488730    0.438129    0.014121    0.009456    0.767127    
#> 319: 0.800920    1.078303    3.488781    0.438004    0.014116    0.009452    0.767102    
#> 320: 0.800691    1.078303    3.488764    0.438476    0.014133    0.009445    0.767143    
#> 321: 0.800391    1.078397    3.488652    0.438394    0.014169    0.009432    0.767207    
#> 322: 0.800218    1.078398    3.488444    0.438870    0.014188    0.009431    0.767137    
#> 323: 0.799573    1.078363    3.488241    0.438958    0.014198    0.009425    0.767029    
#> 324: 0.799442    1.078313    3.488273    0.438627    0.014172    0.009417    0.767062    
#> 325: 0.799026    1.078326    3.488168    0.438427    0.014160    0.009411    0.767004    
#> 326: 0.798910    1.078269    3.488088    0.438492    0.014146    0.009403    0.766858    
#> 327: 0.799163    1.078364    3.488139    0.439196    0.014134    0.009392    0.766778    
#> 328: 0.799237    1.078541    3.488110    0.438932    0.014136    0.009393    0.766727    
#> 329: 0.799310    1.078603    3.488135    0.439322    0.014128    0.009395    0.766583    
#> 330: 0.798849    1.078639    3.488106    0.438420    0.014122    0.009397    0.766606    
#> 331: 0.798822    1.078850    3.488135    0.437679    0.014112    0.009415    0.766546    
#> 332: 0.798941    1.078797    3.488220    0.437021    0.014100    0.009444    0.766467    
#> 333: 0.799068    1.078696    3.488231    0.436768    0.014107    0.009468    0.766323    
#> 334: 0.798816    1.078645    3.488155    0.436521    0.014106    0.009456    0.766200    
#> 335: 0.798536    1.078638    3.488086    0.436474    0.014099    0.009452    0.766147    
#> 336: 0.797921    1.078749    3.488046    0.435756    0.014108    0.009450    0.766272    
#> 337: 0.797480    1.078919    3.487903    0.435282    0.014079    0.009439    0.766327    
#> 338: 0.797144    1.079003    3.487869    0.434672    0.014071    0.009430    0.766405    
#> 339: 0.796930    1.079121    3.487861    0.434312    0.014058    0.009432    0.766397    
#> 340: 0.796853    1.079072    3.487923    0.434089    0.014031    0.009437    0.766494    
#> 341: 0.797133    1.079028    3.488037    0.434226    0.014024    0.009451    0.766511    
#> 342: 0.796754    1.078903    3.488044    0.433656    0.014001    0.009448    0.766478    
#> 343: 0.796249    1.078869    3.488094    0.433179    0.014012    0.009428    0.766491    
#> 344: 0.796118    1.078808    3.488108    0.433183    0.014039    0.009415    0.766498    
#> 345: 0.795989    1.078754    3.488066    0.432934    0.014030    0.009410    0.766499    
#> 346: 0.795828    1.078835    3.487966    0.432814    0.014019    0.009416    0.766573    
#> 347: 0.795602    1.078802    3.487822    0.432710    0.014034    0.009433    0.766628    
#> 348: 0.795030    1.078915    3.487693    0.432600    0.014071    0.009436    0.766615    
#> 349: 0.794737    1.078984    3.487640    0.432200    0.014075    0.009434    0.766646    
#> 350: 0.794292    1.078967    3.487586    0.432125    0.014071    0.009445    0.766651    
#> 351: 0.794211    1.079080    3.487548    0.431893    0.014077    0.009453    0.766673    
#> 352: 0.793939    1.079122    3.487519    0.431662    0.014078    0.009471    0.766705    
#> 353: 0.794031    1.079255    3.487485    0.431496    0.014059    0.009480    0.766587    
#> 354: 0.793870    1.079343    3.487366    0.431504    0.014040    0.009493    0.766459    
#> 355: 0.794234    1.079256    3.487371    0.431469    0.014024    0.009505    0.766368    
#> 356: 0.794029    1.079188    3.487400    0.430615    0.014029    0.009496    0.766536    
#> 357: 0.794091    1.079221    3.487384    0.430582    0.014009    0.009504    0.766462    
#> 358: 0.793910    1.079352    3.487406    0.430821    0.014040    0.009490    0.766376    
#> 359: 0.793765    1.079464    3.487429    0.430507    0.014047    0.009474    0.766368    
#> 360: 0.793650    1.079548    3.487344    0.430398    0.014049    0.009460    0.766290    
#> 361: 0.793297    1.079648    3.487261    0.429977    0.014047    0.009445    0.766228    
#> 362: 0.793282    1.079688    3.487168    0.430054    0.014061    0.009440    0.766077    
#> 363: 0.793251    1.079637    3.487140    0.429880    0.014062    0.009430    0.766031    
#> 364: 0.793282    1.079620    3.487121    0.430105    0.014101    0.009403    0.766085    
#> 365: 0.793246    1.079628    3.487074    0.430192    0.014133    0.009375    0.766101    
#> 366: 0.793268    1.079609    3.487030    0.429807    0.014118    0.009360    0.766263    
#> 367: 0.793278    1.079646    3.487022    0.429706    0.014112    0.009342    0.766238    
#> 368: 0.793348    1.079700    3.486952    0.429789    0.014108    0.009334    0.766112    
#> 369: 0.793141    1.079807    3.486921    0.430157    0.014111    0.009331    0.766125    
#> 370: 0.792802    1.079957    3.486825    0.430475    0.014133    0.009322    0.766085    
#> 371: 0.792358    1.080058    3.486683    0.430277    0.014147    0.009314    0.765997    
#> 372: 0.792164    1.080201    3.486615    0.430229    0.014151    0.009309    0.765984    
#> 373: 0.791924    1.080391    3.486538    0.430176    0.014162    0.009309    0.766042    
#> 374: 0.791752    1.080394    3.486433    0.430718    0.014140    0.009315    0.766052    
#> 375: 0.791867    1.080400    3.486440    0.430881    0.014136    0.009307    0.766003    
#> 376: 0.791831    1.080412    3.486461    0.430876    0.014125    0.009311    0.765917    
#> 377: 0.791982    1.080448    3.486477    0.431169    0.014105    0.009309    0.765924    
#> 378: 0.792014    1.080488    3.486444    0.431215    0.014093    0.009320    0.765951    
#> 379: 0.791920    1.080487    3.486435    0.431189    0.014068    0.009345    0.765873    
#> 380: 0.791630    1.080524    3.486370    0.430856    0.014040    0.009350    0.765858    
#> 381: 0.791694    1.080607    3.486287    0.431595    0.014040    0.009342    0.765808    
#> 382: 0.791372    1.080646    3.486194    0.431278    0.014027    0.009338    0.765778    
#> 383: 0.791346    1.080624    3.486167    0.430926    0.014029    0.009320    0.765845    
#> 384: 0.791198    1.080593    3.486184    0.430825    0.014007    0.009314    0.765924    
#> 385: 0.791165    1.080635    3.486194    0.430566    0.013997    0.009313    0.765939    
#> 386: 0.791353    1.080759    3.486210    0.430759    0.013992    0.009306    0.765821    
#> 387: 0.791476    1.080841    3.486235    0.430910    0.013989    0.009304    0.765747    
#> 388: 0.791478    1.080893    3.486219    0.430952    0.013982    0.009297    0.765774    
#> 389: 0.791550    1.080748    3.486231    0.431310    0.013985    0.009306    0.765757    
#> 390: 0.791445    1.080684    3.486157    0.430888    0.013968    0.009311    0.765783    
#> 391: 0.791424    1.080581    3.486133    0.430715    0.013964    0.009307    0.765757    
#> 392: 0.791553    1.080527    3.486211    0.430716    0.013956    0.009317    0.765741    
#> 393: 0.791515    1.080511    3.486193    0.430625    0.013949    0.009331    0.765705    
#> 394: 0.791610    1.080503    3.486199    0.430638    0.013938    0.009335    0.765624    
#> 395: 0.791827    1.080556    3.486212    0.430938    0.013932    0.009340    0.765488    
#> 396: 0.791915    1.080635    3.486268    0.430645    0.013933    0.009335    0.765391    
#> 397: 0.791963    1.080661    3.486312    0.430377    0.013947    0.009323    0.765406    
#> 398: 0.792104    1.080698    3.486348    0.430237    0.013937    0.009320    0.765471    
#> 399: 0.792244    1.080730    3.486448    0.429987    0.013948    0.009314    0.765508    
#> 400: 0.792354    1.080762    3.486482    0.429643    0.013930    0.009305    0.765483    
#> 401: 0.792345    1.080774    3.486489    0.429561    0.013933    0.009301    0.765511    
#> 402: 0.792295    1.080795    3.486453    0.429345    0.013931    0.009293    0.765565    
#> 403: 0.792511    1.080731    3.486411    0.429275    0.013926    0.009289    0.765639    
#> 404: 0.792562    1.080763    3.486334    0.429375    0.013924    0.009288    0.765639    
#> 405: 0.792732    1.080770    3.486340    0.430104    0.013899    0.009288    0.765724    
#> 406: 0.792736    1.080721    3.486329    0.430148    0.013868    0.009291    0.765819    
#> 407: 0.792651    1.080764    3.486339    0.430188    0.013851    0.009288    0.765802    
#> 408: 0.792705    1.080887    3.486356    0.430167    0.013851    0.009279    0.765838    
#> 409: 0.792503    1.081007    3.486307    0.429968    0.013839    0.009284    0.765798    
#> 410: 0.792376    1.081081    3.486255    0.429855    0.013824    0.009276    0.765839    
#> 411: 0.792407    1.081000    3.486219    0.429937    0.013807    0.009276    0.765885    
#> 412: 0.792377    1.080966    3.486200    0.429678    0.013805    0.009275    0.765881    
#> 413: 0.792205    1.080932    3.486158    0.429405    0.013792    0.009271    0.765948    
#> 414: 0.792076    1.080897    3.486177    0.429718    0.013773    0.009261    0.765974    
#> 415: 0.792365    1.080832    3.486209    0.429931    0.013757    0.009258    0.765888    
#> 416: 0.792541    1.080837    3.486250    0.429641    0.013746    0.009259    0.765864    
#> 417: 0.792594    1.080745    3.486284    0.429336    0.013729    0.009253    0.765853    
#> 418: 0.792627    1.080677    3.486339    0.429032    0.013718    0.009250    0.765864    
#> 419: 0.792886    1.080718    3.486335    0.429231    0.013716    0.009247    0.765822    
#> 420: 0.793003    1.080742    3.486369    0.429278    0.013707    0.009242    0.765712    
#> 421: 0.792881    1.080730    3.486405    0.429188    0.013694    0.009230    0.765689    
#> 422: 0.792940    1.080689    3.486398    0.429303    0.013688    0.009227    0.765727    
#> 423: 0.793175    1.080710    3.486417    0.429568    0.013675    0.009232    0.765780    
#> 424: 0.793141    1.080688    3.486353    0.429756    0.013679    0.009218    0.765892    
#> 425: 0.793404    1.080680    3.486338    0.429846    0.013699    0.009208    0.765994    
#> 426: 0.793345    1.080715    3.486335    0.429953    0.013715    0.009197    0.765957    
#> 427: 0.793238    1.080720    3.486314    0.429987    0.013701    0.009192    0.765949    
#> 428: 0.792974    1.080793    3.486238    0.429696    0.013684    0.009183    0.766015    
#> 429: 0.793011    1.080828    3.486231    0.429600    0.013671    0.009174    0.765995    
#> 430: 0.792807    1.080868    3.486211    0.429376    0.013656    0.009165    0.766056    
#> 431: 0.792591    1.080947    3.486164    0.428967    0.013654    0.009157    0.766049    
#> 432: 0.792601    1.081041    3.486177    0.429045    0.013653    0.009154    0.766046    
#> 433: 0.792656    1.081096    3.486198    0.429047    0.013636    0.009146    0.766054    
#> 434: 0.792576    1.081062    3.486232    0.428988    0.013614    0.009142    0.766050    
#> 435: 0.792524    1.081063    3.486253    0.428772    0.013604    0.009136    0.766001    
#> 436: 0.792516    1.081000    3.486260    0.428440    0.013609    0.009137    0.765948    
#> 437: 0.792454    1.080906    3.486229    0.428283    0.013613    0.009151    0.765988    
#> 438: 0.792513    1.080913    3.486268    0.428244    0.013602    0.009155    0.765923    
#> 439: 0.792551    1.080973    3.486258    0.428136    0.013593    0.009165    0.765859    
#> 440: 0.792424    1.081003    3.486271    0.427903    0.013595    0.009164    0.765882    
#> 441: 0.792506    1.080929    3.486316    0.427686    0.013593    0.009173    0.765846    
#> 442: 0.792427    1.080972    3.486356    0.427746    0.013591    0.009174    0.765760    
#> 443: 0.792539    1.081007    3.486372    0.428015    0.013576    0.009176    0.765720    
#> 444: 0.792566    1.081036    3.486359    0.428010    0.013568    0.009185    0.765661    
#> 445: 0.792342    1.081036    3.486299    0.428135    0.013555    0.009195    0.765729    
#> 446: 0.792107    1.081092    3.486257    0.427966    0.013563    0.009193    0.765733    
#> 447: 0.792173    1.081164    3.486235    0.428027    0.013576    0.009194    0.765722    
#> 448: 0.792146    1.081214    3.486251    0.427998    0.013580    0.009207    0.765726    
#> 449: 0.792197    1.081278    3.486365    0.427895    0.013582    0.009207    0.765795    
#> 450: 0.792281    1.081339    3.486387    0.427976    0.013598    0.009215    0.765796    
#> 451: 0.792314    1.081418    3.486370    0.428268    0.013623    0.009208    0.765792    
#> 452: 0.792233    1.081497    3.486312    0.428236    0.013625    0.009197    0.765737    
#> 453: 0.792059    1.081543    3.486260    0.428364    0.013618    0.009193    0.765712    
#> 454: 0.791942    1.081645    3.486224    0.428372    0.013616    0.009191    0.765630    
#> 455: 0.791814    1.081677    3.486181    0.428164    0.013619    0.009192    0.765573    
#> 456: 0.791652    1.081647    3.486164    0.428393    0.013624    0.009186    0.765541    
#> 457: 0.791722    1.081625    3.486214    0.428381    0.013628    0.009191    0.765473    
#> 458: 0.791814    1.081702    3.486230    0.428581    0.013639    0.009188    0.765430    
#> 459: 0.791739    1.081809    3.486246    0.428786    0.013650    0.009186    0.765398    
#> 460: 0.791524    1.081848    3.486233    0.428635    0.013660    0.009187    0.765387    
#> 461: 0.791473    1.081859    3.486251    0.428546    0.013665    0.009186    0.765369    
#> 462: 0.791433    1.081905    3.486283    0.428759    0.013660    0.009187    0.765382    
#> 463: 0.791502    1.081965    3.486316    0.428716    0.013686    0.009197    0.765343    
#> 464: 0.791516    1.082081    3.486280    0.428741    0.013688    0.009201    0.765255    
#> 465: 0.791476    1.082066    3.486228    0.428769    0.013695    0.009193    0.765208    
#> 466: 0.791544    1.082120    3.486160    0.428768    0.013678    0.009196    0.765240    
#> 467: 0.791418    1.082193    3.486118    0.428582    0.013673    0.009194    0.765180    
#> 468: 0.791660    1.082210    3.486155    0.428765    0.013666    0.009198    0.765234    
#> 469: 0.791780    1.082203    3.486214    0.428973    0.013681    0.009206    0.765292    
#> 470: 0.791884    1.082212    3.486266    0.429027    0.013698    0.009207    0.765268    
#> 471: 0.791843    1.082205    3.486269    0.428879    0.013697    0.009210    0.765245    
#> 472: 0.791840    1.082241    3.486310    0.428559    0.013707    0.009203    0.765288    
#> 473: 0.791713    1.082309    3.486297    0.428475    0.013711    0.009196    0.765299    
#> 474: 0.791833    1.082349    3.486281    0.428742    0.013723    0.009195    0.765263    
#> 475: 0.791954    1.082449    3.486273    0.428743    0.013736    0.009195    0.765158    
#> 476: 0.792087    1.082486    3.486242    0.429072    0.013747    0.009195    0.765157    
#> 477: 0.792079    1.082487    3.486260    0.428859    0.013755    0.009189    0.765124    
#> 478: 0.791966    1.082457    3.486269    0.428705    0.013755    0.009189    0.765103    
#> 479: 0.791954    1.082479    3.486268    0.428556    0.013767    0.009187    0.765091    
#> 480: 0.791989    1.082504    3.486300    0.428334    0.013784    0.009200    0.765109    
#> 481: 0.791901    1.082521    3.486315    0.428274    0.013803    0.009210    0.765105    
#> 482: 0.791986    1.082519    3.486290    0.428432    0.013806    0.009216    0.765125    
#> 483: 0.791841    1.082560    3.486244    0.428609    0.013816    0.009218    0.765109    
#> 484: 0.791718    1.082530    3.486231    0.428619    0.013821    0.009225    0.765120    
#> 485: 0.791719    1.082563    3.486244    0.428609    0.013809    0.009232    0.765114    
#> 486: 0.791678    1.082596    3.486255    0.428564    0.013801    0.009233    0.765104    
#> 487: 0.791747    1.082631    3.486294    0.428502    0.013801    0.009227    0.765039    
#> 488: 0.791862    1.082593    3.486346    0.428337    0.013795    0.009219    0.765000    
#> 489: 0.791967    1.082569    3.486381    0.428262    0.013798    0.009217    0.765020    
#> 490: 0.792074    1.082603    3.486399    0.428381    0.013802    0.009210    0.765053    
#> 491: 0.792107    1.082627    3.486413    0.428273    0.013796    0.009209    0.765035    
#> 492: 0.792053    1.082655    3.486399    0.428357    0.013811    0.009209    0.765082    
#> 493: 0.792044    1.082700    3.486393    0.428226    0.013838    0.009208    0.765167    
#> 494: 0.792107    1.082744    3.486382    0.427822    0.013858    0.009209    0.765172    
#> 495: 0.792098    1.082787    3.486398    0.427926    0.013870    0.009206    0.765189    
#> 496: 0.792139    1.082819    3.486337    0.428123    0.013869    0.009195    0.765271    
#> 497: 0.791998    1.082814    3.486298    0.428391    0.013867    0.009189    0.765281    
#> 498: 0.792010    1.082800    3.486233    0.428646    0.013884    0.009194    0.765242    
#> 499: 0.791989    1.082822    3.486175    0.428732    0.013880    0.009198    0.765269    
#> 500: 0.792038    1.082832    3.486131    0.428736    0.013874    0.009200    0.765238    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.312660    0.967925    3.451135    0.392401    0.080860    0.016800    1.711733    
#> 002: 0.547789    1.015459    3.443589    0.372781    0.076817    0.015960    1.167192    
#> 003: 0.646883    0.977480    3.450728    0.354142    0.080275    0.015162    0.877107    
#> 004: 0.689013    0.985802    3.459160    0.336435    0.082313    0.014404    0.807604    
#> 005: 0.782638    0.949534    3.461098    0.319613    0.078197    0.013684    0.788892    
#> 006: 0.716601    0.952331    3.460382    0.303633    0.077878    0.013000    0.759912    
#> 007: 0.666705    0.967983    3.451313    0.288451    0.083822    0.012350    0.748262    
#> 008: 0.677019    0.934699    3.451063    0.274029    0.097254    0.011732    0.756722    
#> 009: 0.675016    0.919451    3.454916    0.260327    0.100494    0.011146    0.760307    
#> 010: 0.686192    0.931438    3.457741    0.247311    0.104143    0.011312    0.757021    
#> 011: 0.769094    0.945004    3.469093    0.234945    0.108512    0.010746    0.761375    
#> 012: 0.742181    0.937352    3.466221    0.223198    0.103087    0.010310    0.754128    
#> 013: 0.695820    0.940492    3.465159    0.212038    0.097932    0.010077    0.750342    
#> 014: 0.744058    0.933743    3.469378    0.201436    0.096739    0.009573    0.766195    
#> 015: 0.773393    0.921281    3.488498    0.191364    0.091902    0.009095    0.755498    
#> 016: 0.737544    0.919014    3.482588    0.181796    0.099831    0.008640    0.742618    
#> 017: 0.756267    0.943108    3.481276    0.172706    0.102422    0.008208    0.728107    
#> 018: 0.780018    0.925102    3.478352    0.164071    0.097992    0.007798    0.752113    
#> 019: 0.709853    0.918404    3.478343    0.155867    0.093092    0.007408    0.748903    
#> 020: 0.731758    0.928143    3.483609    0.148074    0.096451    0.007037    0.755380    
#> 021: 0.739418    0.909689    3.483069    0.140670    0.091628    0.006685    0.751646    
#> 022: 0.730456    0.917971    3.483747    0.133637    0.087047    0.006351    0.745077    
#> 023: 0.816142    0.927643    3.488027    0.156786    0.082694    0.006513    0.777803    
#> 024: 0.814246    0.937774    3.489984    0.153834    0.091034    0.007091    0.764075    
#> 025: 0.779284    0.914320    3.480608    0.152686    0.093064    0.006736    0.761288    
#> 026: 0.753182    0.957576    3.473184    0.145052    0.110478    0.006399    0.761896    
#> 027: 0.721458    0.973666    3.468760    0.137799    0.112647    0.007087    0.772046    
#> 028: 0.753645    0.954481    3.482406    0.130909    0.107015    0.006961    0.759445    
#> 029: 0.758923    0.952210    3.466200    0.140198    0.101664    0.007602    0.759204    
#> 030: 0.750245    0.964311    3.462636    0.133188    0.096581    0.008072    0.760857    
#> 031: 0.754699    0.941163    3.471414    0.160840    0.091752    0.007669    0.742634    
#> 032: 0.753387    0.910351    3.487258    0.161911    0.097296    0.007285    0.734429    
#> 033: 0.754926    0.951555    3.478478    0.153815    0.104272    0.007863    0.739962    
#> 034: 0.782834    0.948380    3.477009    0.146125    0.104675    0.008077    0.743341    
#> 035: 0.705963    0.938980    3.468537    0.146419    0.099442    0.007673    0.748340    
#> 036: 0.731054    0.960304    3.463540    0.159847    0.115303    0.007290    0.751030    
#> 037: 0.707331    0.952023    3.470721    0.151855    0.113034    0.006925    0.767060    
#> 038: 0.753568    0.941656    3.465500    0.164590    0.108506    0.006579    0.768083    
#> 039: 0.764866    0.943018    3.478636    0.156361    0.103081    0.006250    0.735161    
#> 040: 0.760621    0.944689    3.479860    0.160889    0.101806    0.005938    0.755306    
#> 041: 0.735127    0.932853    3.467015    0.180544    0.099560    0.005641    0.743314    
#> 042: 0.769320    0.937128    3.468233    0.171517    0.098680    0.005359    0.751493    
#> 043: 0.687994    0.950057    3.456525    0.162941    0.100233    0.005091    0.749790    
#> 044: 0.685160    0.964694    3.452859    0.154794    0.100855    0.004858    0.761056    
#> 045: 0.692455    0.986457    3.450483    0.158511    0.096664    0.004615    0.750029    
#> 046: 0.721341    0.955888    3.451696    0.150586    0.095796    0.004969    0.760257    
#> 047: 0.704685    0.975737    3.446680    0.143056    0.099905    0.005670    0.751015    
#> 048: 0.696006    0.973757    3.445723    0.135904    0.099748    0.006697    0.745779    
#> 049: 0.698673    0.964794    3.460180    0.139518    0.094760    0.007088    0.761593    
#> 050: 0.735573    0.932690    3.456427    0.132542    0.099269    0.006733    0.757761    
#> 051: 0.697152    0.959182    3.449466    0.129511    0.095547    0.006666    0.767388    
#> 052: 0.692390    0.978740    3.459574    0.177996    0.092905    0.006333    0.733291    
#> 053: 0.736290    0.946412    3.463220    0.169096    0.088259    0.006016    0.759401    
#> 054: 0.693080    0.935783    3.461211    0.160642    0.101236    0.005716    0.762417    
#> 055: 0.681196    0.955220    3.446435    0.153753    0.096174    0.006702    0.765049    
#> 056: 0.689593    0.943150    3.453548    0.146065    0.097542    0.007474    0.781535    
#> 057: 0.725094    0.926781    3.476716    0.138762    0.092665    0.008101    0.770558    
#> 058: 0.734551    0.918455    3.474736    0.131824    0.089464    0.008338    0.769455    
#> 059: 0.777161    0.874940    3.490554    0.135575    0.110360    0.009104    0.776921    
#> 060: 0.786571    0.862219    3.494138    0.129257    0.116400    0.008649    0.802491    
#> 061: 0.789047    0.907260    3.493843    0.122794    0.121339    0.008216    0.793952    
#> 062: 0.772975    0.928224    3.497511    0.128179    0.133126    0.007805    0.783698    
#> 063: 0.794172    0.912423    3.495510    0.133606    0.126470    0.007415    0.775303    
#> 064: 0.757122    0.912304    3.490244    0.126926    0.120146    0.007044    0.774929    
#> 065: 0.761945    0.908358    3.481033    0.120579    0.114139    0.006692    0.771263    
#> 066: 0.751657    0.942511    3.477043    0.144537    0.108432    0.006358    0.764349    
#> 067: 0.757025    0.900628    3.476157    0.147854    0.103011    0.006142    0.752635    
#> 068: 0.732252    0.937021    3.482307    0.159185    0.119126    0.005835    0.769322    
#> 069: 0.754797    0.950297    3.473914    0.151226    0.123228    0.005543    0.755453    
#> 070: 0.744395    0.937991    3.481444    0.147408    0.117066    0.005690    0.746569    
#> 071: 0.734706    0.949887    3.463915    0.158478    0.133484    0.005509    0.763738    
#> 072: 0.707762    0.926541    3.463451    0.179015    0.126810    0.005234    0.737209    
#> 073: 0.740298    0.954458    3.478126    0.180018    0.120469    0.006244    0.734538    
#> 074: 0.737061    0.927572    3.474370    0.171017    0.114446    0.005932    0.737027    
#> 075: 0.756027    0.908954    3.488837    0.162466    0.108724    0.005635    0.757946    
#> 076: 0.744664    0.947480    3.484710    0.155392    0.123054    0.005353    0.757583    
#> 077: 0.782066    0.914210    3.479854    0.152031    0.118263    0.005198    0.750019    
#> 078: 0.784955    0.934127    3.485327    0.144430    0.114621    0.004938    0.737137    
#> 079: 0.810893    0.950456    3.493852    0.137208    0.122168    0.004691    0.777671    
#> 080: 0.789573    0.924275    3.482885    0.160068    0.146523    0.004456    0.787239    
#> 081: 0.767801    0.947340    3.481150    0.168962    0.139197    0.004234    0.770424    
#> 082: 0.751548    0.927432    3.485713    0.160514    0.132237    0.004753    0.771412    
#> 083: 0.768352    0.960477    3.487432    0.152488    0.125625    0.004628    0.764957    
#> 084: 0.776960    0.934532    3.482033    0.144864    0.119344    0.004396    0.757289    
#> 085: 0.749995    0.966038    3.481633    0.144106    0.113376    0.004176    0.770823    
#> 086: 0.743216    0.957401    3.477363    0.136901    0.124811    0.003968    0.772076    
#> 087: 0.733321    0.948470    3.468546    0.130056    0.118571    0.003769    0.794542    
#> 088: 0.685578    0.939262    3.473612    0.123553    0.112642    0.003581    0.816342    
#> 089: 0.714241    0.962878    3.464842    0.117376    0.120383    0.003402    0.778508    
#> 090: 0.688683    0.946537    3.463037    0.120395    0.114364    0.003232    0.770081    
#> 091: 0.699867    0.942192    3.447313    0.157681    0.108646    0.003641    0.758390    
#> 092: 0.687112    0.957844    3.450121    0.149797    0.103214    0.004418    0.761086    
#> 093: 0.679180    0.956207    3.454160    0.142307    0.098053    0.006237    0.758899    
#> 094: 0.683327    0.970945    3.441503    0.157993    0.093150    0.005925    0.763336    
#> 095: 0.710033    0.962057    3.457539    0.150093    0.088493    0.006046    0.746889    
#> 096: 0.681996    0.967798    3.453074    0.148767    0.098344    0.005744    0.738007    
#> 097: 0.716667    0.968724    3.452508    0.173833    0.093427    0.005457    0.757151    
#> 098: 0.712389    0.978226    3.459826    0.183463    0.097557    0.006160    0.752147    
#> 099: 0.707826    0.944973    3.443487    0.174290    0.108374    0.005852    0.743558    
#> 100: 0.662706    0.969381    3.438964    0.175132    0.102955    0.006202    0.742424    
#> 101: 0.635200    0.962292    3.430582    0.166376    0.108607    0.005892    0.746729    
#> 102: 0.641170    0.986856    3.426947    0.158057    0.109045    0.005597    0.772014    
#> 103: 0.701880    0.960193    3.446377    0.168757    0.103593    0.005317    0.754291    
#> 104: 0.690993    0.958767    3.455347    0.180267    0.098413    0.005051    0.746465    
#> 105: 0.686853    0.937568    3.456146    0.171253    0.093492    0.005470    0.763113    
#> 106: 0.715783    0.950396    3.450197    0.162691    0.094445    0.005196    0.753510    
#> 107: 0.771230    0.954918    3.453200    0.155894    0.106941    0.004936    0.754214    
#> 108: 0.715704    0.962818    3.443925    0.150553    0.113618    0.004875    0.749860    
#> 109: 0.678666    0.962591    3.454294    0.185445    0.107937    0.004632    0.746952    
#> 110: 0.689453    0.948543    3.446386    0.176173    0.102540    0.004400    0.759674    
#> 111: 0.673830    0.953607    3.450979    0.167364    0.099046    0.004180    0.760934    
#> 112: 0.686402    0.922900    3.452109    0.158996    0.109773    0.003971    0.763145    
#> 113: 0.716720    0.970851    3.454079    0.151046    0.104284    0.003779    0.736080    
#> 114: 0.718778    0.960631    3.457819    0.143494    0.099070    0.003590    0.765645    
#> 115: 0.757720    0.944062    3.465260    0.136319    0.094888    0.003410    0.766100    
#> 116: 0.709669    0.956941    3.459581    0.129503    0.102488    0.003751    0.771789    
#> 117: 0.694780    0.968244    3.460937    0.156568    0.105609    0.003563    0.764509    
#> 118: 0.740454    0.947050    3.459837    0.168145    0.114869    0.003385    0.760117    
#> 119: 0.727362    0.962116    3.460964    0.163019    0.112402    0.003216    0.770146    
#> 120: 0.718141    0.945281    3.458236    0.154868    0.115507    0.003055    0.771519    
#> 121: 0.718424    0.979318    3.458501    0.147125    0.131222    0.002902    0.759595    
#> 122: 0.713559    0.933134    3.456471    0.139768    0.124661    0.002757    0.772896    
#> 123: 0.735543    0.959093    3.452346    0.132780    0.119317    0.002619    0.777155    
#> 124: 0.743296    0.965266    3.454085    0.126141    0.121359    0.002757    0.779770    
#> 125: 0.745642    0.976831    3.450175    0.147129    0.117720    0.003145    0.763081    
#> 126: 0.688581    0.984021    3.447270    0.140405    0.111834    0.003763    0.753969    
#> 127: 0.699010    0.952485    3.448130    0.140109    0.106242    0.005013    0.729835    
#> 128: 0.674023    0.967010    3.457520    0.133103    0.104699    0.004762    0.758034    
#> 129: 0.702190    0.974551    3.453313    0.126448    0.124924    0.005172    0.756393    
#> 130: 0.739332    0.973415    3.449396    0.120126    0.120652    0.004914    0.761260    
#> 131: 0.685775    0.957382    3.437927    0.138269    0.129239    0.004897    0.743721    
#> 132: 0.688332    0.985151    3.439651    0.149660    0.122777    0.005496    0.768860    
#> 133: 0.667047    0.974286    3.437896    0.197867    0.117428    0.006291    0.763298    
#> 134: 0.742897    0.958088    3.459468    0.187974    0.111557    0.006122    0.764114    
#> 135: 0.697095    0.952688    3.459509    0.178575    0.105979    0.005815    0.764208    
#> 136: 0.731751    0.920754    3.461482    0.210972    0.105312    0.005525    0.746515    
#> 137: 0.791658    0.930870    3.476870    0.211129    0.103788    0.005248    0.754613    
#> 138: 0.775094    0.954790    3.475975    0.225556    0.098598    0.005128    0.754724    
#> 139: 0.775009    0.947003    3.481931    0.214278    0.097709    0.006552    0.743474    
#> 140: 0.760842    0.944036    3.493129    0.203564    0.104941    0.008516    0.752897    
#> 141: 0.773270    0.898438    3.491913    0.193386    0.099694    0.008090    0.741108    
#> 142: 0.783197    0.893802    3.493789    0.183717    0.105472    0.008050    0.744426    
#> 143: 0.732261    0.933981    3.490884    0.174531    0.100265    0.009545    0.755543    
#> 144: 0.784323    0.936761    3.501041    0.165805    0.095252    0.009068    0.733628    
#> 145: 0.755806    0.938953    3.478195    0.157514    0.090489    0.008614    0.730130    
#> 146: 0.722354    0.957087    3.475779    0.149639    0.090867    0.008562    0.749581    
#> 147: 0.689295    0.937558    3.470400    0.142157    0.104652    0.008849    0.738429    
#> 148: 0.700310    0.948575    3.473888    0.135049    0.099419    0.008406    0.753362    
#> 149: 0.719253    0.924581    3.468874    0.171838    0.094448    0.007986    0.771242    
#> 150: 0.756961    0.926492    3.461486    0.163246    0.102637    0.007587    0.782414    
#> 151: 0.678484    0.990633    3.455435    0.155084    0.106443    0.007208    0.770806    
#> 152: 0.693806    0.974238    3.457108    0.153440    0.097840    0.005813    0.735415    
#> 153: 0.704004    0.954267    3.463619    0.150907    0.095344    0.004983    0.746114    
#> 154: 0.740430    0.957999    3.465995    0.144417    0.098188    0.005573    0.758429    
#> 155: 0.700197    0.953357    3.460234    0.119718    0.092662    0.004572    0.764028    
#> 156: 0.712658    0.944819    3.471902    0.135671    0.090609    0.005338    0.759466    
#> 157: 0.751986    0.937699    3.482302    0.166749    0.094784    0.005322    0.751132    
#> 158: 0.758501    0.958998    3.474022    0.118603    0.104294    0.004253    0.753080    
#> 159: 0.716919    0.946817    3.471625    0.132685    0.093049    0.004682    0.746411    
#> 160: 0.716259    0.921793    3.475708    0.141400    0.120323    0.003976    0.745338    
#> 161: 0.696778    0.930926    3.474398    0.158043    0.114244    0.003907    0.767134    
#> 162: 0.698682    0.949789    3.455510    0.156426    0.114563    0.002974    0.759237    
#> 163: 0.719094    0.948672    3.460165    0.174504    0.110782    0.002580    0.759396    
#> 164: 0.733339    0.938010    3.466106    0.200378    0.100654    0.002882    0.752957    
#> 165: 0.776856    0.914225    3.483635    0.149793    0.092725    0.003769    0.757109    
#> 166: 0.814428    0.940836    3.483823    0.209170    0.106533    0.003859    0.741998    
#> 167: 0.755491    0.954236    3.482290    0.189709    0.082784    0.004044    0.746886    
#> 168: 0.788328    0.962003    3.480813    0.180510    0.090401    0.004286    0.751618    
#> 169: 0.756357    0.984256    3.472666    0.197793    0.077591    0.004046    0.786455    
#> 170: 0.785471    0.947912    3.474988    0.208349    0.087012    0.003776    0.766251    
#> 171: 0.749792    0.941398    3.476510    0.168984    0.083517    0.003449    0.743472    
#> 172: 0.740428    0.964593    3.472587    0.153663    0.096044    0.003182    0.743744    
#> 173: 0.732486    0.948546    3.469768    0.169926    0.090012    0.004235    0.750823    
#> 174: 0.771194    0.946943    3.476964    0.196521    0.095896    0.004387    0.742477    
#> 175: 0.767936    0.951187    3.471564    0.165794    0.095998    0.005251    0.742634    
#> 176: 0.768541    0.952422    3.477942    0.196826    0.093585    0.005406    0.756883    
#> 177: 0.778195    0.929794    3.481357    0.192191    0.108662    0.004254    0.754230    
#> 178: 0.796601    0.935649    3.480177    0.157826    0.110271    0.004720    0.750164    
#> 179: 0.789878    0.926403    3.481143    0.175824    0.117492    0.004418    0.745580    
#> 180: 0.775399    0.930951    3.479726    0.212893    0.102633    0.006448    0.735200    
#> 181: 0.763649    0.945733    3.469131    0.164116    0.101028    0.006645    0.726966    
#> 182: 0.733788    0.957910    3.459866    0.150343    0.082367    0.007132    0.751295    
#> 183: 0.743271    0.967745    3.464146    0.127731    0.082039    0.006968    0.730262    
#> 184: 0.733576    0.952595    3.468673    0.146734    0.086217    0.006089    0.747019    
#> 185: 0.714341    0.964517    3.463452    0.125035    0.089662    0.003940    0.752597    
#> 186: 0.737211    0.980508    3.471836    0.112477    0.084430    0.005463    0.746841    
#> 187: 0.729732    0.929424    3.479411    0.153358    0.095259    0.004930    0.753134    
#> 188: 0.703863    0.963245    3.463284    0.150169    0.096675    0.004489    0.766758    
#> 189: 0.758795    0.957658    3.471029    0.140566    0.092934    0.004175    0.766089    
#> 190: 0.739025    0.938484    3.471406    0.151050    0.102018    0.003806    0.740112    
#> 191: 0.702617    0.958244    3.460037    0.148061    0.112364    0.003436    0.749499    
#> 192: 0.718372    0.991798    3.458490    0.159542    0.100071    0.004211    0.736834    
#> 193: 0.702769    0.974423    3.453489    0.162629    0.113310    0.003708    0.732159    
#> 194: 0.685118    0.963799    3.445559    0.208871    0.121222    0.004238    0.744853    
#> 195: 0.686232    0.955432    3.438789    0.200562    0.103488    0.005033    0.755565    
#> 196: 0.686870    0.962166    3.454852    0.163378    0.110788    0.005026    0.768156    
#> 197: 0.652297    0.963963    3.469771    0.138391    0.109633    0.005080    0.770058    
#> 198: 0.697225    0.937442    3.454441    0.123360    0.094937    0.006167    0.770848    
#> 199: 0.670690    0.959317    3.455235    0.122585    0.094574    0.005551    0.751813    
#> 200: 0.692542    0.952295    3.456731    0.152730    0.094537    0.005018    0.761350    
#> 201: 0.694188    0.946698    3.459743    0.139553    0.093504    0.005321    0.752528    
#> 202: 0.696099    0.951223    3.458600    0.141445    0.098164    0.005020    0.749144    
#> 203: 0.707859    0.948602    3.458191    0.135164    0.099558    0.004916    0.750549    
#> 204: 0.716763    0.941402    3.460263    0.135371    0.098998    0.005260    0.748973    
#> 205: 0.721988    0.946171    3.461621    0.132991    0.100532    0.005551    0.752176    
#> 206: 0.725318    0.951802    3.462241    0.137182    0.100793    0.005711    0.751537    
#> 207: 0.724284    0.951196    3.460849    0.136944    0.098564    0.005819    0.751797    
#> 208: 0.721803    0.953403    3.460686    0.133089    0.098790    0.005807    0.751808    
#> 209: 0.722230    0.952769    3.459349    0.131442    0.098426    0.005895    0.750807    
#> 210: 0.723637    0.951397    3.458876    0.128276    0.097867    0.005866    0.752159    
#> 211: 0.725410    0.952397    3.460106    0.124329    0.097715    0.005810    0.752933    
#> 212: 0.726772    0.950213    3.461110    0.121595    0.097978    0.005699    0.754591    
#> 213: 0.728608    0.949014    3.461347    0.122863    0.098424    0.005666    0.755257    
#> 214: 0.728308    0.948840    3.461518    0.124752    0.098407    0.005695    0.755094    
#> 215: 0.728094    0.949406    3.462132    0.125743    0.097517    0.005724    0.755014    
#> 216: 0.728368    0.949111    3.462129    0.125242    0.096841    0.005779    0.756367    
#> 217: 0.726641    0.950973    3.461908    0.125023    0.096331    0.005731    0.756080    
#> 218: 0.726265    0.952400    3.461521    0.126013    0.095754    0.005647    0.755244    
#> 219: 0.725417    0.951800    3.460847    0.127384    0.096369    0.005602    0.754306    
#> 220: 0.723812    0.952602    3.460735    0.126823    0.096335    0.005549    0.754028    
#> 221: 0.723110    0.953168    3.460457    0.128274    0.096718    0.005485    0.754112    
#> 222: 0.723722    0.953108    3.460464    0.129829    0.096405    0.005444    0.755141    
#> 223: 0.724667    0.952604    3.460468    0.130544    0.096877    0.005386    0.755207    
#> 224: 0.726488    0.952826    3.461073    0.131757    0.096802    0.005331    0.755899    
#> 225: 0.727707    0.950812    3.461576    0.133473    0.096702    0.005268    0.756518    
#> 226: 0.727385    0.949524    3.461570    0.134454    0.097155    0.005203    0.756779    
#> 227: 0.726421    0.949155    3.461657    0.134896    0.097030    0.005176    0.757164    
#> 228: 0.727194    0.949610    3.461514    0.136107    0.097171    0.005141    0.756813    
#> 229: 0.726531    0.949451    3.461458    0.136074    0.097374    0.005109    0.756027    
#> 230: 0.727691    0.948476    3.461577    0.136574    0.097630    0.005124    0.755874    
#> 231: 0.728740    0.948271    3.462090    0.137201    0.097988    0.005143    0.755753    
#> 232: 0.728833    0.947176    3.462818    0.137587    0.098255    0.005183    0.755832    
#> 233: 0.729030    0.946190    3.462961    0.138048    0.097993    0.005181    0.755993    
#> 234: 0.728943    0.946313    3.463149    0.137742    0.097867    0.005172    0.756050    
#> 235: 0.729049    0.945708    3.463180    0.137574    0.098023    0.005177    0.756012    
#> 236: 0.728970    0.946170    3.463189    0.137119    0.097932    0.005166    0.757084    
#> 237: 0.729936    0.946099    3.463467    0.136591    0.097785    0.005181    0.757469    
#> 238: 0.729972    0.946366    3.463430    0.136470    0.097597    0.005192    0.757673    
#> 239: 0.729853    0.947377    3.463279    0.136662    0.097368    0.005191    0.757520    
#> 240: 0.730076    0.947163    3.463496    0.136401    0.097013    0.005203    0.757552    
#> 241: 0.730597    0.946526    3.463648    0.136280    0.096779    0.005223    0.757699    
#> 242: 0.729986    0.946178    3.463588    0.135451    0.096398    0.005260    0.758553    
#> 243: 0.729074    0.946625    3.463628    0.135255    0.096385    0.005272    0.759334    
#> 244: 0.728238    0.946866    3.463753    0.135630    0.096294    0.005319    0.759445    
#> 245: 0.727997    0.946648    3.463777    0.135440    0.096698    0.005310    0.759733    
#> 246: 0.727912    0.946727    3.463871    0.135917    0.097107    0.005358    0.759269    
#> 247: 0.727548    0.946437    3.464148    0.135257    0.097263    0.005374    0.759380    
#> 248: 0.727310    0.946728    3.464321    0.134914    0.097411    0.005370    0.759367    
#> 249: 0.727075    0.946777    3.464418    0.134364    0.097236    0.005409    0.759571    
#> 250: 0.728109    0.946894    3.464732    0.134421    0.096947    0.005468    0.759691    
#> 251: 0.729235    0.947328    3.465094    0.134755    0.096848    0.005492    0.759718    
#> 252: 0.730463    0.947294    3.465496    0.134845    0.096925    0.005504    0.759611    
#> 253: 0.731099    0.947215    3.465743    0.134729    0.097158    0.005521    0.759667    
#> 254: 0.731315    0.947268    3.466117    0.134911    0.097057    0.005545    0.759915    
#> 255: 0.731079    0.947620    3.466434    0.135024    0.096971    0.005575    0.760146    
#> 256: 0.730945    0.947697    3.466363    0.134936    0.096833    0.005598    0.760179    
#> 257: 0.730661    0.947364    3.466296    0.135170    0.096918    0.005610    0.759891    
#> 258: 0.730208    0.947104    3.466213    0.134824    0.097103    0.005589    0.759852    
#> 259: 0.729862    0.947119    3.466175    0.135099    0.097454    0.005585    0.759648    
#> 260: 0.729791    0.947464    3.466196    0.135839    0.097453    0.005599    0.759072    
#> 261: 0.729964    0.947261    3.466310    0.136818    0.097308    0.005603    0.759014    
#> 262: 0.730907    0.947250    3.466374    0.137191    0.097467    0.005634    0.759090    
#> 263: 0.731057    0.947352    3.466490    0.137256    0.097345    0.005658    0.759216    
#> 264: 0.731031    0.947143    3.466447    0.137451    0.097387    0.005666    0.759378    
#> 265: 0.731437    0.946939    3.466448    0.137670    0.097147    0.005692    0.759512    
#> 266: 0.732056    0.946977    3.466433    0.137701    0.096837    0.005710    0.759576    
#> 267: 0.732272    0.947009    3.466498    0.137326    0.096576    0.005725    0.759730    
#> 268: 0.732201    0.946734    3.466435    0.137534    0.096588    0.005739    0.759656    
#> 269: 0.732931    0.946446    3.466568    0.137825    0.096626    0.005763    0.759554    
#> 270: 0.733953    0.946537    3.466594    0.138145    0.096592    0.005770    0.759263    
#> 271: 0.734372    0.946564    3.466522    0.139046    0.096652    0.005788    0.759294    
#> 272: 0.734442    0.946725    3.466411    0.139482    0.096909    0.005804    0.759376    
#> 273: 0.734594    0.947177    3.466310    0.140023    0.097268    0.005824    0.759672    
#> 274: 0.734449    0.947060    3.466377    0.140458    0.097315    0.005834    0.759658    
#> 275: 0.734590    0.947213    3.466347    0.140331    0.097528    0.005841    0.759816    
#> 276: 0.734539    0.947244    3.466607    0.140288    0.097434    0.005839    0.759862    
#> 277: 0.734555    0.947429    3.466872    0.140308    0.097321    0.005840    0.759911    
#> 278: 0.734693    0.947245    3.466956    0.140124    0.097314    0.005828    0.759932    
#> 279: 0.734523    0.946973    3.466998    0.140016    0.097542    0.005817    0.760104    
#> 280: 0.734498    0.946984    3.467031    0.140046    0.097830    0.005799    0.759773    
#> 281: 0.734224    0.946999    3.467105    0.140015    0.098022    0.005778    0.759850    
#> 282: 0.734280    0.946938    3.467215    0.139673    0.098300    0.005775    0.759841    
#> 283: 0.734323    0.946985    3.467254    0.139382    0.098702    0.005776    0.759879    
#> 284: 0.734410    0.946689    3.467285    0.139411    0.098814    0.005776    0.759628    
#> 285: 0.734683    0.946731    3.467179    0.139266    0.098936    0.005808    0.759610    
#> 286: 0.735041    0.946738    3.467212    0.138994    0.099085    0.005820    0.759418    
#> 287: 0.735082    0.946818    3.467236    0.138833    0.099238    0.005822    0.759361    
#> 288: 0.735689    0.946623    3.467310    0.138936    0.099282    0.005835    0.759474    
#> 289: 0.736208    0.946613    3.467427    0.139146    0.099393    0.005847    0.759471    
#> 290: 0.736383    0.946699    3.467436    0.139338    0.099589    0.005840    0.759238    
#> 291: 0.736774    0.946820    3.467574    0.139174    0.099527    0.005847    0.759014    
#> 292: 0.736859    0.946614    3.467670    0.139176    0.099553    0.005843    0.758807    
#> 293: 0.736987    0.946357    3.467753    0.139135    0.099504    0.005830    0.758725    
#> 294: 0.736901    0.946325    3.467725    0.139018    0.099406    0.005829    0.758582    
#> 295: 0.737054    0.946040    3.467701    0.139011    0.099443    0.005823    0.758500    
#> 296: 0.737106    0.945862    3.467780    0.139246    0.099507    0.005832    0.758484    
#> 297: 0.737224    0.945892    3.467909    0.139082    0.099583    0.005834    0.758519    
#> 298: 0.737474    0.945459    3.468043    0.139353    0.099780    0.005833    0.758475    
#> 299: 0.737590    0.945465    3.468038    0.139450    0.099828    0.005833    0.758319    
#> 300: 0.737915    0.945292    3.468190    0.139511    0.099913    0.005847    0.758196    
#> 301: 0.738174    0.945225    3.468183    0.139709    0.099803    0.005842    0.758257    
#> 302: 0.738231    0.945166    3.468168    0.139945    0.099676    0.005834    0.758171    
#> 303: 0.738023    0.945296    3.468116    0.139900    0.099635    0.005825    0.758048    
#> 304: 0.738114    0.945450    3.468111    0.139787    0.099577    0.005828    0.757958    
#> 305: 0.738416    0.944891    3.468237    0.139875    0.099777    0.005823    0.757909    
#> 306: 0.738293    0.944608    3.468279    0.139882    0.099802    0.005821    0.757873    
#> 307: 0.738416    0.944362    3.468273    0.139802    0.099962    0.005811    0.757981    
#> 308: 0.738327    0.944121    3.468233    0.139859    0.100012    0.005793    0.758240    
#> 309: 0.738177    0.943826    3.468125    0.139692    0.100033    0.005783    0.758449    
#> 310: 0.738394    0.943729    3.468038    0.139712    0.100035    0.005778    0.758427    
#> 311: 0.738395    0.943696    3.468011    0.139656    0.100058    0.005779    0.758251    
#> 312: 0.738403    0.943671    3.467948    0.139708    0.100105    0.005781    0.758159    
#> 313: 0.738010    0.943531    3.467926    0.139779    0.100027    0.005781    0.758238    
#> 314: 0.737627    0.943721    3.467810    0.139794    0.100074    0.005772    0.758200    
#> 315: 0.737027    0.944044    3.467703    0.140026    0.100105    0.005769    0.758231    
#> 316: 0.736875    0.944161    3.467634    0.139974    0.100196    0.005759    0.758292    
#> 317: 0.736546    0.944287    3.467573    0.140158    0.100301    0.005747    0.758310    
#> 318: 0.736471    0.944517    3.467440    0.140245    0.100353    0.005742    0.758050    
#> 319: 0.736609    0.944506    3.467459    0.140451    0.100454    0.005747    0.757876    
#> 320: 0.736415    0.944505    3.467390    0.140544    0.100510    0.005765    0.757771    
#> 321: 0.736326    0.944583    3.467331    0.140387    0.100645    0.005777    0.757804    
#> 322: 0.736161    0.944679    3.467213    0.140657    0.100618    0.005778    0.757849    
#> 323: 0.735755    0.944728    3.467148    0.140916    0.100677    0.005764    0.757818    
#> 324: 0.735621    0.944768    3.467151    0.141010    0.100624    0.005757    0.757719    
#> 325: 0.735628    0.944912    3.467157    0.140904    0.100588    0.005757    0.757564    
#> 326: 0.735856    0.944738    3.467183    0.140782    0.100422    0.005751    0.757653    
#> 327: 0.735858    0.944786    3.467233    0.140686    0.100232    0.005766    0.757704    
#> 328: 0.735806    0.944879    3.467241    0.140523    0.100133    0.005772    0.757528    
#> 329: 0.736017    0.944851    3.467333    0.140483    0.099997    0.005777    0.757559    
#> 330: 0.736067    0.944879    3.467450    0.140352    0.100010    0.005802    0.757658    
#> 331: 0.736238    0.944936    3.467556    0.140156    0.099999    0.005819    0.757616    
#> 332: 0.736291    0.944801    3.467632    0.139985    0.099909    0.005839    0.757636    
#> 333: 0.736289    0.944843    3.467573    0.139897    0.099907    0.005852    0.757613    
#> 334: 0.736193    0.944724    3.467495    0.139990    0.099838    0.005856    0.757618    
#> 335: 0.735941    0.944863    3.467429    0.139849    0.099760    0.005860    0.757572    
#> 336: 0.735575    0.945010    3.467387    0.139795    0.099596    0.005879    0.757676    
#> 337: 0.735403    0.945315    3.467334    0.139608    0.099577    0.005886    0.757624    
#> 338: 0.735395    0.945402    3.467317    0.139637    0.099601    0.005884    0.757580    
#> 339: 0.735234    0.945584    3.467272    0.139787    0.099619    0.005882    0.757508    
#> 340: 0.735060    0.945624    3.467298    0.139741    0.099778    0.005880    0.757484    
#> 341: 0.735107    0.945635    3.467351    0.139719    0.099865    0.005880    0.757494    
#> 342: 0.734896    0.945442    3.467374    0.139579    0.099736    0.005871    0.757443    
#> 343: 0.734556    0.945521    3.467401    0.139425    0.099729    0.005856    0.757417    
#> 344: 0.734518    0.945600    3.467418    0.139219    0.099661    0.005847    0.757537    
#> 345: 0.734549    0.945543    3.467449    0.139097    0.099777    0.005837    0.757577    
#> 346: 0.734585    0.945600    3.467451    0.138948    0.099864    0.005828    0.757533    
#> 347: 0.734756    0.945601    3.467410    0.138928    0.099900    0.005830    0.757538    
#> 348: 0.734670    0.945666    3.467368    0.138995    0.100034    0.005838    0.757491    
#> 349: 0.734778    0.945626    3.467303    0.139017    0.100031    0.005850    0.757616    
#> 350: 0.734739    0.945520    3.467237    0.139227    0.100039    0.005856    0.757689    
#> 351: 0.734550    0.945730    3.467176    0.138938    0.100160    0.005859    0.757672    
#> 352: 0.734300    0.945893    3.467171    0.138695    0.100070    0.005850    0.757820    
#> 353: 0.734314    0.945961    3.467168    0.138469    0.100048    0.005858    0.757749    
#> 354: 0.734379    0.945900    3.467108    0.138286    0.100066    0.005866    0.757739    
#> 355: 0.734530    0.945754    3.467082    0.138278    0.100099    0.005865    0.757799    
#> 356: 0.734500    0.945619    3.467097    0.138174    0.100155    0.005868    0.757916    
#> 357: 0.734646    0.945614    3.467080    0.138234    0.100152    0.005875    0.757912    
#> 358: 0.734633    0.945744    3.467102    0.138269    0.100107    0.005873    0.757806    
#> 359: 0.734543    0.945835    3.467110    0.138121    0.100025    0.005878    0.757802    
#> 360: 0.734240    0.945896    3.467026    0.137964    0.099996    0.005879    0.757717    
#> 361: 0.733979    0.945917    3.466959    0.137763    0.100048    0.005877    0.757797    
#> 362: 0.734039    0.945962    3.466925    0.137737    0.100057    0.005877    0.757733    
#> 363: 0.733915    0.945947    3.466898    0.137415    0.099922    0.005880    0.757774    
#> 364: 0.734009    0.946027    3.466879    0.137250    0.099886    0.005875    0.757925    
#> 365: 0.734000    0.946082    3.466889    0.137144    0.099780    0.005884    0.757983    
#> 366: 0.733979    0.946083    3.466822    0.137146    0.099831    0.005893    0.757966    
#> 367: 0.734085    0.946126    3.466809    0.137418    0.099722    0.005894    0.757882    
#> 368: 0.734371    0.946089    3.466816    0.137491    0.099768    0.005900    0.757787    
#> 369: 0.734390    0.946059    3.466789    0.137498    0.099875    0.005896    0.757766    
#> 370: 0.734346    0.946083    3.466784    0.137633    0.099928    0.005895    0.757753    
#> 371: 0.734276    0.946108    3.466709    0.137648    0.100032    0.005890    0.757780    
#> 372: 0.734312    0.946093    3.466688    0.137817    0.099980    0.005895    0.757819    
#> 373: 0.734300    0.946277    3.466639    0.138028    0.100019    0.005893    0.757776    
#> 374: 0.734355    0.946465    3.466567    0.138360    0.100032    0.005892    0.757670    
#> 375: 0.734364    0.946448    3.466526    0.138619    0.099950    0.005883    0.757684    
#> 376: 0.734368    0.946608    3.466525    0.138724    0.099877    0.005883    0.757636    
#> 377: 0.734446    0.946597    3.466547    0.138767    0.099901    0.005876    0.757554    
#> 378: 0.734264    0.946617    3.466505    0.138741    0.099909    0.005874    0.757629    
#> 379: 0.734197    0.946550    3.466510    0.138564    0.100002    0.005867    0.757535    
#> 380: 0.733916    0.946615    3.466438    0.138476    0.100121    0.005860    0.757521    
#> 381: 0.733733    0.946656    3.466394    0.138443    0.100148    0.005852    0.757481    
#> 382: 0.733662    0.946694    3.466346    0.138401    0.100170    0.005846    0.757340    
#> 383: 0.733703    0.946721    3.466355    0.138193    0.100094    0.005850    0.757338    
#> 384: 0.733765    0.946629    3.466412    0.138100    0.100105    0.005854    0.757327    
#> 385: 0.733974    0.946604    3.466491    0.138054    0.100161    0.005868    0.757360    
#> 386: 0.734181    0.946754    3.466590    0.137921    0.100305    0.005875    0.757408    
#> 387: 0.734295    0.946785    3.466655    0.137869    0.100361    0.005877    0.757366    
#> 388: 0.734388    0.946715    3.466733    0.137735    0.100465    0.005874    0.757343    
#> 389: 0.734480    0.946559    3.466750    0.137757    0.100499    0.005868    0.757410    
#> 390: 0.734499    0.946508    3.466761    0.137629    0.100563    0.005861    0.757315    
#> 391: 0.734432    0.946495    3.466710    0.137603    0.100585    0.005859    0.757213    
#> 392: 0.734479    0.946695    3.466755    0.137762    0.100590    0.005859    0.757272    
#> 393: 0.734418    0.946615    3.466748    0.137728    0.100572    0.005858    0.757327    
#> 394: 0.734351    0.946621    3.466742    0.137688    0.100560    0.005856    0.757338    
#> 395: 0.734601    0.946674    3.466805    0.137584    0.100603    0.005860    0.757312    
#> 396: 0.734780    0.946718    3.466876    0.137437    0.100573    0.005863    0.757349    
#> 397: 0.735018    0.946652    3.466967    0.137201    0.100630    0.005865    0.757418    
#> 398: 0.735183    0.946536    3.467042    0.137148    0.100631    0.005871    0.757540    
#> 399: 0.735167    0.946589    3.467095    0.137086    0.100691    0.005875    0.757495    
#> 400: 0.735195    0.946645    3.467134    0.136990    0.100672    0.005875    0.757448    
#> 401: 0.735166    0.946826    3.467123    0.137104    0.100635    0.005890    0.757450    
#> 402: 0.735171    0.946886    3.467137    0.137069    0.100666    0.005903    0.757372    
#> 403: 0.735263    0.946826    3.467112    0.137109    0.100633    0.005915    0.757287    
#> 404: 0.735335    0.946955    3.467062    0.137290    0.100669    0.005919    0.757122    
#> 405: 0.735219    0.947050    3.467019    0.137508    0.100603    0.005922    0.757124    
#> 406: 0.735227    0.947166    3.466979    0.137566    0.100595    0.005925    0.757136    
#> 407: 0.735277    0.947199    3.466965    0.137491    0.100683    0.005925    0.757147    
#> 408: 0.735334    0.947256    3.466957    0.137447    0.100707    0.005924    0.757236    
#> 409: 0.735348    0.947227    3.466900    0.137485    0.100742    0.005922    0.757232    
#> 410: 0.735404    0.947272    3.466822    0.137506    0.100846    0.005912    0.757268    
#> 411: 0.735446    0.947086    3.466788    0.137556    0.100825    0.005913    0.757454    
#> 412: 0.735473    0.947123    3.466753    0.137684    0.100833    0.005915    0.757471    
#> 413: 0.735546    0.947191    3.466705    0.137908    0.100799    0.005908    0.757539    
#> 414: 0.735462    0.947181    3.466710    0.138000    0.100768    0.005905    0.757580    
#> 415: 0.735585    0.947130    3.466703    0.138142    0.100773    0.005901    0.757514    
#> 416: 0.735772    0.947157    3.466702    0.138211    0.100741    0.005898    0.757483    
#> 417: 0.735940    0.947166    3.466717    0.138241    0.100770    0.005895    0.757501    
#> 418: 0.735694    0.947226    3.466711    0.138116    0.100734    0.005898    0.757419    
#> 419: 0.735554    0.947331    3.466675    0.138215    0.100737    0.005905    0.757355    
#> 420: 0.735480    0.947370    3.466673    0.138206    0.100714    0.005907    0.757340    
#> 421: 0.735357    0.947449    3.466672    0.138233    0.100661    0.005903    0.757311    
#> 422: 0.735415    0.947367    3.466666    0.138053    0.100697    0.005900    0.757395    
#> 423: 0.735594    0.947318    3.466732    0.138011    0.100813    0.005895    0.757391    
#> 424: 0.735535    0.947239    3.466750    0.137949    0.100821    0.005888    0.757354    
#> 425: 0.735591    0.947253    3.466777    0.137883    0.100848    0.005887    0.757379    
#> 426: 0.735627    0.947372    3.466781    0.137922    0.100827    0.005880    0.757339    
#> 427: 0.735613    0.947289    3.466778    0.137951    0.100778    0.005872    0.757280    
#> 428: 0.735451    0.947371    3.466752    0.138039    0.100792    0.005867    0.757229    
#> 429: 0.735386    0.947320    3.466777    0.138082    0.100754    0.005861    0.757200    
#> 430: 0.735314    0.947448    3.466764    0.138136    0.100685    0.005859    0.757181    
#> 431: 0.735215    0.947426    3.466730    0.138194    0.100634    0.005860    0.757172    
#> 432: 0.735132    0.947506    3.466724    0.138139    0.100538    0.005868    0.757125    
#> 433: 0.735083    0.947610    3.466735    0.138034    0.100514    0.005876    0.757039    
#> 434: 0.734916    0.947530    3.466781    0.137827    0.100551    0.005875    0.757001    
#> 435: 0.734850    0.947560    3.466798    0.137823    0.100637    0.005869    0.756894    
#> 436: 0.734763    0.947486    3.466802    0.137780    0.100613    0.005866    0.756866    
#> 437: 0.734659    0.947564    3.466761    0.137824    0.100665    0.005866    0.756927    
#> 438: 0.734696    0.947666    3.466792    0.137998    0.100666    0.005862    0.756903    
#> 439: 0.734679    0.947698    3.466795    0.138141    0.100606    0.005856    0.756893    
#> 440: 0.734538    0.947753    3.466806    0.138232    0.100617    0.005853    0.756876    
#> 441: 0.734546    0.947738    3.466836    0.138310    0.100591    0.005859    0.756888    
#> 442: 0.734417    0.947823    3.466850    0.138337    0.100558    0.005858    0.756789    
#> 443: 0.734403    0.947922    3.466824    0.138361    0.100445    0.005862    0.756686    
#> 444: 0.734470    0.948100    3.466776    0.138495    0.100340    0.005868    0.756675    
#> 445: 0.734456    0.948205    3.466722    0.138492    0.100414    0.005869    0.756614    
#> 446: 0.734313    0.948233    3.466681    0.138512    0.100390    0.005869    0.756587    
#> 447: 0.734311    0.948293    3.466660    0.138577    0.100360    0.005870    0.756504    
#> 448: 0.734209    0.948269    3.466680    0.138634    0.100274    0.005877    0.756460    
#> 449: 0.734254    0.948344    3.466762    0.138702    0.100208    0.005882    0.756473    
#> 450: 0.734252    0.948359    3.466767    0.138776    0.100190    0.005890    0.756378    
#> 451: 0.734309    0.948457    3.466748    0.138877    0.100135    0.005889    0.756389    
#> 452: 0.734220    0.948524    3.466715    0.138904    0.100172    0.005887    0.756315    
#> 453: 0.734142    0.948496    3.466697    0.138963    0.100173    0.005882    0.756223    
#> 454: 0.734023    0.948610    3.466643    0.138984    0.100121    0.005881    0.756159    
#> 455: 0.734026    0.948649    3.466606    0.138887    0.100076    0.005884    0.756180    
#> 456: 0.733991    0.948637    3.466602    0.138727    0.100060    0.005891    0.756197    
#> 457: 0.733913    0.948621    3.466640    0.138669    0.100108    0.005888    0.756150    
#> 458: 0.733839    0.948747    3.466653    0.138657    0.100086    0.005876    0.756147    
#> 459: 0.733693    0.948887    3.466656    0.138738    0.100037    0.005872    0.756168    
#> 460: 0.733571    0.948991    3.466615    0.138790    0.100076    0.005872    0.756172    
#> 461: 0.733358    0.949038    3.466585    0.138832    0.099991    0.005873    0.756225    
#> 462: 0.733206    0.949169    3.466567    0.138960    0.099955    0.005880    0.756184    
#> 463: 0.733231    0.949171    3.466568    0.139030    0.099971    0.005884    0.756085    
#> 464: 0.733218    0.949173    3.466555    0.139050    0.099922    0.005886    0.755974    
#> 465: 0.733269    0.949035    3.466543    0.139182    0.099856    0.005889    0.755955    
#> 466: 0.733327    0.949132    3.466490    0.139277    0.099792    0.005884    0.755894    
#> 467: 0.733324    0.949158    3.466458    0.139297    0.099769    0.005881    0.755851    
#> 468: 0.733399    0.949173    3.466456    0.139359    0.099728    0.005877    0.755936    
#> 469: 0.733325    0.949271    3.466431    0.139359    0.099729    0.005875    0.755960    
#> 470: 0.733230    0.949369    3.466400    0.139322    0.099718    0.005873    0.755939    
#> 471: 0.733015    0.949366    3.466352    0.139211    0.099723    0.005868    0.755959    
#> 472: 0.732864    0.949396    3.466343    0.139128    0.099744    0.005862    0.756012    
#> 473: 0.732657    0.949392    3.466337    0.139153    0.099748    0.005861    0.755984    
#> 474: 0.732717    0.949349    3.466347    0.139316    0.099719    0.005866    0.756008    
#> 475: 0.732806    0.949406    3.466356    0.139410    0.099679    0.005872    0.755892    
#> 476: 0.732848    0.949431    3.466336    0.139393    0.099608    0.005876    0.755918    
#> 477: 0.732863    0.949415    3.466358    0.139384    0.099557    0.005878    0.755825    
#> 478: 0.732756    0.949428    3.466372    0.139389    0.099537    0.005878    0.755760    
#> 479: 0.732804    0.949466    3.466390    0.139391    0.099548    0.005877    0.755785    
#> 480: 0.732887    0.949371    3.466449    0.139334    0.099589    0.005883    0.755835    
#> 481: 0.733015    0.949360    3.466472    0.139369    0.099615    0.005882    0.755777    
#> 482: 0.733236    0.949276    3.466510    0.139368    0.099582    0.005881    0.755805    
#> 483: 0.733247    0.949162    3.466536    0.139297    0.099569    0.005877    0.755792    
#> 484: 0.733236    0.949062    3.466552    0.139242    0.099535    0.005874    0.755842    
#> 485: 0.733364    0.949036    3.466604    0.139129    0.099515    0.005874    0.755956    
#> 486: 0.733475    0.949057    3.466631    0.139090    0.099502    0.005871    0.755947    
#> 487: 0.733652    0.949097    3.466662    0.139167    0.099472    0.005876    0.755932    
#> 488: 0.733637    0.949095    3.466687    0.139142    0.099435    0.005880    0.755888    
#> 489: 0.733666    0.949040    3.466685    0.139147    0.099381    0.005883    0.756011    
#> 490: 0.733622    0.949033    3.466702    0.139066    0.099319    0.005883    0.756035    
#> 491: 0.733589    0.949102    3.466739    0.139026    0.099281    0.005890    0.756024    
#> 492: 0.733589    0.949143    3.466768    0.139032    0.099284    0.005898    0.756078    
#> 493: 0.733622    0.949116    3.466795    0.139028    0.099212    0.005907    0.756108    
#> 494: 0.733695    0.949096    3.466822    0.138957    0.099179    0.005908    0.756033    
#> 495: 0.733773    0.949113    3.466850    0.138846    0.099196    0.005911    0.756036    
#> 496: 0.733887    0.949127    3.466851    0.138770    0.099176    0.005913    0.756036    
#> 497: 0.733943    0.949115    3.466852    0.138776    0.099165    0.005919    0.756007    
#> 498: 0.733998    0.949107    3.466839    0.138809    0.099142    0.005924    0.755891    
#> 499: 0.734068    0.949177    3.466830    0.138796    0.099134    0.005922    0.755823    
#> 500: 0.734166    0.949131    3.466818    0.138818    0.099103    0.005923    0.755745    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.324939    0.980760    3.444349    0.392401    0.091316    0.016800    1.760015    
#> 002: 0.477138    0.984458    3.447821    0.372781    0.086750    0.016088    1.170493    
#> 003: 0.645765    0.878245    3.459168    0.354142    0.093105    0.015283    0.931406    
#> 004: 0.590142    0.906300    3.447659    0.339725    0.088450    0.014522    0.852789    
#> 005: 0.677479    0.901586    3.434902    0.470804    0.084027    0.013796    0.796286    
#> 006: 0.622702    0.905664    3.431030    0.464408    0.079826    0.013106    0.738538    
#> 007: 0.592797    0.912636    3.421857    0.441187    0.075835    0.012725    0.768127    
#> 008: 0.571264    0.940810    3.403310    0.479126    0.072043    0.013740    0.755907    
#> 009: 0.557902    0.926977    3.396641    0.577861    0.083030    0.013053    0.754451    
#> 010: 0.557477    0.930116    3.397994    0.597021    0.078878    0.013988    0.749877    
#> 011: 0.603998    0.937734    3.394917    0.616780    0.074935    0.016025    0.731700    
#> 012: 0.569436    0.952512    3.381983    0.613274    0.071188    0.019081    0.711538    
#> 013: 0.527722    0.974718    3.377702    0.582611    0.067628    0.019851    0.726457    
#> 014: 0.562275    0.975314    3.385458    0.643885    0.064247    0.019371    0.711155    
#> 015: 0.588577    0.964370    3.399944    0.626481    0.061035    0.018402    0.715735    
#> 016: 0.609399    0.970194    3.401413    0.618649    0.058399    0.017482    0.727384    
#> 017: 0.582488    0.980464    3.405143    0.606210    0.061723    0.016608    0.709219    
#> 018: 0.570504    0.975511    3.391363    0.599025    0.060524    0.017156    0.705714    
#> 019: 0.540002    0.971307    3.390504    0.569074    0.057498    0.016593    0.703707    
#> 020: 0.593005    0.966878    3.393432    0.630701    0.054623    0.019411    0.702941    
#> 021: 0.596763    0.950691    3.408562    0.599166    0.051892    0.018838    0.701514    
#> 022: 0.593837    0.951885    3.414771    0.572153    0.055091    0.018397    0.692164    
#> 023: 0.676182    0.946048    3.430458    0.605815    0.053914    0.022880    0.707136    
#> 024: 0.650440    0.953740    3.413778    0.636277    0.051219    0.022009    0.678987    
#> 025: 0.609505    0.939253    3.408083    0.604463    0.056380    0.022718    0.709394    
#> 026: 0.580766    0.969356    3.403982    0.574240    0.055493    0.021582    0.717743    
#> 027: 0.563832    0.965681    3.403717    0.629185    0.052753    0.020503    0.742742    
#> 028: 0.605915    0.967389    3.397721    0.700733    0.052476    0.019478    0.719842    
#> 029: 0.588964    0.959945    3.390502    0.665697    0.060653    0.018653    0.715956    
#> 030: 0.575444    0.987084    3.384271    0.637496    0.072033    0.017720    0.709121    
#> 031: 0.552668    0.955717    3.393027    0.690001    0.074230    0.017365    0.692428    
#> 032: 0.603106    0.944914    3.406012    0.701087    0.070519    0.019931    0.692917    
#> 033: 0.570837    0.955090    3.404861    0.686024    0.066993    0.021831    0.697613    
#> 034: 0.583567    0.960814    3.401052    0.651723    0.063643    0.020739    0.706490    
#> 035: 0.552699    0.949497    3.387088    0.619137    0.060461    0.024067    0.689517    
#> 036: 0.545350    0.958944    3.392130    0.588180    0.057438    0.023492    0.698794    
#> 037: 0.521424    0.969466    3.395447    0.558771    0.054566    0.025121    0.725045    
#> 038: 0.558383    0.954572    3.397278    0.574464    0.051838    0.024282    0.720478    
#> 039: 0.589491    0.960239    3.408866    0.666064    0.049498    0.026495    0.702226    
#> 040: 0.565192    0.964643    3.403811    0.632760    0.049506    0.025170    0.700771    
#> 041: 0.521135    0.966105    3.396340    0.601122    0.047031    0.024552    0.712830    
#> 042: 0.574072    0.962787    3.392585    0.571066    0.048951    0.023325    0.697317    
#> 043: 0.545060    0.975732    3.376297    0.542513    0.046503    0.022998    0.693040    
#> 044: 0.518292    0.976083    3.378998    0.542262    0.046108    0.023268    0.697693    
#> 045: 0.561739    0.983832    3.383524    0.584632    0.049053    0.022347    0.706883    
#> 046: 0.509187    0.970628    3.384841    0.555400    0.047487    0.021230    0.709703    
#> 047: 0.531634    0.975506    3.382695    0.527630    0.045112    0.020168    0.700115    
#> 048: 0.553043    0.960336    3.385505    0.543358    0.054358    0.019160    0.707692    
#> 049: 0.572164    0.962333    3.393544    0.542441    0.058544    0.019626    0.709582    
#> 050: 0.591288    0.944764    3.395553    0.668035    0.067293    0.020023    0.701237    
#> 051: 0.579972    0.958293    3.390538    0.688628    0.063928    0.020180    0.705719    
#> 052: 0.616965    0.963675    3.401631    0.683442    0.060732    0.019171    0.700011    
#> 053: 0.611791    0.956910    3.389246    0.772472    0.064111    0.018213    0.680555    
#> 054: 0.544194    0.968992    3.388988    0.733848    0.068384    0.019199    0.699345    
#> 055: 0.590384    0.965426    3.397498    0.697156    0.064965    0.022417    0.695538    
#> 056: 0.600936    0.950409    3.387154    0.735571    0.061717    0.021297    0.703523    
#> 057: 0.646698    0.959746    3.401479    0.864349    0.058631    0.020232    0.714121    
#> 058: 0.629766    0.945249    3.402343    0.821132    0.059553    0.020979    0.725950    
#> 059: 0.630821    0.900153    3.418800    0.780075    0.056575    0.027681    0.738780    
#> 060: 0.607360    0.891346    3.428579    0.741071    0.055964    0.029007    0.747439    
#> 061: 0.685382    0.905388    3.432938    0.704018    0.056565    0.027557    0.734449    
#> 062: 0.675950    0.921042    3.428189    0.753955    0.059824    0.026179    0.751185    
#> 063: 0.693177    0.924751    3.420047    0.741542    0.056833    0.027779    0.727241    
#> 064: 0.588119    0.938473    3.412267    0.704465    0.058643    0.027327    0.732047    
#> 065: 0.581313    0.952771    3.395649    0.669242    0.059265    0.025961    0.696564    
#> 066: 0.591258    0.960907    3.402212    0.635780    0.056302    0.024663    0.703579    
#> 067: 0.600697    0.976641    3.397216    0.615280    0.057158    0.023430    0.689614    
#> 068: 0.582761    0.964294    3.408264    0.626067    0.065295    0.022998    0.710264    
#> 069: 0.589149    0.971698    3.390893    0.632295    0.062030    0.025746    0.709831    
#> 070: 0.591698    0.956064    3.405579    0.628015    0.058929    0.028320    0.710012    
#> 071: 0.594431    0.986292    3.374547    0.825514    0.061880    0.029576    0.710184    
#> 072: 0.572943    0.963036    3.388873    0.784264    0.058786    0.030050    0.702076    
#> 073: 0.627416    0.968247    3.402062    0.892491    0.055847    0.028547    0.713735    
#> 074: 0.614595    0.948313    3.405634    0.847866    0.053055    0.028251    0.711774    
#> 075: 0.634565    0.946012    3.418347    0.805473    0.050402    0.026838    0.721524    
#> 076: 0.660391    0.982301    3.417970    0.765199    0.055090    0.025496    0.697932    
#> 077: 0.687546    0.939420    3.419118    0.822030    0.052335    0.024222    0.713284    
#> 078: 0.705800    0.922448    3.417098    0.929048    0.049718    0.026259    0.695721    
#> 079: 0.632315    0.928798    3.413486    0.882596    0.047232    0.029492    0.715718    
#> 080: 0.658251    0.929868    3.420967    0.838466    0.044871    0.033859    0.736391    
#> 081: 0.633214    0.942417    3.411985    0.800037    0.042627    0.035670    0.705033    
#> 082: 0.609550    0.932783    3.414530    0.760035    0.040496    0.033887    0.709064    
#> 083: 0.654631    0.943727    3.418477    0.893154    0.038471    0.032193    0.727208    
#> 084: 0.647175    0.940915    3.404562    0.848496    0.045059    0.030583    0.722970    
#> 085: 0.580941    0.956737    3.416015    0.806072    0.043487    0.029054    0.711460    
#> 086: 0.636632    0.963060    3.405905    0.765768    0.046392    0.027601    0.709232    
#> 087: 0.657618    0.964835    3.401002    0.899161    0.048733    0.026221    0.701759    
#> 088: 0.573989    0.940930    3.402427    0.854203    0.046597    0.025653    0.718174    
#> 089: 0.587969    0.939385    3.411394    0.811493    0.048441    0.024370    0.714101    
#> 090: 0.598062    0.935041    3.400712    0.770918    0.046019    0.023152    0.725061    
#> 091: 0.608221    0.936264    3.388535    0.739665    0.043718    0.022731    0.705339    
#> 092: 0.552793    0.948241    3.384888    0.702682    0.041532    0.025317    0.690028    
#> 093: 0.503003    0.953397    3.382708    0.667548    0.039456    0.025900    0.697357    
#> 094: 0.545809    0.973302    3.390239    0.639497    0.049103    0.027637    0.695663    
#> 095: 0.560211    0.957916    3.402429    0.607522    0.050120    0.026255    0.699527    
#> 096: 0.544780    0.953874    3.394138    0.613562    0.047614    0.024993    0.679951    
#> 097: 0.584127    0.981380    3.393358    0.648235    0.046551    0.023744    0.701575    
#> 098: 0.564610    0.983180    3.398049    0.644405    0.047046    0.023791    0.708047    
#> 099: 0.520704    0.973842    3.372665    0.612185    0.047458    0.022602    0.718905    
#> 100: 0.524642    0.977594    3.379824    0.581576    0.049366    0.021472    0.700645    
#> 101: 0.528464    0.953896    3.372460    0.552497    0.050380    0.020398    0.715154    
#> 102: 0.538843    0.955905    3.376465    0.549851    0.047861    0.019378    0.716726    
#> 103: 0.594406    0.945926    3.396992    0.605679    0.045468    0.018409    0.716507    
#> 104: 0.581922    0.955788    3.412271    0.577877    0.043194    0.021565    0.718990    
#> 105: 0.588196    0.947324    3.407208    0.575265    0.055700    0.020487    0.717772    
#> 106: 0.587037    0.948228    3.406592    0.565008    0.057399    0.019658    0.704647    
#> 107: 0.592376    0.953760    3.411450    0.538791    0.054529    0.021636    0.698042    
#> 108: 0.585963    0.950968    3.411825    0.547735    0.060853    0.021579    0.707934    
#> 109: 0.584003    0.958388    3.410658    0.588702    0.059253    0.020500    0.706020    
#> 110: 0.563707    0.936794    3.399228    0.559267    0.056290    0.019475    0.704557    
#> 111: 0.560386    0.944924    3.405159    0.531303    0.057405    0.018502    0.699230    
#> 112: 0.577647    0.932711    3.398467    0.570151    0.054534    0.017576    0.729663    
#> 113: 0.578075    0.950778    3.407686    0.628788    0.051808    0.016918    0.719468    
#> 114: 0.589277    0.961951    3.405151    0.597348    0.050140    0.018659    0.723047    
#> 115: 0.579593    0.926962    3.399597    0.567481    0.051291    0.017726    0.733158    
#> 116: 0.562085    0.963125    3.407779    0.539107    0.048726    0.016899    0.735603    
#> 117: 0.524257    0.968666    3.405214    0.512152    0.056843    0.016808    0.732683    
#> 118: 0.560937    0.976665    3.391512    0.540780    0.057603    0.015968    0.708989    
#> 119: 0.594593    0.974566    3.392244    0.629272    0.054723    0.019047    0.728059    
#> 120: 0.542327    0.966030    3.390622    0.597809    0.051987    0.018235    0.717787    
#> 121: 0.551485    0.968899    3.396649    0.567918    0.059322    0.017891    0.708045    
#> 122: 0.580578    0.948909    3.406148    0.539522    0.056356    0.017251    0.720603    
#> 123: 0.636528    0.978326    3.397105    0.715034    0.053539    0.018057    0.725030    
#> 124: 0.561372    1.003041    3.378448    0.679283    0.050862    0.017154    0.725827    
#> 125: 0.563148    0.991038    3.385811    0.645319    0.048319    0.017006    0.723346    
#> 126: 0.515743    1.014740    3.369588    0.613053    0.061999    0.016156    0.748667    
#> 127: 0.541067    0.975374    3.383421    0.582400    0.060807    0.015348    0.748173    
#> 128: 0.544674    0.959428    3.402795    0.553280    0.057767    0.015043    0.742631    
#> 129: 0.587902    0.949557    3.408771    0.525616    0.060617    0.018475    0.731252    
#> 130: 0.647526    0.967013    3.413099    0.523672    0.058873    0.022047    0.709291    
#> 131: 0.620521    0.948138    3.406793    0.593980    0.061093    0.028137    0.689868    
#> 132: 0.584223    0.948331    3.396986    0.564281    0.058038    0.026730    0.685434    
#> 133: 0.561769    0.954188    3.403732    0.542953    0.055137    0.025394    0.706472    
#> 134: 0.613517    0.938826    3.409683    0.683901    0.052380    0.027114    0.697961    
#> 135: 0.590115    0.921272    3.419446    0.649706    0.049761    0.025978    0.706670    
#> 136: 0.576911    0.918488    3.416244    0.617221    0.053108    0.024679    0.696020    
#> 137: 0.628386    0.933665    3.415371    0.586360    0.050452    0.025889    0.717578    
#> 138: 0.553725    0.946706    3.389360    0.576252    0.047930    0.024594    0.712980    
#> 139: 0.568585    0.949943    3.405182    0.624334    0.045533    0.023364    0.724095    
#> 140: 0.585173    0.978575    3.401090    0.597137    0.045640    0.022196    0.736499    
#> 141: 0.558918    0.941173    3.403205    0.567280    0.056797    0.021086    0.715952    
#> 142: 0.556051    0.927832    3.411643    0.538916    0.068421    0.020032    0.709620    
#> 143: 0.544979    0.952380    3.403617    0.547592    0.074832    0.019031    0.724475    
#> 144: 0.586520    0.973807    3.406036    0.544293    0.071091    0.018079    0.698811    
#> 145: 0.536916    0.984196    3.381762    0.595015    0.067536    0.017175    0.706500    
#> 146: 0.540351    0.983489    3.388138    0.597111    0.064160    0.016902    0.712977    
#> 147: 0.533894    0.975590    3.376277    0.662327    0.060952    0.017378    0.701575    
#> 148: 0.507880    0.981494    3.393787    0.629210    0.057904    0.019862    0.706264    
#> 149: 0.531079    0.969977    3.390480    0.644458    0.055009    0.019438    0.710022    
#> 150: 0.548263    0.971323    3.375237    0.693185    0.059421    0.018466    0.718499    
#> 151: 0.573063    0.992346    3.383599    0.832061    0.056836    0.017543    0.707821    
#> 152: 0.623941    0.983889    3.387425    0.909440    0.056860    0.017930    0.702312    
#> 153: 0.663704    0.987700    3.409604    0.938541    0.062497    0.022616    0.716723    
#> 154: 0.651003    0.970260    3.411674    0.801390    0.048512    0.028159    0.712406    
#> 155: 0.598371    0.967449    3.405636    0.627511    0.039359    0.027298    0.711672    
#> 156: 0.587053    0.970521    3.402421    0.610900    0.036181    0.022101    0.716661    
#> 157: 0.583006    0.954385    3.401126    0.548208    0.038770    0.023512    0.716879    
#> 158: 0.600133    0.960181    3.402118    0.553171    0.055473    0.023705    0.701882    
#> 159: 0.536679    0.959485    3.406339    0.546091    0.061451    0.024153    0.711534    
#> 160: 0.584501    0.945769    3.409904    0.603378    0.062337    0.022852    0.706054    
#> 161: 0.595049    0.943888    3.408139    0.596561    0.061597    0.025264    0.712453    
#> 162: 0.575767    0.951912    3.405426    0.551935    0.049402    0.025367    0.714071    
#> 163: 0.589700    0.958734    3.392053    0.536108    0.050772    0.023056    0.711748    
#> 164: 0.550969    0.974941    3.384243    0.534431    0.060950    0.019338    0.706356    
#> 165: 0.553681    0.973608    3.394712    0.507740    0.057523    0.017579    0.708320    
#> 166: 0.603850    1.010367    3.387844    0.562396    0.065712    0.017382    0.733830    
#> 167: 0.567740    1.008084    3.397111    0.522660    0.057786    0.021205    0.734602    
#> 168: 0.592531    1.001255    3.397047    0.533824    0.054942    0.025382    0.708494    
#> 169: 0.558890    1.010667    3.385296    0.554514    0.059651    0.024235    0.714952    
#> 170: 0.604931    0.975131    3.395273    0.653891    0.057700    0.022374    0.717325    
#> 171: 0.551456    0.965092    3.389099    0.664318    0.056511    0.020738    0.712424    
#> 172: 0.568495    0.966094    3.386060    0.784844    0.053700    0.023196    0.701689    
#> 173: 0.569787    0.991836    3.376598    0.663030    0.051495    0.023336    0.709614    
#> 174: 0.624489    0.973815    3.402478    0.641111    0.042047    0.019834    0.739027    
#> 175: 0.594817    0.970670    3.389471    0.650213    0.043553    0.015701    0.730831    
#> 176: 0.560155    0.974745    3.400984    0.555201    0.054798    0.016455    0.710959    
#> 177: 0.578659    0.973462    3.401021    0.535442    0.055673    0.013734    0.708812    
#> 178: 0.599286    0.961109    3.403263    0.481861    0.050668    0.014947    0.717336    
#> 179: 0.608504    0.971238    3.399968    0.494694    0.060561    0.018141    0.728656    
#> 180: 0.562576    0.969466    3.392235    0.580754    0.057720    0.019981    0.712552    
#> 181: 0.600290    0.953121    3.374317    0.689818    0.054164    0.017830    0.722688    
#> 182: 0.559973    0.977900    3.369196    0.636799    0.056786    0.015078    0.731210    
#> 183: 0.522769    0.993826    3.371529    0.555637    0.047430    0.015889    0.737601    
#> 184: 0.501247    0.985915    3.373689    0.555607    0.053477    0.017158    0.713116    
#> 185: 0.502815    1.003087    3.378022    0.515360    0.061899    0.015979    0.716722    
#> 186: 0.526638    1.012071    3.389042    0.447478    0.066587    0.010903    0.728694    
#> 187: 0.511278    0.985330    3.395042    0.419312    0.061754    0.012185    0.722040    
#> 188: 0.501931    0.999231    3.384565    0.450294    0.057190    0.013131    0.734680    
#> 189: 0.503435    1.001468    3.388034    0.413873    0.056403    0.015495    0.732842    
#> 190: 0.547894    0.983658    3.395698    0.491608    0.052576    0.012859    0.722436    
#> 191: 0.524474    0.990614    3.385159    0.514626    0.048963    0.012465    0.722334    
#> 192: 0.554295    0.975415    3.390716    0.549682    0.051024    0.012528    0.719869    
#> 193: 0.581415    0.986738    3.394119    0.497129    0.051679    0.013499    0.708232    
#> 194: 0.549938    0.975340    3.397462    0.468656    0.062258    0.015747    0.724887    
#> 195: 0.496392    0.981515    3.384816    0.457054    0.050248    0.013605    0.729399    
#> 196: 0.542127    0.979732    3.388082    0.506499    0.061158    0.012580    0.738076    
#> 197: 0.540214    0.977184    3.409142    0.506477    0.054469    0.014153    0.750665    
#> 198: 0.550888    0.964355    3.397222    0.462215    0.059408    0.016498    0.730808    
#> 199: 0.562063    0.952737    3.398192    0.527047    0.052186    0.015080    0.727421    
#> 200: 0.516505    0.963718    3.395539    0.474467    0.064562    0.018909    0.706173    
#> 201: 0.549854    0.955183    3.405992    0.526218    0.060722    0.020853    0.704801    
#> 202: 0.557541    0.955428    3.407074    0.567756    0.059391    0.021245    0.708333    
#> 203: 0.576045    0.950804    3.407648    0.579840    0.059591    0.020430    0.710407    
#> 204: 0.571325    0.948084    3.408631    0.570794    0.061168    0.020017    0.713977    
#> 205: 0.567151    0.952823    3.408191    0.549291    0.062314    0.019920    0.717495    
#> 206: 0.570242    0.957321    3.409091    0.557053    0.060867    0.019971    0.721978    
#> 207: 0.571985    0.960030    3.406662    0.552813    0.060118    0.019862    0.722438    
#> 208: 0.572279    0.960921    3.406414    0.551461    0.059847    0.020152    0.722386    
#> 209: 0.576130    0.959023    3.406073    0.554631    0.057992    0.020261    0.720535    
#> 210: 0.577659    0.958295    3.406284    0.556267    0.056989    0.020138    0.719326    
#> 211: 0.580428    0.958332    3.406398    0.556862    0.055922    0.020124    0.717291    
#> 212: 0.583492    0.957548    3.406680    0.559412    0.055306    0.020089    0.716103    
#> 213: 0.586883    0.954450    3.408056    0.567880    0.055294    0.020061    0.716649    
#> 214: 0.590764    0.954128    3.408647    0.571605    0.055444    0.020138    0.716696    
#> 215: 0.590507    0.953745    3.408882    0.568873    0.054639    0.020218    0.717178    
#> 216: 0.593338    0.952527    3.409305    0.567682    0.054022    0.020023    0.718608    
#> 217: 0.592630    0.952667    3.409483    0.567384    0.053338    0.019781    0.718782    
#> 218: 0.591999    0.953453    3.408655    0.568678    0.053517    0.019760    0.718530    
#> 219: 0.588171    0.953990    3.407309    0.564097    0.053033    0.019813    0.718753    
#> 220: 0.586520    0.955317    3.406391    0.566042    0.053116    0.020135    0.718115    
#> 221: 0.585036    0.955771    3.405674    0.566027    0.052666    0.020294    0.717226    
#> 222: 0.583323    0.954940    3.405053    0.567883    0.051964    0.020639    0.716994    
#> 223: 0.583873    0.954921    3.405024    0.574005    0.051333    0.021058    0.716313    
#> 224: 0.585084    0.955651    3.405011    0.578661    0.050794    0.021248    0.715287    
#> 225: 0.585132    0.954828    3.405001    0.579693    0.050482    0.021362    0.715279    
#> 226: 0.584189    0.954257    3.404376    0.578206    0.050001    0.021391    0.714918    
#> 227: 0.583216    0.954845    3.403911    0.577161    0.050051    0.021443    0.714752    
#> 228: 0.580620    0.956526    3.402995    0.574749    0.050031    0.021479    0.715206    
#> 229: 0.578462    0.957054    3.402234    0.575609    0.050031    0.021407    0.715044    
#> 230: 0.578861    0.957409    3.401851    0.576648    0.049995    0.021269    0.715127    
#> 231: 0.579167    0.957552    3.401662    0.578215    0.050071    0.021199    0.715043    
#> 232: 0.578170    0.957849    3.401266    0.580521    0.050178    0.021117    0.714564    
#> 233: 0.575815    0.957469    3.400820    0.580882    0.050227    0.021168    0.714621    
#> 234: 0.574407    0.957496    3.400562    0.580258    0.050416    0.021181    0.714603    
#> 235: 0.574357    0.957074    3.400651    0.579886    0.050283    0.021135    0.714260    
#> 236: 0.574843    0.957523    3.400334    0.581319    0.050140    0.021091    0.714274    
#> 237: 0.576026    0.957447    3.400471    0.582651    0.050282    0.021148    0.714768    
#> 238: 0.577107    0.957497    3.400661    0.582909    0.050349    0.021217    0.715418    
#> 239: 0.577779    0.957757    3.400676    0.585030    0.050332    0.021274    0.715186    
#> 240: 0.578334    0.957663    3.400901    0.586470    0.050558    0.021326    0.714927    
#> 241: 0.579429    0.956912    3.401205    0.586526    0.050601    0.021449    0.715133    
#> 242: 0.579486    0.956600    3.401066    0.586641    0.050596    0.021515    0.715667    
#> 243: 0.577862    0.956980    3.400649    0.585373    0.050533    0.021545    0.715678    
#> 244: 0.576689    0.957352    3.400479    0.586405    0.050360    0.021625    0.716015    
#> 245: 0.576094    0.957202    3.400321    0.586090    0.050269    0.021593    0.716793    
#> 246: 0.575374    0.957125    3.400365    0.583838    0.050111    0.021638    0.717187    
#> 247: 0.575160    0.956703    3.400582    0.583859    0.050171    0.021695    0.717275    
#> 248: 0.575224    0.956836    3.400443    0.585598    0.050273    0.021679    0.717122    
#> 249: 0.574278    0.956861    3.400396    0.585824    0.050043    0.021732    0.717522    
#> 250: 0.574376    0.957091    3.400411    0.586137    0.049915    0.021725    0.717732    
#> 251: 0.574705    0.957349    3.400598    0.587051    0.049818    0.021818    0.718213    
#> 252: 0.575041    0.957640    3.400724    0.586577    0.049795    0.021879    0.718702    
#> 253: 0.574774    0.957835    3.400605    0.586320    0.049763    0.021950    0.718669    
#> 254: 0.575084    0.958202    3.400597    0.587473    0.049723    0.022064    0.718551    
#> 255: 0.575105    0.958344    3.400512    0.588348    0.049715    0.022143    0.718774    
#> 256: 0.574885    0.958393    3.400344    0.588554    0.049741    0.022233    0.719069    
#> 257: 0.574250    0.958294    3.400304    0.588188    0.049873    0.022221    0.719103    
#> 258: 0.574793    0.957922    3.400335    0.588439    0.050060    0.022124    0.719080    
#> 259: 0.575308    0.957821    3.400371    0.588572    0.050166    0.022042    0.719130    
#> 260: 0.575464    0.957886    3.400618    0.587200    0.050167    0.022016    0.719143    
#> 261: 0.576027    0.957704    3.400720    0.587715    0.050299    0.021944    0.719445    
#> 262: 0.575942    0.957991    3.400587    0.588503    0.050281    0.021906    0.719320    
#> 263: 0.575945    0.958374    3.400479    0.587991    0.050282    0.021927    0.719314    
#> 264: 0.575493    0.958434    3.400495    0.585964    0.050344    0.021874    0.719222    
#> 265: 0.575734    0.958331    3.400474    0.585507    0.050446    0.021850    0.719294    
#> 266: 0.575676    0.958544    3.400391    0.584076    0.050281    0.021798    0.719481    
#> 267: 0.575257    0.958754    3.400491    0.583189    0.050229    0.021792    0.719800    
#> 268: 0.575419    0.958763    3.400374    0.584595    0.050252    0.021796    0.719591    
#> 269: 0.576178    0.958864    3.400253    0.587164    0.050324    0.021794    0.719196    
#> 270: 0.577151    0.958903    3.400205    0.588873    0.050265    0.021782    0.718878    
#> 271: 0.577363    0.958984    3.400139    0.589654    0.050338    0.021730    0.718835    
#> 272: 0.577937    0.958926    3.400141    0.589425    0.050379    0.021664    0.719169    
#> 273: 0.577987    0.959371    3.400161    0.589344    0.050599    0.021645    0.719418    
#> 274: 0.578023    0.959588    3.400324    0.588423    0.050535    0.021606    0.719440    
#> 275: 0.578499    0.959443    3.400309    0.588023    0.050501    0.021557    0.719154    
#> 276: 0.578454    0.959481    3.400430    0.587563    0.050530    0.021586    0.718955    
#> 277: 0.578607    0.959511    3.400620    0.587633    0.050514    0.021592    0.719056    
#> 278: 0.579237    0.959327    3.400798    0.588412    0.050361    0.021602    0.719143    
#> 279: 0.579759    0.958896    3.400980    0.590155    0.050259    0.021694    0.719321    
#> 280: 0.579642    0.958728    3.401043    0.590235    0.050185    0.021723    0.719313    
#> 281: 0.578835    0.958686    3.400931    0.589736    0.050086    0.021710    0.719324    
#> 282: 0.578809    0.958781    3.400929    0.589979    0.050138    0.021713    0.719197    
#> 283: 0.578390    0.958928    3.400929    0.589439    0.050192    0.021771    0.719611    
#> 284: 0.578191    0.958753    3.400965    0.588292    0.050081    0.021848    0.719587    
#> 285: 0.577426    0.958830    3.400790    0.587281    0.049968    0.021894    0.719785    
#> 286: 0.577537    0.958804    3.400672    0.587335    0.049882    0.021934    0.719919    
#> 287: 0.576917    0.958988    3.400482    0.587131    0.049789    0.021968    0.720027    
#> 288: 0.577207    0.958927    3.400401    0.587235    0.049724    0.021973    0.720127    
#> 289: 0.578016    0.958723    3.400460    0.588053    0.049721    0.021890    0.720022    
#> 290: 0.578218    0.958701    3.400486    0.587784    0.049885    0.021803    0.719991    
#> 291: 0.578482    0.958894    3.400683    0.587183    0.050078    0.021713    0.719930    
#> 292: 0.578487    0.959012    3.400701    0.586752    0.050160    0.021644    0.719929    
#> 293: 0.578232    0.959334    3.400506    0.587365    0.050220    0.021600    0.719733    
#> 294: 0.577683    0.959512    3.400211    0.587462    0.050237    0.021564    0.719689    
#> 295: 0.577191    0.959433    3.399951    0.588107    0.050334    0.021506    0.719563    
#> 296: 0.577261    0.959358    3.399884    0.588074    0.050313    0.021477    0.719698    
#> 297: 0.577413    0.959443    3.399808    0.588205    0.050251    0.021509    0.719767    
#> 298: 0.577147    0.959386    3.399748    0.587842    0.050239    0.021507    0.719667    
#> 299: 0.577001    0.959521    3.399711    0.587653    0.050234    0.021470    0.719530    
#> 300: 0.576761    0.959329    3.399788    0.586547    0.050164    0.021422    0.719503    
#> 301: 0.576806    0.959132    3.399766    0.586568    0.050068    0.021378    0.719668    
#> 302: 0.577073    0.959071    3.399730    0.587213    0.049985    0.021326    0.719607    
#> 303: 0.576741    0.959084    3.399669    0.586358    0.049902    0.021323    0.719415    
#> 304: 0.576771    0.959380    3.399574    0.586286    0.049888    0.021334    0.719325    
#> 305: 0.576742    0.959229    3.399496    0.586298    0.049805    0.021360    0.719263    
#> 306: 0.576621    0.959052    3.399451    0.586539    0.049776    0.021348    0.719132    
#> 307: 0.576704    0.959006    3.399356    0.587365    0.049734    0.021346    0.719100    
#> 308: 0.576619    0.958959    3.399201    0.588156    0.049634    0.021389    0.719255    
#> 309: 0.576714    0.958719    3.399187    0.588843    0.049572    0.021461    0.719432    
#> 310: 0.576788    0.958639    3.399088    0.588432    0.049549    0.021473    0.719456    
#> 311: 0.576675    0.958708    3.399058    0.588270    0.049569    0.021449    0.719380    
#> 312: 0.576364    0.958746    3.398956    0.588062    0.049520    0.021428    0.719394    
#> 313: 0.576391    0.958736    3.398915    0.588639    0.049467    0.021416    0.719417    
#> 314: 0.576141    0.958832    3.398865    0.589105    0.049390    0.021411    0.719358    
#> 315: 0.576187    0.958951    3.398813    0.590088    0.049391    0.021391    0.719108    
#> 316: 0.576068    0.959073    3.398762    0.590325    0.049452    0.021358    0.719055    
#> 317: 0.576636    0.959169    3.398845    0.591962    0.049489    0.021342    0.718977    
#> 318: 0.576763    0.959313    3.398747    0.591904    0.049552    0.021325    0.718819    
#> 319: 0.577037    0.959365    3.398780    0.592678    0.049575    0.021295    0.718804    
#> 320: 0.576328    0.959364    3.398680    0.591854    0.049663    0.021237    0.719032    
#> 321: 0.575988    0.959538    3.398537    0.591210    0.049670    0.021210    0.719257    
#> 322: 0.575889    0.959623    3.398439    0.590809    0.049687    0.021180    0.719331    
#> 323: 0.575259    0.959723    3.398321    0.589934    0.049667    0.021163    0.719367    
#> 324: 0.575155    0.959883    3.398278    0.589958    0.049647    0.021163    0.719283    
#> 325: 0.575340    0.960117    3.398237    0.589932    0.049614    0.021127    0.719124    
#> 326: 0.575435    0.960071    3.398215    0.590317    0.049692    0.021122    0.718971    
#> 327: 0.575531    0.960163    3.398269    0.590575    0.049638    0.021153    0.718953    
#> 328: 0.575893    0.960318    3.398312    0.591035    0.049628    0.021159    0.718852    
#> 329: 0.576290    0.960377    3.398393    0.591587    0.049710    0.021148    0.718698    
#> 330: 0.576299    0.960262    3.398374    0.592557    0.049804    0.021124    0.718622    
#> 331: 0.576881    0.960282    3.398433    0.593872    0.049829    0.021080    0.718560    
#> 332: 0.577229    0.960164    3.398551    0.594571    0.049840    0.021061    0.718600    
#> 333: 0.577169    0.960103    3.398528    0.594420    0.049791    0.021044    0.718519    
#> 334: 0.577214    0.959879    3.398470    0.595172    0.049744    0.021046    0.718461    
#> 335: 0.577362    0.959731    3.398514    0.595659    0.049734    0.021044    0.718368    
#> 336: 0.577212    0.959820    3.398528    0.595900    0.049787    0.021058    0.718268    
#> 337: 0.576727    0.960030    3.398392    0.595276    0.049820    0.021056    0.718213    
#> 338: 0.576735    0.960042    3.398354    0.596042    0.049858    0.021038    0.718120    
#> 339: 0.576543    0.960204    3.398262    0.595970    0.049833    0.021009    0.718102    
#> 340: 0.576399    0.960190    3.398224    0.595860    0.049887    0.020985    0.718104    
#> 341: 0.576601    0.960094    3.398288    0.596263    0.049945    0.020953    0.718035    
#> 342: 0.576487    0.959919    3.398355    0.595806    0.049960    0.020914    0.718007    
#> 343: 0.576455    0.959793    3.398352    0.596165    0.049978    0.020904    0.718094    
#> 344: 0.576355    0.959654    3.398386    0.595967    0.050001    0.020899    0.718139    
#> 345: 0.576509    0.959587    3.398474    0.595884    0.050071    0.020905    0.718010    
#> 346: 0.576588    0.959640    3.398429    0.595885    0.050026    0.020880    0.717927    
#> 347: 0.576494    0.959498    3.398424    0.595955    0.050041    0.020919    0.717864    
#> 348: 0.576320    0.959553    3.398381    0.595590    0.049981    0.020916    0.717980    
#> 349: 0.576229    0.959475    3.398368    0.595298    0.049916    0.020924    0.717971    
#> 350: 0.575977    0.959382    3.398351    0.595636    0.049924    0.020947    0.717990    
#> 351: 0.575961    0.959475    3.398315    0.595740    0.049977    0.020977    0.717918    
#> 352: 0.575695    0.959574    3.398287    0.595432    0.050058    0.021010    0.717966    
#> 353: 0.575972    0.959737    3.398250    0.595695    0.050163    0.021015    0.717969    
#> 354: 0.575830    0.959819    3.398107    0.595276    0.050213    0.021036    0.717920    
#> 355: 0.576188    0.959681    3.398062    0.595193    0.050268    0.021039    0.717853    
#> 356: 0.576288    0.959608    3.398094    0.594815    0.050350    0.021045    0.717955    
#> 357: 0.576478    0.959690    3.398096    0.595190    0.050358    0.021029    0.717779    
#> 358: 0.576600    0.959762    3.398108    0.595311    0.050277    0.021034    0.717599    
#> 359: 0.576416    0.960014    3.398083    0.594835    0.050289    0.021020    0.717478    
#> 360: 0.576249    0.960124    3.397954    0.594377    0.050275    0.021018    0.717299    
#> 361: 0.575884    0.960181    3.397833    0.593969    0.050302    0.021032    0.717196    
#> 362: 0.575903    0.960238    3.397779    0.594213    0.050303    0.021041    0.717010    
#> 363: 0.575805    0.960306    3.397761    0.594127    0.050294    0.021047    0.716855    
#> 364: 0.575938    0.960356    3.397725    0.594585    0.050298    0.021036    0.716734    
#> 365: 0.575758    0.960327    3.397685    0.594798    0.050381    0.021019    0.716712    
#> 366: 0.575252    0.960441    3.397508    0.594722    0.050418    0.021017    0.716692    
#> 367: 0.574964    0.960592    3.397351    0.595024    0.050431    0.021002    0.716701    
#> 368: 0.575149    0.960734    3.397289    0.595162    0.050372    0.020978    0.716727    
#> 369: 0.574921    0.960806    3.397269    0.594922    0.050328    0.020939    0.716825    
#> 370: 0.574879    0.960891    3.397247    0.595077    0.050317    0.020925    0.716804    
#> 371: 0.574452    0.961048    3.397080    0.594165    0.050291    0.020914    0.716865    
#> 372: 0.573980    0.961245    3.396961    0.593784    0.050290    0.020891    0.716831    
#> 373: 0.573765    0.961477    3.396904    0.593254    0.050349    0.020875    0.716907    
#> 374: 0.573893    0.961467    3.396907    0.593649    0.050378    0.020864    0.716869    
#> 375: 0.573893    0.961455    3.396930    0.593616    0.050362    0.020865    0.716935    
#> 376: 0.573982    0.961524    3.396962    0.593253    0.050453    0.020837    0.716881    
#> 377: 0.573763    0.961600    3.396944    0.592782    0.050575    0.020801    0.716851    
#> 378: 0.573754    0.961593    3.396945    0.592353    0.050633    0.020792    0.716796    
#> 379: 0.573655    0.961422    3.397004    0.591682    0.050646    0.020767    0.716847    
#> 380: 0.573574    0.961303    3.397028    0.591404    0.050704    0.020741    0.716757    
#> 381: 0.573513    0.961184    3.397082    0.591203    0.050706    0.020703    0.716791    
#> 382: 0.573443    0.961055    3.397155    0.590849    0.050705    0.020687    0.716665    
#> 383: 0.573619    0.960987    3.397194    0.590846    0.050729    0.020667    0.716551    
#> 384: 0.573543    0.960979    3.397204    0.590901    0.050737    0.020647    0.716576    
#> 385: 0.573775    0.960963    3.397237    0.590681    0.050746    0.020630    0.716594    
#> 386: 0.573787    0.961110    3.397258    0.590618    0.050794    0.020623    0.716619    
#> 387: 0.573883    0.961131    3.397384    0.590484    0.050789    0.020631    0.716605    
#> 388: 0.574069    0.961138    3.397418    0.590722    0.050760    0.020617    0.716608    
#> 389: 0.574257    0.960924    3.397431    0.590724    0.050725    0.020602    0.716633    
#> 390: 0.574205    0.960804    3.397451    0.590019    0.050739    0.020582    0.716665    
#> 391: 0.574497    0.960614    3.397461    0.590191    0.050731    0.020597    0.716629    
#> 392: 0.574868    0.960621    3.397562    0.590601    0.050777    0.020610    0.716680    
#> 393: 0.574865    0.960550    3.397532    0.590210    0.050789    0.020609    0.716664    
#> 394: 0.575029    0.960480    3.397523    0.590288    0.050784    0.020608    0.716613    
#> 395: 0.575219    0.960613    3.397495    0.591017    0.050816    0.020610    0.716502    
#> 396: 0.575265    0.960695    3.397481    0.591226    0.050819    0.020637    0.716399    
#> 397: 0.575376    0.960601    3.397501    0.591798    0.050793    0.020656    0.716359    
#> 398: 0.575476    0.960520    3.397550    0.591994    0.050757    0.020668    0.716447    
#> 399: 0.575476    0.960521    3.397619    0.591942    0.050736    0.020670    0.716462    
#> 400: 0.575611    0.960489    3.397668    0.591860    0.050716    0.020657    0.716388    
#> 401: 0.575759    0.960450    3.397669    0.591728    0.050712    0.020631    0.716452    
#> 402: 0.575846    0.960512    3.397680    0.591687    0.050748    0.020614    0.716427    
#> 403: 0.576146    0.960553    3.397707    0.592223    0.050818    0.020614    0.716326    
#> 404: 0.576235    0.960603    3.397644    0.592814    0.050896    0.020615    0.716171    
#> 405: 0.576134    0.960642    3.397636    0.592727    0.050963    0.020606    0.716119    
#> 406: 0.576045    0.960755    3.397583    0.592587    0.051028    0.020620    0.716178    
#> 407: 0.576040    0.960781    3.397605    0.592912    0.051080    0.020641    0.716244    
#> 408: 0.576050    0.960867    3.397586    0.593163    0.051087    0.020652    0.716291    
#> 409: 0.576028    0.960895    3.397507    0.593917    0.051059    0.020692    0.716216    
#> 410: 0.575957    0.961011    3.397419    0.594421    0.051051    0.020714    0.716191    
#> 411: 0.576069    0.960889    3.397428    0.595176    0.051063    0.020714    0.716169    
#> 412: 0.576158    0.960901    3.397410    0.595252    0.051031    0.020741    0.716055    
#> 413: 0.576427    0.960937    3.397377    0.596094    0.051034    0.020771    0.715906    
#> 414: 0.576358    0.960882    3.397424    0.596307    0.051051    0.020807    0.715810    
#> 415: 0.576342    0.960875    3.397427    0.596112    0.051014    0.020845    0.715735    
#> 416: 0.576383    0.960948    3.397443    0.595896    0.050992    0.020866    0.715685    
#> 417: 0.576329    0.960952    3.397454    0.595647    0.051002    0.020872    0.715637    
#> 418: 0.576015    0.961024    3.397448    0.595152    0.051025    0.020877    0.715607    
#> 419: 0.575832    0.961070    3.397436    0.594674    0.050979    0.020875    0.715634    
#> 420: 0.575962    0.961164    3.397437    0.594834    0.050983    0.020875    0.715559    
#> 421: 0.575947    0.961178    3.397458    0.594841    0.051019    0.020883    0.715442    
#> 422: 0.576175    0.961072    3.397469    0.595299    0.051017    0.020892    0.715425    
#> 423: 0.576381    0.960924    3.397524    0.596026    0.051005    0.020900    0.715354    
#> 424: 0.576318    0.960858    3.397508    0.595817    0.050992    0.020895    0.715300    
#> 425: 0.576292    0.960864    3.397493    0.595855    0.050995    0.020901    0.715284    
#> 426: 0.576460    0.960938    3.397501    0.596356    0.050931    0.020904    0.715271    
#> 427: 0.576489    0.960966    3.397528    0.596703    0.050875    0.020905    0.715266    
#> 428: 0.576658    0.961030    3.397547    0.597405    0.050873    0.020908    0.715267    
#> 429: 0.576713    0.961091    3.397569    0.597797    0.050868    0.020899    0.715302    
#> 430: 0.576570    0.961103    3.397577    0.597492    0.050865    0.020910    0.715282    
#> 431: 0.576650    0.961018    3.397565    0.597760    0.050826    0.020904    0.715173    
#> 432: 0.576724    0.961112    3.397518    0.598243    0.050815    0.020902    0.715087    
#> 433: 0.576721    0.961192    3.397551    0.598175    0.050849    0.020901    0.715105    
#> 434: 0.576503    0.961137    3.397527    0.597717    0.050864    0.020905    0.715063    
#> 435: 0.576500    0.961135    3.397505    0.597763    0.050840    0.020911    0.714969    
#> 436: 0.576575    0.961089    3.397584    0.597808    0.050803    0.020915    0.715067    
#> 437: 0.576618    0.961024    3.397613    0.597744    0.050782    0.020934    0.715100    
#> 438: 0.576523    0.961147    3.397636    0.597611    0.050755    0.020920    0.715153    
#> 439: 0.576725    0.961201    3.397650    0.597883    0.050729    0.020917    0.715095    
#> 440: 0.576723    0.961184    3.397692    0.597752    0.050735    0.020912    0.715035    
#> 441: 0.576718    0.961156    3.397734    0.597535    0.050809    0.020914    0.714996    
#> 442: 0.576615    0.961152    3.397767    0.597312    0.050827    0.020908    0.714968    
#> 443: 0.576666    0.961131    3.397781    0.597179    0.050811    0.020897    0.715007    
#> 444: 0.576608    0.961145    3.397745    0.597025    0.050821    0.020882    0.715006    
#> 445: 0.576393    0.961245    3.397701    0.596759    0.050871    0.020856    0.715050    
#> 446: 0.576116    0.961284    3.397655    0.596288    0.050871    0.020839    0.715062    
#> 447: 0.576294    0.961330    3.397677    0.596177    0.050860    0.020820    0.715128    
#> 448: 0.576333    0.961364    3.397704    0.596238    0.050885    0.020819    0.715078    
#> 449: 0.576319    0.961388    3.397771    0.595824    0.050864    0.020811    0.715128    
#> 450: 0.576417    0.961316    3.397789    0.595904    0.050852    0.020801    0.715170    
#> 451: 0.576532    0.961300    3.397786    0.595694    0.050860    0.020802    0.715239    
#> 452: 0.576490    0.961317    3.397786    0.595753    0.050881    0.020793    0.715230    
#> 453: 0.576536    0.961324    3.397751    0.596132    0.050967    0.020781    0.715099    
#> 454: 0.576631    0.961460    3.397725    0.597088    0.051006    0.020772    0.715041    
#> 455: 0.576817    0.961519    3.397700    0.598194    0.051045    0.020763    0.714945    
#> 456: 0.576798    0.961521    3.397674    0.598618    0.051057    0.020760    0.714836    
#> 457: 0.576791    0.961535    3.397689    0.598810    0.051048    0.020744    0.714744    
#> 458: 0.576804    0.961610    3.397736    0.598742    0.051022    0.020742    0.714669    
#> 459: 0.576599    0.961674    3.397744    0.598756    0.051011    0.020736    0.714713    
#> 460: 0.576507    0.961709    3.397732    0.598727    0.051004    0.020748    0.714662    
#> 461: 0.576594    0.961781    3.397737    0.599030    0.051026    0.020754    0.714614    
#> 462: 0.576500    0.961851    3.397707    0.599118    0.051007    0.020756    0.714581    
#> 463: 0.576384    0.961934    3.397686    0.599078    0.050964    0.020767    0.714648    
#> 464: 0.576309    0.962031    3.397631    0.599237    0.050970    0.020788    0.714603    
#> 465: 0.576323    0.961935    3.397608    0.599368    0.050979    0.020794    0.714573    
#> 466: 0.576224    0.961942    3.397544    0.599194    0.050969    0.020790    0.714558    
#> 467: 0.576086    0.961925    3.397587    0.599063    0.050946    0.020789    0.714501    
#> 468: 0.576180    0.961910    3.397668    0.598730    0.050940    0.020784    0.714567    
#> 469: 0.576265    0.961989    3.397723    0.598457    0.050936    0.020798    0.714623    
#> 470: 0.576179    0.962085    3.397660    0.598303    0.050916    0.020818    0.714590    
#> 471: 0.576040    0.962142    3.397643    0.597962    0.050935    0.020820    0.714568    
#> 472: 0.575857    0.962138    3.397611    0.597684    0.050895    0.020822    0.714521    
#> 473: 0.575704    0.962159    3.397587    0.597674    0.050863    0.020833    0.714474    
#> 474: 0.575563    0.962199    3.397535    0.597563    0.050857    0.020844    0.714488    
#> 475: 0.575556    0.962353    3.397484    0.597707    0.050838    0.020853    0.714517    
#> 476: 0.575445    0.962380    3.397450    0.597395    0.050812    0.020861    0.714608    
#> 477: 0.575378    0.962432    3.397445    0.597332    0.050780    0.020868    0.714534    
#> 478: 0.575325    0.962430    3.397430    0.597641    0.050758    0.020867    0.714573    
#> 479: 0.575532    0.962549    3.397394    0.598611    0.050749    0.020873    0.714583    
#> 480: 0.575723    0.962642    3.397364    0.599326    0.050688    0.020885    0.714636    
#> 481: 0.575804    0.962704    3.397314    0.599844    0.050648    0.020903    0.714648    
#> 482: 0.575854    0.962738    3.397226    0.600226    0.050600    0.020911    0.714708    
#> 483: 0.575790    0.962741    3.397200    0.600408    0.050558    0.020925    0.714698    
#> 484: 0.575622    0.962653    3.397185    0.600304    0.050531    0.020928    0.714683    
#> 485: 0.575594    0.962663    3.397162    0.600612    0.050546    0.020932    0.714655    
#> 486: 0.575587    0.962722    3.397163    0.600896    0.050570    0.020929    0.714614    
#> 487: 0.575827    0.962765    3.397195    0.601591    0.050585    0.020936    0.714493    
#> 488: 0.575863    0.962747    3.397214    0.601808    0.050579    0.020944    0.714436    
#> 489: 0.575924    0.962699    3.397208    0.601835    0.050573    0.020957    0.714410    
#> 490: 0.575779    0.962732    3.397197    0.601556    0.050547    0.020966    0.714367    
#> 491: 0.575725    0.962845    3.397176    0.601574    0.050529    0.020963    0.714365    
#> 492: 0.575537    0.962953    3.397111    0.601588    0.050502    0.020953    0.714412    
#> 493: 0.575368    0.963021    3.397075    0.601620    0.050481    0.020968    0.714384    
#> 494: 0.575363    0.963089    3.397014    0.601825    0.050439    0.020977    0.714333    
#> 495: 0.575334    0.963152    3.396971    0.602101    0.050404    0.020998    0.714246    
#> 496: 0.575353    0.963256    3.396919    0.602112    0.050373    0.021010    0.714291    
#> 497: 0.575085    0.963316    3.396848    0.601816    0.050394    0.021003    0.714325    
#> 498: 0.574920    0.963360    3.396763    0.601710    0.050382    0.021006    0.714354    
#> 499: 0.574743    0.963461    3.396670    0.601532    0.050417    0.021012    0.714347    
#> 500: 0.574632    0.963512    3.396614    0.601468    0.050442    0.021009    0.714335    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.269355    0.969659    3.441448    0.392401    0.074443    0.016800    1.763837    
#> 002: 0.274187    1.039027    3.465813    0.372781    0.070721    0.018503    1.112909    
#> 003: 0.383213    1.014863    3.513440    0.354142    0.079076    0.017578    0.832417    
#> 004: 0.389267    1.051955    3.518284    0.336435    0.087575    0.016699    0.737633    
#> 005: 0.430147    1.064780    3.502737    0.319613    0.097576    0.015864    0.719200    
#> 006: 0.390211    1.076185    3.494527    0.303633    0.102270    0.015071    0.666411    
#> 007: 0.369519    1.093495    3.494574    0.288451    0.110102    0.015221    0.679183    
#> 008: 0.350646    1.092189    3.486821    0.274029    0.104597    0.016668    0.685067    
#> 009: 0.332012    1.084590    3.482426    0.260327    0.099367    0.019036    0.682722    
#> 010: 0.355916    1.079405    3.485641    0.247311    0.094398    0.018084    0.711215    
#> 011: 0.402605    1.078247    3.492164    0.234945    0.119943    0.017180    0.713456    
#> 012: 0.403840    1.091157    3.485172    0.226760    0.113946    0.016321    0.722693    
#> 013: 0.327070    1.110341    3.472044    0.220872    0.116491    0.017237    0.702821    
#> 014: 0.378566    1.094115    3.482285    0.228390    0.110666    0.018906    0.718285    
#> 015: 0.395195    1.102774    3.497459    0.231962    0.105133    0.022229    0.675245    
#> 016: 0.399716    1.107971    3.510330    0.220364    0.099876    0.021682    0.693965    
#> 017: 0.405105    1.106634    3.512421    0.233125    0.097296    0.020598    0.674798    
#> 018: 0.404502    1.078010    3.494486    0.221469    0.092431    0.019568    0.690040    
#> 019: 0.370833    1.094476    3.501885    0.210396    0.095962    0.018589    0.677732    
#> 020: 0.422033    1.082033    3.507283    0.219562    0.094859    0.017660    0.689860    
#> 021: 0.425702    1.069024    3.514322    0.221049    0.090116    0.016777    0.673429    
#> 022: 0.412330    1.070541    3.526159    0.210077    0.085610    0.019218    0.675015    
#> 023: 0.464133    1.090991    3.524903    0.221011    0.088207    0.021034    0.696805    
#> 024: 0.519796    1.108161    3.540828    0.209960    0.091322    0.022535    0.686441    
#> 025: 0.477899    1.067676    3.536891    0.199462    0.086756    0.026215    0.677543    
#> 026: 0.447538    1.079237    3.519739    0.190408    0.082418    0.026469    0.678988    
#> 027: 0.419888    1.102846    3.510148    0.222970    0.078297    0.025146    0.692292    
#> 028: 0.441268    1.092116    3.510801    0.220532    0.090583    0.026895    0.674334    
#> 029: 0.437491    1.096192    3.507836    0.256821    0.099258    0.027022    0.678854    
#> 030: 0.439485    1.098604    3.511436    0.243980    0.094295    0.025671    0.685749    
#> 031: 0.401855    1.073729    3.521293    0.231781    0.089581    0.024387    0.693207    
#> 032: 0.405252    1.068414    3.510075    0.247531    0.085102    0.023168    0.691824    
#> 033: 0.402632    1.105280    3.505957    0.235155    0.098106    0.022983    0.683402    
#> 034: 0.413983    1.099945    3.507275    0.236467    0.093201    0.023674    0.673511    
#> 035: 0.393537    1.098019    3.498725    0.258269    0.088541    0.028231    0.670471    
#> 036: 0.396780    1.095011    3.506715    0.257247    0.084114    0.026819    0.679845    
#> 037: 0.397672    1.100929    3.504127    0.244385    0.086833    0.025478    0.682315    
#> 038: 0.405985    1.078258    3.505897    0.241711    0.091562    0.025058    0.681852    
#> 039: 0.439529    1.084612    3.527396    0.237638    0.086984    0.023805    0.679867    
#> 040: 0.439376    1.072353    3.523617    0.248841    0.082634    0.022956    0.680143    
#> 041: 0.429016    1.064630    3.521676    0.236399    0.084381    0.023574    0.681437    
#> 042: 0.438333    1.084081    3.510638    0.224579    0.080162    0.025223    0.675619    
#> 043: 0.390758    1.093618    3.494467    0.213350    0.076154    0.025931    0.672027    
#> 044: 0.386966    1.102380    3.489047    0.202683    0.074222    0.024634    0.687810    
#> 045: 0.384460    1.125537    3.490375    0.192549    0.077419    0.023403    0.696600    
#> 046: 0.397665    1.114479    3.489382    0.182921    0.079921    0.022233    0.690357    
#> 047: 0.395398    1.115991    3.492850    0.173775    0.090337    0.021298    0.673941    
#> 048: 0.414172    1.102900    3.511265    0.165087    0.091039    0.021834    0.682443    
#> 049: 0.388799    1.100648    3.510558    0.182831    0.098335    0.020743    0.683288    
#> 050: 0.438221    1.061691    3.504088    0.182962    0.094093    0.019705    0.717822    
#> 051: 0.415935    1.079361    3.502904    0.173814    0.102841    0.022478    0.702046    
#> 052: 0.400926    1.086028    3.514372    0.206344    0.097699    0.021354    0.677442    
#> 053: 0.411602    1.072493    3.511447    0.214418    0.094789    0.020286    0.687025    
#> 054: 0.396481    1.088536    3.506994    0.203697    0.102195    0.022906    0.700028    
#> 055: 0.401730    1.071507    3.506274    0.199029    0.110357    0.021761    0.694542    
#> 056: 0.421586    1.070364    3.513206    0.199052    0.104839    0.020673    0.704673    
#> 057: 0.426345    1.066532    3.532254    0.202537    0.100664    0.020791    0.701396    
#> 058: 0.407829    1.059467    3.516468    0.210283    0.098609    0.019752    0.714048    
#> 059: 0.439822    1.027982    3.522175    0.232630    0.093679    0.023105    0.708844    
#> 060: 0.454379    1.048902    3.529052    0.236575    0.103943    0.023772    0.687463    
#> 061: 0.509934    1.049041    3.544419    0.224746    0.098746    0.023753    0.712562    
#> 062: 0.447090    1.085594    3.533485    0.246361    0.124396    0.022565    0.703948    
#> 063: 0.481234    1.053472    3.532917    0.234043    0.118176    0.021437    0.704516    
#> 064: 0.472266    1.046108    3.541090    0.222341    0.112267    0.021928    0.707745    
#> 065: 0.461135    1.047460    3.517675    0.211224    0.106654    0.020832    0.689081    
#> 066: 0.455840    1.077048    3.520238    0.227781    0.101321    0.019790    0.687884    
#> 067: 0.450379    1.056915    3.532701    0.225708    0.096255    0.023018    0.688092    
#> 068: 0.432279    1.057034    3.536278    0.214423    0.091442    0.023786    0.700465    
#> 069: 0.433211    1.074357    3.517351    0.253114    0.086870    0.022596    0.696208    
#> 070: 0.434860    1.069604    3.528072    0.270698    0.099081    0.021466    0.676448    
#> 071: 0.378171    1.098365    3.485094    0.257163    0.094127    0.020393    0.689242    
#> 072: 0.343036    1.070916    3.483030    0.244671    0.089421    0.019373    0.699596    
#> 073: 0.369138    1.090978    3.494197    0.232437    0.094281    0.020280    0.678530    
#> 074: 0.375019    1.082458    3.493904    0.246377    0.106065    0.019266    0.671892    
#> 075: 0.399802    1.067192    3.521356    0.234058    0.100761    0.018608    0.676847    
#> 076: 0.422409    1.084437    3.527807    0.241314    0.095723    0.022830    0.659608    
#> 077: 0.469479    1.066421    3.527490    0.229249    0.090937    0.022159    0.663135    
#> 078: 0.469475    1.079495    3.527145    0.217786    0.086390    0.024681    0.673448    
#> 079: 0.454387    1.086449    3.528577    0.206897    0.099087    0.025901    0.695432    
#> 080: 0.444068    1.077240    3.524369    0.217868    0.094133    0.028214    0.702865    
#> 081: 0.437254    1.097718    3.516469    0.206974    0.089426    0.028148    0.681762    
#> 082: 0.410396    1.078795    3.518121    0.229961    0.097236    0.026740    0.688877    
#> 083: 0.424329    1.105739    3.519571    0.218463    0.092374    0.025403    0.686604    
#> 084: 0.432374    1.093509    3.517278    0.219674    0.091778    0.024133    0.693708    
#> 085: 0.428814    1.094189    3.528510    0.246315    0.102764    0.022926    0.699831    
#> 086: 0.423382    1.099039    3.515533    0.233999    0.097626    0.026757    0.686142    
#> 087: 0.376465    1.090937    3.509195    0.222299    0.092745    0.027146    0.681252    
#> 088: 0.346505    1.086638    3.510372    0.211184    0.088107    0.025789    0.708606    
#> 089: 0.394140    1.120187    3.489616    0.228103    0.093499    0.024500    0.695469    
#> 090: 0.376896    1.113891    3.491398    0.217083    0.111518    0.023275    0.694748    
#> 091: 0.375172    1.102977    3.480886    0.206229    0.105942    0.023250    0.683882    
#> 092: 0.358329    1.113062    3.475795    0.235843    0.100645    0.022088    0.682855    
#> 093: 0.352356    1.084690    3.484303    0.234385    0.095613    0.021896    0.704242    
#> 094: 0.344014    1.106468    3.477543    0.237047    0.090832    0.022338    0.693334    
#> 095: 0.360665    1.119951    3.495458    0.237364    0.086291    0.027527    0.692735    
#> 096: 0.340223    1.115852    3.489079    0.225496    0.083447    0.026151    0.680558    
#> 097: 0.380905    1.118614    3.488484    0.227989    0.083068    0.024843    0.679656    
#> 098: 0.374089    1.131933    3.489482    0.216590    0.078914    0.024796    0.690366    
#> 099: 0.372247    1.103645    3.480240    0.205760    0.076877    0.023557    0.676888    
#> 100: 0.347367    1.116537    3.482955    0.226321    0.087911    0.022379    0.679939    
#> 101: 0.304455    1.119270    3.460717    0.215005    0.083515    0.021260    0.696509    
#> 102: 0.337870    1.119596    3.471640    0.211149    0.084732    0.020197    0.702868    
#> 103: 0.368922    1.114629    3.488239    0.248108    0.101653    0.019187    0.673914    
#> 104: 0.384059    1.116119    3.501192    0.235703    0.102714    0.018832    0.693327    
#> 105: 0.423033    1.083635    3.513868    0.241865    0.097578    0.021216    0.670891    
#> 106: 0.447141    1.083023    3.515300    0.229771    0.092699    0.023265    0.674843    
#> 107: 0.465633    1.084652    3.517227    0.218283    0.088064    0.023630    0.680566    
#> 108: 0.485824    1.069688    3.541177    0.207369    0.085906    0.022448    0.697778    
#> 109: 0.436144    1.073271    3.531846    0.198583    0.081611    0.021326    0.673711    
#> 110: 0.481410    1.053350    3.524547    0.243300    0.077530    0.023459    0.674832    
#> 111: 0.480535    1.067721    3.537057    0.231135    0.076944    0.024644    0.656495    
#> 112: 0.452026    1.040237    3.522547    0.219579    0.098147    0.023681    0.678936    
#> 113: 0.457694    1.088260    3.523269    0.208600    0.102550    0.022497    0.669251    
#> 114: 0.414107    1.083318    3.521744    0.200376    0.100884    0.021372    0.686966    
#> 115: 0.482375    1.035611    3.535411    0.196714    0.095840    0.020303    0.694568    
#> 116: 0.477696    1.058950    3.531592    0.201341    0.091048    0.025869    0.688246    
#> 117: 0.425467    1.073383    3.528420    0.191274    0.095014    0.024576    0.687238    
#> 118: 0.434007    1.067480    3.521544    0.181723    0.092018    0.023347    0.704676    
#> 119: 0.412401    1.075890    3.514377    0.231072    0.099750    0.022180    0.701060    
#> 120: 0.370873    1.088541    3.505752    0.219519    0.094762    0.022239    0.680440    
#> 121: 0.403926    1.099374    3.511877    0.238194    0.096521    0.021127    0.698650    
#> 122: 0.410664    1.080190    3.520996    0.226284    0.091695    0.020071    0.672394    
#> 123: 0.421747    1.113460    3.501262    0.218645    0.106274    0.019067    0.694772    
#> 124: 0.405815    1.115571    3.506142    0.207713    0.102048    0.019511    0.690727    
#> 125: 0.421130    1.109477    3.503069    0.197327    0.102054    0.019401    0.690899    
#> 126: 0.385460    1.123267    3.495399    0.187461    0.096951    0.019335    0.711054    
#> 127: 0.391966    1.075769    3.496866    0.178088    0.092104    0.020936    0.711365    
#> 128: 0.377048    1.103917    3.502816    0.189746    0.100894    0.019889    0.700065    
#> 129: 0.413916    1.108145    3.515912    0.206898    0.095849    0.018895    0.700948    
#> 130: 0.462352    1.095483    3.519087    0.196553    0.104951    0.017950    0.676920    
#> 131: 0.440625    1.079948    3.508419    0.200492    0.099704    0.017052    0.699138    
#> 132: 0.384623    1.095881    3.486669    0.190468    0.094719    0.018077    0.707708    
#> 133: 0.385937    1.081008    3.491243    0.212652    0.089983    0.017173    0.695153    
#> 134: 0.417154    1.067550    3.510332    0.240253    0.085826    0.016314    0.700640    
#> 135: 0.406282    1.080286    3.508397    0.228240    0.113850    0.015498    0.698349    
#> 136: 0.413022    1.074700    3.509058    0.262306    0.108158    0.014851    0.676737    
#> 137: 0.462027    1.101401    3.517358    0.249191    0.102750    0.018150    0.684417    
#> 138: 0.423364    1.101149    3.505488    0.253984    0.125311    0.017242    0.683747    
#> 139: 0.436972    1.088449    3.517602    0.241284    0.125013    0.016380    0.687712    
#> 140: 0.426237    1.089520    3.516289    0.237883    0.119375    0.015561    0.699841    
#> 141: 0.427017    1.065615    3.516351    0.262748    0.122281    0.014783    0.692963    
#> 142: 0.445721    1.067144    3.521869    0.250113    0.116167    0.015143    0.707100    
#> 143: 0.403172    1.097631    3.515739    0.242607    0.110358    0.020441    0.681483    
#> 144: 0.461557    1.087781    3.529019    0.230476    0.104840    0.024184    0.653557    
#> 145: 0.429675    1.104825    3.511900    0.224814    0.099598    0.022975    0.648268    
#> 146: 0.415414    1.084882    3.523512    0.213574    0.094618    0.021826    0.669531    
#> 147: 0.404958    1.079468    3.514220    0.202895    0.089888    0.027254    0.671918    
#> 148: 0.422636    1.082780    3.524701    0.223313    0.087902    0.025891    0.688761    
#> 149: 0.415263    1.062350    3.519516    0.217556    0.083926    0.024597    0.687183    
#> 150: 0.446035    1.073633    3.513595    0.206679    0.086665    0.026669    0.712364    
#> 151: 0.400898    1.110957    3.512891    0.213988    0.092546    0.025335    0.698487    
#> 152: 0.400232    1.107595    3.506340    0.240847    0.084740    0.020461    0.693320    
#> 153: 0.395194    1.083985    3.513293    0.206779    0.090750    0.023058    0.698331    
#> 154: 0.429200    1.093893    3.506616    0.200313    0.088183    0.024425    0.689560    
#> 155: 0.385888    1.066614    3.501790    0.256922    0.096185    0.019820    0.705028    
#> 156: 0.383933    1.089663    3.511110    0.272031    0.095909    0.022465    0.724556    
#> 157: 0.446299    1.081718    3.517907    0.284384    0.098550    0.020554    0.704018    
#> 158: 0.482678    1.073655    3.516634    0.262605    0.084070    0.020965    0.698116    
#> 159: 0.448295    1.089743    3.534393    0.237226    0.081759    0.024722    0.689229    
#> 160: 0.490799    1.056360    3.542132    0.202859    0.079664    0.026139    0.697857    
#> 161: 0.479588    1.069471    3.531396    0.236690    0.091404    0.025326    0.690798    
#> 162: 0.450439    1.102325    3.516027    0.250850    0.104083    0.022141    0.684813    
#> 163: 0.475080    1.088334    3.515032    0.267966    0.098659    0.024335    0.682466    
#> 164: 0.467476    1.058004    3.515252    0.285487    0.091978    0.023047    0.676054    
#> 165: 0.430231    1.077016    3.520997    0.240867    0.086716    0.025498    0.673503    
#> 166: 0.465383    1.086240    3.519430    0.314424    0.078383    0.027500    0.686937    
#> 167: 0.463176    1.098918    3.530688    0.272195    0.077336    0.027414    0.698871    
#> 168: 0.467806    1.098079    3.518802    0.267689    0.087329    0.018158    0.707081    
#> 169: 0.425524    1.127934    3.507283    0.233934    0.093401    0.020722    0.712275    
#> 170: 0.413024    1.122017    3.505242    0.223109    0.093229    0.020844    0.682994    
#> 171: 0.389257    1.103974    3.497676    0.203552    0.084335    0.018856    0.676920    
#> 172: 0.388575    1.107457    3.503580    0.178843    0.095151    0.014916    0.685187    
#> 173: 0.402279    1.118323    3.497732    0.164178    0.103115    0.015061    0.689233    
#> 174: 0.408073    1.100155    3.508265    0.167994    0.096118    0.017708    0.687633    
#> 175: 0.389885    1.095201    3.493374    0.174372    0.107375    0.016736    0.684447    
#> 176: 0.387809    1.111824    3.505641    0.138086    0.097747    0.017796    0.704682    
#> 177: 0.423729    1.080651    3.524544    0.178844    0.083977    0.020626    0.709337    
#> 178: 0.420047    1.076922    3.511285    0.153889    0.089666    0.017430    0.691351    
#> 179: 0.419404    1.102611    3.502684    0.190004    0.089687    0.016836    0.709923    
#> 180: 0.384311    1.093571    3.501351    0.162770    0.096327    0.017563    0.696984    
#> 181: 0.385388    1.118758    3.485031    0.154974    0.098341    0.019056    0.687579    
#> 182: 0.337692    1.114132    3.487276    0.179634    0.102076    0.020460    0.702391    
#> 183: 0.368350    1.126462    3.490230    0.168224    0.105538    0.020284    0.696410    
#> 184: 0.392336    1.099429    3.495044    0.234464    0.089957    0.018901    0.686121    
#> 185: 0.368675    1.109321    3.491117    0.199981    0.095634    0.018319    0.680310    
#> 186: 0.389189    1.128726    3.492892    0.179764    0.114013    0.018968    0.692032    
#> 187: 0.410112    1.084827    3.505395    0.216783    0.097995    0.017724    0.694350    
#> 188: 0.363193    1.095614    3.496533    0.193813    0.103636    0.018835    0.706425    
#> 189: 0.416327    1.102456    3.506240    0.198026    0.121921    0.016419    0.708618    
#> 190: 0.396906    1.094509    3.510063    0.213848    0.079841    0.019396    0.686603    
#> 191: 0.373151    1.102785    3.497180    0.183118    0.077016    0.019267    0.684038    
#> 192: 0.355596    1.124673    3.493129    0.182947    0.070258    0.019435    0.678514    
#> 193: 0.417292    1.113016    3.500055    0.199395    0.064706    0.021124    0.678324    
#> 194: 0.389068    1.106968    3.493247    0.243902    0.078378    0.025555    0.696923    
#> 195: 0.381636    1.105314    3.499215    0.232141    0.083436    0.029349    0.664418    
#> 196: 0.395387    1.098446    3.511640    0.265325    0.081683    0.028867    0.670962    
#> 197: 0.366543    1.107144    3.517406    0.227186    0.080957    0.028870    0.699998    
#> 198: 0.432660    1.084208    3.520515    0.218009    0.083844    0.027934    0.665861    
#> 199: 0.405898    1.073242    3.509130    0.200730    0.078014    0.024761    0.667057    
#> 200: 0.420070    1.074542    3.516647    0.187700    0.080622    0.021458    0.685971    
#> 201: 0.417011    1.073449    3.522051    0.183680    0.077658    0.022041    0.690256    
#> 202: 0.408809    1.074560    3.521272    0.183543    0.076419    0.023284    0.687381    
#> 203: 0.411140    1.075013    3.519542    0.179837    0.076618    0.023746    0.686809    
#> 204: 0.419863    1.067924    3.522491    0.180923    0.079262    0.024921    0.686600    
#> 205: 0.423376    1.071525    3.523119    0.182421    0.080106    0.025686    0.689199    
#> 206: 0.428622    1.073779    3.523985    0.185386    0.081256    0.025304    0.689178    
#> 207: 0.428573    1.073946    3.522746    0.185602    0.082006    0.024716    0.688427    
#> 208: 0.429218    1.074369    3.522590    0.183491    0.082777    0.023900    0.686938    
#> 209: 0.431134    1.073172    3.521323    0.186723    0.084064    0.023034    0.686676    
#> 210: 0.433767    1.071940    3.521891    0.185517    0.085298    0.022605    0.685479    
#> 211: 0.434376    1.072990    3.521844    0.185256    0.086968    0.022465    0.683540    
#> 212: 0.434504    1.072782    3.521877    0.183383    0.085816    0.022806    0.683876    
#> 213: 0.437415    1.071391    3.522881    0.184165    0.083878    0.023275    0.685460    
#> 214: 0.438591    1.071088    3.523232    0.185144    0.082502    0.023373    0.686759    
#> 215: 0.437063    1.070928    3.523349    0.184178    0.082013    0.023397    0.687398    
#> 216: 0.437378    1.070600    3.523365    0.185555    0.083313    0.023561    0.689047    
#> 217: 0.436546    1.070743    3.523577    0.185656    0.084062    0.023483    0.688570    
#> 218: 0.435744    1.071371    3.523615    0.186591    0.084593    0.023456    0.687346    
#> 219: 0.434953    1.071135    3.522740    0.187801    0.084859    0.023069    0.687233    
#> 220: 0.434906    1.070988    3.522432    0.189938    0.085284    0.023040    0.687026    
#> 221: 0.433675    1.072489    3.521854    0.191823    0.085499    0.022966    0.686743    
#> 222: 0.433531    1.073367    3.521064    0.195313    0.086006    0.022828    0.686100    
#> 223: 0.434959    1.074222    3.521268    0.196530    0.087008    0.022661    0.685845    
#> 224: 0.436047    1.075093    3.521121    0.197530    0.087693    0.022486    0.685729    
#> 225: 0.435955    1.073655    3.521649    0.196930    0.087995    0.022313    0.685988    
#> 226: 0.435458    1.072504    3.521270    0.196611    0.087908    0.022256    0.685963    
#> 227: 0.435171    1.072919    3.521483    0.197385    0.088279    0.022207    0.685300    
#> 228: 0.432802    1.073633    3.520583    0.197814    0.088329    0.022180    0.685438    
#> 229: 0.431536    1.073642    3.519967    0.197978    0.088158    0.022202    0.685076    
#> 230: 0.430791    1.073406    3.519484    0.197163    0.087919    0.022058    0.685051    
#> 231: 0.430842    1.074003    3.519428    0.198467    0.088425    0.022021    0.684729    
#> 232: 0.430316    1.074223    3.519725    0.198665    0.088331    0.022065    0.684386    
#> 233: 0.430470    1.073694    3.519956    0.198546    0.088298    0.022081    0.685072    
#> 234: 0.430486    1.074033    3.519809    0.199784    0.088470    0.022195    0.684889    
#> 235: 0.430109    1.074163    3.519579    0.200453    0.088196    0.022276    0.684819    
#> 236: 0.430010    1.075060    3.519211    0.200862    0.088141    0.022229    0.685051    
#> 237: 0.429507    1.075580    3.518784    0.200651    0.088463    0.022135    0.685890    
#> 238: 0.429804    1.075272    3.519048    0.201288    0.088986    0.022059    0.686123    
#> 239: 0.429709    1.075382    3.518883    0.201528    0.089106    0.021963    0.686189    
#> 240: 0.429318    1.075263    3.518716    0.201523    0.089160    0.021882    0.685715    
#> 241: 0.429513    1.074555    3.518734    0.201379    0.089213    0.021890    0.685615    
#> 242: 0.428656    1.074434    3.518316    0.200493    0.089250    0.021880    0.685964    
#> 243: 0.427709    1.074637    3.518038    0.200059    0.089191    0.021866    0.686315    
#> 244: 0.427073    1.074789    3.517973    0.200788    0.088866    0.021876    0.686304    
#> 245: 0.427296    1.074635    3.517968    0.201063    0.089041    0.021864    0.686734    
#> 246: 0.427436    1.074663    3.518012    0.201390    0.088922    0.021832    0.687161    
#> 247: 0.427537    1.074223    3.518153    0.201527    0.088871    0.021868    0.687290    
#> 248: 0.427324    1.074185    3.518117    0.201525    0.088588    0.021855    0.687185    
#> 249: 0.427714    1.074395    3.518325    0.201736    0.088618    0.021820    0.686947    
#> 250: 0.428235    1.074170    3.518681    0.201700    0.088585    0.021997    0.686886    
#> 251: 0.429388    1.074383    3.519150    0.202154    0.088527    0.022085    0.686924    
#> 252: 0.430079    1.074730    3.519658    0.202232    0.088734    0.022085    0.687116    
#> 253: 0.430343    1.074992    3.519912    0.202367    0.088865    0.022256    0.687268    
#> 254: 0.430627    1.075554    3.519995    0.202372    0.089096    0.022257    0.687281    
#> 255: 0.430649    1.075973    3.519926    0.202730    0.088842    0.022271    0.687408    
#> 256: 0.430964    1.076221    3.519795    0.202806    0.088711    0.022226    0.687855    
#> 257: 0.430666    1.075915    3.519641    0.203544    0.088866    0.022156    0.688004    
#> 258: 0.430249    1.075692    3.519690    0.202879    0.088678    0.022194    0.688191    
#> 259: 0.430379    1.075497    3.519854    0.202943    0.088596    0.022279    0.688519    
#> 260: 0.430032    1.075529    3.519912    0.202814    0.088656    0.022296    0.688346    
#> 261: 0.429766    1.075441    3.519988    0.202787    0.088611    0.022296    0.688340    
#> 262: 0.429950    1.075546    3.520182    0.202340    0.088619    0.022396    0.688541    
#> 263: 0.429964    1.075929    3.520251    0.201708    0.088786    0.022458    0.688791    
#> 264: 0.429863    1.076143    3.520103    0.201835    0.088899    0.022488    0.689066    
#> 265: 0.429707    1.076078    3.520132    0.201890    0.088953    0.022565    0.689207    
#> 266: 0.429958    1.076158    3.520141    0.201563    0.089033    0.022580    0.689182    
#> 267: 0.430637    1.076033    3.520352    0.201489    0.089128    0.022646    0.689045    
#> 268: 0.431063    1.075844    3.520455    0.201663    0.089164    0.022634    0.688907    
#> 269: 0.432267    1.075609    3.520653    0.201998    0.089213    0.022642    0.689096    
#> 270: 0.432919    1.075537    3.520671    0.202315    0.089120    0.022621    0.688789    
#> 271: 0.433163    1.075280    3.520669    0.202438    0.088986    0.022630    0.689206    
#> 272: 0.433396    1.074937    3.520696    0.202923    0.089044    0.022664    0.689823    
#> 273: 0.433244    1.075092    3.520745    0.202620    0.089001    0.022659    0.690069    
#> 274: 0.433246    1.075072    3.520846    0.202060    0.088881    0.022631    0.690114    
#> 275: 0.432969    1.074922    3.520883    0.201984    0.088908    0.022595    0.690050    
#> 276: 0.432806    1.075029    3.521033    0.201664    0.088759    0.022602    0.690045    
#> 277: 0.432929    1.075134    3.521248    0.201771    0.088858    0.022636    0.690144    
#> 278: 0.433331    1.074905    3.521639    0.201781    0.089245    0.022660    0.690154    
#> 279: 0.433337    1.074720    3.521754    0.201773    0.089553    0.022669    0.690360    
#> 280: 0.433617    1.074803    3.521841    0.201484    0.089552    0.022655    0.690356    
#> 281: 0.433397    1.075144    3.521793    0.201214    0.089485    0.022688    0.690258    
#> 282: 0.433433    1.075303    3.521773    0.201419    0.089389    0.022718    0.690214    
#> 283: 0.433607    1.075344    3.521866    0.201513    0.089286    0.022768    0.690270    
#> 284: 0.433581    1.075121    3.521882    0.201362    0.089006    0.022818    0.690219    
#> 285: 0.433417    1.075195    3.521664    0.201850    0.088691    0.022862    0.690193    
#> 286: 0.433283    1.075533    3.521422    0.202488    0.088668    0.022932    0.689990    
#> 287: 0.433274    1.075623    3.521383    0.203139    0.088392    0.023034    0.689847    
#> 288: 0.433486    1.075617    3.521419    0.203438    0.088385    0.023065    0.689822    
#> 289: 0.433676    1.075552    3.521415    0.203454    0.088289    0.023061    0.689938    
#> 290: 0.433806    1.075314    3.521541    0.203203    0.088136    0.023097    0.690016    
#> 291: 0.434195    1.075243    3.521769    0.202963    0.087879    0.023218    0.689770    
#> 292: 0.434147    1.075072    3.521926    0.202994    0.087710    0.023276    0.689645    
#> 293: 0.434206    1.075034    3.521902    0.203073    0.087645    0.023296    0.689380    
#> 294: 0.434236    1.075029    3.521855    0.202723    0.087635    0.023266    0.689256    
#> 295: 0.434217    1.074749    3.521904    0.202915    0.087536    0.023279    0.689041    
#> 296: 0.434146    1.074619    3.521947    0.202776    0.087335    0.023331    0.689159    
#> 297: 0.434267    1.074677    3.521948    0.202572    0.087202    0.023355    0.689204    
#> 298: 0.434340    1.074676    3.521914    0.202615    0.087074    0.023377    0.689159    
#> 299: 0.434179    1.074954    3.521705    0.202887    0.087026    0.023349    0.689156    
#> 300: 0.434227    1.074983    3.521714    0.202868    0.087114    0.023348    0.688977    
#> 301: 0.434301    1.074991    3.521552    0.202653    0.087294    0.023313    0.689008    
#> 302: 0.434202    1.075102    3.521496    0.202779    0.087513    0.023268    0.688921    
#> 303: 0.434184    1.075197    3.521424    0.202454    0.087492    0.023241    0.688767    
#> 304: 0.434326    1.075445    3.521399    0.202161    0.087513    0.023223    0.688792    
#> 305: 0.434252    1.075127    3.521346    0.202361    0.087610    0.023225    0.688824    
#> 306: 0.433993    1.075169    3.521238    0.202554    0.087616    0.023190    0.688730    
#> 307: 0.433723    1.075371    3.521026    0.202010    0.087836    0.023147    0.688923    
#> 308: 0.433376    1.075423    3.520943    0.202042    0.088025    0.023098    0.689081    
#> 309: 0.433390    1.075174    3.520878    0.202045    0.087991    0.023052    0.689379    
#> 310: 0.433289    1.075031    3.520751    0.202448    0.088072    0.023019    0.689479    
#> 311: 0.433604    1.074984    3.520777    0.202775    0.087940    0.023055    0.689479    
#> 312: 0.433657    1.074771    3.520832    0.202699    0.087884    0.023043    0.689444    
#> 313: 0.433599    1.074350    3.520788    0.202546    0.087942    0.023004    0.689616    
#> 314: 0.433278    1.074390    3.520586    0.202448    0.088000    0.022945    0.689610    
#> 315: 0.432934    1.074661    3.520442    0.202823    0.087994    0.022952    0.689622    
#> 316: 0.432766    1.074802    3.520282    0.203180    0.087841    0.022957    0.689563    
#> 317: 0.432561    1.074981    3.520266    0.203378    0.087715    0.022930    0.689688    
#> 318: 0.432431    1.075047    3.520083    0.203505    0.087627    0.022931    0.689659    
#> 319: 0.432188    1.075073    3.519961    0.203505    0.087611    0.022906    0.689623    
#> 320: 0.431784    1.075196    3.519859    0.203496    0.087573    0.022884    0.689692    
#> 321: 0.431560    1.075389    3.519761    0.203260    0.087652    0.022841    0.689753    
#> 322: 0.431447    1.075332    3.519672    0.203380    0.087574    0.022809    0.689798    
#> 323: 0.431076    1.075318    3.519629    0.203552    0.087464    0.022801    0.689895    
#> 324: 0.431219    1.075152    3.519744    0.203459    0.087454    0.022758    0.689901    
#> 325: 0.431178    1.075127    3.519806    0.203230    0.087493    0.022732    0.689918    
#> 326: 0.431100    1.074999    3.519700    0.203302    0.087645    0.022679    0.689851    
#> 327: 0.431077    1.075017    3.519666    0.203666    0.087897    0.022600    0.689819    
#> 328: 0.431247    1.075257    3.519647    0.203889    0.087925    0.022558    0.689759    
#> 329: 0.431474    1.075389    3.519664    0.204163    0.087865    0.022561    0.689749    
#> 330: 0.431233    1.075374    3.519641    0.204359    0.087769    0.022577    0.689696    
#> 331: 0.431369    1.075476    3.519717    0.204390    0.087731    0.022564    0.689676    
#> 332: 0.431343    1.075543    3.519795    0.204618    0.087643    0.022622    0.689623    
#> 333: 0.431119    1.075573    3.519691    0.204907    0.087627    0.022626    0.689569    
#> 334: 0.430669    1.075547    3.519459    0.205278    0.087598    0.022579    0.689671    
#> 335: 0.430259    1.075644    3.519242    0.205380    0.087637    0.022580    0.689607    
#> 336: 0.429876    1.075919    3.519055    0.205384    0.087636    0.022569    0.689674    
#> 337: 0.429695    1.076402    3.518832    0.205653    0.087626    0.022556    0.689724    
#> 338: 0.429384    1.076665    3.518735    0.205845    0.087592    0.022533    0.689748    
#> 339: 0.429038    1.077002    3.518580    0.206086    0.087515    0.022534    0.689816    
#> 340: 0.428880    1.076932    3.518500    0.206267    0.087538    0.022538    0.689757    
#> 341: 0.428855    1.077006    3.518456    0.206364    0.087482    0.022532    0.689747    
#> 342: 0.428646    1.076887    3.518418    0.206246    0.087481    0.022555    0.689604    
#> 343: 0.428232    1.076884    3.518335    0.206359    0.087481    0.022571    0.689539    
#> 344: 0.428161    1.076840    3.518349    0.206330    0.087478    0.022595    0.689566    
#> 345: 0.428161    1.076911    3.518364    0.206345    0.087373    0.022626    0.689588    
#> 346: 0.428085    1.077121    3.518243    0.206527    0.087246    0.022642    0.689487    
#> 347: 0.428022    1.077156    3.518133    0.206466    0.087136    0.022657    0.689563    
#> 348: 0.427784    1.077329    3.518058    0.206682    0.087168    0.022670    0.689429    
#> 349: 0.427641    1.077400    3.517922    0.206732    0.087245    0.022672    0.689331    
#> 350: 0.427171    1.077430    3.517789    0.206793    0.087288    0.022634    0.689379    
#> 351: 0.427052    1.077630    3.517664    0.206943    0.087291    0.022593    0.689450    
#> 352: 0.426662    1.077890    3.517547    0.207324    0.087398    0.022582    0.689455    
#> 353: 0.426504    1.077996    3.517394    0.207553    0.087393    0.022577    0.689527    
#> 354: 0.426282    1.078082    3.517242    0.207486    0.087439    0.022559    0.689646    
#> 355: 0.426613    1.077991    3.517265    0.207387    0.087453    0.022567    0.689672    
#> 356: 0.426593    1.077955    3.517271    0.207241    0.087442    0.022576    0.689818    
#> 357: 0.426761    1.078041    3.517268    0.207467    0.087425    0.022590    0.689813    
#> 358: 0.426875    1.078009    3.517337    0.207712    0.087409    0.022600    0.689757    
#> 359: 0.426830    1.078158    3.517336    0.207733    0.087421    0.022603    0.689753    
#> 360: 0.426742    1.078169    3.517265    0.207575    0.087433    0.022575    0.689640    
#> 361: 0.426634    1.078356    3.517208    0.207563    0.087589    0.022533    0.689540    
#> 362: 0.426588    1.078522    3.517029    0.207878    0.087650    0.022487    0.689468    
#> 363: 0.426506    1.078583    3.516945    0.207880    0.087654    0.022455    0.689334    
#> 364: 0.426379    1.078668    3.516864    0.207778    0.087715    0.022428    0.689289    
#> 365: 0.426157    1.078632    3.516799    0.207615    0.087703    0.022385    0.689346    
#> 366: 0.426062    1.078659    3.516689    0.207582    0.087745    0.022359    0.689414    
#> 367: 0.425971    1.078727    3.516635    0.207743    0.087816    0.022331    0.689354    
#> 368: 0.426086    1.078822    3.516576    0.207810    0.087856    0.022327    0.689282    
#> 369: 0.426003    1.078776    3.516510    0.207817    0.087913    0.022294    0.689290    
#> 370: 0.425900    1.078900    3.516445    0.207726    0.088087    0.022250    0.689360    
#> 371: 0.425716    1.079063    3.516302    0.207897    0.088169    0.022211    0.689472    
#> 372: 0.425634    1.079119    3.516229    0.208075    0.088179    0.022197    0.689495    
#> 373: 0.425369    1.079273    3.516164    0.207973    0.088165    0.022201    0.689496    
#> 374: 0.425190    1.079360    3.516083    0.207934    0.088187    0.022226    0.689402    
#> 375: 0.424970    1.079528    3.516017    0.207811    0.088307    0.022230    0.689457    
#> 376: 0.425038    1.079618    3.516006    0.207731    0.088388    0.022245    0.689442    
#> 377: 0.425065    1.079604    3.516055    0.207623    0.088362    0.022268    0.689384    
#> 378: 0.424989    1.079609    3.516007    0.207748    0.088302    0.022269    0.689349    
#> 379: 0.425075    1.079502    3.515997    0.207583    0.088334    0.022251    0.689302    
#> 380: 0.424942    1.079466    3.515976    0.207474    0.088248    0.022231    0.689306    
#> 381: 0.424852    1.079473    3.515938    0.207299    0.088235    0.022206    0.689329    
#> 382: 0.424859    1.079475    3.515943    0.207057    0.088233    0.022186    0.689254    
#> 383: 0.424889    1.079512    3.515942    0.206892    0.088240    0.022159    0.689197    
#> 384: 0.424595    1.079537    3.515890    0.206790    0.088205    0.022143    0.689201    
#> 385: 0.424425    1.079547    3.515845    0.206768    0.088235    0.022133    0.689212    
#> 386: 0.424454    1.079862    3.515799    0.206764    0.088203    0.022134    0.689227    
#> 387: 0.424380    1.080082    3.515864    0.206770    0.088183    0.022144    0.689171    
#> 388: 0.424410    1.080244    3.515894    0.206772    0.088082    0.022168    0.689152    
#> 389: 0.424349    1.080107    3.515945    0.206643    0.087983    0.022189    0.689317    
#> 390: 0.424293    1.080149    3.515943    0.206517    0.087860    0.022210    0.689485    
#> 391: 0.424346    1.080113    3.515924    0.206676    0.087825    0.022201    0.689497    
#> 392: 0.424377    1.080054    3.515981    0.206713    0.087811    0.022210    0.689471    
#> 393: 0.424215    1.080044    3.515919    0.206713    0.087779    0.022216    0.689408    
#> 394: 0.424100    1.080081    3.515822    0.206807    0.087717    0.022219    0.689445    
#> 395: 0.424294    1.080184    3.515822    0.206908    0.087729    0.022234    0.689436    
#> 396: 0.424598    1.080211    3.515924    0.206825    0.087659    0.022234    0.689396    
#> 397: 0.424825    1.080144    3.516040    0.206773    0.087614    0.022254    0.689316    
#> 398: 0.425050    1.080030    3.516195    0.206695    0.087598    0.022292    0.689301    
#> 399: 0.425193    1.079951    3.516279    0.206563    0.087566    0.022311    0.689332    
#> 400: 0.425234    1.079991    3.516332    0.206221    0.087551    0.022317    0.689355    
#> 401: 0.425258    1.080028    3.516322    0.206081    0.087529    0.022316    0.689441    
#> 402: 0.425234    1.080095    3.516349    0.205923    0.087403    0.022317    0.689586    
#> 403: 0.425405    1.080145    3.516368    0.206159    0.087340    0.022321    0.689553    
#> 404: 0.425497    1.080205    3.516304    0.206399    0.087272    0.022300    0.689507    
#> 405: 0.425435    1.080238    3.516291    0.206613    0.087268    0.022277    0.689591    
#> 406: 0.425388    1.080263    3.516236    0.206645    0.087307    0.022269    0.689699    
#> 407: 0.425343    1.080312    3.516214    0.206726    0.087383    0.022258    0.689667    
#> 408: 0.425409    1.080306    3.516267    0.206677    0.087378    0.022258    0.689770    
#> 409: 0.425369    1.080196    3.516247    0.206493    0.087438    0.022249    0.689788    
#> 410: 0.425257    1.080274    3.516146    0.206313    0.087529    0.022238    0.689825    
#> 411: 0.425259    1.080056    3.516136    0.206226    0.087578    0.022233    0.689918    
#> 412: 0.425223    1.080030    3.516130    0.206181    0.087595    0.022207    0.689988    
#> 413: 0.425141    1.079992    3.516112    0.206153    0.087678    0.022185    0.690112    
#> 414: 0.424992    1.079907    3.516102    0.206184    0.087703    0.022143    0.690119    
#> 415: 0.425094    1.079770    3.516114    0.206313    0.087706    0.022103    0.690160    
#> 416: 0.425257    1.079773    3.516166    0.206248    0.087786    0.022093    0.690088    
#> 417: 0.425511    1.079710    3.516258    0.206094    0.087821    0.022099    0.690015    
#> 418: 0.425465    1.079732    3.516310    0.206022    0.087873    0.022103    0.689981    
#> 419: 0.425537    1.079808    3.516307    0.206072    0.087975    0.022114    0.689876    
#> 420: 0.425558    1.079840    3.516295    0.206118    0.087936    0.022106    0.689730    
#> 421: 0.425453    1.079864    3.516318    0.206099    0.087974    0.022108    0.689625    
#> 422: 0.425550    1.079806    3.516351    0.206106    0.088023    0.022096    0.689571    
#> 423: 0.425760    1.079678    3.516429    0.206200    0.088002    0.022102    0.689635    
#> 424: 0.425787    1.079591    3.516418    0.206293    0.087958    0.022107    0.689621    
#> 425: 0.426040    1.079661    3.516414    0.206269    0.087925    0.022107    0.689775    
#> 426: 0.426133    1.079799    3.516404    0.206396    0.087926    0.022091    0.689709    
#> 427: 0.425956    1.079786    3.516417    0.206391    0.087868    0.022086    0.689673    
#> 428: 0.425796    1.079827    3.516451    0.206391    0.087791    0.022083    0.689667    
#> 429: 0.425748    1.079887    3.516474    0.206270    0.087789    0.022076    0.689629    
#> 430: 0.425822    1.079966    3.516457    0.206230    0.087786    0.022060    0.689637    
#> 431: 0.425834    1.080058    3.516418    0.206042    0.087812    0.022045    0.689633    
#> 432: 0.425866    1.080138    3.516453    0.205885    0.087859    0.022056    0.689599    
#> 433: 0.425922    1.080238    3.516495    0.205601    0.087880    0.022044    0.689609    
#> 434: 0.425850    1.080157    3.516501    0.205415    0.087819    0.022037    0.689636    
#> 435: 0.425824    1.080146    3.516484    0.205251    0.087799    0.022042    0.689607    
#> 436: 0.425838    1.080163    3.516525    0.205049    0.087852    0.022049    0.689692    
#> 437: 0.425786    1.080177    3.516548    0.204949    0.087861    0.022042    0.689675    
#> 438: 0.425701    1.080248    3.516554    0.205015    0.087896    0.022027    0.689663    
#> 439: 0.425666    1.080376    3.516584    0.205024    0.087964    0.022015    0.689559    
#> 440: 0.425584    1.080411    3.516613    0.204845    0.087946    0.022020    0.689503    
#> 441: 0.425563    1.080426    3.516598    0.204771    0.088023    0.022015    0.689473    
#> 442: 0.425417    1.080477    3.516564    0.204767    0.088081    0.022012    0.689441    
#> 443: 0.425365    1.080483    3.516558    0.204754    0.088076    0.022012    0.689466    
#> 444: 0.425404    1.080471    3.516522    0.204643    0.088088    0.022024    0.689487    
#> 445: 0.425360    1.080437    3.516553    0.204651    0.088090    0.022045    0.689533    
#> 446: 0.425161    1.080532    3.516456    0.204615    0.088112    0.022047    0.689512    
#> 447: 0.425215    1.080584    3.516449    0.204585    0.088091    0.022048    0.689501    
#> 448: 0.425077    1.080604    3.516455    0.204502    0.088094    0.022044    0.689486    
#> 449: 0.425063    1.080763    3.516498    0.204445    0.088149    0.022049    0.689438    
#> 450: 0.425023    1.080783    3.516498    0.204389    0.088128    0.022071    0.689433    
#> 451: 0.425116    1.080800    3.516489    0.204560    0.088081    0.022083    0.689435    
#> 452: 0.425154    1.080758    3.516498    0.204582    0.088029    0.022097    0.689400    
#> 453: 0.425174    1.080755    3.516497    0.204528    0.088015    0.022110    0.689365    
#> 454: 0.425208    1.080832    3.516522    0.204401    0.088072    0.022100    0.689341    
#> 455: 0.425206    1.080873    3.516504    0.204321    0.088027    0.022098    0.689362    
#> 456: 0.425162    1.080820    3.516500    0.204481    0.087968    0.022091    0.689322    
#> 457: 0.425109    1.080773    3.516536    0.204671    0.087907    0.022115    0.689285    
#> 458: 0.425106    1.080858    3.516586    0.204817    0.087862    0.022141    0.689262    
#> 459: 0.425015    1.080937    3.516615    0.204806    0.087775    0.022163    0.689219    
#> 460: 0.424794    1.081068    3.516538    0.204785    0.087737    0.022166    0.689239    
#> 461: 0.424585    1.081155    3.516476    0.204748    0.087709    0.022161    0.689249    
#> 462: 0.424432    1.081208    3.516472    0.204851    0.087644    0.022175    0.689234    
#> 463: 0.424513    1.081262    3.516522    0.205042    0.087600    0.022202    0.689162    
#> 464: 0.424555    1.081301    3.516490    0.205221    0.087580    0.022212    0.689073    
#> 465: 0.424616    1.081133    3.516496    0.205385    0.087561    0.022207    0.689076    
#> 466: 0.424577    1.081152    3.516457    0.205405    0.087530    0.022211    0.689045    
#> 467: 0.424498    1.081107    3.516441    0.205434    0.087489    0.022216    0.688924    
#> 468: 0.424727    1.081102    3.516489    0.205462    0.087501    0.022215    0.688888    
#> 469: 0.424883    1.081207    3.516544    0.205406    0.087509    0.022214    0.688904    
#> 470: 0.424795    1.081247    3.516521    0.205380    0.087571    0.022218    0.688904    
#> 471: 0.424563    1.081189    3.516507    0.205231    0.087521    0.022223    0.688947    
#> 472: 0.424504    1.081231    3.516480    0.205103    0.087570    0.022226    0.688955    
#> 473: 0.424384    1.081265    3.516453    0.205058    0.087521    0.022215    0.688905    
#> 474: 0.424330    1.081218    3.516435    0.205100    0.087546    0.022193    0.688889    
#> 475: 0.424338    1.081319    3.516431    0.205108    0.087513    0.022171    0.688902    
#> 476: 0.424404    1.081326    3.516413    0.205044    0.087558    0.022161    0.688911    
#> 477: 0.424319    1.081362    3.516409    0.205006    0.087620    0.022138    0.688854    
#> 478: 0.424213    1.081359    3.516388    0.204954    0.087613    0.022119    0.688912    
#> 479: 0.424246    1.081413    3.516395    0.204883    0.087650    0.022097    0.688959    
#> 480: 0.424284    1.081447    3.516409    0.204776    0.087720    0.022085    0.689009    
#> 481: 0.424195    1.081480    3.516382    0.204795    0.087785    0.022062    0.688981    
#> 482: 0.424239    1.081436    3.516373    0.204794    0.087813    0.022065    0.688951    
#> 483: 0.424198    1.081363    3.516353    0.204738    0.087861    0.022054    0.688947    
#> 484: 0.424095    1.081295    3.516325    0.204757    0.087850    0.022036    0.689075    
#> 485: 0.424174    1.081324    3.516342    0.204769    0.087885    0.022034    0.689046    
#> 486: 0.424253    1.081297    3.516409    0.204777    0.087918    0.022042    0.689009    
#> 487: 0.424451    1.081261    3.516521    0.204819    0.087952    0.022045    0.688950    
#> 488: 0.424612    1.081261    3.516585    0.204778    0.087931    0.022039    0.688917    
#> 489: 0.424827    1.081200    3.516610    0.204732    0.087933    0.022026    0.688913    
#> 490: 0.425077    1.081171    3.516678    0.204707    0.087930    0.022020    0.688912    
#> 491: 0.425147    1.081211    3.516764    0.204742    0.087955    0.022022    0.688879    
#> 492: 0.425217    1.081229    3.516810    0.204711    0.087954    0.022031    0.688942    
#> 493: 0.425318    1.081218    3.516875    0.204577    0.087975    0.022037    0.688989    
#> 494: 0.425444    1.081297    3.516892    0.204521    0.088014    0.022028    0.688950    
#> 495: 0.425547    1.081250    3.516913    0.204550    0.087994    0.022020    0.688928    
#> 496: 0.425609    1.081215    3.516902    0.204514    0.087983    0.022025    0.688949    
#> 497: 0.425489    1.081187    3.516858    0.204566    0.087940    0.022050    0.688952    
#> 498: 0.425496    1.081195    3.516827    0.204606    0.087975    0.022047    0.688893    
#> 499: 0.425525    1.081243    3.516807    0.204549    0.087959    0.022050    0.688817    
#> 500: 0.425533    1.081237    3.516765    0.204598    0.087936    0.022060    0.688729    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.302229    0.953055    3.450155    0.392401    0.087684    0.016800    1.959092    
#> 002: 0.217778    1.009001    3.487947    0.372781    0.083300    0.019001    1.302396    
#> 003: 0.235067    1.021317    3.489583    0.354142    0.086239    0.018051    1.009780    
#> 004: 0.182695    1.070333    3.485633    0.336435    0.088408    0.017149    0.923194    
#> 005: 0.241499    1.076481    3.479875    0.319613    0.095936    0.016466    0.887816    
#> 006: 0.210777    1.083928    3.466499    0.303633    0.091139    0.015643    0.872644    
#> 007: 0.198130    1.094066    3.467530    0.288451    0.095001    0.017635    0.889429    
#> 008: 0.144458    1.102525    3.457190    0.274029    0.109067    0.021167    0.871643    
#> 009: 0.145261    1.078164    3.442738    0.260327    0.103613    0.022823    0.869399    
#> 010: 0.149262    1.100987    3.450157    0.247311    0.098433    0.021681    0.882502    
#> 011: 0.202118    1.105269    3.459393    0.234945    0.097809    0.020597    0.863965    
#> 012: 0.215912    1.107772    3.436369    0.223198    0.092919    0.019568    0.857587    
#> 013: 0.127488    1.124104    3.433961    0.212038    0.105850    0.020411    0.862294    
#> 014: 0.182885    1.116318    3.441480    0.201436    0.107189    0.020290    0.880273    
#> 015: 0.202626    1.104849    3.464806    0.191364    0.104755    0.023634    0.829575    
#> 016: 0.223495    1.102722    3.471202    0.181796    0.099517    0.035580    0.847688    
#> 017: 0.242604    1.100885    3.481671    0.172706    0.094542    0.034243    0.832157    
#> 018: 0.257803    1.104879    3.470689    0.164071    0.089815    0.037005    0.865734    
#> 019: 0.186943    1.080209    3.467056    0.184101    0.085324    0.036196    0.825679    
#> 020: 0.218485    1.080801    3.473289    0.188673    0.098288    0.034386    0.850172    
#> 021: 0.198924    1.063818    3.470232    0.179239    0.093374    0.032667    0.847411    
#> 022: 0.232651    1.064796    3.497196    0.177463    0.088705    0.037237    0.833309    
#> 023: 0.309229    1.079947    3.507518    0.168590    0.084270    0.035375    0.887736    
#> 024: 0.328046    1.081974    3.500262    0.160161    0.080057    0.034706    0.855709    
#> 025: 0.263342    1.052677    3.500768    0.152153    0.076054    0.040783    0.839193    
#> 026: 0.225751    1.078421    3.481168    0.174937    0.072251    0.038744    0.853788    
#> 027: 0.224912    1.101132    3.486195    0.166190    0.068638    0.038674    0.853634    
#> 028: 0.239977    1.078649    3.483822    0.157881    0.065207    0.041195    0.824135    
#> 029: 0.271098    1.094934    3.477531    0.149987    0.066856    0.039136    0.868422    
#> 030: 0.270011    1.107899    3.477448    0.142487    0.066093    0.037179    0.862640    
#> 031: 0.281014    1.080170    3.500152    0.135363    0.078325    0.035320    0.864643    
#> 032: 0.267591    1.062408    3.514580    0.128595    0.074409    0.034395    0.868208    
#> 033: 0.251296    1.084917    3.503866    0.138817    0.073298    0.040964    0.850661    
#> 034: 0.297865    1.096868    3.497877    0.141329    0.079482    0.038916    0.860499    
#> 035: 0.214373    1.076380    3.474830    0.134262    0.075508    0.036970    0.841054    
#> 036: 0.230705    1.087861    3.478616    0.127549    0.071733    0.039514    0.857397    
#> 037: 0.232886    1.089385    3.493644    0.121172    0.073356    0.043300    0.841080    
#> 038: 0.275470    1.082057    3.489182    0.133256    0.069688    0.041135    0.862561    
#> 039: 0.295668    1.084676    3.505605    0.132445    0.084748    0.040724    0.822941    
#> 040: 0.267228    1.059225    3.502303    0.125823    0.080511    0.039014    0.863739    
#> 041: 0.231070    1.052467    3.511442    0.119532    0.080828    0.045448    0.862780    
#> 042: 0.299033    1.047402    3.509922    0.114316    0.076787    0.043689    0.851972    
#> 043: 0.258467    1.073047    3.492158    0.113141    0.072948    0.041504    0.853216    
#> 044: 0.230689    1.079930    3.473154    0.107484    0.069300    0.039429    0.848779    
#> 045: 0.220141    1.114897    3.464810    0.102110    0.065835    0.037458    0.860182    
#> 046: 0.234142    1.104356    3.475646    0.128137    0.071877    0.035585    0.842330    
#> 047: 0.242080    1.092674    3.469694    0.121730    0.068283    0.033805    0.848632    
#> 048: 0.237260    1.079953    3.477461    0.146316    0.064869    0.032115    0.843273    
#> 049: 0.205813    1.066461    3.486175    0.139000    0.066854    0.031809    0.858949    
#> 050: 0.270924    1.042778    3.493011    0.132050    0.072009    0.030219    0.882855    
#> 051: 0.259438    1.075457    3.489973    0.125447    0.068408    0.032517    0.868460    
#> 052: 0.271130    1.080225    3.504655    0.119175    0.064988    0.032620    0.849936    
#> 053: 0.277078    1.070766    3.489846    0.133329    0.067861    0.032556    0.851016    
#> 054: 0.234229    1.060866    3.510271    0.134160    0.067195    0.043153    0.852169    
#> 055: 0.238564    1.057186    3.505154    0.127452    0.075023    0.040995    0.880428    
#> 056: 0.240717    1.068087    3.493354    0.121079    0.076142    0.038945    0.843815    
#> 057: 0.254924    1.074542    3.496433    0.134476    0.072335    0.046259    0.845474    
#> 058: 0.249070    1.075574    3.489389    0.127753    0.076885    0.043946    0.856853    
#> 059: 0.241978    1.025115    3.503922    0.121365    0.073041    0.041749    0.890416    
#> 060: 0.242869    1.024524    3.500340    0.146903    0.069389    0.043722    0.870153    
#> 061: 0.247655    1.044084    3.504752    0.174205    0.073800    0.046334    0.879959    
#> 062: 0.233421    1.080870    3.503578    0.165494    0.115183    0.044017    0.884039    
#> 063: 0.280149    1.051967    3.507631    0.157220    0.109424    0.042788    0.858740    
#> 064: 0.262336    1.048551    3.510086    0.149359    0.103952    0.040649    0.877078    
#> 065: 0.254336    1.033737    3.482394    0.141891    0.098755    0.038616    0.866437    
#> 066: 0.255120    1.077902    3.498101    0.134796    0.093817    0.041117    0.829633    
#> 067: 0.279090    1.070296    3.511652    0.128056    0.089126    0.046013    0.833610    
#> 068: 0.229455    1.073996    3.512125    0.121654    0.084670    0.045468    0.853746    
#> 069: 0.252630    1.082980    3.489245    0.115571    0.080436    0.046621    0.860673    
#> 070: 0.252431    1.067674    3.505383    0.109792    0.077631    0.044290    0.882080    
#> 071: 0.235229    1.101405    3.483294    0.104303    0.086781    0.042790    0.882802    
#> 072: 0.169350    1.070093    3.466860    0.102916    0.088672    0.046077    0.885501    
#> 073: 0.194703    1.078261    3.487685    0.097771    0.088133    0.046350    0.873010    
#> 074: 0.174216    1.087432    3.476925    0.092882    0.087978    0.044032    0.867713    
#> 075: 0.219118    1.070310    3.511888    0.098826    0.097420    0.041831    0.838076    
#> 076: 0.197314    1.097669    3.482010    0.095057    0.094538    0.039739    0.855033    
#> 077: 0.244435    1.064227    3.488289    0.098703    0.093009    0.037752    0.870070    
#> 078: 0.254620    1.075348    3.496812    0.093767    0.088358    0.037455    0.852086    
#> 079: 0.281249    1.089951    3.509705    0.092332    0.083941    0.045212    0.842768    
#> 080: 0.284516    1.079381    3.511180    0.087715    0.087821    0.049988    0.853054    
#> 081: 0.270865    1.061767    3.522555    0.083329    0.083430    0.048832    0.855037    
#> 082: 0.262199    1.060893    3.508975    0.079163    0.079258    0.046391    0.874685    
#> 083: 0.253254    1.086166    3.505688    0.075205    0.075295    0.044071    0.870316    
#> 084: 0.256602    1.058839    3.516442    0.071445    0.071530    0.043097    0.870907    
#> 085: 0.223069    1.066052    3.507099    0.087313    0.067954    0.041363    0.889648    
#> 086: 0.213636    1.030645    3.496842    0.099083    0.064556    0.039295    0.868694    
#> 087: 0.204102    1.063248    3.473781    0.099743    0.061328    0.045498    0.893069    
#> 088: 0.192353    1.069400    3.483035    0.150607    0.068842    0.043223    0.876660    
#> 089: 0.200894    1.104740    3.459360    0.143076    0.086704    0.041062    0.840006    
#> 090: 0.151729    1.105634    3.466420    0.135922    0.090076    0.039008    0.836505    
#> 091: 0.145359    1.075695    3.446731    0.129126    0.085573    0.037058    0.846453    
#> 092: 0.134715    1.106176    3.441479    0.122670    0.085687    0.035205    0.857408    
#> 093: 0.149011    1.078165    3.456809    0.116536    0.087170    0.038505    0.875152    
#> 094: 0.178249    1.093221    3.460324    0.110710    0.086917    0.036580    0.870519    
#> 095: 0.166719    1.110448    3.468220    0.137357    0.082571    0.034751    0.868297    
#> 096: 0.178104    1.105081    3.476887    0.130489    0.078442    0.044036    0.851772    
#> 097: 0.227448    1.109882    3.482084    0.123964    0.074520    0.041835    0.838295    
#> 098: 0.220720    1.109049    3.499419    0.117766    0.070794    0.051155    0.854568    
#> 099: 0.219552    1.071113    3.476108    0.111878    0.067254    0.048598    0.847784    
#> 100: 0.231585    1.067952    3.489746    0.106284    0.063892    0.050754    0.846232    
#> 101: 0.200566    1.051148    3.465864    0.100970    0.060697    0.048217    0.874709    
#> 102: 0.186215    1.032402    3.458378    0.095921    0.060407    0.045806    0.866972    
#> 103: 0.253960    1.050243    3.504058    0.091125    0.057997    0.048301    0.838429    
#> 104: 0.310459    1.048579    3.529480    0.086569    0.060029    0.048706    0.862589    
#> 105: 0.294796    1.038226    3.539499    0.099619    0.068140    0.046270    0.864586    
#> 106: 0.296593    1.053769    3.523056    0.111277    0.071078    0.043957    0.849636    
#> 107: 0.301370    1.052243    3.516911    0.111133    0.067524    0.045770    0.850003    
#> 108: 0.261197    1.046900    3.523179    0.105576    0.064148    0.043481    0.880491    
#> 109: 0.246738    1.049633    3.513433    0.100298    0.060941    0.043326    0.865359    
#> 110: 0.204062    1.071097    3.479039    0.095283    0.067386    0.041160    0.849925    
#> 111: 0.191640    1.082721    3.488624    0.101114    0.064016    0.040087    0.845899    
#> 112: 0.191333    1.059431    3.471887    0.096059    0.073480    0.042821    0.853415    
#> 113: 0.170238    1.096026    3.469849    0.091256    0.080003    0.040680    0.858150    
#> 114: 0.178322    1.110887    3.473368    0.086693    0.076003    0.051637    0.869481    
#> 115: 0.205292    1.080472    3.469428    0.082358    0.072203    0.049055    0.896038    
#> 116: 0.220679    1.106563    3.469889    0.088188    0.079068    0.050544    0.901252    
#> 117: 0.207772    1.113211    3.466491    0.104839    0.075115    0.048017    0.865353    
#> 118: 0.219835    1.105577    3.479310    0.119573    0.071359    0.045616    0.853074    
#> 119: 0.244510    1.073019    3.492067    0.113594    0.067791    0.044614    0.864083    
#> 120: 0.225673    1.061068    3.493428    0.107914    0.064402    0.049896    0.841524    
#> 121: 0.226874    1.102285    3.494438    0.109528    0.061182    0.050265    0.854247    
#> 122: 0.272929    1.065116    3.502546    0.147106    0.059781    0.047971    0.864782    
#> 123: 0.277587    1.086359    3.498723    0.139750    0.060220    0.046165    0.857970    
#> 124: 0.285015    1.084060    3.520223    0.132763    0.057209    0.050447    0.856079    
#> 125: 0.303717    1.056893    3.506784    0.126125    0.054348    0.047925    0.861275    
#> 126: 0.238867    1.079918    3.488756    0.135936    0.052143    0.047177    0.846302    
#> 127: 0.290352    1.059279    3.489132    0.132465    0.050308    0.048565    0.870986    
#> 128: 0.270384    1.042717    3.515644    0.145347    0.069154    0.046367    0.853803    
#> 129: 0.264620    1.073164    3.505967    0.154724    0.070254    0.044049    0.868754    
#> 130: 0.285798    1.079652    3.509364    0.159404    0.074234    0.041847    0.835813    
#> 131: 0.251192    1.063479    3.489650    0.151434    0.071862    0.039754    0.859023    
#> 132: 0.209471    1.080970    3.466476    0.143862    0.075644    0.037767    0.870678    
#> 133: 0.245011    1.069764    3.493562    0.136669    0.102764    0.041120    0.885149    
#> 134: 0.275752    1.046285    3.509825    0.129836    0.097626    0.042766    0.874156    
#> 135: 0.226220    1.040875    3.512505    0.123344    0.112899    0.040628    0.871030    
#> 136: 0.256790    1.035984    3.510356    0.117177    0.107254    0.039660    0.861755    
#> 137: 0.256385    1.050028    3.511509    0.111318    0.101891    0.037677    0.863739    
#> 138: 0.265772    1.045602    3.517358    0.105752    0.097374    0.035793    0.847717    
#> 139: 0.289317    1.062930    3.530633    0.100464    0.092505    0.040657    0.859805    
#> 140: 0.297638    1.069154    3.521993    0.109715    0.087880    0.041437    0.859396    
#> 141: 0.280752    1.047141    3.527132    0.104229    0.090882    0.039559    0.841104    
#> 142: 0.293564    1.030602    3.524612    0.111980    0.086338    0.038522    0.880126    
#> 143: 0.268389    1.038727    3.514460    0.128216    0.082021    0.043443    0.859678    
#> 144: 0.297986    1.049916    3.515413    0.144828    0.077920    0.041271    0.840699    
#> 145: 0.260440    1.084566    3.485987    0.181185    0.075645    0.039207    0.837550    
#> 146: 0.239990    1.088747    3.499408    0.172125    0.071862    0.037247    0.847976    
#> 147: 0.206790    1.056217    3.483973    0.163519    0.068269    0.046157    0.828392    
#> 148: 0.204603    1.092237    3.487624    0.158993    0.071806    0.045280    0.848143    
#> 149: 0.204111    1.080631    3.465669    0.156130    0.083746    0.043016    0.846287    
#> 150: 0.267921    1.080026    3.475431    0.176947    0.097941    0.041790    0.843798    
#> 151: 0.202333    1.114217    3.473026    0.168100    0.093044    0.039700    0.851206    
#> 152: 0.186533    1.096133    3.471311    0.139427    0.064585    0.041488    0.831407    
#> 153: 0.199149    1.101933    3.488797    0.136295    0.067190    0.043451    0.855202    
#> 154: 0.242175    1.106412    3.485976    0.126323    0.055362    0.044027    0.857326    
#> 155: 0.208475    1.100404    3.479028    0.112759    0.077679    0.036995    0.823964    
#> 156: 0.219321    1.114539    3.483511    0.134084    0.090913    0.035590    0.855740    
#> 157: 0.261691    1.082510    3.513853    0.098502    0.089823    0.037124    0.864656    
#> 158: 0.278620    1.099610    3.498748    0.102596    0.078436    0.039999    0.858926    
#> 159: 0.246941    1.096429    3.508248    0.096492    0.084228    0.036541    0.884385    
#> 160: 0.313865    1.043037    3.528364    0.099098    0.071016    0.043228    0.867719    
#> 161: 0.273724    1.045174    3.521568    0.080872    0.073314    0.041999    0.872694    
#> 162: 0.221541    1.075515    3.486698    0.100044    0.089217    0.029725    0.859879    
#> 163: 0.241790    1.064543    3.482557    0.114870    0.094790    0.029266    0.838254    
#> 164: 0.271726    1.071344    3.486787    0.114934    0.072066    0.033867    0.842931    
#> 165: 0.304313    1.053255    3.514068    0.121461    0.080880    0.037074    0.834856    
#> 166: 0.347187    1.094539    3.529202    0.111535    0.082362    0.043303    0.858957    
#> 167: 0.327019    1.096073    3.526949    0.119968    0.083685    0.048225    0.863091    
#> 168: 0.303715    1.084215    3.515164    0.085690    0.067911    0.044283    0.856425    
#> 169: 0.241294    1.130937    3.482887    0.094457    0.073270    0.045982    0.880642    
#> 170: 0.234748    1.097055    3.485393    0.088546    0.067096    0.040857    0.868682    
#> 171: 0.184567    1.103085    3.467775    0.103056    0.069684    0.044454    0.847545    
#> 172: 0.205938    1.128965    3.481192    0.121088    0.076007    0.035547    0.833430    
#> 173: 0.214353    1.123381    3.474590    0.114154    0.074132    0.039585    0.830725    
#> 174: 0.215958    1.098640    3.488288    0.104657    0.063923    0.047314    0.850071    
#> 175: 0.239376    1.101615    3.483514    0.119000    0.067633    0.041787    0.844516    
#> 176: 0.246144    1.089124    3.494907    0.112951    0.074575    0.037922    0.855496    
#> 177: 0.262522    1.076326    3.505369    0.087928    0.078239    0.042062    0.864963    
#> 178: 0.257579    1.067077    3.500470    0.087492    0.071526    0.038425    0.853065    
#> 179: 0.256321    1.064457    3.499702    0.103946    0.073075    0.036361    0.858943    
#> 180: 0.269229    1.067940    3.504805    0.098171    0.077848    0.040476    0.845647    
#> 181: 0.223305    1.038131    3.473620    0.112874    0.072536    0.038257    0.839490    
#> 182: 0.173678    1.063671    3.477303    0.113394    0.063810    0.043117    0.861545    
#> 183: 0.181589    1.099802    3.468524    0.129465    0.068794    0.034846    0.839261    
#> 184: 0.178007    1.082799    3.483041    0.117483    0.073447    0.032661    0.843347    
#> 185: 0.174694    1.098498    3.468329    0.112847    0.079718    0.036533    0.853358    
#> 186: 0.175690    1.113193    3.465640    0.141583    0.083389    0.039008    0.843583    
#> 187: 0.215978    1.098432    3.470662    0.123873    0.086713    0.032855    0.850598    
#> 188: 0.193887    1.110086    3.472658    0.136079    0.087691    0.038966    0.864227    
#> 189: 0.243805    1.110521    3.493421    0.109073    0.097968    0.035960    0.856721    
#> 190: 0.220041    1.090809    3.491266    0.122709    0.066083    0.044893    0.852336    
#> 191: 0.211984    1.101015    3.470978    0.130341    0.075599    0.032631    0.854254    
#> 192: 0.183803    1.083084    3.479683    0.083207    0.074006    0.033290    0.840080    
#> 193: 0.224207    1.101854    3.490510    0.082366    0.079512    0.031452    0.838441    
#> 194: 0.223148    1.081491    3.470984    0.094039    0.077248    0.029324    0.850480    
#> 195: 0.176431    1.097119    3.463922    0.095806    0.067202    0.036620    0.839577    
#> 196: 0.182147    1.081508    3.487600    0.101749    0.061324    0.038788    0.879818    
#> 197: 0.192212    1.095091    3.509100    0.116093    0.069532    0.040422    0.878639    
#> 198: 0.273650    1.064863    3.504068    0.128232    0.060235    0.045464    0.844085    
#> 199: 0.252584    1.067563    3.492126    0.126596    0.071925    0.038073    0.848045    
#> 200: 0.255483    1.061429    3.511647    0.099507    0.092655    0.039309    0.865476    
#> 201: 0.262101    1.057880    3.516736    0.091543    0.084541    0.042260    0.860006    
#> 202: 0.265447    1.062370    3.509786    0.090471    0.076124    0.041538    0.859063    
#> 203: 0.266801    1.064354    3.504009    0.096320    0.074438    0.039959    0.857354    
#> 204: 0.274974    1.053536    3.508130    0.102623    0.074605    0.040163    0.860216    
#> 205: 0.273254    1.058784    3.507658    0.099525    0.072508    0.040120    0.866945    
#> 206: 0.268440    1.063817    3.507227    0.097975    0.074611    0.039786    0.869004    
#> 207: 0.266061    1.063512    3.504834    0.096498    0.076303    0.038910    0.871473    
#> 208: 0.267298    1.061704    3.506638    0.095825    0.076860    0.038087    0.870192    
#> 209: 0.270286    1.061032    3.505354    0.094888    0.079082    0.037128    0.869503    
#> 210: 0.274374    1.059972    3.506384    0.094430    0.080112    0.036482    0.867726    
#> 211: 0.272575    1.060754    3.507176    0.094272    0.081462    0.036254    0.866418    
#> 212: 0.272383    1.062094    3.507052    0.094556    0.082488    0.035824    0.866311    
#> 213: 0.272635    1.060042    3.507469    0.096552    0.082150    0.035880    0.865277    
#> 214: 0.273909    1.060166    3.507804    0.096572    0.081585    0.035800    0.864839    
#> 215: 0.273507    1.060428    3.507578    0.096456    0.081434    0.035348    0.864955    
#> 216: 0.274267    1.059326    3.507079    0.098212    0.081612    0.035121    0.865715    
#> 217: 0.272116    1.060469    3.506563    0.099782    0.081788    0.034708    0.864062    
#> 218: 0.270887    1.062188    3.505531    0.099656    0.080908    0.034318    0.863237    
#> 219: 0.269294    1.062115    3.504113    0.099098    0.080501    0.034257    0.862054    
#> 220: 0.267088    1.062558    3.503708    0.099147    0.079220    0.034930    0.861886    
#> 221: 0.266293    1.062450    3.503285    0.098140    0.078011    0.035210    0.861379    
#> 222: 0.265665    1.064128    3.502459    0.097277    0.078110    0.035366    0.861211    
#> 223: 0.267714    1.064581    3.502596    0.096283    0.078077    0.035298    0.860848    
#> 224: 0.269441    1.065365    3.503062    0.096553    0.077668    0.035420    0.860850    
#> 225: 0.270231    1.063998    3.504043    0.096760    0.076966    0.035642    0.860965    
#> 226: 0.270421    1.063160    3.503778    0.096916    0.077028    0.035554    0.860940    
#> 227: 0.268998    1.063347    3.503829    0.096892    0.077036    0.035830    0.861645    
#> 228: 0.266603    1.064475    3.503030    0.097147    0.077815    0.036038    0.861334    
#> 229: 0.265252    1.064941    3.502680    0.096952    0.077830    0.036187    0.860660    
#> 230: 0.264491    1.063905    3.502361    0.097227    0.077750    0.035815    0.860150    
#> 231: 0.264591    1.063921    3.502361    0.097155    0.078058    0.035828    0.859595    
#> 232: 0.263038    1.064069    3.502115    0.098294    0.078285    0.035970    0.859278    
#> 233: 0.262380    1.063759    3.501978    0.098682    0.078242    0.036008    0.858994    
#> 234: 0.261444    1.064099    3.501778    0.098469    0.077914    0.036393    0.858960    
#> 235: 0.260923    1.064182    3.501377    0.098563    0.077349    0.036403    0.858561    
#> 236: 0.260322    1.064823    3.501056    0.098743    0.077607    0.036369    0.858768    
#> 237: 0.260573    1.065221    3.500678    0.099655    0.077898    0.036157    0.859265    
#> 238: 0.260843    1.065206    3.500585    0.100300    0.078238    0.035981    0.859768    
#> 239: 0.260546    1.065868    3.500106    0.100410    0.078532    0.035829    0.859345    
#> 240: 0.260239    1.066121    3.499959    0.100935    0.078675    0.035807    0.858783    
#> 241: 0.259699    1.065655    3.499743    0.101498    0.078755    0.035703    0.859003    
#> 242: 0.258105    1.065131    3.499061    0.102036    0.078704    0.035590    0.860100    
#> 243: 0.256413    1.065784    3.498488    0.102745    0.078532    0.035614    0.860311    
#> 244: 0.255166    1.066010    3.498304    0.102633    0.078531    0.035588    0.860920    
#> 245: 0.254982    1.066162    3.498027    0.102878    0.078741    0.035562    0.860946    
#> 246: 0.254382    1.066219    3.497959    0.102838    0.078639    0.035592    0.861240    
#> 247: 0.254419    1.066001    3.498257    0.103132    0.078528    0.035650    0.861312    
#> 248: 0.254969    1.066369    3.498176    0.103151    0.078462    0.035570    0.861067    
#> 249: 0.254839    1.066341    3.498116    0.103110    0.078857    0.035537    0.861299    
#> 250: 0.255504    1.066476    3.498452    0.103375    0.078891    0.035555    0.861395    
#> 251: 0.256420    1.067166    3.498809    0.103706    0.079183    0.035529    0.861444    
#> 252: 0.256872    1.067995    3.499269    0.103827    0.079591    0.035492    0.861197    
#> 253: 0.256653    1.068374    3.499423    0.103908    0.079835    0.035435    0.860929    
#> 254: 0.256720    1.068966    3.499658    0.103634    0.080256    0.035368    0.860731    
#> 255: 0.256524    1.069610    3.499680    0.103570    0.080338    0.035433    0.860853    
#> 256: 0.257175    1.069671    3.499621    0.103963    0.080234    0.035435    0.860596    
#> 257: 0.256572    1.069321    3.499580    0.104371    0.080190    0.035340    0.861201    
#> 258: 0.256266    1.068943    3.499481    0.104981    0.080083    0.035450    0.860743    
#> 259: 0.255845    1.069204    3.499123    0.105231    0.080123    0.035629    0.860778    
#> 260: 0.255242    1.069467    3.499086    0.105276    0.080215    0.035671    0.860418    
#> 261: 0.255098    1.069378    3.499281    0.105369    0.080176    0.035719    0.860322    
#> 262: 0.255518    1.069537    3.499243    0.106069    0.080291    0.035670    0.859949    
#> 263: 0.255277    1.069946    3.499119    0.106270    0.080306    0.035726    0.859679    
#> 264: 0.255633    1.069974    3.499240    0.106184    0.080254    0.035783    0.859817    
#> 265: 0.256108    1.069829    3.499346    0.105918    0.080511    0.035788    0.859951    
#> 266: 0.256521    1.070194    3.499423    0.105754    0.080898    0.035791    0.860191    
#> 267: 0.256402    1.070228    3.499596    0.105666    0.081053    0.035733    0.860357    
#> 268: 0.256333    1.070118    3.499400    0.105689    0.080920    0.035658    0.860265    
#> 269: 0.256989    1.070175    3.499266    0.105868    0.080895    0.035640    0.860414    
#> 270: 0.257364    1.070251    3.499078    0.105845    0.080789    0.035638    0.860151    
#> 271: 0.257589    1.070026    3.499131    0.105678    0.080572    0.035721    0.860218    
#> 272: 0.257518    1.069862    3.498939    0.105775    0.080598    0.035749    0.860616    
#> 273: 0.257276    1.069908    3.499029    0.105607    0.080713    0.035762    0.860551    
#> 274: 0.256686    1.070105    3.499111    0.105330    0.080602    0.035731    0.860332    
#> 275: 0.256227    1.070407    3.498885    0.105270    0.080363    0.035778    0.860108    
#> 276: 0.256012    1.070529    3.499014    0.105398    0.080297    0.035807    0.859949    
#> 277: 0.255531    1.070763    3.499182    0.105249    0.080243    0.035832    0.859741    
#> 278: 0.255318    1.070791    3.499225    0.104803    0.080315    0.035803    0.859644    
#> 279: 0.255182    1.070635    3.499370    0.104548    0.080687    0.035805    0.859772    
#> 280: 0.255438    1.070733    3.499543    0.104305    0.080698    0.035734    0.859670    
#> 281: 0.254930    1.070995    3.499517    0.104430    0.080728    0.035738    0.859344    
#> 282: 0.254685    1.071317    3.499444    0.104915    0.080892    0.035653    0.859391    
#> 283: 0.255029    1.071501    3.499485    0.105242    0.080909    0.035555    0.859555    
#> 284: 0.254819    1.071462    3.499462    0.105336    0.080722    0.035437    0.859555    
#> 285: 0.255022    1.071484    3.499304    0.105509    0.080741    0.035327    0.859494    
#> 286: 0.254970    1.071688    3.499201    0.105486    0.080899    0.035319    0.859313    
#> 287: 0.254819    1.071766    3.499094    0.105435    0.080941    0.035350    0.859122    
#> 288: 0.255037    1.071728    3.499138    0.105138    0.081018    0.035367    0.859204    
#> 289: 0.254964    1.071526    3.499086    0.105002    0.081005    0.035358    0.859317    
#> 290: 0.254822    1.071299    3.499059    0.105098    0.081039    0.035348    0.859426    
#> 291: 0.255021    1.071483    3.499136    0.105368    0.080977    0.035354    0.859289    
#> 292: 0.255002    1.071639    3.499075    0.105516    0.080834    0.035350    0.859104    
#> 293: 0.254875    1.071563    3.498937    0.105476    0.080684    0.035327    0.858788    
#> 294: 0.254458    1.071598    3.498771    0.105619    0.080576    0.035274    0.858556    
#> 295: 0.254466    1.071205    3.498882    0.105538    0.080413    0.035337    0.858235    
#> 296: 0.254679    1.070953    3.498996    0.105427    0.080373    0.035394    0.858257    
#> 297: 0.255063    1.070867    3.499189    0.105535    0.080340    0.035337    0.858310    
#> 298: 0.255398    1.070577    3.499280    0.105391    0.080223    0.035270    0.858376    
#> 299: 0.255588    1.070499    3.499342    0.105150    0.080171    0.035219    0.858366    
#> 300: 0.255877    1.070307    3.499471    0.105173    0.080173    0.035147    0.858228    
#> 301: 0.256228    1.070198    3.499463    0.104774    0.080332    0.035098    0.858192    
#> 302: 0.256552    1.070230    3.499478    0.104538    0.080418    0.035076    0.858151    
#> 303: 0.256463    1.070297    3.499465    0.104444    0.080518    0.035103    0.857902    
#> 304: 0.256678    1.070475    3.499374    0.104411    0.080599    0.035121    0.857846    
#> 305: 0.256357    1.070333    3.499245    0.104481    0.080691    0.035118    0.857616    
#> 306: 0.255810    1.070183    3.499003    0.104461    0.080713    0.035113    0.857618    
#> 307: 0.255535    1.070203    3.498866    0.104628    0.080919    0.035148    0.857590    
#> 308: 0.255397    1.070066    3.498785    0.104713    0.081107    0.035116    0.857734    
#> 309: 0.255495    1.069788    3.498782    0.104630    0.081164    0.035156    0.857902    
#> 310: 0.255556    1.069747    3.498588    0.104461    0.081219    0.035166    0.858115    
#> 311: 0.255402    1.069991    3.498466    0.104480    0.081185    0.035228    0.858155    
#> 312: 0.254939    1.070085    3.498226    0.104537    0.080975    0.035250    0.858162    
#> 313: 0.254421    1.069766    3.497948    0.104532    0.080744    0.035269    0.858487    
#> 314: 0.253682    1.070041    3.497661    0.104416    0.080595    0.035311    0.858524    
#> 315: 0.253309    1.070306    3.497507    0.104273    0.080528    0.035348    0.858463    
#> 316: 0.253020    1.070570    3.497407    0.104204    0.080510    0.035391    0.858351    
#> 317: 0.253002    1.070525    3.497426    0.104172    0.080398    0.035369    0.858315    
#> 318: 0.253206    1.070573    3.497400    0.103955    0.080349    0.035340    0.858157    
#> 319: 0.253240    1.070426    3.497396    0.103690    0.080226    0.035337    0.858086    
#> 320: 0.253039    1.070553    3.497279    0.103713    0.080128    0.035371    0.858156    
#> 321: 0.252734    1.070683    3.497163    0.103891    0.080102    0.035374    0.858294    
#> 322: 0.252497    1.070831    3.497032    0.103914    0.080009    0.035450    0.858166    
#> 323: 0.251726    1.070879    3.496817    0.104084    0.079926    0.035502    0.858130    
#> 324: 0.251663    1.071031    3.496765    0.104148    0.080026    0.035494    0.858046    
#> 325: 0.251435    1.071290    3.496673    0.104011    0.080123    0.035493    0.858165    
#> 326: 0.251330    1.071308    3.496523    0.103876    0.080176    0.035512    0.858067    
#> 327: 0.251215    1.071307    3.496635    0.103816    0.080411    0.035440    0.858047    
#> 328: 0.251104    1.071445    3.496583    0.103703    0.080398    0.035383    0.857914    
#> 329: 0.251087    1.071535    3.496606    0.103511    0.080414    0.035334    0.857827    
#> 330: 0.251026    1.071379    3.496722    0.103431    0.080294    0.035390    0.857906    
#> 331: 0.251070    1.071684    3.496694    0.103382    0.080328    0.035499    0.857895    
#> 332: 0.250747    1.071832    3.496687    0.103372    0.080261    0.035596    0.857914    
#> 333: 0.250562    1.071985    3.496570    0.103355    0.080282    0.035584    0.857772    
#> 334: 0.250396    1.072115    3.496438    0.103399    0.080319    0.035547    0.857599    
#> 335: 0.250214    1.072129    3.496390    0.103368    0.080215    0.035553    0.857520    
#> 336: 0.250043    1.072221    3.496398    0.103375    0.080220    0.035560    0.857589    
#> 337: 0.250067    1.072540    3.496314    0.103332    0.080209    0.035536    0.857757    
#> 338: 0.250234    1.072644    3.496378    0.103289    0.080272    0.035491    0.857760    
#> 339: 0.249998    1.072914    3.496219    0.103307    0.080483    0.035407    0.857776    
#> 340: 0.249810    1.072914    3.496138    0.103389    0.080637    0.035343    0.857728    
#> 341: 0.249794    1.073074    3.496126    0.103553    0.080750    0.035307    0.857725    
#> 342: 0.249529    1.072850    3.496064    0.103668    0.080753    0.035300    0.857695    
#> 343: 0.249205    1.072863    3.496008    0.103806    0.080789    0.035270    0.857602    
#> 344: 0.249263    1.072952    3.496000    0.103897    0.080853    0.035224    0.857679    
#> 345: 0.249463    1.073254    3.495973    0.103974    0.080837    0.035209    0.857689    
#> 346: 0.249556    1.073597    3.495846    0.104018    0.080908    0.035167    0.857468    
#> 347: 0.249584    1.073640    3.495803    0.104162    0.080939    0.035139    0.857579    
#> 348: 0.249457    1.073837    3.495692    0.104328    0.081083    0.035142    0.857634    
#> 349: 0.249438    1.073830    3.495636    0.104411    0.081014    0.035159    0.857551    
#> 350: 0.249167    1.073934    3.495538    0.104268    0.081029    0.035162    0.857573    
#> 351: 0.248843    1.074239    3.495365    0.104162    0.080979    0.035135    0.857565    
#> 352: 0.248329    1.074400    3.495328    0.104243    0.081013    0.035131    0.857718    
#> 353: 0.247946    1.074555    3.495162    0.104509    0.080887    0.035179    0.857789    
#> 354: 0.247789    1.074711    3.495023    0.104848    0.080771    0.035153    0.857867    
#> 355: 0.248083    1.074479    3.494978    0.104917    0.080787    0.035152    0.857804    
#> 356: 0.248172    1.074379    3.494972    0.104994    0.080807    0.035141    0.857858    
#> 357: 0.248393    1.074580    3.494940    0.105105    0.080803    0.035152    0.857720    
#> 358: 0.248504    1.074705    3.495005    0.105084    0.080804    0.035141    0.857624    
#> 359: 0.248503    1.074839    3.494937    0.105068    0.080750    0.035095    0.857603    
#> 360: 0.248365    1.074947    3.494680    0.104979    0.080716    0.035069    0.857573    
#> 361: 0.248146    1.075026    3.494644    0.104880    0.080736    0.035050    0.857541    
#> 362: 0.248104    1.075100    3.494610    0.104907    0.080748    0.035078    0.857496    
#> 363: 0.248070    1.075103    3.494504    0.105001    0.080764    0.035064    0.857526    
#> 364: 0.248077    1.075204    3.494434    0.105261    0.080864    0.035049    0.857656    
#> 365: 0.247904    1.075167    3.494401    0.105622    0.080872    0.035126    0.857839    
#> 366: 0.247666    1.075357    3.494122    0.105937    0.080911    0.035177    0.857919    
#> 367: 0.247435    1.075519    3.494057    0.105928    0.080920    0.035201    0.857986    
#> 368: 0.247655    1.075611    3.494062    0.105853    0.080875    0.035243    0.857926    
#> 369: 0.247711    1.075611    3.494016    0.105876    0.080848    0.035224    0.857836    
#> 370: 0.247516    1.075687    3.493973    0.106139    0.080879    0.035242    0.857798    
#> 371: 0.247297    1.075864    3.493766    0.106249    0.081027    0.035188    0.857690    
#> 372: 0.247178    1.076056    3.493565    0.106240    0.081069    0.035165    0.857693    
#> 373: 0.247041    1.076290    3.493483    0.106228    0.081036    0.035160    0.857862    
#> 374: 0.247169    1.076250    3.493471    0.106000    0.080943    0.035209    0.857874    
#> 375: 0.247043    1.076258    3.493528    0.105773    0.080935    0.035251    0.857733    
#> 376: 0.246978    1.076397    3.493560    0.105600    0.080993    0.035267    0.857685    
#> 377: 0.246915    1.076465    3.493548    0.105479    0.081032    0.035288    0.857638    
#> 378: 0.246769    1.076462    3.493497    0.105465    0.080909    0.035305    0.857665    
#> 379: 0.246662    1.076267    3.493534    0.105573    0.080895    0.035264    0.857648    
#> 380: 0.246425    1.076196    3.493533    0.105551    0.080736    0.035263    0.857623    
#> 381: 0.246354    1.076042    3.493583    0.105504    0.080658    0.035304    0.857648    
#> 382: 0.246381    1.075903    3.493602    0.105512    0.080509    0.035292    0.857688    
#> 383: 0.246540    1.075649    3.493653    0.105665    0.080411    0.035292    0.857606    
#> 384: 0.246600    1.075590    3.493686    0.105844    0.080378    0.035318    0.857512    
#> 385: 0.246760    1.075524    3.493720    0.105965    0.080284    0.035352    0.857444    
#> 386: 0.247064    1.075691    3.493847    0.105974    0.080167    0.035392    0.857557    
#> 387: 0.247138    1.075767    3.493965    0.106049    0.080065    0.035414    0.857444    
#> 388: 0.247201    1.075787    3.494060    0.106178    0.079954    0.035461    0.857350    
#> 389: 0.247221    1.075673    3.494080    0.106276    0.079938    0.035501    0.857460    
#> 390: 0.247257    1.075656    3.494038    0.106459    0.079925    0.035534    0.857468    
#> 391: 0.247373    1.075592    3.494055    0.106513    0.079858    0.035538    0.857391    
#> 392: 0.247489    1.075629    3.494102    0.106524    0.079801    0.035543    0.857338    
#> 393: 0.247469    1.075535    3.494050    0.106579    0.079765    0.035528    0.857280    
#> 394: 0.247403    1.075692    3.493975    0.106524    0.079709    0.035510    0.857362    
#> 395: 0.247456    1.075875    3.493940    0.106460    0.079653    0.035504    0.857382    
#> 396: 0.247540    1.075961    3.493986    0.106457    0.079611    0.035518    0.857333    
#> 397: 0.247658    1.075874    3.494057    0.106457    0.079560    0.035553    0.857287    
#> 398: 0.247927    1.075732    3.494280    0.106444    0.079506    0.035598    0.857322    
#> 399: 0.248176    1.075674    3.494443    0.106438    0.079455    0.035606    0.857204    
#> 400: 0.248564    1.075680    3.494545    0.106499    0.079518    0.035596    0.857154    
#> 401: 0.248724    1.075701    3.494576    0.106526    0.079600    0.035573    0.857177    
#> 402: 0.248836    1.075854    3.494624    0.106625    0.079561    0.035564    0.857211    
#> 403: 0.248936    1.075858    3.494663    0.106537    0.079625    0.035577    0.857201    
#> 404: 0.249024    1.075873    3.494594    0.106468    0.079546    0.035577    0.857128    
#> 405: 0.248959    1.075829    3.494615    0.106460    0.079501    0.035566    0.857177    
#> 406: 0.248971    1.075835    3.494658    0.106355    0.079533    0.035553    0.857285    
#> 407: 0.249128    1.075926    3.494672    0.106292    0.079595    0.035539    0.857284    
#> 408: 0.249220    1.076034    3.494690    0.106250    0.079726    0.035527    0.857234    
#> 409: 0.249160    1.075982    3.494672    0.106268    0.079718    0.035519    0.857174    
#> 410: 0.249078    1.076059    3.494558    0.106234    0.079679    0.035493    0.857238    
#> 411: 0.249207    1.075888    3.494536    0.106344    0.079601    0.035482    0.857388    
#> 412: 0.249204    1.075910    3.494481    0.106229    0.079567    0.035468    0.857430    
#> 413: 0.249083    1.076038    3.494417    0.106216    0.079557    0.035454    0.857567    
#> 414: 0.248887    1.076062    3.494383    0.106172    0.079524    0.035417    0.857605    
#> 415: 0.248869    1.075970    3.494343    0.106246    0.079468    0.035413    0.857587    
#> 416: 0.248957    1.076035    3.494342    0.106364    0.079460    0.035442    0.857457    
#> 417: 0.248959    1.075958    3.494367    0.106585    0.079481    0.035443    0.857466    
#> 418: 0.248770    1.075987    3.494366    0.106715    0.079538    0.035443    0.857489    
#> 419: 0.248801    1.076166    3.494362    0.106786    0.079671    0.035411    0.857493    
#> 420: 0.248871    1.076258    3.494321    0.106818    0.079732    0.035363    0.857466    
#> 421: 0.248875    1.076288    3.494320    0.106791    0.079682    0.035328    0.857417    
#> 422: 0.248880    1.076204    3.494309    0.106900    0.079663    0.035300    0.857400    
#> 423: 0.248901    1.076186    3.494292    0.106895    0.079595    0.035305    0.857342    
#> 424: 0.248859    1.076279    3.494203    0.106866    0.079580    0.035263    0.857296    
#> 425: 0.248983    1.076306    3.494165    0.106921    0.079554    0.035232    0.857452    
#> 426: 0.248923    1.076523    3.494098    0.106950    0.079662    0.035220    0.857423    
#> 427: 0.248845    1.076643    3.494054    0.106928    0.079666    0.035182    0.857390    
#> 428: 0.248637    1.076704    3.494073    0.106833    0.079661    0.035218    0.857455    
#> 429: 0.248568    1.076757    3.494135    0.106819    0.079691    0.035242    0.857456    
#> 430: 0.248492    1.076727    3.494103    0.106900    0.079674    0.035236    0.857390    
#> 431: 0.248259    1.076749    3.493937    0.107021    0.079707    0.035201    0.857354    
#> 432: 0.248057    1.076843    3.493855    0.107089    0.079730    0.035175    0.857328    
#> 433: 0.247916    1.076954    3.493823    0.107176    0.079694    0.035184    0.857333    
#> 434: 0.247691    1.076914    3.493751    0.107276    0.079686    0.035180    0.857279    
#> 435: 0.247601    1.076942    3.493693    0.107336    0.079621    0.035195    0.857255    
#> 436: 0.247450    1.076957    3.493699    0.107425    0.079673    0.035187    0.857193    
#> 437: 0.247343    1.076950    3.493657    0.107604    0.079655    0.035154    0.857192    
#> 438: 0.247292    1.077154    3.493607    0.107637    0.079654    0.035137    0.857197    
#> 439: 0.247250    1.077293    3.493544    0.107628    0.079671    0.035114    0.857154    
#> 440: 0.247109    1.077416    3.493526    0.107578    0.079619    0.035125    0.857031    
#> 441: 0.247071    1.077445    3.493529    0.107476    0.079641    0.035120    0.856961    
#> 442: 0.246882    1.077523    3.493500    0.107493    0.079675    0.035114    0.856837    
#> 443: 0.246758    1.077635    3.493412    0.107526    0.079703    0.035093    0.856764    
#> 444: 0.246613    1.077719    3.493317    0.107566    0.079690    0.035075    0.856726    
#> 445: 0.246573    1.077781    3.493271    0.107696    0.079684    0.035056    0.856741    
#> 446: 0.246405    1.077889    3.493190    0.107677    0.079695    0.035048    0.856623    
#> 447: 0.246391    1.077911    3.493212    0.107592    0.079726    0.035037    0.856611    
#> 448: 0.246240    1.077911    3.493251    0.107433    0.079742    0.035073    0.856574    
#> 449: 0.246165    1.078031    3.493325    0.107316    0.079768    0.035120    0.856530    
#> 450: 0.246126    1.078094    3.493314    0.107204    0.079707    0.035151    0.856519    
#> 451: 0.246159    1.078114    3.493323    0.107078    0.079639    0.035152    0.856597    
#> 452: 0.246123    1.078181    3.493262    0.107021    0.079578    0.035168    0.856620    
#> 453: 0.246018    1.078216    3.493209    0.106960    0.079459    0.035190    0.856567    
#> 454: 0.245895    1.078413    3.493133    0.106938    0.079447    0.035187    0.856463    
#> 455: 0.245790    1.078509    3.493087    0.106980    0.079426    0.035162    0.856473    
#> 456: 0.245615    1.078514    3.493014    0.107066    0.079418    0.035153    0.856449    
#> 457: 0.245510    1.078551    3.493012    0.107040    0.079361    0.035157    0.856440    
#> 458: 0.245356    1.078744    3.492982    0.107108    0.079358    0.035165    0.856418    
#> 459: 0.245226    1.078940    3.492919    0.107049    0.079327    0.035186    0.856398    
#> 460: 0.245041    1.079032    3.492833    0.107048    0.079345    0.035194    0.856444    
#> 461: 0.244771    1.079091    3.492774    0.107045    0.079365    0.035197    0.856501    
#> 462: 0.244575    1.079198    3.492705    0.107026    0.079326    0.035185    0.856614    
#> 463: 0.244663    1.079300    3.492688    0.107059    0.079341    0.035187    0.856699    
#> 464: 0.244679    1.079394    3.492624    0.106974    0.079357    0.035184    0.856663    
#> 465: 0.244596    1.079344    3.492606    0.106899    0.079386    0.035179    0.856715    
#> 466: 0.244665    1.079434    3.492558    0.106773    0.079318    0.035210    0.856696    
#> 467: 0.244644    1.079413    3.492619    0.106633    0.079215    0.035244    0.856630    
#> 468: 0.244844    1.079375    3.492728    0.106651    0.079219    0.035285    0.856650    
#> 469: 0.244903    1.079468    3.492804    0.106719    0.079211    0.035328    0.856671    
#> 470: 0.244734    1.079519    3.492763    0.106696    0.079229    0.035351    0.856662    
#> 471: 0.244517    1.079500    3.492729    0.106728    0.079225    0.035364    0.856630    
#> 472: 0.244335    1.079587    3.492624    0.106850    0.079281    0.035352    0.856594    
#> 473: 0.244024    1.079630    3.492504    0.106859    0.079296    0.035322    0.856565    
#> 474: 0.243896    1.079597    3.492434    0.106764    0.079368    0.035330    0.856604    
#> 475: 0.243840    1.079826    3.492367    0.106689    0.079434    0.035294    0.856644    
#> 476: 0.243851    1.079899    3.492322    0.106778    0.079534    0.035261    0.856610    
#> 477: 0.243764    1.079949    3.492320    0.106729    0.079617    0.035253    0.856515    
#> 478: 0.243731    1.079849    3.492353    0.106681    0.079578    0.035272    0.856502    
#> 479: 0.243845    1.079890    3.492348    0.106741    0.079569    0.035264    0.856490    
#> 480: 0.243810    1.079940    3.492338    0.106676    0.079663    0.035251    0.856544    
#> 481: 0.243780    1.079953    3.492349    0.106612    0.079685    0.035256    0.856575    
#> 482: 0.243875    1.079910    3.492348    0.106566    0.079713    0.035284    0.856738    
#> 483: 0.243866    1.079815    3.492356    0.106640    0.079791    0.035272    0.856769    
#> 484: 0.243859    1.079708    3.492316    0.106709    0.079800    0.035267    0.856801    
#> 485: 0.243872    1.079744    3.492296    0.106770    0.079844    0.035248    0.856859    
#> 486: 0.243900    1.079751    3.492323    0.106655    0.079809    0.035229    0.856855    
#> 487: 0.244110    1.079694    3.492422    0.106546    0.079876    0.035227    0.856850    
#> 488: 0.244139    1.079626    3.492476    0.106494    0.079880    0.035203    0.856923    
#> 489: 0.244212    1.079541    3.492475    0.106521    0.079884    0.035199    0.857016    
#> 490: 0.244293    1.079594    3.492476    0.106601    0.079906    0.035211    0.857035    
#> 491: 0.244323    1.079630    3.492509    0.106643    0.079892    0.035226    0.856948    
#> 492: 0.244242    1.079652    3.492467    0.106674    0.079832    0.035244    0.856923    
#> 493: 0.244116    1.079636    3.492468    0.106780    0.079789    0.035274    0.856886    
#> 494: 0.244267    1.079621    3.492493    0.106852    0.079691    0.035321    0.856868    
#> 495: 0.244347    1.079532    3.492480    0.106916    0.079599    0.035324    0.856826    
#> 496: 0.244215    1.079603    3.492365    0.106945    0.079574    0.035311    0.856846    
#> 497: 0.244171    1.079539    3.492368    0.106864    0.079484    0.035317    0.856927    
#> 498: 0.244169    1.079542    3.492340    0.106813    0.079514    0.035326    0.856972    
#> 499: 0.244136    1.079607    3.492295    0.106791    0.079530    0.035311    0.856959    
#> 500: 0.244199    1.079570    3.492288    0.106750    0.079493    0.035308    0.856908    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.260093    0.983112    3.448901    0.392401    0.083094    0.016800    1.706202    
#> 002: 0.202518    1.046942    3.462040    0.372781    0.078939    0.015960    1.169231    
#> 003: 0.318714    0.991821    3.486386    0.354142    0.081559    0.015162    0.866952    
#> 004: 0.293462    1.026923    3.487769    0.336435    0.089080    0.014404    0.788227    
#> 005: 0.346557    1.033808    3.474545    0.319613    0.097043    0.013684    0.772759    
#> 006: 0.320167    1.027274    3.477687    0.303633    0.092191    0.013000    0.743608    
#> 007: 0.302617    1.056112    3.469116    0.288451    0.091684    0.012350    0.755473    
#> 008: 0.275584    1.037300    3.453247    0.274029    0.100246    0.011732    0.756022    
#> 009: 0.232960    1.045258    3.444825    0.260327    0.101659    0.011146    0.761847    
#> 010: 0.234227    1.057447    3.432899    0.292484    0.105419    0.010588    0.770374    
#> 011: 0.298762    1.053846    3.448851    0.328621    0.115095    0.012206    0.772573    
#> 012: 0.274849    1.081065    3.438072    0.341322    0.109341    0.011766    0.748935    
#> 013: 0.235935    1.087719    3.436717    0.324256    0.103874    0.011178    0.756494    
#> 014: 0.305761    1.069721    3.454483    0.308043    0.098680    0.010619    0.785183    
#> 015: 0.309526    1.061908    3.468955    0.292641    0.093746    0.011331    0.762871    
#> 016: 0.325866    1.051506    3.469436    0.278009    0.089059    0.012125    0.774047    
#> 017: 0.345836    1.036323    3.481058    0.275513    0.088074    0.013921    0.751464    
#> 018: 0.335127    1.027062    3.470612    0.261737    0.085889    0.015717    0.776500    
#> 019: 0.286280    1.039825    3.466911    0.248651    0.081595    0.016001    0.750835    
#> 020: 0.296432    1.038785    3.479283    0.236218    0.082804    0.016450    0.746935    
#> 021: 0.351505    1.024385    3.496110    0.240506    0.078664    0.015627    0.747167    
#> 022: 0.356516    1.022038    3.502226    0.246533    0.077957    0.015414    0.737966    
#> 023: 0.426322    1.009147    3.517317    0.310833    0.074059    0.018029    0.762381    
#> 024: 0.403152    1.043777    3.512202    0.295291    0.080001    0.020423    0.731766    
#> 025: 0.389964    1.003768    3.509130    0.280527    0.078495    0.019402    0.736228    
#> 026: 0.364285    1.028174    3.495545    0.266501    0.075805    0.018432    0.734053    
#> 027: 0.311979    1.026728    3.483392    0.253176    0.072862    0.017510    0.755503    
#> 028: 0.376054    1.031176    3.498726    0.268829    0.069218    0.019603    0.734471    
#> 029: 0.361602    1.027686    3.478201    0.267659    0.079929    0.018623    0.769352    
#> 030: 0.390610    1.039261    3.478279    0.310521    0.081552    0.017691    0.722430    
#> 031: 0.323991    1.032050    3.488608    0.294995    0.077475    0.017249    0.722083    
#> 032: 0.310915    1.030147    3.487644    0.280246    0.074291    0.016387    0.719220    
#> 033: 0.324273    1.038629    3.482653    0.313043    0.070576    0.015568    0.740551    
#> 034: 0.343090    1.047622    3.473046    0.367417    0.067048    0.016965    0.739382    
#> 035: 0.309470    1.036388    3.461925    0.349092    0.076081    0.016117    0.732522    
#> 036: 0.294356    1.047631    3.460999    0.331637    0.072589    0.015882    0.753896    
#> 037: 0.288162    1.059629    3.469753    0.333907    0.068960    0.015088    0.754541    
#> 038: 0.318534    1.045263    3.461947    0.317212    0.076986    0.014334    0.752206    
#> 039: 0.345406    1.055089    3.472539    0.310378    0.078497    0.013617    0.748813    
#> 040: 0.328253    1.067055    3.479895    0.294860    0.074572    0.012936    0.752373    
#> 041: 0.301475    1.037691    3.475413    0.280117    0.087589    0.012289    0.757180    
#> 042: 0.338154    1.034735    3.472359    0.329779    0.083209    0.011675    0.740643    
#> 043: 0.315188    1.051149    3.462906    0.320131    0.079049    0.011091    0.734166    
#> 044: 0.291661    1.059794    3.462002    0.304125    0.078672    0.011036    0.747618    
#> 045: 0.293816    1.058772    3.464032    0.288918    0.095736    0.010484    0.739904    
#> 046: 0.331355    1.057733    3.458587    0.331708    0.100803    0.009960    0.740486    
#> 047: 0.294756    1.054187    3.453605    0.315122    0.106776    0.009462    0.745322    
#> 048: 0.287800    1.041216    3.466528    0.303845    0.114686    0.009146    0.759780    
#> 049: 0.287763    1.048227    3.457773    0.288653    0.108952    0.008689    0.759736    
#> 050: 0.359332    1.028219    3.463345    0.333168    0.103504    0.008255    0.775853    
#> 051: 0.329430    1.040682    3.463667    0.316510    0.100722    0.007842    0.777062    
#> 052: 0.327308    1.040070    3.475073    0.305411    0.099261    0.007450    0.762947    
#> 053: 0.313575    1.032900    3.472653    0.290141    0.110839    0.007893    0.748534    
#> 054: 0.268119    1.026323    3.480807    0.275634    0.105297    0.011721    0.762670    
#> 055: 0.287226    1.028141    3.469559    0.274137    0.100032    0.011487    0.749045    
#> 056: 0.349380    1.015590    3.478615    0.300570    0.095031    0.011149    0.755771    
#> 057: 0.351879    1.041436    3.480099    0.286849    0.102895    0.011493    0.768218    
#> 058: 0.331216    1.034524    3.468742    0.294261    0.097750    0.010918    0.768695    
#> 059: 0.334331    0.992074    3.484364    0.306240    0.093189    0.013485    0.782808    
#> 060: 0.328719    0.982065    3.490342    0.290928    0.088530    0.012811    0.793681    
#> 061: 0.383615    1.006677    3.494629    0.337226    0.085877    0.014961    0.786631    
#> 062: 0.343391    1.035077    3.495388    0.320365    0.096644    0.014440    0.801919    
#> 063: 0.356664    1.004541    3.491259    0.304346    0.093648    0.014604    0.795127    
#> 064: 0.322048    1.011652    3.495957    0.289129    0.088966    0.016130    0.767090    
#> 065: 0.359440    0.993611    3.491529    0.274673    0.094741    0.016549    0.763437    
#> 066: 0.374412    1.025562    3.497289    0.291310    0.090004    0.018146    0.742938    
#> 067: 0.371487    1.025608    3.499120    0.290882    0.085504    0.021782    0.722145    
#> 068: 0.324709    1.017579    3.497974    0.276338    0.086853    0.020692    0.745254    
#> 069: 0.305574    1.028362    3.475468    0.341259    0.089163    0.019658    0.736934    
#> 070: 0.320296    1.027066    3.486174    0.341410    0.084705    0.021316    0.761431    
#> 071: 0.327267    1.056101    3.467834    0.324340    0.098781    0.020250    0.769968    
#> 072: 0.309609    1.007388    3.488287    0.308123    0.093842    0.019237    0.750047    
#> 073: 0.308793    1.044193    3.488893    0.325651    0.089150    0.018276    0.756477    
#> 074: 0.306979    1.011664    3.478097    0.309369    0.084693    0.017362    0.760595    
#> 075: 0.372703    0.988111    3.516328    0.293900    0.080458    0.016494    0.750660    
#> 076: 0.344819    1.019369    3.508473    0.279205    0.087662    0.015669    0.751811    
#> 077: 0.418609    1.005957    3.511805    0.277048    0.083279    0.015364    0.756435    
#> 078: 0.392693    0.994489    3.510001    0.263195    0.079469    0.014596    0.761149    
#> 079: 0.366498    1.032104    3.509096    0.314107    0.078740    0.013866    0.775310    
#> 080: 0.374043    1.017552    3.499339    0.352339    0.074803    0.013543    0.793054    
#> 081: 0.356480    1.046257    3.481049    0.348072    0.071063    0.012866    0.756445    
#> 082: 0.334432    1.045302    3.487433    0.330668    0.071749    0.012417    0.765596    
#> 083: 0.308145    1.042709    3.479418    0.319590    0.087876    0.011796    0.780124    
#> 084: 0.327561    1.051680    3.465955    0.334368    0.099948    0.011207    0.757476    
#> 085: 0.249145    1.083873    3.455821    0.317649    0.102241    0.010646    0.760010    
#> 086: 0.247530    1.086873    3.447187    0.340530    0.106731    0.010114    0.747013    
#> 087: 0.267154    1.070370    3.445041    0.323503    0.117661    0.009608    0.759610    
#> 088: 0.188372    1.056007    3.435320    0.342046    0.111778    0.011561    0.783884    
#> 089: 0.239383    1.083971    3.423336    0.325426    0.106189    0.015774    0.768840    
#> 090: 0.237206    1.080847    3.438882    0.309154    0.100880    0.023125    0.756448    
#> 091: 0.210639    1.078022    3.428610    0.309127    0.095836    0.021968    0.761299    
#> 092: 0.241457    1.071612    3.448798    0.294743    0.091044    0.023127    0.761005    
#> 093: 0.262111    1.055896    3.453717    0.280006    0.086492    0.021971    0.752465    
#> 094: 0.299103    1.046106    3.466468    0.266006    0.082167    0.020872    0.774266    
#> 095: 0.298794    1.052707    3.481203    0.262309    0.078059    0.023627    0.768788    
#> 096: 0.257179    1.052008    3.466300    0.316077    0.082868    0.022445    0.749113    
#> 097: 0.320639    1.050289    3.473116    0.300274    0.078724    0.021323    0.743475    
#> 098: 0.307759    1.073857    3.482900    0.285260    0.079656    0.020257    0.751078    
#> 099: 0.303243    1.055648    3.461953    0.270997    0.082906    0.019244    0.738555    
#> 100: 0.274314    1.062127    3.453650    0.257447    0.089013    0.018282    0.741225    
#> 101: 0.226877    1.044914    3.430223    0.255570    0.084562    0.017368    0.761980    
#> 102: 0.227829    1.069200    3.424723    0.290938    0.080334    0.016749    0.742878    
#> 103: 0.282590    1.063329    3.455855    0.277942    0.076317    0.015911    0.750197    
#> 104: 0.247498    1.056429    3.474073    0.311813    0.072501    0.015116    0.764350    
#> 105: 0.279914    1.046722    3.466693    0.296317    0.082702    0.014360    0.766311    
#> 106: 0.309358    1.058599    3.462403    0.288798    0.078567    0.013642    0.758654    
#> 107: 0.313357    1.064513    3.459250    0.348113    0.086931    0.012960    0.770025    
#> 108: 0.304986    1.041393    3.471110    0.330707    0.089812    0.013408    0.780063    
#> 109: 0.284400    1.025172    3.473484    0.314172    0.085321    0.013463    0.762972    
#> 110: 0.315946    1.017236    3.460197    0.298463    0.081055    0.014530    0.777449    
#> 111: 0.302400    1.023519    3.471995    0.286009    0.081503    0.013914    0.738178    
#> 112: 0.287220    1.020487    3.458944    0.271709    0.077428    0.013779    0.773855    
#> 113: 0.295225    1.067327    3.473363    0.258123    0.073557    0.013398    0.735676    
#> 114: 0.341191    1.062358    3.475459    0.264102    0.082992    0.014305    0.745743    
#> 115: 0.379582    1.035921    3.480671    0.321288    0.084333    0.014664    0.752139    
#> 116: 0.365153    1.035661    3.480691    0.329514    0.080116    0.015537    0.752154    
#> 117: 0.328599    1.046131    3.490231    0.313039    0.082112    0.014760    0.758776    
#> 118: 0.356904    1.034420    3.490124    0.297387    0.096919    0.014022    0.742873    
#> 119: 0.358580    1.036726    3.502507    0.282517    0.092073    0.013946    0.764674    
#> 120: 0.346123    1.015624    3.493006    0.298372    0.087470    0.013766    0.744305    
#> 121: 0.346980    1.051846    3.488984    0.293391    0.112417    0.015161    0.734451    
#> 122: 0.356918    1.019854    3.486120    0.278721    0.106797    0.014403    0.753101    
#> 123: 0.370877    1.047726    3.483819    0.279204    0.101457    0.014034    0.758547    
#> 124: 0.372040    1.063089    3.484732    0.265244    0.096384    0.013332    0.760296    
#> 125: 0.375872    1.064906    3.467357    0.263485    0.091565    0.012702    0.750485    
#> 126: 0.277934    1.080554    3.445903    0.250310    0.094273    0.012779    0.744494    
#> 127: 0.291087    1.053498    3.445243    0.310061    0.089559    0.012523    0.740316    
#> 128: 0.285606    1.050982    3.453594    0.325789    0.088843    0.014628    0.738973    
#> 129: 0.325498    1.053981    3.465415    0.315944    0.099256    0.013897    0.729856    
#> 130: 0.331232    1.060749    3.465299    0.300147    0.096592    0.013202    0.726066    
#> 131: 0.316695    1.051787    3.465141    0.285139    0.099587    0.013564    0.723881    
#> 132: 0.273580    1.063672    3.450227    0.270883    0.094607    0.012886    0.739848    
#> 133: 0.285797    1.050014    3.455451    0.270637    0.089877    0.012242    0.766269    
#> 134: 0.311285    1.043084    3.472715    0.257105    0.085383    0.015552    0.735082    
#> 135: 0.309792    1.052265    3.489946    0.244250    0.081114    0.015680    0.758354    
#> 136: 0.316406    1.034440    3.493022    0.232038    0.077058    0.018673    0.752223    
#> 137: 0.350341    1.025026    3.492425    0.282271    0.073205    0.019269    0.732850    
#> 138: 0.330630    1.039856    3.491829    0.268158    0.074614    0.019140    0.733150    
#> 139: 0.348043    1.041269    3.498537    0.258928    0.072801    0.019163    0.748187    
#> 140: 0.365559    1.038650    3.508346    0.311437    0.069161    0.019742    0.776397    
#> 141: 0.357129    1.002678    3.507076    0.295865    0.065703    0.019847    0.764491    
#> 142: 0.361532    0.993957    3.522889    0.281072    0.062975    0.018855    0.776030    
#> 143: 0.314131    1.033549    3.506880    0.267018    0.070102    0.020452    0.768684    
#> 144: 0.342392    1.029479    3.502485    0.330471    0.073501    0.019429    0.755650    
#> 145: 0.332779    1.033611    3.478216    0.313947    0.069826    0.018458    0.744163    
#> 146: 0.310775    1.042636    3.489594    0.298250    0.071431    0.020017    0.747635    
#> 147: 0.287723    1.027390    3.478761    0.283337    0.081832    0.020157    0.740260    
#> 148: 0.312518    1.031950    3.488274    0.269170    0.077741    0.019149    0.741969    
#> 149: 0.293400    1.031202    3.488454    0.255712    0.073854    0.019997    0.758253    
#> 150: 0.328350    1.049745    3.470570    0.242926    0.070161    0.018997    0.765715    
#> 151: 0.263657    1.072548    3.464211    0.231089    0.073892    0.018047    0.769072    
#> 152: 0.295826    1.060465    3.476390    0.240649    0.079319    0.013012    0.753150    
#> 153: 0.323659    1.048741    3.481346    0.237665    0.083824    0.014827    0.742773    
#> 154: 0.358781    1.053630    3.482247    0.241181    0.071498    0.016479    0.761268    
#> 155: 0.339312    1.039662    3.486160    0.217616    0.066931    0.015988    0.782676    
#> 156: 0.326134    1.052000    3.486501    0.192587    0.047655    0.018363    0.778082    
#> 157: 0.336528    1.034268    3.489536    0.236914    0.048431    0.020541    0.755669    
#> 158: 0.362858    1.038061    3.485884    0.221190    0.062223    0.018033    0.739985    
#> 159: 0.302628    1.047667    3.483559    0.236354    0.070517    0.020559    0.751608    
#> 160: 0.315788    1.015173    3.489863    0.278983    0.070861    0.019765    0.754338    
#> 161: 0.318628    1.041423    3.480943    0.277202    0.066949    0.025729    0.738218    
#> 162: 0.308552    1.072820    3.467448    0.284498    0.056340    0.027258    0.761759    
#> 163: 0.342781    1.065656    3.473968    0.297199    0.058636    0.027444    0.742670    
#> 164: 0.321293    1.052032    3.482482    0.281573    0.056762    0.028162    0.755887    
#> 165: 0.348830    1.048807    3.487759    0.259088    0.065228    0.020505    0.733138    
#> 166: 0.339334    1.086789    3.480398    0.259223    0.069901    0.023092    0.741084    
#> 167: 0.343509    1.075076    3.484015    0.267181    0.069814    0.024253    0.763239    
#> 168: 0.341469    1.079087    3.475477    0.271999    0.067644    0.022539    0.760211    
#> 169: 0.338868    1.093756    3.475908    0.261223    0.059256    0.022020    0.757804    
#> 170: 0.370370    1.054979    3.487995    0.284679    0.056827    0.022375    0.751533    
#> 171: 0.332740    1.051870    3.487281    0.261872    0.062955    0.015484    0.746520    
#> 172: 0.311282    1.050013    3.477833    0.202642    0.072813    0.016646    0.751862    
#> 173: 0.279864    1.058489    3.460413    0.202988    0.074558    0.012920    0.762525    
#> 174: 0.303546    1.050102    3.469642    0.248371    0.081024    0.009554    0.757044    
#> 175: 0.309245    1.035714    3.459333    0.255613    0.078484    0.012165    0.760818    
#> 176: 0.352846    1.070639    3.473809    0.331859    0.076639    0.009590    0.758752    
#> 177: 0.353041    1.061424    3.475276    0.317058    0.077898    0.009502    0.753266    
#> 178: 0.342092    1.048011    3.475553    0.281829    0.086257    0.011572    0.743768    
#> 179: 0.342981    1.057221    3.480363    0.272392    0.094384    0.013055    0.771117    
#> 180: 0.316423    1.063292    3.481863    0.296902    0.098060    0.011485    0.744950    
#> 181: 0.318017    1.057753    3.460964    0.272722    0.092524    0.010552    0.734843    
#> 182: 0.312470    1.074024    3.454092    0.215954    0.089811    0.008866    0.763519    
#> 183: 0.280707    1.072999    3.452785    0.242174    0.099397    0.008081    0.737338    
#> 184: 0.289052    1.035890    3.458912    0.236989    0.089184    0.007667    0.751289    
#> 185: 0.247936    1.077653    3.453873    0.231728    0.084127    0.005624    0.768829    
#> 186: 0.284163    1.094699    3.458534    0.262587    0.109056    0.005501    0.757187    
#> 187: 0.292545    1.054937    3.468169    0.332680    0.093057    0.005138    0.756752    
#> 188: 0.286966    1.075914    3.457842    0.306200    0.103085    0.005464    0.766605    
#> 189: 0.326196    1.070342    3.463777    0.395698    0.116344    0.005955    0.770293    
#> 190: 0.332511    1.058276    3.475401    0.423004    0.101274    0.006726    0.747408    
#> 191: 0.298660    1.058855    3.465818    0.285156    0.108696    0.007500    0.746562    
#> 192: 0.260525    1.063099    3.466688    0.297354    0.090524    0.008370    0.735368    
#> 193: 0.298187    1.074440    3.469162    0.309808    0.085699    0.008806    0.722997    
#> 194: 0.278843    1.055144    3.451673    0.308046    0.091479    0.011104    0.752569    
#> 195: 0.274567    1.049702    3.458905    0.284996    0.090357    0.008670    0.746362    
#> 196: 0.262422    1.063551    3.467499    0.265047    0.114241    0.009873    0.761872    
#> 197: 0.238439    1.062040    3.470997    0.243726    0.095241    0.009374    0.766244    
#> 198: 0.293285    1.040497    3.456607    0.248138    0.085764    0.009851    0.755911    
#> 199: 0.280070    1.036434    3.458501    0.308594    0.087325    0.008876    0.740751    
#> 200: 0.291544    1.058757    3.457962    0.323269    0.080124    0.007477    0.742406    
#> 201: 0.284872    1.056431    3.459031    0.295019    0.080382    0.007587    0.743646    
#> 202: 0.286809    1.058184    3.458547    0.287202    0.089318    0.006997    0.752419    
#> 203: 0.291908    1.056025    3.457920    0.279795    0.095802    0.006710    0.755258    
#> 204: 0.294117    1.050843    3.458621    0.278242    0.102156    0.006764    0.758946    
#> 205: 0.289029    1.055231    3.458850    0.275817    0.103643    0.007281    0.760715    
#> 206: 0.289198    1.060181    3.459864    0.275658    0.103375    0.007833    0.764001    
#> 207: 0.284244    1.059039    3.459391    0.284568    0.101837    0.008162    0.763682    
#> 208: 0.285390    1.058553    3.460424    0.288516    0.098892    0.008437    0.760381    
#> 209: 0.288963    1.054695    3.461911    0.291517    0.098016    0.008757    0.758662    
#> 210: 0.293179    1.051343    3.463612    0.292875    0.097249    0.008873    0.756872    
#> 211: 0.297291    1.050213    3.465298    0.291535    0.096072    0.008944    0.754846    
#> 212: 0.300301    1.048465    3.466207    0.294337    0.095779    0.009081    0.753912    
#> 213: 0.303490    1.047279    3.466586    0.297418    0.095979    0.009428    0.754143    
#> 214: 0.306666    1.046296    3.467547    0.299589    0.095782    0.009687    0.753607    
#> 215: 0.308577    1.046031    3.468195    0.304882    0.094782    0.010039    0.751496    
#> 216: 0.310421    1.045242    3.468197    0.304976    0.094054    0.010127    0.752062    
#> 217: 0.309672    1.046484    3.468263    0.301633    0.092998    0.010142    0.750811    
#> 218: 0.310428    1.047588    3.467672    0.301572    0.092738    0.010191    0.749959    
#> 219: 0.310419    1.047862    3.466802    0.302725    0.092463    0.010316    0.749825    
#> 220: 0.309905    1.048412    3.466564    0.307424    0.092446    0.010500    0.748901    
#> 221: 0.310367    1.048279    3.466540    0.311752    0.091643    0.010624    0.748491    
#> 222: 0.311295    1.047274    3.466928    0.311314    0.090233    0.010902    0.748397    
#> 223: 0.312194    1.047589    3.466890    0.309925    0.089784    0.011002    0.748377    
#> 224: 0.313447    1.048788    3.467212    0.308599    0.090031    0.011063    0.748221    
#> 225: 0.312953    1.046821    3.467533    0.307313    0.090280    0.011070    0.749100    
#> 226: 0.313028    1.045649    3.467397    0.305474    0.090179    0.011035    0.750485    
#> 227: 0.311463    1.045088    3.467547    0.304427    0.089818    0.011000    0.750179    
#> 228: 0.308733    1.046075    3.466668    0.304234    0.089097    0.011088    0.750357    
#> 229: 0.306698    1.046405    3.465904    0.303445    0.088588    0.011105    0.750369    
#> 230: 0.306263    1.046402    3.465374    0.302648    0.087993    0.011101    0.750471    
#> 231: 0.305278    1.047238    3.465218    0.301575    0.087591    0.011147    0.750373    
#> 232: 0.304392    1.047691    3.465230    0.301443    0.087327    0.011138    0.750680    
#> 233: 0.302460    1.047352    3.465053    0.301354    0.086965    0.011209    0.750999    
#> 234: 0.301190    1.047738    3.465018    0.301718    0.086955    0.011190    0.750779    
#> 235: 0.300680    1.047833    3.464671    0.301970    0.086890    0.011144    0.750433    
#> 236: 0.300408    1.048397    3.464497    0.301689    0.086892    0.011182    0.750592    
#> 237: 0.301757    1.048554    3.464578    0.301214    0.086958    0.011200    0.751076    
#> 238: 0.302640    1.048474    3.464785    0.300013    0.087198    0.011286    0.751439    
#> 239: 0.303048    1.048862    3.464940    0.297882    0.087198    0.011355    0.751324    
#> 240: 0.303320    1.048548    3.465209    0.295738    0.087508    0.011416    0.750861    
#> 241: 0.303729    1.047584    3.465615    0.294867    0.087464    0.011491    0.750341    
#> 242: 0.304150    1.046762    3.465783    0.296261    0.087771    0.011548    0.750382    
#> 243: 0.303701    1.047023    3.465914    0.296076    0.088027    0.011573    0.750412    
#> 244: 0.303013    1.046881    3.465966    0.295297    0.088033    0.011614    0.750612    
#> 245: 0.302720    1.046715    3.465895    0.295007    0.088313    0.011620    0.751473    
#> 246: 0.303409    1.045929    3.466330    0.294684    0.088187    0.011702    0.751424    
#> 247: 0.303958    1.045435    3.467014    0.292944    0.087991    0.011768    0.751537    
#> 248: 0.304249    1.045434    3.467451    0.291945    0.087726    0.011794    0.751436    
#> 249: 0.305036    1.045238    3.467795    0.292559    0.087498    0.011823    0.751348    
#> 250: 0.305777    1.045391    3.468159    0.292012    0.087251    0.011843    0.751696    
#> 251: 0.306769    1.045500    3.468762    0.291126    0.087069    0.011862    0.752058    
#> 252: 0.307897    1.045395    3.469326    0.291313    0.087261    0.011908    0.752117    
#> 253: 0.308379    1.045458    3.469579    0.292401    0.087483    0.011942    0.752038    
#> 254: 0.308944    1.045454    3.470011    0.292850    0.087303    0.012007    0.752068    
#> 255: 0.309043    1.045563    3.470380    0.293112    0.087321    0.012049    0.752246    
#> 256: 0.309539    1.045184    3.470560    0.293037    0.087374    0.012064    0.752149    
#> 257: 0.309760    1.044723    3.470765    0.292146    0.087772    0.012085    0.752480    
#> 258: 0.309998    1.044325    3.470890    0.291153    0.087954    0.012007    0.752778    
#> 259: 0.309460    1.044286    3.470828    0.291296    0.088215    0.011941    0.752719    
#> 260: 0.309331    1.044466    3.470849    0.290917    0.088356    0.011888    0.752665    
#> 261: 0.309658    1.044139    3.471045    0.290563    0.088450    0.011859    0.753081    
#> 262: 0.310338    1.044026    3.471293    0.289355    0.088359    0.011869    0.753227    
#> 263: 0.310678    1.043980    3.471635    0.289511    0.088130    0.011952    0.753344    
#> 264: 0.311268    1.043780    3.471899    0.289530    0.088020    0.011993    0.753722    
#> 265: 0.311483    1.043647    3.472215    0.288365    0.087977    0.012038    0.754227    
#> 266: 0.311571    1.043712    3.472410    0.286932    0.087864    0.012065    0.754397    
#> 267: 0.311522    1.043676    3.472472    0.287781    0.087776    0.012114    0.754391    
#> 268: 0.311848    1.043587    3.472416    0.288194    0.087866    0.012142    0.754273    
#> 269: 0.312533    1.043555    3.472413    0.287363    0.087740    0.012178    0.754443    
#> 270: 0.312741    1.044076    3.472288    0.286482    0.087462    0.012175    0.754219    
#> 271: 0.312596    1.044288    3.472180    0.286419    0.087314    0.012163    0.754263    
#> 272: 0.313243    1.043966    3.472284    0.286576    0.087269    0.012147    0.754279    
#> 273: 0.313481    1.044090    3.472478    0.286500    0.087401    0.012144    0.754337    
#> 274: 0.313065    1.044223    3.472521    0.286933    0.087451    0.012099    0.754541    
#> 275: 0.313121    1.044086    3.472488    0.286454    0.087582    0.012076    0.754428    
#> 276: 0.312819    1.044172    3.472594    0.286720    0.087343    0.012044    0.754443    
#> 277: 0.312708    1.044139    3.472940    0.286261    0.087158    0.012086    0.754596    
#> 278: 0.312564    1.044012    3.473104    0.286435    0.087008    0.012070    0.754507    
#> 279: 0.312541    1.043899    3.473128    0.286719    0.087001    0.012061    0.754582    
#> 280: 0.312612    1.044273    3.473209    0.286656    0.087154    0.012028    0.754606    
#> 281: 0.312343    1.044355    3.473302    0.286287    0.087320    0.011984    0.754668    
#> 282: 0.312469    1.044690    3.473330    0.285655    0.087460    0.011998    0.754737    
#> 283: 0.312585    1.044724    3.473342    0.285894    0.087523    0.012030    0.754807    
#> 284: 0.312291    1.044633    3.473304    0.286256    0.087539    0.012064    0.754614    
#> 285: 0.311743    1.044854    3.473027    0.286405    0.087423    0.012110    0.754401    
#> 286: 0.311403    1.045102    3.472784    0.287043    0.087408    0.012160    0.754421    
#> 287: 0.310998    1.045536    3.472492    0.287501    0.087474    0.012232    0.754420    
#> 288: 0.311090    1.045727    3.472394    0.287870    0.087513    0.012235    0.754531    
#> 289: 0.311253    1.045555    3.472370    0.287918    0.087563    0.012229    0.754582    
#> 290: 0.311458    1.045532    3.472342    0.287842    0.087727    0.012236    0.754728    
#> 291: 0.311857    1.045581    3.472494    0.287295    0.087791    0.012234    0.754724    
#> 292: 0.311947    1.045488    3.472505    0.287401    0.087893    0.012205    0.754621    
#> 293: 0.312058    1.045457    3.472482    0.286987    0.088037    0.012179    0.754478    
#> 294: 0.311860    1.045542    3.472372    0.287215    0.088089    0.012182    0.754202    
#> 295: 0.311937    1.045325    3.472381    0.286663    0.088198    0.012178    0.753988    
#> 296: 0.312002    1.044980    3.472390    0.286791    0.088117    0.012183    0.754033    
#> 297: 0.312001    1.045079    3.472259    0.287072    0.088146    0.012179    0.753815    
#> 298: 0.311880    1.045074    3.472146    0.287086    0.088264    0.012179    0.753745    
#> 299: 0.311879    1.045307    3.471971    0.287251    0.088242    0.012148    0.753506    
#> 300: 0.311827    1.045298    3.471983    0.287783    0.088365    0.012103    0.753448    
#> 301: 0.311852    1.045195    3.471868    0.287827    0.088387    0.012073    0.753524    
#> 302: 0.311661    1.045295    3.471809    0.287580    0.088305    0.012050    0.753415    
#> 303: 0.311475    1.045313    3.471816    0.286905    0.088131    0.012047    0.753404    
#> 304: 0.311494    1.045491    3.471722    0.286682    0.088059    0.012038    0.753455    
#> 305: 0.311542    1.045093    3.471788    0.286661    0.087974    0.012054    0.753400    
#> 306: 0.311324    1.045000    3.471690    0.286560    0.087910    0.012029    0.753411    
#> 307: 0.311217    1.045131    3.471611    0.286493    0.088020    0.012019    0.753544    
#> 308: 0.310464    1.045187    3.471456    0.286526    0.088069    0.012020    0.753707    
#> 309: 0.310654    1.044957    3.471421    0.287054    0.088009    0.012027    0.753799    
#> 310: 0.310968    1.044853    3.471364    0.287473    0.088000    0.012037    0.753864    
#> 311: 0.310829    1.044841    3.471321    0.287533    0.087927    0.012027    0.753788    
#> 312: 0.310716    1.044770    3.471301    0.287355    0.087946    0.012015    0.753696    
#> 313: 0.310373    1.044647    3.471228    0.287412    0.087899    0.012017    0.753649    
#> 314: 0.309959    1.044826    3.471109    0.287245    0.087865    0.012034    0.753751    
#> 315: 0.309720    1.045126    3.471052    0.287214    0.087791    0.012072    0.753802    
#> 316: 0.309940    1.045283    3.471036    0.287225    0.087771    0.012071    0.753841    
#> 317: 0.310121    1.045174    3.471119    0.287202    0.087754    0.012069    0.753889    
#> 318: 0.310245    1.045232    3.471101    0.287412    0.087934    0.012079    0.753835    
#> 319: 0.310196    1.045166    3.471122    0.287386    0.088102    0.012060    0.753819    
#> 320: 0.309861    1.044955    3.471008    0.286988    0.088079    0.012033    0.753942    
#> 321: 0.309422    1.045005    3.470779    0.286936    0.088049    0.012005    0.753929    
#> 322: 0.309122    1.045048    3.470559    0.286908    0.087945    0.012000    0.753833    
#> 323: 0.308593    1.045100    3.470441    0.286832    0.087912    0.011984    0.753704    
#> 324: 0.308524    1.045256    3.470429    0.286976    0.087763    0.011986    0.753534    
#> 325: 0.308433    1.045560    3.470342    0.286925    0.087743    0.011989    0.753439    
#> 326: 0.308459    1.045486    3.470216    0.286870    0.087778    0.011986    0.753484    
#> 327: 0.308487    1.045632    3.470202    0.286546    0.087713    0.011987    0.753513    
#> 328: 0.308597    1.045679    3.470174    0.286406    0.087660    0.011997    0.753339    
#> 329: 0.308759    1.045663    3.470201    0.286340    0.087533    0.011995    0.753299    
#> 330: 0.308755    1.045717    3.470271    0.286080    0.087667    0.011998    0.753375    
#> 331: 0.308978    1.045908    3.470281    0.286343    0.087688    0.011987    0.753349    
#> 332: 0.309042    1.045965    3.470272    0.286515    0.087637    0.011961    0.753415    
#> 333: 0.308620    1.046156    3.470184    0.286632    0.087672    0.011951    0.753294    
#> 334: 0.308327    1.046081    3.470012    0.286584    0.087613    0.011935    0.753285    
#> 335: 0.307854    1.046193    3.469813    0.286477    0.087558    0.011911    0.753303    
#> 336: 0.307374    1.046363    3.469734    0.286426    0.087558    0.011902    0.753390    
#> 337: 0.307321    1.046700    3.469675    0.286605    0.087534    0.011893    0.753383    
#> 338: 0.307281    1.046790    3.469637    0.286633    0.087535    0.011890    0.753388    
#> 339: 0.307144    1.046947    3.469595    0.286448    0.087473    0.011899    0.753349    
#> 340: 0.307223    1.046837    3.469623    0.286599    0.087483    0.011946    0.753265    
#> 341: 0.307319    1.046829    3.469626    0.286740    0.087385    0.011970    0.753217    
#> 342: 0.307144    1.046782    3.469523    0.286660    0.087317    0.011950    0.753148    
#> 343: 0.306929    1.046818    3.469578    0.286231    0.087234    0.011964    0.753086    
#> 344: 0.307024    1.046928    3.469642    0.286216    0.087115    0.011978    0.753202    
#> 345: 0.307100    1.046870    3.469675    0.286119    0.087166    0.011997    0.753166    
#> 346: 0.307199    1.046915    3.469687    0.286181    0.087087    0.012001    0.753056    
#> 347: 0.307369    1.046910    3.469598    0.286130    0.087048    0.012023    0.753048    
#> 348: 0.307388    1.046890    3.469542    0.285851    0.086951    0.012029    0.753051    
#> 349: 0.307469    1.046890    3.469528    0.286085    0.086905    0.012033    0.752949    
#> 350: 0.307196    1.046868    3.469459    0.286148    0.086887    0.012041    0.752867    
#> 351: 0.307203    1.046988    3.469434    0.286047    0.086913    0.012059    0.752813    
#> 352: 0.307074    1.047187    3.469443    0.286010    0.086918    0.012077    0.753001    
#> 353: 0.307242    1.047404    3.469414    0.285969    0.087021    0.012096    0.752995    
#> 354: 0.307317    1.047470    3.469325    0.286101    0.087071    0.012114    0.752960    
#> 355: 0.307553    1.047389    3.469376    0.286202    0.087090    0.012129    0.752884    
#> 356: 0.307706    1.047312    3.469465    0.286574    0.087129    0.012125    0.752881    
#> 357: 0.307868    1.047343    3.469481    0.286647    0.087054    0.012121    0.752784    
#> 358: 0.307992    1.047502    3.469481    0.286661    0.086949    0.012118    0.752661    
#> 359: 0.307884    1.047611    3.469453    0.286566    0.086907    0.012116    0.752583    
#> 360: 0.307696    1.047652    3.469272    0.286251    0.086826    0.012109    0.752545    
#> 361: 0.307546    1.047844    3.469112    0.286012    0.086909    0.012105    0.752508    
#> 362: 0.307652    1.047943    3.469079    0.285776    0.086930    0.012099    0.752359    
#> 363: 0.307803    1.047911    3.469115    0.285597    0.086836    0.012115    0.752256    
#> 364: 0.307887    1.047967    3.469186    0.285189    0.086645    0.012117    0.752339    
#> 365: 0.307911    1.047927    3.469254    0.285013    0.086657    0.012121    0.752390    
#> 366: 0.308015    1.047995    3.469253    0.284837    0.086680    0.012114    0.752505    
#> 367: 0.308026    1.048070    3.469196    0.284941    0.086643    0.012084    0.752646    
#> 368: 0.308277    1.048161    3.469144    0.285584    0.086681    0.012059    0.752564    
#> 369: 0.308353    1.048247    3.469116    0.285843    0.086673    0.012043    0.752624    
#> 370: 0.308243    1.048255    3.469063    0.285661    0.086705    0.012024    0.752683    
#> 371: 0.308058    1.048311    3.468931    0.285508    0.086676    0.012004    0.752638    
#> 372: 0.307818    1.048483    3.468835    0.285366    0.086604    0.011992    0.752692    
#> 373: 0.307610    1.048709    3.468696    0.285629    0.086600    0.011981    0.752699    
#> 374: 0.307583    1.048765    3.468653    0.286043    0.086539    0.011965    0.752572    
#> 375: 0.307519    1.048813    3.468615    0.286486    0.086498    0.011961    0.752541    
#> 376: 0.307395    1.048810    3.468563    0.286424    0.086500    0.011965    0.752521    
#> 377: 0.307246    1.048888    3.468501    0.286439    0.086437    0.011952    0.752469    
#> 378: 0.307025    1.048852    3.468418    0.286342    0.086386    0.011958    0.752603    
#> 379: 0.306727    1.048738    3.468386    0.286443    0.086344    0.011962    0.752617    
#> 380: 0.306518    1.048764    3.468349    0.286363    0.086376    0.011942    0.752652    
#> 381: 0.306498    1.048738    3.468341    0.286396    0.086406    0.011927    0.752710    
#> 382: 0.306495    1.048686    3.468386    0.286641    0.086405    0.011922    0.752538    
#> 383: 0.306706    1.048665    3.468445    0.286806    0.086409    0.011932    0.752465    
#> 384: 0.306502    1.048645    3.468457    0.286698    0.086389    0.011927    0.752457    
#> 385: 0.306548    1.048621    3.468484    0.286847    0.086443    0.011941    0.752375    
#> 386: 0.306843    1.048778    3.468633    0.287005    0.086492    0.011956    0.752321    
#> 387: 0.307180    1.048771    3.468783    0.286876    0.086452    0.011977    0.752348    
#> 388: 0.307431    1.048766    3.468902    0.286777    0.086427    0.011994    0.752332    
#> 389: 0.307328    1.048711    3.468843    0.286746    0.086385    0.011991    0.752510    
#> 390: 0.307275    1.048802    3.468785    0.286700    0.086432    0.011995    0.752492    
#> 391: 0.307238    1.048856    3.468716    0.286419    0.086479    0.011993    0.752507    
#> 392: 0.307194    1.048918    3.468740    0.286388    0.086556    0.011984    0.752446    
#> 393: 0.307065    1.048876    3.468689    0.286379    0.086511    0.011979    0.752384    
#> 394: 0.307121    1.048956    3.468649    0.286792    0.086545    0.011996    0.752361    
#> 395: 0.307504    1.049110    3.468658    0.287035    0.086579    0.012012    0.752361    
#> 396: 0.307773    1.049178    3.468697    0.287148    0.086508    0.012032    0.752360    
#> 397: 0.307814    1.049154    3.468738    0.287058    0.086499    0.012032    0.752323    
#> 398: 0.308064    1.049062    3.468823    0.286967    0.086456    0.012021    0.752467    
#> 399: 0.308139    1.048946    3.468954    0.286854    0.086439    0.012019    0.752491    
#> 400: 0.308200    1.048888    3.469036    0.286751    0.086462    0.012014    0.752594    
#> 401: 0.308179    1.048933    3.469048    0.286809    0.086471    0.012018    0.752748    
#> 402: 0.308149    1.048958    3.469091    0.286454    0.086508    0.012042    0.752777    
#> 403: 0.308398    1.048887    3.469109    0.286096    0.086488    0.012056    0.752793    
#> 404: 0.308382    1.048968    3.469035    0.285952    0.086585    0.012061    0.752833    
#> 405: 0.308288    1.048927    3.469054    0.285944    0.086600    0.012067    0.752917    
#> 406: 0.308274    1.048985    3.468985    0.286176    0.086691    0.012068    0.752954    
#> 407: 0.308407    1.049051    3.469008    0.286351    0.086645    0.012070    0.752930    
#> 408: 0.308424    1.049126    3.469018    0.286173    0.086603    0.012072    0.753036    
#> 409: 0.308393    1.049034    3.469000    0.286129    0.086572    0.012080    0.752972    
#> 410: 0.308217    1.049096    3.468918    0.286066    0.086600    0.012086    0.752974    
#> 411: 0.308227    1.049002    3.468904    0.285783    0.086636    0.012103    0.753004    
#> 412: 0.308210    1.049022    3.468939    0.285712    0.086570    0.012132    0.752998    
#> 413: 0.308195    1.048996    3.468921    0.285569    0.086602    0.012139    0.752988    
#> 414: 0.308060    1.048917    3.468949    0.285379    0.086661    0.012147    0.752939    
#> 415: 0.308221    1.048868    3.468967    0.285421    0.086705    0.012162    0.752889    
#> 416: 0.308333    1.048977    3.468992    0.285700    0.086763    0.012158    0.752830    
#> 417: 0.308502    1.048959    3.469017    0.285864    0.086717    0.012161    0.752804    
#> 418: 0.308412    1.049018    3.469034    0.285977    0.086718    0.012151    0.752809    
#> 419: 0.308437    1.049097    3.469043    0.286054    0.086644    0.012154    0.752782    
#> 420: 0.308765    1.049131    3.469085    0.286200    0.086560    0.012168    0.752697    
#> 421: 0.308851    1.049077    3.469197    0.286221    0.086518    0.012182    0.752637    
#> 422: 0.309085    1.048964    3.469274    0.285913    0.086473    0.012207    0.752636    
#> 423: 0.309308    1.048936    3.469318    0.285863    0.086432    0.012206    0.752681    
#> 424: 0.309357    1.048960    3.469260    0.286226    0.086452    0.012197    0.752620    
#> 425: 0.309498    1.049083    3.469279    0.286773    0.086509    0.012201    0.752541    
#> 426: 0.309705    1.049275    3.469295    0.287064    0.086510    0.012195    0.752474    
#> 427: 0.309647    1.049379    3.469330    0.287125    0.086474    0.012217    0.752340    
#> 428: 0.309503    1.049439    3.469317    0.287049    0.086404    0.012223    0.752323    
#> 429: 0.309513    1.049437    3.469347    0.286982    0.086355    0.012222    0.752333    
#> 430: 0.309505    1.049440    3.469368    0.286786    0.086290    0.012233    0.752279    
#> 431: 0.309446    1.049442    3.469339    0.286743    0.086205    0.012229    0.752271    
#> 432: 0.309499    1.049548    3.469377    0.286809    0.086183    0.012232    0.752233    
#> 433: 0.309607    1.049593    3.469458    0.286860    0.086233    0.012244    0.752224    
#> 434: 0.309528    1.049516    3.469493    0.286847    0.086275    0.012260    0.752206    
#> 435: 0.309611    1.049455    3.469516    0.286819    0.086323    0.012263    0.752145    
#> 436: 0.309656    1.049379    3.469569    0.286807    0.086369    0.012267    0.752162    
#> 437: 0.309638    1.049307    3.469562    0.286716    0.086354    0.012272    0.752206    
#> 438: 0.309667    1.049469    3.469554    0.286563    0.086431    0.012257    0.752198    
#> 439: 0.309626    1.049532    3.469544    0.286453    0.086432    0.012252    0.752156    
#> 440: 0.309663    1.049594    3.469570    0.286612    0.086434    0.012254    0.752048    
#> 441: 0.309759    1.049544    3.469595    0.286656    0.086418    0.012258    0.752001    
#> 442: 0.309621    1.049600    3.469622    0.286436    0.086332    0.012256    0.751929    
#> 443: 0.309573    1.049706    3.469617    0.286283    0.086248    0.012262    0.751851    
#> 444: 0.309487    1.049805    3.469549    0.286341    0.086165    0.012277    0.751855    
#> 445: 0.309446    1.049911    3.469504    0.286258    0.086180    0.012279    0.751910    
#> 446: 0.309260    1.049982    3.469448    0.286224    0.086122    0.012265    0.751927    
#> 447: 0.309309    1.050032    3.469443    0.286154    0.086115    0.012255    0.751969    
#> 448: 0.309211    1.050072    3.469435    0.286042    0.086140    0.012243    0.751958    
#> 449: 0.309182    1.050183    3.469518    0.285982    0.086153    0.012231    0.752067    
#> 450: 0.309076    1.050184    3.469525    0.285961    0.086136    0.012228    0.752076    
#> 451: 0.309101    1.050240    3.469513    0.286117    0.086148    0.012232    0.752059    
#> 452: 0.309124    1.050320    3.469489    0.286035    0.086181    0.012222    0.752014    
#> 453: 0.309025    1.050381    3.469460    0.285803    0.086243    0.012206    0.751985    
#> 454: 0.308975    1.050559    3.469389    0.285827    0.086328    0.012193    0.751893    
#> 455: 0.308944    1.050678    3.469341    0.285869    0.086336    0.012189    0.751872    
#> 456: 0.308902    1.050649    3.469327    0.285869    0.086344    0.012194    0.751785    
#> 457: 0.308922    1.050655    3.469356    0.285972    0.086355    0.012202    0.751718    
#> 458: 0.308972    1.050761    3.469395    0.286037    0.086344    0.012202    0.751679    
#> 459: 0.308946    1.050865    3.469413    0.286120    0.086270    0.012206    0.751716    
#> 460: 0.308915    1.050855    3.469399    0.286041    0.086260    0.012216    0.751689    
#> 461: 0.308862    1.050927    3.469404    0.285865    0.086241    0.012225    0.751725    
#> 462: 0.308784    1.050958    3.469436    0.285669    0.086203    0.012243    0.751734    
#> 463: 0.308793    1.051046    3.469430    0.285484    0.086203    0.012250    0.751740    
#> 464: 0.308882    1.051077    3.469411    0.285488    0.086133    0.012260    0.751660    
#> 465: 0.308868    1.050917    3.469423    0.285304    0.086078    0.012265    0.751634    
#> 466: 0.309103    1.050926    3.469387    0.285652    0.085979    0.012263    0.751647    
#> 467: 0.309079    1.050882    3.469419    0.285956    0.085938    0.012270    0.751605    
#> 468: 0.309349    1.050886    3.469472    0.286399    0.085910    0.012269    0.751646    
#> 469: 0.309400    1.050959    3.469519    0.286551    0.085943    0.012268    0.751684    
#> 470: 0.309264    1.050996    3.469495    0.286742    0.085925    0.012272    0.751619    
#> 471: 0.309191    1.050991    3.469494    0.286817    0.085904    0.012269    0.751564    
#> 472: 0.309254    1.050879    3.469525    0.287019    0.085925    0.012264    0.751546    
#> 473: 0.309216    1.050835    3.469553    0.287052    0.085850    0.012276    0.751469    
#> 474: 0.309116    1.050807    3.469558    0.286928    0.085826    0.012288    0.751471    
#> 475: 0.309144    1.050843    3.469602    0.286772    0.085822    0.012304    0.751438    
#> 476: 0.309221    1.050835    3.469624    0.286546    0.085804    0.012302    0.751574    
#> 477: 0.309208    1.050828    3.469663    0.286601    0.085790    0.012300    0.751495    
#> 478: 0.309085    1.050836    3.469641    0.286530    0.085777    0.012292    0.751554    
#> 479: 0.309154    1.050861    3.469643    0.286277    0.085767    0.012283    0.751617    
#> 480: 0.309240    1.050850    3.469664    0.286380    0.085813    0.012289    0.751681    
#> 481: 0.309223    1.050863    3.469697    0.286327    0.085869    0.012290    0.751714    
#> 482: 0.309357    1.050800    3.469713    0.286367    0.085846    0.012296    0.751752    
#> 483: 0.309453    1.050673    3.469767    0.286338    0.085797    0.012300    0.751736    
#> 484: 0.309467    1.050542    3.469793    0.286359    0.085769    0.012291    0.751749    
#> 485: 0.309510    1.050541    3.469814    0.286417    0.085803    0.012305    0.751703    
#> 486: 0.309589    1.050591    3.469838    0.286422    0.085851    0.012306    0.751635    
#> 487: 0.309816    1.050547    3.469875    0.286520    0.085894    0.012311    0.751624    
#> 488: 0.309800    1.050518    3.469905    0.286551    0.085873    0.012322    0.751606    
#> 489: 0.309917    1.050537    3.469915    0.286606    0.085818    0.012334    0.751664    
#> 490: 0.309943    1.050531    3.469952    0.286730    0.085846    0.012331    0.751702    
#> 491: 0.309979    1.050583    3.470023    0.286737    0.085825    0.012335    0.751710    
#> 492: 0.309997    1.050626    3.470024    0.286713    0.085826    0.012326    0.751809    
#> 493: 0.310007    1.050565    3.470035    0.286758    0.085810    0.012338    0.751785    
#> 494: 0.310032    1.050617    3.470002    0.286627    0.085856    0.012351    0.751769    
#> 495: 0.310102    1.050640    3.470016    0.286444    0.085896    0.012357    0.751737    
#> 496: 0.310246    1.050660    3.470017    0.286544    0.085908    0.012363    0.751768    
#> 497: 0.310204    1.050650    3.470017    0.286470    0.085951    0.012360    0.751759    
#> 498: 0.310202    1.050568    3.469988    0.286360    0.085997    0.012363    0.751733    
#> 499: 0.310267    1.050652    3.469943    0.286340    0.085983    0.012374    0.751717    
#> 500: 0.310206    1.050612    3.469911    0.286273    0.085960    0.012382    0.751702    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.308598    0.978091    3.447474    0.392401    0.083430    0.016800    1.670634    
#> 002: 0.356393    1.008854    3.470234    0.372781    0.079258    0.017073    1.067616    
#> 003: 0.511728    0.958056    3.497181    0.354142    0.075295    0.016220    0.767981    
#> 004: 0.472074    0.968070    3.488297    0.336435    0.071530    0.015409    0.629449    
#> 005: 0.469295    0.977795    3.475975    0.319613    0.067954    0.014638    0.577172    
#> 006: 0.431804    0.989598    3.471181    0.303633    0.064556    0.013906    0.544464    
#> 007: 0.389923    0.994073    3.463245    0.288451    0.065955    0.013796    0.576419    
#> 008: 0.381584    0.992207    3.445990    0.274029    0.062657    0.016729    0.571763    
#> 009: 0.357625    0.977604    3.451586    0.260327    0.059524    0.015893    0.566726    
#> 010: 0.369384    0.979377    3.447877    0.247311    0.056548    0.017557    0.553829    
#> 011: 0.420053    1.000151    3.458303    0.239449    0.055994    0.017145    0.552641    
#> 012: 0.417158    0.997187    3.452811    0.247772    0.055647    0.016680    0.532699    
#> 013: 0.385984    0.994312    3.449157    0.235383    0.058971    0.017465    0.536214    
#> 014: 0.418563    0.987724    3.453301    0.275556    0.056022    0.018451    0.542887    
#> 015: 0.408369    0.996080    3.459443    0.271105    0.053221    0.019582    0.528914    
#> 016: 0.431394    0.992127    3.464033    0.275440    0.050560    0.021900    0.544210    
#> 017: 0.397026    0.992924    3.457751    0.261668    0.049937    0.020805    0.524698    
#> 018: 0.383842    0.999265    3.445898    0.248584    0.047440    0.021124    0.549512    
#> 019: 0.374994    1.002799    3.454008    0.258529    0.052295    0.020186    0.529929    
#> 020: 0.420371    0.992305    3.462469    0.245602    0.051891    0.022123    0.537584    
#> 021: 0.409776    0.992040    3.470691    0.233322    0.049296    0.022310    0.534824    
#> 022: 0.422287    0.977335    3.478668    0.221656    0.046831    0.025202    0.541397    
#> 023: 0.489945    0.974205    3.489285    0.236175    0.048044    0.027017    0.573415    
#> 024: 0.480534    0.996981    3.486252    0.224366    0.055142    0.025666    0.555121    
#> 025: 0.467349    0.978570    3.480287    0.227019    0.061609    0.024383    0.535099    
#> 026: 0.454585    0.980697    3.474360    0.237832    0.058529    0.023164    0.521980    
#> 027: 0.422751    0.978576    3.472046    0.225941    0.055602    0.022005    0.527778    
#> 028: 0.447720    0.983292    3.473538    0.216848    0.055968    0.020905    0.517910    
#> 029: 0.458345    0.973890    3.465552    0.206006    0.053169    0.019860    0.541228    
#> 030: 0.445544    0.992527    3.461316    0.203715    0.050511    0.018867    0.535063    
#> 031: 0.418739    0.982413    3.468303    0.193529    0.049277    0.017924    0.533341    
#> 032: 0.407122    0.962956    3.477369    0.204447    0.048250    0.017027    0.526545    
#> 033: 0.436269    0.980859    3.471205    0.225220    0.046355    0.017317    0.531564    
#> 034: 0.434490    0.990102    3.473791    0.222655    0.053808    0.016451    0.529395    
#> 035: 0.422074    0.989712    3.461658    0.215064    0.057743    0.015628    0.512963    
#> 036: 0.417567    1.008357    3.465707    0.228698    0.054856    0.014847    0.533629    
#> 037: 0.411152    1.005031    3.465151    0.232392    0.052113    0.014105    0.553033    
#> 038: 0.432782    0.997636    3.459219    0.220773    0.052398    0.013399    0.553225    
#> 039: 0.437380    0.997338    3.469714    0.209734    0.054227    0.012729    0.537148    
#> 040: 0.411954    1.006652    3.471491    0.199247    0.066121    0.012093    0.548708    
#> 041: 0.382648    0.989576    3.464792    0.189285    0.063831    0.011488    0.555380    
#> 042: 0.406895    0.988708    3.459931    0.198948    0.060640    0.010914    0.535009    
#> 043: 0.389508    0.997772    3.450832    0.191304    0.071357    0.010368    0.541174    
#> 044: 0.402748    0.996750    3.454264    0.181739    0.067789    0.009850    0.541603    
#> 045: 0.384981    1.003808    3.444426    0.188235    0.067078    0.009357    0.552954    
#> 046: 0.379241    0.993113    3.451824    0.192282    0.063724    0.009646    0.552849    
#> 047: 0.415658    1.005907    3.452117    0.198522    0.060582    0.010748    0.536786    
#> 048: 0.400636    1.009966    3.451809    0.210587    0.058753    0.010837    0.550840    
#> 049: 0.390834    1.009336    3.448013    0.201884    0.056102    0.010609    0.546501    
#> 050: 0.437282    0.983647    3.456487    0.221599    0.058529    0.012655    0.553331    
#> 051: 0.422966    0.980970    3.459633    0.228545    0.055602    0.013148    0.561568    
#> 052: 0.430328    0.984763    3.468665    0.217117    0.052822    0.012491    0.544009    
#> 053: 0.444155    0.987392    3.465474    0.214756    0.058484    0.011866    0.533073    
#> 054: 0.420437    0.982372    3.475152    0.220034    0.066148    0.013208    0.545361    
#> 055: 0.430864    0.976876    3.473240    0.233013    0.068768    0.014435    0.527579    
#> 056: 0.461971    0.960335    3.480694    0.223067    0.067019    0.014091    0.536966    
#> 057: 0.449703    0.975597    3.483810    0.212289    0.075367    0.014807    0.543733    
#> 058: 0.442809    0.989377    3.465526    0.210421    0.071599    0.014066    0.563615    
#> 059: 0.441684    0.954646    3.471426    0.235943    0.068019    0.013363    0.555148    
#> 060: 0.445881    0.961847    3.470124    0.258810    0.064618    0.016764    0.554589    
#> 061: 0.457413    0.980880    3.476378    0.285534    0.066503    0.016774    0.553084    
#> 062: 0.460340    0.994677    3.480846    0.271257    0.077069    0.015935    0.570628    
#> 063: 0.480755    0.960580    3.476099    0.267938    0.073216    0.015138    0.549202    
#> 064: 0.457016    0.977475    3.479338    0.254541    0.075186    0.014381    0.557784    
#> 065: 0.450855    0.974572    3.461127    0.241814    0.071427    0.013662    0.548616    
#> 066: 0.426945    0.997894    3.466752    0.229724    0.067856    0.012979    0.532441    
#> 067: 0.416371    0.980807    3.462820    0.218238    0.064463    0.014284    0.529235    
#> 068: 0.415688    0.977211    3.467627    0.208960    0.061240    0.013925    0.554079    
#> 069: 0.419694    0.989767    3.457130    0.233821    0.058178    0.014216    0.562558    
#> 070: 0.431455    0.977972    3.475661    0.222130    0.066800    0.016090    0.544526    
#> 071: 0.416006    0.980762    3.456142    0.211024    0.076650    0.015285    0.551974    
#> 072: 0.403300    0.958851    3.466896    0.200472    0.076098    0.014521    0.537541    
#> 073: 0.393449    0.982850    3.470616    0.204000    0.072294    0.013795    0.538748    
#> 074: 0.395535    0.965793    3.464650    0.218931    0.068679    0.013279    0.538631    
#> 075: 0.425921    0.958323    3.485695    0.218726    0.067261    0.012615    0.547387    
#> 076: 0.430195    0.975958    3.488976    0.212858    0.063898    0.011984    0.556088    
#> 077: 0.461991    0.967395    3.477973    0.227246    0.065614    0.013078    0.558151    
#> 078: 0.430544    0.990744    3.475103    0.215884    0.064947    0.012883    0.544032    
#> 079: 0.429873    0.978462    3.473551    0.225946    0.064865    0.012953    0.552078    
#> 080: 0.422111    0.985235    3.471905    0.214649    0.061622    0.013530    0.548111    
#> 081: 0.399196    0.996606    3.465850    0.211551    0.058541    0.013029    0.546110    
#> 082: 0.431656    0.973148    3.476150    0.213223    0.055614    0.013120    0.556154    
#> 083: 0.426666    0.991285    3.469328    0.210174    0.054731    0.012464    0.547576    
#> 084: 0.407707    0.989541    3.463659    0.199666    0.052988    0.012173    0.542730    
#> 085: 0.425735    0.995219    3.477915    0.198092    0.061455    0.013093    0.543889    
#> 086: 0.421289    0.999912    3.468120    0.233843    0.058382    0.013930    0.530484    
#> 087: 0.418521    0.993778    3.460871    0.222151    0.055463    0.014711    0.535531    
#> 088: 0.367375    0.992684    3.457432    0.236360    0.052690    0.013976    0.538425    
#> 089: 0.379170    0.995053    3.444961    0.255572    0.056592    0.015904    0.537889    
#> 090: 0.378527    0.991523    3.442476    0.249867    0.053763    0.015323    0.540609    
#> 091: 0.373671    0.993166    3.443612    0.237743    0.051075    0.014557    0.552112    
#> 092: 0.394270    0.999282    3.441724    0.261258    0.048590    0.018029    0.547309    
#> 093: 0.372962    0.997416    3.447536    0.250954    0.050323    0.017501    0.549356    
#> 094: 0.382905    0.997920    3.452004    0.250072    0.054143    0.017870    0.541615    
#> 095: 0.409344    1.011469    3.454568    0.240482    0.051436    0.022810    0.535966    
#> 096: 0.381558    1.008304    3.451008    0.228458    0.048864    0.021670    0.534355    
#> 097: 0.397871    1.019278    3.454779    0.217035    0.046421    0.020586    0.540348    
#> 098: 0.396871    1.013107    3.458879    0.206183    0.044100    0.019557    0.556166    
#> 099: 0.389734    1.003936    3.443382    0.217845    0.041895    0.018579    0.554985    
#> 100: 0.364515    1.004533    3.439252    0.218735    0.050502    0.017650    0.542870    
#> 101: 0.335370    0.996731    3.427193    0.230314    0.047977    0.016768    0.553838    
#> 102: 0.365168    1.000638    3.430515    0.242738    0.045578    0.015929    0.556700    
#> 103: 0.394467    0.991696    3.451603    0.256766    0.054200    0.015133    0.535161    
#> 104: 0.394087    0.986925    3.466292    0.243927    0.051490    0.015879    0.547197    
#> 105: 0.418190    0.981560    3.470577    0.249181    0.066864    0.015661    0.547901    
#> 106: 0.427713    0.983713    3.472608    0.236722    0.063520    0.014878    0.535334    
#> 107: 0.450827    0.980312    3.471659    0.245727    0.060344    0.014134    0.542275    
#> 108: 0.433268    0.988913    3.470581    0.233440    0.057327    0.014902    0.561244    
#> 109: 0.423680    0.979022    3.483168    0.249349    0.055331    0.015063    0.550402    
#> 110: 0.458199    0.954100    3.471419    0.248622    0.062032    0.014310    0.544793    
#> 111: 0.441119    0.972502    3.477260    0.238427    0.063136    0.013595    0.529945    
#> 112: 0.411742    0.959580    3.468889    0.232659    0.073294    0.012915    0.547752    
#> 113: 0.433555    0.983181    3.473537    0.221026    0.069629    0.012269    0.532207    
#> 114: 0.425969    0.989995    3.467844    0.209974    0.067861    0.011656    0.549855    
#> 115: 0.444873    0.973814    3.466138    0.203727    0.075237    0.011073    0.572735    
#> 116: 0.420686    0.972414    3.468856    0.205670    0.071475    0.011797    0.573138    
#> 117: 0.407215    0.990026    3.472640    0.204337    0.070350    0.013151    0.548290    
#> 118: 0.438724    0.969421    3.478680    0.224374    0.066832    0.013527    0.548716    
#> 119: 0.422590    0.984902    3.467963    0.213155    0.064854    0.012850    0.549129    
#> 120: 0.391877    0.984171    3.456732    0.216087    0.061611    0.012208    0.539760    
#> 121: 0.421897    1.016585    3.464545    0.205283    0.058530    0.013144    0.533319    
#> 122: 0.429265    0.994323    3.471323    0.195019    0.055604    0.013560    0.527730    
#> 123: 0.449184    0.996387    3.476093    0.220877    0.055287    0.012937    0.538894    
#> 124: 0.453391    0.992331    3.469591    0.209834    0.058561    0.014794    0.542669    
#> 125: 0.457106    0.990957    3.471699    0.203201    0.060611    0.015166    0.537865    
#> 126: 0.422776    1.002078    3.463229    0.209078    0.059327    0.014408    0.542606    
#> 127: 0.451723    0.996028    3.467959    0.234242    0.056360    0.016247    0.546100    
#> 128: 0.440563    0.971146    3.474946    0.222530    0.058995    0.015435    0.547579    
#> 129: 0.464517    0.977009    3.486212    0.242599    0.072051    0.015944    0.539782    
#> 130: 0.475198    0.983522    3.477463    0.230469    0.068448    0.015620    0.520457    
#> 131: 0.446029    0.971562    3.472246    0.218946    0.065026    0.017909    0.539478    
#> 132: 0.419396    0.990360    3.467821    0.207998    0.065329    0.017013    0.538200    
#> 133: 0.416934    0.980890    3.475549    0.199143    0.069732    0.016163    0.546300    
#> 134: 0.421731    0.967930    3.474037    0.199231    0.066245    0.015354    0.551538    
#> 135: 0.445241    0.962476    3.477079    0.199341    0.065643    0.014587    0.537007    
#> 136: 0.445963    0.953843    3.479833    0.218054    0.064663    0.014742    0.531201    
#> 137: 0.464685    0.961847    3.485920    0.224146    0.061430    0.016506    0.533677    
#> 138: 0.460776    0.954936    3.482354    0.212938    0.058358    0.015799    0.537881    
#> 139: 0.453571    0.971823    3.488099    0.212813    0.061631    0.015927    0.535246    
#> 140: 0.449401    0.987809    3.479129    0.204883    0.058550    0.017645    0.550399    
#> 141: 0.432122    0.964467    3.478254    0.194639    0.055622    0.016762    0.530925    
#> 142: 0.448383    0.968324    3.487702    0.184907    0.052841    0.015924    0.543368    
#> 143: 0.422025    0.989829    3.475079    0.190328    0.053463    0.016384    0.559433    
#> 144: 0.464040    0.975148    3.482704    0.204659    0.053710    0.015564    0.529925    
#> 145: 0.430689    0.995590    3.468170    0.207084    0.051749    0.014792    0.524202    
#> 146: 0.409893    0.981958    3.475320    0.196730    0.053816    0.015617    0.537590    
#> 147: 0.403909    0.979533    3.469942    0.192358    0.051125    0.017985    0.533821    
#> 148: 0.412915    0.975279    3.476254    0.196150    0.049092    0.017511    0.532575    
#> 149: 0.427085    0.974130    3.473193    0.190606    0.055458    0.019500    0.544159    
#> 150: 0.437692    0.975501    3.466216    0.215595    0.054387    0.018525    0.552407    
#> 151: 0.404456    0.993566    3.466414    0.227528    0.054936    0.017599    0.540376    
#> 152: 0.404507    0.997839    3.460897    0.223794    0.052545    0.018035    0.541155    
#> 153: 0.416436    1.004211    3.458469    0.254581    0.055411    0.014857    0.536972    
#> 154: 0.428448    1.002755    3.463145    0.230826    0.055749    0.015543    0.541557    
#> 155: 0.408034    0.991479    3.458241    0.218382    0.055130    0.011935    0.549311    
#> 156: 0.433736    0.992702    3.465774    0.201638    0.055337    0.013990    0.556968    
#> 157: 0.429390    0.999538    3.468216    0.226218    0.065951    0.014482    0.552841    
#> 158: 0.467407    0.990900    3.471949    0.214730    0.065820    0.012221    0.548718    
#> 159: 0.431133    0.991871    3.476580    0.196391    0.052828    0.014389    0.553969    
#> 160: 0.466975    0.967608    3.480148    0.239963    0.056815    0.014166    0.553961    
#> 161: 0.457927    0.984864    3.473487    0.214453    0.064858    0.012052    0.556107    
#> 162: 0.413880    0.987855    3.465919    0.233218    0.066111    0.012506    0.552931    
#> 163: 0.439952    0.982327    3.466727    0.245550    0.061279    0.011504    0.552837    
#> 164: 0.424983    0.986541    3.463867    0.226027    0.063136    0.010466    0.537233    
#> 165: 0.430126    0.977815    3.464933    0.210595    0.057882    0.011965    0.540827    
#> 166: 0.430862    0.995620    3.469706    0.210349    0.072267    0.010389    0.538772    
#> 167: 0.443083    0.993923    3.473402    0.226358    0.058666    0.008482    0.563191    
#> 168: 0.428351    0.985350    3.469745    0.199093    0.065001    0.009432    0.552377    
#> 169: 0.448277    1.001792    3.467296    0.204165    0.058705    0.011277    0.560356    
#> 170: 0.438358    0.992778    3.463508    0.188255    0.053750    0.012205    0.552581    
#> 171: 0.410387    0.992012    3.464198    0.176437    0.059917    0.012182    0.529178    
#> 172: 0.392935    1.000666    3.456469    0.191760    0.052796    0.012897    0.530566    
#> 173: 0.385632    1.012915    3.447130    0.193024    0.054097    0.010011    0.542247    
#> 174: 0.396312    1.015877    3.453759    0.181355    0.057463    0.008691    0.551330    
#> 175: 0.377841    1.010724    3.445399    0.219680    0.073295    0.009523    0.548420    
#> 176: 0.390145    0.999573    3.453006    0.211923    0.067824    0.008475    0.551085    
#> 177: 0.401818    0.990860    3.461830    0.205627    0.057192    0.010169    0.553575    
#> 178: 0.422330    0.984191    3.461018    0.227176    0.058606    0.012588    0.534663    
#> 179: 0.435520    0.998764    3.467647    0.206921    0.053892    0.014044    0.554549    
#> 180: 0.416205    0.980748    3.476372    0.204260    0.053221    0.015131    0.544125    
#> 181: 0.427215    0.979137    3.463390    0.185702    0.056476    0.013560    0.548067    
#> 182: 0.421142    0.990350    3.459346    0.153721    0.061415    0.012525    0.563056    
#> 183: 0.424355    1.001883    3.463248    0.155490    0.048278    0.009967    0.574629    
#> 184: 0.436502    0.993652    3.466797    0.200791    0.049716    0.010413    0.556592    
#> 185: 0.399898    1.007778    3.458858    0.193897    0.045638    0.009187    0.581840    
#> 186: 0.393471    1.017358    3.454930    0.168674    0.055138    0.010585    0.569787    
#> 187: 0.380780    0.993685    3.455595    0.195346    0.056031    0.008678    0.562328    
#> 188: 0.386646    1.008841    3.465141    0.179653    0.063664    0.010846    0.562357    
#> 189: 0.427982    0.994364    3.470028    0.206017    0.071608    0.009963    0.547077    
#> 190: 0.412868    0.998440    3.473754    0.198039    0.061017    0.010123    0.545855    
#> 191: 0.389329    1.014918    3.458450    0.174706    0.064928    0.008181    0.541592    
#> 192: 0.382280    1.014335    3.452771    0.195781    0.056436    0.009666    0.543963    
#> 193: 0.419305    1.006429    3.461595    0.186348    0.055892    0.008692    0.552935    
#> 194: 0.394160    0.995260    3.456959    0.180202    0.069553    0.008680    0.552696    
#> 195: 0.396103    0.992427    3.448581    0.188984    0.062438    0.008467    0.545350    
#> 196: 0.397018    0.985338    3.459358    0.181940    0.069408    0.008142    0.559256    
#> 197: 0.384943    0.991560    3.475828    0.184062    0.061823    0.009662    0.562304    
#> 198: 0.429752    0.989995    3.466968    0.206041    0.055860    0.010484    0.549786    
#> 199: 0.428368    0.990794    3.464792    0.218538    0.068721    0.009033    0.556106    
#> 200: 0.413901    0.992581    3.461597    0.206186    0.072849    0.009619    0.562612    
#> 201: 0.401016    0.994038    3.465165    0.205876    0.068118    0.009821    0.567771    
#> 202: 0.401745    0.993092    3.464480    0.209111    0.068376    0.009747    0.565106    
#> 203: 0.410702    0.992704    3.461747    0.211119    0.067747    0.009653    0.567617    
#> 204: 0.412729    0.992056    3.462456    0.213406    0.070254    0.009936    0.564907    
#> 205: 0.413591    0.994633    3.463964    0.211978    0.072319    0.010139    0.566045    
#> 206: 0.415001    0.995585    3.465380    0.209547    0.071738    0.010240    0.567988    
#> 207: 0.415903    0.993683    3.464741    0.211036    0.069492    0.010173    0.568105    
#> 208: 0.417399    0.993395    3.464446    0.211221    0.067870    0.010314    0.565255    
#> 209: 0.421001    0.990857    3.464277    0.215009    0.066572    0.010457    0.564556    
#> 210: 0.423725    0.988755    3.465178    0.214185    0.066634    0.010641    0.563107    
#> 211: 0.426808    0.988353    3.466332    0.212372    0.065858    0.010772    0.561502    
#> 212: 0.427039    0.987571    3.466354    0.211577    0.064828    0.010807    0.560989    
#> 213: 0.429302    0.986849    3.466835    0.211965    0.064056    0.010860    0.560423    
#> 214: 0.430683    0.985849    3.467215    0.210681    0.063678    0.011029    0.560358    
#> 215: 0.431349    0.984792    3.468132    0.209467    0.063016    0.011220    0.560069    
#> 216: 0.433124    0.985022    3.468396    0.207607    0.063178    0.011280    0.561394    
#> 217: 0.433201    0.985029    3.468565    0.206955    0.063077    0.011362    0.560371    
#> 218: 0.432787    0.985293    3.468601    0.205777    0.062861    0.011359    0.559592    
#> 219: 0.432129    0.985113    3.468065    0.204243    0.063333    0.011333    0.559134    
#> 220: 0.429477    0.985676    3.467653    0.202402    0.063791    0.011355    0.558913    
#> 221: 0.427901    0.985993    3.467199    0.200903    0.064036    0.011302    0.558453    
#> 222: 0.426899    0.986068    3.466792    0.198704    0.064326    0.011349    0.558890    
#> 223: 0.427192    0.986108    3.466908    0.197262    0.064877    0.011391    0.558520    
#> 224: 0.427694    0.986464    3.467121    0.196820    0.065170    0.011399    0.557975    
#> 225: 0.427352    0.985106    3.467574    0.196048    0.065434    0.011396    0.557961    
#> 226: 0.427270    0.984861    3.467449    0.195854    0.065477    0.011353    0.557560    
#> 227: 0.427194    0.984901    3.467687    0.196156    0.065754    0.011363    0.557195    
#> 228: 0.426929    0.985441    3.467359    0.196819    0.066010    0.011436    0.556786    
#> 229: 0.426230    0.984793    3.467136    0.197533    0.065954    0.011430    0.556155    
#> 230: 0.425674    0.984665    3.466906    0.197759    0.065974    0.011409    0.555953    
#> 231: 0.425077    0.985078    3.466597    0.197925    0.065950    0.011405    0.555521    
#> 232: 0.423791    0.985165    3.466450    0.197657    0.065919    0.011396    0.555313    
#> 233: 0.423562    0.984766    3.466473    0.198111    0.065901    0.011378    0.555083    
#> 234: 0.423269    0.984492    3.466488    0.197411    0.066114    0.011353    0.554783    
#> 235: 0.423062    0.984158    3.466479    0.196972    0.065946    0.011319    0.554801    
#> 236: 0.423140    0.984233    3.466453    0.196672    0.065850    0.011301    0.554986    
#> 237: 0.423600    0.984445    3.466596    0.196136    0.066056    0.011364    0.555027    
#> 238: 0.423998    0.984677    3.466486    0.194958    0.066215    0.011399    0.555277    
#> 239: 0.423502    0.985493    3.466328    0.193807    0.066182    0.011410    0.555343    
#> 240: 0.423389    0.985398    3.466560    0.193360    0.066331    0.011432    0.555031    
#> 241: 0.423596    0.984785    3.466717    0.193060    0.065875    0.011483    0.555041    
#> 242: 0.423391    0.984534    3.466739    0.193488    0.065778    0.011573    0.555097    
#> 243: 0.422852    0.984837    3.466562    0.193876    0.065609    0.011650    0.555046    
#> 244: 0.422162    0.985182    3.466596    0.193691    0.065420    0.011706    0.555036    
#> 245: 0.422175    0.984791    3.466710    0.194042    0.064996    0.011752    0.555236    
#> 246: 0.422277    0.984918    3.466790    0.193965    0.064813    0.011826    0.554977    
#> 247: 0.422687    0.984669    3.466990    0.193574    0.064545    0.011859    0.554980    
#> 248: 0.423145    0.984857    3.467195    0.193318    0.064303    0.011921    0.554899    
#> 249: 0.423143    0.984894    3.467244    0.193657    0.064096    0.012025    0.554587    
#> 250: 0.423548    0.985174    3.467309    0.194315    0.063893    0.012120    0.554543    
#> 251: 0.423992    0.985552    3.467418    0.194933    0.063822    0.012163    0.554421    
#> 252: 0.424728    0.985764    3.467627    0.195264    0.063855    0.012207    0.554228    
#> 253: 0.424566    0.986154    3.467649    0.195783    0.063875    0.012249    0.554098    
#> 254: 0.424551    0.986410    3.467650    0.196057    0.063999    0.012286    0.553751    
#> 255: 0.424574    0.986680    3.467727    0.196690    0.063914    0.012359    0.553333    
#> 256: 0.424755    0.986704    3.467641    0.197376    0.063814    0.012420    0.553168    
#> 257: 0.424559    0.986544    3.467588    0.197376    0.063650    0.012471    0.553083    
#> 258: 0.424080    0.986382    3.467447    0.197977    0.063415    0.012486    0.553096    
#> 259: 0.424070    0.986529    3.467320    0.198808    0.063351    0.012502    0.552850    
#> 260: 0.423756    0.986718    3.467251    0.199383    0.063182    0.012481    0.552725    
#> 261: 0.423603    0.986621    3.467273    0.199524    0.063109    0.012462    0.552793    
#> 262: 0.423428    0.986799    3.467262    0.199336    0.063265    0.012471    0.552721    
#> 263: 0.423550    0.986865    3.467273    0.199519    0.063307    0.012491    0.552667    
#> 264: 0.423382    0.986994    3.467145    0.199799    0.063291    0.012484    0.552830    
#> 265: 0.422973    0.986994    3.467039    0.199609    0.063349    0.012462    0.552854    
#> 266: 0.422914    0.987105    3.467034    0.199396    0.063473    0.012417    0.552756    
#> 267: 0.423033    0.987193    3.467194    0.199323    0.063521    0.012420    0.552674    
#> 268: 0.423106    0.987038    3.467167    0.199221    0.063503    0.012424    0.552618    
#> 269: 0.423909    0.986867    3.467231    0.199284    0.063433    0.012425    0.552740    
#> 270: 0.424024    0.986900    3.467186    0.199249    0.063469    0.012435    0.552776    
#> 271: 0.424175    0.986815    3.467122    0.199625    0.063452    0.012434    0.552789    
#> 272: 0.424382    0.986573    3.467112    0.199757    0.063504    0.012425    0.552948    
#> 273: 0.424290    0.986650    3.467247    0.199544    0.063638    0.012449    0.552917    
#> 274: 0.424291    0.986590    3.467353    0.199469    0.063729    0.012415    0.552883    
#> 275: 0.424367    0.986640    3.467288    0.199183    0.063798    0.012415    0.552854    
#> 276: 0.424409    0.986978    3.467392    0.199296    0.063757    0.012434    0.552637    
#> 277: 0.424235    0.987125    3.467539    0.199382    0.063642    0.012454    0.552401    
#> 278: 0.423940    0.987257    3.467592    0.199427    0.063720    0.012463    0.552208    
#> 279: 0.424103    0.987181    3.467672    0.199634    0.063899    0.012509    0.552359    
#> 280: 0.424229    0.987232    3.467717    0.199675    0.063846    0.012530    0.552284    
#> 281: 0.423955    0.987397    3.467654    0.200012    0.063683    0.012556    0.552020    
#> 282: 0.423935    0.987372    3.467713    0.200482    0.063719    0.012576    0.551887    
#> 283: 0.424182    0.987363    3.467798    0.201185    0.063549    0.012666    0.552049    
#> 284: 0.424160    0.987195    3.467807    0.201673    0.063379    0.012733    0.551961    
#> 285: 0.423958    0.987369    3.467673    0.202218    0.063225    0.012802    0.551942    
#> 286: 0.423914    0.987506    3.467577    0.202710    0.063071    0.012855    0.551797    
#> 287: 0.423677    0.987720    3.467379    0.203232    0.062973    0.012900    0.551632    
#> 288: 0.423873    0.987790    3.467340    0.203636    0.062825    0.012932    0.551771    
#> 289: 0.424073    0.987801    3.467332    0.203520    0.062737    0.012926    0.551693    
#> 290: 0.424233    0.987657    3.467440    0.203302    0.062636    0.012936    0.551703    
#> 291: 0.424519    0.987643    3.467554    0.203199    0.062681    0.012921    0.551522    
#> 292: 0.424511    0.987527    3.467538    0.203280    0.062621    0.012910    0.551578    
#> 293: 0.424498    0.987415    3.467530    0.203314    0.062616    0.012905    0.551578    
#> 294: 0.424479    0.987371    3.467520    0.203739    0.062563    0.012909    0.551606    
#> 295: 0.424336    0.987178    3.467477    0.203730    0.062483    0.012907    0.551486    
#> 296: 0.424138    0.987052    3.467438    0.203579    0.062439    0.012907    0.551510    
#> 297: 0.423930    0.987196    3.467311    0.203610    0.062410    0.012897    0.551470    
#> 298: 0.423774    0.987288    3.467243    0.203645    0.062345    0.012898    0.551412    
#> 299: 0.423693    0.987442    3.467148    0.203528    0.062244    0.012898    0.551294    
#> 300: 0.423810    0.987363    3.467146    0.203678    0.062252    0.012875    0.551138    
#> 301: 0.423993    0.987229    3.467089    0.203536    0.062343    0.012850    0.551158    
#> 302: 0.423899    0.987238    3.467039    0.203644    0.062410    0.012820    0.551070    
#> 303: 0.423801    0.987222    3.466928    0.203872    0.062340    0.012832    0.550914    
#> 304: 0.423613    0.987501    3.466829    0.204411    0.062269    0.012857    0.550878    
#> 305: 0.423442    0.987347    3.466759    0.204694    0.062194    0.012902    0.550731    
#> 306: 0.423093    0.987409    3.466654    0.204929    0.062121    0.012926    0.550670    
#> 307: 0.422943    0.987306    3.466600    0.205047    0.062135    0.012931    0.550625    
#> 308: 0.422507    0.987328    3.466521    0.205309    0.062213    0.012919    0.550597    
#> 309: 0.422292    0.987144    3.466453    0.205411    0.062107    0.012923    0.550765    
#> 310: 0.422362    0.987044    3.466374    0.205396    0.062023    0.012920    0.550738    
#> 311: 0.422149    0.987169    3.466280    0.205630    0.062023    0.012915    0.550673    
#> 312: 0.421760    0.987343    3.466104    0.205575    0.061982    0.012912    0.550743    
#> 313: 0.421434    0.987260    3.465975    0.205530    0.061977    0.012915    0.550971    
#> 314: 0.420902    0.987377    3.465749    0.205589    0.061953    0.012919    0.551042    
#> 315: 0.420517    0.987609    3.465541    0.205873    0.061897    0.012937    0.551127    
#> 316: 0.420397    0.987881    3.465431    0.206027    0.061875    0.012936    0.551140    
#> 317: 0.420361    0.987904    3.465424    0.205976    0.061867    0.012955    0.551245    
#> 318: 0.420261    0.988021    3.465332    0.205943    0.061848    0.012981    0.551232    
#> 319: 0.419995    0.988004    3.465355    0.205678    0.061885    0.012972    0.551334    
#> 320: 0.419778    0.987909    3.465303    0.205792    0.061879    0.012969    0.551457    
#> 321: 0.419539    0.988009    3.465197    0.205970    0.061882    0.012978    0.551609    
#> 322: 0.419460    0.988023    3.465098    0.205833    0.061888    0.012948    0.551644    
#> 323: 0.419136    0.988018    3.465064    0.205705    0.061815    0.012926    0.551577    
#> 324: 0.419051    0.988093    3.465091    0.205653    0.061811    0.012922    0.551386    
#> 325: 0.418923    0.988188    3.465016    0.205465    0.061812    0.012918    0.551298    
#> 326: 0.418881    0.988109    3.465002    0.205263    0.061822    0.012922    0.551221    
#> 327: 0.419152    0.988117    3.465082    0.205298    0.061944    0.012920    0.551223    
#> 328: 0.419455    0.988209    3.465119    0.205423    0.062043    0.012938    0.551159    
#> 329: 0.419777    0.988182    3.465197    0.205458    0.062050    0.012945    0.551059    
#> 330: 0.419819    0.988203    3.465269    0.205520    0.062004    0.012956    0.550989    
#> 331: 0.419990    0.988251    3.465348    0.205243    0.062023    0.012961    0.550970    
#> 332: 0.420008    0.988199    3.465471    0.204953    0.061947    0.012961    0.551102    
#> 333: 0.419882    0.988177    3.465447    0.205005    0.061970    0.012948    0.551124    
#> 334: 0.419581    0.988054    3.465353    0.205022    0.061907    0.012939    0.551196    
#> 335: 0.419271    0.988134    3.465264    0.204838    0.061932    0.012935    0.551202    
#> 336: 0.418689    0.988351    3.465123    0.204610    0.061936    0.012933    0.551237    
#> 337: 0.418551    0.988557    3.464997    0.204824    0.061944    0.012932    0.551209    
#> 338: 0.418433    0.988707    3.464951    0.204863    0.061909    0.012946    0.551233    
#> 339: 0.418150    0.988801    3.464836    0.204750    0.061851    0.012959    0.551221    
#> 340: 0.418183    0.988698    3.464824    0.204939    0.061828    0.012965    0.551202    
#> 341: 0.418298    0.988764    3.464845    0.205031    0.061809    0.012983    0.551126    
#> 342: 0.418152    0.988684    3.464819    0.205051    0.061791    0.012975    0.551011    
#> 343: 0.417880    0.988720    3.464798    0.205115    0.061761    0.012977    0.550950    
#> 344: 0.417952    0.988648    3.464822    0.205208    0.061741    0.012993    0.550983    
#> 345: 0.417932    0.988627    3.464814    0.205265    0.061746    0.013028    0.550983    
#> 346: 0.417906    0.988674    3.464723    0.205366    0.061691    0.013050    0.550926    
#> 347: 0.417870    0.988674    3.464636    0.205432    0.061583    0.013106    0.550974    
#> 348: 0.417607    0.988761    3.464572    0.205421    0.061542    0.013131    0.550889    
#> 349: 0.417439    0.988629    3.464561    0.205468    0.061537    0.013140    0.550762    
#> 350: 0.417316    0.988560    3.464537    0.205466    0.061523    0.013130    0.550611    
#> 351: 0.417286    0.988711    3.464462    0.205538    0.061523    0.013137    0.550470    
#> 352: 0.417004    0.988933    3.464353    0.205776    0.061524    0.013161    0.550519    
#> 353: 0.416888    0.989221    3.464237    0.206054    0.061458    0.013192    0.550512    
#> 354: 0.416859    0.989386    3.464116    0.206269    0.061385    0.013232    0.550464    
#> 355: 0.416966    0.989400    3.464022    0.206537    0.061345    0.013249    0.550387    
#> 356: 0.416863    0.989436    3.464029    0.206768    0.061357    0.013247    0.550423    
#> 357: 0.416971    0.989491    3.464033    0.207176    0.061339    0.013243    0.550392    
#> 358: 0.416915    0.989518    3.464034    0.207223    0.061231    0.013257    0.550274    
#> 359: 0.416868    0.989563    3.464020    0.207152    0.061239    0.013262    0.550167    
#> 360: 0.416710    0.989581    3.463950    0.207143    0.061237    0.013261    0.550118    
#> 361: 0.416659    0.989544    3.463918    0.207196    0.061267    0.013262    0.550097    
#> 362: 0.416831    0.989507    3.463941    0.207333    0.061249    0.013268    0.549944    
#> 363: 0.416922    0.989433    3.463971    0.207474    0.061206    0.013281    0.549767    
#> 364: 0.417157    0.989377    3.464018    0.207534    0.061163    0.013301    0.549738    
#> 365: 0.417260    0.989265    3.464071    0.207450    0.061070    0.013323    0.549712    
#> 366: 0.417519    0.989276    3.464067    0.207399    0.061057    0.013337    0.549716    
#> 367: 0.417666    0.989246    3.464063    0.207235    0.061072    0.013337    0.549681    
#> 368: 0.417889    0.989352    3.464070    0.207395    0.061053    0.013338    0.549572    
#> 369: 0.417822    0.989326    3.464036    0.207390    0.061055    0.013335    0.549541    
#> 370: 0.417683    0.989398    3.464028    0.207259    0.061041    0.013329    0.549561    
#> 371: 0.417619    0.989536    3.463963    0.207218    0.061027    0.013335    0.549508    
#> 372: 0.417524    0.989541    3.463956    0.207177    0.061033    0.013340    0.549529    
#> 373: 0.417282    0.989666    3.463864    0.207258    0.061087    0.013345    0.549503    
#> 374: 0.417259    0.989759    3.463780    0.207317    0.061109    0.013338    0.549476    
#> 375: 0.417233    0.989770    3.463737    0.207363    0.061145    0.013334    0.549482    
#> 376: 0.417218    0.989863    3.463729    0.207323    0.061189    0.013310    0.549378    
#> 377: 0.417065    0.989940    3.463670    0.207373    0.061184    0.013307    0.549314    
#> 378: 0.416876    0.990029    3.463608    0.207558    0.061164    0.013311    0.549255    
#> 379: 0.416703    0.989951    3.463571    0.207762    0.061169    0.013316    0.549148    
#> 380: 0.416535    0.989984    3.463530    0.207844    0.061165    0.013324    0.549147    
#> 381: 0.416404    0.989938    3.463488    0.207843    0.061108    0.013333    0.549154    
#> 382: 0.416301    0.989959    3.463450    0.207734    0.061104    0.013343    0.549068    
#> 383: 0.416421    0.989986    3.463440    0.207635    0.061058    0.013349    0.549002    
#> 384: 0.416361    0.989981    3.463495    0.207503    0.061026    0.013367    0.548980    
#> 385: 0.416451    0.989922    3.463541    0.207524    0.060973    0.013392    0.548910    
#> 386: 0.416563    0.989960    3.463572    0.207605    0.060882    0.013411    0.548939    
#> 387: 0.416702    0.990032    3.463623    0.207675    0.060812    0.013431    0.548896    
#> 388: 0.416890    0.990114    3.463671    0.207718    0.060756    0.013444    0.548823    
#> 389: 0.416980    0.989958    3.463722    0.207737    0.060691    0.013455    0.548837    
#> 390: 0.417021    0.989955    3.463734    0.207753    0.060643    0.013457    0.548791    
#> 391: 0.417137    0.989940    3.463776    0.207770    0.060643    0.013456    0.548773    
#> 392: 0.417056    0.989903    3.463805    0.207783    0.060658    0.013457    0.548801    
#> 393: 0.417001    0.989894    3.463768    0.207797    0.060702    0.013450    0.548774    
#> 394: 0.417055    0.989829    3.463760    0.207821    0.060698    0.013444    0.548842    
#> 395: 0.417217    0.989848    3.463785    0.207763    0.060687    0.013437    0.548905    
#> 396: 0.417402    0.989798    3.463831    0.207805    0.060666    0.013434    0.548875    
#> 397: 0.417587    0.989726    3.463891    0.207794    0.060657    0.013421    0.548927    
#> 398: 0.417755    0.989587    3.463909    0.207730    0.060694    0.013405    0.549010    
#> 399: 0.417794    0.989551    3.463956    0.207652    0.060684    0.013391    0.548991    
#> 400: 0.417844    0.989531    3.464015    0.207569    0.060680    0.013390    0.549003    
#> 401: 0.417824    0.989566    3.464052    0.207498    0.060653    0.013394    0.549068    
#> 402: 0.417916    0.989612    3.464094    0.207390    0.060572    0.013418    0.549083    
#> 403: 0.418096    0.989561    3.464136    0.207361    0.060532    0.013435    0.549043    
#> 404: 0.418232    0.989573    3.464135    0.207429    0.060453    0.013454    0.549020    
#> 405: 0.418323    0.989568    3.464181    0.207420    0.060387    0.013470    0.549028    
#> 406: 0.418338    0.989661    3.464160    0.207424    0.060400    0.013484    0.549038    
#> 407: 0.418431    0.989614    3.464226    0.207505    0.060417    0.013492    0.548984    
#> 408: 0.418587    0.989607    3.464229    0.207622    0.060438    0.013496    0.548924    
#> 409: 0.418542    0.989542    3.464180    0.207755    0.060438    0.013493    0.548825    
#> 410: 0.418436    0.989566    3.464127    0.207788    0.060458    0.013484    0.548800    
#> 411: 0.418327    0.989444    3.464114    0.207856    0.060486    0.013476    0.548765    
#> 412: 0.418359    0.989468    3.464113    0.207867    0.060497    0.013472    0.548723    
#> 413: 0.418368    0.989507    3.464108    0.207815    0.060520    0.013464    0.548753    
#> 414: 0.418237    0.989488    3.464119    0.207980    0.060520    0.013459    0.548736    
#> 415: 0.418387    0.989438    3.464129    0.208112    0.060495    0.013458    0.548697    
#> 416: 0.418516    0.989426    3.464184    0.208212    0.060509    0.013456    0.548647    
#> 417: 0.418621    0.989375    3.464202    0.208361    0.060521    0.013445    0.548642    
#> 418: 0.418667    0.989367    3.464235    0.208500    0.060538    0.013433    0.548598    
#> 419: 0.418681    0.989367    3.464282    0.208500    0.060519    0.013424    0.548635    
#> 420: 0.418827    0.989295    3.464330    0.208492    0.060483    0.013418    0.548632    
#> 421: 0.418794    0.989293    3.464361    0.208466    0.060507    0.013416    0.548596    
#> 422: 0.418988    0.989175    3.464408    0.208584    0.060514    0.013430    0.548558    
#> 423: 0.419219    0.989076    3.464444    0.208662    0.060533    0.013440    0.548551    
#> 424: 0.419234    0.989000    3.464448    0.208726    0.060505    0.013431    0.548590    
#> 425: 0.419313    0.988992    3.464442    0.208865    0.060490    0.013423    0.548604    
#> 426: 0.419427    0.989036    3.464453    0.208881    0.060467    0.013418    0.548566    
#> 427: 0.419359    0.989058    3.464481    0.208925    0.060464    0.013430    0.548428    
#> 428: 0.419235    0.989127    3.464481    0.208808    0.060433    0.013432    0.548442    
#> 429: 0.419268    0.989122    3.464495    0.208779    0.060392    0.013433    0.548445    
#> 430: 0.419300    0.989157    3.464517    0.208725    0.060358    0.013439    0.548417    
#> 431: 0.419333    0.989170    3.464517    0.208686    0.060333    0.013439    0.548345    
#> 432: 0.419288    0.989244    3.464532    0.208700    0.060288    0.013449    0.548296    
#> 433: 0.419312    0.989288    3.464555    0.208627    0.060256    0.013462    0.548293    
#> 434: 0.419187    0.989232    3.464533    0.208624    0.060246    0.013469    0.548258    
#> 435: 0.419275    0.989233    3.464523    0.208609    0.060225    0.013468    0.548209    
#> 436: 0.419350    0.989140    3.464575    0.208602    0.060184    0.013468    0.548216    
#> 437: 0.419450    0.989010    3.464611    0.208655    0.060124    0.013471    0.548200    
#> 438: 0.419506    0.989132    3.464610    0.208625    0.060121    0.013464    0.548181    
#> 439: 0.419482    0.989151    3.464634    0.208592    0.060159    0.013453    0.548141    
#> 440: 0.419525    0.989133    3.464640    0.208625    0.060219    0.013445    0.548169    
#> 441: 0.419509    0.989127    3.464618    0.208709    0.060247    0.013436    0.548137    
#> 442: 0.419411    0.989171    3.464633    0.208800    0.060276    0.013432    0.548128    
#> 443: 0.419279    0.989281    3.464560    0.208772    0.060274    0.013426    0.548155    
#> 444: 0.419122    0.989454    3.464474    0.208668    0.060248    0.013425    0.548178    
#> 445: 0.418970    0.989546    3.464414    0.208614    0.060233    0.013434    0.548193    
#> 446: 0.418735    0.989648    3.464360    0.208521    0.060182    0.013430    0.548179    
#> 447: 0.418650    0.989690    3.464344    0.208458    0.060142    0.013435    0.548137    
#> 448: 0.418531    0.989693    3.464347    0.208360    0.060125    0.013430    0.548059    
#> 449: 0.418507    0.989747    3.464409    0.208148    0.060127    0.013423    0.548093    
#> 450: 0.418558    0.989682    3.464429    0.208054    0.060073    0.013419    0.548151    
#> 451: 0.418572    0.989683    3.464441    0.208136    0.060042    0.013413    0.548200    
#> 452: 0.418570    0.989738    3.464453    0.207976    0.060028    0.013402    0.548241    
#> 453: 0.418461    0.989788    3.464435    0.207753    0.060020    0.013381    0.548262    
#> 454: 0.418335    0.989892    3.464413    0.207689    0.060045    0.013369    0.548253    
#> 455: 0.418261    0.989977    3.464366    0.207596    0.060044    0.013364    0.548261    
#> 456: 0.418125    0.989979    3.464321    0.207669    0.059997    0.013368    0.548218    
#> 457: 0.418078    0.989967    3.464322    0.207755    0.059980    0.013369    0.548162    
#> 458: 0.417998    0.990115    3.464307    0.207855    0.059970    0.013361    0.548154    
#> 459: 0.417846    0.990236    3.464293    0.207890    0.059979    0.013355    0.548212    
#> 460: 0.417644    0.990275    3.464240    0.207880    0.059961    0.013347    0.548223    
#> 461: 0.417588    0.990335    3.464221    0.207793    0.059958    0.013344    0.548230    
#> 462: 0.417502    0.990405    3.464191    0.207716    0.059966    0.013350    0.548253    
#> 463: 0.417492    0.990476    3.464176    0.207645    0.059979    0.013346    0.548282    
#> 464: 0.417534    0.990529    3.464155    0.207553    0.059974    0.013347    0.548284    
#> 465: 0.417553    0.990393    3.464153    0.207490    0.059969    0.013340    0.548310    
#> 466: 0.417620    0.990381    3.464142    0.207407    0.059937    0.013330    0.548340    
#> 467: 0.417569    0.990359    3.464173    0.207375    0.059912    0.013326    0.548267    
#> 468: 0.417679    0.990347    3.464217    0.207529    0.059924    0.013320    0.548231    
#> 469: 0.417771    0.990393    3.464265    0.207588    0.059897    0.013327    0.548205    
#> 470: 0.417780    0.990441    3.464268    0.207533    0.059901    0.013327    0.548140    
#> 471: 0.417764    0.990416    3.464268    0.207591    0.059876    0.013320    0.548094    
#> 472: 0.417850    0.990408    3.464283    0.207650    0.059882    0.013320    0.548052    
#> 473: 0.417811    0.990421    3.464283    0.207624    0.059874    0.013315    0.547995    
#> 474: 0.417801    0.990395    3.464285    0.207596    0.059879    0.013310    0.548048    
#> 475: 0.417761    0.990474    3.464267    0.207508    0.059862    0.013311    0.548061    
#> 476: 0.417801    0.990468    3.464261    0.207547    0.059876    0.013305    0.548166    
#> 477: 0.417823    0.990487    3.464308    0.207519    0.059898    0.013308    0.548122    
#> 478: 0.417799    0.990463    3.464337    0.207435    0.059878    0.013307    0.548153    
#> 479: 0.417925    0.990467    3.464367    0.207390    0.059883    0.013308    0.548166    
#> 480: 0.417993    0.990475    3.464388    0.207382    0.059939    0.013312    0.548191    
#> 481: 0.417984    0.990440    3.464399    0.207354    0.059967    0.013317    0.548247    
#> 482: 0.418024    0.990439    3.464387    0.207402    0.059965    0.013319    0.548258    
#> 483: 0.418021    0.990357    3.464386    0.207410    0.059941    0.013314    0.548270    
#> 484: 0.418020    0.990236    3.464414    0.207460    0.059942    0.013314    0.548259    
#> 485: 0.418013    0.990227    3.464433    0.207588    0.059961    0.013317    0.548231    
#> 486: 0.418060    0.990215    3.464466    0.207670    0.059963    0.013320    0.548202    
#> 487: 0.418166    0.990175    3.464513    0.207780    0.059978    0.013322    0.548167    
#> 488: 0.418123    0.990134    3.464522    0.207781    0.059970    0.013321    0.548146    
#> 489: 0.418094    0.990157    3.464480    0.207776    0.059964    0.013331    0.548115    
#> 490: 0.418131    0.990212    3.464466    0.207892    0.059958    0.013330    0.548045    
#> 491: 0.418143    0.990271    3.464504    0.207856    0.059954    0.013334    0.547998    
#> 492: 0.418142    0.990299    3.464497    0.207833    0.059944    0.013330    0.548028    
#> 493: 0.418132    0.990304    3.464502    0.207803    0.059918    0.013345    0.548050    
#> 494: 0.418180    0.990354    3.464483    0.207747    0.059884    0.013344    0.548056    
#> 495: 0.418277    0.990378    3.464492    0.207786    0.059855    0.013352    0.548049    
#> 496: 0.418397    0.990447    3.464467    0.207890    0.059858    0.013354    0.548075    
#> 497: 0.418373    0.990481    3.464468    0.207941    0.059877    0.013353    0.548080    
#> 498: 0.418424    0.990496    3.464489    0.207990    0.059884    0.013358    0.548012    
#> 499: 0.418487    0.990471    3.464495    0.208039    0.059880    0.013363    0.547926    
#> 500: 0.418537    0.990415    3.464486    0.208025    0.059872    0.013365    0.547856    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.306394    0.978653    3.446515    0.392401    0.087389    0.016800    1.621585    
#> 002: 0.341761    1.049591    3.478211    0.372781    0.083019    0.017224    1.092885    
#> 003: 0.545137    1.020304    3.523359    0.354142    0.078868    0.016363    0.810477    
#> 004: 0.537442    1.050345    3.530292    0.336435    0.074925    0.016135    0.718624    
#> 005: 0.577977    1.086881    3.524538    0.319613    0.071178    0.015328    0.665351    
#> 006: 0.522534    1.092182    3.508308    0.303633    0.067620    0.014561    0.640149    
#> 007: 0.475387    1.102592    3.501555    0.288451    0.064239    0.013833    0.633377    
#> 008: 0.487727    1.096288    3.494204    0.274029    0.061027    0.015209    0.627404    
#> 009: 0.437989    1.084133    3.486740    0.260327    0.057975    0.015121    0.622881    
#> 010: 0.447031    1.095989    3.496907    0.247311    0.055077    0.017374    0.626578    
#> 011: 0.505897    1.096487    3.503654    0.245341    0.052323    0.018584    0.638084    
#> 012: 0.495799    1.101416    3.495219    0.233074    0.049707    0.019142    0.624547    
#> 013: 0.473186    1.102170    3.492286    0.241224    0.047221    0.018824    0.615872    
#> 014: 0.523111    1.105046    3.495760    0.276553    0.044860    0.020590    0.621853    
#> 015: 0.505791    1.118217    3.498783    0.282617    0.042617    0.019561    0.620250    
#> 016: 0.507377    1.134872    3.503746    0.279957    0.040486    0.021653    0.633902    
#> 017: 0.474915    1.123810    3.496779    0.265959    0.038462    0.021125    0.621549    
#> 018: 0.491555    1.129737    3.478792    0.264018    0.036539    0.020944    0.624292    
#> 019: 0.401163    1.141029    3.468971    0.250817    0.034712    0.019914    0.624737    
#> 020: 0.438821    1.127497    3.488718    0.238276    0.032976    0.024870    0.614704    
#> 021: 0.459624    1.124468    3.488033    0.226362    0.032592    0.023627    0.617401    
#> 022: 0.466745    1.121577    3.498226    0.215044    0.030963    0.023053    0.602641    
#> 023: 0.536631    1.106568    3.506012    0.213897    0.029414    0.022689    0.617683    
#> 024: 0.536341    1.127810    3.506511    0.203202    0.027944    0.021554    0.621810    
#> 025: 0.491257    1.102867    3.507714    0.203999    0.028510    0.020977    0.626247    
#> 026: 0.460609    1.121743    3.486903    0.200309    0.027084    0.022700    0.606844    
#> 027: 0.483954    1.132265    3.488288    0.217935    0.025730    0.026566    0.607373    
#> 028: 0.500613    1.124828    3.495599    0.224988    0.024500    0.025237    0.611473    
#> 029: 0.508199    1.102194    3.499419    0.252719    0.026386    0.023975    0.645487    
#> 030: 0.507009    1.122969    3.489007    0.250847    0.025067    0.024082    0.624561    
#> 031: 0.456324    1.116172    3.493572    0.238304    0.025693    0.023426    0.624557    
#> 032: 0.465727    1.110405    3.498056    0.226389    0.031193    0.022255    0.624661    
#> 033: 0.434249    1.140050    3.476016    0.215070    0.029633    0.021142    0.635017    
#> 034: 0.471081    1.133850    3.489507    0.212668    0.028152    0.020085    0.607764    
#> 035: 0.416284    1.118458    3.475006    0.205989    0.026744    0.019081    0.614912    
#> 036: 0.422917    1.126730    3.469785    0.195690    0.025407    0.018127    0.615854    
#> 037: 0.450131    1.133770    3.476877    0.185905    0.024136    0.017692    0.648162    
#> 038: 0.492574    1.128838    3.486868    0.204957    0.022930    0.019423    0.646195    
#> 039: 0.477268    1.119071    3.488661    0.194709    0.021783    0.019865    0.617418    
#> 040: 0.450167    1.113545    3.496859    0.206319    0.021005    0.019709    0.614905    
#> 041: 0.468079    1.100782    3.491697    0.196003    0.020636    0.019953    0.633954    
#> 042: 0.516694    1.094733    3.495897    0.209244    0.022729    0.023497    0.629424    
#> 043: 0.467848    1.110762    3.491254    0.210468    0.024525    0.022322    0.632514    
#> 044: 0.457835    1.127078    3.492935    0.199945    0.023488    0.021206    0.628405    
#> 045: 0.433427    1.129754    3.476923    0.199340    0.023954    0.020146    0.630481    
#> 046: 0.446984    1.118531    3.483892    0.189373    0.022756    0.019139    0.620193    
#> 047: 0.485719    1.123579    3.491353    0.179905    0.024822    0.018182    0.617091    
#> 048: 0.489946    1.112883    3.491610    0.187030    0.026764    0.018474    0.638454    
#> 049: 0.459301    1.092710    3.496611    0.191746    0.025425    0.022941    0.636444    
#> 050: 0.534422    1.086373    3.515196    0.220133    0.024154    0.026262    0.649455    
#> 051: 0.522562    1.081602    3.511725    0.216131    0.022946    0.029367    0.656514    
#> 052: 0.553830    1.082420    3.529364    0.238480    0.021799    0.027899    0.625282    
#> 053: 0.547745    1.069953    3.519492    0.273160    0.020709    0.026504    0.620608    
#> 054: 0.499148    1.084672    3.505608    0.259502    0.023952    0.027040    0.616383    
#> 055: 0.507043    1.097169    3.512374    0.258438    0.024877    0.030527    0.612693    
#> 056: 0.508426    1.103128    3.502236    0.270497    0.023828    0.029551    0.606375    
#> 057: 0.506849    1.096844    3.509583    0.259859    0.022636    0.028128    0.616750    
#> 058: 0.501530    1.104842    3.494400    0.246866    0.021504    0.026722    0.617058    
#> 059: 0.506839    1.073108    3.510414    0.234523    0.022289    0.031740    0.620896    
#> 060: 0.521808    1.066520    3.516803    0.236511    0.021174    0.031912    0.636152    
#> 061: 0.534529    1.082866    3.518054    0.307765    0.021328    0.031096    0.634400    
#> 062: 0.519272    1.093862    3.504668    0.292376    0.030056    0.029541    0.630577    
#> 063: 0.535759    1.079122    3.502479    0.277758    0.028553    0.028736    0.631422    
#> 064: 0.495821    1.098568    3.504672    0.263870    0.029464    0.027299    0.629722    
#> 065: 0.514687    1.097968    3.486220    0.250676    0.030214    0.025934    0.628382    
#> 066: 0.484621    1.103793    3.501316    0.238142    0.028704    0.024638    0.625856    
#> 067: 0.456244    1.122815    3.479553    0.226235    0.027269    0.025966    0.605812    
#> 068: 0.422924    1.133038    3.483024    0.214924    0.028407    0.024667    0.618102    
#> 069: 0.442686    1.136579    3.465603    0.251634    0.030788    0.023434    0.622609    
#> 070: 0.454521    1.125815    3.487572    0.239052    0.037238    0.022262    0.633178    
#> 071: 0.471443    1.138133    3.474298    0.254365    0.035567    0.021149    0.639967    
#> 072: 0.448761    1.103437    3.489566    0.241646    0.033789    0.022022    0.616721    
#> 073: 0.492658    1.106229    3.504683    0.238063    0.032099    0.023635    0.623519    
#> 074: 0.459145    1.114224    3.495127    0.226159    0.030494    0.022453    0.621997    
#> 075: 0.494299    1.114627    3.517911    0.214851    0.028970    0.021331    0.619132    
#> 076: 0.531430    1.110157    3.515084    0.206552    0.027521    0.020264    0.624744    
#> 077: 0.542418    1.111179    3.508405    0.196225    0.026145    0.020258    0.611891    
#> 078: 0.509132    1.115137    3.503656    0.186414    0.025336    0.019550    0.620481    
#> 079: 0.509735    1.122030    3.504519    0.194156    0.024069    0.024193    0.628617    
#> 080: 0.495946    1.112168    3.491943    0.227923    0.027648    0.022984    0.625261    
#> 081: 0.501046    1.115893    3.491875    0.244837    0.026266    0.021835    0.619211    
#> 082: 0.473770    1.093938    3.507326    0.232595    0.024952    0.021052    0.625515    
#> 083: 0.487973    1.101711    3.493940    0.220965    0.023705    0.019999    0.614027    
#> 084: 0.488785    1.113843    3.493909    0.209917    0.022519    0.018999    0.602859    
#> 085: 0.469258    1.109064    3.503547    0.199421    0.023216    0.020851    0.610937    
#> 086: 0.456244    1.100150    3.494084    0.218023    0.022056    0.020217    0.612285    
#> 087: 0.468707    1.089749    3.496576    0.235289    0.020953    0.020420    0.625695    
#> 088: 0.448952    1.089882    3.498386    0.223525    0.019905    0.022653    0.624305    
#> 089: 0.470816    1.105563    3.479748    0.238449    0.018910    0.024419    0.629037    
#> 090: 0.476668    1.091118    3.494479    0.253808    0.017964    0.024350    0.618933    
#> 091: 0.466170    1.090214    3.483437    0.245139    0.017066    0.023306    0.622528    
#> 092: 0.470595    1.111018    3.481071    0.277597    0.016435    0.026104    0.618569    
#> 093: 0.479114    1.093587    3.498381    0.263717    0.016787    0.026652    0.623692    
#> 094: 0.469676    1.110107    3.492926    0.250531    0.018559    0.027521    0.615334    
#> 095: 0.507879    1.108171    3.498621    0.238005    0.019911    0.029024    0.627116    
#> 096: 0.428768    1.117278    3.481159    0.226104    0.018915    0.029764    0.629670    
#> 097: 0.492614    1.125675    3.489057    0.214799    0.017969    0.028751    0.629032    
#> 098: 0.485969    1.127388    3.490266    0.204059    0.017071    0.028749    0.628607    
#> 099: 0.457015    1.110008    3.477451    0.213566    0.017096    0.027311    0.623430    
#> 100: 0.456375    1.104043    3.488126    0.220561    0.018752    0.025946    0.608100    
#> 101: 0.446382    1.095684    3.476078    0.209533    0.017815    0.028083    0.607884    
#> 102: 0.453800    1.104432    3.481716    0.199056    0.016924    0.030255    0.626682    
#> 103: 0.494320    1.105865    3.494325    0.243166    0.016078    0.031044    0.622317    
#> 104: 0.487442    1.103993    3.500675    0.233183    0.015274    0.029491    0.631158    
#> 105: 0.538096    1.106032    3.509069    0.221524    0.016494    0.028017    0.619591    
#> 106: 0.521527    1.108557    3.503847    0.218884    0.016056    0.026616    0.625479    
#> 107: 0.534053    1.113692    3.499623    0.226890    0.015253    0.025285    0.632963    
#> 108: 0.495014    1.112058    3.498986    0.215545    0.016474    0.024021    0.634903    
#> 109: 0.475341    1.119569    3.499877    0.240481    0.015945    0.022820    0.629919    
#> 110: 0.487180    1.106171    3.488945    0.228457    0.015393    0.021679    0.627329    
#> 111: 0.519974    1.104303    3.501253    0.217034    0.018226    0.021555    0.610692    
#> 112: 0.523956    1.079514    3.494574    0.225537    0.024301    0.020477    0.614340    
#> 113: 0.477602    1.101361    3.501342    0.214260    0.023102    0.019935    0.599237    
#> 114: 0.495746    1.123162    3.499633    0.203547    0.028413    0.020392    0.599423    
#> 115: 0.501901    1.101219    3.495771    0.193369    0.029368    0.019373    0.615905    
#> 116: 0.486819    1.118274    3.493974    0.198013    0.027899    0.020978    0.625637    
#> 117: 0.451107    1.132179    3.491801    0.188112    0.030295    0.022127    0.621340    
#> 118: 0.470024    1.124679    3.495529    0.190348    0.028979    0.022871    0.616121    
#> 119: 0.502153    1.108892    3.498084    0.227489    0.027530    0.023326    0.609269    
#> 120: 0.460442    1.110004    3.497961    0.216115    0.027881    0.022160    0.598951    
#> 121: 0.510669    1.126091    3.502289    0.206216    0.030444    0.021052    0.604018    
#> 122: 0.520894    1.106306    3.501741    0.195906    0.031856    0.021313    0.608976    
#> 123: 0.543278    1.131717    3.496048    0.240341    0.030263    0.021813    0.626739    
#> 124: 0.513112    1.145515    3.498130    0.228324    0.028750    0.025087    0.625224    
#> 125: 0.500463    1.134805    3.490182    0.216908    0.027313    0.023833    0.626220    
#> 126: 0.466711    1.134998    3.481912    0.210953    0.025947    0.023023    0.633086    
#> 127: 0.484824    1.125143    3.485882    0.202812    0.024650    0.023330    0.638162    
#> 128: 0.484960    1.105230    3.504582    0.192671    0.023417    0.022164    0.636628    
#> 129: 0.515653    1.111997    3.520030    0.233562    0.026217    0.027006    0.624310    
#> 130: 0.569863    1.110972    3.511892    0.221884    0.024906    0.028472    0.607500    
#> 131: 0.515158    1.103215    3.503693    0.210789    0.023861    0.028293    0.595486    
#> 132: 0.464081    1.100538    3.497119    0.200250    0.022755    0.026879    0.633618    
#> 133: 0.510764    1.079697    3.499084    0.235088    0.025906    0.025535    0.622650    
#> 134: 0.540246    1.079548    3.524779    0.237796    0.025681    0.024258    0.615572    
#> 135: 0.544796    1.082660    3.525083    0.225907    0.028629    0.023045    0.618205    
#> 136: 0.527236    1.073274    3.521546    0.214611    0.027197    0.021893    0.616166    
#> 137: 0.541878    1.057546    3.519179    0.216703    0.025837    0.023316    0.635875    
#> 138: 0.511826    1.069395    3.510452    0.206153    0.024546    0.023862    0.624484    
#> 139: 0.511462    1.094819    3.520695    0.201518    0.023318    0.023661    0.630278    
#> 140: 0.517220    1.110105    3.516722    0.209165    0.022152    0.025080    0.649191    
#> 141: 0.487590    1.092312    3.507124    0.198707    0.024451    0.023826    0.610390    
#> 142: 0.501600    1.081931    3.515683    0.190051    0.028767    0.022635    0.613915    
#> 143: 0.516840    1.100425    3.509875    0.236722    0.027328    0.023427    0.613876    
#> 144: 0.526437    1.100678    3.514812    0.224886    0.025962    0.022256    0.610099    
#> 145: 0.495986    1.117121    3.495763    0.213642    0.024664    0.021785    0.602523    
#> 146: 0.478467    1.121106    3.504957    0.221699    0.024554    0.021050    0.613078    
#> 147: 0.458378    1.116455    3.485531    0.210614    0.023326    0.020198    0.599124    
#> 148: 0.444713    1.122034    3.495192    0.214127    0.022160    0.019265    0.610175    
#> 149: 0.451456    1.109315    3.491410    0.248800    0.024161    0.022545    0.612571    
#> 150: 0.470457    1.106327    3.471392    0.276539    0.024910    0.021418    0.624752    
#> 151: 0.441599    1.111797    3.486391    0.262712    0.023665    0.022700    0.617596    
#> 152: 0.438629    1.110497    3.487400    0.240186    0.024245    0.025922    0.615677    
#> 153: 0.461158    1.131571    3.492946    0.283328    0.028255    0.028739    0.622282    
#> 154: 0.514950    1.124984    3.503975    0.302460    0.022045    0.030293    0.607096    
#> 155: 0.487422    1.109112    3.489447    0.267919    0.021276    0.026926    0.609569    
#> 156: 0.521587    1.112932    3.500414    0.269504    0.023623    0.025898    0.625511    
#> 157: 0.499274    1.099254    3.507113    0.229727    0.026251    0.025433    0.635920    
#> 158: 0.515676    1.129170    3.489766    0.242307    0.020437    0.025827    0.599058    
#> 159: 0.469412    1.144542    3.494755    0.222389    0.019559    0.025449    0.616266    
#> 160: 0.517332    1.130786    3.500563    0.265892    0.023215    0.023303    0.623145    
#> 161: 0.490212    1.127332    3.500679    0.228100    0.025759    0.025189    0.616349    
#> 162: 0.501586    1.125960    3.499703    0.252862    0.022520    0.026451    0.617022    
#> 163: 0.498451    1.116440    3.486250    0.269160    0.021223    0.026054    0.607528    
#> 164: 0.483726    1.116719    3.485866    0.252875    0.023918    0.023265    0.605456    
#> 165: 0.521398    1.109329    3.492535    0.235260    0.020030    0.021461    0.610965    
#> 166: 0.511407    1.130671    3.497926    0.213202    0.019676    0.017770    0.619970    
#> 167: 0.513624    1.125144    3.507309    0.200691    0.020326    0.019707    0.633036    
#> 168: 0.510651    1.135185    3.492871    0.218106    0.025842    0.022488    0.620740    
#> 169: 0.499204    1.129375    3.490179    0.203899    0.025886    0.018797    0.629436    
#> 170: 0.495053    1.111419    3.496453    0.227918    0.022868    0.019612    0.614695    
#> 171: 0.473545    1.116408    3.489878    0.213638    0.022756    0.020390    0.610481    
#> 172: 0.455227    1.131012    3.490599    0.225393    0.019813    0.021663    0.606557    
#> 173: 0.462600    1.139750    3.481808    0.216792    0.024814    0.019906    0.609836    
#> 174: 0.471775    1.131540    3.486057    0.246626    0.022467    0.021739    0.634133    
#> 175: 0.465360    1.126388    3.477050    0.242839    0.027295    0.021918    0.625108    
#> 176: 0.438881    1.127678    3.488312    0.189012    0.026486    0.017160    0.628214    
#> 177: 0.452492    1.119476    3.498710    0.184855    0.027394    0.022494    0.634226    
#> 178: 0.491649    1.112319    3.497551    0.228617    0.026519    0.026898    0.616553    
#> 179: 0.510004    1.126581    3.505020    0.180308    0.029544    0.022240    0.618790    
#> 180: 0.471073    1.122504    3.499922    0.206980    0.027084    0.021770    0.603674    
#> 181: 0.480444    1.095544    3.479996    0.200227    0.030585    0.019038    0.604315    
#> 182: 0.490384    1.097885    3.488360    0.172784    0.035436    0.021766    0.627884    
#> 183: 0.494730    1.119864    3.494762    0.190934    0.022851    0.019941    0.630666    
#> 184: 0.501685    1.095519    3.502466    0.211514    0.020803    0.018782    0.626732    
#> 185: 0.465085    1.114987    3.498432    0.205618    0.017353    0.021322    0.622079    
#> 186: 0.464372    1.130924    3.488253    0.192029    0.018772    0.023613    0.634866    
#> 187: 0.469716    1.119417    3.498750    0.173224    0.015925    0.022563    0.631945    
#> 188: 0.440224    1.138956    3.485257    0.190848    0.021312    0.021446    0.646943    
#> 189: 0.479985    1.130154    3.494135    0.187567    0.023823    0.019754    0.652172    
#> 190: 0.505617    1.117950    3.506097    0.222555    0.021664    0.018748    0.630703    
#> 191: 0.477317    1.129997    3.487804    0.196539    0.022508    0.018856    0.620284    
#> 192: 0.441171    1.121897    3.487601    0.171236    0.021514    0.017362    0.628120    
#> 193: 0.481339    1.130884    3.492612    0.176394    0.020689    0.016686    0.629816    
#> 194: 0.443571    1.131585    3.481728    0.195063    0.024711    0.016729    0.635195    
#> 195: 0.416235    1.131005    3.470880    0.212895    0.022724    0.015292    0.642957    
#> 196: 0.436667    1.132961    3.480318    0.215120    0.032426    0.013378    0.631792    
#> 197: 0.438824    1.142038    3.491971    0.228420    0.029164    0.018220    0.632004    
#> 198: 0.492335    1.121113    3.493352    0.199280    0.026781    0.016469    0.609306    
#> 199: 0.477925    1.105485    3.489985    0.236565    0.030577    0.014520    0.607318    
#> 200: 0.469970    1.120731    3.494637    0.236907    0.036429    0.015405    0.618369    
#> 201: 0.468581    1.111666    3.499418    0.243532    0.034119    0.016869    0.613842    
#> 202: 0.467947    1.107258    3.500058    0.235364    0.030811    0.018285    0.615939    
#> 203: 0.484447    1.105399    3.500318    0.240330    0.029224    0.019158    0.613379    
#> 204: 0.490753    1.100814    3.503374    0.237259    0.027309    0.019902    0.616205    
#> 205: 0.487853    1.104840    3.503913    0.233725    0.027061    0.020706    0.617363    
#> 206: 0.487340    1.110566    3.503004    0.235181    0.027286    0.020735    0.619625    
#> 207: 0.484753    1.112965    3.501031    0.233418    0.027001    0.020875    0.620545    
#> 208: 0.484189    1.112688    3.500891    0.235007    0.025929    0.021233    0.620664    
#> 209: 0.488332    1.109462    3.501445    0.236235    0.025376    0.021749    0.620912    
#> 210: 0.493224    1.107900    3.502878    0.236479    0.024743    0.021850    0.620900    
#> 211: 0.493709    1.108821    3.502572    0.237870    0.024514    0.021957    0.620017    
#> 212: 0.494599    1.108997    3.502811    0.238820    0.024148    0.022232    0.620057    
#> 213: 0.494943    1.107355    3.502805    0.239709    0.023911    0.022175    0.621570    
#> 214: 0.496985    1.106973    3.503405    0.241285    0.023879    0.022211    0.622704    
#> 215: 0.496147    1.106689    3.503659    0.240559    0.023739    0.022157    0.624857    
#> 216: 0.496509    1.106405    3.503751    0.238149    0.023636    0.022002    0.625844    
#> 217: 0.497188    1.106877    3.503773    0.235895    0.023391    0.021909    0.625737    
#> 218: 0.495783    1.107070    3.502971    0.234142    0.023379    0.021930    0.625605    
#> 219: 0.493446    1.106898    3.501632    0.231829    0.023488    0.022053    0.626022    
#> 220: 0.491604    1.107428    3.500845    0.232556    0.023465    0.022212    0.626014    
#> 221: 0.489912    1.107846    3.500095    0.232254    0.023229    0.022211    0.625943    
#> 222: 0.490145    1.107757    3.499662    0.233012    0.023077    0.022224    0.625757    
#> 223: 0.492012    1.107939    3.499700    0.232950    0.022897    0.022355    0.625351    
#> 224: 0.493716    1.108422    3.499804    0.232553    0.022911    0.022434    0.624328    
#> 225: 0.492946    1.107639    3.500048    0.231370    0.022931    0.022333    0.624824    
#> 226: 0.492907    1.106792    3.499815    0.229798    0.022746    0.022282    0.625244    
#> 227: 0.492670    1.106543    3.499625    0.228547    0.022757    0.022331    0.624879    
#> 228: 0.491960    1.107483    3.499107    0.227854    0.022836    0.022345    0.624389    
#> 229: 0.490993    1.107872    3.498452    0.227422    0.022867    0.022302    0.623357    
#> 230: 0.491234    1.108194    3.498075    0.227792    0.022944    0.022299    0.622703    
#> 231: 0.492047    1.108738    3.498172    0.229087    0.022944    0.022374    0.622497    
#> 232: 0.491497    1.109002    3.498205    0.228514    0.022900    0.022352    0.622553    
#> 233: 0.491270    1.108606    3.498080    0.228027    0.022842    0.022365    0.622427    
#> 234: 0.490671    1.108414    3.497747    0.227986    0.022690    0.022454    0.622076    
#> 235: 0.491187    1.107907    3.497768    0.228340    0.022508    0.022498    0.621832    
#> 236: 0.490925    1.107885    3.497547    0.228110    0.022454    0.022641    0.621601    
#> 237: 0.491479    1.107767    3.497492    0.228439    0.022487    0.022922    0.621812    
#> 238: 0.491603    1.108064    3.497434    0.227475    0.022629    0.022977    0.622208    
#> 239: 0.490629    1.108482    3.497058    0.227032    0.022686    0.023121    0.622191    
#> 240: 0.490456    1.108694    3.497220    0.226168    0.022790    0.023234    0.622276    
#> 241: 0.489758    1.108765    3.497186    0.226497    0.022729    0.023236    0.622227    
#> 242: 0.489588    1.108752    3.496720    0.227707    0.022845    0.023330    0.622498    
#> 243: 0.488674    1.109146    3.496514    0.228692    0.022928    0.023384    0.622554    
#> 244: 0.488181    1.109169    3.496612    0.229592    0.022956    0.023520    0.622540    
#> 245: 0.488789    1.109020    3.496856    0.230562    0.022877    0.023608    0.623053    
#> 246: 0.488818    1.108897    3.496801    0.230259    0.022734    0.023657    0.623063    
#> 247: 0.488889    1.108562    3.496995    0.230446    0.022611    0.023648    0.623167    
#> 248: 0.488822    1.108913    3.497027    0.230353    0.022539    0.023664    0.622921    
#> 249: 0.488822    1.109110    3.497306    0.229670    0.022468    0.023731    0.622884    
#> 250: 0.489417    1.109183    3.497493    0.230346    0.022450    0.023807    0.622602    
#> 251: 0.489461    1.109349    3.497714    0.229838    0.022503    0.023774    0.622607    
#> 252: 0.489865    1.109502    3.497988    0.229158    0.022444    0.023826    0.622360    
#> 253: 0.490016    1.109953    3.498057    0.229121    0.022429    0.023916    0.622212    
#> 254: 0.489785    1.110554    3.498053    0.229068    0.022425    0.023951    0.622046    
#> 255: 0.489133    1.110788    3.497975    0.229229    0.022418    0.024000    0.621924    
#> 256: 0.488969    1.110629    3.497794    0.229066    0.022381    0.024014    0.621672    
#> 257: 0.487999    1.110690    3.497405    0.228290    0.022345    0.023963    0.621808    
#> 258: 0.487714    1.110262    3.497267    0.228522    0.022300    0.023925    0.621900    
#> 259: 0.487455    1.110133    3.497208    0.228656    0.022392    0.023862    0.622111    
#> 260: 0.487609    1.110405    3.497231    0.228859    0.022411    0.023814    0.622047    
#> 261: 0.487634    1.110414    3.497245    0.228802    0.022425    0.023771    0.621926    
#> 262: 0.488095    1.110379    3.497483    0.228085    0.022568    0.023715    0.621990    
#> 263: 0.488303    1.110317    3.497762    0.227752    0.022564    0.023694    0.621888    
#> 264: 0.487749    1.110391    3.497657    0.228103    0.022467    0.023661    0.622317    
#> 265: 0.487855    1.110314    3.497744    0.228029    0.022442    0.023644    0.622402    
#> 266: 0.487943    1.110379    3.497744    0.228117    0.022441    0.023644    0.622325    
#> 267: 0.487774    1.110457    3.497870    0.227995    0.022442    0.023692    0.622208    
#> 268: 0.487401    1.110308    3.497764    0.227944    0.022400    0.023734    0.621919    
#> 269: 0.487724    1.110137    3.497722    0.227880    0.022349    0.023762    0.621560    
#> 270: 0.487892    1.110139    3.497613    0.228086    0.022324    0.023765    0.621372    
#> 271: 0.488022    1.110074    3.497489    0.228762    0.022320    0.023749    0.621232    
#> 272: 0.487761    1.109996    3.497380    0.229137    0.022326    0.023714    0.621434    
#> 273: 0.487640    1.110327    3.497339    0.229139    0.022417    0.023689    0.621298    
#> 274: 0.487166    1.110668    3.497285    0.228775    0.022426    0.023617    0.621217    
#> 275: 0.487429    1.110652    3.497256    0.228316    0.022467    0.023566    0.621047    
#> 276: 0.487173    1.110765    3.497304    0.227924    0.022562    0.023517    0.620766    
#> 277: 0.486762    1.110953    3.497304    0.227675    0.022586    0.023485    0.620509    
#> 278: 0.486657    1.110963    3.497343    0.227785    0.022591    0.023446    0.620224    
#> 279: 0.486740    1.110792    3.497376    0.228329    0.022620    0.023473    0.620160    
#> 280: 0.486747    1.110791    3.497335    0.228219    0.022617    0.023492    0.620074    
#> 281: 0.486571    1.110747    3.497323    0.228299    0.022565    0.023530    0.619987    
#> 282: 0.486587    1.110881    3.497407    0.228473    0.022579    0.023569    0.620307    
#> 283: 0.486726    1.110895    3.497501    0.228609    0.022518    0.023676    0.620727    
#> 284: 0.486949    1.110651    3.497602    0.228395    0.022442    0.023774    0.620767    
#> 285: 0.486908    1.110480    3.497557    0.228375    0.022398    0.023833    0.620813    
#> 286: 0.487030    1.110516    3.497452    0.228465    0.022438    0.023859    0.620738    
#> 287: 0.486801    1.110639    3.497399    0.228078    0.022510    0.023850    0.620907    
#> 288: 0.486850    1.110572    3.497425    0.228200    0.022501    0.023847    0.621106    
#> 289: 0.487451    1.110396    3.497503    0.228460    0.022448    0.023859    0.621445    
#> 290: 0.487714    1.110261    3.497606    0.228173    0.022403    0.023841    0.621787    
#> 291: 0.487467    1.110451    3.497645    0.227687    0.022417    0.023814    0.621805    
#> 292: 0.487485    1.110648    3.497602    0.227377    0.022407    0.023773    0.621616    
#> 293: 0.487435    1.110856    3.497553    0.227234    0.022407    0.023736    0.621323    
#> 294: 0.487281    1.111028    3.497473    0.227156    0.022400    0.023711    0.621258    
#> 295: 0.487209    1.110996    3.497399    0.227223    0.022415    0.023691    0.621069    
#> 296: 0.487243    1.111029    3.497381    0.227080    0.022386    0.023687    0.621191    
#> 297: 0.487411    1.111099    3.497403    0.227240    0.022363    0.023711    0.621140    
#> 298: 0.487375    1.111030    3.497262    0.227309    0.022332    0.023682    0.621041    
#> 299: 0.487473    1.111196    3.497206    0.227244    0.022348    0.023641    0.620967    
#> 300: 0.487772    1.111156    3.497265    0.226932    0.022311    0.023604    0.620894    
#> 301: 0.488019    1.111138    3.497196    0.226962    0.022288    0.023564    0.620918    
#> 302: 0.488130    1.111231    3.497173    0.226840    0.022299    0.023538    0.620882    
#> 303: 0.487790    1.111433    3.496982    0.227035    0.022288    0.023556    0.620635    
#> 304: 0.487792    1.111630    3.496802    0.227338    0.022238    0.023587    0.620571    
#> 305: 0.487521    1.111554    3.496642    0.227177    0.022248    0.023575    0.620461    
#> 306: 0.487211    1.111437    3.496455    0.227119    0.022231    0.023574    0.620453    
#> 307: 0.487062    1.111344    3.496306    0.227158    0.022250    0.023588    0.620460    
#> 308: 0.486579    1.111191    3.496301    0.227498    0.022237    0.023631    0.620556    
#> 309: 0.486472    1.111023    3.496223    0.227824    0.022179    0.023674    0.620815    
#> 310: 0.486611    1.110884    3.496148    0.227876    0.022190    0.023679    0.620903    
#> 311: 0.486618    1.110991    3.496206    0.228092    0.022186    0.023697    0.620881    
#> 312: 0.486575    1.110914    3.496191    0.227900    0.022213    0.023688    0.620967    
#> 313: 0.486339    1.110810    3.496144    0.227614    0.022223    0.023687    0.620980    
#> 314: 0.485980    1.110846    3.496033    0.227563    0.022208    0.023693    0.620950    
#> 315: 0.485577    1.110823    3.496005    0.227852    0.022178    0.023692    0.620947    
#> 316: 0.485719    1.110852    3.496035    0.228396    0.022180    0.023672    0.620857    
#> 317: 0.486030    1.110867    3.496184    0.228505    0.022197    0.023667    0.620864    
#> 318: 0.486105    1.110934    3.496123    0.228408    0.022170    0.023681    0.620711    
#> 319: 0.485956    1.110904    3.496066    0.228032    0.022201    0.023686    0.620780    
#> 320: 0.485520    1.110786    3.496048    0.227742    0.022216    0.023688    0.620865    
#> 321: 0.485264    1.110760    3.495991    0.227299    0.022215    0.023671    0.620920    
#> 322: 0.485113    1.110773    3.495901    0.227388    0.022196    0.023640    0.620999    
#> 323: 0.484582    1.110809    3.495766    0.227617    0.022193    0.023619    0.621005    
#> 324: 0.484385    1.110979    3.495640    0.227819    0.022207    0.023609    0.620890    
#> 325: 0.484200    1.111134    3.495542    0.227897    0.022217    0.023600    0.620720    
#> 326: 0.484271    1.111192    3.495491    0.227801    0.022254    0.023585    0.620694    
#> 327: 0.484340    1.111438    3.495520    0.227760    0.022317    0.023612    0.620650    
#> 328: 0.484569    1.111580    3.495551    0.227929    0.022369    0.023619    0.620515    
#> 329: 0.484843    1.111648    3.495612    0.228099    0.022418    0.023619    0.620305    
#> 330: 0.484720    1.111708    3.495606    0.228301    0.022405    0.023608    0.620133    
#> 331: 0.484843    1.111860    3.495650    0.228127    0.022401    0.023608    0.620037    
#> 332: 0.484934    1.111829    3.495648    0.228187    0.022358    0.023595    0.620076    
#> 333: 0.484768    1.111752    3.495562    0.228089    0.022333    0.023611    0.620128    
#> 334: 0.484612    1.111658    3.495436    0.228178    0.022291    0.023636    0.620118    
#> 335: 0.484414    1.111524    3.495394    0.227869    0.022307    0.023670    0.620183    
#> 336: 0.484114    1.111542    3.495355    0.227777    0.022304    0.023714    0.620295    
#> 337: 0.484053    1.111575    3.495307    0.227651    0.022281    0.023739    0.620337    
#> 338: 0.484088    1.111611    3.495412    0.227703    0.022307    0.023783    0.620234    
#> 339: 0.484051    1.111708    3.495389    0.227495    0.022285    0.023818    0.620177    
#> 340: 0.484223    1.111597    3.495440    0.227384    0.022289    0.023852    0.620089    
#> 341: 0.484520    1.111533    3.495550    0.227286    0.022299    0.023878    0.620100    
#> 342: 0.484437    1.111431    3.495591    0.227202    0.022268    0.023892    0.620131    
#> 343: 0.484307    1.111412    3.495526    0.227289    0.022236    0.023877    0.620103    
#> 344: 0.484445    1.111373    3.495557    0.227422    0.022214    0.023886    0.620159    
#> 345: 0.484481    1.111342    3.495595    0.227238    0.022217    0.023911    0.620136    
#> 346: 0.484528    1.111404    3.495523    0.227217    0.022197    0.023920    0.620091    
#> 347: 0.484462    1.111274    3.495459    0.227095    0.022189    0.023962    0.620102    
#> 348: 0.484215    1.111170    3.495435    0.227060    0.022181    0.023982    0.620157    
#> 349: 0.484166    1.111042    3.495446    0.227091    0.022186    0.024000    0.620165    
#> 350: 0.483920    1.110866    3.495403    0.226955    0.022170    0.024007    0.620207    
#> 351: 0.483853    1.110881    3.495343    0.226981    0.022170    0.024023    0.620179    
#> 352: 0.483653    1.110959    3.495339    0.226929    0.022159    0.024053    0.620280    
#> 353: 0.483603    1.111165    3.495261    0.227027    0.022165    0.024092    0.620335    
#> 354: 0.483515    1.111298    3.495121    0.226948    0.022120    0.024175    0.620362    
#> 355: 0.483811    1.111164    3.495153    0.227224    0.022101    0.024193    0.620383    
#> 356: 0.483720    1.111124    3.495165    0.227290    0.022148    0.024205    0.620545    
#> 357: 0.483766    1.111208    3.495197    0.227210    0.022157    0.024167    0.620629    
#> 358: 0.483585    1.111333    3.495129    0.227095    0.022145    0.024178    0.620631    
#> 359: 0.483253    1.111530    3.495010    0.226900    0.022169    0.024162    0.620580    
#> 360: 0.482911    1.111633    3.494810    0.226849    0.022174    0.024150    0.620515    
#> 361: 0.482779    1.111732    3.494750    0.226916    0.022144    0.024146    0.620418    
#> 362: 0.482921    1.111726    3.494712    0.227060    0.022110    0.024142    0.620279    
#> 363: 0.483015    1.111613    3.494743    0.227202    0.022076    0.024167    0.620128    
#> 364: 0.483194    1.111626    3.494704    0.227417    0.022032    0.024193    0.620105    
#> 365: 0.483089    1.111565    3.494684    0.227590    0.021981    0.024220    0.620168    
#> 366: 0.483124    1.111524    3.494609    0.227549    0.021946    0.024232    0.620166    
#> 367: 0.483082    1.111518    3.494555    0.227331    0.021937    0.024215    0.620097    
#> 368: 0.483160    1.111508    3.494520    0.227247    0.021891    0.024234    0.620088    
#> 369: 0.483255    1.111548    3.494492    0.227324    0.021897    0.024259    0.620126    
#> 370: 0.483219    1.111658    3.494461    0.227480    0.021892    0.024304    0.620103    
#> 371: 0.482889    1.111789    3.494337    0.227312    0.021912    0.024323    0.620018    
#> 372: 0.482721    1.111858    3.494263    0.227287    0.021933    0.024311    0.620004    
#> 373: 0.482549    1.111969    3.494205    0.227170    0.021934    0.024308    0.619959    
#> 374: 0.482597    1.112023    3.494178    0.227178    0.021936    0.024281    0.619902    
#> 375: 0.482416    1.111996    3.494171    0.227119    0.021918    0.024270    0.619875    
#> 376: 0.482237    1.112039    3.494176    0.226724    0.021928    0.024226    0.619872    
#> 377: 0.482163    1.112139    3.494135    0.226498    0.021971    0.024201    0.619776    
#> 378: 0.481843    1.112196    3.493999    0.226404    0.022002    0.024190    0.619755    
#> 379: 0.481569    1.112180    3.493951    0.226300    0.022034    0.024169    0.619772    
#> 380: 0.481416    1.112230    3.493916    0.226221    0.022090    0.024165    0.619768    
#> 381: 0.481186    1.112256    3.493859    0.226260    0.022111    0.024139    0.619759    
#> 382: 0.481096    1.112164    3.493832    0.226136    0.022132    0.024112    0.619718    
#> 383: 0.481228    1.112102    3.493827    0.226129    0.022146    0.024078    0.619659    
#> 384: 0.481006    1.112078    3.493831    0.225992    0.022179    0.024070    0.619650    
#> 385: 0.481098    1.111974    3.493862    0.225899    0.022187    0.024091    0.619642    
#> 386: 0.481285    1.112047    3.493930    0.225757    0.022184    0.024092    0.619749    
#> 387: 0.481517    1.112068    3.494064    0.225673    0.022156    0.024101    0.619764    
#> 388: 0.481734    1.112050    3.494142    0.225660    0.022158    0.024111    0.619780    
#> 389: 0.481745    1.111968    3.494138    0.225507    0.022174    0.024115    0.619849    
#> 390: 0.481690    1.112008    3.494182    0.225308    0.022174    0.024119    0.619862    
#> 391: 0.481874    1.112000    3.494226    0.225259    0.022177    0.024102    0.619842    
#> 392: 0.481997    1.112002    3.494259    0.225232    0.022166    0.024092    0.619908    
#> 393: 0.482026    1.111991    3.494225    0.225299    0.022160    0.024099    0.619898    
#> 394: 0.482002    1.112013    3.494149    0.225506    0.022135    0.024104    0.619895    
#> 395: 0.482318    1.112032    3.494199    0.225768    0.022104    0.024099    0.619918    
#> 396: 0.482508    1.112078    3.494234    0.225993    0.022084    0.024099    0.619834    
#> 397: 0.482544    1.112053    3.494285    0.226042    0.022058    0.024093    0.619832    
#> 398: 0.482680    1.111952    3.494370    0.225993    0.022056    0.024088    0.619843    
#> 399: 0.482882    1.111938    3.494454    0.226102    0.022051    0.024083    0.619879    
#> 400: 0.482958    1.111947    3.494508    0.226238    0.022067    0.024083    0.619912    
#> 401: 0.482927    1.112084    3.494505    0.226164    0.022103    0.024073    0.619962    
#> 402: 0.482954    1.112096    3.494528    0.226106    0.022106    0.024071    0.619910    
#> 403: 0.483075    1.112016    3.494550    0.226216    0.022127    0.024065    0.619835    
#> 404: 0.483162    1.111985    3.494533    0.226305    0.022123    0.024079    0.619772    
#> 405: 0.483133    1.111944    3.494546    0.226120    0.022110    0.024090    0.619786    
#> 406: 0.483168    1.111916    3.494537    0.226137    0.022102    0.024127    0.619854    
#> 407: 0.483287    1.111945    3.494570    0.226276    0.022100    0.024144    0.619807    
#> 408: 0.483321    1.112018    3.494615    0.226364    0.022109    0.024160    0.619842    
#> 409: 0.483329    1.111971    3.494602    0.226468    0.022109    0.024169    0.619758    
#> 410: 0.483255    1.112004    3.494551    0.226640    0.022130    0.024166    0.619720    
#> 411: 0.483352    1.111869    3.494516    0.226783    0.022163    0.024167    0.619711    
#> 412: 0.483323    1.111926    3.494481    0.226674    0.022195    0.024169    0.619752    
#> 413: 0.483078    1.112020    3.494394    0.226754    0.022210    0.024169    0.619735    
#> 414: 0.482897    1.112050    3.494377    0.226886    0.022207    0.024193    0.619650    
#> 415: 0.482880    1.112031    3.494367    0.226920    0.022166    0.024220    0.619590    
#> 416: 0.482890    1.112041    3.494365    0.226935    0.022140    0.024233    0.619599    
#> 417: 0.482785    1.112046    3.494353    0.226973    0.022130    0.024233    0.619581    
#> 418: 0.482689    1.112034    3.494358    0.226999    0.022149    0.024212    0.619522    
#> 419: 0.482666    1.112100    3.494338    0.226791    0.022125    0.024175    0.619560    
#> 420: 0.482715    1.112164    3.494314    0.226810    0.022121    0.024141    0.619557    
#> 421: 0.482570    1.112217    3.494321    0.226766    0.022123    0.024108    0.619544    
#> 422: 0.482763    1.112139    3.494361    0.226866    0.022130    0.024088    0.619497    
#> 423: 0.483010    1.112082    3.494417    0.226904    0.022147    0.024064    0.619464    
#> 424: 0.482967    1.112066    3.494385    0.226719    0.022160    0.024038    0.619468    
#> 425: 0.483084    1.112099    3.494358    0.226575    0.022168    0.024038    0.619589    
#> 426: 0.483267    1.112099    3.494404    0.226567    0.022158    0.024017    0.619539    
#> 427: 0.483362    1.112028    3.494473    0.226713    0.022146    0.024016    0.619408    
#> 428: 0.483313    1.112020    3.494476    0.226721    0.022141    0.024000    0.619392    
#> 429: 0.483420    1.112087    3.494490    0.226708    0.022161    0.023977    0.619423    
#> 430: 0.483494    1.112176    3.494495    0.226828    0.022173    0.023994    0.619418    
#> 431: 0.483423    1.112197    3.494436    0.226942    0.022147    0.023998    0.619333    
#> 432: 0.483418    1.112227    3.494427    0.227027    0.022114    0.024027    0.619303    
#> 433: 0.483346    1.112262    3.494389    0.226988    0.022083    0.024046    0.619349    
#> 434: 0.483267    1.112258    3.494366    0.226907    0.022073    0.024075    0.619301    
#> 435: 0.483263    1.112280    3.494356    0.226777    0.022068    0.024077    0.619268    
#> 436: 0.483211    1.112252    3.494401    0.226795    0.022041    0.024072    0.619292    
#> 437: 0.483289    1.112264    3.494429    0.226717    0.022021    0.024080    0.619221    
#> 438: 0.483363    1.112391    3.494451    0.226592    0.022027    0.024079    0.619185    
#> 439: 0.483397    1.112417    3.494456    0.226502    0.022014    0.024064    0.619161    
#> 440: 0.483362    1.112473    3.494495    0.226394    0.022005    0.024063    0.619150    
#> 441: 0.483418    1.112460    3.494543    0.226500    0.022007    0.024065    0.619173    
#> 442: 0.483369    1.112462    3.494551    0.226450    0.022000    0.024059    0.619122    
#> 443: 0.483318    1.112507    3.494477    0.226418    0.021989    0.024046    0.619087    
#> 444: 0.483236    1.112572    3.494401    0.226254    0.021980    0.024037    0.619108    
#> 445: 0.483123    1.112627    3.494320    0.226111    0.022005    0.024015    0.619119    
#> 446: 0.482992    1.112667    3.494257    0.225977    0.022022    0.023992    0.619090    
#> 447: 0.483160    1.112679    3.494269    0.226048    0.022030    0.023976    0.619094    
#> 448: 0.483180    1.112653    3.494309    0.226042    0.022037    0.023972    0.619052    
#> 449: 0.483218    1.112647    3.494407    0.225893    0.022039    0.023966    0.619047    
#> 450: 0.483168    1.112671    3.494401    0.225891    0.022034    0.023959    0.619059    
#> 451: 0.483115    1.112742    3.494376    0.225873    0.022020    0.023952    0.619107    
#> 452: 0.483082    1.112735    3.494363    0.225889    0.022013    0.023941    0.619028    
#> 453: 0.482967    1.112761    3.494325    0.225797    0.022021    0.023920    0.618989    
#> 454: 0.482937    1.112831    3.494299    0.225716    0.022029    0.023907    0.618960    
#> 455: 0.482924    1.112845    3.494281    0.225732    0.022013    0.023906    0.618937    
#> 456: 0.482835    1.112839    3.494273    0.225655    0.021989    0.023911    0.618945    
#> 457: 0.482904    1.112838    3.494328    0.225660    0.021978    0.023907    0.618930    
#> 458: 0.482985    1.112920    3.494326    0.225611    0.021978    0.023894    0.618972    
#> 459: 0.482685    1.113067    3.494258    0.225624    0.021986    0.023869    0.619014    
#> 460: 0.482514    1.113118    3.494180    0.225637    0.021981    0.023873    0.619030    
#> 461: 0.482362    1.113133    3.494139    0.225633    0.021973    0.023873    0.619062    
#> 462: 0.482247    1.113193    3.494117    0.225674    0.021974    0.023876    0.619040    
#> 463: 0.482297    1.113215    3.494155    0.225651    0.021964    0.023866    0.619071    
#> 464: 0.482362    1.113230    3.494156    0.225556    0.021956    0.023863    0.619019    
#> 465: 0.482261    1.113141    3.494160    0.225443    0.021939    0.023846    0.619057    
#> 466: 0.482327    1.113100    3.494166    0.225332    0.021926    0.023831    0.619030    
#> 467: 0.482311    1.113084    3.494208    0.225319    0.021937    0.023823    0.618974    
#> 468: 0.482455    1.113086    3.494275    0.225283    0.021940    0.023816    0.619032    
#> 469: 0.482502    1.113129    3.494329    0.225240    0.021921    0.023821    0.619121    
#> 470: 0.482440    1.113198    3.494310    0.225098    0.021913    0.023816    0.619184    
#> 471: 0.482332    1.113237    3.494285    0.225017    0.021913    0.023792    0.619213    
#> 472: 0.482302    1.113271    3.494268    0.224979    0.021905    0.023785    0.619215    
#> 473: 0.482204    1.113264    3.494255    0.224891    0.021888    0.023789    0.619232    
#> 474: 0.482131    1.113235    3.494262    0.224742    0.021877    0.023801    0.619304    
#> 475: 0.482162    1.113304    3.494263    0.224542    0.021862    0.023809    0.619345    
#> 476: 0.482192    1.113283    3.494249    0.224465    0.021860    0.023793    0.619386    
#> 477: 0.482303    1.113274    3.494302    0.224347    0.021853    0.023794    0.619322    
#> 478: 0.482339    1.113261    3.494335    0.224367    0.021838    0.023788    0.619324    
#> 479: 0.482520    1.113281    3.494358    0.224418    0.021829    0.023781    0.619315    
#> 480: 0.482610    1.113323    3.494329    0.224468    0.021845    0.023782    0.619328    
#> 481: 0.482598    1.113285    3.494337    0.224449    0.021826    0.023788    0.619301    
#> 482: 0.482589    1.113307    3.494312    0.224444    0.021810    0.023782    0.619316    
#> 483: 0.482606    1.113283    3.494329    0.224433    0.021793    0.023781    0.619322    
#> 484: 0.482700    1.113188    3.494384    0.224479    0.021789    0.023790    0.619293    
#> 485: 0.482766    1.113205    3.494389    0.224507    0.021763    0.023799    0.619283    
#> 486: 0.482862    1.113207    3.494450    0.224534    0.021733    0.023795    0.619255    
#> 487: 0.483117    1.113179    3.494542    0.224569    0.021722    0.023794    0.619219    
#> 488: 0.483186    1.113133    3.494563    0.224565    0.021710    0.023779    0.619181    
#> 489: 0.483322    1.113076    3.494579    0.224554    0.021700    0.023780    0.619180    
#> 490: 0.483460    1.113028    3.494637    0.224611    0.021693    0.023793    0.619167    
#> 491: 0.483619    1.113028    3.494695    0.224642    0.021694    0.023809    0.619132    
#> 492: 0.483596    1.113063    3.494690    0.224618    0.021699    0.023813    0.619188    
#> 493: 0.483538    1.113051    3.494709    0.224536    0.021689    0.023814    0.619230    
#> 494: 0.483662    1.113040    3.494709    0.224558    0.021687    0.023807    0.619189    
#> 495: 0.483783    1.113065    3.494729    0.224567    0.021687    0.023811    0.619169    
#> 496: 0.483870    1.113104    3.494738    0.224506    0.021690    0.023804    0.619208    
#> 497: 0.483937    1.113061    3.494786    0.224395    0.021716    0.023790    0.619249    
#> 498: 0.484008    1.112949    3.494845    0.224241    0.021726    0.023772    0.619256    
#> 499: 0.484135    1.112887    3.494888    0.224237    0.021771    0.023761    0.619244    
#> 500: 0.484163    1.112856    3.494868    0.224230    0.021791    0.023752    0.619209    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.324692    0.957458    3.447465    0.392401    0.077125    0.016800    1.582008    
#> 002: 0.387255    1.036256    3.468572    0.372781    0.073269    0.015960    1.041374    
#> 003: 0.436336    1.016004    3.479986    0.354142    0.069606    0.015162    0.845873    
#> 004: 0.361453    1.028718    3.461944    0.336435    0.066125    0.014404    0.802048    
#> 005: 0.427842    1.045952    3.443880    0.319613    0.062819    0.013684    0.791439    
#> 006: 0.390607    1.049447    3.437408    0.303633    0.059678    0.013000    0.752077    
#> 007: 0.358119    1.060285    3.441192    0.288451    0.056694    0.012350    0.759651    
#> 008: 0.335867    1.055185    3.422896    0.274029    0.053860    0.014862    0.750284    
#> 009: 0.332045    1.044163    3.420049    0.260327    0.051167    0.015474    0.738823    
#> 010: 0.332544    1.057690    3.417604    0.247311    0.048608    0.014700    0.738764    
#> 011: 0.354350    1.080709    3.418776    0.234945    0.046178    0.013965    0.738302    
#> 012: 0.381646    1.075930    3.417428    0.223198    0.043869    0.013267    0.736398    
#> 013: 0.327210    1.064729    3.407227    0.212566    0.041675    0.014988    0.727235    
#> 014: 0.362019    1.074271    3.415839    0.203345    0.039592    0.015652    0.748210    
#> 015: 0.367833    1.067841    3.431310    0.196588    0.037612    0.015850    0.722610    
#> 016: 0.412915    1.052785    3.453015    0.193165    0.035732    0.017380    0.734961    
#> 017: 0.406902    1.057086    3.450107    0.208175    0.033945    0.019502    0.725580    
#> 018: 0.396899    1.061824    3.436908    0.230390    0.032248    0.018527    0.724209    
#> 019: 0.348200    1.051280    3.429183    0.218871    0.030635    0.017610    0.711606    
#> 020: 0.376088    1.051081    3.430397    0.268673    0.031624    0.017265    0.735497    
#> 021: 0.365907    1.046871    3.433657    0.255240    0.030043    0.016402    0.740255    
#> 022: 0.360683    1.059907    3.431804    0.242478    0.028541    0.015582    0.732805    
#> 023: 0.449361    1.043547    3.459485    0.230354    0.027114    0.014803    0.768043    
#> 024: 0.468540    1.063152    3.454698    0.218836    0.025758    0.014063    0.753893    
#> 025: 0.439564    1.049472    3.447228    0.207894    0.024470    0.013359    0.749835    
#> 026: 0.389736    1.060399    3.441899    0.213555    0.023247    0.012691    0.729143    
#> 027: 0.364811    1.080230    3.434353    0.219170    0.022084    0.014864    0.757319    
#> 028: 0.395028    1.065700    3.435197    0.234743    0.020980    0.014121    0.753123    
#> 029: 0.394017    1.055489    3.427687    0.223006    0.023829    0.013415    0.767069    
#> 030: 0.415267    1.067124    3.437866    0.211856    0.022638    0.012744    0.755617    
#> 031: 0.400797    1.039703    3.446348    0.201263    0.024021    0.012852    0.752223    
#> 032: 0.413368    1.038141    3.457629    0.191200    0.022820    0.012209    0.747012    
#> 033: 0.419786    1.055357    3.447007    0.181640    0.021679    0.011599    0.762688    
#> 034: 0.435610    1.044138    3.456638    0.184829    0.026227    0.011252    0.736470    
#> 035: 0.370370    1.015558    3.450875    0.175587    0.024915    0.010689    0.739170    
#> 036: 0.366800    1.031238    3.440282    0.166808    0.023670    0.010155    0.748480    
#> 037: 0.395588    1.032986    3.452267    0.165997    0.022486    0.010080    0.739018    
#> 038: 0.395508    1.040414    3.441511    0.157697    0.021362    0.011646    0.744150    
#> 039: 0.418279    1.030734    3.452771    0.159505    0.020294    0.014057    0.732046    
#> 040: 0.396934    1.025308    3.462983    0.165283    0.019279    0.016414    0.747396    
#> 041: 0.389295    1.019628    3.446107    0.157019    0.018315    0.015594    0.748596    
#> 042: 0.436123    1.028622    3.451696    0.213928    0.017399    0.014880    0.729253    
#> 043: 0.386784    1.044065    3.448349    0.203232    0.016529    0.014136    0.741044    
#> 044: 0.353778    1.046859    3.432658    0.193070    0.015703    0.013429    0.737422    
#> 045: 0.394252    1.056380    3.429953    0.192788    0.014918    0.014428    0.747852    
#> 046: 0.417901    1.057128    3.437554    0.183454    0.017895    0.013706    0.763405    
#> 047: 0.440263    1.046603    3.450035    0.221284    0.017001    0.013718    0.741218    
#> 048: 0.438129    1.027697    3.461121    0.210220    0.017067    0.017841    0.761083    
#> 049: 0.401066    1.020399    3.451383    0.199709    0.016214    0.016949    0.770027    
#> 050: 0.495041    1.016235    3.475553    0.205205    0.015403    0.016102    0.794036    
#> 051: 0.480354    1.022056    3.461370    0.195627    0.014633    0.015297    0.779337    
#> 052: 0.424920    1.044582    3.462505    0.185846    0.013902    0.014532    0.744921    
#> 053: 0.444254    1.039972    3.451359    0.190154    0.013206    0.014484    0.744939    
#> 054: 0.400593    1.032858    3.445691    0.220172    0.015512    0.013759    0.735376    
#> 055: 0.399731    1.028240    3.444517    0.209164    0.014736    0.013511    0.750715    
#> 056: 0.397518    1.023759    3.445459    0.219226    0.020194    0.014979    0.748955    
#> 057: 0.394296    1.028469    3.456056    0.216194    0.019185    0.015492    0.749039    
#> 058: 0.400134    1.036763    3.436135    0.205384    0.018225    0.014717    0.750499    
#> 059: 0.400339    1.021224    3.445117    0.210848    0.021642    0.013981    0.757365    
#> 060: 0.402175    1.020286    3.452008    0.224282    0.024072    0.013282    0.742839    
#> 061: 0.383533    1.027083    3.438924    0.213067    0.022869    0.013160    0.755564    
#> 062: 0.384663    1.054152    3.450752    0.202414    0.033362    0.012502    0.762557    
#> 063: 0.425084    1.036280    3.451586    0.192293    0.037469    0.011877    0.768243    
#> 064: 0.396450    1.049960    3.459659    0.182679    0.035595    0.011283    0.751315    
#> 065: 0.456404    1.022918    3.449984    0.173545    0.033816    0.011128    0.760070    
#> 066: 0.419089    1.034486    3.466940    0.164868    0.032125    0.013116    0.737706    
#> 067: 0.413117    1.042789    3.454683    0.159596    0.030519    0.014054    0.745262    
#> 068: 0.350399    1.055736    3.446779    0.167429    0.028993    0.013351    0.781810    
#> 069: 0.361546    1.083939    3.426392    0.160505    0.027543    0.012684    0.781589    
#> 070: 0.384719    1.077177    3.441912    0.152480    0.026166    0.012243    0.772949    
#> 071: 0.370262    1.094273    3.431235    0.144856    0.024858    0.011630    0.780136    
#> 072: 0.306159    1.053593    3.429317    0.137613    0.023615    0.013209    0.767783    
#> 073: 0.379167    1.065542    3.441266    0.130732    0.022981    0.012549    0.741702    
#> 074: 0.358700    1.057196    3.430070    0.146977    0.022988    0.011921    0.746912    
#> 075: 0.391220    1.055571    3.451128    0.164471    0.022626    0.011325    0.749017    
#> 076: 0.429536    1.066722    3.465613    0.183199    0.025236    0.010759    0.760438    
#> 077: 0.422691    1.051470    3.445688    0.174194    0.024680    0.012474    0.747722    
#> 078: 0.431357    1.050963    3.460705    0.209948    0.024561    0.013755    0.733793    
#> 079: 0.443789    1.040229    3.465285    0.199450    0.027636    0.013067    0.768938    
#> 080: 0.430401    1.038907    3.457344    0.189478    0.034106    0.012414    0.764250    
#> 081: 0.431993    1.036940    3.453965    0.180004    0.032401    0.011793    0.755869    
#> 082: 0.425193    1.025049    3.463833    0.171004    0.030781    0.011203    0.759740    
#> 083: 0.420256    1.029551    3.467509    0.183770    0.029242    0.012306    0.759893    
#> 084: 0.446943    1.041058    3.462628    0.174581    0.027780    0.012973    0.746469    
#> 085: 0.409721    1.076069    3.461711    0.173588    0.026566    0.012324    0.760983    
#> 086: 0.414581    1.059846    3.459165    0.170053    0.025237    0.012437    0.737801    
#> 087: 0.401214    1.038183    3.443358    0.197065    0.023975    0.012422    0.728665    
#> 088: 0.360422    1.036624    3.451117    0.191482    0.022777    0.013453    0.739854    
#> 089: 0.422229    1.053159    3.447747    0.181907    0.022610    0.013084    0.745276    
#> 090: 0.373388    1.047048    3.446842    0.172812    0.021480    0.012430    0.747928    
#> 091: 0.378548    1.049623    3.428488    0.164249    0.020622    0.012586    0.734857    
#> 092: 0.371866    1.075502    3.422958    0.183523    0.019591    0.011957    0.737558    
#> 093: 0.337256    1.066835    3.427025    0.174347    0.018611    0.011359    0.737799    
#> 094: 0.340366    1.082025    3.414916    0.165630    0.018732    0.010791    0.751163    
#> 095: 0.343171    1.073628    3.431236    0.183424    0.017796    0.010252    0.747376    
#> 096: 0.340860    1.078320    3.429507    0.174253    0.020201    0.010925    0.730565    
#> 097: 0.394577    1.089314    3.440630    0.192007    0.019191    0.011270    0.730276    
#> 098: 0.377302    1.072902    3.448439    0.182406    0.018231    0.012575    0.735699    
#> 099: 0.352977    1.051036    3.435995    0.178736    0.017320    0.015704    0.732388    
#> 100: 0.371341    1.039445    3.435560    0.171593    0.016454    0.017199    0.739652    
#> 101: 0.329253    1.036952    3.412065    0.172388    0.015631    0.016339    0.729561    
#> 102: 0.302057    1.044102    3.405110    0.163769    0.014849    0.015522    0.736517    
#> 103: 0.393125    1.049476    3.434213    0.162877    0.014107    0.014746    0.715932    
#> 104: 0.402600    1.040281    3.451657    0.154733    0.014365    0.014009    0.751027    
#> 105: 0.408257    1.041061    3.463972    0.185227    0.017244    0.014355    0.751274    
#> 106: 0.423254    1.044433    3.443465    0.181081    0.016381    0.016572    0.747534    
#> 107: 0.430655    1.055123    3.451587    0.216293    0.015562    0.015743    0.747324    
#> 108: 0.381175    1.063748    3.441224    0.205478    0.017408    0.014956    0.759149    
#> 109: 0.387542    1.051772    3.448279    0.195204    0.016537    0.015134    0.767040    
#> 110: 0.378441    1.053870    3.424174    0.185444    0.015710    0.016809    0.748233    
#> 111: 0.349924    1.070430    3.422983    0.180836    0.014925    0.015968    0.719498    
#> 112: 0.347978    1.054922    3.413693    0.178065    0.015478    0.015170    0.743079    
#> 113: 0.365304    1.051808    3.428797    0.214800    0.014960    0.014411    0.713715    
#> 114: 0.378865    1.057904    3.436885    0.204060    0.014289    0.014484    0.724145    
#> 115: 0.407632    1.034082    3.437007    0.220124    0.013575    0.013760    0.744312    
#> 116: 0.384404    1.041997    3.436427    0.209118    0.013437    0.015191    0.749456    
#> 117: 0.335646    1.062138    3.429685    0.198662    0.013175    0.014431    0.743349    
#> 118: 0.399063    1.066012    3.433783    0.232518    0.013454    0.014508    0.713516    
#> 119: 0.397618    1.051162    3.447252    0.220892    0.012782    0.019097    0.724991    
#> 120: 0.390181    1.042749    3.436933    0.209848    0.012142    0.018142    0.717986    
#> 121: 0.404899    1.056597    3.445655    0.214455    0.014045    0.017235    0.727912    
#> 122: 0.434548    1.053552    3.460870    0.204141    0.013707    0.017732    0.734811    
#> 123: 0.454683    1.052462    3.452691    0.233281    0.013021    0.017436    0.732570    
#> 124: 0.426446    1.080499    3.442120    0.228462    0.012370    0.019217    0.736501    
#> 125: 0.428567    1.072167    3.422815    0.245376    0.011752    0.018256    0.730839    
#> 126: 0.333797    1.078060    3.414885    0.233107    0.011554    0.022667    0.729428    
#> 127: 0.387557    1.059131    3.421891    0.223749    0.010977    0.022375    0.746555    
#> 128: 0.383620    1.053275    3.438829    0.229290    0.014394    0.021256    0.719175    
#> 129: 0.432292    1.062878    3.452013    0.217826    0.018082    0.020193    0.719210    
#> 130: 0.439272    1.065088    3.452568    0.210796    0.018232    0.019184    0.726474    
#> 131: 0.455137    1.052541    3.442430    0.200257    0.020584    0.018596    0.745998    
#> 132: 0.383399    1.043807    3.430918    0.190244    0.022004    0.017666    0.744353    
#> 133: 0.394046    1.043665    3.433717    0.180732    0.020904    0.016783    0.765348    
#> 134: 0.393739    1.037102    3.450200    0.171695    0.019859    0.015944    0.760964    
#> 135: 0.368094    1.021165    3.460930    0.163110    0.018866    0.015404    0.755912    
#> 136: 0.413072    1.022248    3.457442    0.154955    0.017922    0.016289    0.754940    
#> 137: 0.436591    1.019718    3.461115    0.147207    0.017026    0.015683    0.758526    
#> 138: 0.387925    1.045612    3.445617    0.149946    0.018872    0.019844    0.742410    
#> 139: 0.405317    1.048255    3.460194    0.155612    0.018841    0.018852    0.740819    
#> 140: 0.390046    1.044513    3.459855    0.176126    0.021068    0.017909    0.749566    
#> 141: 0.407351    1.030442    3.465220    0.167320    0.022733    0.017014    0.731533    
#> 142: 0.427595    1.014524    3.472111    0.158954    0.021596    0.016163    0.745957    
#> 143: 0.394693    1.037814    3.464357    0.163212    0.020517    0.019023    0.763962    
#> 144: 0.429053    1.042043    3.463661    0.181744    0.019491    0.018072    0.747435    
#> 145: 0.388224    1.056536    3.435810    0.198430    0.018516    0.017169    0.726774    
#> 146: 0.372703    1.072611    3.441875    0.212747    0.017590    0.017496    0.742796    
#> 147: 0.350558    1.068723    3.422788    0.206128    0.016887    0.017267    0.723592    
#> 148: 0.347337    1.069271    3.435209    0.201131    0.016043    0.016403    0.736022    
#> 149: 0.387999    1.063799    3.433614    0.191074    0.019015    0.015583    0.738846    
#> 150: 0.381518    1.064250    3.429316    0.181521    0.023810    0.014804    0.743805    
#> 151: 0.353500    1.077814    3.429647    0.209727    0.023581    0.014195    0.728656    
#> 152: 0.357163    1.073318    3.436534    0.166652    0.019431    0.013784    0.722703    
#> 153: 0.362890    1.075376    3.444507    0.153429    0.018867    0.015378    0.736890    
#> 154: 0.407704    1.074517    3.450834    0.179979    0.012652    0.017120    0.737428    
#> 155: 0.379615    1.053971    3.441419    0.179173    0.013667    0.019790    0.728335    
#> 156: 0.389589    1.053422    3.447179    0.156592    0.014886    0.023794    0.746064    
#> 157: 0.419397    1.059111    3.464943    0.164233    0.018048    0.023978    0.740870    
#> 158: 0.456622    1.062250    3.462101    0.184261    0.021685    0.020563    0.732396    
#> 159: 0.385474    1.069014    3.454396    0.175873    0.016831    0.018512    0.727403    
#> 160: 0.419683    1.051166    3.462588    0.190799    0.021471    0.017158    0.726505    
#> 161: 0.395700    1.048486    3.450070    0.200120    0.024015    0.015637    0.733009    
#> 162: 0.387521    1.068162    3.443429    0.174572    0.021491    0.014617    0.725282    
#> 163: 0.402239    1.057622    3.433866    0.154820    0.024003    0.012753    0.716563    
#> 164: 0.409937    1.058106    3.448726    0.140955    0.020510    0.014500    0.736287    
#> 165: 0.414476    1.069853    3.451766    0.164284    0.017551    0.014755    0.732260    
#> 166: 0.457700    1.084168    3.451386    0.177510    0.017714    0.013532    0.743148    
#> 167: 0.442747    1.070856    3.458905    0.192453    0.015267    0.017476    0.759758    
#> 168: 0.431422    1.083233    3.454977    0.160926    0.012611    0.017376    0.766487    
#> 169: 0.388490    1.088315    3.440889    0.135163    0.012436    0.015642    0.770143    
#> 170: 0.407337    1.058938    3.448480    0.135156    0.011497    0.015211    0.752350    
#> 171: 0.386421    1.066885    3.444903    0.146750    0.012624    0.014173    0.738305    
#> 172: 0.385674    1.066438    3.447439    0.153719    0.011866    0.012252    0.745035    
#> 173: 0.360659    1.085024    3.430695    0.155854    0.012169    0.015048    0.744122    
#> 174: 0.373678    1.080931    3.439202    0.150244    0.011309    0.017171    0.758626    
#> 175: 0.387188    1.071583    3.429405    0.166934    0.012078    0.016317    0.746662    
#> 176: 0.372058    1.071285    3.442518    0.137973    0.010291    0.015737    0.737407    
#> 177: 0.409398    1.068081    3.458568    0.150150    0.011824    0.014966    0.731694    
#> 178: 0.415264    1.059697    3.449791    0.177423    0.015871    0.016398    0.730830    
#> 179: 0.428256    1.060008    3.449008    0.178885    0.015997    0.015940    0.728092    
#> 180: 0.372060    1.049279    3.436276    0.158825    0.015452    0.019208    0.728725    
#> 181: 0.376261    1.030595    3.426936    0.189550    0.013888    0.018379    0.714377    
#> 182: 0.339565    1.037284    3.412302    0.218945    0.011037    0.019060    0.743900    
#> 183: 0.373643    1.047111    3.422262    0.204347    0.009447    0.020831    0.718224    
#> 184: 0.392648    1.044623    3.431505    0.188201    0.009246    0.020228    0.737120    
#> 185: 0.370342    1.058363    3.434388    0.204835    0.009491    0.017859    0.727943    
#> 186: 0.338715    1.075819    3.424741    0.194963    0.011514    0.020589    0.738728    
#> 187: 0.362502    1.061184    3.437386    0.165133    0.011120    0.024205    0.755772    
#> 188: 0.367987    1.079186    3.432685    0.151925    0.015745    0.019764    0.762635    
#> 189: 0.382688    1.095275    3.439466    0.175876    0.018679    0.016144    0.754687    
#> 190: 0.368926    1.088332    3.443233    0.149619    0.019547    0.016544    0.743089    
#> 191: 0.368723    1.097416    3.430788    0.229120    0.017713    0.014459    0.735789    
#> 192: 0.347443    1.085776    3.431349    0.209407    0.014474    0.013784    0.744074    
#> 193: 0.386787    1.084636    3.436798    0.187081    0.013035    0.015007    0.724957    
#> 194: 0.346776    1.073469    3.423234    0.187880    0.013605    0.014323    0.749007    
#> 195: 0.321419    1.072040    3.418000    0.151132    0.012029    0.016438    0.745404    
#> 196: 0.324225    1.081878    3.425753    0.168697    0.012589    0.018194    0.754484    
#> 197: 0.302299    1.094452    3.439145    0.157530    0.014553    0.017887    0.756672    
#> 198: 0.384792    1.073497    3.433178    0.182463    0.008642    0.019684    0.731518    
#> 199: 0.355345    1.066173    3.433896    0.186252    0.011681    0.017210    0.743902    
#> 200: 0.355938    1.062278    3.435179    0.177415    0.013803    0.016227    0.746888    
#> 201: 0.359171    1.055776    3.442766    0.164031    0.014929    0.016869    0.750482    
#> 202: 0.373272    1.053704    3.444704    0.165093    0.014328    0.017493    0.748804    
#> 203: 0.386867    1.051398    3.444576    0.177037    0.013780    0.017742    0.745526    
#> 204: 0.395381    1.046420    3.446217    0.189847    0.013547    0.017912    0.744564    
#> 205: 0.397390    1.046194    3.447169    0.202609    0.013236    0.018268    0.742894    
#> 206: 0.397279    1.048353    3.446838    0.207672    0.012952    0.018313    0.742737    
#> 207: 0.397991    1.048132    3.446074    0.210561    0.012386    0.018528    0.741565    
#> 208: 0.400851    1.045807    3.447365    0.207598    0.012065    0.018277    0.740240    
#> 209: 0.401653    1.044094    3.447613    0.204110    0.012040    0.018350    0.739614    
#> 210: 0.406359    1.043750    3.448871    0.203388    0.012046    0.018447    0.738796    
#> 211: 0.406461    1.044530    3.449512    0.203021    0.012132    0.018512    0.739202    
#> 212: 0.405621    1.044582    3.449478    0.202811    0.012049    0.018609    0.739533    
#> 213: 0.406295    1.043071    3.449601    0.202220    0.011996    0.018738    0.739957    
#> 214: 0.407463    1.041829    3.449983    0.199022    0.012100    0.018545    0.740344    
#> 215: 0.408028    1.041496    3.450934    0.197258    0.012087    0.018591    0.741496    
#> 216: 0.409607    1.040376    3.451023    0.197886    0.012101    0.018722    0.742716    
#> 217: 0.409038    1.040892    3.451137    0.196667    0.012122    0.018669    0.742321    
#> 218: 0.407571    1.042214    3.450726    0.193887    0.012037    0.018559    0.742713    
#> 219: 0.406488    1.043020    3.449717    0.192533    0.012020    0.018351    0.742287    
#> 220: 0.405917    1.043735    3.449637    0.190864    0.011987    0.018228    0.741668    
#> 221: 0.405768    1.043996    3.449659    0.188916    0.011836    0.018154    0.741579    
#> 222: 0.405177    1.043594    3.449259    0.187348    0.011772    0.018182    0.740706    
#> 223: 0.406440    1.043768    3.449470    0.186742    0.011827    0.018294    0.740170    
#> 224: 0.407259    1.043897    3.449339    0.185301    0.011818    0.018333    0.739926    
#> 225: 0.408386    1.042833    3.450210    0.184750    0.011896    0.018340    0.740286    
#> 226: 0.409172    1.042073    3.449903    0.185085    0.011907    0.018287    0.741286    
#> 227: 0.408856    1.041542    3.450021    0.185178    0.011915    0.018317    0.741478    
#> 228: 0.407630    1.041732    3.449591    0.184739    0.012021    0.018351    0.741381    
#> 229: 0.406975    1.041383    3.449412    0.184186    0.012063    0.018325    0.740736    
#> 230: 0.408317    1.041019    3.449469    0.183852    0.012018    0.018387    0.740617    
#> 231: 0.408391    1.040815    3.449698    0.184001    0.011994    0.018444    0.740407    
#> 232: 0.408088    1.040752    3.449953    0.184525    0.012075    0.018516    0.740280    
#> 233: 0.407626    1.040347    3.449851    0.184911    0.012045    0.018562    0.739844    
#> 234: 0.407444    1.040330    3.449746    0.185343    0.011946    0.018683    0.739596    
#> 235: 0.406763    1.040438    3.449408    0.185135    0.011827    0.018729    0.739571    
#> 236: 0.406506    1.041259    3.449122    0.185713    0.011759    0.018739    0.739917    
#> 237: 0.407336    1.041548    3.449101    0.185364    0.011720    0.018741    0.739999    
#> 238: 0.407396    1.041802    3.448899    0.184745    0.011760    0.018724    0.740248    
#> 239: 0.407224    1.042504    3.448696    0.185106    0.011854    0.018835    0.740068    
#> 240: 0.407695    1.042802    3.448861    0.186761    0.011898    0.018977    0.739769    
#> 241: 0.408567    1.042813    3.449049    0.187757    0.011871    0.018957    0.739696    
#> 242: 0.407982    1.042956    3.448697    0.187458    0.011895    0.018939    0.740030    
#> 243: 0.407058    1.043372    3.448535    0.187261    0.011912    0.018966    0.740532    
#> 244: 0.406115    1.043484    3.448473    0.187194    0.011957    0.018900    0.741120    
#> 245: 0.406507    1.043230    3.448798    0.186546    0.011992    0.018864    0.741345    
#> 246: 0.406048    1.043053    3.448670    0.185444    0.012051    0.018838    0.741633    
#> 247: 0.405526    1.042739    3.448796    0.185417    0.012096    0.018844    0.741641    
#> 248: 0.404878    1.042887    3.448392    0.185593    0.012164    0.018852    0.741583    
#> 249: 0.404440    1.042926    3.448347    0.186150    0.012261    0.018863    0.741703    
#> 250: 0.404786    1.043072    3.448423    0.186751    0.012269    0.018844    0.741874    
#> 251: 0.405598    1.043071    3.448819    0.186619    0.012293    0.018777    0.742123    
#> 252: 0.406204    1.043225    3.449085    0.186383    0.012336    0.018716    0.742004    
#> 253: 0.406011    1.043457    3.449070    0.186565    0.012407    0.018639    0.742053    
#> 254: 0.406110    1.043813    3.449362    0.186675    0.012448    0.018598    0.741954    
#> 255: 0.405958    1.043949    3.449428    0.187086    0.012433    0.018552    0.742216    
#> 256: 0.406542    1.043911    3.449435    0.187285    0.012395    0.018503    0.742108    
#> 257: 0.406821    1.043946    3.449110    0.187545    0.012395    0.018392    0.742150    
#> 258: 0.406964    1.043811    3.449176    0.187604    0.012396    0.018356    0.741838    
#> 259: 0.407314    1.043815    3.449182    0.188081    0.012490    0.018309    0.741519    
#> 260: 0.407517    1.043957    3.449414    0.187644    0.012569    0.018299    0.741143    
#> 261: 0.407629    1.043857    3.449543    0.186887    0.012595    0.018308    0.741259    
#> 262: 0.408524    1.043689    3.449758    0.187232    0.012659    0.018311    0.741080    
#> 263: 0.408524    1.043835    3.449728    0.186749    0.012679    0.018286    0.740961    
#> 264: 0.407930    1.043997    3.449629    0.186496    0.012755    0.018255    0.740863    
#> 265: 0.408593    1.044170    3.449704    0.187014    0.012776    0.018282    0.740629    
#> 266: 0.408847    1.044419    3.449676    0.187472    0.012840    0.018289    0.740472    
#> 267: 0.408756    1.044417    3.449806    0.187733    0.012845    0.018277    0.740511    
#> 268: 0.408695    1.044311    3.449734    0.187686    0.012840    0.018260    0.740412    
#> 269: 0.409224    1.044196    3.449796    0.188148    0.012817    0.018229    0.740316    
#> 270: 0.409372    1.043907    3.449852    0.187982    0.012801    0.018244    0.740241    
#> 271: 0.409404    1.043665    3.449853    0.187810    0.012841    0.018256    0.740512    
#> 272: 0.409410    1.043608    3.449837    0.188062    0.012844    0.018334    0.740605    
#> 273: 0.409307    1.043807    3.449730    0.188335    0.012818    0.018389    0.740695    
#> 274: 0.408611    1.044026    3.449599    0.187710    0.012771    0.018422    0.740691    
#> 275: 0.408498    1.044119    3.449499    0.187492    0.012732    0.018452    0.740577    
#> 276: 0.408412    1.044297    3.449566    0.187281    0.012726    0.018433    0.740570    
#> 277: 0.408546    1.044388    3.449753    0.187228    0.012726    0.018412    0.740498    
#> 278: 0.408662    1.044662    3.449813    0.186946    0.012792    0.018360    0.740384    
#> 279: 0.408522    1.044731    3.449815    0.186191    0.012870    0.018328    0.740440    
#> 280: 0.408656    1.044913    3.449935    0.186089    0.012932    0.018297    0.740325    
#> 281: 0.408743    1.045011    3.450026    0.185976    0.012967    0.018289    0.740350    
#> 282: 0.408624    1.045258    3.449961    0.186452    0.013024    0.018279    0.740420    
#> 283: 0.408803    1.045553    3.449941    0.186394    0.013110    0.018220    0.740510    
#> 284: 0.408893    1.045646    3.449929    0.186710    0.013112    0.018164    0.740440    
#> 285: 0.409284    1.045754    3.449889    0.187007    0.013179    0.018144    0.740609    
#> 286: 0.409223    1.045835    3.449855    0.187054    0.013249    0.018092    0.740628    
#> 287: 0.409005    1.046068    3.449747    0.187209    0.013280    0.018037    0.740658    
#> 288: 0.409076    1.046161    3.449798    0.187118    0.013305    0.018017    0.740840    
#> 289: 0.409135    1.046219    3.449771    0.187266    0.013308    0.018003    0.740912    
#> 290: 0.408976    1.046277    3.449765    0.187497    0.013282    0.017999    0.740958    
#> 291: 0.408868    1.046560    3.449726    0.187462    0.013284    0.018018    0.740892    
#> 292: 0.408504    1.046761    3.449532    0.187444    0.013249    0.018000    0.740948    
#> 293: 0.408152    1.046989    3.449259    0.187800    0.013204    0.017988    0.740794    
#> 294: 0.407618    1.047276    3.448986    0.188122    0.013183    0.017995    0.740750    
#> 295: 0.407427    1.047174    3.448926    0.188319    0.013155    0.018028    0.740644    
#> 296: 0.407117    1.047170    3.448836    0.188140    0.013127    0.018052    0.740667    
#> 297: 0.407080    1.047374    3.448626    0.188432    0.013108    0.018089    0.740706    
#> 298: 0.406806    1.047530    3.448433    0.188375    0.013110    0.018050    0.740647    
#> 299: 0.406853    1.047713    3.448289    0.188523    0.013098    0.017997    0.740665    
#> 300: 0.406908    1.047788    3.448368    0.188566    0.013105    0.017984    0.740604    
#> 301: 0.406971    1.047801    3.448330    0.188281    0.013131    0.017937    0.740656    
#> 302: 0.407064    1.047856    3.448316    0.187997    0.013114    0.017905    0.740472    
#> 303: 0.406898    1.047907    3.448263    0.188090    0.013103    0.017896    0.740068    
#> 304: 0.406799    1.047997    3.448156    0.187972    0.013096    0.017887    0.739905    
#> 305: 0.406375    1.047974    3.447950    0.187899    0.013123    0.017861    0.739781    
#> 306: 0.405780    1.048009    3.447691    0.187973    0.013132    0.017846    0.739670    
#> 307: 0.405723    1.047839    3.447658    0.188256    0.013177    0.017853    0.739701    
#> 308: 0.405542    1.047587    3.447666    0.188210    0.013225    0.017835    0.739768    
#> 309: 0.405549    1.047520    3.447568    0.188089    0.013249    0.017816    0.739888    
#> 310: 0.405648    1.047479    3.447450    0.187605    0.013257    0.017799    0.740199    
#> 311: 0.405641    1.047357    3.447420    0.187470    0.013251    0.017811    0.740140    
#> 312: 0.405540    1.047272    3.447311    0.187644    0.013246    0.017837    0.739952    
#> 313: 0.405477    1.047181    3.447288    0.187573    0.013233    0.017832    0.740106    
#> 314: 0.405222    1.047158    3.447188    0.187464    0.013234    0.017843    0.740067    
#> 315: 0.404787    1.047083    3.447043    0.187488    0.013216    0.017835    0.740051    
#> 316: 0.404604    1.047078    3.446920    0.187528    0.013185    0.017828    0.740046    
#> 317: 0.404489    1.047132    3.446862    0.187459    0.013170    0.017860    0.740155    
#> 318: 0.404453    1.047269    3.446737    0.187432    0.013121    0.017868    0.740121    
#> 319: 0.404506    1.047210    3.446774    0.187561    0.013080    0.017891    0.740206    
#> 320: 0.404064    1.047268    3.446543    0.187582    0.013086    0.017880    0.740231    
#> 321: 0.403459    1.047331    3.446295    0.187780    0.013075    0.017859    0.740263    
#> 322: 0.403005    1.047367    3.446072    0.187532    0.013049    0.017842    0.740360    
#> 323: 0.402458    1.047417    3.445975    0.187412    0.013049    0.017822    0.740350    
#> 324: 0.402175    1.047550    3.445961    0.187145    0.013036    0.017819    0.740321    
#> 325: 0.401849    1.047770    3.445849    0.187028    0.013046    0.017839    0.740255    
#> 326: 0.401697    1.047760    3.445807    0.187224    0.013053    0.017826    0.740303    
#> 327: 0.401738    1.047749    3.445801    0.187322    0.013065    0.017815    0.740379    
#> 328: 0.401784    1.047833    3.445785    0.187406    0.013071    0.017767    0.740319    
#> 329: 0.401865    1.047751    3.445857    0.187630    0.013073    0.017738    0.740256    
#> 330: 0.401524    1.047787    3.445801    0.187990    0.013064    0.017730    0.740327    
#> 331: 0.401626    1.047891    3.445856    0.188348    0.013068    0.017740    0.740258    
#> 332: 0.401502    1.047872    3.445814    0.188726    0.013085    0.017734    0.740273    
#> 333: 0.401343    1.047797    3.445721    0.189043    0.013090    0.017708    0.740311    
#> 334: 0.401200    1.047695    3.445567    0.189013    0.013102    0.017704    0.740273    
#> 335: 0.400844    1.047606    3.445415    0.188963    0.013119    0.017696    0.740322    
#> 336: 0.400520    1.047815    3.445297    0.188962    0.013114    0.017690    0.740338    
#> 337: 0.400240    1.047974    3.445181    0.188897    0.013132    0.017662    0.740392    
#> 338: 0.400360    1.048104    3.445193    0.188713    0.013167    0.017615    0.740481    
#> 339: 0.400100    1.048233    3.445127    0.188514    0.013194    0.017591    0.740566    
#> 340: 0.399955    1.048145    3.445156    0.188258    0.013250    0.017573    0.740595    
#> 341: 0.400329    1.048043    3.445320    0.188018    0.013308    0.017564    0.740458    
#> 342: 0.400086    1.047917    3.445326    0.187912    0.013365    0.017551    0.740418    
#> 343: 0.399751    1.047876    3.445331    0.187911    0.013400    0.017533    0.740345    
#> 344: 0.400025    1.047853    3.445408    0.188252    0.013399    0.017540    0.740391    
#> 345: 0.400132    1.047829    3.445481    0.188381    0.013422    0.017540    0.740260    
#> 346: 0.400031    1.047992    3.445384    0.188495    0.013448    0.017505    0.740217    
#> 347: 0.399839    1.048037    3.445192    0.188337    0.013460    0.017493    0.740394    
#> 348: 0.399621    1.048215    3.445037    0.188299    0.013516    0.017465    0.740381    
#> 349: 0.399499    1.048325    3.444960    0.188491    0.013532    0.017482    0.740287    
#> 350: 0.399234    1.048410    3.444833    0.188497    0.013543    0.017489    0.740209    
#> 351: 0.399179    1.048631    3.444679    0.188649    0.013530    0.017485    0.740107    
#> 352: 0.398678    1.048781    3.444571    0.188758    0.013537    0.017464    0.740445    
#> 353: 0.398545    1.049035    3.444433    0.188725    0.013569    0.017480    0.740583    
#> 354: 0.398543    1.049175    3.444298    0.189025    0.013562    0.017501    0.740583    
#> 355: 0.398702    1.049121    3.444281    0.188969    0.013562    0.017495    0.740480    
#> 356: 0.398697    1.049100    3.444325    0.189041    0.013575    0.017501    0.740590    
#> 357: 0.398761    1.049167    3.444343    0.189102    0.013586    0.017491    0.740629    
#> 358: 0.398834    1.049254    3.444342    0.189043    0.013573    0.017483    0.740540    
#> 359: 0.398681    1.049399    3.444273    0.188997    0.013545    0.017474    0.740561    
#> 360: 0.398412    1.049487    3.444131    0.189001    0.013540    0.017468    0.740536    
#> 361: 0.398075    1.049542    3.444064    0.188907    0.013541    0.017476    0.740545    
#> 362: 0.398010    1.049610    3.443943    0.188691    0.013552    0.017458    0.740453    
#> 363: 0.397994    1.049540    3.443987    0.188748    0.013538    0.017436    0.740370    
#> 364: 0.398129    1.049463    3.444048    0.188742    0.013536    0.017441    0.740395    
#> 365: 0.398156    1.049288    3.444084    0.188888    0.013517    0.017474    0.740512    
#> 366: 0.398172    1.049177    3.444041    0.189084    0.013500    0.017510    0.740506    
#> 367: 0.398096    1.049175    3.443999    0.188960    0.013495    0.017524    0.740490    
#> 368: 0.398019    1.049233    3.443875    0.188767    0.013499    0.017543    0.740540    
#> 369: 0.397818    1.049254    3.443811    0.188755    0.013509    0.017546    0.740604    
#> 370: 0.397525    1.049368    3.443724    0.188562    0.013523    0.017549    0.740589    
#> 371: 0.397162    1.049556    3.443506    0.188544    0.013541    0.017525    0.740504    
#> 372: 0.396991    1.049651    3.443436    0.188553    0.013530    0.017519    0.740469    
#> 373: 0.396718    1.049822    3.443421    0.188323    0.013523    0.017517    0.740563    
#> 374: 0.396500    1.049888    3.443334    0.187995    0.013516    0.017499    0.740566    
#> 375: 0.396334    1.049898    3.443335    0.187687    0.013522    0.017486    0.740612    
#> 376: 0.396165    1.049979    3.443316    0.187424    0.013507    0.017493    0.740589    
#> 377: 0.396059    1.050104    3.443355    0.187308    0.013506    0.017488    0.740618    
#> 378: 0.395842    1.050091    3.443302    0.187474    0.013496    0.017480    0.740636    
#> 379: 0.395801    1.050086    3.443303    0.187523    0.013498    0.017470    0.740656    
#> 380: 0.395678    1.050069    3.443303    0.187437    0.013494    0.017456    0.740676    
#> 381: 0.395677    1.050005    3.443344    0.187373    0.013497    0.017446    0.740734    
#> 382: 0.395850    1.049920    3.443408    0.187216    0.013496    0.017422    0.740719    
#> 383: 0.396072    1.049837    3.443435    0.187339    0.013492    0.017430    0.740623    
#> 384: 0.395863    1.049784    3.443415    0.187434    0.013479    0.017424    0.740601    
#> 385: 0.395675    1.049809    3.443392    0.187475    0.013473    0.017439    0.740516    
#> 386: 0.395622    1.049971    3.443385    0.187487    0.013493    0.017436    0.740447    
#> 387: 0.395651    1.050051    3.443479    0.187412    0.013505    0.017437    0.740472    
#> 388: 0.395878    1.050031    3.443593    0.187582    0.013514    0.017461    0.740440    
#> 389: 0.395843    1.049909    3.443633    0.187521    0.013518    0.017464    0.740608    
#> 390: 0.395818    1.049907    3.443625    0.187734    0.013527    0.017472    0.740682    
#> 391: 0.396188    1.049859    3.443686    0.187744    0.013512    0.017477    0.740709    
#> 392: 0.396295    1.049859    3.443760    0.187545    0.013487    0.017472    0.740831    
#> 393: 0.396165    1.049861    3.443693    0.187424    0.013473    0.017445    0.740849    
#> 394: 0.396092    1.049931    3.443633    0.187224    0.013460    0.017463    0.740801    
#> 395: 0.396140    1.050033    3.443629    0.187221    0.013451    0.017463    0.740683    
#> 396: 0.396274    1.050119    3.443632    0.187273    0.013432    0.017469    0.740585    
#> 397: 0.396588    1.050045    3.443738    0.187470    0.013421    0.017474    0.740571    
#> 398: 0.396881    1.049986    3.443812    0.187722    0.013424    0.017464    0.740566    
#> 399: 0.397180    1.050038    3.443880    0.187840    0.013457    0.017462    0.740410    
#> 400: 0.397258    1.050147    3.443858    0.187872    0.013471    0.017451    0.740423    
#> 401: 0.397228    1.050214    3.443827    0.187852    0.013475    0.017469    0.740441    
#> 402: 0.397043    1.050301    3.443736    0.187892    0.013467    0.017478    0.740334    
#> 403: 0.397128    1.050317    3.443661    0.188021    0.013461    0.017489    0.740301    
#> 404: 0.397149    1.050455    3.443552    0.188171    0.013469    0.017494    0.740262    
#> 405: 0.397049    1.050551    3.443489    0.188501    0.013464    0.017513    0.740403    
#> 406: 0.396948    1.050629    3.443393    0.188587    0.013464    0.017517    0.740523    
#> 407: 0.396939    1.050743    3.443412    0.188582    0.013474    0.017509    0.740493    
#> 408: 0.397043    1.050859    3.443387    0.188676    0.013476    0.017501    0.740588    
#> 409: 0.397135    1.050786    3.443392    0.188602    0.013467    0.017479    0.740591    
#> 410: 0.397113    1.050750    3.443385    0.188439    0.013471    0.017449    0.740580    
#> 411: 0.397192    1.050632    3.443366    0.188400    0.013467    0.017443    0.740576    
#> 412: 0.397294    1.050662    3.443368    0.188331    0.013484    0.017447    0.740528    
#> 413: 0.397263    1.050693    3.443313    0.188267    0.013500    0.017443    0.740468    
#> 414: 0.397117    1.050730    3.443284    0.188280    0.013508    0.017425    0.740446    
#> 415: 0.397153    1.050704    3.443246    0.188259    0.013499    0.017418    0.740472    
#> 416: 0.397212    1.050732    3.443261    0.188250    0.013507    0.017404    0.740404    
#> 417: 0.397217    1.050678    3.443269    0.188194    0.013519    0.017390    0.740401    
#> 418: 0.397167    1.050590    3.443339    0.188242    0.013523    0.017388    0.740364    
#> 419: 0.397251    1.050619    3.443404    0.188223    0.013526    0.017387    0.740389    
#> 420: 0.397338    1.050636    3.443466    0.188153    0.013531    0.017366    0.740338    
#> 421: 0.397216    1.050658    3.443495    0.188094    0.013529    0.017348    0.740326    
#> 422: 0.397325    1.050639    3.443501    0.188120    0.013527    0.017333    0.740306    
#> 423: 0.397535    1.050652    3.443533    0.188077    0.013537    0.017320    0.740348    
#> 424: 0.397471    1.050684    3.443494    0.188026    0.013531    0.017308    0.740260    
#> 425: 0.397665    1.050714    3.443507    0.188019    0.013522    0.017306    0.740364    
#> 426: 0.397715    1.050752    3.443492    0.187879    0.013516    0.017293    0.740438    
#> 427: 0.397538    1.050745    3.443445    0.187704    0.013505    0.017284    0.740453    
#> 428: 0.397243    1.050822    3.443391    0.187549    0.013506    0.017283    0.740528    
#> 429: 0.397083    1.050867    3.443328    0.187408    0.013500    0.017288    0.740613    
#> 430: 0.396878    1.050928    3.443249    0.187385    0.013495    0.017286    0.740682    
#> 431: 0.396665    1.050952    3.443177    0.187353    0.013493    0.017286    0.740572    
#> 432: 0.396724    1.051028    3.443221    0.187468    0.013486    0.017317    0.740585    
#> 433: 0.396692    1.051103    3.443269    0.187486    0.013485    0.017328    0.740588    
#> 434: 0.396651    1.051029    3.443286    0.187519    0.013483    0.017326    0.740529    
#> 435: 0.396742    1.050958    3.443282    0.187442    0.013471    0.017320    0.740589    
#> 436: 0.396664    1.050906    3.443326    0.187467    0.013471    0.017333    0.740551    
#> 437: 0.396710    1.050878    3.443350    0.187527    0.013470    0.017325    0.740526    
#> 438: 0.396727    1.050950    3.443404    0.187542    0.013468    0.017329    0.740486    
#> 439: 0.396847    1.050987    3.443432    0.187514    0.013454    0.017323    0.740424    
#> 440: 0.396842    1.051042    3.443485    0.187446    0.013437    0.017337    0.740477    
#> 441: 0.396922    1.051008    3.443542    0.187352    0.013422    0.017349    0.740527    
#> 442: 0.396783    1.051047    3.443565    0.187458    0.013419    0.017351    0.740448    
#> 443: 0.396719    1.051089    3.443524    0.187623    0.013413    0.017362    0.740439    
#> 444: 0.396650    1.051095    3.443450    0.187735    0.013408    0.017365    0.740517    
#> 445: 0.396499    1.051113    3.443403    0.187847    0.013415    0.017342    0.740687    
#> 446: 0.396212    1.051180    3.443304    0.187928    0.013428    0.017319    0.740782    
#> 447: 0.396188    1.051199    3.443288    0.187846    0.013436    0.017315    0.740804    
#> 448: 0.396148    1.051260    3.443318    0.187836    0.013440    0.017314    0.740782    
#> 449: 0.396069    1.051344    3.443367    0.187729    0.013434    0.017319    0.740793    
#> 450: 0.396000    1.051429    3.443333    0.187670    0.013431    0.017336    0.740798    
#> 451: 0.395956    1.051502    3.443302    0.187710    0.013426    0.017337    0.740861    
#> 452: 0.395818    1.051600    3.443276    0.187855    0.013430    0.017339    0.740816    
#> 453: 0.395692    1.051702    3.443253    0.187890    0.013426    0.017337    0.740761    
#> 454: 0.395499    1.051852    3.443168    0.187949    0.013428    0.017326    0.740803    
#> 455: 0.395300    1.051955    3.443072    0.188088    0.013425    0.017313    0.740885    
#> 456: 0.395014    1.052061    3.442961    0.188285    0.013429    0.017308    0.740897    
#> 457: 0.394863    1.052098    3.442938    0.188232    0.013428    0.017308    0.740904    
#> 458: 0.394725    1.052190    3.442927    0.188182    0.013424    0.017304    0.740991    
#> 459: 0.394617    1.052250    3.442922    0.188048    0.013418    0.017304    0.740994    
#> 460: 0.394465    1.052282    3.442821    0.187923    0.013412    0.017313    0.741044    
#> 461: 0.394322    1.052322    3.442794    0.187779    0.013391    0.017311    0.741132    
#> 462: 0.394188    1.052379    3.442792    0.187705    0.013373    0.017314    0.741185    
#> 463: 0.394160    1.052364    3.442815    0.187729    0.013391    0.017325    0.741172    
#> 464: 0.394181    1.052381    3.442784    0.187817    0.013388    0.017317    0.741126    
#> 465: 0.394144    1.052317    3.442770    0.187793    0.013378    0.017318    0.741094    
#> 466: 0.394118    1.052312    3.442726    0.187810    0.013369    0.017319    0.741100    
#> 467: 0.393959    1.052307    3.442701    0.187831    0.013356    0.017303    0.741073    
#> 468: 0.393945    1.052298    3.442737    0.187869    0.013345    0.017302    0.741092    
#> 469: 0.393893    1.052339    3.442751    0.187948    0.013342    0.017291    0.741174    
#> 470: 0.393962    1.052397    3.442728    0.188010    0.013331    0.017281    0.741254    
#> 471: 0.393940    1.052405    3.442755    0.188008    0.013310    0.017271    0.741283    
#> 472: 0.393903    1.052350    3.442775    0.187955    0.013300    0.017256    0.741331    
#> 473: 0.393775    1.052407    3.442763    0.187774    0.013289    0.017245    0.741316    
#> 474: 0.393822    1.052426    3.442783    0.187689    0.013290    0.017236    0.741369    
#> 475: 0.393862    1.052449    3.442812    0.187569    0.013284    0.017228    0.741438    
#> 476: 0.393840    1.052460    3.442787    0.187526    0.013269    0.017224    0.741504    
#> 477: 0.393839    1.052556    3.442796    0.187519    0.013260    0.017232    0.741480    
#> 478: 0.393640    1.052567    3.442785    0.187471    0.013248    0.017234    0.741501    
#> 479: 0.393656    1.052595    3.442755    0.187514    0.013229    0.017247    0.741506    
#> 480: 0.393624    1.052570    3.442744    0.187520    0.013237    0.017241    0.741504    
#> 481: 0.393457    1.052514    3.442718    0.187453    0.013242    0.017229    0.741497    
#> 482: 0.393461    1.052458    3.442710    0.187465    0.013253    0.017227    0.741501    
#> 483: 0.393422    1.052438    3.442720    0.187451    0.013262    0.017224    0.741440    
#> 484: 0.393425    1.052377    3.442740    0.187446    0.013268    0.017223    0.741431    
#> 485: 0.393504    1.052403    3.442766    0.187509    0.013268    0.017215    0.741443    
#> 486: 0.393580    1.052444    3.442773    0.187444    0.013258    0.017202    0.741389    
#> 487: 0.393711    1.052466    3.442809    0.187274    0.013252    0.017205    0.741369    
#> 488: 0.393794    1.052405    3.442842    0.187287    0.013251    0.017205    0.741375    
#> 489: 0.393901    1.052340    3.442843    0.187192    0.013256    0.017204    0.741436    
#> 490: 0.393941    1.052358    3.442849    0.187176    0.013253    0.017208    0.741441    
#> 491: 0.394006    1.052372    3.442894    0.187159    0.013243    0.017219    0.741447    
#> 492: 0.394079    1.052394    3.442931    0.187270    0.013223    0.017244    0.741452    
#> 493: 0.394130    1.052431    3.442955    0.187356    0.013213    0.017262    0.741465    
#> 494: 0.394257    1.052493    3.442920    0.187323    0.013204    0.017261    0.741467    
#> 495: 0.394330    1.052526    3.442925    0.187367    0.013187    0.017251    0.741454    
#> 496: 0.394342    1.052559    3.442885    0.187296    0.013180    0.017243    0.741480    
#> 497: 0.394275    1.052502    3.442890    0.187176    0.013179    0.017238    0.741523    
#> 498: 0.394369    1.052444    3.442874    0.187330    0.013185    0.017224    0.741493    
#> 499: 0.394332    1.052448    3.442827    0.187272    0.013186    0.017215    0.741442    
#> 500: 0.394350    1.052419    3.442796    0.187198    0.013170    0.017218    0.741369    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.275271    0.981459    3.441744    0.392690    0.086754    0.016800    1.647620    
#> 002: 0.346120    0.969332    3.490755    0.373055    0.082416    0.015960    1.073258    
#> 003: 0.467921    0.975781    3.498649    0.354402    0.078295    0.015162    0.917277    
#> 004: 0.454569    1.028673    3.496194    0.525615    0.074380    0.014404    0.777794    
#> 005: 0.509257    1.058478    3.489218    0.499334    0.073609    0.013684    0.709590    
#> 006: 0.511823    1.073725    3.480879    0.603449    0.069928    0.013000    0.646285    
#> 007: 0.502263    1.084816    3.471840    0.601209    0.066432    0.012799    0.652499    
#> 008: 0.461915    1.091624    3.465594    0.648873    0.065014    0.012562    0.667287    
#> 009: 0.412666    1.074732    3.462440    0.637230    0.061763    0.013035    0.648814    
#> 010: 0.423293    1.079803    3.457190    0.605368    0.058675    0.012384    0.675115    
#> 011: 0.487109    1.102434    3.453173    0.719158    0.055741    0.011764    0.670737    
#> 012: 0.484195    1.094269    3.452794    0.683200    0.052954    0.012658    0.652833    
#> 013: 0.480185    1.087653    3.460275    0.724856    0.050306    0.017056    0.647143    
#> 014: 0.507451    1.094420    3.466355    0.806018    0.047791    0.018754    0.647505    
#> 015: 0.502325    1.094885    3.478530    0.765717    0.045402    0.017817    0.634082    
#> 016: 0.546411    1.106512    3.489754    0.727431    0.046547    0.016926    0.645812    
#> 017: 0.550350    1.094210    3.484737    0.691059    0.044220    0.016079    0.635601    
#> 018: 0.565038    1.086958    3.473560    0.826702    0.042084    0.015275    0.637550    
#> 019: 0.545691    1.089330    3.482784    0.785367    0.041216    0.014512    0.628684    
#> 020: 0.564446    1.086408    3.487066    0.746099    0.039390    0.014760    0.639219    
#> 021: 0.535603    1.078485    3.489563    0.708794    0.043720    0.014575    0.629721    
#> 022: 0.532525    1.087992    3.492427    0.673354    0.042133    0.014332    0.622784    
#> 023: 0.571047    1.087677    3.500439    0.693678    0.047326    0.014190    0.630725    
#> 024: 0.542316    1.105061    3.493132    0.695944    0.045901    0.013481    0.629705    
#> 025: 0.576106    1.089246    3.488024    0.695136    0.043606    0.013228    0.637694    
#> 026: 0.548140    1.112094    3.480341    0.663161    0.041425    0.013001    0.642855    
#> 027: 0.511124    1.115563    3.475342    0.630003    0.040924    0.015063    0.647877    
#> 028: 0.575344    1.104884    3.488815    0.707982    0.039419    0.014694    0.620876    
#> 029: 0.556491    1.081787    3.487536    0.673938    0.039363    0.016519    0.630570    
#> 030: 0.532417    1.086901    3.484578    0.665248    0.038304    0.019961    0.639867    
#> 031: 0.486619    1.081581    3.483417    0.647155    0.039448    0.018963    0.636435    
#> 032: 0.481212    1.081748    3.471165    0.663083    0.041633    0.018015    0.644999    
#> 033: 0.477793    1.115538    3.458602    0.695409    0.045461    0.017114    0.633126    
#> 034: 0.502021    1.123471    3.460750    0.662587    0.043188    0.016258    0.635923    
#> 035: 0.499094    1.106052    3.460828    0.680553    0.041053    0.015505    0.630904    
#> 036: 0.542062    1.112272    3.466624    0.794119    0.042837    0.014730    0.647023    
#> 037: 0.522882    1.103521    3.470296    0.754413    0.044288    0.014632    0.660011    
#> 038: 0.490688    1.110767    3.463289    0.716693    0.045913    0.016614    0.653882    
#> 039: 0.515891    1.098710    3.465997    0.714568    0.043617    0.017902    0.649595    
#> 040: 0.504078    1.095788    3.475410    0.683754    0.041437    0.020109    0.657814    
#> 041: 0.478400    1.088111    3.465049    0.649566    0.039365    0.024016    0.635522    
#> 042: 0.509740    1.093243    3.471130    0.686147    0.037396    0.026136    0.633006    
#> 043: 0.503166    1.098204    3.468216    0.765730    0.035527    0.024830    0.659980    
#> 044: 0.525592    1.106473    3.463797    0.727443    0.035695    0.023588    0.639983    
#> 045: 0.516519    1.119626    3.458528    0.691071    0.033910    0.022409    0.648713    
#> 046: 0.539570    1.106721    3.471504    0.770793    0.034182    0.022492    0.629559    
#> 047: 0.590796    1.096537    3.465534    1.033363    0.032473    0.028542    0.632192    
#> 048: 0.594869    1.100962    3.465059    1.064382    0.031823    0.027115    0.644828    
#> 049: 0.627504    1.092101    3.483884    1.201193    0.035111    0.025759    0.645146    
#> 050: 0.662502    1.070399    3.492315    1.141133    0.035349    0.024471    0.645520    
#> 051: 0.610484    1.083717    3.491571    1.084077    0.040931    0.023375    0.639975    
#> 052: 0.554824    1.085491    3.494892    1.029873    0.038884    0.022206    0.631861    
#> 053: 0.574063    1.069133    3.492359    0.978379    0.038738    0.021096    0.640990    
#> 054: 0.540936    1.073311    3.484581    0.929460    0.037962    0.020639    0.653093    
#> 055: 0.579288    1.075816    3.490518    1.021584    0.040667    0.019607    0.650117    
#> 056: 0.597008    1.064953    3.486699    0.977275    0.047733    0.018627    0.657444    
#> 057: 0.551045    1.078951    3.483417    0.928411    0.048173    0.017695    0.641279    
#> 058: 0.582108    1.090531    3.465898    1.001023    0.051461    0.016811    0.639455    
#> 059: 0.555146    1.063963    3.473276    0.962418    0.050234    0.019106    0.646019    
#> 060: 0.575252    1.056784    3.486186    0.923582    0.047722    0.018910    0.651471    
#> 061: 0.575930    1.059564    3.500396    0.877403    0.045336    0.026676    0.652469    
#> 062: 0.538390    1.090065    3.489972    0.833533    0.043069    0.031354    0.658342    
#> 063: 0.594259    1.083585    3.488385    0.806296    0.040916    0.029786    0.666867    
#> 064: 0.553383    1.079656    3.478938    0.866664    0.038870    0.028297    0.653787    
#> 065: 0.538194    1.077916    3.470233    0.823330    0.036926    0.026882    0.650917    
#> 066: 0.555491    1.095359    3.470031    0.825044    0.035317    0.025538    0.635734    
#> 067: 0.488861    1.086942    3.466525    0.783792    0.033551    0.024261    0.648111    
#> 068: 0.476879    1.095780    3.478161    0.744602    0.031874    0.023048    0.648826    
#> 069: 0.523389    1.102625    3.470629    0.776877    0.030280    0.021895    0.656881    
#> 070: 0.501060    1.112022    3.479050    0.738033    0.033012    0.020801    0.646841    
#> 071: 0.474580    1.140132    3.454321    0.701131    0.031361    0.019761    0.677459    
#> 072: 0.460026    1.102877    3.472850    0.666075    0.034399    0.018773    0.655832    
#> 073: 0.480789    1.106080    3.493965    0.632771    0.040702    0.017834    0.653993    
#> 074: 0.492408    1.081305    3.476014    0.619466    0.040224    0.016942    0.635692    
#> 075: 0.512662    1.088049    3.486440    0.706957    0.046612    0.016095    0.643069    
#> 076: 0.561540    1.092970    3.489668    0.857421    0.044281    0.019388    0.646043    
#> 077: 0.561670    1.071453    3.483087    0.819326    0.042067    0.018897    0.620178    
#> 078: 0.536850    1.092413    3.478857    0.816598    0.039964    0.017952    0.630522    
#> 079: 0.531217    1.100989    3.471046    0.829920    0.037965    0.017055    0.628667    
#> 080: 0.535042    1.084034    3.470292    0.804518    0.036067    0.019913    0.655078    
#> 081: 0.516694    1.100275    3.469527    0.828805    0.034264    0.018918    0.639390    
#> 082: 0.503511    1.092063    3.476734    0.787365    0.040403    0.018967    0.655587    
#> 083: 0.525296    1.107973    3.485266    0.838076    0.038383    0.019069    0.654325    
#> 084: 0.553447    1.100801    3.475688    0.796172    0.040484    0.019725    0.648412    
#> 085: 0.565543    1.085803    3.492855    0.849367    0.038460    0.020613    0.653880    
#> 086: 0.566627    1.081140    3.483619    0.806899    0.036537    0.023128    0.635374    
#> 087: 0.539149    1.086626    3.475091    0.811373    0.034710    0.021971    0.633180    
#> 088: 0.505078    1.083940    3.480362    0.793480    0.032975    0.020873    0.640463    
#> 089: 0.520366    1.112093    3.464633    0.920286    0.031326    0.024037    0.630984    
#> 090: 0.506603    1.109765    3.455053    0.874272    0.040657    0.023547    0.635488    
#> 091: 0.452165    1.094912    3.451140    0.830559    0.038624    0.022369    0.648052    
#> 092: 0.468492    1.112814    3.440238    0.812886    0.036872    0.021251    0.643835    
#> 093: 0.436428    1.109316    3.443690    0.772242    0.039884    0.020188    0.658325    
#> 094: 0.477567    1.127961    3.455742    0.821148    0.041540    0.019179    0.663550    
#> 095: 0.464607    1.136855    3.453528    0.780091    0.040763    0.018220    0.664185    
#> 096: 0.415441    1.130601    3.442613    0.741086    0.038725    0.018511    0.654527    
#> 097: 0.451271    1.136724    3.445278    0.704032    0.036789    0.020161    0.656116    
#> 098: 0.471246    1.127859    3.459661    0.668830    0.039519    0.019153    0.650872    
#> 099: 0.509782    1.114080    3.467537    0.696296    0.042354    0.018195    0.632186    
#> 100: 0.485235    1.117812    3.468739    0.661481    0.046123    0.017285    0.628133    
#> 101: 0.471262    1.100733    3.455985    0.628407    0.043817    0.016421    0.638056    
#> 102: 0.447801    1.088745    3.449172    0.596987    0.041626    0.015600    0.657571    
#> 103: 0.482983    1.102935    3.459688    0.679419    0.040831    0.016040    0.634193    
#> 104: 0.511804    1.111617    3.477340    0.742884    0.050092    0.015238    0.657514    
#> 105: 0.551967    1.075773    3.478792    0.766953    0.053211    0.014476    0.645672    
#> 106: 0.556269    1.075014    3.486597    0.806959    0.050903    0.016782    0.637763    
#> 107: 0.557607    1.093432    3.488160    0.766611    0.049777    0.016697    0.637041    
#> 108: 0.544576    1.095948    3.479541    0.800118    0.047288    0.015862    0.640449    
#> 109: 0.536712    1.096350    3.485071    0.761739    0.049645    0.015069    0.640511    
#> 110: 0.618485    1.072836    3.476951    0.982539    0.047163    0.014316    0.632973    
#> 111: 0.584819    1.080723    3.486007    0.933412    0.044805    0.014643    0.625118    
#> 112: 0.522158    1.077406    3.474391    0.886741    0.042564    0.014228    0.633940    
#> 113: 0.484826    1.111331    3.473086    0.842404    0.040436    0.013517    0.637228    
#> 114: 0.533489    1.116041    3.473837    0.824586    0.042643    0.012841    0.635964    
#> 115: 0.581646    1.071967    3.472301    0.965468    0.045489    0.012199    0.651570    
#> 116: 0.560508    1.093672    3.482647    0.917195    0.044552    0.013851    0.653514    
#> 117: 0.552936    1.110712    3.486538    0.871335    0.044512    0.014451    0.656620    
#> 118: 0.598611    1.096882    3.484686    0.875696    0.042287    0.015984    0.645090    
#> 119: 0.548946    1.102089    3.487104    0.831911    0.040172    0.015185    0.665775    
#> 120: 0.498858    1.094237    3.480389    0.790316    0.038164    0.017957    0.667890    
#> 121: 0.558231    1.115159    3.477374    0.815213    0.040185    0.017059    0.647270    
#> 122: 0.547454    1.087345    3.491712    0.774453    0.038175    0.016206    0.663022    
#> 123: 0.605228    1.110639    3.485839    0.951479    0.036267    0.016395    0.635662    
#> 124: 0.555770    1.110748    3.474625    0.903905    0.034453    0.016775    0.652001    
#> 125: 0.547755    1.120527    3.472647    0.858710    0.037068    0.018635    0.642261    
#> 126: 0.556215    1.126346    3.467996    0.815775    0.037788    0.018298    0.655397    
#> 127: 0.595545    1.102736    3.479839    0.822778    0.039279    0.017384    0.645088    
#> 128: 0.559212    1.089899    3.483660    0.838324    0.037369    0.016514    0.645788    
#> 129: 0.589086    1.096800    3.491418    0.871211    0.035500    0.018880    0.644806    
#> 130: 0.600988    1.109942    3.483995    0.827650    0.033725    0.019208    0.643523    
#> 131: 0.527979    1.097605    3.468250    0.786268    0.038249    0.018248    0.651307    
#> 132: 0.502955    1.110665    3.457801    0.746954    0.041420    0.017336    0.640523    
#> 133: 0.557134    1.089718    3.475196    0.905639    0.043571    0.016469    0.648769    
#> 134: 0.552788    1.070197    3.481425    0.928189    0.043567    0.016162    0.654980    
#> 135: 0.588075    1.066878    3.483581    0.956770    0.041389    0.015353    0.654408    
#> 136: 0.543499    1.068040    3.483496    0.908931    0.039320    0.014586    0.649685    
#> 137: 0.602938    1.076426    3.485467    0.863485    0.037800    0.015403    0.658929    
#> 138: 0.567187    1.084260    3.488711    0.820310    0.040683    0.015882    0.634609    
#> 139: 0.469177    1.087849    3.479096    0.779295    0.038649    0.016483    0.656631    
#> 140: 0.555846    1.096361    3.488962    0.780840    0.036924    0.015659    0.668783    
#> 141: 0.529936    1.076901    3.488304    0.741798    0.038975    0.016374    0.638863    
#> 142: 0.562993    1.063397    3.491243    0.810263    0.037027    0.016938    0.644448    
#> 143: 0.504176    1.089901    3.478299    0.771788    0.035175    0.018385    0.638505    
#> 144: 0.568034    1.099346    3.481001    0.898438    0.034438    0.018691    0.623401    
#> 145: 0.543622    1.105474    3.467149    0.853516    0.036367    0.017963    0.632805    
#> 146: 0.499440    1.109473    3.477856    0.810840    0.037737    0.018385    0.645214    
#> 147: 0.519918    1.105994    3.465305    0.827586    0.036918    0.018835    0.623947    
#> 148: 0.523013    1.097920    3.481430    0.833683    0.039589    0.017893    0.623072    
#> 149: 0.499786    1.087015    3.468981    0.813870    0.040933    0.016998    0.645079    
#> 150: 0.541994    1.076070    3.470113    0.864233    0.045992    0.016148    0.657976    
#> 151: 0.486470    1.093840    3.460415    0.821808    0.043692    0.015341    0.640984    
#> 152: 0.503705    1.098606    3.470545    0.813600    0.034287    0.017479    0.644225    
#> 153: 0.471479    1.102702    3.481683    0.783852    0.037978    0.019628    0.648618    
#> 154: 0.544594    1.110671    3.470137    0.842829    0.033992    0.025565    0.637249    
#> 155: 0.493782    1.094517    3.463385    0.796025    0.031784    0.023443    0.633680    
#> 156: 0.524896    1.098530    3.483682    0.794423    0.033714    0.022507    0.648014    
#> 157: 0.531199    1.099509    3.476587    0.915886    0.033627    0.021523    0.647529    
#> 158: 0.580711    1.114702    3.470325    1.020651    0.035374    0.022314    0.633876    
#> 159: 0.466669    1.125629    3.475141    0.653566    0.036206    0.020845    0.644547    
#> 160: 0.523792    1.106131    3.479391    0.725297    0.031200    0.022632    0.668773    
#> 161: 0.513613    1.099718    3.477017    0.702943    0.031170    0.024868    0.671405    
#> 162: 0.511665    1.119654    3.467322    0.666840    0.032510    0.024599    0.656259    
#> 163: 0.534536    1.101771    3.463499    0.687907    0.030650    0.022990    0.645039    
#> 164: 0.539654    1.102389    3.474392    0.782937    0.028734    0.024968    0.617705    
#> 165: 0.551739    1.079922    3.480005    0.855202    0.028448    0.025902    0.629586    
#> 166: 0.541594    1.101474    3.474552    0.786247    0.023769    0.024011    0.641855    
#> 167: 0.538021    1.108486    3.480297    0.791590    0.029285    0.022000    0.637816    
#> 168: 0.542384    1.120938    3.475934    0.843726    0.029223    0.022022    0.628508    
#> 169: 0.542884    1.127192    3.477956    0.755242    0.038136    0.019878    0.633034    
#> 170: 0.520966    1.107073    3.482028    0.713947    0.041786    0.020326    0.645055    
#> 171: 0.480386    1.102619    3.467330    0.688514    0.042887    0.018783    0.642326    
#> 172: 0.457506    1.132156    3.466485    0.651910    0.046245    0.015793    0.641367    
#> 173: 0.480112    1.134018    3.450188    0.664370    0.039116    0.014417    0.650330    
#> 174: 0.518418    1.124527    3.460064    0.803631    0.034267    0.015789    0.640649    
#> 175: 0.476158    1.117351    3.451844    0.751942    0.037453    0.016377    0.654708    
#> 176: 0.480652    1.117105    3.476717    0.652471    0.036372    0.016891    0.653731    
#> 177: 0.490776    1.103510    3.491155    0.612325    0.035734    0.019826    0.653362    
#> 178: 0.527027    1.097483    3.482526    0.715295    0.036063    0.019428    0.640522    
#> 179: 0.544467    1.116321    3.471353    0.586402    0.040670    0.016118    0.654646    
#> 180: 0.502593    1.088582    3.473068    0.653949    0.032990    0.016665    0.666508    
#> 181: 0.472757    1.084479    3.456128    0.636319    0.033678    0.018121    0.659150    
#> 182: 0.468963    1.101414    3.455960    0.604157    0.037050    0.016388    0.663304    
#> 183: 0.478898    1.113702    3.460081    0.685806    0.044141    0.016362    0.653576    
#> 184: 0.515877    1.088346    3.473242    0.807280    0.036765    0.015838    0.639899    
#> 185: 0.486648    1.118912    3.455352    0.801953    0.037587    0.017116    0.633215    
#> 186: 0.530488    1.121807    3.476442    0.808969    0.038394    0.021030    0.638157    
#> 187: 0.551377    1.097501    3.487160    0.678648    0.047096    0.016773    0.636652    
#> 188: 0.526974    1.110453    3.483639    0.631315    0.049684    0.014590    0.640316    
#> 189: 0.538677    1.113670    3.494661    0.694740    0.048974    0.014473    0.654345    
#> 190: 0.557350    1.100444    3.498295    0.726784    0.041350    0.015720    0.638581    
#> 191: 0.557511    1.105068    3.484073    0.737522    0.031296    0.018521    0.623774    
#> 192: 0.531803    1.098894    3.485499    0.674598    0.034197    0.018443    0.616459    
#> 193: 0.566579    1.096079    3.486238    0.771995    0.034300    0.016764    0.629253    
#> 194: 0.530611    1.089396    3.477131    0.691534    0.035274    0.017887    0.648254    
#> 195: 0.527621    1.101364    3.468336    0.711998    0.034346    0.017153    0.647194    
#> 196: 0.532163    1.106863    3.474409    0.836737    0.040651    0.017520    0.659532    
#> 197: 0.484837    1.108603    3.486878    0.751488    0.034833    0.020770    0.665029    
#> 198: 0.530920    1.092832    3.474986    0.704494    0.033823    0.020024    0.644911    
#> 199: 0.507113    1.096198    3.477846    0.693641    0.034156    0.019026    0.624888    
#> 200: 0.554227    1.103364    3.480352    0.839145    0.045134    0.018455    0.637929    
#> 201: 0.534893    1.093451    3.486229    0.732156    0.042841    0.020237    0.643786    
#> 202: 0.529296    1.093262    3.486656    0.691430    0.038938    0.020523    0.645776    
#> 203: 0.545055    1.091159    3.484746    0.687370    0.036830    0.020781    0.649476    
#> 204: 0.543915    1.086263    3.486853    0.696658    0.037372    0.020394    0.652739    
#> 205: 0.549882    1.090870    3.486287    0.713100    0.037919    0.020438    0.655210    
#> 206: 0.548673    1.095234    3.486852    0.707137    0.038297    0.019873    0.654401    
#> 207: 0.547347    1.095734    3.484981    0.707097    0.039486    0.019293    0.651135    
#> 208: 0.542484    1.097536    3.483236    0.703879    0.039355    0.018879    0.647750    
#> 209: 0.540384    1.096648    3.481726    0.709341    0.039470    0.018561    0.646465    
#> 210: 0.541292    1.097167    3.480970    0.719415    0.039097    0.018615    0.645617    
#> 211: 0.543456    1.097156    3.481256    0.721913    0.038878    0.018827    0.645129    
#> 212: 0.544190    1.096748    3.481306    0.724702    0.038444    0.018991    0.644289    
#> 213: 0.548443    1.095225    3.482068    0.726245    0.038039    0.018835    0.644944    
#> 214: 0.547807    1.094081    3.482026    0.717032    0.037380    0.018700    0.645767    
#> 215: 0.546267    1.093661    3.482078    0.713639    0.037078    0.018639    0.646266    
#> 216: 0.550738    1.092287    3.482351    0.723038    0.037573    0.018746    0.647301    
#> 217: 0.549348    1.092965    3.482358    0.720524    0.038008    0.018703    0.646593    
#> 218: 0.548982    1.093617    3.481776    0.721342    0.038503    0.018877    0.645427    
#> 219: 0.547957    1.093098    3.481106    0.719378    0.038387    0.018766    0.645134    
#> 220: 0.545452    1.092936    3.480422    0.721053    0.038017    0.018641    0.645300    
#> 221: 0.543313    1.093445    3.479548    0.718296    0.038160    0.018429    0.646023    
#> 222: 0.540851    1.093879    3.478452    0.717703    0.038260    0.018427    0.646011    
#> 223: 0.538727    1.095015    3.477488    0.715858    0.038226    0.018423    0.646083    
#> 224: 0.537782    1.095982    3.477305    0.712516    0.038388    0.018481    0.646298    
#> 225: 0.535763    1.095567    3.477057    0.711486    0.038151    0.018448    0.646651    
#> 226: 0.532632    1.095080    3.476146    0.709430    0.038081    0.018376    0.646680    
#> 227: 0.531122    1.095650    3.475631    0.707205    0.038111    0.018338    0.645860    
#> 228: 0.529378    1.096954    3.475005    0.705393    0.038128    0.018302    0.645674    
#> 229: 0.526689    1.097602    3.474491    0.704930    0.038011    0.018364    0.645389    
#> 230: 0.526779    1.098091    3.474249    0.706971    0.038007    0.018277    0.645384    
#> 231: 0.526505    1.098561    3.473926    0.710701    0.038080    0.018164    0.645460    
#> 232: 0.524545    1.098489    3.473641    0.708132    0.038191    0.018045    0.646065    
#> 233: 0.523789    1.098024    3.473452    0.707652    0.038355    0.018012    0.646601    
#> 234: 0.522806    1.098139    3.473223    0.708191    0.038465    0.017977    0.646722    
#> 235: 0.522827    1.098006    3.472958    0.710106    0.038433    0.017995    0.646584    
#> 236: 0.522391    1.098585    3.472581    0.710956    0.038579    0.018013    0.646453    
#> 237: 0.522580    1.098730    3.472237    0.715051    0.038614    0.018044    0.646448    
#> 238: 0.522194    1.098705    3.472328    0.713926    0.038739    0.018021    0.647177    
#> 239: 0.521415    1.099356    3.472214    0.713932    0.038889    0.018087    0.647478    
#> 240: 0.521634    1.099097    3.472359    0.714408    0.038911    0.018001    0.647644    
#> 241: 0.521377    1.098294    3.472548    0.713481    0.039227    0.017863    0.647412    
#> 242: 0.520981    1.097689    3.472380    0.714375    0.039606    0.017800    0.647757    
#> 243: 0.520082    1.098031    3.472080    0.714413    0.040047    0.017722    0.647646    
#> 244: 0.519134    1.097759    3.472089    0.714618    0.040241    0.017687    0.647669    
#> 245: 0.519490    1.097569    3.472300    0.715030    0.040518    0.017676    0.647825    
#> 246: 0.519286    1.097446    3.472464    0.712690    0.040589    0.017590    0.647848    
#> 247: 0.519755    1.097129    3.472894    0.711967    0.040642    0.017560    0.647586    
#> 248: 0.519890    1.097480    3.472766    0.711739    0.040669    0.017444    0.647668    
#> 249: 0.519590    1.097764    3.472743    0.712112    0.040869    0.017358    0.647739    
#> 250: 0.519574    1.098148    3.472683    0.713189    0.041239    0.017332    0.647859    
#> 251: 0.519952    1.098318    3.472931    0.713839    0.041472    0.017296    0.647901    
#> 252: 0.520490    1.098357    3.473410    0.713725    0.041708    0.017294    0.648076    
#> 253: 0.520867    1.098313    3.473616    0.714465    0.041877    0.017323    0.648269    
#> 254: 0.521262    1.098638    3.473762    0.714182    0.041996    0.017319    0.648493    
#> 255: 0.520952    1.098799    3.473824    0.713915    0.042073    0.017278    0.648488    
#> 256: 0.521267    1.098458    3.473926    0.714422    0.042045    0.017225    0.648625    
#> 257: 0.521266    1.098106    3.473922    0.714337    0.042030    0.017182    0.648623    
#> 258: 0.520830    1.097680    3.473898    0.712027    0.041960    0.017175    0.648825    
#> 259: 0.520451    1.097347    3.473903    0.711132    0.041833    0.017182    0.648902    
#> 260: 0.519882    1.097403    3.473996    0.710625    0.041726    0.017150    0.648912    
#> 261: 0.519629    1.097401    3.474071    0.708719    0.041695    0.017156    0.648903    
#> 262: 0.519432    1.097437    3.474157    0.707388    0.041538    0.017124    0.649097    
#> 263: 0.519280    1.097640    3.474107    0.706931    0.041558    0.017108    0.649233    
#> 264: 0.518492    1.097831    3.473841    0.706822    0.041716    0.017095    0.649438    
#> 265: 0.517949    1.097971    3.473774    0.706024    0.042020    0.017090    0.649576    
#> 266: 0.518323    1.097932    3.473951    0.705674    0.042103    0.017085    0.649513    
#> 267: 0.518380    1.097899    3.474277    0.705389    0.042229    0.017132    0.649493    
#> 268: 0.518399    1.097842    3.474307    0.704835    0.042205    0.017148    0.649280    
#> 269: 0.519510    1.097762    3.474254    0.707581    0.042183    0.017198    0.649104    
#> 270: 0.520564    1.097782    3.474265    0.709319    0.042150    0.017235    0.648957    
#> 271: 0.520283    1.097756    3.474113    0.710642    0.042114    0.017288    0.648957    
#> 272: 0.520575    1.097288    3.474056    0.712887    0.042140    0.017346    0.649077    
#> 273: 0.520303    1.097408    3.474093    0.711630    0.042130    0.017380    0.649143    
#> 274: 0.520124    1.097443    3.474196    0.711289    0.042077    0.017406    0.649220    
#> 275: 0.520438    1.097473    3.474162    0.712843    0.042011    0.017420    0.649344    
#> 276: 0.520175    1.097624    3.474168    0.714155    0.041947    0.017458    0.649294    
#> 277: 0.520373    1.097724    3.474322    0.715314    0.041889    0.017473    0.649086    
#> 278: 0.520521    1.097641    3.474452    0.715356    0.041872    0.017453    0.649041    
#> 279: 0.519886    1.097486    3.474573    0.714414    0.041841    0.017477    0.649254    
#> 280: 0.519644    1.097644    3.474737    0.712194    0.041847    0.017481    0.649158    
#> 281: 0.519350    1.097738    3.474874    0.710996    0.041761    0.017467    0.649186    
#> 282: 0.519389    1.097982    3.474955    0.711619    0.041787    0.017456    0.649336    
#> 283: 0.519653    1.098122    3.475019    0.712514    0.041727    0.017434    0.649406    
#> 284: 0.519881    1.097911    3.474942    0.713205    0.041703    0.017388    0.649334    
#> 285: 0.520215    1.097958    3.474764    0.716441    0.041728    0.017353    0.649097    
#> 286: 0.520323    1.098005    3.474653    0.718370    0.041787    0.017318    0.649125    
#> 287: 0.519994    1.098179    3.474298    0.721314    0.041743    0.017299    0.649247    
#> 288: 0.520064    1.098278    3.474075    0.723430    0.041801    0.017268    0.649286    
#> 289: 0.520313    1.098414    3.473922    0.724919    0.041758    0.017234    0.649288    
#> 290: 0.519804    1.098467    3.473682    0.724769    0.041719    0.017210    0.649571    
#> 291: 0.519542    1.098615    3.473681    0.723912    0.041663    0.017225    0.649416    
#> 292: 0.519297    1.098821    3.473568    0.723291    0.041619    0.017220    0.649331    
#> 293: 0.518853    1.099206    3.473402    0.723724    0.041607    0.017230    0.649239    
#> 294: 0.518718    1.099592    3.473283    0.723754    0.041575    0.017241    0.649346    
#> 295: 0.518537    1.099454    3.473101    0.724225    0.041508    0.017279    0.649205    
#> 296: 0.518423    1.099348    3.473082    0.724270    0.041428    0.017351    0.649195    
#> 297: 0.518517    1.099306    3.473027    0.724889    0.041276    0.017409    0.649083    
#> 298: 0.518544    1.099215    3.472971    0.725903    0.041133    0.017466    0.649004    
#> 299: 0.518502    1.099392    3.472902    0.726203    0.041096    0.017502    0.648838    
#> 300: 0.518599    1.099366    3.472864    0.726198    0.041024    0.017500    0.648813    
#> 301: 0.518479    1.099175    3.472871    0.725059    0.040942    0.017524    0.648819    
#> 302: 0.518492    1.099176    3.472803    0.725212    0.040995    0.017530    0.648733    
#> 303: 0.518525    1.099238    3.472653    0.725751    0.040968    0.017529    0.648544    
#> 304: 0.518109    1.099444    3.472504    0.725907    0.040899    0.017544    0.648335    
#> 305: 0.518015    1.099335    3.472379    0.726279    0.040838    0.017547    0.648154    
#> 306: 0.518196    1.099150    3.472422    0.726790    0.040781    0.017558    0.647978    
#> 307: 0.518353    1.098876    3.472441    0.726609    0.040765    0.017549    0.648005    
#> 308: 0.518191    1.098921    3.472346    0.727500    0.040780    0.017559    0.648012    
#> 309: 0.518671    1.098821    3.472349    0.729094    0.040733    0.017585    0.648104    
#> 310: 0.519207    1.098725    3.472267    0.731408    0.040727    0.017612    0.648124    
#> 311: 0.519477    1.098629    3.472217    0.733342    0.040727    0.017601    0.648107    
#> 312: 0.519049    1.098588    3.472096    0.732926    0.040715    0.017568    0.648192    
#> 313: 0.518597    1.098424    3.471959    0.732777    0.040691    0.017597    0.648328    
#> 314: 0.517627    1.098447    3.471771    0.731336    0.040661    0.017581    0.648503    
#> 315: 0.516930    1.098520    3.471580    0.730218    0.040657    0.017564    0.648427    
#> 316: 0.516865    1.098561    3.471545    0.730333    0.040690    0.017539    0.648354    
#> 317: 0.517156    1.098389    3.471708    0.729753    0.040662    0.017504    0.648550    
#> 318: 0.517316    1.098428    3.471773    0.729254    0.040610    0.017488    0.648591    
#> 319: 0.517441    1.098323    3.471871    0.728524    0.040515    0.017510    0.648711    
#> 320: 0.517048    1.098374    3.471729    0.728503    0.040433    0.017513    0.648882    
#> 321: 0.516891    1.098564    3.471555    0.728668    0.040339    0.017509    0.648992    
#> 322: 0.516630    1.098649    3.471414    0.728155    0.040324    0.017503    0.648995    
#> 323: 0.516441    1.098798    3.471376    0.727954    0.040275    0.017512    0.648929    
#> 324: 0.516225    1.098980    3.471346    0.726746    0.040281    0.017490    0.648872    
#> 325: 0.515940    1.099182    3.471201    0.726631    0.040255    0.017459    0.648782    
#> 326: 0.516021    1.099134    3.471147    0.727108    0.040228    0.017440    0.648748    
#> 327: 0.516250    1.099084    3.471179    0.727556    0.040267    0.017426    0.648678    
#> 328: 0.516506    1.099084    3.471250    0.727862    0.040221    0.017427    0.648547    
#> 329: 0.516848    1.099082    3.471325    0.728229    0.040200    0.017438    0.648488    
#> 330: 0.516980    1.099110    3.471338    0.728364    0.040187    0.017424    0.648530    
#> 331: 0.516991    1.099292    3.471343    0.728545    0.040200    0.017419    0.648363    
#> 332: 0.516855    1.099263    3.471360    0.728577    0.040190    0.017430    0.648320    
#> 333: 0.516879    1.099224    3.471320    0.728903    0.040176    0.017443    0.648270    
#> 334: 0.516446    1.099233    3.471128    0.729060    0.040149    0.017434    0.648227    
#> 335: 0.516223    1.099279    3.471003    0.728006    0.040146    0.017426    0.648288    
#> 336: 0.515856    1.099488    3.470959    0.727023    0.040165    0.017431    0.648438    
#> 337: 0.515556    1.099733    3.470833    0.726825    0.040124    0.017450    0.648497    
#> 338: 0.515079    1.099811    3.470828    0.726279    0.040096    0.017464    0.648600    
#> 339: 0.514631    1.099890    3.470754    0.726106    0.040102    0.017499    0.648530    
#> 340: 0.514415    1.099744    3.470743    0.726096    0.040132    0.017547    0.648443    
#> 341: 0.514491    1.099668    3.470792    0.726636    0.040154    0.017584    0.648306    
#> 342: 0.514363    1.099477    3.470812    0.726778    0.040208    0.017609    0.648249    
#> 343: 0.514684    1.099492    3.470822    0.727746    0.040287    0.017607    0.648270    
#> 344: 0.515048    1.099496    3.470827    0.729287    0.040368    0.017639    0.648308    
#> 345: 0.515536    1.099430    3.470906    0.730145    0.040271    0.017666    0.648287    
#> 346: 0.515760    1.099487    3.470900    0.730675    0.040215    0.017687    0.648248    
#> 347: 0.515910    1.099389    3.470937    0.730152    0.040184    0.017709    0.648378    
#> 348: 0.515705    1.099501    3.470918    0.730028    0.040181    0.017725    0.648382    
#> 349: 0.515481    1.099549    3.470833    0.729812    0.040141    0.017743    0.648357    
#> 350: 0.515047    1.099510    3.470715    0.729007    0.040092    0.017751    0.648409    
#> 351: 0.514793    1.099636    3.470580    0.728738    0.040059    0.017736    0.648506    
#> 352: 0.514653    1.099760    3.470543    0.728887    0.040059    0.017771    0.648552    
#> 353: 0.515043    1.099711    3.470568    0.729289    0.039988    0.017795    0.648519    
#> 354: 0.515182    1.099723    3.470487    0.729855    0.039910    0.017859    0.648423    
#> 355: 0.515788    1.099673    3.470448    0.731511    0.039837    0.017911    0.648373    
#> 356: 0.515935    1.099653    3.470441    0.732335    0.039788    0.017946    0.648347    
#> 357: 0.516139    1.099726    3.470397    0.733769    0.039750    0.017975    0.648159    
#> 358: 0.516141    1.099871    3.470415    0.734087    0.039805    0.017991    0.647997    
#> 359: 0.516167    1.099946    3.470412    0.734543    0.039786    0.018000    0.647887    
#> 360: 0.516249    1.099964    3.470390    0.734397    0.039765    0.017994    0.647753    
#> 361: 0.516523    1.099990    3.470416    0.735359    0.039726    0.017968    0.647695    
#> 362: 0.516816    1.099946    3.470443    0.735781    0.039690    0.017957    0.647599    
#> 363: 0.516989    1.099808    3.470535    0.736211    0.039679    0.017942    0.647496    
#> 364: 0.517146    1.099753    3.470543    0.736287    0.039717    0.017917    0.647464    
#> 365: 0.517195    1.099719    3.470548    0.736799    0.039818    0.017892    0.647464    
#> 366: 0.517414    1.099795    3.470473    0.737804    0.039829    0.017868    0.647488    
#> 367: 0.517245    1.099828    3.470471    0.737292    0.039859    0.017838    0.647444    
#> 368: 0.517423    1.099839    3.470528    0.736927    0.039822    0.017823    0.647410    
#> 369: 0.517497    1.099843    3.470600    0.736334    0.039823    0.017812    0.647411    
#> 370: 0.517426    1.099851    3.470620    0.735994    0.039841    0.017811    0.647487    
#> 371: 0.517268    1.099892    3.470567    0.735721    0.039837    0.017802    0.647543    
#> 372: 0.516781    1.099952    3.470494    0.735748    0.039853    0.017792    0.647674    
#> 373: 0.516605    1.100043    3.470431    0.736121    0.039816    0.017782    0.647719    
#> 374: 0.516550    1.100116    3.470357    0.736028    0.039782    0.017780    0.647609    
#> 375: 0.516582    1.100133    3.470394    0.735993    0.039783    0.017766    0.647561    
#> 376: 0.516492    1.100225    3.470404    0.735412    0.039792    0.017780    0.647453    
#> 377: 0.516141    1.100325    3.470325    0.735081    0.039784    0.017804    0.647503    
#> 378: 0.515936    1.100356    3.470202    0.735101    0.039751    0.017832    0.647502    
#> 379: 0.515833    1.100269    3.470179    0.734933    0.039742    0.017856    0.647495    
#> 380: 0.515622    1.100248    3.470167    0.734272    0.039728    0.017878    0.647482    
#> 381: 0.515382    1.100268    3.470131    0.734006    0.039769    0.017868    0.647424    
#> 382: 0.515183    1.100285    3.470106    0.733836    0.039725    0.017880    0.647343    
#> 383: 0.515260    1.100354    3.470094    0.733706    0.039731    0.017854    0.647304    
#> 384: 0.515080    1.100336    3.470158    0.733354    0.039684    0.017843    0.647349    
#> 385: 0.515204    1.100256    3.470262    0.732816    0.039667    0.017840    0.647419    
#> 386: 0.515327    1.100269    3.470339    0.732473    0.039675    0.017831    0.647532    
#> 387: 0.515701    1.100257    3.470507    0.732809    0.039674    0.017844    0.647601    
#> 388: 0.515797    1.100221    3.470600    0.733046    0.039670    0.017850    0.647608    
#> 389: 0.515668    1.100084    3.470635    0.732999    0.039673    0.017846    0.647555    
#> 390: 0.515708    1.100104    3.470630    0.733686    0.039675    0.017842    0.647506    
#> 391: 0.515887    1.100049    3.470617    0.734084    0.039634    0.017841    0.647446    
#> 392: 0.515951    1.100043    3.470654    0.733380    0.039596    0.017845    0.647448    
#> 393: 0.515920    1.100052    3.470678    0.732694    0.039573    0.017881    0.647412    
#> 394: 0.516253    1.100015    3.470712    0.733090    0.039539    0.017893    0.647320    
#> 395: 0.516444    1.100102    3.470717    0.733756    0.039501    0.017920    0.647237    
#> 396: 0.516375    1.100182    3.470687    0.733544    0.039516    0.017936    0.647159    
#> 397: 0.516362    1.100083    3.470678    0.733837    0.039516    0.017946    0.647196    
#> 398: 0.516512    1.100025    3.470660    0.734860    0.039487    0.017949    0.647226    
#> 399: 0.516761    1.099999    3.470742    0.735049    0.039460    0.017944    0.647237    
#> 400: 0.517158    1.099951    3.470854    0.734918    0.039472    0.017954    0.647247    
#> 401: 0.517313    1.100028    3.470899    0.734698    0.039502    0.017953    0.647344    
#> 402: 0.517327    1.100106    3.470897    0.733977    0.039500    0.017945    0.647368    
#> 403: 0.517279    1.100186    3.470854    0.733841    0.039497    0.017934    0.647302    
#> 404: 0.517219    1.100175    3.470785    0.733746    0.039493    0.017925    0.647308    
#> 405: 0.517152    1.100170    3.470796    0.733786    0.039528    0.017925    0.647250    
#> 406: 0.517069    1.100149    3.470829    0.733606    0.039523    0.017932    0.647263    
#> 407: 0.517281    1.100184    3.470875    0.733794    0.039526    0.017935    0.647303    
#> 408: 0.517622    1.100244    3.470921    0.734070    0.039531    0.017940    0.647242    
#> 409: 0.517643    1.100171    3.470940    0.734018    0.039487    0.017954    0.647190    
#> 410: 0.517780    1.100120    3.470973    0.733694    0.039439    0.017969    0.647189    
#> 411: 0.517912    1.099893    3.471058    0.733519    0.039426    0.017982    0.647109    
#> 412: 0.517727    1.099888    3.471052    0.733084    0.039413    0.017958    0.647070    
#> 413: 0.517673    1.099966    3.471008    0.733123    0.039424    0.017951    0.646961    
#> 414: 0.517458    1.100019    3.470968    0.732818    0.039400    0.017953    0.646888    
#> 415: 0.517529    1.100106    3.470970    0.732787    0.039379    0.017970    0.646773    
#> 416: 0.517574    1.100150    3.470994    0.732916    0.039357    0.017984    0.646691    
#> 417: 0.517692    1.100077    3.471005    0.733169    0.039350    0.017983    0.646653    
#> 418: 0.517821    1.100049    3.471042    0.733654    0.039384    0.017971    0.646569    
#> 419: 0.517757    1.100134    3.471039    0.733616    0.039390    0.017975    0.646515    
#> 420: 0.517670    1.100251    3.471015    0.733246    0.039434    0.017983    0.646440    
#> 421: 0.517400    1.100327    3.471020    0.732901    0.039470    0.017974    0.646403    
#> 422: 0.517409    1.100275    3.471011    0.732876    0.039465    0.017970    0.646371    
#> 423: 0.517456    1.100235    3.470993    0.732866    0.039442    0.017981    0.646446    
#> 424: 0.517442    1.100263    3.470936    0.733005    0.039415    0.017966    0.646457    
#> 425: 0.517438    1.100294    3.470909    0.732813    0.039412    0.017960    0.646509    
#> 426: 0.517457    1.100345    3.470914    0.732750    0.039437    0.017933    0.646531    
#> 427: 0.517279    1.100353    3.470911    0.732431    0.039436    0.017917    0.646535    
#> 428: 0.517146    1.100396    3.470924    0.732032    0.039443    0.017911    0.646532    
#> 429: 0.517081    1.100376    3.470932    0.731549    0.039456    0.017899    0.646541    
#> 430: 0.516969    1.100423    3.470907    0.731775    0.039467    0.017896    0.646524    
#> 431: 0.516752    1.100462    3.470844    0.731697    0.039475    0.017892    0.646494    
#> 432: 0.516559    1.100549    3.470801    0.731457    0.039491    0.017903    0.646483    
#> 433: 0.516400    1.100580    3.470811    0.731083    0.039470    0.017894    0.646565    
#> 434: 0.516158    1.100455    3.470803    0.730582    0.039416    0.017899    0.646638    
#> 435: 0.516081    1.100382    3.470780    0.729990    0.039374    0.017893    0.646664    
#> 436: 0.516128    1.100322    3.470845    0.729656    0.039373    0.017879    0.646675    
#> 437: 0.516264    1.100291    3.470882    0.729489    0.039376    0.017874    0.646672    
#> 438: 0.516373    1.100391    3.470904    0.729753    0.039382    0.017870    0.646645    
#> 439: 0.516447    1.100488    3.470940    0.729683    0.039399    0.017862    0.646578    
#> 440: 0.516522    1.100561    3.470981    0.729492    0.039404    0.017851    0.646564    
#> 441: 0.516413    1.100555    3.470979    0.729098    0.039450    0.017834    0.646573    
#> 442: 0.516276    1.100549    3.470992    0.728644    0.039486    0.017812    0.646593    
#> 443: 0.516160    1.100617    3.470926    0.728353    0.039538    0.017781    0.646615    
#> 444: 0.515963    1.100659    3.470894    0.728082    0.039604    0.017763    0.646568    
#> 445: 0.515665    1.100678    3.470861    0.727604    0.039638    0.017760    0.646665    
#> 446: 0.515483    1.100772    3.470830    0.727540    0.039695    0.017747    0.646659    
#> 447: 0.515435    1.100796    3.470826    0.727454    0.039726    0.017746    0.646713    
#> 448: 0.515274    1.100801    3.470820    0.727574    0.039740    0.017740    0.646746    
#> 449: 0.515198    1.100867    3.470860    0.727310    0.039777    0.017732    0.646832    
#> 450: 0.515027    1.100925    3.470822    0.727063    0.039809    0.017723    0.646863    
#> 451: 0.515081    1.101035    3.470818    0.726932    0.039849    0.017717    0.646891    
#> 452: 0.515023    1.101074    3.470820    0.726676    0.039849    0.017718    0.646887    
#> 453: 0.515073    1.101101    3.470840    0.726437    0.039840    0.017722    0.646827    
#> 454: 0.515102    1.101180    3.470842    0.726291    0.039839    0.017715    0.646700    
#> 455: 0.515024    1.101196    3.470870    0.726047    0.039816    0.017717    0.646687    
#> 456: 0.515094    1.101149    3.470902    0.726029    0.039807    0.017713    0.646655    
#> 457: 0.515118    1.101132    3.470949    0.725916    0.039789    0.017710    0.646605    
#> 458: 0.515292    1.101211    3.471041    0.726025    0.039783    0.017714    0.646533    
#> 459: 0.515237    1.101293    3.471110    0.725669    0.039791    0.017720    0.646505    
#> 460: 0.515228    1.101321    3.471123    0.725239    0.039795    0.017726    0.646487    
#> 461: 0.515084    1.101346    3.471181    0.724657    0.039829    0.017728    0.646456    
#> 462: 0.514979    1.101379    3.471214    0.724471    0.039860    0.017729    0.646411    
#> 463: 0.514930    1.101436    3.471205    0.724519    0.039855    0.017726    0.646355    
#> 464: 0.514962    1.101414    3.471184    0.724331    0.039853    0.017714    0.646330    
#> 465: 0.515094    1.101242    3.471199    0.724330    0.039881    0.017700    0.646296    
#> 466: 0.515209    1.101185    3.471227    0.724372    0.039891    0.017699    0.646286    
#> 467: 0.515295    1.101128    3.471274    0.725104    0.039915    0.017689    0.646191    
#> 468: 0.515645    1.101132    3.471318    0.726312    0.039942    0.017688    0.646136    
#> 469: 0.515664    1.101274    3.471333    0.726300    0.039973    0.017688    0.646069    
#> 470: 0.515640    1.101366    3.471304    0.726160    0.040016    0.017678    0.646071    
#> 471: 0.515495    1.101348    3.471274    0.725850    0.040011    0.017668    0.646087    
#> 472: 0.515442    1.101345    3.471298    0.725979    0.040050    0.017661    0.646017    
#> 473: 0.515214    1.101340    3.471259    0.725618    0.040057    0.017650    0.646030    
#> 474: 0.515072    1.101373    3.471219    0.725349    0.040058    0.017643    0.646084    
#> 475: 0.515024    1.101476    3.471188    0.725142    0.040067    0.017636    0.646125    
#> 476: 0.515006    1.101534    3.471143    0.725271    0.040082    0.017638    0.646189    
#> 477: 0.514999    1.101558    3.471157    0.725014    0.040091    0.017628    0.646131    
#> 478: 0.514833    1.101580    3.471146    0.724659    0.040105    0.017621    0.646181    
#> 479: 0.514880    1.101645    3.471158    0.724235    0.040142    0.017612    0.646175    
#> 480: 0.514888    1.101673    3.471158    0.724145    0.040154    0.017599    0.646205    
#> 481: 0.514780    1.101697    3.471170    0.723844    0.040161    0.017576    0.646247    
#> 482: 0.514689    1.101712    3.471149    0.723610    0.040186    0.017560    0.646286    
#> 483: 0.514555    1.101708    3.471176    0.723287    0.040239    0.017543    0.646279    
#> 484: 0.514434    1.101604    3.471173    0.723008    0.040246    0.017523    0.646303    
#> 485: 0.514301    1.101629    3.471168    0.722773    0.040251    0.017504    0.646330    
#> 486: 0.514302    1.101673    3.471204    0.722723    0.040254    0.017490    0.646286    
#> 487: 0.514340    1.101667    3.471270    0.722427    0.040265    0.017492    0.646239    
#> 488: 0.514374    1.101654    3.471289    0.722201    0.040276    0.017487    0.646162    
#> 489: 0.514536    1.101633    3.471315    0.722177    0.040281    0.017493    0.646117    
#> 490: 0.514751    1.101646    3.471363    0.722463    0.040294    0.017501    0.646050    
#> 491: 0.514905    1.101688    3.471398    0.722712    0.040315    0.017490    0.646035    
#> 492: 0.514803    1.101712    3.471421    0.722341    0.040328    0.017478    0.646125    
#> 493: 0.514695    1.101709    3.471445    0.721808    0.040369    0.017456    0.646161    
#> 494: 0.514771    1.101784    3.471435    0.721683    0.040390    0.017443    0.646115    
#> 495: 0.514789    1.101801    3.471426    0.721597    0.040390    0.017423    0.646074    
#> 496: 0.514794    1.101823    3.471371    0.721624    0.040413    0.017414    0.646076    
#> 497: 0.514757    1.101800    3.471378    0.721584    0.040413    0.017408    0.646069    
#> 498: 0.514851    1.101765    3.471372    0.721781    0.040427    0.017404    0.645988    
#> 499: 0.514925    1.101756    3.471345    0.721894    0.040448    0.017397    0.645909    
#> 500: 0.514856    1.101690    3.471324    0.721751    0.040433    0.017408    0.645901    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.288684    0.980072    3.448456    0.392401    0.082164    0.016800    1.730655    
#> 002: 0.299647    1.026195    3.463113    0.372781    0.078056    0.017048    1.111160    
#> 003: 0.382502    1.016726    3.508647    0.354142    0.074153    0.016195    0.841349    
#> 004: 0.375825    1.025827    3.513278    0.336435    0.070445    0.015386    0.776860    
#> 005: 0.411817    1.052116    3.506870    0.319613    0.075873    0.016033    0.759923    
#> 006: 0.389740    1.051194    3.500333    0.303633    0.085022    0.016348    0.701247    
#> 007: 0.322533    1.070374    3.491158    0.288451    0.084758    0.021939    0.714441    
#> 008: 0.344507    1.047050    3.490581    0.274029    0.080520    0.024466    0.718523    
#> 009: 0.322286    1.060327    3.484910    0.260327    0.087848    0.023243    0.726340    
#> 010: 0.315570    1.066945    3.472189    0.247311    0.083455    0.022081    0.748202    
#> 011: 0.369724    1.064282    3.477296    0.234945    0.079373    0.024561    0.736014    
#> 012: 0.338883    1.075129    3.477496    0.223198    0.075404    0.023333    0.719143    
#> 013: 0.240984    1.088744    3.451508    0.212038    0.085128    0.022166    0.743502    
#> 014: 0.309643    1.081159    3.480622    0.201436    0.080872    0.021058    0.780085    
#> 015: 0.344498    1.083064    3.505368    0.191364    0.076828    0.021911    0.740989    
#> 016: 0.367751    1.063878    3.511291    0.181796    0.072987    0.020816    0.752276    
#> 017: 0.384564    1.071905    3.503710    0.172706    0.069338    0.019775    0.743648    
#> 018: 0.347059    1.065598    3.474288    0.180630    0.069161    0.018786    0.747294    
#> 019: 0.298121    1.074533    3.476337    0.171599    0.071558    0.019770    0.731441    
#> 020: 0.305729    1.077120    3.478590    0.166563    0.067980    0.021001    0.737059    
#> 021: 0.334546    1.072479    3.491130    0.158235    0.064581    0.024223    0.728147    
#> 022: 0.333007    1.055524    3.498831    0.165828    0.071260    0.023012    0.716049    
#> 023: 0.415780    1.063867    3.505368    0.157537    0.073273    0.026947    0.727712    
#> 024: 0.413097    1.103439    3.497866    0.152227    0.079218    0.025600    0.722768    
#> 025: 0.366876    1.069187    3.495325    0.144616    0.088253    0.024320    0.734227    
#> 026: 0.345806    1.098606    3.485147    0.137385    0.084723    0.023104    0.729950    
#> 027: 0.328040    1.111733    3.478967    0.130516    0.080487    0.022241    0.746458    
#> 028: 0.357172    1.087388    3.489656    0.123990    0.076463    0.021129    0.726079    
#> 029: 0.378894    1.081449    3.480128    0.148088    0.084061    0.020073    0.733690    
#> 030: 0.360083    1.084262    3.483476    0.140684    0.079858    0.019069    0.735826    
#> 031: 0.348181    1.070063    3.501145    0.133650    0.095965    0.018115    0.724029    
#> 032: 0.347317    1.040238    3.506051    0.158180    0.091167    0.017972    0.728823    
#> 033: 0.346652    1.049354    3.499501    0.150426    0.086609    0.017243    0.744828    
#> 034: 0.399721    1.069523    3.502396    0.142905    0.082278    0.016796    0.747668    
#> 035: 0.317957    1.057070    3.482556    0.151508    0.085662    0.016931    0.720435    
#> 036: 0.339783    1.053972    3.493968    0.177032    0.081379    0.019603    0.744495    
#> 037: 0.336745    1.075463    3.484977    0.180314    0.077310    0.018623    0.745862    
#> 038: 0.370179    1.073048    3.479604    0.171298    0.077712    0.017753    0.742156    
#> 039: 0.374004    1.084768    3.499611    0.182265    0.073827    0.016914    0.708143    
#> 040: 0.372079    1.088546    3.506919    0.187188    0.070135    0.016958    0.724642    
#> 041: 0.367532    1.069695    3.506470    0.177828    0.084315    0.020575    0.716602    
#> 042: 0.391360    1.057284    3.496977    0.168937    0.080099    0.019546    0.723468    
#> 043: 0.359867    1.077026    3.478023    0.160490    0.076094    0.020563    0.739973    
#> 044: 0.321746    1.099166    3.473850    0.152466    0.072289    0.019535    0.736303    
#> 045: 0.314536    1.106045    3.463687    0.144842    0.068675    0.018558    0.739494    
#> 046: 0.335908    1.109817    3.465248    0.145641    0.068332    0.017630    0.729221    
#> 047: 0.307029    1.101483    3.452597    0.138359    0.083203    0.021257    0.722954    
#> 048: 0.324979    1.074043    3.466110    0.158540    0.084605    0.020194    0.717682    
#> 049: 0.305501    1.096482    3.477117    0.150613    0.095698    0.019184    0.734455    
#> 050: 0.338669    1.062804    3.483652    0.143082    0.090913    0.018225    0.770785    
#> 051: 0.332810    1.070481    3.488920    0.149633    0.086368    0.020645    0.753212    
#> 052: 0.366761    1.084490    3.504156    0.170053    0.082049    0.019613    0.733976    
#> 053: 0.392294    1.065918    3.506742    0.188248    0.092320    0.018632    0.735772    
#> 054: 0.327744    1.081631    3.502581    0.178836    0.087704    0.021060    0.729904    
#> 055: 0.334971    1.067273    3.499938    0.178498    0.096200    0.024973    0.739477    
#> 056: 0.346622    1.046202    3.496445    0.169573    0.091390    0.023724    0.743206    
#> 057: 0.348607    1.058821    3.501173    0.161095    0.088178    0.023318    0.724277    
#> 058: 0.374051    1.060260    3.490695    0.164734    0.085953    0.022152    0.728714    
#> 059: 0.386717    1.022381    3.504898    0.201707    0.082832    0.027076    0.750355    
#> 060: 0.400643    1.024635    3.523251    0.236706    0.085992    0.025722    0.749984    
#> 061: 0.391476    1.043909    3.513119    0.224871    0.082189    0.024436    0.743509    
#> 062: 0.387893    1.049946    3.515818    0.213627    0.094379    0.023214    0.751882    
#> 063: 0.404646    1.019546    3.520398    0.202946    0.089660    0.022054    0.764676    
#> 064: 0.378957    1.040546    3.518430    0.192798    0.088236    0.020951    0.761067    
#> 065: 0.393309    1.040737    3.490626    0.183406    0.095918    0.019903    0.740836    
#> 066: 0.400637    1.066751    3.494926    0.191368    0.095654    0.018908    0.735864    
#> 067: 0.344976    1.062378    3.483490    0.181800    0.090872    0.017963    0.739140    
#> 068: 0.317250    1.060659    3.488676    0.172710    0.093547    0.017065    0.751597    
#> 069: 0.326990    1.068979    3.487035    0.167819    0.088869    0.016211    0.736144    
#> 070: 0.328592    1.078959    3.491996    0.196093    0.091951    0.018766    0.738577    
#> 071: 0.329715    1.118247    3.466359    0.186288    0.091210    0.019754    0.777097    
#> 072: 0.290864    1.045283    3.484326    0.176974    0.094342    0.018795    0.745812    
#> 073: 0.313469    1.062389    3.492763    0.168125    0.089625    0.020272    0.755669    
#> 074: 0.312894    1.049985    3.488136    0.159719    0.085143    0.019258    0.736195    
#> 075: 0.347901    1.025638    3.515436    0.151733    0.092351    0.018295    0.753673    
#> 076: 0.383665    1.065705    3.517213    0.154866    0.087733    0.017380    0.761280    
#> 077: 0.397417    1.042072    3.514125    0.147123    0.083347    0.019846    0.749213    
#> 078: 0.379384    1.039283    3.515790    0.139767    0.089471    0.018854    0.734617    
#> 079: 0.414536    1.047669    3.518971    0.132779    0.084997    0.018705    0.759516    
#> 080: 0.378330    1.049381    3.510054    0.150918    0.080747    0.022007    0.773527    
#> 081: 0.353807    1.069548    3.494786    0.143372    0.076710    0.022718    0.751897    
#> 082: 0.332983    1.058516    3.495657    0.155754    0.072875    0.021582    0.742136    
#> 083: 0.340508    1.074399    3.496615    0.147966    0.069231    0.020503    0.755340    
#> 084: 0.363733    1.079004    3.493018    0.154320    0.071613    0.022906    0.744390    
#> 085: 0.363899    1.076811    3.501395    0.157130    0.068033    0.022130    0.745969    
#> 086: 0.351375    1.067977    3.498462    0.160818    0.064631    0.022640    0.740311    
#> 087: 0.342949    1.073669    3.483349    0.153096    0.061400    0.023657    0.741875    
#> 088: 0.324345    1.070835    3.490162    0.183888    0.058330    0.022474    0.742732    
#> 089: 0.357058    1.079970    3.484034    0.185921    0.067345    0.021492    0.735672    
#> 090: 0.303166    1.078737    3.477964    0.176625    0.076202    0.020417    0.719670    
#> 091: 0.299652    1.061910    3.460820    0.167794    0.073520    0.019397    0.723938    
#> 092: 0.273707    1.089164    3.454430    0.159404    0.071363    0.020290    0.757914    
#> 093: 0.271202    1.082502    3.464903    0.169292    0.078582    0.020206    0.735644    
#> 094: 0.286328    1.084321    3.473054    0.181221    0.090322    0.019196    0.741204    
#> 095: 0.333062    1.111495    3.484538    0.203342    0.085806    0.019814    0.742738    
#> 096: 0.296090    1.091433    3.463619    0.193175    0.084965    0.018824    0.733195    
#> 097: 0.306438    1.114063    3.465280    0.183516    0.085709    0.019645    0.731352    
#> 098: 0.310002    1.134343    3.470436    0.174341    0.084652    0.022548    0.742850    
#> 099: 0.285052    1.112067    3.446322    0.190478    0.085710    0.021420    0.732039    
#> 100: 0.305469    1.104782    3.460707    0.191268    0.094771    0.020349    0.720887    
#> 101: 0.251978    1.104784    3.430790    0.181704    0.090032    0.019332    0.727293    
#> 102: 0.252629    1.105548    3.432981    0.174205    0.085531    0.018365    0.752850    
#> 103: 0.311474    1.096881    3.456848    0.197174    0.084922    0.017447    0.724547    
#> 104: 0.295986    1.089533    3.473829    0.192604    0.083682    0.016575    0.737175    
#> 105: 0.326928    1.079417    3.478056    0.188266    0.088962    0.015746    0.736216    
#> 106: 0.331060    1.056137    3.478610    0.178853    0.084514    0.014959    0.751934    
#> 107: 0.370552    1.064412    3.478969    0.169910    0.082523    0.014211    0.766204    
#> 108: 0.312607    1.069482    3.465509    0.164834    0.088011    0.013500    0.781955    
#> 109: 0.315585    1.091219    3.474687    0.183826    0.091817    0.012825    0.756136    
#> 110: 0.305412    1.064784    3.469864    0.199391    0.092381    0.012184    0.742157    
#> 111: 0.317118    1.080809    3.472271    0.189422    0.096749    0.011575    0.751656    
#> 112: 0.353702    1.052723    3.471891    0.187509    0.106135    0.010996    0.748663    
#> 113: 0.350038    1.098110    3.478118    0.185408    0.100828    0.010446    0.733465    
#> 114: 0.326914    1.080672    3.478716    0.176138    0.102458    0.009924    0.763245    
#> 115: 0.340191    1.066345    3.481680    0.167331    0.097335    0.009646    0.763003    
#> 116: 0.347036    1.075275    3.487754    0.173972    0.092469    0.012318    0.773494    
#> 117: 0.331900    1.109531    3.482051    0.182540    0.087845    0.013357    0.756611    
#> 118: 0.333941    1.074558    3.486718    0.173413    0.083453    0.012689    0.739453    
#> 119: 0.335318    1.061942    3.492625    0.164743    0.084704    0.012055    0.758946    
#> 120: 0.345652    1.045192    3.484354    0.156505    0.086041    0.012025    0.740393    
#> 121: 0.352025    1.099134    3.489504    0.148680    0.105570    0.013955    0.738390    
#> 122: 0.345887    1.065100    3.491054    0.147043    0.100291    0.013838    0.748722    
#> 123: 0.384944    1.079731    3.484753    0.158811    0.095277    0.014683    0.741632    
#> 124: 0.394044    1.102104    3.493631    0.150870    0.090513    0.014085    0.757877    
#> 125: 0.367147    1.100841    3.484410    0.151880    0.113337    0.013587    0.726466    
#> 126: 0.330772    1.101252    3.471484    0.197390    0.107670    0.016691    0.724799    
#> 127: 0.324317    1.069891    3.462310    0.199910    0.102287    0.015856    0.744459    
#> 128: 0.292122    1.084579    3.474600    0.189914    0.097172    0.015063    0.729725    
#> 129: 0.334841    1.101480    3.491892    0.187777    0.092314    0.017439    0.735796    
#> 130: 0.384813    1.074063    3.494075    0.182375    0.087698    0.016762    0.711500    
#> 131: 0.363204    1.064366    3.487037    0.183855    0.085144    0.018775    0.734154    
#> 132: 0.301308    1.094743    3.464159    0.174662    0.084570    0.021431    0.748080    
#> 133: 0.298185    1.074754    3.472899    0.197317    0.080342    0.020360    0.752561    
#> 134: 0.371023    1.059046    3.505009    0.187451    0.076325    0.022755    0.756582    
#> 135: 0.364413    1.051280    3.510005    0.178078    0.074619    0.021617    0.749094    
#> 136: 0.367359    1.056211    3.505805    0.204989    0.075520    0.022559    0.722092    
#> 137: 0.415576    1.064818    3.503903    0.194739    0.071744    0.024171    0.734126    
#> 138: 0.411529    1.031619    3.509575    0.195502    0.068157    0.022962    0.746313    
#> 139: 0.399932    1.061715    3.525580    0.197251    0.086005    0.021814    0.741001    
#> 140: 0.417367    1.049231    3.528313    0.187389    0.081705    0.021319    0.752204    
#> 141: 0.393079    1.018410    3.523284    0.178019    0.081480    0.020253    0.742941    
#> 142: 0.384560    1.016976    3.524088    0.169118    0.077406    0.019240    0.769829    
#> 143: 0.365426    1.044976    3.518012    0.160662    0.081414    0.018439    0.770993    
#> 144: 0.428533    1.038648    3.518814    0.152629    0.077343    0.017517    0.738195    
#> 145: 0.375158    1.055798    3.500566    0.176957    0.073476    0.016641    0.723614    
#> 146: 0.374841    1.066478    3.509968    0.168109    0.074310    0.019040    0.718472    
#> 147: 0.349240    1.057240    3.493599    0.159704    0.070594    0.020672    0.708696    
#> 148: 0.328062    1.059629    3.496403    0.168725    0.073828    0.019638    0.724520    
#> 149: 0.343740    1.055170    3.502426    0.195345    0.070137    0.020882    0.731125    
#> 150: 0.363663    1.054115    3.488581    0.196839    0.079216    0.019838    0.732531    
#> 151: 0.289418    1.086396    3.475361    0.189301    0.078847    0.018846    0.739550    
#> 152: 0.325339    1.087215    3.485679    0.177015    0.071471    0.015743    0.727696    
#> 153: 0.340346    1.088365    3.486926    0.162927    0.080576    0.015240    0.725122    
#> 154: 0.367244    1.075164    3.500166    0.162403    0.083502    0.018304    0.747118    
#> 155: 0.344948    1.055551    3.494164    0.165658    0.071333    0.018208    0.732300    
#> 156: 0.379346    1.077037    3.498603    0.177563    0.065131    0.020760    0.748878    
#> 157: 0.361526    1.086453    3.505469    0.172856    0.081936    0.018673    0.744897    
#> 158: 0.370267    1.093640    3.489961    0.167829    0.094323    0.015033    0.731667    
#> 159: 0.336680    1.079957    3.498113    0.173196    0.077224    0.018011    0.739895    
#> 160: 0.349375    1.051221    3.504122    0.202798    0.083274    0.019522    0.723413    
#> 161: 0.362390    1.055879    3.496968    0.169159    0.081661    0.020808    0.737056    
#> 162: 0.340353    1.075227    3.472439    0.225261    0.078433    0.022447    0.726307    
#> 163: 0.372513    1.075359    3.483318    0.235004    0.079474    0.021865    0.721073    
#> 164: 0.368754    1.074562    3.486578    0.250346    0.067567    0.020380    0.718164    
#> 165: 0.373201    1.073625    3.492999    0.202590    0.067807    0.025780    0.709301    
#> 166: 0.394991    1.102107    3.486257    0.266300    0.073853    0.023335    0.734129    
#> 167: 0.360401    1.110163    3.496796    0.230814    0.072321    0.021028    0.737758    
#> 168: 0.381172    1.093103    3.493427    0.212033    0.077051    0.018001    0.736841    
#> 169: 0.369236    1.105663    3.487605    0.169011    0.077084    0.017362    0.744457    
#> 170: 0.372991    1.067231    3.497376    0.189760    0.073222    0.021351    0.714126    
#> 171: 0.355772    1.062127    3.497695    0.180569    0.076182    0.020639    0.717391    
#> 172: 0.330470    1.086315    3.492374    0.162716    0.073953    0.018710    0.737426    
#> 173: 0.319478    1.086268    3.473390    0.170425    0.069724    0.014956    0.750510    
#> 174: 0.341548    1.074063    3.489977    0.197104    0.066201    0.016489    0.736897    
#> 175: 0.342476    1.081815    3.472813    0.199059    0.072560    0.015173    0.744722    
#> 176: 0.342280    1.093286    3.482720    0.179369    0.067449    0.012239    0.746477    
#> 177: 0.370433    1.074969    3.490270    0.151784    0.078457    0.010362    0.746617    
#> 178: 0.368541    1.078700    3.485082    0.151036    0.085723    0.013141    0.730802    
#> 179: 0.360387    1.094865    3.482912    0.153930    0.077999    0.016425    0.738666    
#> 180: 0.340219    1.083257    3.477883    0.148128    0.074840    0.014790    0.735705    
#> 181: 0.335611    1.079251    3.461667    0.139300    0.071524    0.015227    0.737609    
#> 182: 0.322146    1.091788    3.468275    0.148045    0.088721    0.016658    0.765970    
#> 183: 0.336690    1.088785    3.475225    0.157282    0.069871    0.020848    0.747564    
#> 184: 0.318816    1.082616    3.474406    0.215864    0.075287    0.019902    0.729398    
#> 185: 0.282163    1.109567    3.471512    0.184407    0.068259    0.020183    0.737845    
#> 186: 0.319920    1.112137    3.469784    0.183100    0.077037    0.024252    0.729253    
#> 187: 0.308278    1.085843    3.473846    0.220720    0.061959    0.027167    0.732903    
#> 188: 0.306124    1.117784    3.459816    0.203637    0.071395    0.021923    0.752975    
#> 189: 0.348577    1.131267    3.483651    0.211176    0.086744    0.022720    0.759768    
#> 190: 0.336535    1.096847    3.488278    0.179100    0.070706    0.024652    0.730150    
#> 191: 0.281897    1.092439    3.466788    0.170209    0.065318    0.021363    0.720745    
#> 192: 0.306541    1.087314    3.478164    0.143569    0.061682    0.020054    0.737400    
#> 193: 0.350409    1.100112    3.480815    0.163338    0.055851    0.020522    0.740994    
#> 194: 0.358176    1.066954    3.493952    0.193736    0.078291    0.020917    0.722388    
#> 195: 0.328875    1.074678    3.481544    0.205383    0.069035    0.019718    0.727657    
#> 196: 0.319901    1.083453    3.477819    0.214338    0.075286    0.019254    0.734292    
#> 197: 0.278483    1.089364    3.486975    0.209559    0.076684    0.015600    0.740521    
#> 198: 0.336854    1.093764    3.484068    0.190973    0.091669    0.017068    0.728165    
#> 199: 0.292805    1.074100    3.480694    0.166915    0.086349    0.013081    0.744934    
#> 200: 0.299462    1.082831    3.482475    0.154848    0.102381    0.012623    0.768661    
#> 201: 0.314098    1.074969    3.491851    0.137297    0.095318    0.013268    0.758210    
#> 202: 0.326327    1.075202    3.491617    0.141153    0.095184    0.013219    0.755037    
#> 203: 0.338156    1.074546    3.490365    0.138390    0.094568    0.013568    0.753947    
#> 204: 0.350304    1.068482    3.492386    0.140736    0.096446    0.013461    0.754475    
#> 205: 0.352982    1.073638    3.493088    0.140830    0.096602    0.014096    0.757950    
#> 206: 0.355678    1.076145    3.493850    0.145263    0.097250    0.014360    0.757730    
#> 207: 0.353603    1.073313    3.492418    0.143800    0.096285    0.014419    0.757557    
#> 208: 0.351234    1.073856    3.491038    0.144227    0.093557    0.014526    0.756175    
#> 209: 0.352951    1.071508    3.490185    0.146290    0.091580    0.014504    0.754466    
#> 210: 0.352909    1.070407    3.489829    0.144479    0.090637    0.014374    0.753275    
#> 211: 0.352321    1.070731    3.491012    0.142284    0.089854    0.014594    0.751139    
#> 212: 0.352966    1.068342    3.491599    0.142389    0.088292    0.015035    0.751188    
#> 213: 0.353591    1.065855    3.491497    0.142889    0.086662    0.015316    0.751033    
#> 214: 0.354044    1.064949    3.491289    0.145237    0.085680    0.015459    0.748897    
#> 215: 0.353694    1.063792    3.492173    0.147577    0.084790    0.015716    0.748926    
#> 216: 0.355647    1.063174    3.492397    0.149923    0.084596    0.015957    0.748457    
#> 217: 0.357232    1.064035    3.492857    0.152926    0.084241    0.016056    0.746134    
#> 218: 0.357908    1.065069    3.492867    0.155239    0.084762    0.016154    0.744845    
#> 219: 0.357697    1.064536    3.492021    0.156705    0.084808    0.016174    0.744373    
#> 220: 0.357054    1.064802    3.491850    0.155967    0.084468    0.016271    0.744690    
#> 221: 0.356646    1.064909    3.491437    0.155813    0.084123    0.016480    0.743905    
#> 222: 0.355711    1.064798    3.491313    0.157954    0.084161    0.016734    0.743702    
#> 223: 0.356948    1.064155    3.491429    0.158417    0.084195    0.016947    0.743266    
#> 224: 0.358357    1.064972    3.491617    0.158790    0.084387    0.016953    0.742939    
#> 225: 0.357254    1.063643    3.491790    0.157698    0.084194    0.016900    0.743557    
#> 226: 0.357871    1.062422    3.491806    0.157603    0.083896    0.016735    0.743544    
#> 227: 0.357530    1.062763    3.491918    0.156201    0.084383    0.016613    0.743513    
#> 228: 0.356183    1.063712    3.491248    0.155421    0.084894    0.016477    0.743556    
#> 229: 0.355493    1.063001    3.491171    0.155714    0.084921    0.016429    0.743111    
#> 230: 0.355210    1.062811    3.490889    0.156097    0.084529    0.016381    0.742748    
#> 231: 0.354532    1.063663    3.490579    0.156498    0.084729    0.016316    0.742891    
#> 232: 0.353205    1.063913    3.490366    0.157324    0.084441    0.016280    0.743185    
#> 233: 0.352328    1.063160    3.490258    0.157764    0.084355    0.016308    0.743183    
#> 234: 0.351328    1.063920    3.490217    0.157068    0.084728    0.016282    0.743181    
#> 235: 0.351349    1.063867    3.489826    0.157026    0.084570    0.016263    0.743055    
#> 236: 0.351417    1.064224    3.489833    0.156230    0.084786    0.016298    0.743127    
#> 237: 0.351724    1.064780    3.489653    0.155803    0.085051    0.016331    0.743425    
#> 238: 0.351232    1.065506    3.489337    0.155339    0.085633    0.016336    0.743937    
#> 239: 0.350659    1.066417    3.489090    0.155175    0.086015    0.016494    0.743696    
#> 240: 0.350547    1.066526    3.489162    0.155255    0.086143    0.016515    0.743017    
#> 241: 0.350525    1.066182    3.489218    0.155337    0.086128    0.016525    0.742600    
#> 242: 0.350349    1.066169    3.489103    0.155118    0.086496    0.016523    0.742493    
#> 243: 0.349031    1.066814    3.488928    0.155111    0.086728    0.016461    0.742601    
#> 244: 0.348631    1.066905    3.489172    0.155235    0.086517    0.016524    0.742643    
#> 245: 0.349225    1.066723    3.489423    0.155850    0.086551    0.016552    0.743298    
#> 246: 0.349574    1.066351    3.489570    0.156807    0.086045    0.016582    0.743547    
#> 247: 0.349474    1.066262    3.490087    0.157394    0.085881    0.016636    0.743455    
#> 248: 0.349579    1.066565    3.490152    0.158013    0.085800    0.016629    0.743163    
#> 249: 0.349727    1.066177    3.490481    0.158100    0.085700    0.016632    0.743202    
#> 250: 0.350523    1.066523    3.490788    0.158726    0.085917    0.016721    0.743241    
#> 251: 0.351150    1.066970    3.490989    0.159750    0.085959    0.016691    0.743333    
#> 252: 0.351956    1.067162    3.491448    0.159649    0.086271    0.016639    0.743165    
#> 253: 0.352623    1.067221    3.491739    0.159954    0.086356    0.016712    0.743278    
#> 254: 0.353480    1.067690    3.491973    0.159811    0.086597    0.016659    0.743179    
#> 255: 0.353731    1.067821    3.492234    0.159501    0.086569    0.016633    0.743398    
#> 256: 0.353801    1.067628    3.492275    0.159524    0.086593    0.016608    0.743645    
#> 257: 0.353524    1.067449    3.492122    0.159511    0.086583    0.016562    0.743724    
#> 258: 0.353381    1.066954    3.492100    0.159491    0.086358    0.016518    0.743859    
#> 259: 0.353230    1.066839    3.492140    0.159196    0.086148    0.016499    0.743842    
#> 260: 0.352940    1.066858    3.492321    0.159698    0.086016    0.016453    0.743520    
#> 261: 0.352980    1.066740    3.492472    0.160016    0.086107    0.016448    0.743264    
#> 262: 0.353030    1.066924    3.492473    0.159910    0.086142    0.016421    0.743266    
#> 263: 0.352889    1.067454    3.492401    0.160429    0.086302    0.016421    0.743196    
#> 264: 0.352766    1.067480    3.492352    0.160680    0.086402    0.016397    0.743365    
#> 265: 0.352875    1.067252    3.492358    0.160677    0.086789    0.016404    0.743409    
#> 266: 0.353425    1.067309    3.492454    0.160635    0.086747    0.016402    0.743455    
#> 267: 0.353996    1.067378    3.492617    0.160445    0.086822    0.016431    0.743294    
#> 268: 0.354102    1.067531    3.492537    0.160723    0.086906    0.016439    0.743246    
#> 269: 0.354663    1.067638    3.492547    0.161072    0.086858    0.016448    0.743299    
#> 270: 0.354880    1.068043    3.492307    0.161357    0.086556    0.016438    0.743152    
#> 271: 0.355001    1.067895    3.492108    0.161562    0.086304    0.016435    0.743275    
#> 272: 0.354890    1.067758    3.491947    0.162219    0.086034    0.016449    0.743585    
#> 273: 0.354451    1.068064    3.491849    0.162358    0.086004    0.016477    0.743690    
#> 274: 0.353835    1.068293    3.491716    0.161955    0.085882    0.016483    0.743893    
#> 275: 0.353803    1.068465    3.491538    0.162045    0.085984    0.016502    0.744084    
#> 276: 0.353316    1.068801    3.491555    0.161978    0.085910    0.016544    0.744196    
#> 277: 0.353061    1.069128    3.491629    0.161602    0.085790    0.016576    0.744143    
#> 278: 0.352513    1.069282    3.491574    0.160888    0.085933    0.016573    0.744040    
#> 279: 0.352179    1.069365    3.491524    0.160657    0.086084    0.016600    0.744004    
#> 280: 0.352157    1.069476    3.491523    0.160700    0.085970    0.016645    0.743750    
#> 281: 0.351793    1.069805    3.491438    0.161010    0.085860    0.016645    0.743486    
#> 282: 0.351735    1.070024    3.491563    0.161273    0.085670    0.016699    0.743330    
#> 283: 0.351924    1.069932    3.491686    0.161635    0.085413    0.016796    0.743285    
#> 284: 0.351792    1.069612    3.491750    0.161808    0.085076    0.016876    0.743114    
#> 285: 0.351595    1.069642    3.491600    0.161733    0.084882    0.016933    0.743172    
#> 286: 0.351680    1.069922    3.491490    0.161623    0.084779    0.016999    0.743223    
#> 287: 0.351841    1.070167    3.491492    0.161485    0.084623    0.017062    0.743309    
#> 288: 0.352355    1.070130    3.491654    0.161335    0.084503    0.017116    0.743390    
#> 289: 0.353129    1.069867    3.491865    0.161190    0.084365    0.017158    0.743403    
#> 290: 0.353436    1.069899    3.491974    0.160940    0.084182    0.017166    0.743692    
#> 291: 0.354166    1.070050    3.492189    0.160945    0.084088    0.017192    0.743691    
#> 292: 0.353955    1.070076    3.492137    0.161266    0.083962    0.017190    0.743663    
#> 293: 0.353972    1.070060    3.492045    0.161197    0.083982    0.017207    0.743643    
#> 294: 0.353564    1.070211    3.491882    0.161226    0.083906    0.017206    0.743461    
#> 295: 0.353242    1.070189    3.491693    0.161392    0.083729    0.017227    0.743221    
#> 296: 0.352996    1.070301    3.491670    0.161337    0.083449    0.017285    0.743204    
#> 297: 0.352799    1.070516    3.491538    0.161270    0.083190    0.017316    0.743162    
#> 298: 0.352764    1.070561    3.491490    0.161357    0.083051    0.017288    0.743116    
#> 299: 0.352626    1.070677    3.491354    0.161364    0.082955    0.017278    0.743177    
#> 300: 0.352774    1.070554    3.491325    0.161339    0.082885    0.017262    0.742990    
#> 301: 0.352970    1.070491    3.491242    0.161191    0.082871    0.017248    0.742883    
#> 302: 0.353049    1.070511    3.491154    0.161404    0.082928    0.017229    0.742609    
#> 303: 0.353068    1.070636    3.491120    0.161323    0.082776    0.017253    0.742374    
#> 304: 0.353093    1.070828    3.491092    0.161467    0.082620    0.017268    0.742370    
#> 305: 0.352850    1.070692    3.491091    0.161359    0.082604    0.017307    0.742280    
#> 306: 0.352494    1.070750    3.490934    0.161208    0.082629    0.017296    0.742233    
#> 307: 0.352250    1.070802    3.490786    0.161065    0.082735    0.017298    0.742377    
#> 308: 0.352057    1.070531    3.490757    0.161302    0.082897    0.017335    0.742515    
#> 309: 0.352144    1.070285    3.490683    0.161477    0.082809    0.017330    0.742605    
#> 310: 0.352321    1.070110    3.490650    0.161398    0.082904    0.017313    0.742508    
#> 311: 0.352373    1.069994    3.490798    0.161472    0.082805    0.017335    0.742434    
#> 312: 0.352291    1.069893    3.490790    0.161872    0.082777    0.017343    0.742362    
#> 313: 0.351843    1.069758    3.490662    0.161876    0.082809    0.017375    0.742411    
#> 314: 0.351226    1.069953    3.490449    0.161769    0.082795    0.017369    0.742370    
#> 315: 0.350906    1.070029    3.490418    0.162014    0.082726    0.017380    0.742289    
#> 316: 0.350989    1.070291    3.490322    0.162466    0.082662    0.017364    0.742214    
#> 317: 0.351152    1.070238    3.490420    0.162740    0.082655    0.017364    0.742326    
#> 318: 0.351183    1.070362    3.490348    0.162878    0.082610    0.017372    0.742134    
#> 319: 0.351326    1.070300    3.490381    0.162867    0.082624    0.017387    0.741974    
#> 320: 0.351069    1.070341    3.490357    0.163097    0.082606    0.017405    0.741957    
#> 321: 0.350715    1.070349    3.490239    0.163126    0.082488    0.017407    0.742030    
#> 322: 0.350353    1.070375    3.490050    0.163710    0.082500    0.017393    0.742065    
#> 323: 0.349667    1.070464    3.489896    0.163972    0.082469    0.017429    0.742162    
#> 324: 0.349610    1.070686    3.489834    0.164172    0.082551    0.017427    0.741967    
#> 325: 0.349580    1.070804    3.489683    0.164053    0.082541    0.017410    0.741819    
#> 326: 0.349436    1.070570    3.489591    0.163955    0.082627    0.017383    0.741732    
#> 327: 0.349451    1.070501    3.489651    0.164017    0.082719    0.017378    0.741676    
#> 328: 0.349540    1.070533    3.489729    0.163922    0.082638    0.017385    0.741530    
#> 329: 0.349782    1.070571    3.489771    0.163912    0.082638    0.017383    0.741555    
#> 330: 0.349762    1.070652    3.489751    0.163914    0.082656    0.017351    0.741562    
#> 331: 0.349758    1.070800    3.489706    0.163729    0.082618    0.017328    0.741545    
#> 332: 0.349641    1.070885    3.489749    0.163631    0.082437    0.017331    0.741538    
#> 333: 0.349470    1.071063    3.489603    0.163810    0.082310    0.017376    0.741438    
#> 334: 0.349223    1.071186    3.489392    0.163926    0.082169    0.017403    0.741287    
#> 335: 0.348814    1.071362    3.489185    0.164059    0.082223    0.017416    0.741248    
#> 336: 0.348442    1.071653    3.489037    0.163926    0.082310    0.017435    0.741317    
#> 337: 0.348281    1.072051    3.488888    0.163733    0.082291    0.017435    0.741355    
#> 338: 0.348252    1.072272    3.488954    0.163571    0.082207    0.017458    0.741381    
#> 339: 0.348006    1.072403    3.488950    0.163475    0.082079    0.017499    0.741253    
#> 340: 0.347962    1.072440    3.488955    0.163418    0.082033    0.017522    0.741166    
#> 341: 0.347939    1.072421    3.488985    0.163451    0.081907    0.017552    0.741089    
#> 342: 0.347776    1.072347    3.488963    0.163194    0.081929    0.017591    0.740892    
#> 343: 0.347431    1.072429    3.488964    0.163172    0.081915    0.017609    0.740755    
#> 344: 0.347366    1.072498    3.488920    0.163321    0.081880    0.017652    0.740632    
#> 345: 0.347277    1.072382    3.488915    0.163339    0.081817    0.017651    0.740617    
#> 346: 0.347197    1.072446    3.488863    0.163385    0.081665    0.017651    0.740557    
#> 347: 0.347215    1.072380    3.488793    0.163406    0.081585    0.017661    0.740657    
#> 348: 0.347024    1.072386    3.488767    0.163530    0.081605    0.017657    0.740665    
#> 349: 0.347364    1.072156    3.488829    0.163591    0.081619    0.017644    0.740705    
#> 350: 0.347250    1.071995    3.488726    0.163578    0.081644    0.017611    0.740764    
#> 351: 0.347206    1.072161    3.488606    0.163381    0.081618    0.017589    0.740821    
#> 352: 0.346925    1.072347    3.488558    0.163423    0.081630    0.017593    0.740859    
#> 353: 0.346849    1.072627    3.488470    0.163844    0.081614    0.017602    0.740921    
#> 354: 0.346762    1.072774    3.488274    0.163979    0.081576    0.017641    0.740866    
#> 355: 0.347073    1.072646    3.488266    0.164042    0.081532    0.017652    0.740818    
#> 356: 0.347060    1.072528    3.488241    0.163867    0.081485    0.017665    0.740924    
#> 357: 0.347159    1.072635    3.488218    0.163810    0.081487    0.017677    0.740839    
#> 358: 0.347039    1.072676    3.488220    0.163720    0.081404    0.017689    0.740797    
#> 359: 0.347016    1.072734    3.488256    0.163669    0.081358    0.017685    0.740660    
#> 360: 0.346706    1.072761    3.488167    0.163551    0.081380    0.017659    0.740583    
#> 361: 0.346392    1.072872    3.488054    0.163485    0.081411    0.017631    0.740535    
#> 362: 0.346206    1.072998    3.487917    0.163427    0.081413    0.017617    0.740422    
#> 363: 0.346048    1.072947    3.487898    0.163410    0.081336    0.017616    0.740278    
#> 364: 0.345906    1.072992    3.487866    0.163680    0.081302    0.017620    0.740208    
#> 365: 0.345691    1.072899    3.487878    0.163743    0.081289    0.017645    0.740171    
#> 366: 0.345747    1.072948    3.487825    0.163817    0.081269    0.017665    0.740160    
#> 367: 0.345953    1.073027    3.487805    0.163842    0.081361    0.017650    0.740181    
#> 368: 0.346167    1.073019    3.487803    0.163901    0.081276    0.017651    0.740240    
#> 369: 0.346173    1.073071    3.487744    0.164000    0.081231    0.017665    0.740210    
#> 370: 0.345851    1.073104    3.487633    0.163990    0.081203    0.017687    0.740237    
#> 371: 0.345368    1.073239    3.487386    0.164002    0.081090    0.017711    0.740329    
#> 372: 0.345063    1.073338    3.487234    0.164010    0.081034    0.017729    0.740378    
#> 373: 0.344635    1.073493    3.487107    0.164047    0.081035    0.017742    0.740422    
#> 374: 0.344411    1.073572    3.486996    0.163881    0.081064    0.017746    0.740475    
#> 375: 0.344180    1.073611    3.486957    0.163740    0.081072    0.017744    0.740534    
#> 376: 0.344010    1.073875    3.486857    0.163640    0.081166    0.017745    0.740393    
#> 377: 0.343989    1.074059    3.486808    0.163533    0.081136    0.017736    0.740441    
#> 378: 0.343912    1.074094    3.486758    0.163600    0.081108    0.017728    0.740446    
#> 379: 0.343766    1.073998    3.486743    0.163721    0.081086    0.017730    0.740361    
#> 380: 0.343552    1.074057    3.486675    0.163682    0.081089    0.017729    0.740231    
#> 381: 0.343342    1.074022    3.486647    0.163526    0.081044    0.017722    0.740234    
#> 382: 0.343371    1.074063    3.486622    0.163405    0.080982    0.017754    0.740192    
#> 383: 0.343420    1.074059    3.486595    0.163436    0.080960    0.017767    0.740086    
#> 384: 0.343279    1.074079    3.486552    0.163514    0.080952    0.017757    0.740053    
#> 385: 0.343241    1.074133    3.486510    0.163686    0.080939    0.017757    0.740070    
#> 386: 0.343355    1.074334    3.486591    0.163688    0.080913    0.017768    0.740107    
#> 387: 0.343455    1.074410    3.486692    0.163748    0.080836    0.017788    0.740021    
#> 388: 0.343385    1.074526    3.486703    0.163719    0.080769    0.017797    0.739940    
#> 389: 0.343321    1.074531    3.486687    0.163616    0.080670    0.017808    0.739936    
#> 390: 0.343096    1.074546    3.486644    0.163629    0.080556    0.017829    0.739884    
#> 391: 0.343015    1.074521    3.486587    0.163858    0.080476    0.017846    0.739809    
#> 392: 0.343132    1.074497    3.486577    0.164077    0.080446    0.017857    0.739880    
#> 393: 0.343120    1.074551    3.486523    0.164162    0.080410    0.017860    0.739784    
#> 394: 0.343122    1.074554    3.486481    0.164212    0.080412    0.017854    0.739750    
#> 395: 0.343275    1.074695    3.486482    0.164430    0.080425    0.017846    0.739750    
#> 396: 0.343440    1.074812    3.486514    0.164631    0.080367    0.017838    0.739636    
#> 397: 0.343682    1.074780    3.486620    0.164777    0.080318    0.017843    0.739563    
#> 398: 0.343909    1.074711    3.486715    0.164645    0.080342    0.017870    0.739635    
#> 399: 0.344033    1.074717    3.486830    0.164627    0.080320    0.017876    0.739671    
#> 400: 0.344011    1.074855    3.486887    0.164475    0.080389    0.017883    0.739688    
#> 401: 0.344079    1.074951    3.486834    0.164383    0.080367    0.017895    0.739713    
#> 402: 0.343852    1.075131    3.486736    0.164243    0.080271    0.017908    0.739721    
#> 403: 0.343652    1.075178    3.486622    0.164259    0.080252    0.017933    0.739676    
#> 404: 0.343540    1.075214    3.486487    0.164311    0.080194    0.017931    0.739584    
#> 405: 0.343404    1.075276    3.486448    0.164297    0.080206    0.017919    0.739590    
#> 406: 0.343398    1.075377    3.486393    0.164037    0.080201    0.017905    0.739633    
#> 407: 0.343428    1.075424    3.486405    0.163910    0.080245    0.017879    0.739603    
#> 408: 0.343493    1.075422    3.486413    0.163794    0.080244    0.017864    0.739709    
#> 409: 0.343411    1.075401    3.486336    0.163764    0.080257    0.017857    0.739682    
#> 410: 0.343333    1.075454    3.486264    0.163856    0.080297    0.017852    0.739570    
#> 411: 0.343451    1.075352    3.486232    0.164132    0.080363    0.017844    0.739556    
#> 412: 0.343459    1.075400    3.486214    0.164188    0.080399    0.017834    0.739564    
#> 413: 0.343537    1.075375    3.486185    0.164262    0.080425    0.017818    0.739613    
#> 414: 0.343650    1.075338    3.486228    0.164422    0.080459    0.017807    0.739524    
#> 415: 0.343757    1.075249    3.486266    0.164396    0.080427    0.017801    0.739435    
#> 416: 0.343966    1.075264    3.486331    0.164372    0.080449    0.017808    0.739345    
#> 417: 0.344139    1.075192    3.486391    0.164353    0.080447    0.017798    0.739245    
#> 418: 0.344113    1.075274    3.486399    0.164284    0.080565    0.017769    0.739194    
#> 419: 0.344151    1.075466    3.486365    0.164359    0.080585    0.017752    0.739128    
#> 420: 0.344289    1.075553    3.486356    0.164418    0.080555    0.017736    0.739071    
#> 421: 0.344224    1.075613    3.486395    0.164400    0.080626    0.017723    0.739032    
#> 422: 0.344350    1.075593    3.486424    0.164602    0.080638    0.017720    0.738938    
#> 423: 0.344496    1.075522    3.486494    0.164624    0.080599    0.017720    0.738996    
#> 424: 0.344528    1.075531    3.486451    0.164689    0.080607    0.017725    0.738897    
#> 425: 0.344662    1.075686    3.486406    0.164717    0.080587    0.017732    0.738910    
#> 426: 0.344644    1.075747    3.486367    0.164873    0.080553    0.017732    0.738912    
#> 427: 0.344592    1.075684    3.486363    0.165036    0.080503    0.017741    0.738889    
#> 428: 0.344423    1.075742    3.486335    0.165047    0.080454    0.017732    0.738907    
#> 429: 0.344568    1.075814    3.486374    0.165016    0.080488    0.017710    0.738866    
#> 430: 0.344643    1.075835    3.486389    0.165120    0.080474    0.017710    0.738805    
#> 431: 0.344573    1.075742    3.486345    0.165202    0.080482    0.017708    0.738700    
#> 432: 0.344474    1.075725    3.486355    0.165272    0.080447    0.017722    0.738619    
#> 433: 0.344446    1.075824    3.486360    0.165230    0.080384    0.017740    0.738556    
#> 434: 0.344313    1.075707    3.486381    0.165254    0.080296    0.017761    0.738465    
#> 435: 0.344344    1.075680    3.486367    0.165258    0.080241    0.017766    0.738383    
#> 436: 0.344320    1.075604    3.486411    0.165195    0.080165    0.017773    0.738376    
#> 437: 0.344370    1.075617    3.486396    0.165196    0.080122    0.017789    0.738388    
#> 438: 0.344329    1.075685    3.486417    0.165098    0.080151    0.017795    0.738389    
#> 439: 0.344377    1.075751    3.486420    0.165052    0.080158    0.017781    0.738353    
#> 440: 0.344327    1.075830    3.486423    0.164952    0.080202    0.017768    0.738325    
#> 441: 0.344400    1.075806    3.486446    0.164962    0.080254    0.017768    0.738323    
#> 442: 0.344335    1.075921    3.486416    0.165075    0.080277    0.017767    0.738287    
#> 443: 0.344263    1.076067    3.486360    0.165170    0.080279    0.017776    0.738259    
#> 444: 0.344274    1.076170    3.486285    0.165183    0.080314    0.017780    0.738212    
#> 445: 0.344150    1.076146    3.486242    0.165311    0.080340    0.017782    0.738223    
#> 446: 0.344055    1.076183    3.486201    0.165343    0.080351    0.017785    0.738189    
#> 447: 0.344163    1.076163    3.486213    0.165388    0.080330    0.017809    0.738142    
#> 448: 0.344019    1.076135    3.486221    0.165336    0.080353    0.017815    0.738119    
#> 449: 0.344021    1.076171    3.486289    0.165319    0.080367    0.017822    0.738147    
#> 450: 0.344067    1.076101    3.486311    0.165331    0.080351    0.017842    0.738120    
#> 451: 0.344105    1.076170    3.486263    0.165413    0.080368    0.017842    0.738152    
#> 452: 0.344074    1.076223    3.486235    0.165318    0.080407    0.017832    0.738139    
#> 453: 0.344017    1.076244    3.486212    0.165289    0.080426    0.017813    0.738091    
#> 454: 0.343906    1.076392    3.486161    0.165128    0.080512    0.017803    0.738083    
#> 455: 0.343844    1.076416    3.486137    0.165002    0.080519    0.017788    0.738185    
#> 456: 0.343741    1.076340    3.486103    0.164988    0.080495    0.017795    0.738210    
#> 457: 0.343799    1.076279    3.486149    0.164985    0.080456    0.017798    0.738173    
#> 458: 0.343973    1.076300    3.486253    0.165038    0.080415    0.017821    0.738141    
#> 459: 0.343923    1.076345    3.486273    0.165078    0.080398    0.017831    0.738112    
#> 460: 0.343870    1.076363    3.486197    0.165177    0.080358    0.017851    0.738126    
#> 461: 0.343785    1.076438    3.486182    0.165357    0.080304    0.017880    0.738096    
#> 462: 0.343710    1.076629    3.486174    0.165463    0.080254    0.017901    0.738091    
#> 463: 0.343734    1.076735    3.486180    0.165642    0.080210    0.017919    0.738051    
#> 464: 0.343771    1.076775    3.486137    0.165758    0.080195    0.017919    0.737982    
#> 465: 0.343624    1.076635    3.486121    0.165711    0.080196    0.017905    0.738055    
#> 466: 0.343598    1.076657    3.486055    0.165550    0.080193    0.017884    0.738127    
#> 467: 0.343536    1.076590    3.486071    0.165573    0.080182    0.017886    0.738000    
#> 468: 0.343696    1.076579    3.486120    0.165604    0.080163    0.017893    0.738026    
#> 469: 0.343757    1.076647    3.486127    0.165704    0.080152    0.017921    0.737996    
#> 470: 0.343693    1.076728    3.486100    0.165599    0.080153    0.017943    0.737991    
#> 471: 0.343540    1.076704    3.486081    0.165379    0.080139    0.017936    0.738017    
#> 472: 0.343480    1.076729    3.486111    0.165287    0.080181    0.017939    0.737973    
#> 473: 0.343366    1.076713    3.486117    0.165261    0.080121    0.017948    0.737901    
#> 474: 0.343385    1.076670    3.486139    0.165199    0.080131    0.017949    0.737945    
#> 475: 0.343369    1.076711    3.486146    0.165108    0.080089    0.017940    0.737901    
#> 476: 0.343336    1.076715    3.486114    0.165120    0.080107    0.017927    0.737886    
#> 477: 0.343288    1.076739    3.486120    0.165060    0.080068    0.017926    0.737821    
#> 478: 0.343181    1.076733    3.486117    0.165009    0.079990    0.017935    0.737815    
#> 479: 0.343272    1.076793    3.486101    0.165048    0.079975    0.017939    0.737808    
#> 480: 0.343364    1.076819    3.486140    0.165033    0.079950    0.017944    0.737894    
#> 481: 0.343442    1.076776    3.486196    0.165029    0.079972    0.017933    0.737966    
#> 482: 0.343585    1.076711    3.486236    0.165076    0.080009    0.017944    0.737968    
#> 483: 0.343549    1.076698    3.486266    0.165174    0.080007    0.017934    0.737959    
#> 484: 0.343590    1.076546    3.486312    0.165341    0.079972    0.017932    0.737945    
#> 485: 0.343683    1.076501    3.486347    0.165421    0.079997    0.017936    0.737959    
#> 486: 0.343758    1.076443    3.486436    0.165436    0.080032    0.017933    0.737928    
#> 487: 0.343956    1.076375    3.486521    0.165383    0.080074    0.017920    0.737928    
#> 488: 0.343951    1.076387    3.486552    0.165362    0.080061    0.017908    0.737893    
#> 489: 0.344001    1.076405    3.486510    0.165403    0.080082    0.017891    0.737901    
#> 490: 0.344107    1.076452    3.486531    0.165449    0.080122    0.017862    0.737909    
#> 491: 0.344097    1.076549    3.486597    0.165355    0.080203    0.017849    0.737927    
#> 492: 0.344119    1.076604    3.486618    0.165271    0.080232    0.017832    0.737990    
#> 493: 0.344012    1.076676    3.486623    0.165210    0.080262    0.017833    0.737969    
#> 494: 0.343959    1.076716    3.486560    0.165129    0.080284    0.017830    0.737987    
#> 495: 0.344010    1.076756    3.486544    0.165204    0.080257    0.017834    0.737926    
#> 496: 0.344089    1.076782    3.486524    0.165128    0.080234    0.017843    0.737914    
#> 497: 0.344004    1.076786    3.486502    0.165119    0.080228    0.017844    0.737877    
#> 498: 0.343936    1.076750    3.486457    0.165141    0.080212    0.017842    0.737843    
#> 499: 0.343876    1.076862    3.486394    0.165209    0.080260    0.017841    0.737764    
#> 500: 0.343893    1.076873    3.486347    0.165375    0.080221    0.017846    0.737708    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.309360    0.966479    3.440945    0.392401    0.077737    0.016800    1.729942    
#> 002: 0.316752    1.016226    3.448642    0.372781    0.073851    0.015960    1.173974    
#> 003: 0.396219    0.941179    3.440577    0.354142    0.070158    0.015162    0.945350    
#> 004: 0.394716    0.973785    3.433579    0.336435    0.066650    0.014404    0.876132    
#> 005: 0.472774    0.965282    3.433480    0.343179    0.063318    0.013684    0.795143    
#> 006: 0.419450    0.976760    3.417196    0.366297    0.060152    0.013000    0.751815    
#> 007: 0.384569    0.979257    3.417583    0.347983    0.057144    0.012350    0.777215    
#> 008: 0.386063    0.972208    3.410944    0.330583    0.054287    0.015957    0.766007    
#> 009: 0.392164    0.965638    3.410305    0.359693    0.051573    0.016406    0.762518    
#> 010: 0.389764    0.948054    3.410029    0.341708    0.048994    0.017449    0.763341    
#> 011: 0.441773    0.984666    3.412775    0.379850    0.046544    0.017255    0.777367    
#> 012: 0.440386    0.965432    3.417399    0.360858    0.044217    0.016392    0.753977    
#> 013: 0.396109    0.979380    3.402135    0.418155    0.042006    0.021842    0.748380    
#> 014: 0.454278    0.979853    3.408407    0.496330    0.039906    0.020750    0.759583    
#> 015: 0.465734    0.983221    3.413131    0.517935    0.037911    0.021572    0.722661    
#> 016: 0.439112    1.012376    3.416874    0.492038    0.036015    0.022780    0.750205    
#> 017: 0.380030    1.004874    3.399776    0.467436    0.034214    0.021641    0.724111    
#> 018: 0.425471    1.013601    3.399244    0.480661    0.032504    0.020559    0.753476    
#> 019: 0.393080    1.007334    3.393007    0.456628    0.030878    0.019531    0.732210    
#> 020: 0.410273    0.999890    3.406956    0.433797    0.029335    0.018554    0.738148    
#> 021: 0.412574    0.994490    3.418875    0.412107    0.027868    0.017626    0.740675    
#> 022: 0.409994    0.987221    3.427824    0.391501    0.026474    0.016745    0.744163    
#> 023: 0.469948    0.996501    3.431149    0.374472    0.025151    0.015908    0.767489    
#> 024: 0.485542    1.009371    3.433339    0.375762    0.023893    0.015601    0.757626    
#> 025: 0.451988    0.979318    3.424143    0.367583    0.022698    0.018865    0.748058    
#> 026: 0.426263    0.992028    3.406508    0.409071    0.021564    0.017922    0.763870    
#> 027: 0.387734    1.008821    3.401847    0.447646    0.023964    0.017257    0.756000    
#> 028: 0.456917    1.001918    3.421541    0.434354    0.022766    0.018693    0.737829    
#> 029: 0.461454    0.996116    3.413124    0.412637    0.023394    0.020012    0.774359    
#> 030: 0.440092    1.027594    3.410744    0.417291    0.022224    0.019894    0.747275    
#> 031: 0.412329    1.008852    3.412975    0.396426    0.021113    0.018899    0.721465    
#> 032: 0.407137    1.008857    3.417693    0.380599    0.020057    0.017954    0.733466    
#> 033: 0.378683    1.027033    3.406442    0.364997    0.019054    0.020885    0.729002    
#> 034: 0.395206    1.014548    3.406609    0.346747    0.018102    0.019841    0.719803    
#> 035: 0.363884    0.996064    3.394714    0.329410    0.017197    0.019106    0.724822    
#> 036: 0.382089    1.003390    3.400879    0.322122    0.018493    0.018151    0.737907    
#> 037: 0.380102    1.008387    3.408126    0.358399    0.021092    0.019882    0.749976    
#> 038: 0.403810    1.019015    3.392486    0.391910    0.020743    0.023345    0.729294    
#> 039: 0.384261    1.020402    3.397580    0.415056    0.019706    0.023939    0.730401    
#> 040: 0.387476    1.022214    3.401542    0.394304    0.018720    0.022742    0.733363    
#> 041: 0.368859    1.015196    3.391278    0.374588    0.017784    0.021663    0.736087    
#> 042: 0.402213    1.020435    3.386528    0.412363    0.016895    0.024415    0.736019    
#> 043: 0.352551    1.025503    3.377980    0.391745    0.016050    0.023194    0.748078    
#> 044: 0.363201    1.022992    3.393840    0.381928    0.015248    0.022034    0.751912    
#> 045: 0.375129    1.022277    3.380506    0.375250    0.014486    0.024379    0.738731    
#> 046: 0.375939    1.023090    3.388992    0.405690    0.014578    0.023160    0.721134    
#> 047: 0.373559    1.013823    3.385392    0.385406    0.017282    0.024583    0.723757    
#> 048: 0.378884    1.005593    3.390172    0.441830    0.016418    0.028133    0.740332    
#> 049: 0.412259    1.000920    3.400924    0.429817    0.015597    0.026726    0.756114    
#> 050: 0.467477    0.983798    3.414501    0.466593    0.014817    0.026930    0.759679    
#> 051: 0.423246    0.990679    3.404979    0.491388    0.014889    0.034133    0.751859    
#> 052: 0.418305    0.994387    3.408351    0.551545    0.016329    0.032426    0.742253    
#> 053: 0.444451    0.986689    3.407235    0.558726    0.015918    0.030805    0.745440    
#> 054: 0.405545    1.002416    3.403946    0.530790    0.015122    0.029265    0.734696    
#> 055: 0.372829    1.017515    3.387821    0.504250    0.014366    0.027802    0.725430    
#> 056: 0.399780    1.006649    3.395262    0.479038    0.013647    0.026412    0.738124    
#> 057: 0.420390    0.998684    3.406278    0.569895    0.012965    0.027118    0.739415    
#> 058: 0.416538    0.998946    3.396412    0.541400    0.012317    0.031597    0.723844    
#> 059: 0.375882    0.988315    3.390868    0.514330    0.013142    0.032879    0.756969    
#> 060: 0.412394    0.987475    3.400669    0.488613    0.015418    0.031235    0.753302    
#> 061: 0.424932    0.980286    3.418092    0.464183    0.014647    0.030420    0.752563    
#> 062: 0.390165    0.998726    3.408139    0.440974    0.016624    0.028899    0.767674    
#> 063: 0.449187    0.989331    3.407988    0.427214    0.015793    0.028145    0.764750    
#> 064: 0.392257    0.988410    3.408474    0.405853    0.015003    0.026738    0.751758    
#> 065: 0.396609    0.985837    3.393376    0.399176    0.014253    0.026050    0.743968    
#> 066: 0.386577    0.984940    3.403748    0.405047    0.013540    0.026057    0.734284    
#> 067: 0.376938    0.990589    3.406735    0.384795    0.012863    0.027562    0.746943    
#> 068: 0.371117    0.993878    3.406250    0.381505    0.012372    0.026184    0.749521    
#> 069: 0.359608    0.996743    3.397535    0.376747    0.013887    0.024874    0.768044    
#> 070: 0.385990    0.992413    3.403127    0.360014    0.015631    0.023631    0.748554    
#> 071: 0.403165    1.005653    3.400855    0.414970    0.014849    0.022449    0.738172    
#> 072: 0.404717    0.997851    3.394554    0.459541    0.014107    0.021327    0.749356    
#> 073: 0.429970    1.013628    3.401461    0.601505    0.014095    0.020260    0.726305    
#> 074: 0.435828    0.999482    3.398955    0.571430    0.016014    0.019247    0.729835    
#> 075: 0.446049    0.999221    3.428526    0.542858    0.015865    0.021891    0.747509    
#> 076: 0.440933    1.005821    3.415934    0.515715    0.019774    0.020796    0.747289    
#> 077: 0.423291    1.000142    3.405595    0.548806    0.018785    0.020124    0.747084    
#> 078: 0.438736    0.999938    3.420173    0.521366    0.017846    0.022907    0.736667    
#> 079: 0.421400    1.010605    3.404610    0.509651    0.017416    0.024628    0.735728    
#> 080: 0.388137    1.008416    3.394713    0.484168    0.023430    0.023397    0.751034    
#> 081: 0.387494    1.016623    3.390229    0.466489    0.022258    0.022227    0.743354    
#> 082: 0.387078    1.003799    3.399787    0.443164    0.021145    0.021115    0.745565    
#> 083: 0.418491    1.008461    3.399026    0.425552    0.020088    0.020060    0.726993    
#> 084: 0.409686    1.015269    3.403657    0.404274    0.019697    0.019608    0.742608    
#> 085: 0.378901    1.007153    3.406315    0.384060    0.021572    0.022572    0.741418    
#> 086: 0.405939    1.003729    3.403380    0.413034    0.020493    0.024409    0.740407    
#> 087: 0.411454    0.999027    3.391555    0.444826    0.019469    0.023189    0.733640    
#> 088: 0.328063    1.001687    3.397565    0.460019    0.018495    0.022029    0.749304    
#> 089: 0.378048    1.013246    3.379241    0.489183    0.017571    0.020928    0.745973    
#> 090: 0.367665    1.015170    3.381674    0.464724    0.016692    0.019881    0.758331    
#> 091: 0.336083    1.006490    3.366632    0.441487    0.015857    0.018887    0.759766    
#> 092: 0.338902    1.010573    3.368383    0.419413    0.015065    0.017943    0.755070    
#> 093: 0.302979    1.013740    3.368286    0.398442    0.014311    0.018769    0.768164    
#> 094: 0.326234    1.027136    3.372059    0.378520    0.013596    0.019926    0.757074    
#> 095: 0.359237    1.021683    3.398469    0.359594    0.013160    0.018930    0.767760    
#> 096: 0.336119    1.024240    3.395611    0.341615    0.013776    0.018032    0.745612    
#> 097: 0.396966    1.021580    3.392858    0.324534    0.013087    0.018466    0.758214    
#> 098: 0.374937    1.000031    3.411463    0.308307    0.012433    0.018745    0.769161    
#> 099: 0.361326    0.990965    3.389674    0.346326    0.012776    0.021094    0.757321    
#> 100: 0.350049    0.994802    3.388654    0.338121    0.012137    0.020813    0.735738    
#> 101: 0.310847    0.998658    3.367733    0.321215    0.011635    0.020895    0.727005    
#> 102: 0.331413    0.993303    3.371364    0.328402    0.012457    0.020070    0.733970    
#> 103: 0.382115    1.004554    3.390242    0.389088    0.011834    0.020081    0.736730    
#> 104: 0.355090    1.003138    3.398185    0.422514    0.013064    0.020120    0.741152    
#> 105: 0.400112    0.992991    3.407378    0.401388    0.013558    0.020553    0.730998    
#> 106: 0.397946    1.000801    3.395019    0.440615    0.012880    0.023930    0.738200    
#> 107: 0.414816    1.005174    3.406413    0.443579    0.012236    0.027510    0.733107    
#> 108: 0.425639    1.004322    3.417985    0.430137    0.011624    0.026134    0.738192    
#> 109: 0.402281    1.003364    3.423461    0.408631    0.011043    0.024828    0.764531    
#> 110: 0.414529    1.015903    3.397925    0.388199    0.010491    0.024770    0.763711    
#> 111: 0.403294    1.017302    3.400455    0.427044    0.009966    0.026272    0.752725    
#> 112: 0.411965    0.994113    3.397989    0.423355    0.009468    0.025879    0.743991    
#> 113: 0.397771    1.006354    3.402828    0.402187    0.008995    0.024585    0.720760    
#> 114: 0.398759    1.006736    3.413537    0.382077    0.010259    0.023630    0.730450    
#> 115: 0.432196    0.989762    3.401059    0.397616    0.009746    0.024078    0.746046    
#> 116: 0.402558    1.006894    3.390250    0.386872    0.009664    0.026615    0.740990    
#> 117: 0.362249    1.030217    3.395291    0.405893    0.010388    0.026103    0.729173    
#> 118: 0.391552    1.029757    3.394143    0.462202    0.011108    0.029489    0.732522    
#> 119: 0.385296    1.016487    3.389326    0.454676    0.013859    0.028015    0.761986    
#> 120: 0.350451    1.008419    3.387750    0.431942    0.014743    0.026614    0.745158    
#> 121: 0.422696    1.013475    3.409814    0.410345    0.020788    0.025283    0.738757    
#> 122: 0.421483    1.008578    3.408171    0.405281    0.028117    0.024019    0.733722    
#> 123: 0.447787    1.024280    3.402420    0.438444    0.026712    0.022818    0.729598    
#> 124: 0.394573    1.051386    3.389490    0.440467    0.025376    0.023774    0.743287    
#> 125: 0.411268    1.039092    3.389346    0.433009    0.024107    0.027079    0.734252    
#> 126: 0.349525    1.058075    3.377881    0.411358    0.022902    0.033274    0.770550    
#> 127: 0.363916    1.037197    3.381978    0.390790    0.021757    0.031753    0.756867    
#> 128: 0.355625    1.004390    3.393416    0.371251    0.020669    0.030166    0.759677    
#> 129: 0.414179    1.014835    3.414071    0.367611    0.024256    0.028657    0.747062    
#> 130: 0.406525    1.024563    3.409735    0.349231    0.023608    0.027224    0.730595    
#> 131: 0.372322    1.027815    3.383634    0.338890    0.022575    0.025863    0.728496    
#> 132: 0.366269    1.002008    3.380905    0.321946    0.022518    0.024570    0.751132    
#> 133: 0.363171    0.999722    3.391763    0.327481    0.021392    0.023342    0.767106    
#> 134: 0.396961    0.975264    3.409404    0.408428    0.021839    0.022174    0.751341    
#> 135: 0.373414    0.975410    3.412014    0.388006    0.023221    0.021066    0.738842    
#> 136: 0.388007    0.974533    3.420116    0.368606    0.026465    0.020012    0.741645    
#> 137: 0.422949    0.969462    3.421778    0.350176    0.025142    0.019012    0.769010    
#> 138: 0.405658    0.990713    3.421026    0.332667    0.023885    0.021655    0.762572    
#> 139: 0.417495    0.986284    3.431177    0.353528    0.022691    0.024980    0.760013    
#> 140: 0.450047    0.992405    3.434140    0.349026    0.025213    0.023731    0.781357    
#> 141: 0.406623    0.976999    3.423883    0.331575    0.031372    0.022544    0.761597    
#> 142: 0.446168    0.967270    3.444281    0.355053    0.029803    0.021417    0.749696    
#> 143: 0.400115    0.989947    3.418858    0.354737    0.028313    0.028575    0.768785    
#> 144: 0.454209    1.003690    3.417902    0.460502    0.026897    0.027146    0.726061    
#> 145: 0.380372    1.003339    3.399040    0.437476    0.025552    0.025789    0.723783    
#> 146: 0.391119    1.013385    3.409999    0.415603    0.024275    0.025429    0.762078    
#> 147: 0.384786    1.007960    3.405083    0.408461    0.023061    0.024158    0.730575    
#> 148: 0.368251    1.006721    3.403461    0.421657    0.021908    0.022950    0.725637    
#> 149: 0.404842    1.000885    3.408725    0.449188    0.020813    0.021802    0.743318    
#> 150: 0.456963    0.989994    3.403809    0.521538    0.019826    0.020712    0.763599    
#> 151: 0.400784    1.003308    3.408020    0.495461    0.018834    0.019978    0.741095    
#> 152: 0.392423    1.012967    3.403129    0.429293    0.017667    0.019936    0.744423    
#> 153: 0.394521    1.028566    3.409667    0.468096    0.016333    0.023707    0.751559    
#> 154: 0.401499    1.022328    3.407851    0.377753    0.017184    0.023759    0.759062    
#> 155: 0.389949    1.008739    3.406322    0.303510    0.017794    0.023543    0.749672    
#> 156: 0.363610    1.018281    3.397492    0.333429    0.018719    0.028440    0.754955    
#> 157: 0.365540    1.011807    3.402587    0.330705    0.022064    0.025083    0.778716    
#> 158: 0.426147    1.024223    3.399068    0.376733    0.017177    0.024833    0.739474    
#> 159: 0.382582    1.041856    3.406055    0.332008    0.016055    0.021525    0.748626    
#> 160: 0.396946    1.011769    3.411803    0.408145    0.021562    0.017626    0.740574    
#> 161: 0.363177    1.008213    3.397112    0.314160    0.026887    0.016790    0.739830    
#> 162: 0.371149    1.020925    3.386429    0.346461    0.026084    0.016061    0.733577    
#> 163: 0.380493    1.011156    3.382661    0.361899    0.027608    0.013713    0.742626    
#> 164: 0.396879    1.027597    3.393903    0.371418    0.025735    0.015950    0.737972    
#> 165: 0.396733    1.019426    3.410961    0.308984    0.019504    0.020779    0.736261    
#> 166: 0.404769    1.040143    3.406444    0.300558    0.020157    0.020730    0.760580    
#> 167: 0.415538    1.051805    3.411576    0.346481    0.016546    0.019319    0.775343    
#> 168: 0.391566    1.046120    3.401568    0.373223    0.017607    0.018677    0.742952    
#> 169: 0.397021    1.048884    3.400408    0.354976    0.016042    0.019753    0.761143    
#> 170: 0.374942    1.038779    3.404617    0.362950    0.016398    0.018778    0.754870    
#> 171: 0.361444    1.029299    3.395390    0.445268    0.012014    0.020933    0.740445    
#> 172: 0.389219    1.028392    3.391710    0.448315    0.010127    0.020805    0.731609    
#> 173: 0.373126    1.038272    3.383063    0.412891    0.012654    0.024662    0.722480    
#> 174: 0.436513    1.029314    3.406935    0.478134    0.008985    0.033183    0.739050    
#> 175: 0.372440    1.027315    3.376748    0.507315    0.010144    0.032798    0.754530    
#> 176: 0.360411    1.034362    3.385421    0.452637    0.006304    0.030115    0.728143    
#> 177: 0.385913    1.039567    3.394919    0.402403    0.005286    0.034073    0.734076    
#> 178: 0.404456    1.030633    3.397384    0.390878    0.005608    0.030595    0.746226    
#> 179: 0.426371    1.033839    3.399677    0.394446    0.007526    0.028061    0.746111    
#> 180: 0.361765    1.027007    3.396408    0.434593    0.007296    0.021351    0.731172    
#> 181: 0.364358    1.004817    3.380977    0.420595    0.008113    0.028260    0.713116    
#> 182: 0.351306    1.011734    3.379194    0.402779    0.009452    0.034059    0.744669    
#> 183: 0.366629    1.015943    3.386614    0.380206    0.008049    0.034069    0.757182    
#> 184: 0.371150    1.001950    3.392372    0.397487    0.008059    0.033209    0.752348    
#> 185: 0.354527    1.008519    3.382112    0.417439    0.006324    0.033149    0.740709    
#> 186: 0.345757    1.017140    3.383860    0.400150    0.006291    0.036037    0.765854    
#> 187: 0.355934    1.014838    3.395416    0.365633    0.007306    0.033237    0.765472    
#> 188: 0.337101    1.031359    3.379346    0.355826    0.009183    0.026343    0.760496    
#> 189: 0.370637    1.031605    3.399463    0.319109    0.008449    0.026901    0.796093    
#> 190: 0.354902    1.021379    3.406513    0.335830    0.008737    0.030900    0.779174    
#> 191: 0.365955    1.028441    3.390230    0.382201    0.008874    0.025623    0.767975    
#> 192: 0.326514    1.032495    3.401082    0.336508    0.006284    0.025485    0.784353    
#> 193: 0.386441    1.041335    3.409446    0.355214    0.005077    0.025757    0.765905    
#> 194: 0.340684    1.028373    3.392226    0.312668    0.005568    0.025600    0.762972    
#> 195: 0.312403    1.028514    3.371497    0.327964    0.005319    0.029130    0.760197    
#> 196: 0.298012    1.022615    3.379712    0.321194    0.005399    0.032079    0.770251    
#> 197: 0.320092    1.026188    3.401582    0.385604    0.004960    0.032757    0.778330    
#> 198: 0.393113    1.022017    3.399581    0.399323    0.003391    0.030620    0.764614    
#> 199: 0.341045    1.020562    3.384340    0.386009    0.003142    0.033583    0.737962    
#> 200: 0.366383    1.014755    3.400598    0.381183    0.003221    0.038441    0.739416    
#> 201: 0.365090    1.012449    3.400839    0.395549    0.003665    0.038919    0.736497    
#> 202: 0.363850    1.012732    3.397811    0.400811    0.003835    0.039214    0.741633    
#> 203: 0.380506    1.011006    3.395756    0.408863    0.003665    0.039982    0.743029    
#> 204: 0.379358    1.007655    3.397102    0.404937    0.003451    0.039754    0.741909    
#> 205: 0.384309    1.008025    3.397396    0.407949    0.003324    0.039032    0.744252    
#> 206: 0.383328    1.009309    3.397675    0.412525    0.003257    0.038257    0.745011    
#> 207: 0.380343    1.008704    3.395960    0.414871    0.003122    0.037776    0.743598    
#> 208: 0.383493    1.008305    3.394674    0.419828    0.003025    0.037537    0.741999    
#> 209: 0.388192    1.007605    3.395976    0.427782    0.002931    0.037438    0.740567    
#> 210: 0.391435    1.007022    3.397243    0.429749    0.002849    0.037244    0.740158    
#> 211: 0.395782    1.007566    3.398359    0.430823    0.002877    0.036991    0.739991    
#> 212: 0.397771    1.008132    3.398977    0.431789    0.002832    0.036797    0.741338    
#> 213: 0.400693    1.006883    3.400033    0.431590    0.002862    0.036146    0.742845    
#> 214: 0.402560    1.006230    3.401092    0.430487    0.002867    0.035741    0.743542    
#> 215: 0.402117    1.005961    3.401499    0.429257    0.002836    0.035424    0.745377    
#> 216: 0.403834    1.005106    3.402200    0.426681    0.002839    0.035270    0.745963    
#> 217: 0.403208    1.004584    3.402155    0.424852    0.002813    0.034929    0.745811    
#> 218: 0.402260    1.004040    3.401893    0.423949    0.002815    0.034835    0.746011    
#> 219: 0.402170    1.003644    3.401687    0.426274    0.002849    0.034871    0.746599    
#> 220: 0.401717    1.003332    3.401838    0.430132    0.002836    0.034448    0.747587    
#> 221: 0.401468    1.003046    3.401996    0.429103    0.002830    0.034090    0.747615    
#> 222: 0.400578    1.003005    3.401654    0.426985    0.002800    0.033915    0.747660    
#> 223: 0.401526    1.003165    3.401867    0.427621    0.002793    0.033759    0.747218    
#> 224: 0.402672    1.003097    3.401894    0.428437    0.002772    0.033820    0.746288    
#> 225: 0.402726    1.002661    3.402479    0.430038    0.002761    0.033907    0.746053    
#> 226: 0.402226    1.002055    3.402497    0.428646    0.002750    0.033877    0.745634    
#> 227: 0.400913    1.001781    3.402404    0.427844    0.002741    0.034131    0.745735    
#> 228: 0.399187    1.001764    3.401349    0.426433    0.002736    0.034191    0.746137    
#> 229: 0.397746    1.001412    3.400602    0.428007    0.002714    0.034186    0.745721    
#> 230: 0.397820    1.001164    3.400431    0.431350    0.002710    0.034079    0.745319    
#> 231: 0.397764    1.001112    3.400594    0.434523    0.002699    0.034085    0.745200    
#> 232: 0.396704    1.001003    3.400482    0.434715    0.002707    0.034108    0.745104    
#> 233: 0.396464    1.000613    3.400506    0.436067    0.002706    0.034104    0.744957    
#> 234: 0.394885    1.000401    3.400133    0.435474    0.002732    0.034266    0.744632    
#> 235: 0.394070    1.000044    3.400020    0.437021    0.002750    0.034297    0.744818    
#> 236: 0.394048    0.999961    3.399361    0.440404    0.002761    0.034322    0.745263    
#> 237: 0.394911    0.999737    3.399126    0.442505    0.002752    0.034328    0.746153    
#> 238: 0.395308    0.999632    3.399072    0.442333    0.002758    0.034137    0.747245    
#> 239: 0.394664    0.999758    3.398877    0.442149    0.002764    0.034032    0.747260    
#> 240: 0.395800    0.999866    3.399241    0.440987    0.002771    0.034007    0.747253    
#> 241: 0.396222    0.999721    3.399277    0.440685    0.002778    0.033967    0.747097    
#> 242: 0.395811    0.999661    3.399050    0.442334    0.002798    0.033948    0.746933    
#> 243: 0.394924    0.999764    3.399001    0.441589    0.002830    0.033988    0.747223    
#> 244: 0.394155    0.999579    3.399248    0.441062    0.002836    0.033882    0.747573    
#> 245: 0.394110    0.999285    3.399450    0.441742    0.002867    0.033798    0.747814    
#> 246: 0.393592    0.999123    3.399558    0.440411    0.002880    0.033743    0.748384    
#> 247: 0.393822    0.998997    3.399703    0.440230    0.002898    0.033645    0.748418    
#> 248: 0.393528    0.999069    3.399570    0.440972    0.002908    0.033610    0.748234    
#> 249: 0.393135    0.999005    3.399791    0.439733    0.002923    0.033618    0.748523    
#> 250: 0.393127    0.998967    3.399765    0.439171    0.002939    0.033629    0.748594    
#> 251: 0.393236    0.999056    3.400059    0.438058    0.002957    0.033578    0.748614    
#> 252: 0.393594    0.999120    3.400427    0.436056    0.002961    0.033630    0.748785    
#> 253: 0.392998    0.999146    3.400489    0.435571    0.002948    0.033679    0.749067    
#> 254: 0.393044    0.999264    3.400532    0.434478    0.002926    0.033653    0.749554    
#> 255: 0.392685    0.999338    3.400606    0.434301    0.002901    0.033657    0.750221    
#> 256: 0.393117    0.999166    3.400735    0.434024    0.002888    0.033677    0.750553    
#> 257: 0.393017    0.998921    3.400743    0.432808    0.002876    0.033684    0.750879    
#> 258: 0.393803    0.998695    3.400922    0.433084    0.002859    0.033682    0.751055    
#> 259: 0.393763    0.998570    3.400970    0.433087    0.002854    0.033711    0.751120    
#> 260: 0.393935    0.998609    3.401166    0.432857    0.002846    0.033715    0.751083    
#> 261: 0.394350    0.998577    3.401513    0.433023    0.002841    0.033716    0.751293    
#> 262: 0.394909    0.998454    3.401493    0.435119    0.002839    0.033681    0.751023    
#> 263: 0.395414    0.998423    3.401621    0.436538    0.002820    0.033678    0.750793    
#> 264: 0.394990    0.998428    3.401597    0.436019    0.002812    0.033657    0.750779    
#> 265: 0.394403    0.998342    3.401551    0.434576    0.002802    0.033767    0.750952    
#> 266: 0.394807    0.998332    3.401750    0.434340    0.002800    0.033788    0.750910    
#> 267: 0.394944    0.998204    3.402050    0.433822    0.002792    0.033786    0.750940    
#> 268: 0.395335    0.998068    3.402111    0.433421    0.002795    0.033772    0.750878    
#> 269: 0.396097    0.997888    3.402314    0.434065    0.002799    0.033794    0.750672    
#> 270: 0.396026    0.997676    3.402317    0.433616    0.002801    0.033762    0.750638    
#> 271: 0.396259    0.997479    3.402353    0.434233    0.002789    0.033829    0.750707    
#> 272: 0.396338    0.997334    3.402464    0.433787    0.002782    0.033818    0.751027    
#> 273: 0.396240    0.997322    3.402499    0.433363    0.002777    0.033797    0.750947    
#> 274: 0.396032    0.997398    3.402426    0.433842    0.002777    0.033742    0.750705    
#> 275: 0.395653    0.997481    3.402216    0.433500    0.002765    0.033714    0.750660    
#> 276: 0.395925    0.997465    3.402431    0.433941    0.002767    0.033697    0.750702    
#> 277: 0.396275    0.997425    3.402522    0.433401    0.002767    0.033658    0.750737    
#> 278: 0.396252    0.997488    3.402593    0.433693    0.002771    0.033601    0.750694    
#> 279: 0.395982    0.997489    3.402646    0.433756    0.002771    0.033569    0.750801    
#> 280: 0.396068    0.997499    3.402789    0.433212    0.002766    0.033501    0.750753    
#> 281: 0.396055    0.997442    3.402875    0.433561    0.002757    0.033526    0.750679    
#> 282: 0.396040    0.997575    3.402843    0.433989    0.002754    0.033522    0.750726    
#> 283: 0.395929    0.997614    3.402808    0.433356    0.002762    0.033500    0.751090    
#> 284: 0.395899    0.997659    3.402777    0.431874    0.002761    0.033453    0.751186    
#> 285: 0.395542    0.997690    3.402631    0.430898    0.002765    0.033406    0.751399    
#> 286: 0.395361    0.997751    3.402556    0.430634    0.002776    0.033367    0.751389    
#> 287: 0.395090    0.997784    3.402333    0.430810    0.002786    0.033287    0.751531    
#> 288: 0.394973    0.997710    3.402310    0.430720    0.002796    0.033286    0.751548    
#> 289: 0.395494    0.997704    3.402218    0.432284    0.002797    0.033327    0.751490    
#> 290: 0.395846    0.997684    3.402116    0.433227    0.002793    0.033346    0.751420    
#> 291: 0.395986    0.997701    3.402223    0.433486    0.002790    0.033368    0.751179    
#> 292: 0.395952    0.997683    3.402223    0.432771    0.002783    0.033312    0.751062    
#> 293: 0.395856    0.997624    3.402186    0.432539    0.002778    0.033255    0.751106    
#> 294: 0.395502    0.997549    3.402176    0.432163    0.002778    0.033222    0.751218    
#> 295: 0.395570    0.997455    3.402210    0.431851    0.002775    0.033213    0.751063    
#> 296: 0.395674    0.997349    3.402166    0.431902    0.002772    0.033212    0.751075    
#> 297: 0.395923    0.997369    3.402167    0.432341    0.002770    0.033195    0.751144    
#> 298: 0.395953    0.997285    3.402144    0.431725    0.002763    0.033149    0.751075    
#> 299: 0.395470    0.997326    3.402023    0.431156    0.002757    0.033082    0.751047    
#> 300: 0.395527    0.997388    3.401972    0.430930    0.002753    0.033059    0.751099    
#> 301: 0.395465    0.997403    3.401816    0.431473    0.002745    0.032998    0.751216    
#> 302: 0.395244    0.997414    3.401522    0.431960    0.002739    0.033013    0.751125    
#> 303: 0.394894    0.997477    3.401306    0.432117    0.002733    0.033021    0.750890    
#> 304: 0.394757    0.997631    3.401155    0.432398    0.002730    0.033043    0.750960    
#> 305: 0.394447    0.997626    3.401062    0.432235    0.002724    0.033036    0.750876    
#> 306: 0.393850    0.997603    3.400943    0.432163    0.002721    0.033011    0.750767    
#> 307: 0.393566    0.997548    3.400727    0.432567    0.002720    0.032980    0.750821    
#> 308: 0.392926    0.997519    3.400588    0.432475    0.002722    0.032922    0.750992    
#> 309: 0.393067    0.997456    3.400514    0.432961    0.002719    0.032943    0.751143    
#> 310: 0.392935    0.997428    3.400502    0.433133    0.002721    0.033004    0.751313    
#> 311: 0.392516    0.997414    3.400380    0.433769    0.002722    0.033007    0.751382    
#> 312: 0.392113    0.997337    3.400266    0.433787    0.002723    0.033060    0.751386    
#> 313: 0.391986    0.997312    3.400128    0.434481    0.002725    0.033044    0.751438    
#> 314: 0.391829    0.997331    3.400022    0.434707    0.002725    0.033025    0.751482    
#> 315: 0.391711    0.997406    3.399919    0.434868    0.002728    0.032957    0.751474    
#> 316: 0.391359    0.997419    3.399857    0.434555    0.002730    0.032894    0.751482    
#> 317: 0.391360    0.997397    3.399925    0.434278    0.002739    0.032873    0.751446    
#> 318: 0.391330    0.997348    3.399911    0.434338    0.002739    0.032863    0.751427    
#> 319: 0.391361    0.997260    3.400022    0.434290    0.002737    0.032938    0.751438    
#> 320: 0.390952    0.997174    3.400028    0.434337    0.002747    0.032949    0.751568    
#> 321: 0.390794    0.997196    3.399957    0.434609    0.002753    0.032954    0.751574    
#> 322: 0.390611    0.997207    3.399934    0.434486    0.002756    0.032931    0.751624    
#> 323: 0.390167    0.997244    3.399925    0.433888    0.002756    0.032936    0.751634    
#> 324: 0.389901    0.997323    3.399911    0.433468    0.002750    0.032896    0.751589    
#> 325: 0.389878    0.997457    3.399886    0.433158    0.002752    0.032900    0.751432    
#> 326: 0.390019    0.997436    3.399895    0.432887    0.002751    0.032893    0.751406    
#> 327: 0.390156    0.997458    3.399911    0.432505    0.002747    0.032936    0.751371    
#> 328: 0.390153    0.997531    3.399979    0.432287    0.002744    0.032927    0.751373    
#> 329: 0.390201    0.997564    3.400027    0.432146    0.002744    0.032922    0.751096    
#> 330: 0.390215    0.997557    3.400062    0.431997    0.002743    0.032908    0.750869    
#> 331: 0.390452    0.997616    3.400115    0.431427    0.002749    0.032911    0.750830    
#> 332: 0.390832    0.997611    3.400277    0.430986    0.002753    0.032906    0.750887    
#> 333: 0.391239    0.997569    3.400345    0.430917    0.002756    0.032877    0.750979    
#> 334: 0.391053    0.997575    3.400269    0.430810    0.002752    0.032880    0.751104    
#> 335: 0.391052    0.997600    3.400203    0.430355    0.002748    0.032900    0.751208    
#> 336: 0.390985    0.997655    3.400183    0.430404    0.002745    0.032916    0.751304    
#> 337: 0.390949    0.997691    3.400182    0.429573    0.002741    0.032876    0.751477    
#> 338: 0.391033    0.997704    3.400203    0.429236    0.002736    0.032853    0.751443    
#> 339: 0.390855    0.997715    3.400165    0.428809    0.002734    0.032829    0.751478    
#> 340: 0.390841    0.997685    3.400214    0.428724    0.002740    0.032800    0.751465    
#> 341: 0.390975    0.997685    3.400287    0.428803    0.002754    0.032752    0.751320    
#> 342: 0.391069    0.997643    3.400351    0.428971    0.002766    0.032726    0.751202    
#> 343: 0.391116    0.997601    3.400365    0.429321    0.002773    0.032668    0.751064    
#> 344: 0.391382    0.997544    3.400426    0.429661    0.002782    0.032660    0.750973    
#> 345: 0.391592    0.997537    3.400531    0.429701    0.002793    0.032659    0.750841    
#> 346: 0.391638    0.997575    3.400470    0.429281    0.002802    0.032611    0.750780    
#> 347: 0.391905    0.997547    3.400439    0.429525    0.002812    0.032604    0.750748    
#> 348: 0.391825    0.997573    3.400391    0.429390    0.002825    0.032590    0.750681    
#> 349: 0.391722    0.997584    3.400364    0.429383    0.002832    0.032586    0.750530    
#> 350: 0.391655    0.997548    3.400373    0.429456    0.002833    0.032583    0.750391    
#> 351: 0.391748    0.997630    3.400346    0.429620    0.002834    0.032566    0.750386    
#> 352: 0.391566    0.997646    3.400430    0.429017    0.002831    0.032507    0.750577    
#> 353: 0.391779    0.997689    3.400499    0.428643    0.002831    0.032510    0.750525    
#> 354: 0.391978    0.997760    3.400479    0.428428    0.002833    0.032511    0.750431    
#> 355: 0.392543    0.997756    3.400539    0.428884    0.002840    0.032477    0.750383    
#> 356: 0.392692    0.997744    3.400565    0.429545    0.002850    0.032458    0.750465    
#> 357: 0.392874    0.997754    3.400648    0.429765    0.002852    0.032458    0.750424    
#> 358: 0.392871    0.997754    3.400686    0.429636    0.002862    0.032464    0.750376    
#> 359: 0.392501    0.997806    3.400553    0.429214    0.002872    0.032439    0.750438    
#> 360: 0.392391    0.997836    3.400454    0.428959    0.002880    0.032427    0.750370    
#> 361: 0.392173    0.997935    3.400355    0.428568    0.002882    0.032428    0.750392    
#> 362: 0.391927    0.998004    3.400262    0.428257    0.002886    0.032420    0.750342    
#> 363: 0.391943    0.998019    3.400245    0.428062    0.002883    0.032390    0.750213    
#> 364: 0.392088    0.998025    3.400278    0.428079    0.002879    0.032359    0.750161    
#> 365: 0.392166    0.998006    3.400351    0.427977    0.002879    0.032351    0.750297    
#> 366: 0.392371    0.997958    3.400321    0.427844    0.002877    0.032335    0.750466    
#> 367: 0.392554    0.997921    3.400376    0.427737    0.002872    0.032291    0.750507    
#> 368: 0.392615    0.997895    3.400358    0.428056    0.002868    0.032320    0.750490    
#> 369: 0.392704    0.997856    3.400375    0.427854    0.002865    0.032340    0.750540    
#> 370: 0.392773    0.997861    3.400374    0.427917    0.002863    0.032374    0.750482    
#> 371: 0.392657    0.997869    3.400292    0.427471    0.002861    0.032345    0.750458    
#> 372: 0.392540    0.997912    3.400251    0.427210    0.002858    0.032402    0.750467    
#> 373: 0.392216    0.997970    3.400177    0.427224    0.002853    0.032440    0.750585    
#> 374: 0.392119    0.997979    3.400101    0.427657    0.002848    0.032480    0.750626    
#> 375: 0.391683    0.997967    3.399986    0.427516    0.002839    0.032480    0.750758    
#> 376: 0.391500    0.997981    3.399980    0.427514    0.002833    0.032494    0.750748    
#> 377: 0.391255    0.998030    3.399876    0.427595    0.002830    0.032515    0.750776    
#> 378: 0.390969    0.998040    3.399755    0.427064    0.002828    0.032497    0.750851    
#> 379: 0.390883    0.998025    3.399767    0.426968    0.002830    0.032485    0.750855    
#> 380: 0.390733    0.998030    3.399711    0.426922    0.002837    0.032465    0.750852    
#> 381: 0.390417    0.998026    3.399619    0.427150    0.002838    0.032453    0.750845    
#> 382: 0.390352    0.998019    3.399637    0.427416    0.002840    0.032467    0.750778    
#> 383: 0.390542    0.997979    3.399667    0.427540    0.002842    0.032464    0.750668    
#> 384: 0.390385    0.997947    3.399668    0.427294    0.002839    0.032485    0.750665    
#> 385: 0.390452    0.997942    3.399716    0.427070    0.002835    0.032507    0.750706    
#> 386: 0.390550    0.997977    3.399760    0.426904    0.002834    0.032545    0.750695    
#> 387: 0.390716    0.997989    3.399857    0.426992    0.002832    0.032556    0.750660    
#> 388: 0.390897    0.997982    3.399891    0.427175    0.002830    0.032581    0.750684    
#> 389: 0.390999    0.997945    3.399871    0.427415    0.002830    0.032616    0.750829    
#> 390: 0.391012    0.997916    3.399895    0.427394    0.002829    0.032617    0.750890    
#> 391: 0.391103    0.997892    3.399873    0.427352    0.002830    0.032637    0.750938    
#> 392: 0.391233    0.997857    3.399964    0.427616    0.002830    0.032667    0.751016    
#> 393: 0.391112    0.997824    3.399965    0.427506    0.002833    0.032690    0.751064    
#> 394: 0.391105    0.997814    3.399914    0.427673    0.002828    0.032703    0.751104    
#> 395: 0.391392    0.997852    3.399917    0.428126    0.002827    0.032731    0.751060    
#> 396: 0.391658    0.997863    3.399974    0.428172    0.002829    0.032728    0.751034    
#> 397: 0.391936    0.997816    3.400011    0.428370    0.002833    0.032747    0.751071    
#> 398: 0.392129    0.997776    3.400040    0.428557    0.002833    0.032746    0.750988    
#> 399: 0.392162    0.997751    3.400083    0.428573    0.002835    0.032749    0.750936    
#> 400: 0.392122    0.997762    3.400124    0.428678    0.002837    0.032754    0.750940    
#> 401: 0.392060    0.997768    3.400138    0.428442    0.002839    0.032765    0.750966    
#> 402: 0.392179    0.997790    3.400171    0.428536    0.002845    0.032767    0.750914    
#> 403: 0.392405    0.997826    3.400180    0.428752    0.002854    0.032784    0.750939    
#> 404: 0.392584    0.997918    3.400164    0.429244    0.002860    0.032790    0.750868    
#> 405: 0.392598    0.997950    3.400157    0.429282    0.002860    0.032802    0.750910    
#> 406: 0.392667    0.997984    3.400120    0.429489    0.002860    0.032838    0.750968    
#> 407: 0.392804    0.998011    3.400169    0.429344    0.002864    0.032851    0.750954    
#> 408: 0.393001    0.998062    3.400174    0.429727    0.002866    0.032840    0.750926    
#> 409: 0.393011    0.998089    3.400199    0.429715    0.002868    0.032820    0.750877    
#> 410: 0.392925    0.998149    3.400094    0.429752    0.002871    0.032787    0.750895    
#> 411: 0.392913    0.998103    3.400056    0.430008    0.002873    0.032774    0.750912    
#> 412: 0.392895    0.998079    3.399981    0.430429    0.002874    0.032768    0.750842    
#> 413: 0.393146    0.998109    3.399992    0.430897    0.002877    0.032759    0.750784    
#> 414: 0.393060    0.998141    3.400031    0.431036    0.002876    0.032758    0.750747    
#> 415: 0.393067    0.998136    3.400074    0.430853    0.002870    0.032753    0.750748    
#> 416: 0.393152    0.998138    3.400120    0.430581    0.002866    0.032763    0.750718    
#> 417: 0.393236    0.998102    3.400139    0.430769    0.002862    0.032777    0.750665    
#> 418: 0.393210    0.998040    3.400166    0.430773    0.002860    0.032793    0.750601    
#> 419: 0.393246    0.998017    3.400187    0.430462    0.002859    0.032780    0.750630    
#> 420: 0.393325    0.998004    3.400209    0.430185    0.002856    0.032739    0.750557    
#> 421: 0.393287    0.997979    3.400281    0.430232    0.002853    0.032721    0.750511    
#> 422: 0.393551    0.997962    3.400317    0.430548    0.002853    0.032686    0.750539    
#> 423: 0.393948    0.997940    3.400405    0.430743    0.002856    0.032661    0.750501    
#> 424: 0.393965    0.997925    3.400377    0.430719    0.002861    0.032645    0.750471    
#> 425: 0.394136    0.997941    3.400427    0.430877    0.002868    0.032629    0.750496    
#> 426: 0.394164    0.997952    3.400414    0.430763    0.002870    0.032613    0.750491    
#> 427: 0.394106    0.997926    3.400482    0.430799    0.002869    0.032585    0.750526    
#> 428: 0.394204    0.997926    3.400527    0.430877    0.002870    0.032576    0.750569    
#> 429: 0.394246    0.997905    3.400568    0.430868    0.002872    0.032541    0.750595    
#> 430: 0.394228    0.997880    3.400601    0.430835    0.002872    0.032507    0.750630    
#> 431: 0.394244    0.997898    3.400565    0.430992    0.002868    0.032482    0.750646    
#> 432: 0.394328    0.997945    3.400598    0.431118    0.002865    0.032502    0.750665    
#> 433: 0.394455    0.997975    3.400664    0.431004    0.002862    0.032523    0.750825    
#> 434: 0.394433    0.998003    3.400679    0.430547    0.002860    0.032530    0.750834    
#> 435: 0.394484    0.998031    3.400647    0.430272    0.002855    0.032536    0.750742    
#> 436: 0.394555    0.998030    3.400679    0.430284    0.002854    0.032557    0.750673    
#> 437: 0.394609    0.998042    3.400736    0.429955    0.002855    0.032529    0.750720    
#> 438: 0.394682    0.998113    3.400747    0.429436    0.002853    0.032516    0.750768    
#> 439: 0.394843    0.998143    3.400761    0.429407    0.002852    0.032504    0.750727    
#> 440: 0.394781    0.998182    3.400754    0.429436    0.002852    0.032497    0.750765    
#> 441: 0.394674    0.998176    3.400745    0.429154    0.002850    0.032474    0.750710    
#> 442: 0.394510    0.998160    3.400748    0.428744    0.002854    0.032436    0.750716    
#> 443: 0.394412    0.998144    3.400697    0.428301    0.002855    0.032411    0.750789    
#> 444: 0.394238    0.998130    3.400641    0.427921    0.002858    0.032394    0.750806    
#> 445: 0.394158    0.998127    3.400614    0.427573    0.002862    0.032382    0.750838    
#> 446: 0.393997    0.998116    3.400599    0.427296    0.002870    0.032374    0.750843    
#> 447: 0.393926    0.998091    3.400628    0.427226    0.002873    0.032388    0.750797    
#> 448: 0.393959    0.998076    3.400669    0.427290    0.002877    0.032405    0.750750    
#> 449: 0.393881    0.998094    3.400759    0.426988    0.002880    0.032414    0.750819    
#> 450: 0.393817    0.998105    3.400756    0.426772    0.002881    0.032430    0.750813    
#> 451: 0.393821    0.998127    3.400742    0.426494    0.002882    0.032440    0.750841    
#> 452: 0.393834    0.998140    3.400717    0.426420    0.002883    0.032436    0.750788    
#> 453: 0.393924    0.998142    3.400709    0.426576    0.002883    0.032419    0.750767    
#> 454: 0.393734    0.998178    3.400635    0.426441    0.002883    0.032409    0.750715    
#> 455: 0.393707    0.998201    3.400609    0.426591    0.002878    0.032405    0.750663    
#> 456: 0.393537    0.998174    3.400571    0.426457    0.002874    0.032394    0.750722    
#> 457: 0.393390    0.998145    3.400574    0.426106    0.002870    0.032375    0.750773    
#> 458: 0.393299    0.998166    3.400566    0.426005    0.002868    0.032352    0.750872    
#> 459: 0.393049    0.998190    3.400544    0.425978    0.002863    0.032336    0.750962    
#> 460: 0.392925    0.998196    3.400513    0.425913    0.002864    0.032320    0.750951    
#> 461: 0.392833    0.998228    3.400481    0.425630    0.002863    0.032315    0.750984    
#> 462: 0.392677    0.998287    3.400466    0.425450    0.002864    0.032305    0.751029    
#> 463: 0.392613    0.998311    3.400451    0.425204    0.002865    0.032303    0.751093    
#> 464: 0.392640    0.998334    3.400411    0.425101    0.002863    0.032292    0.751100    
#> 465: 0.392638    0.998326    3.400386    0.425154    0.002861    0.032290    0.751054    
#> 466: 0.392680    0.998342    3.400342    0.425404    0.002858    0.032301    0.751046    
#> 467: 0.392633    0.998365    3.400371    0.425522    0.002857    0.032288    0.750989    
#> 468: 0.392658    0.998377    3.400387    0.425345    0.002854    0.032297    0.751009    
#> 469: 0.392687    0.998430    3.400388    0.425296    0.002853    0.032304    0.751061    
#> 470: 0.392571    0.998483    3.400330    0.425258    0.002851    0.032330    0.751120    
#> 471: 0.392489    0.998511    3.400299    0.425452    0.002847    0.032358    0.751150    
#> 472: 0.392388    0.998514    3.400281    0.425490    0.002842    0.032358    0.751207    
#> 473: 0.392293    0.998532    3.400254    0.425383    0.002837    0.032358    0.751213    
#> 474: 0.392379    0.998538    3.400242    0.425576    0.002833    0.032362    0.751222    
#> 475: 0.392517    0.998571    3.400277    0.425847    0.002828    0.032356    0.751231    
#> 476: 0.392458    0.998579    3.400263    0.425789    0.002824    0.032354    0.751273    
#> 477: 0.392298    0.998584    3.400268    0.425395    0.002820    0.032338    0.751288    
#> 478: 0.392228    0.998572    3.400262    0.425508    0.002817    0.032330    0.751283    
#> 479: 0.392360    0.998566    3.400310    0.425674    0.002816    0.032328    0.751305    
#> 480: 0.392568    0.998579    3.400336    0.425898    0.002818    0.032319    0.751282    
#> 481: 0.392563    0.998583    3.400334    0.426047    0.002820    0.032310    0.751262    
#> 482: 0.392530    0.998592    3.400253    0.426136    0.002822    0.032280    0.751331    
#> 483: 0.392464    0.998600    3.400279    0.426034    0.002827    0.032262    0.751345    
#> 484: 0.392383    0.998571    3.400313    0.425687    0.002829    0.032242    0.751402    
#> 485: 0.392338    0.998589    3.400310    0.425497    0.002829    0.032223    0.751378    
#> 486: 0.392315    0.998619    3.400337    0.425548    0.002828    0.032209    0.751328    
#> 487: 0.392531    0.998657    3.400407    0.425779    0.002829    0.032203    0.751284    
#> 488: 0.392532    0.998645    3.400426    0.425978    0.002829    0.032183    0.751204    
#> 489: 0.392616    0.998619    3.400421    0.425955    0.002830    0.032166    0.751235    
#> 490: 0.392717    0.998607    3.400480    0.426112    0.002834    0.032158    0.751214    
#> 491: 0.392826    0.998626    3.400500    0.426229    0.002833    0.032161    0.751131    
#> 492: 0.392866    0.998623    3.400501    0.426301    0.002835    0.032168    0.751115    
#> 493: 0.392856    0.998607    3.400527    0.426203    0.002837    0.032149    0.751161    
#> 494: 0.393023    0.998611    3.400554    0.426364    0.002837    0.032116    0.751140    
#> 495: 0.393144    0.998621    3.400574    0.426409    0.002837    0.032098    0.751141    
#> 496: 0.393199    0.998639    3.400539    0.426530    0.002838    0.032085    0.751180    
#> 497: 0.393081    0.998640    3.400525    0.426326    0.002839    0.032106    0.751206    
#> 498: 0.393108    0.998641    3.400498    0.426174    0.002839    0.032101    0.751175    
#> 499: 0.393190    0.998631    3.400520    0.426173    0.002843    0.032085    0.751118    
#> 500: 0.393215    0.998636    3.400512    0.426191    0.002844    0.032067    0.751092    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.331846    0.975560    3.453983    0.392401    0.088328    0.016800    1.782545    
#> 002: 0.369771    1.008671    3.450535    0.372781    0.083911    0.015960    1.179999    
#> 003: 0.554634    0.908473    3.460381    0.410736    0.079716    0.015162    0.870979    
#> 004: 0.571058    0.899275    3.454994    0.490439    0.075730    0.014404    0.753951    
#> 005: 0.624486    0.896473    3.435199    0.694494    0.071943    0.013684    0.655410    
#> 006: 0.645603    0.913714    3.429069    0.810530    0.079068    0.013000    0.612945    
#> 007: 0.612035    0.939909    3.416011    0.817224    0.078267    0.013817    0.593829    
#> 008: 0.622431    0.923491    3.413805    0.868133    0.089684    0.013632    0.573514    
#> 009: 0.619210    0.925158    3.404139    0.894415    0.090744    0.013014    0.565884    
#> 010: 0.621981    0.921660    3.407927    0.885509    0.086207    0.013422    0.565014    
#> 011: 0.649357    0.936194    3.414347    1.047352    0.081897    0.014876    0.568952    
#> 012: 0.591191    0.931103    3.398494    0.994985    0.077802    0.014439    0.564684    
#> 013: 0.578081    0.927085    3.399341    0.945236    0.073912    0.014343    0.577608    
#> 014: 0.609123    0.938304    3.400058    1.066152    0.070216    0.013626    0.590430    
#> 015: 0.613623    0.944201    3.406149    1.012845    0.066705    0.012945    0.581545    
#> 016: 0.602989    0.945037    3.409115    0.962203    0.064878    0.012297    0.592791    
#> 017: 0.574486    0.951558    3.402576    0.953535    0.067417    0.013700    0.581718    
#> 018: 0.581376    0.941011    3.396102    0.905858    0.066560    0.017767    0.562986    
#> 019: 0.571729    0.945134    3.404405    0.918400    0.063232    0.017839    0.559566    
#> 020: 0.598841    0.933092    3.410040    1.013849    0.060071    0.020508    0.565447    
#> 021: 0.634674    0.916874    3.413132    1.036981    0.057067    0.019483    0.560376    
#> 022: 0.662566    0.936830    3.420090    1.162797    0.061437    0.018509    0.550356    
#> 023: 0.734542    0.943372    3.423917    1.278872    0.069312    0.018320    0.566912    
#> 024: 0.674071    0.950480    3.419186    1.214929    0.067757    0.017404    0.559440    
#> 025: 0.629454    0.941713    3.405365    1.154182    0.064370    0.016534    0.556780    
#> 026: 0.623955    0.958911    3.391671    1.096473    0.069941    0.015949    0.564108    
#> 027: 0.564570    0.983857    3.390974    1.041650    0.078214    0.015525    0.573108    
#> 028: 0.608526    0.965289    3.387818    1.151379    0.074303    0.018390    0.556829    
#> 029: 0.609251    0.958675    3.383422    1.139531    0.070588    0.019369    0.555147    
#> 030: 0.623083    0.966177    3.379530    1.229401    0.067059    0.022291    0.549035    
#> 031: 0.605156    0.961924    3.385688    1.167931    0.063706    0.022397    0.554423    
#> 032: 0.624690    0.952241    3.390255    1.198750    0.063475    0.021278    0.553760    
#> 033: 0.620968    0.955448    3.389916    1.249700    0.060449    0.022274    0.542765    
#> 034: 0.669603    0.956190    3.396279    1.308667    0.057426    0.023147    0.545438    
#> 035: 0.686141    0.934419    3.406651    1.243233    0.065753    0.021990    0.546487    
#> 036: 0.647522    0.937571    3.411605    1.181072    0.069213    0.021812    0.564445    
#> 037: 0.631599    0.940762    3.412020    1.122018    0.075619    0.020721    0.564049    
#> 038: 0.656233    0.957047    3.401891    1.138145    0.071838    0.021361    0.557522    
#> 039: 0.658688    0.952719    3.401459    1.149711    0.068246    0.020293    0.553354    
#> 040: 0.623552    0.952313    3.406844    1.092225    0.064834    0.019916    0.570229    
#> 041: 0.585880    0.955033    3.402268    1.037614    0.061592    0.019017    0.556422    
#> 042: 0.640722    0.939161    3.396537    1.109783    0.063999    0.018066    0.548486    
#> 043: 0.636566    0.950525    3.399435    1.054294    0.060799    0.017313    0.557473    
#> 044: 0.636350    0.940424    3.401408    1.001580    0.060545    0.017249    0.551073    
#> 045: 0.572419    0.952382    3.393415    0.951501    0.064400    0.017210    0.541307    
#> 046: 0.583905    0.938522    3.401655    0.903926    0.062762    0.017790    0.548302    
#> 047: 0.609459    0.953013    3.403447    0.897310    0.061246    0.019130    0.543344    
#> 048: 0.601474    0.939644    3.403810    0.931236    0.064051    0.020271    0.537232    
#> 049: 0.595657    0.939148    3.403753    0.884674    0.065160    0.021947    0.553368    
#> 050: 0.656923    0.917773    3.406764    1.122925    0.061902    0.020849    0.571165    
#> 051: 0.631204    0.932004    3.402156    1.125046    0.065230    0.019807    0.571819    
#> 052: 0.656651    0.930686    3.416523    1.102415    0.066915    0.020148    0.564843    
#> 053: 0.707430    0.931212    3.405475    1.222705    0.066153    0.019140    0.543127    
#> 054: 0.622042    0.946203    3.408445    1.161570    0.069194    0.019250    0.565825    
#> 055: 0.609446    0.948718    3.407153    1.103491    0.065735    0.020463    0.571162    
#> 056: 0.665911    0.939072    3.396471    1.190633    0.067419    0.019439    0.573170    
#> 057: 0.661037    0.934070    3.412858    1.248600    0.064048    0.018467    0.577518    
#> 058: 0.634204    0.922168    3.397382    1.186170    0.060846    0.019523    0.570542    
#> 059: 0.669169    0.886100    3.418816    1.199517    0.066386    0.022035    0.596623    
#> 060: 0.638062    0.896449    3.413257    1.139541    0.063638    0.020933    0.590332    
#> 061: 0.758999    0.924147    3.427822    1.245871    0.061444    0.019887    0.591896    
#> 062: 0.679638    0.919063    3.427102    1.183578    0.058372    0.018924    0.603401    
#> 063: 0.661056    0.907285    3.417324    1.124399    0.059806    0.017996    0.585275    
#> 064: 0.629459    0.925500    3.417233    1.068179    0.059655    0.020679    0.602124    
#> 065: 0.629159    0.916733    3.405861    1.014770    0.061741    0.020806    0.586925    
#> 066: 0.626306    0.937999    3.405846    1.016294    0.066932    0.019766    0.572210    
#> 067: 0.645119    0.932339    3.397159    1.252713    0.063585    0.018777    0.567670    
#> 068: 0.630204    0.946643    3.402177    1.190077    0.069102    0.019731    0.572508    
#> 069: 0.688496    0.944431    3.398519    1.364145    0.065647    0.018745    0.571500    
#> 070: 0.695127    0.936767    3.404350    1.452716    0.062365    0.021011    0.565265    
#> 071: 0.648796    0.961607    3.379007    1.380080    0.059246    0.021664    0.566122    
#> 072: 0.659730    0.930566    3.389010    1.311076    0.056284    0.020580    0.553599    
#> 073: 0.668767    0.945902    3.406980    1.357300    0.056348    0.021600    0.553330    
#> 074: 0.643090    0.928000    3.400352    1.289435    0.059731    0.020520    0.551431    
#> 075: 0.619443    0.926853    3.412080    1.224964    0.062436    0.022432    0.547746    
#> 076: 0.634794    0.933630    3.404701    1.163715    0.059314    0.025098    0.554504    
#> 077: 0.689762    0.921867    3.409532    1.237864    0.056348    0.024411    0.558113    
#> 078: 0.716272    0.929893    3.410972    1.384022    0.053531    0.023190    0.546472    
#> 079: 0.681235    0.938962    3.403490    1.314821    0.050854    0.022031    0.561158    
#> 080: 0.677001    0.936422    3.404028    1.296278    0.048312    0.025732    0.568042    
#> 081: 0.620521    0.949699    3.399527    1.231465    0.045896    0.024445    0.561508    
#> 082: 0.641444    0.945848    3.407029    1.189978    0.046797    0.027506    0.562974    
#> 083: 0.670981    0.957193    3.398638    1.422408    0.044814    0.031037    0.560457    
#> 084: 0.695629    0.941387    3.397663    1.510610    0.053153    0.029485    0.570238    
#> 085: 0.643517    0.954848    3.399000    1.435079    0.053114    0.033080    0.568367    
#> 086: 0.662588    0.963325    3.387028    1.450792    0.057097    0.031426    0.560903    
#> 087: 0.660369    0.952659    3.394105    1.378253    0.054242    0.029854    0.555516    
#> 088: 0.608961    0.954400    3.400394    1.309340    0.053333    0.028362    0.570790    
#> 089: 0.650772    0.948392    3.401707    1.268427    0.054262    0.026944    0.568222    
#> 090: 0.664067    0.931142    3.397214    1.212561    0.059382    0.025596    0.569770    
#> 091: 0.684992    0.939885    3.386267    1.332402    0.056413    0.024317    0.575866    
#> 092: 0.581045    0.948896    3.385410    1.265781    0.054832    0.023926    0.571786    
#> 093: 0.585521    0.950831    3.386767    1.202492    0.060987    0.023312    0.568699    
#> 094: 0.564969    0.954951    3.389755    1.142368    0.062866    0.022146    0.566270    
#> 095: 0.601196    0.958212    3.391314    1.085249    0.062739    0.021100    0.564831    
#> 096: 0.612763    0.953657    3.377269    1.120737    0.076424    0.020045    0.555592    
#> 097: 0.606820    0.970977    3.380077    1.105618    0.072603    0.019042    0.555417    
#> 098: 0.654003    0.967440    3.385784    1.176800    0.075197    0.018090    0.558469    
#> 099: 0.565843    0.954280    3.382041    1.117960    0.076930    0.019896    0.555396    
#> 100: 0.553853    0.958855    3.392616    1.062062    0.073083    0.019342    0.559375    
#> 101: 0.584703    0.951516    3.382760    1.034416    0.069429    0.023331    0.553066    
#> 102: 0.598184    0.956818    3.387055    1.060220    0.065958    0.022966    0.563442    
#> 103: 0.658000    0.954507    3.389727    1.148573    0.062660    0.024049    0.551655    
#> 104: 0.709935    0.951432    3.407162    1.360653    0.060852    0.023001    0.560397    
#> 105: 0.754929    0.933258    3.408440    1.531318    0.063934    0.022250    0.572435    
#> 106: 0.708577    0.926538    3.411652    1.454752    0.060738    0.022154    0.549987    
#> 107: 0.725695    0.937806    3.406647    1.441654    0.069611    0.021046    0.545279    
#> 108: 0.657136    0.930123    3.415937    1.369571    0.066130    0.021145    0.558562    
#> 109: 0.705893    0.934055    3.421936    1.301093    0.063618    0.020088    0.549157    
#> 110: 0.699104    0.912327    3.414000    1.236038    0.060437    0.019084    0.552928    
#> 111: 0.701977    0.923077    3.420311    1.174236    0.057415    0.018130    0.549280    
#> 112: 0.660220    0.910265    3.412817    1.115524    0.054545    0.021122    0.557638    
#> 113: 0.683409    0.941573    3.404002    1.203541    0.051817    0.020066    0.555159    
#> 114: 0.652707    0.957888    3.403057    1.143364    0.052029    0.019316    0.563119    
#> 115: 0.648439    0.945241    3.396063    1.115722    0.053480    0.021411    0.579593    
#> 116: 0.694565    0.951401    3.404006    1.232007    0.066463    0.021244    0.554666    
#> 117: 0.623689    0.946662    3.409690    1.170407    0.063140    0.023764    0.551437    
#> 118: 0.701176    0.925591    3.414870    1.248909    0.059983    0.024182    0.555746    
#> 119: 0.734281    0.931871    3.407807    1.377359    0.056984    0.027635    0.558268    
#> 120: 0.712465    0.928160    3.413653    1.316456    0.054135    0.026253    0.546232    
#> 121: 0.744845    0.943801    3.410356    1.409347    0.059943    0.024941    0.552764    
#> 122: 0.708789    0.919783    3.415778    1.338879    0.063272    0.023694    0.553234    
#> 123: 0.698063    0.948211    3.415960    1.271935    0.064152    0.022509    0.554447    
#> 124: 0.652049    0.968673    3.409329    1.208339    0.061324    0.021383    0.558386    
#> 125: 0.685409    0.974060    3.409271    1.178045    0.063903    0.023183    0.557021    
#> 126: 0.582359    0.978207    3.390308    1.119143    0.064047    0.023739    0.562696    
#> 127: 0.643466    0.948466    3.396677    1.063941    0.060845    0.022552    0.555085    
#> 128: 0.693736    0.937425    3.403929    1.256314    0.057803    0.022925    0.563072    
#> 129: 0.671312    0.946580    3.415315    1.244125    0.054913    0.022823    0.568740    
#> 130: 0.652002    0.944718    3.402298    1.181919    0.052167    0.021682    0.562582    
#> 131: 0.613056    0.933643    3.390206    1.122823    0.063170    0.024267    0.544180    
#> 132: 0.562782    0.954088    3.386247    1.066682    0.061128    0.023694    0.541270    
#> 133: 0.588649    0.954462    3.389679    1.056730    0.058581    0.022509    0.549669    
#> 134: 0.619321    0.915509    3.405710    1.064425    0.055652    0.022522    0.555459    
#> 135: 0.629230    0.919117    3.410952    1.011204    0.052869    0.024831    0.562361    
#> 136: 0.639353    0.916307    3.411899    0.980074    0.055617    0.023589    0.560711    
#> 137: 0.705803    0.925017    3.417498    1.171969    0.052836    0.023934    0.558103    
#> 138: 0.714505    0.919603    3.425195    1.279482    0.050194    0.023156    0.544527    
#> 139: 0.657537    0.927140    3.416827    1.215508    0.056079    0.021998    0.546363    
#> 140: 0.685184    0.928109    3.421030    1.227941    0.062226    0.023369    0.545692    
#> 141: 0.612285    0.915576    3.418613    1.166544    0.059115    0.022400    0.561162    
#> 142: 0.631949    0.915375    3.421291    1.108216    0.056159    0.023486    0.566097    
#> 143: 0.622977    0.929209    3.413313    1.052806    0.053351    0.022507    0.575409    
#> 144: 0.680198    0.937310    3.415991    1.000165    0.050684    0.021381    0.556692    
#> 145: 0.571080    0.956562    3.396693    0.950157    0.051779    0.020312    0.568144    
#> 146: 0.581577    0.958401    3.409748    0.902649    0.054941    0.019297    0.556815    
#> 147: 0.566833    0.940514    3.388012    0.898034    0.069377    0.018332    0.557079    
#> 148: 0.590693    0.952305    3.398527    0.993208    0.065908    0.021408    0.546637    
#> 149: 0.589477    0.943992    3.401004    0.943547    0.062613    0.021108    0.554414    
#> 150: 0.614936    0.951479    3.392470    0.987212    0.059482    0.020053    0.565888    
#> 151: 0.580829    0.975200    3.405776    0.937851    0.057992    0.019050    0.565525    
#> 152: 0.610829    0.962620    3.404158    0.943222    0.050603    0.015696    0.563755    
#> 153: 0.600951    0.949909    3.414010    0.822155    0.059073    0.016746    0.567548    
#> 154: 0.642379    0.942860    3.416401    0.910721    0.062259    0.020182    0.553961    
#> 155: 0.634639    0.918946    3.417022    0.864738    0.049778    0.019545    0.569639    
#> 156: 0.634227    0.922734    3.419139    0.924651    0.053997    0.020892    0.579189    
#> 157: 0.662628    0.922345    3.425801    1.065015    0.055446    0.022181    0.566922    
#> 158: 0.646017    0.947303    3.418367    0.919702    0.062441    0.019413    0.566316    
#> 159: 0.611863    0.937903    3.421790    0.947551    0.063363    0.016062    0.558440    
#> 160: 0.655199    0.922233    3.426974    0.945749    0.068299    0.017198    0.574861    
#> 161: 0.681974    0.904705    3.429574    1.034348    0.060948    0.018697    0.593302    
#> 162: 0.647127    0.929260    3.422014    1.010269    0.056282    0.018379    0.587157    
#> 163: 0.671426    0.937099    3.410350    1.157032    0.062846    0.018780    0.567745    
#> 164: 0.654891    0.942812    3.411586    1.087627    0.055241    0.020369    0.560377    
#> 165: 0.702397    0.928033    3.409113    1.336702    0.053056    0.022954    0.562555    
#> 166: 0.773493    0.950345    3.417741    1.369120    0.061256    0.023932    0.569576    
#> 167: 0.689712    0.952287    3.429273    1.086539    0.057555    0.026191    0.563366    
#> 168: 0.677642    0.935809    3.430667    0.968054    0.059324    0.027621    0.570181    
#> 169: 0.676050    0.959118    3.420223    1.037623    0.066389    0.021218    0.572081    
#> 170: 0.692502    0.936645    3.428281    1.030575    0.056252    0.022628    0.566406    
#> 171: 0.663210    0.927813    3.417945    0.972946    0.052413    0.020004    0.549098    
#> 172: 0.626800    0.953392    3.414918    0.987703    0.056652    0.021964    0.549588    
#> 173: 0.599534    0.957604    3.404438    0.872586    0.059187    0.019117    0.548322    
#> 174: 0.602899    0.936719    3.412532    0.856896    0.058323    0.016381    0.554942    
#> 175: 0.598342    0.941198    3.402810    0.943817    0.055896    0.017094    0.555603    
#> 176: 0.671252    0.941655    3.416170    1.028942    0.055476    0.019022    0.543628    
#> 177: 0.668777    0.934957    3.415667    1.063011    0.062997    0.017792    0.548521    
#> 178: 0.646365    0.930971    3.414984    0.967135    0.057398    0.019345    0.551329    
#> 179: 0.674913    0.944709    3.413449    0.976458    0.048583    0.023628    0.565050    
#> 180: 0.652011    0.937666    3.422404    0.952017    0.046813    0.020163    0.565744    
#> 181: 0.634836    0.929023    3.405867    0.922305    0.042181    0.021055    0.564305    
#> 182: 0.592407    0.933904    3.401516    0.952319    0.057098    0.020860    0.565664    
#> 183: 0.603207    0.945021    3.405936    0.822761    0.058521    0.023346    0.558978    
#> 184: 0.605421    0.936964    3.410353    0.879549    0.055581    0.020324    0.566424    
#> 185: 0.604428    0.960288    3.401703    0.872850    0.058634    0.019001    0.562097    
#> 186: 0.575285    0.963048    3.404574    0.789000    0.065940    0.020117    0.578147    
#> 187: 0.644460    0.933902    3.412374    0.959740    0.066835    0.019824    0.563038    
#> 188: 0.642651    0.956664    3.403169    1.030058    0.065206    0.019727    0.563656    
#> 189: 0.677108    0.942912    3.408237    1.222485    0.057279    0.023671    0.552066    
#> 190: 0.674226    0.948477    3.402873    1.278815    0.057565    0.023223    0.549070    
#> 191: 0.682451    0.963819    3.406160    1.144553    0.061713    0.022572    0.538537    
#> 192: 0.665401    0.953380    3.414066    1.061941    0.052534    0.023351    0.551684    
#> 193: 0.679919    0.956109    3.415098    1.159020    0.044130    0.021652    0.560205    
#> 194: 0.641314    0.946097    3.409505    1.058344    0.061044    0.023148    0.542467    
#> 195: 0.634955    0.935408    3.410329    1.039465    0.061600    0.022902    0.538911    
#> 196: 0.699910    0.932085    3.413983    1.170441    0.061824    0.020243    0.555700    
#> 197: 0.627148    0.928145    3.417278    0.971416    0.060670    0.021621    0.572939    
#> 198: 0.684463    0.932224    3.406948    1.136642    0.054424    0.020161    0.566219    
#> 199: 0.650321    0.930319    3.400267    1.072676    0.062237    0.019274    0.581827    
#> 200: 0.630991    0.949526    3.407770    1.017049    0.062613    0.018913    0.578654    
#> 201: 0.623833    0.951222    3.409282    0.992734    0.062269    0.017896    0.571534    
#> 202: 0.612884    0.948435    3.406585    0.972035    0.061934    0.016848    0.571299    
#> 203: 0.614624    0.948022    3.405104    0.982451    0.061570    0.016227    0.569938    
#> 204: 0.616714    0.943072    3.406571    0.971374    0.063420    0.015616    0.569479    
#> 205: 0.615395    0.946829    3.407631    0.951363    0.062612    0.015730    0.569431    
#> 206: 0.621228    0.948988    3.409074    0.964446    0.061799    0.016165    0.568861    
#> 207: 0.623889    0.948977    3.409131    0.950735    0.061576    0.016026    0.569537    
#> 208: 0.624785    0.948997    3.409588    0.938543    0.061193    0.015947    0.568895    
#> 209: 0.629924    0.945687    3.410553    0.947193    0.060725    0.016235    0.567613    
#> 210: 0.633431    0.944131    3.411283    0.944840    0.060554    0.016605    0.565778    
#> 211: 0.636202    0.943795    3.412026    0.942811    0.060431    0.016852    0.564417    
#> 212: 0.635829    0.943675    3.412019    0.948764    0.061094    0.016886    0.564087    
#> 213: 0.640575    0.943343    3.412648    0.967307    0.062084    0.017079    0.564194    
#> 214: 0.643788    0.943274    3.412924    0.976843    0.062703    0.017276    0.564372    
#> 215: 0.645289    0.942900    3.413594    0.982557    0.062972    0.017593    0.564847    
#> 216: 0.649776    0.940485    3.414746    0.993921    0.063189    0.018208    0.565138    
#> 217: 0.651933    0.939451    3.415253    0.996864    0.062839    0.018530    0.565071    
#> 218: 0.654169    0.938799    3.415109    1.000841    0.062956    0.018712    0.565362    
#> 219: 0.654050    0.937772    3.415235    1.002972    0.062171    0.019033    0.565542    
#> 220: 0.653488    0.937670    3.415210    1.006387    0.061774    0.019304    0.565554    
#> 221: 0.651706    0.938405    3.415078    1.001750    0.061390    0.019415    0.564732    
#> 222: 0.653098    0.938097    3.414749    1.011341    0.061294    0.019588    0.564357    
#> 223: 0.654656    0.937787    3.414568    1.017876    0.061118    0.019724    0.564087    
#> 224: 0.656358    0.937911    3.414550    1.020885    0.061123    0.019620    0.564089    
#> 225: 0.658099    0.936766    3.415117    1.024205    0.061045    0.019608    0.563972    
#> 226: 0.659542    0.935486    3.415463    1.025666    0.060932    0.019458    0.563814    
#> 227: 0.660434    0.935028    3.415729    1.027759    0.060696    0.019346    0.563590    
#> 228: 0.659636    0.934653    3.415486    1.024885    0.060549    0.019297    0.563824    
#> 229: 0.659575    0.934398    3.415377    1.026261    0.060543    0.019241    0.563469    
#> 230: 0.658610    0.934000    3.415300    1.023859    0.060283    0.019237    0.563345    
#> 231: 0.659319    0.933542    3.415551    1.023473    0.060089    0.019273    0.563341    
#> 232: 0.660617    0.932742    3.415804    1.030142    0.059807    0.019259    0.563684    
#> 233: 0.661048    0.931879    3.415881    1.033863    0.059561    0.019327    0.563821    
#> 234: 0.662033    0.931879    3.415532    1.042037    0.059394    0.019406    0.563594    
#> 235: 0.662379    0.932115    3.415220    1.046075    0.059226    0.019481    0.563291    
#> 236: 0.661880    0.932521    3.414722    1.049524    0.059202    0.019516    0.563136    
#> 237: 0.662702    0.932742    3.414357    1.054893    0.059021    0.019519    0.563584    
#> 238: 0.663084    0.932674    3.414529    1.054529    0.059167    0.019591    0.563891    
#> 239: 0.663489    0.932855    3.414556    1.054666    0.059531    0.019614    0.564072    
#> 240: 0.664078    0.932517    3.414715    1.053845    0.059778    0.019624    0.563787    
#> 241: 0.665236    0.931670    3.414916    1.055482    0.059872    0.019657    0.563541    
#> 242: 0.665047    0.931032    3.415008    1.055355    0.060073    0.019726    0.563601    
#> 243: 0.664439    0.931199    3.415032    1.053945    0.060260    0.019750    0.563432    
#> 244: 0.663462    0.931128    3.415237    1.051512    0.060283    0.019779    0.563281    
#> 245: 0.662461    0.930506    3.415320    1.048614    0.060250    0.019806    0.563453    
#> 246: 0.661614    0.930088    3.415349    1.046632    0.060056    0.019872    0.563395    
#> 247: 0.660434    0.929797    3.415264    1.043920    0.059942    0.019906    0.563183    
#> 248: 0.659268    0.930326    3.414927    1.043121    0.059902    0.019889    0.563112    
#> 249: 0.658267    0.930245    3.414788    1.043449    0.059789    0.019932    0.562828    
#> 250: 0.657955    0.930262    3.414624    1.043590    0.059752    0.019943    0.562695    
#> 251: 0.658794    0.930650    3.414567    1.046609    0.059514    0.019945    0.562569    
#> 252: 0.659841    0.930980    3.414561    1.051035    0.059453    0.019930    0.562644    
#> 253: 0.659465    0.931247    3.414502    1.051453    0.059359    0.019907    0.562666    
#> 254: 0.659560    0.931504    3.414468    1.052094    0.059416    0.019878    0.562812    
#> 255: 0.660298    0.931539    3.414500    1.054922    0.059381    0.019848    0.562868    
#> 256: 0.661152    0.931361    3.414397    1.058802    0.059462    0.019842    0.562883    
#> 257: 0.661075    0.931088    3.414295    1.058517    0.059564    0.019848    0.562849    
#> 258: 0.661779    0.930682    3.414422    1.061227    0.059690    0.019806    0.562843    
#> 259: 0.662445    0.930307    3.414444    1.064605    0.059657    0.019767    0.563092    
#> 260: 0.662147    0.930362    3.414569    1.062989    0.059589    0.019745    0.563204    
#> 261: 0.662168    0.930155    3.414667    1.061028    0.059557    0.019719    0.563113    
#> 262: 0.661488    0.930291    3.414765    1.059254    0.059439    0.019706    0.563068    
#> 263: 0.661508    0.930534    3.414728    1.059726    0.059328    0.019663    0.563230    
#> 264: 0.661910    0.930762    3.414687    1.061204    0.059221    0.019619    0.563416    
#> 265: 0.661724    0.930951    3.414726    1.060502    0.059206    0.019588    0.563662    
#> 266: 0.661957    0.931048    3.414734    1.062503    0.059203    0.019591    0.563523    
#> 267: 0.662554    0.931216    3.414895    1.065462    0.059115    0.019616    0.563313    
#> 268: 0.663455    0.931213    3.414875    1.068827    0.059146    0.019650    0.563065    
#> 269: 0.664102    0.931173    3.414871    1.072566    0.059051    0.019655    0.563154    
#> 270: 0.665132    0.931386    3.414825    1.076022    0.058976    0.019626    0.563015    
#> 271: 0.665438    0.931485    3.414702    1.077974    0.059046    0.019573    0.563111    
#> 272: 0.665773    0.931364    3.414782    1.077513    0.059131    0.019549    0.563366    
#> 273: 0.665681    0.931754    3.414856    1.076897    0.059262    0.019501    0.563422    
#> 274: 0.664789    0.931949    3.414837    1.073838    0.059261    0.019472    0.563430    
#> 275: 0.664567    0.931826    3.414741    1.072329    0.059249    0.019443    0.563447    
#> 276: 0.664044    0.931992    3.414771    1.070923    0.059197    0.019450    0.563310    
#> 277: 0.663415    0.932161    3.414774    1.069762    0.059136    0.019462    0.563297    
#> 278: 0.662496    0.932041    3.414822    1.068574    0.059133    0.019459    0.563423    
#> 279: 0.662021    0.931848    3.414839    1.067924    0.059204    0.019455    0.563433    
#> 280: 0.661351    0.932037    3.414814    1.067052    0.059181    0.019449    0.563237    
#> 281: 0.660749    0.932268    3.414726    1.066295    0.059190    0.019415    0.563103    
#> 282: 0.660626    0.932439    3.414711    1.066415    0.059135    0.019424    0.563181    
#> 283: 0.661051    0.932654    3.414713    1.068336    0.059226    0.019442    0.563300    
#> 284: 0.661290    0.932526    3.414634    1.070334    0.059255    0.019466    0.563165    
#> 285: 0.661347    0.932517    3.414528    1.070332    0.059119    0.019512    0.563156    
#> 286: 0.661531    0.932614    3.414315    1.071307    0.059018    0.019542    0.563062    
#> 287: 0.660924    0.932809    3.414134    1.070555    0.058978    0.019579    0.563033    
#> 288: 0.661059    0.932867    3.414031    1.071392    0.058920    0.019635    0.563149    
#> 289: 0.661019    0.932948    3.413955    1.072271    0.058950    0.019639    0.563189    
#> 290: 0.660586    0.933066    3.413844    1.071683    0.058971    0.019624    0.563152    
#> 291: 0.660502    0.933217    3.413815    1.072224    0.058952    0.019596    0.563206    
#> 292: 0.660450    0.933362    3.413675    1.073865    0.058987    0.019605    0.563138    
#> 293: 0.660943    0.933450    3.413560    1.076497    0.058906    0.019627    0.563217    
#> 294: 0.661157    0.933577    3.413441    1.079086    0.058882    0.019648    0.563244    
#> 295: 0.661422    0.933274    3.413470    1.079217    0.058743    0.019647    0.563230    
#> 296: 0.661191    0.933241    3.413433    1.077415    0.058668    0.019645    0.563347    
#> 297: 0.661682    0.933300    3.413402    1.078477    0.058611    0.019648    0.563372    
#> 298: 0.661662    0.933303    3.413424    1.078391    0.058562    0.019643    0.563242    
#> 299: 0.661744    0.933345    3.413410    1.078643    0.058502    0.019642    0.563035    
#> 300: 0.662023    0.933332    3.413477    1.079990    0.058392    0.019634    0.562918    
#> 301: 0.661857    0.933190    3.413476    1.078664    0.058305    0.019611    0.562879    
#> 302: 0.661752    0.933142    3.413437    1.078149    0.058168    0.019594    0.562867    
#> 303: 0.661511    0.933148    3.413378    1.077316    0.058199    0.019594    0.562712    
#> 304: 0.661242    0.933385    3.413242    1.076805    0.058224    0.019595    0.562654    
#> 305: 0.660957    0.933265    3.413078    1.077148    0.058202    0.019595    0.562621    
#> 306: 0.660310    0.933115    3.412978    1.075812    0.058195    0.019592    0.562557    
#> 307: 0.659852    0.933028    3.412904    1.074849    0.058182    0.019611    0.562477    
#> 308: 0.659461    0.932906    3.412808    1.073740    0.058154    0.019631    0.562561    
#> 309: 0.659074    0.932781    3.412688    1.073886    0.058174    0.019661    0.562721    
#> 310: 0.658815    0.932878    3.412491    1.073917    0.058223    0.019667    0.562707    
#> 311: 0.658351    0.932925    3.412404    1.073576    0.058215    0.019669    0.562621    
#> 312: 0.658042    0.932945    3.412304    1.073174    0.058272    0.019676    0.562448    
#> 313: 0.658045    0.932893    3.412254    1.073657    0.058332    0.019665    0.562408    
#> 314: 0.657292    0.933060    3.412117    1.072227    0.058376    0.019632    0.562412    
#> 315: 0.656797    0.933248    3.412042    1.070911    0.058501    0.019607    0.562345    
#> 316: 0.656675    0.933293    3.412009    1.070291    0.058615    0.019571    0.562228    
#> 317: 0.657056    0.933382    3.412036    1.071545    0.058751    0.019533    0.562238    
#> 318: 0.657626    0.933534    3.411978    1.073418    0.058909    0.019530    0.562223    
#> 319: 0.658106    0.933530    3.411981    1.075316    0.059000    0.019519    0.562190    
#> 320: 0.657863    0.933541    3.411970    1.074802    0.059100    0.019505    0.562355    
#> 321: 0.657609    0.933528    3.411929    1.074437    0.059220    0.019506    0.562394    
#> 322: 0.657449    0.933550    3.411788    1.074966    0.059282    0.019503    0.562347    
#> 323: 0.656857    0.933646    3.411681    1.073857    0.059374    0.019500    0.562336    
#> 324: 0.656988    0.933641    3.411709    1.074426    0.059382    0.019502    0.562126    
#> 325: 0.657621    0.933645    3.411746    1.075962    0.059341    0.019478    0.562001    
#> 326: 0.658047    0.933490    3.411736    1.076794    0.059309    0.019454    0.562049    
#> 327: 0.658553    0.933515    3.411778    1.078015    0.059189    0.019454    0.562102    
#> 328: 0.659248    0.933554    3.411859    1.079907    0.059106    0.019453    0.562053    
#> 329: 0.659808    0.933406    3.411991    1.081393    0.059087    0.019438    0.562060    
#> 330: 0.660106    0.933266    3.412115    1.082702    0.059062    0.019435    0.561990    
#> 331: 0.660834    0.933299    3.412227    1.085984    0.058964    0.019453    0.562033    
#> 332: 0.661063    0.933247    3.412282    1.086712    0.058946    0.019457    0.562160    
#> 333: 0.661171    0.933183    3.412229    1.087256    0.058909    0.019476    0.562271    
#> 334: 0.661060    0.933018    3.412108    1.088420    0.058825    0.019492    0.562374    
#> 335: 0.660842    0.933020    3.412066    1.088557    0.058781    0.019510    0.562388    
#> 336: 0.660241    0.933165    3.411945    1.087255    0.058751    0.019531    0.562379    
#> 337: 0.659850    0.933426    3.411783    1.087039    0.058709    0.019546    0.562364    
#> 338: 0.660034    0.933587    3.411726    1.088335    0.058699    0.019586    0.562295    
#> 339: 0.659924    0.933773    3.411660    1.088485    0.058682    0.019619    0.562266    
#> 340: 0.659957    0.933626    3.411710    1.088452    0.058669    0.019625    0.562235    
#> 341: 0.659973    0.933490    3.411774    1.088540    0.058689    0.019611    0.562231    
#> 342: 0.659710    0.933368    3.411784    1.087468    0.058750    0.019600    0.562190    
#> 343: 0.659377    0.933344    3.411770    1.086185    0.058747    0.019580    0.562236    
#> 344: 0.659220    0.933325    3.411839    1.084999    0.058779    0.019571    0.562396    
#> 345: 0.659217    0.933368    3.411826    1.084856    0.058816    0.019561    0.562359    
#> 346: 0.659231    0.933453    3.411722    1.085350    0.058842    0.019535    0.562362    
#> 347: 0.659014    0.933487    3.411618    1.085133    0.058874    0.019520    0.562440    
#> 348: 0.658506    0.933514    3.411491    1.084504    0.058855    0.019518    0.562520    
#> 349: 0.658260    0.933490    3.411353    1.085201    0.058850    0.019521    0.562552    
#> 350: 0.658095    0.933414    3.411268    1.085668    0.058926    0.019526    0.562626    
#> 351: 0.658066    0.933372    3.411201    1.086453    0.059015    0.019549    0.562612    
#> 352: 0.657338    0.933496    3.411098    1.085589    0.059114    0.019550    0.562736    
#> 353: 0.657251    0.933670    3.411026    1.086074    0.059197    0.019553    0.562704    
#> 354: 0.657019    0.933801    3.410901    1.086672    0.059200    0.019583    0.562669    
#> 355: 0.657044    0.933851    3.410740    1.087328    0.059158    0.019579    0.562715    
#> 356: 0.656987    0.933884    3.410647    1.087523    0.059169    0.019560    0.562741    
#> 357: 0.657157    0.933935    3.410609    1.088611    0.059188    0.019535    0.562724    
#> 358: 0.657508    0.934002    3.410546    1.090179    0.059133    0.019535    0.562672    
#> 359: 0.657475    0.934087    3.410501    1.090013    0.059115    0.019555    0.562727    
#> 360: 0.657124    0.934156    3.410405    1.089047    0.059129    0.019573    0.562694    
#> 361: 0.656869    0.934184    3.410344    1.088861    0.059064    0.019604    0.562707    
#> 362: 0.656935    0.934147    3.410317    1.089591    0.059023    0.019624    0.562618    
#> 363: 0.656809    0.934049    3.410298    1.089468    0.058993    0.019629    0.562536    
#> 364: 0.656929    0.934076    3.410194    1.090358    0.058951    0.019625    0.562475    
#> 365: 0.656593    0.934142    3.410128    1.090074    0.059014    0.019638    0.562353    
#> 366: 0.656260    0.934260    3.410004    1.089503    0.059049    0.019662    0.562279    
#> 367: 0.656326    0.934311    3.409950    1.089939    0.059048    0.019650    0.562251    
#> 368: 0.656847    0.934366    3.409930    1.091436    0.059055    0.019640    0.562160    
#> 369: 0.656835    0.934337    3.409919    1.091706    0.059078    0.019633    0.562089    
#> 370: 0.656529    0.934376    3.409864    1.090720    0.059090    0.019635    0.562114    
#> 371: 0.656286    0.934428    3.409831    1.090025    0.059075    0.019641    0.562103    
#> 372: 0.655883    0.934468    3.409749    1.089881    0.059111    0.019648    0.562121    
#> 373: 0.655394    0.934632    3.409613    1.089798    0.059097    0.019657    0.562215    
#> 374: 0.655281    0.934793    3.409532    1.089608    0.059074    0.019661    0.562252    
#> 375: 0.654930    0.934884    3.409462    1.089312    0.059060    0.019674    0.562345    
#> 376: 0.654620    0.934984    3.409414    1.089189    0.059085    0.019673    0.562358    
#> 377: 0.654293    0.935096    3.409336    1.089093    0.059086    0.019664    0.562354    
#> 378: 0.654215    0.935166    3.409254    1.089110    0.059098    0.019672    0.562397    
#> 379: 0.653866    0.935077    3.409248    1.088507    0.059054    0.019687    0.562403    
#> 380: 0.653428    0.935041    3.409209    1.087294    0.059102    0.019696    0.562441    
#> 381: 0.653321    0.935082    3.409175    1.087092    0.059127    0.019692    0.562443    
#> 382: 0.653427    0.935077    3.409174    1.087264    0.059074    0.019694    0.562375    
#> 383: 0.653390    0.935092    3.409197    1.086678    0.059073    0.019677    0.562293    
#> 384: 0.653170    0.935065    3.409249    1.085662    0.059035    0.019663    0.562286    
#> 385: 0.653160    0.935072    3.409288    1.085035    0.059026    0.019653    0.562247    
#> 386: 0.653078    0.935158    3.409320    1.084089    0.059060    0.019627    0.562225    
#> 387: 0.652739    0.935344    3.409341    1.082594    0.059060    0.019606    0.562277    
#> 388: 0.652693    0.935442    3.409336    1.082644    0.059031    0.019602    0.562202    
#> 389: 0.652740    0.935436    3.409286    1.083292    0.058972    0.019594    0.562210    
#> 390: 0.652751    0.935557    3.409210    1.083527    0.058934    0.019586    0.562180    
#> 391: 0.652767    0.935592    3.409179    1.083669    0.058892    0.019602    0.562094    
#> 392: 0.652809    0.935605    3.409147    1.084181    0.058858    0.019614    0.562024    
#> 393: 0.652814    0.935560    3.409132    1.084690    0.058797    0.019633    0.562041    
#> 394: 0.653116    0.935566    3.409109    1.085632    0.058819    0.019627    0.562122    
#> 395: 0.653426    0.935698    3.409057    1.087144    0.058819    0.019629    0.562143    
#> 396: 0.653737    0.935764    3.409042    1.088862    0.058826    0.019639    0.562020    
#> 397: 0.653702    0.935784    3.409006    1.089098    0.058826    0.019659    0.561972    
#> 398: 0.653826    0.935715    3.409015    1.090082    0.058824    0.019680    0.561933    
#> 399: 0.653544    0.935736    3.409027    1.089448    0.058837    0.019687    0.561908    
#> 400: 0.653367    0.935741    3.409006    1.089032    0.058801    0.019686    0.561940    
#> 401: 0.653056    0.935812    3.408924    1.088304    0.058815    0.019687    0.561959    
#> 402: 0.652822    0.935983    3.408864    1.087805    0.058865    0.019686    0.561988    
#> 403: 0.652651    0.936013    3.408805    1.087748    0.058833    0.019684    0.562014    
#> 404: 0.652448    0.936137    3.408680    1.087693    0.058838    0.019673    0.561961    
#> 405: 0.652309    0.936152    3.408643    1.087837    0.058825    0.019670    0.561942    
#> 406: 0.652255    0.936281    3.408595    1.087945    0.058845    0.019679    0.561945    
#> 407: 0.652047    0.936339    3.408600    1.087623    0.058873    0.019664    0.561958    
#> 408: 0.652005    0.936420    3.408577    1.087243    0.058900    0.019653    0.561955    
#> 409: 0.651925    0.936383    3.408556    1.087100    0.058873    0.019638    0.561930    
#> 410: 0.651848    0.936436    3.408543    1.086654    0.058877    0.019625    0.561915    
#> 411: 0.651748    0.936320    3.408530    1.086528    0.058905    0.019615    0.561936    
#> 412: 0.651433    0.936374    3.408469    1.085930    0.058921    0.019605    0.561947    
#> 413: 0.651223    0.936432    3.408401    1.085376    0.058952    0.019593    0.561991    
#> 414: 0.651083    0.936495    3.408364    1.085549    0.058976    0.019579    0.562017    
#> 415: 0.650949    0.936505    3.408318    1.085142    0.059006    0.019556    0.561983    
#> 416: 0.650900    0.936553    3.408331    1.084851    0.059030    0.019558    0.561917    
#> 417: 0.650697    0.936531    3.408289    1.084251    0.059026    0.019547    0.561931    
#> 418: 0.650503    0.936496    3.408271    1.083679    0.059051    0.019536    0.561921    
#> 419: 0.650449    0.936507    3.408253    1.083702    0.059050    0.019517    0.561966    
#> 420: 0.650422    0.936453    3.408248    1.083623    0.059064    0.019506    0.561926    
#> 421: 0.650177    0.936433    3.408280    1.082768    0.059072    0.019499    0.561961    
#> 422: 0.650149    0.936304    3.408314    1.082105    0.059086    0.019483    0.561991    
#> 423: 0.650331    0.936197    3.408362    1.082362    0.059095    0.019480    0.562001    
#> 424: 0.650251    0.936165    3.408339    1.081946    0.059108    0.019468    0.561992    
#> 425: 0.650374    0.936233    3.408306    1.082059    0.059110    0.019461    0.562039    
#> 426: 0.650518    0.936358    3.408248    1.083265    0.059093    0.019448    0.562096    
#> 427: 0.650610    0.936448    3.408233    1.083713    0.059088    0.019435    0.562129    
#> 428: 0.650607    0.936532    3.408220    1.084118    0.059099    0.019412    0.562138    
#> 429: 0.650725    0.936601    3.408188    1.084517    0.059125    0.019394    0.562163    
#> 430: 0.650591    0.936636    3.408196    1.083434    0.059143    0.019383    0.562222    
#> 431: 0.650482    0.936600    3.408221    1.082751    0.059167    0.019380    0.562175    
#> 432: 0.650640    0.936629    3.408229    1.083177    0.059194    0.019380    0.562137    
#> 433: 0.650883    0.936666    3.408267    1.083756    0.059212    0.019378    0.562122    
#> 434: 0.650628    0.936597    3.408255    1.083303    0.059182    0.019378    0.562100    
#> 435: 0.650677    0.936593    3.408257    1.083431    0.059158    0.019379    0.562087    
#> 436: 0.650755    0.936545    3.408300    1.083572    0.059153    0.019378    0.562175    
#> 437: 0.650881    0.936492    3.408344    1.083679    0.059161    0.019387    0.562193    
#> 438: 0.650940    0.936599    3.408348    1.083646    0.059141    0.019393    0.562180    
#> 439: 0.651006    0.936625    3.408374    1.083597    0.059104    0.019389    0.562169    
#> 440: 0.651260    0.936586    3.408458    1.083547    0.059124    0.019373    0.562196    
#> 441: 0.651441    0.936545    3.408512    1.083453    0.059161    0.019355    0.562198    
#> 442: 0.651437    0.936604    3.408535    1.082941    0.059192    0.019342    0.562241    
#> 443: 0.651557    0.936661    3.408571    1.082620    0.059163    0.019339    0.562266    
#> 444: 0.651579    0.936746    3.408547    1.082338    0.059154    0.019335    0.562271    
#> 445: 0.651581    0.936726    3.408572    1.082330    0.059149    0.019327    0.562292    
#> 446: 0.651364    0.936741    3.408555    1.081745    0.059126    0.019318    0.562231    
#> 447: 0.651366    0.936746    3.408535    1.081773    0.059130    0.019311    0.562218    
#> 448: 0.651249    0.936771    3.408542    1.081412    0.059137    0.019300    0.562204    
#> 449: 0.651030    0.936830    3.408587    1.080618    0.059146    0.019285    0.562232    
#> 450: 0.651104    0.936816    3.408606    1.080515    0.059205    0.019275    0.562229    
#> 451: 0.651205    0.936850    3.408608    1.080841    0.059307    0.019263    0.562203    
#> 452: 0.651069    0.936866    3.408601    1.080257    0.059363    0.019254    0.562170    
#> 453: 0.650938    0.936900    3.408567    1.079800    0.059368    0.019237    0.562153    
#> 454: 0.651317    0.936998    3.408560    1.081600    0.059391    0.019231    0.562120    
#> 455: 0.651830    0.937025    3.408549    1.083758    0.059384    0.019215    0.562057    
#> 456: 0.651931    0.937028    3.408541    1.084431    0.059416    0.019205    0.562003    
#> 457: 0.652047    0.937057    3.408575    1.084812    0.059478    0.019189    0.561932    
#> 458: 0.652149    0.937148    3.408604    1.085038    0.059486    0.019176    0.561886    
#> 459: 0.652150    0.937258    3.408614    1.085228    0.059496    0.019160    0.561875    
#> 460: 0.652004    0.937347    3.408579    1.084632    0.059540    0.019157    0.561847    
#> 461: 0.651967    0.937375    3.408611    1.084413    0.059532    0.019174    0.561819    
#> 462: 0.652022    0.937403    3.408657    1.084075    0.059511    0.019184    0.561820    
#> 463: 0.652073    0.937421    3.408680    1.083711    0.059523    0.019183    0.561806    
#> 464: 0.652220    0.937449    3.408693    1.083761    0.059516    0.019196    0.561775    
#> 465: 0.652146    0.937336    3.408723    1.083413    0.059511    0.019209    0.561763    
#> 466: 0.652162    0.937328    3.408711    1.083209    0.059516    0.019214    0.561775    
#> 467: 0.652110    0.937283    3.408762    1.082940    0.059521    0.019233    0.561737    
#> 468: 0.652236    0.937229    3.408800    1.083272    0.059506    0.019251    0.561741    
#> 469: 0.652206    0.937277    3.408817    1.083262    0.059495    0.019274    0.561761    
#> 470: 0.652226    0.937297    3.408794    1.083593    0.059491    0.019295    0.561836    
#> 471: 0.652105    0.937288    3.408776    1.083392    0.059436    0.019300    0.561893    
#> 472: 0.651991    0.937285    3.408751    1.083294    0.059431    0.019304    0.561865    
#> 473: 0.651885    0.937330    3.408741    1.083120    0.059429    0.019319    0.561824    
#> 474: 0.651949    0.937371    3.408745    1.083209    0.059427    0.019342    0.561836    
#> 475: 0.651973    0.937468    3.408746    1.083151    0.059401    0.019356    0.561848    
#> 476: 0.651896    0.937495    3.408737    1.083077    0.059356    0.019380    0.561876    
#> 477: 0.651811    0.937471    3.408751    1.082956    0.059300    0.019392    0.561822    
#> 478: 0.651732    0.937424    3.408770    1.082919    0.059297    0.019395    0.561842    
#> 479: 0.651856    0.937401    3.408778    1.083543    0.059259    0.019394    0.561845    
#> 480: 0.651952    0.937414    3.408764    1.084102    0.059271    0.019400    0.561905    
#> 481: 0.651916    0.937452    3.408734    1.083905    0.059281    0.019407    0.561911    
#> 482: 0.652007    0.937513    3.408694    1.084217    0.059322    0.019406    0.561881    
#> 483: 0.651836    0.937531    3.408664    1.084250    0.059363    0.019405    0.561905    
#> 484: 0.651717    0.937463    3.408652    1.083898    0.059370    0.019400    0.561898    
#> 485: 0.651702    0.937513    3.408630    1.084154    0.059368    0.019394    0.561908    
#> 486: 0.651501    0.937561    3.408618    1.083772    0.059361    0.019395    0.561892    
#> 487: 0.651666    0.937568    3.408651    1.083984    0.059352    0.019410    0.561876    
#> 488: 0.651728    0.937588    3.408673    1.084011    0.059353    0.019436    0.561877    
#> 489: 0.651808    0.937628    3.408651    1.083989    0.059361    0.019463    0.561837    
#> 490: 0.651922    0.937634    3.408647    1.084048    0.059343    0.019477    0.561805    
#> 491: 0.651971    0.937685    3.408686    1.083720    0.059328    0.019492    0.561755    
#> 492: 0.652049    0.937718    3.408692    1.083747    0.059355    0.019500    0.561797    
#> 493: 0.652023    0.937768    3.408667    1.083961    0.059398    0.019495    0.561741    
#> 494: 0.652071    0.937812    3.408648    1.084236    0.059426    0.019493    0.561692    
#> 495: 0.651933    0.937859    3.408610    1.084070    0.059434    0.019504    0.561625    
#> 496: 0.652020    0.938002    3.408553    1.084390    0.059444    0.019514    0.561588    
#> 497: 0.652150    0.938057    3.408549    1.084980    0.059464    0.019519    0.561645    
#> 498: 0.652083    0.938068    3.408493    1.085126    0.059460    0.019514    0.561637    
#> 499: 0.651950    0.938135    3.408431    1.085458    0.059464    0.019507    0.561626    
#> 500: 0.651920    0.938154    3.408374    1.085871    0.059465    0.019516    0.561579    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.291107    0.970146    3.443842    0.392401    0.078215    0.016800    1.945896    
#> 002: 0.282203    0.984970    3.439787    0.372781    0.074304    0.015960    1.362803    
#> 003: 0.423940    0.884321    3.464128    0.354142    0.070589    0.015162    1.022549    
#> 004: 0.406091    0.850988    3.453113    0.336435    0.071791    0.014404    0.901183    
#> 005: 0.490134    0.844630    3.454057    0.358302    0.094554    0.013684    0.802068    
#> 006: 0.473421    0.856228    3.443922    0.411452    0.120354    0.016344    0.709448    
#> 007: 0.412618    0.888281    3.442553    0.420496    0.114337    0.018436    0.731841    
#> 008: 0.422893    0.878020    3.427402    0.427151    0.108620    0.020201    0.736264    
#> 009: 0.376866    0.867464    3.419001    0.405793    0.115892    0.020057    0.715122    
#> 010: 0.407600    0.886721    3.414461    0.486772    0.110098    0.021517    0.694039    
#> 011: 0.472357    0.911263    3.421227    0.569921    0.105708    0.022394    0.674517    
#> 012: 0.433005    0.904769    3.424162    0.541425    0.114013    0.023865    0.656580    
#> 013: 0.394580    0.906879    3.408586    0.518576    0.108313    0.022672    0.677587    
#> 014: 0.413104    0.899126    3.411214    0.492647    0.113205    0.021832    0.665267    
#> 015: 0.430902    0.917997    3.413202    0.550311    0.107545    0.023636    0.652039    
#> 016: 0.417984    0.927801    3.414438    0.533934    0.108492    0.022454    0.662687    
#> 017: 0.422826    0.920329    3.423309    0.507237    0.103067    0.021332    0.672887    
#> 018: 0.422427    0.920514    3.409165    0.499419    0.105876    0.021846    0.667789    
#> 019: 0.389264    0.916521    3.414581    0.487180    0.103466    0.022081    0.661822    
#> 020: 0.404715    0.918967    3.419375    0.480340    0.109022    0.023649    0.672953    
#> 021: 0.428393    0.898709    3.429064    0.570560    0.103570    0.026725    0.656097    
#> 022: 0.431937    0.902639    3.429585    0.542032    0.107449    0.025388    0.659337    
#> 023: 0.520912    0.911411    3.448051    0.581915    0.110521    0.031442    0.671515    
#> 024: 0.490431    0.911489    3.441372    0.552819    0.110316    0.029870    0.655534    
#> 025: 0.463178    0.901138    3.422031    0.525178    0.104800    0.028377    0.667812    
#> 026: 0.428783    0.927062    3.418928    0.498919    0.099560    0.026958    0.659491    
#> 027: 0.406658    0.939705    3.410805    0.482540    0.105416    0.025610    0.663938    
#> 028: 0.430609    0.946500    3.414308    0.516606    0.110064    0.024330    0.644070    
#> 029: 0.428445    0.928084    3.405561    0.533679    0.123402    0.026407    0.669502    
#> 030: 0.434099    0.925120    3.408719    0.627841    0.117232    0.026251    0.657045    
#> 031: 0.406779    0.911454    3.420927    0.596449    0.111370    0.027062    0.661291    
#> 032: 0.408109    0.909716    3.420228    0.566627    0.105801    0.025709    0.660874    
#> 033: 0.414814    0.931655    3.420589    0.538295    0.100511    0.024424    0.661468    
#> 034: 0.449399    0.927466    3.418939    0.579369    0.095486    0.023202    0.698138    
#> 035: 0.441864    0.907985    3.423226    0.550401    0.099198    0.022042    0.664535    
#> 036: 0.431694    0.918533    3.419967    0.522881    0.115864    0.020940    0.677702    
#> 037: 0.417822    0.915693    3.421004    0.544577    0.110071    0.020143    0.673276    
#> 038: 0.421737    0.921017    3.419601    0.517348    0.104979    0.020293    0.667644    
#> 039: 0.451644    0.923455    3.418601    0.524160    0.101376    0.020622    0.655384    
#> 040: 0.437724    0.924648    3.417245    0.523640    0.113403    0.020875    0.682234    
#> 041: 0.411721    0.927794    3.414281    0.553650    0.110275    0.019831    0.679429    
#> 042: 0.456192    0.935562    3.400265    0.716857    0.105955    0.018840    0.674138    
#> 043: 0.408551    0.933945    3.393556    0.681014    0.109616    0.019052    0.675812    
#> 044: 0.390863    0.942337    3.397034    0.646964    0.119497    0.018099    0.673069    
#> 045: 0.386310    0.937928    3.393329    0.614615    0.121102    0.017194    0.667006    
#> 046: 0.393466    0.899576    3.402092    0.606371    0.115047    0.021564    0.657801    
#> 047: 0.423163    0.936553    3.403173    0.620719    0.110104    0.023038    0.649602    
#> 048: 0.407197    0.940826    3.401394    0.589683    0.119105    0.021886    0.653136    
#> 049: 0.392224    0.953911    3.406289    0.560199    0.118108    0.020792    0.674559    
#> 050: 0.450999    0.938456    3.406598    0.632976    0.135864    0.020767    0.666502    
#> 051: 0.393293    0.930291    3.405057    0.601327    0.135304    0.021289    0.663583    
#> 052: 0.420366    0.926563    3.424017    0.571261    0.128538    0.020225    0.640573    
#> 053: 0.415180    0.921007    3.415949    0.542698    0.122111    0.020033    0.649781    
#> 054: 0.389411    0.919841    3.418473    0.515563    0.116006    0.022116    0.682091    
#> 055: 0.408216    0.916210    3.416470    0.491907    0.114332    0.021010    0.672663    
#> 056: 0.425409    0.907645    3.409861    0.496370    0.112989    0.019960    0.699543    
#> 057: 0.394332    0.909059    3.414496    0.471552    0.113675    0.018962    0.700677    
#> 058: 0.409772    0.923295    3.405088    0.504441    0.107991    0.019521    0.679899    
#> 059: 0.415260    0.863594    3.424111    0.545164    0.102838    0.024245    0.687414    
#> 060: 0.438806    0.873594    3.433058    0.517906    0.107256    0.023383    0.682251    
#> 061: 0.486370    0.900950    3.434218    0.571839    0.101893    0.024561    0.686403    
#> 062: 0.443270    0.903082    3.437085    0.543247    0.105673    0.023515    0.703746    
#> 063: 0.472733    0.870442    3.433564    0.516085    0.100389    0.022563    0.701521    
#> 064: 0.460050    0.875448    3.443426    0.490281    0.104662    0.021435    0.700280    
#> 065: 0.461723    0.883480    3.426922    0.472766    0.099429    0.020545    0.678991    
#> 066: 0.472963    0.922182    3.426743    0.521448    0.103212    0.020002    0.687399    
#> 067: 0.480530    0.895804    3.429977    0.562289    0.113510    0.020449    0.680403    
#> 068: 0.435574    0.905026    3.438005    0.534175    0.110242    0.025899    0.705735    
#> 069: 0.475621    0.899751    3.411635    0.650745    0.118815    0.025152    0.683400    
#> 070: 0.444116    0.916121    3.425591    0.618208    0.112875    0.027536    0.667701    
#> 071: 0.433242    0.940054    3.402602    0.587297    0.107231    0.026160    0.651975    
#> 072: 0.398669    0.911762    3.414513    0.581463    0.101869    0.024852    0.660074    
#> 073: 0.417305    0.919859    3.424054    0.603103    0.096776    0.023609    0.665327    
#> 074: 0.418920    0.887628    3.428369    0.572948    0.106692    0.026083    0.668625    
#> 075: 0.426329    0.884975    3.433494    0.556143    0.101357    0.026346    0.669007    
#> 076: 0.471397    0.894465    3.434474    0.588063    0.098323    0.027412    0.665130    
#> 077: 0.457875    0.882748    3.439414    0.583354    0.104590    0.027215    0.668816    
#> 078: 0.463863    0.900974    3.435078    0.554186    0.103037    0.025855    0.671055    
#> 079: 0.447857    0.919061    3.423314    0.546753    0.109869    0.024562    0.691276    
#> 080: 0.449515    0.921461    3.415070    0.567082    0.104650    0.023334    0.712628    
#> 081: 0.426801    0.937952    3.400378    0.625973    0.113482    0.022167    0.682640    
#> 082: 0.429134    0.918540    3.416259    0.617195    0.114062    0.022349    0.668873    
#> 083: 0.445463    0.938422    3.413754    0.649944    0.108358    0.021504    0.670147    
#> 084: 0.455470    0.938665    3.408887    0.665187    0.116748    0.025018    0.648327    
#> 085: 0.416040    0.929408    3.428278    0.631928    0.110911    0.025436    0.656037    
#> 086: 0.431549    0.923011    3.424090    0.600331    0.105365    0.027412    0.646807    
#> 087: 0.405184    0.916355    3.418083    0.570315    0.100097    0.026042    0.651712    
#> 088: 0.407352    0.917948    3.423406    0.541799    0.095092    0.025332    0.654545    
#> 089: 0.389815    0.936282    3.410699    0.514709    0.093023    0.026298    0.653707    
#> 090: 0.394813    0.925304    3.401489    0.492643    0.094759    0.026518    0.665461    
#> 091: 0.407208    0.921381    3.396146    0.522671    0.092552    0.025967    0.673382    
#> 092: 0.384246    0.937211    3.395138    0.548484    0.102996    0.028128    0.675829    
#> 093: 0.352561    0.933274    3.404383    0.521059    0.099859    0.029174    0.688903    
#> 094: 0.399857    0.945849    3.406462    0.524035    0.094866    0.027715    0.683832    
#> 095: 0.414320    0.945544    3.422474    0.497833    0.101888    0.027155    0.668340    
#> 096: 0.385992    0.943803    3.414196    0.515160    0.096793    0.025797    0.657716    
#> 097: 0.437942    0.952729    3.415284    0.590759    0.100261    0.027104    0.656346    
#> 098: 0.449967    0.952111    3.415880    0.561221    0.101480    0.025863    0.668175    
#> 099: 0.429199    0.911562    3.411085    0.533160    0.096406    0.024569    0.669746    
#> 100: 0.383708    0.933868    3.414879    0.506502    0.091586    0.023341    0.677816    
#> 101: 0.377631    0.913086    3.402570    0.481177    0.097603    0.022174    0.658499    
#> 102: 0.414061    0.922021    3.407243    0.539556    0.092723    0.021065    0.657626    
#> 103: 0.442096    0.918283    3.422461    0.516413    0.110429    0.020012    0.649504    
#> 104: 0.453511    0.916601    3.433589    0.566251    0.104908    0.019660    0.673627    
#> 105: 0.468623    0.902030    3.437513    0.582276    0.106942    0.018677    0.690513    
#> 106: 0.485446    0.891823    3.427331    0.626429    0.118020    0.018180    0.678232    
#> 107: 0.473989    0.921805    3.429646    0.603598    0.112119    0.020446    0.649430    
#> 108: 0.446227    0.905612    3.436633    0.573418    0.108410    0.024502    0.661564    
#> 109: 0.461608    0.909086    3.442188    0.544748    0.120719    0.023277    0.664615    
#> 110: 0.463573    0.889786    3.434286    0.558310    0.114683    0.022113    0.668557    
#> 111: 0.473177    0.888797    3.436291    0.537839    0.111647    0.022849    0.658711    
#> 112: 0.447136    0.876816    3.429893    0.512828    0.112727    0.023050    0.689150    
#> 113: 0.417284    0.927674    3.420433    0.487186    0.124249    0.021897    0.664355    
#> 114: 0.413635    0.928250    3.415205    0.472105    0.135539    0.021782    0.668744    
#> 115: 0.434305    0.902100    3.413171    0.563990    0.128762    0.022740    0.683046    
#> 116: 0.451189    0.911292    3.406762    0.562411    0.122324    0.024241    0.675362    
#> 117: 0.366152    0.936965    3.407917    0.534290    0.121448    0.023029    0.676604    
#> 118: 0.403394    0.914560    3.410252    0.519004    0.119615    0.021877    0.667303    
#> 119: 0.401725    0.929799    3.404170    0.493053    0.120687    0.020783    0.663360    
#> 120: 0.411441    0.919985    3.409507    0.570344    0.114653    0.019744    0.671868    
#> 121: 0.418444    0.943507    3.414093    0.541827    0.114671    0.018757    0.666096    
#> 122: 0.456487    0.932163    3.414437    0.526245    0.108938    0.019196    0.673936    
#> 123: 0.466083    0.949247    3.417791    0.512686    0.103491    0.020089    0.695324    
#> 124: 0.458503    0.949406    3.413872    0.487052    0.113547    0.019085    0.694503    
#> 125: 0.436900    0.946695    3.407943    0.479497    0.118658    0.019171    0.664547    
#> 126: 0.406825    0.946206    3.399942    0.455522    0.128929    0.018213    0.682407    
#> 127: 0.445816    0.923843    3.400014    0.524800    0.122483    0.017302    0.665991    
#> 128: 0.421562    0.940455    3.411641    0.557865    0.122179    0.016437    0.665471    
#> 129: 0.415057    0.926879    3.412917    0.529972    0.131149    0.015615    0.671965    
#> 130: 0.422947    0.927185    3.410304    0.503474    0.124592    0.017885    0.659447    
#> 131: 0.396442    0.914808    3.400463    0.478300    0.132999    0.019523    0.681203    
#> 132: 0.386069    0.931131    3.400974    0.456744    0.126349    0.020726    0.667648    
#> 133: 0.385974    0.914608    3.405378    0.487553    0.120031    0.020306    0.680428    
#> 134: 0.395960    0.898831    3.424711    0.489164    0.114030    0.023013    0.676432    
#> 135: 0.432416    0.900345    3.431138    0.479434    0.108328    0.021863    0.670894    
#> 136: 0.436537    0.899513    3.422058    0.468472    0.102912    0.020769    0.682156    
#> 137: 0.483729    0.894295    3.444622    0.562585    0.104858    0.023978    0.667856    
#> 138: 0.450987    0.909734    3.437382    0.534455    0.099681    0.022779    0.676664    
#> 139: 0.420300    0.902232    3.436557    0.529516    0.121168    0.021640    0.684227    
#> 140: 0.431037    0.900400    3.433445    0.503041    0.125310    0.020558    0.671996    
#> 141: 0.431273    0.864742    3.437254    0.477888    0.119044    0.019530    0.672859    
#> 142: 0.431404    0.885671    3.437205    0.453994    0.128168    0.019541    0.681911    
#> 143: 0.396474    0.919057    3.430134    0.431294    0.132904    0.021435    0.693371    
#> 144: 0.454451    0.912304    3.431059    0.485646    0.127424    0.020364    0.667890    
#> 145: 0.412340    0.935665    3.411721    0.461364    0.123876    0.019346    0.660938    
#> 146: 0.391959    0.925190    3.415584    0.507017    0.122218    0.018924    0.666819    
#> 147: 0.373353    0.909901    3.400856    0.481666    0.116107    0.017977    0.671114    
#> 148: 0.360419    0.922447    3.410635    0.467802    0.115774    0.020036    0.664870    
#> 149: 0.400329    0.912946    3.419980    0.444412    0.109986    0.019034    0.680961    
#> 150: 0.463052    0.909743    3.417538    0.489216    0.104486    0.018082    0.685643    
#> 151: 0.414158    0.922904    3.416351    0.482746    0.099262    0.017178    0.673271    
#> 152: 0.374764    0.927005    3.410258    0.406973    0.118680    0.014722    0.671052    
#> 153: 0.399818    0.937101    3.414470    0.458843    0.127682    0.018061    0.665752    
#> 154: 0.426852    0.918189    3.418246    0.453192    0.114919    0.019773    0.670509    
#> 155: 0.406541    0.913426    3.414285    0.431290    0.088330    0.021843    0.677607    
#> 156: 0.411396    0.906984    3.411489    0.467446    0.073717    0.027787    0.680687    
#> 157: 0.401355    0.907378    3.414422    0.451837    0.081398    0.030868    0.671882    
#> 158: 0.412798    0.929098    3.415293    0.480919    0.093901    0.027212    0.651605    
#> 159: 0.399193    0.909674    3.425513    0.498941    0.092016    0.029500    0.661987    
#> 160: 0.441031    0.879082    3.428022    0.552820    0.084448    0.034399    0.671560    
#> 161: 0.447283    0.907213    3.422563    0.551496    0.093375    0.034445    0.676791    
#> 162: 0.423526    0.908693    3.423872    0.550722    0.088976    0.032435    0.692955    
#> 163: 0.432429    0.916715    3.412285    0.589751    0.090175    0.032841    0.682456    
#> 164: 0.392215    0.931618    3.415251    0.471948    0.091384    0.026093    0.665239    
#> 165: 0.398941    0.921975    3.404501    0.517642    0.104988    0.017902    0.662908    
#> 166: 0.418406    0.950734    3.408121    0.484897    0.112026    0.016167    0.680267    
#> 167: 0.366647    0.947393    3.410258    0.457217    0.124327    0.015882    0.688891    
#> 168: 0.403167    0.961402    3.414357    0.469110    0.118470    0.016880    0.653571    
#> 169: 0.425268    0.953706    3.402554    0.509304    0.114516    0.015936    0.669938    
#> 170: 0.408730    0.942449    3.405518    0.523746    0.115057    0.018655    0.662312    
#> 171: 0.409594    0.923769    3.411838    0.481219    0.125466    0.014684    0.653439    
#> 172: 0.391916    0.929252    3.416946    0.429862    0.120102    0.015142    0.671070    
#> 173: 0.382079    0.918590    3.402115    0.393321    0.125206    0.012552    0.684812    
#> 174: 0.426899    0.918003    3.415289    0.514080    0.126329    0.016561    0.685479    
#> 175: 0.404187    0.932996    3.398625    0.496923    0.123388    0.015703    0.688217    
#> 176: 0.458804    0.935207    3.416977    0.632749    0.129283    0.017339    0.664625    
#> 177: 0.451441    0.932511    3.420375    0.573909    0.131112    0.015336    0.687320    
#> 178: 0.434060    0.924300    3.415946    0.500162    0.123741    0.014116    0.688017    
#> 179: 0.420353    0.931859    3.413476    0.501680    0.112857    0.016573    0.683956    
#> 180: 0.436837    0.921026    3.422585    0.554796    0.122530    0.016251    0.657238    
#> 181: 0.411643    0.919518    3.404649    0.498001    0.111210    0.017781    0.667309    
#> 182: 0.397080    0.938172    3.395051    0.436606    0.111210    0.016555    0.683555    
#> 183: 0.393664    0.965556    3.397458    0.455099    0.125972    0.019640    0.701469    
#> 184: 0.366827    0.932372    3.397153    0.499535    0.132672    0.016373    0.680251    
#> 185: 0.360006    0.954529    3.394959    0.425943    0.129400    0.010888    0.690617    
#> 186: 0.377212    0.959562    3.400791    0.415896    0.126180    0.010389    0.700195    
#> 187: 0.388981    0.935383    3.403582    0.461005    0.106227    0.010089    0.691703    
#> 188: 0.357407    0.939604    3.402352    0.417330    0.114466    0.010542    0.707056    
#> 189: 0.406592    0.950836    3.409303    0.562730    0.123071    0.012624    0.710937    
#> 190: 0.426560    0.930265    3.409314    0.592921    0.112523    0.010533    0.686247    
#> 191: 0.400711    0.941809    3.398461    0.497311    0.119611    0.012308    0.682104    
#> 192: 0.390677    0.950501    3.405027    0.488140    0.109948    0.010922    0.677284    
#> 193: 0.402439    0.943042    3.402514    0.471009    0.121173    0.011808    0.672207    
#> 194: 0.354910    0.926321    3.393572    0.457456    0.112103    0.014359    0.678971    
#> 195: 0.334624    0.943518    3.392165    0.478627    0.116337    0.013896    0.673716    
#> 196: 0.361157    0.930247    3.400211    0.447498    0.134486    0.013453    0.679656    
#> 197: 0.339667    0.932530    3.411681    0.411783    0.118385    0.014689    0.705951    
#> 198: 0.393141    0.901582    3.404837    0.404301    0.116968    0.015369    0.688333    
#> 199: 0.386398    0.911195    3.409043    0.462413    0.097953    0.017764    0.676498    
#> 200: 0.396482    0.909311    3.413620    0.502477    0.085681    0.017996    0.705005    
#> 201: 0.408993    0.911320    3.419110    0.459658    0.086218    0.018020    0.700276    
#> 202: 0.407409    0.914117    3.418127    0.459131    0.093564    0.019188    0.696984    
#> 203: 0.421311    0.913081    3.417699    0.455337    0.098649    0.019847    0.693925    
#> 204: 0.426340    0.911715    3.420223    0.464530    0.102692    0.020163    0.692060    
#> 205: 0.424537    0.916574    3.420761    0.473578    0.106125    0.020444    0.690183    
#> 206: 0.427888    0.919961    3.422167    0.481136    0.106031    0.020512    0.692351    
#> 207: 0.431744    0.919719    3.422507    0.494069    0.106712    0.020764    0.693032    
#> 208: 0.438534    0.919082    3.423497    0.503863    0.107975    0.020851    0.691152    
#> 209: 0.445398    0.915778    3.424284    0.518148    0.108115    0.021278    0.689774    
#> 210: 0.447367    0.914967    3.424870    0.526492    0.107604    0.021379    0.686651    
#> 211: 0.446856    0.915233    3.425178    0.521802    0.106666    0.021161    0.685606    
#> 212: 0.448462    0.913231    3.425912    0.522137    0.106110    0.021294    0.684037    
#> 213: 0.453126    0.912034    3.426295    0.528485    0.105918    0.021457    0.682765    
#> 214: 0.455758    0.911445    3.426538    0.530246    0.105389    0.021579    0.682164    
#> 215: 0.456675    0.911809    3.427049    0.533455    0.105452    0.021777    0.682668    
#> 216: 0.459758    0.910240    3.428138    0.528449    0.105191    0.021900    0.683470    
#> 217: 0.458374    0.908942    3.429177    0.522329    0.104620    0.021899    0.682825    
#> 218: 0.457845    0.908327    3.429417    0.520430    0.105162    0.021967    0.681942    
#> 219: 0.455382    0.907473    3.428505    0.520663    0.105463    0.021928    0.681704    
#> 220: 0.454273    0.907563    3.428463    0.526768    0.105658    0.022021    0.681477    
#> 221: 0.454410    0.908148    3.427825    0.529937    0.105309    0.022080    0.681481    
#> 222: 0.453745    0.908021    3.427568    0.531403    0.104649    0.022258    0.681773    
#> 223: 0.453119    0.907568    3.427271    0.529813    0.104619    0.022443    0.681842    
#> 224: 0.453451    0.908087    3.427006    0.526564    0.104986    0.022539    0.681915    
#> 225: 0.451518    0.907069    3.427030    0.525618    0.105313    0.022466    0.681423    
#> 226: 0.448759    0.906703    3.426412    0.523458    0.105133    0.022462    0.680802    
#> 227: 0.447233    0.906818    3.426021    0.523287    0.105657    0.022409    0.680134    
#> 228: 0.444612    0.908089    3.425305    0.522116    0.105694    0.022324    0.680186    
#> 229: 0.442666    0.908475    3.424771    0.519866    0.105836    0.022110    0.679926    
#> 230: 0.441978    0.909457    3.424247    0.518798    0.105834    0.022102    0.679838    
#> 231: 0.440784    0.910426    3.423867    0.520004    0.106431    0.022019    0.679282    
#> 232: 0.438760    0.910989    3.423548    0.518469    0.106787    0.021832    0.679155    
#> 233: 0.436926    0.910552    3.423474    0.516623    0.106750    0.021841    0.679207    
#> 234: 0.436470    0.910604    3.423224    0.517580    0.106604    0.021780    0.679111    
#> 235: 0.436094    0.910640    3.422961    0.517490    0.106480    0.021787    0.678848    
#> 236: 0.435473    0.911036    3.422738    0.516783    0.106419    0.021894    0.678726    
#> 237: 0.435399    0.911035    3.422560    0.517477    0.106268    0.022006    0.678783    
#> 238: 0.435830    0.911299    3.422457    0.518969    0.106007    0.022119    0.679270    
#> 239: 0.435464    0.911524    3.422359    0.517242    0.105723    0.022097    0.679128    
#> 240: 0.435413    0.911208    3.422563    0.515038    0.105861    0.022025    0.678961    
#> 241: 0.436152    0.910196    3.422882    0.513660    0.105833    0.022037    0.679053    
#> 242: 0.435766    0.909754    3.422635    0.515052    0.106220    0.022080    0.679084    
#> 243: 0.434368    0.910043    3.422404    0.513925    0.106575    0.022073    0.679075    
#> 244: 0.433783    0.910049    3.422401    0.514737    0.106450    0.022084    0.679054    
#> 245: 0.433731    0.909273    3.422472    0.514142    0.106440    0.021996    0.679467    
#> 246: 0.433521    0.908933    3.422520    0.513682    0.106251    0.022045    0.679555    
#> 247: 0.433817    0.908589    3.422780    0.513849    0.106270    0.022089    0.679624    
#> 248: 0.434053    0.908931    3.422852    0.513750    0.106559    0.022063    0.679396    
#> 249: 0.433787    0.909114    3.422774    0.515124    0.106565    0.022058    0.679078    
#> 250: 0.433475    0.909906    3.422427    0.515612    0.106354    0.022089    0.678930    
#> 251: 0.433446    0.910571    3.422575    0.515104    0.106293    0.022063    0.678908    
#> 252: 0.433800    0.910928    3.422812    0.515881    0.106301    0.022096    0.678654    
#> 253: 0.433636    0.910837    3.422869    0.516660    0.106245    0.022271    0.678227    
#> 254: 0.433051    0.911206    3.422618    0.517224    0.106057    0.022378    0.677815    
#> 255: 0.433072    0.911731    3.422433    0.517927    0.106034    0.022386    0.677653    
#> 256: 0.432977    0.911557    3.422376    0.518467    0.106193    0.022431    0.677653    
#> 257: 0.432616    0.911525    3.422288    0.517467    0.106486    0.022392    0.677527    
#> 258: 0.431927    0.911373    3.422267    0.516622    0.106611    0.022275    0.677615    
#> 259: 0.431437    0.911445    3.422122    0.516916    0.106745    0.022154    0.677730    
#> 260: 0.431414    0.911688    3.422087    0.515670    0.106819    0.022063    0.677702    
#> 261: 0.431478    0.911550    3.422198    0.515085    0.106918    0.022019    0.677593    
#> 262: 0.431273    0.911695    3.422338    0.513785    0.106604    0.021986    0.677592    
#> 263: 0.431320    0.911911    3.422406    0.513635    0.106573    0.021986    0.677484    
#> 264: 0.431219    0.911965    3.422373    0.513580    0.106489    0.022049    0.677661    
#> 265: 0.431102    0.911967    3.422460    0.511966    0.106551    0.022099    0.677993    
#> 266: 0.431259    0.911872    3.422473    0.511198    0.106383    0.022120    0.678474    
#> 267: 0.431407    0.911500    3.422575    0.512471    0.106177    0.022129    0.678588    
#> 268: 0.431135    0.910979    3.422559    0.512184    0.106230    0.022120    0.678776    
#> 269: 0.431329    0.910733    3.422581    0.512318    0.106211    0.022115    0.678971    
#> 270: 0.431422    0.910840    3.422374    0.512586    0.105949    0.022114    0.678925    
#> 271: 0.431553    0.910870    3.422245    0.513148    0.105912    0.022090    0.678896    
#> 272: 0.431599    0.910839    3.422156    0.513689    0.105796    0.022083    0.679074    
#> 273: 0.431341    0.911254    3.422125    0.513636    0.105866    0.022029    0.679094    
#> 274: 0.431660    0.911675    3.422190    0.513883    0.106242    0.021990    0.679172    
#> 275: 0.432250    0.911697    3.422202    0.514400    0.106705    0.021919    0.679329    
#> 276: 0.432398    0.911845    3.422330    0.515467    0.106755    0.021872    0.679244    
#> 277: 0.431994    0.911865    3.422454    0.515217    0.106561    0.021838    0.679389    
#> 278: 0.432020    0.911830    3.422486    0.516002    0.106486    0.021871    0.679315    
#> 279: 0.431640    0.911745    3.422511    0.516574    0.106425    0.021905    0.679590    
#> 280: 0.431430    0.912050    3.422377    0.517134    0.106488    0.021936    0.679498    
#> 281: 0.431171    0.912169    3.422249    0.517263    0.106362    0.021917    0.679433    
#> 282: 0.431067    0.912418    3.422215    0.517206    0.106223    0.021906    0.679386    
#> 283: 0.431124    0.912489    3.422212    0.518560    0.106105    0.021981    0.679603    
#> 284: 0.431258    0.912415    3.422092    0.519616    0.106323    0.022003    0.679395    
#> 285: 0.431437    0.912578    3.421873    0.521048    0.106327    0.022045    0.679328    
#> 286: 0.431915    0.912761    3.421816    0.523138    0.106270    0.022049    0.679288    
#> 287: 0.431943    0.913089    3.421647    0.523874    0.106176    0.022044    0.679298    
#> 288: 0.432387    0.913159    3.421595    0.524886    0.106130    0.022058    0.679611    
#> 289: 0.432612    0.913057    3.421683    0.524899    0.106183    0.022023    0.679577    
#> 290: 0.433040    0.913085    3.421757    0.524752    0.106314    0.022013    0.679715    
#> 291: 0.433248    0.913350    3.421867    0.524282    0.106433    0.021990    0.679515    
#> 292: 0.432952    0.913295    3.421892    0.523519    0.106424    0.021975    0.679463    
#> 293: 0.432597    0.913522    3.421741    0.523357    0.106397    0.021981    0.679310    
#> 294: 0.432226    0.913748    3.421588    0.523728    0.106403    0.021995    0.679053    
#> 295: 0.431728    0.913844    3.421402    0.523333    0.106500    0.021948    0.678865    
#> 296: 0.431542    0.913822    3.421206    0.523434    0.106442    0.021925    0.678867    
#> 297: 0.431655    0.913817    3.421140    0.524501    0.106459    0.021918    0.678786    
#> 298: 0.431444    0.913835    3.421058    0.524344    0.106584    0.021889    0.678577    
#> 299: 0.431136    0.913955    3.420922    0.523952    0.106607    0.021892    0.678606    
#> 300: 0.431137    0.913864    3.420941    0.524486    0.106577    0.021928    0.678618    
#> 301: 0.431135    0.913801    3.420841    0.523925    0.106465    0.021935    0.678478    
#> 302: 0.430996    0.913760    3.420667    0.523919    0.106414    0.021956    0.678344    
#> 303: 0.430769    0.913817    3.420545    0.523592    0.106398    0.021952    0.678182    
#> 304: 0.430541    0.914087    3.420349    0.523015    0.106305    0.021951    0.678200    
#> 305: 0.430169    0.913938    3.420164    0.522467    0.106201    0.021938    0.678243    
#> 306: 0.429576    0.913918    3.419941    0.521774    0.106166    0.021882    0.678168    
#> 307: 0.428995    0.913901    3.419699    0.521651    0.106025    0.021846    0.678157    
#> 308: 0.428273    0.914022    3.419480    0.521260    0.106096    0.021821    0.678258    
#> 309: 0.428127    0.913916    3.419407    0.522130    0.106086    0.021826    0.678494    
#> 310: 0.427963    0.913886    3.419207    0.522503    0.106082    0.021801    0.678678    
#> 311: 0.427790    0.913992    3.419149    0.522975    0.106172    0.021788    0.678646    
#> 312: 0.427325    0.913957    3.418965    0.522621    0.106230    0.021752    0.678912    
#> 313: 0.427164    0.913833    3.418838    0.523339    0.106431    0.021747    0.678945    
#> 314: 0.426825    0.913825    3.418725    0.524204    0.106364    0.021795    0.678913    
#> 315: 0.426356    0.913994    3.418507    0.524360    0.106193    0.021875    0.678992    
#> 316: 0.426225    0.914188    3.418259    0.525084    0.106032    0.021906    0.679033    
#> 317: 0.425959    0.914285    3.418220    0.525066    0.105919    0.021962    0.679155    
#> 318: 0.426144    0.914488    3.418162    0.525572    0.106005    0.021988    0.678996    
#> 319: 0.426105    0.914492    3.418139    0.526088    0.106048    0.021995    0.679174    
#> 320: 0.425663    0.914386    3.418011    0.525786    0.106002    0.021993    0.679341    
#> 321: 0.425431    0.914575    3.417878    0.525617    0.106002    0.022001    0.679394    
#> 322: 0.425495    0.914588    3.417813    0.525532    0.106015    0.021973    0.679378    
#> 323: 0.425273    0.914734    3.417733    0.525511    0.105933    0.021970    0.679322    
#> 324: 0.425397    0.914851    3.417712    0.526057    0.105901    0.021958    0.679111    
#> 325: 0.425516    0.915012    3.417654    0.526530    0.105859    0.021973    0.679003    
#> 326: 0.425592    0.914837    3.417670    0.526863    0.105848    0.021986    0.679009    
#> 327: 0.425837    0.914677    3.417793    0.526694    0.105729    0.022016    0.678969    
#> 328: 0.425905    0.914690    3.417773    0.526906    0.105728    0.022006    0.678845    
#> 329: 0.426099    0.914639    3.417879    0.526563    0.105662    0.022014    0.678811    
#> 330: 0.426003    0.914666    3.417855    0.526304    0.105708    0.021991    0.678680    
#> 331: 0.426212    0.914769    3.417911    0.526160    0.105650    0.021943    0.678536    
#> 332: 0.426317    0.914837    3.417993    0.526015    0.105717    0.021946    0.678590    
#> 333: 0.425928    0.914855    3.417815    0.525847    0.105874    0.021919    0.678502    
#> 334: 0.425561    0.914790    3.417611    0.525615    0.105953    0.021900    0.678486    
#> 335: 0.425280    0.915089    3.417493    0.525210    0.106045    0.021880    0.678442    
#> 336: 0.425193    0.915443    3.417375    0.524702    0.106109    0.021881    0.678305    
#> 337: 0.425007    0.915768    3.417189    0.524918    0.106146    0.021883    0.678196    
#> 338: 0.424911    0.915921    3.417191    0.524593    0.106129    0.021899    0.678199    
#> 339: 0.424650    0.916096    3.417127    0.524204    0.106046    0.021928    0.678147    
#> 340: 0.424575    0.915969    3.417102    0.524178    0.105982    0.021958    0.678023    
#> 341: 0.424462    0.915914    3.417117    0.524231    0.105885    0.021951    0.677912    
#> 342: 0.424221    0.915844    3.417091    0.524146    0.105749    0.021937    0.677749    
#> 343: 0.424130    0.915904    3.417096    0.523929    0.105619    0.021942    0.677670    
#> 344: 0.424189    0.916011    3.417086    0.523881    0.105673    0.021938    0.677692    
#> 345: 0.424090    0.915966    3.417087    0.524063    0.105684    0.021930    0.677621    
#> 346: 0.424013    0.916034    3.416964    0.524249    0.105603    0.021929    0.677583    
#> 347: 0.423900    0.915972    3.416842    0.524524    0.105506    0.021941    0.677576    
#> 348: 0.423440    0.916080    3.416731    0.523858    0.105423    0.021953    0.677628    
#> 349: 0.423287    0.916091    3.416637    0.524168    0.105419    0.021967    0.677499    
#> 350: 0.423207    0.916021    3.416553    0.524522    0.105368    0.021975    0.677489    
#> 351: 0.423244    0.916192    3.416474    0.524822    0.105389    0.021984    0.677542    
#> 352: 0.423090    0.916347    3.416451    0.524818    0.105373    0.022006    0.677705    
#> 353: 0.423459    0.916515    3.416466    0.524644    0.105556    0.022000    0.677835    
#> 354: 0.423435    0.916574    3.416397    0.524561    0.105737    0.022003    0.677910    
#> 355: 0.423549    0.916497    3.416426    0.524306    0.105910    0.022006    0.678030    
#> 356: 0.423724    0.916519    3.416426    0.525579    0.105916    0.022042    0.678010    
#> 357: 0.423977    0.916506    3.416409    0.526193    0.105935    0.022029    0.677968    
#> 358: 0.424065    0.916587    3.416413    0.526692    0.106008    0.022043    0.677886    
#> 359: 0.424182    0.916751    3.416385    0.527274    0.106090    0.022078    0.677757    
#> 360: 0.424276    0.916799    3.416399    0.527345    0.106035    0.022100    0.677624    
#> 361: 0.424258    0.916911    3.416357    0.527350    0.106049    0.022103    0.677525    
#> 362: 0.424186    0.916876    3.416338    0.527213    0.106039    0.022089    0.677349    
#> 363: 0.424177    0.916863    3.416351    0.526941    0.106013    0.022121    0.677104    
#> 364: 0.424245    0.916854    3.416339    0.526791    0.105900    0.022157    0.677066    
#> 365: 0.424492    0.916767    3.416436    0.526807    0.105837    0.022196    0.676970    
#> 366: 0.424642    0.916644    3.416454    0.526673    0.105729    0.022195    0.677001    
#> 367: 0.424656    0.916530    3.416473    0.527012    0.105647    0.022199    0.676946    
#> 368: 0.424841    0.916526    3.416468    0.528305    0.105657    0.022182    0.676864    
#> 369: 0.424907    0.916400    3.416503    0.528451    0.105655    0.022185    0.676886    
#> 370: 0.424822    0.916415    3.416479    0.528265    0.105651    0.022194    0.676768    
#> 371: 0.424931    0.916467    3.416477    0.528387    0.105573    0.022200    0.676614    
#> 372: 0.424888    0.916519    3.416450    0.529072    0.105556    0.022213    0.676509    
#> 373: 0.424762    0.916728    3.416400    0.529590    0.105678    0.022221    0.676398    
#> 374: 0.424816    0.916678    3.416351    0.529980    0.105748    0.022207    0.676328    
#> 375: 0.424730    0.916702    3.416344    0.530037    0.105846    0.022185    0.676393    
#> 376: 0.424479    0.916680    3.416318    0.529478    0.105892    0.022151    0.676472    
#> 377: 0.424435    0.916682    3.416316    0.529560    0.105890    0.022147    0.676461    
#> 378: 0.424300    0.916778    3.416285    0.529670    0.105921    0.022135    0.676558    
#> 379: 0.423937    0.916757    3.416229    0.529363    0.105925    0.022137    0.676557    
#> 380: 0.423600    0.916750    3.416202    0.529040    0.105984    0.022114    0.676607    
#> 381: 0.423317    0.916690    3.416140    0.528901    0.105909    0.022100    0.676690    
#> 382: 0.423215    0.916757    3.416060    0.529362    0.105836    0.022116    0.676570    
#> 383: 0.423242    0.916876    3.416032    0.529327    0.105811    0.022119    0.676508    
#> 384: 0.423007    0.916919    3.415990    0.529001    0.105750    0.022112    0.676409    
#> 385: 0.422937    0.916958    3.415962    0.528748    0.105790    0.022101    0.676365    
#> 386: 0.422998    0.917154    3.415981    0.528465    0.105949    0.022081    0.676326    
#> 387: 0.423131    0.917228    3.416047    0.528480    0.105960    0.022077    0.676306    
#> 388: 0.423297    0.917226    3.416109    0.528765    0.106011    0.022066    0.676264    
#> 389: 0.423453    0.917017    3.416129    0.529221    0.106141    0.022061    0.676352    
#> 390: 0.423413    0.916986    3.416134    0.529379    0.106141    0.022053    0.676303    
#> 391: 0.423495    0.916947    3.416126    0.529318    0.106151    0.022064    0.676202    
#> 392: 0.423646    0.916949    3.416197    0.529659    0.106186    0.022089    0.676035    
#> 393: 0.423716    0.916825    3.416213    0.529903    0.106197    0.022097    0.675958    
#> 394: 0.423865    0.916707    3.416198    0.530482    0.106199    0.022109    0.675924    
#> 395: 0.424139    0.916708    3.416185    0.531508    0.106167    0.022108    0.675931    
#> 396: 0.424450    0.916725    3.416220    0.532066    0.106094    0.022119    0.675894    
#> 397: 0.424720    0.916678    3.416285    0.532301    0.106047    0.022123    0.675898    
#> 398: 0.424869    0.916622    3.416362    0.532680    0.105996    0.022120    0.675927    
#> 399: 0.424858    0.916531    3.416405    0.532499    0.105955    0.022109    0.675975    
#> 400: 0.425036    0.916524    3.416463    0.532266    0.105942    0.022105    0.676038    
#> 401: 0.425132    0.916609    3.416480    0.532077    0.105977    0.022078    0.676078    
#> 402: 0.425278    0.916651    3.416515    0.531564    0.106013    0.022050    0.676169    
#> 403: 0.425402    0.916626    3.416530    0.531180    0.106040    0.022029    0.676223    
#> 404: 0.425208    0.916614    3.416449    0.530896    0.106154    0.022012    0.676254    
#> 405: 0.425063    0.916696    3.416406    0.530836    0.106267    0.021995    0.676301    
#> 406: 0.424950    0.916771    3.416323    0.530900    0.106325    0.022001    0.676399    
#> 407: 0.425004    0.916805    3.416373    0.530812    0.106324    0.022024    0.676369    
#> 408: 0.425099    0.916926    3.416390    0.530667    0.106241    0.022040    0.676348    
#> 409: 0.425037    0.916866    3.416360    0.530392    0.106245    0.022034    0.676347    
#> 410: 0.424947    0.916889    3.416327    0.530321    0.106303    0.022040    0.676390    
#> 411: 0.424821    0.916733    3.416364    0.529748    0.106335    0.022041    0.676396    
#> 412: 0.424812    0.916711    3.416411    0.529578    0.106258    0.022060    0.676377    
#> 413: 0.424856    0.916771    3.416413    0.529539    0.106243    0.022056    0.676318    
#> 414: 0.424785    0.916774    3.416456    0.529271    0.106226    0.022092    0.676266    
#> 415: 0.424854    0.916765    3.416445    0.529315    0.106230    0.022107    0.676190    
#> 416: 0.424984    0.916821    3.416497    0.529643    0.106210    0.022111    0.676184    
#> 417: 0.425297    0.916761    3.416594    0.529698    0.106190    0.022125    0.676093    
#> 418: 0.425390    0.916706    3.416672    0.529808    0.106142    0.022132    0.675971    
#> 419: 0.425521    0.916704    3.416684    0.530219    0.106078    0.022141    0.675941    
#> 420: 0.425712    0.916739    3.416726    0.530386    0.106023    0.022153    0.675797    
#> 421: 0.425778    0.916832    3.416759    0.530332    0.106058    0.022165    0.675692    
#> 422: 0.425869    0.916814    3.416798    0.530142    0.106096    0.022166    0.675604    
#> 423: 0.426199    0.916697    3.416873    0.530544    0.106065    0.022190    0.675561    
#> 424: 0.426282    0.916633    3.416876    0.530911    0.106085    0.022209    0.675509    
#> 425: 0.426369    0.916710    3.416863    0.531481    0.106125    0.022225    0.675529    
#> 426: 0.426431    0.916725    3.416834    0.531873    0.106110    0.022230    0.675500    
#> 427: 0.426507    0.916684    3.416889    0.531802    0.106082    0.022262    0.675443    
#> 428: 0.426400    0.916724    3.416934    0.531509    0.106045    0.022280    0.675463    
#> 429: 0.426492    0.916741    3.416981    0.531262    0.105989    0.022280    0.675473    
#> 430: 0.426565    0.916690    3.417044    0.530884    0.106003    0.022294    0.675459    
#> 431: 0.426600    0.916528    3.417100    0.530548    0.105933    0.022285    0.675372    
#> 432: 0.426740    0.916440    3.417170    0.530507    0.105852    0.022289    0.675270    
#> 433: 0.426934    0.916411    3.417222    0.530585    0.105930    0.022295    0.675215    
#> 434: 0.426913    0.916277    3.417235    0.530408    0.105916    0.022292    0.675124    
#> 435: 0.426990    0.916241    3.417250    0.530388    0.105894    0.022295    0.675067    
#> 436: 0.427133    0.916229    3.417317    0.530460    0.105857    0.022287    0.675085    
#> 437: 0.427211    0.916176    3.417369    0.530165    0.105805    0.022287    0.675026    
#> 438: 0.427148    0.916286    3.417374    0.530060    0.105839    0.022260    0.674973    
#> 439: 0.427258    0.916347    3.417401    0.530157    0.105833    0.022248    0.674933    
#> 440: 0.427339    0.916415    3.417441    0.530057    0.105911    0.022223    0.674951    
#> 441: 0.427480    0.916373    3.417481    0.529861    0.106004    0.022204    0.674885    
#> 442: 0.427501    0.916318    3.417585    0.529407    0.105975    0.022196    0.674853    
#> 443: 0.427537    0.916301    3.417593    0.529161    0.105952    0.022200    0.674854    
#> 444: 0.427536    0.916364    3.417547    0.529300    0.105946    0.022199    0.674786    
#> 445: 0.427470    0.916397    3.417548    0.529198    0.105991    0.022198    0.674713    
#> 446: 0.427307    0.916486    3.417518    0.529090    0.106063    0.022190    0.674634    
#> 447: 0.427296    0.916586    3.417501    0.529116    0.106110    0.022177    0.674588    
#> 448: 0.427173    0.916577    3.417502    0.528903    0.106102    0.022161    0.674508    
#> 449: 0.427194    0.916617    3.417580    0.528632    0.106137    0.022133    0.674558    
#> 450: 0.427342    0.916569    3.417622    0.528408    0.106141    0.022100    0.674535    
#> 451: 0.427444    0.916516    3.417662    0.528154    0.106177    0.022081    0.674528    
#> 452: 0.427434    0.916498    3.417702    0.527922    0.106206    0.022063    0.674513    
#> 453: 0.427415    0.916480    3.417721    0.527578    0.106258    0.022044    0.674446    
#> 454: 0.427509    0.916578    3.417723    0.527641    0.106303    0.022015    0.674427    
#> 455: 0.427597    0.916642    3.417750    0.527809    0.106388    0.021995    0.674389    
#> 456: 0.427623    0.916583    3.417782    0.527744    0.106469    0.021976    0.674386    
#> 457: 0.427675    0.916523    3.417836    0.527505    0.106509    0.021963    0.674348    
#> 458: 0.427789    0.916592    3.417919    0.527212    0.106521    0.021967    0.674315    
#> 459: 0.427755    0.916626    3.417971    0.527053    0.106586    0.021973    0.674286    
#> 460: 0.427833    0.916530    3.418002    0.526915    0.106609    0.021976    0.674329    
#> 461: 0.427824    0.916476    3.418059    0.526632    0.106640    0.021968    0.674265    
#> 462: 0.427868    0.916449    3.418113    0.526533    0.106656    0.021959    0.674224    
#> 463: 0.427793    0.916512    3.418145    0.526523    0.106639    0.021952    0.674187    
#> 464: 0.427857    0.916568    3.418117    0.526598    0.106618    0.021941    0.674181    
#> 465: 0.427832    0.916516    3.418107    0.526360    0.106584    0.021932    0.674201    
#> 466: 0.427965    0.916524    3.418098    0.526943    0.106574    0.021913    0.674168    
#> 467: 0.428013    0.916397    3.418139    0.527294    0.106562    0.021909    0.674121    
#> 468: 0.428173    0.916379    3.418164    0.527587    0.106627    0.021894    0.674038    
#> 469: 0.428227    0.916487    3.418174    0.527418    0.106683    0.021876    0.674121    
#> 470: 0.428188    0.916588    3.418105    0.527667    0.106684    0.021867    0.674066    
#> 471: 0.428103    0.916578    3.418058    0.527638    0.106722    0.021856    0.674052    
#> 472: 0.428026    0.916539    3.418048    0.527604    0.106734    0.021849    0.673998    
#> 473: 0.428024    0.916571    3.418021    0.527514    0.106713    0.021858    0.673934    
#> 474: 0.427925    0.916575    3.417996    0.527492    0.106668    0.021861    0.673919    
#> 475: 0.428053    0.916623    3.417999    0.527573    0.106643    0.021867    0.673890    
#> 476: 0.428000    0.916623    3.417977    0.527446    0.106684    0.021855    0.673895    
#> 477: 0.427932    0.916601    3.417971    0.527464    0.106720    0.021843    0.673798    
#> 478: 0.427772    0.916614    3.417931    0.527315    0.106788    0.021824    0.673791    
#> 479: 0.427716    0.916665    3.417903    0.527042    0.106871    0.021808    0.673763    
#> 480: 0.427717    0.916661    3.417868    0.527305    0.106854    0.021807    0.673782    
#> 481: 0.427654    0.916671    3.417849    0.527375    0.106872    0.021800    0.673765    
#> 482: 0.427775    0.916659    3.417800    0.527525    0.106822    0.021793    0.673822    
#> 483: 0.427621    0.916527    3.417806    0.527333    0.106749    0.021796    0.673877    
#> 484: 0.427570    0.916362    3.417812    0.527139    0.106748    0.021794    0.673929    
#> 485: 0.427570    0.916328    3.417819    0.527127    0.106735    0.021808    0.673963    
#> 486: 0.427635    0.916300    3.417868    0.527213    0.106745    0.021828    0.673995    
#> 487: 0.427768    0.916265    3.417942    0.527293    0.106665    0.021852    0.673992    
#> 488: 0.427832    0.916276    3.417957    0.527404    0.106605    0.021893    0.673930    
#> 489: 0.428010    0.916258    3.417951    0.527685    0.106554    0.021926    0.673913    
#> 490: 0.428051    0.916268    3.417956    0.528113    0.106490    0.021951    0.673918    
#> 491: 0.428118    0.916384    3.417971    0.528402    0.106473    0.021965    0.673964    
#> 492: 0.428058    0.916518    3.417935    0.528583    0.106467    0.021982    0.674045    
#> 493: 0.427957    0.916519    3.417920    0.528781    0.106505    0.021977    0.674042    
#> 494: 0.428119    0.916530    3.417922    0.529067    0.106491    0.021976    0.674013    
#> 495: 0.428279    0.916495    3.417949    0.529189    0.106462    0.021991    0.674000    
#> 496: 0.428507    0.916539    3.417953    0.529550    0.106403    0.022006    0.674003    
#> 497: 0.428422    0.916492    3.417956    0.529552    0.106433    0.022014    0.673976    
#> 498: 0.428325    0.916477    3.417930    0.529336    0.106464    0.022002    0.673976    
#> 499: 0.428284    0.916515    3.417892    0.529311    0.106458    0.021992    0.673968    
#> 500: 0.428306    0.916477    3.417863    0.529340    0.106459    0.021978    0.673964    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.322457    0.982109    3.451262    0.392401    0.076704    0.016800    1.805401    
#> 002: 0.361415    1.011057    3.458680    0.372781    0.072869    0.018130    1.230261    
#> 003: 0.476546    0.961234    3.474099    0.354142    0.098343    0.017224    0.941647    
#> 004: 0.468442    0.956620    3.471669    0.336435    0.101171    0.016362    0.819754    
#> 005: 0.501587    0.978805    3.475839    0.319613    0.108228    0.015544    0.751703    
#> 006: 0.449482    0.986632    3.456615    0.303633    0.117418    0.015734    0.708409    
#> 007: 0.425482    0.990324    3.453668    0.288451    0.113671    0.014948    0.742954    
#> 008: 0.432616    0.977599    3.448333    0.274029    0.126283    0.017818    0.735740    
#> 009: 0.425238    0.959608    3.461081    0.260327    0.119969    0.016927    0.733899    
#> 010: 0.437463    0.960927    3.464484    0.247311    0.135919    0.022301    0.715983    
#> 011: 0.501990    0.973899    3.468604    0.263142    0.129123    0.021581    0.724596    
#> 012: 0.483057    0.981192    3.465632    0.249985    0.122667    0.020502    0.712119    
#> 013: 0.419340    0.984162    3.454196    0.237486    0.116533    0.019930    0.713964    
#> 014: 0.462465    0.997795    3.456585    0.225611    0.127487    0.018933    0.741189    
#> 015: 0.482442    0.999858    3.464460    0.222249    0.121112    0.018007    0.700781    
#> 016: 0.479643    1.000610    3.472530    0.211137    0.131716    0.017107    0.703492    
#> 017: 0.470645    0.997592    3.469775    0.202330    0.129215    0.020052    0.689325    
#> 018: 0.468075    1.005957    3.467053    0.227673    0.129507    0.024680    0.679695    
#> 019: 0.439947    0.986293    3.454147    0.218224    0.123032    0.023576    0.685041    
#> 020: 0.463397    1.002794    3.465679    0.207313    0.116880    0.022398    0.683348    
#> 021: 0.462577    0.984939    3.468362    0.204128    0.120920    0.021278    0.671411    
#> 022: 0.446029    1.018933    3.472072    0.205216    0.121852    0.021231    0.677509    
#> 023: 0.509401    0.996514    3.477448    0.238741    0.115759    0.021285    0.705495    
#> 024: 0.506920    0.997529    3.475051    0.226804    0.109971    0.022064    0.702706    
#> 025: 0.480836    0.985046    3.464048    0.215464    0.104472    0.022776    0.701909    
#> 026: 0.462581    1.007071    3.462534    0.204691    0.099249    0.021637    0.712719    
#> 027: 0.451937    1.007375    3.460262    0.194456    0.111372    0.021359    0.725574    
#> 028: 0.486035    1.002888    3.474462    0.191365    0.105803    0.022942    0.705753    
#> 029: 0.479527    0.994197    3.460466    0.220348    0.103349    0.024934    0.707153    
#> 030: 0.487098    1.014894    3.463598    0.209331    0.105158    0.023688    0.696443    
#> 031: 0.427242    0.993610    3.458811    0.198864    0.116350    0.023246    0.688799    
#> 032: 0.453229    0.965037    3.479609    0.237296    0.110532    0.027161    0.673988    
#> 033: 0.446504    0.989209    3.475023    0.225431    0.109163    0.028781    0.698807    
#> 034: 0.477599    0.995955    3.474670    0.214159    0.105280    0.027342    0.696456    
#> 035: 0.474240    0.956868    3.471945    0.203451    0.100016    0.025975    0.688075    
#> 036: 0.513046    0.980403    3.483405    0.258559    0.140404    0.024676    0.672844    
#> 037: 0.500942    0.991517    3.479233    0.263877    0.146962    0.023442    0.685251    
#> 038: 0.484235    0.999745    3.460308    0.250683    0.139613    0.025372    0.691175    
#> 039: 0.478619    1.009244    3.461354    0.238149    0.137995    0.024103    0.685199    
#> 040: 0.453695    1.004448    3.486901    0.226241    0.131648    0.024479    0.726068    
#> 041: 0.470237    0.992836    3.481177    0.214929    0.125066    0.023255    0.707088    
#> 042: 0.517474    0.983547    3.477191    0.204183    0.118813    0.022092    0.703035    
#> 043: 0.454452    0.981072    3.460971    0.193973    0.128720    0.020988    0.709531    
#> 044: 0.428775    0.995835    3.460332    0.184275    0.125145    0.019938    0.697431    
#> 045: 0.418020    1.016025    3.448772    0.175061    0.123650    0.020134    0.705780    
#> 046: 0.429109    0.986692    3.460328    0.173917    0.146825    0.019127    0.700597    
#> 047: 0.463105    0.999991    3.461651    0.196961    0.139484    0.018171    0.703893    
#> 048: 0.473637    0.977037    3.469866    0.221403    0.132509    0.019872    0.720662    
#> 049: 0.459208    0.970565    3.479632    0.210333    0.125884    0.023455    0.710940    
#> 050: 0.515797    0.959302    3.486794    0.199816    0.119590    0.023363    0.756703    
#> 051: 0.491899    0.992721    3.469810    0.206745    0.147759    0.022195    0.718816    
#> 052: 0.460607    0.986723    3.473929    0.196408    0.140371    0.021085    0.704166    
#> 053: 0.463466    0.983404    3.461654    0.214853    0.133353    0.020031    0.693484    
#> 054: 0.411659    0.987693    3.459985    0.225073    0.126685    0.019029    0.699942    
#> 055: 0.436942    0.996050    3.460760    0.229632    0.120351    0.018078    0.721812    
#> 056: 0.441230    0.985536    3.458823    0.218151    0.137889    0.019911    0.711236    
#> 057: 0.478316    0.970937    3.477263    0.221155    0.130995    0.018915    0.748028    
#> 058: 0.484447    0.970368    3.477890    0.210098    0.124445    0.021854    0.717996    
#> 059: 0.471573    0.948906    3.476446    0.203091    0.130589    0.023590    0.722788    
#> 060: 0.456477    0.957354    3.471479    0.216129    0.124059    0.024646    0.727321    
#> 061: 0.493603    0.992558    3.471417    0.226282    0.121919    0.023414    0.732832    
#> 062: 0.483542    0.996783    3.485885    0.214968    0.115823    0.022243    0.736347    
#> 063: 0.525502    0.946707    3.495055    0.206715    0.118116    0.023419    0.717028    
#> 064: 0.506450    0.971576    3.483883    0.203924    0.112210    0.024050    0.711682    
#> 065: 0.506788    0.961160    3.467545    0.199282    0.108437    0.024918    0.706498    
#> 066: 0.490637    0.990071    3.471289    0.207773    0.104303    0.025820    0.682383    
#> 067: 0.491565    0.978646    3.474090    0.197385    0.104863    0.024529    0.684951    
#> 068: 0.466552    0.978913    3.488381    0.216341    0.100293    0.027964    0.702846    
#> 069: 0.462406    0.982970    3.471236    0.206530    0.110613    0.033204    0.701947    
#> 070: 0.483641    0.975473    3.482116    0.212342    0.105082    0.031544    0.705201    
#> 071: 0.459535    0.992285    3.467321    0.201725    0.099828    0.029967    0.723369    
#> 072: 0.402750    0.966729    3.457802    0.193966    0.102583    0.028468    0.720989    
#> 073: 0.442202    0.985711    3.478534    0.184267    0.116663    0.027045    0.701760    
#> 074: 0.434299    0.958722    3.462545    0.221138    0.120706    0.025840    0.688337    
#> 075: 0.441204    0.948149    3.487566    0.210081    0.131929    0.025578    0.702534    
#> 076: 0.503417    0.956897    3.502552    0.231085    0.125332    0.028520    0.702117    
#> 077: 0.528806    0.941175    3.507598    0.241567    0.121022    0.027094    0.711555    
#> 078: 0.514194    0.960579    3.498382    0.229488    0.114971    0.025975    0.712421    
#> 079: 0.534863    0.975872    3.501069    0.218014    0.125549    0.025327    0.740528    
#> 080: 0.557771    0.966030    3.511520    0.207113    0.135125    0.031706    0.725132    
#> 081: 0.545519    0.955240    3.505249    0.196758    0.128369    0.035643    0.710778    
#> 082: 0.517518    0.933450    3.503531    0.197487    0.121951    0.035943    0.704640    
#> 083: 0.516621    0.969703    3.495427    0.188837    0.115853    0.034813    0.698031    
#> 084: 0.499417    0.975382    3.478622    0.179395    0.110060    0.033072    0.685962    
#> 085: 0.490675    0.987901    3.489749    0.206583    0.107185    0.031419    0.707679    
#> 086: 0.479473    0.987822    3.483839    0.209429    0.121092    0.029848    0.682546    
#> 087: 0.470022    0.990695    3.467637    0.203485    0.115038    0.028355    0.693830    
#> 088: 0.406950    0.998853    3.464938    0.198195    0.124525    0.026937    0.706267    
#> 089: 0.444610    1.021045    3.446215    0.212288    0.118299    0.025591    0.696335    
#> 090: 0.433816    0.994644    3.450553    0.201674    0.117503    0.024311    0.700311    
#> 091: 0.417827    0.999209    3.435336    0.212458    0.111628    0.023096    0.679044    
#> 092: 0.433366    1.006449    3.450475    0.201835    0.139292    0.021941    0.683723    
#> 093: 0.404011    0.983861    3.456097    0.219213    0.132327    0.020964    0.700647    
#> 094: 0.427648    1.005455    3.441836    0.260052    0.127911    0.019916    0.690405    
#> 095: 0.397517    1.013585    3.446279    0.247050    0.133694    0.019204    0.702542    
#> 096: 0.391683    1.009049    3.444905    0.234697    0.134824    0.019124    0.692658    
#> 097: 0.411676    1.020539    3.437880    0.264135    0.128083    0.018168    0.689557    
#> 098: 0.383946    1.050530    3.436719    0.270218    0.139883    0.017260    0.700753    
#> 099: 0.381145    1.013500    3.431950    0.256707    0.132889    0.016397    0.691594    
#> 100: 0.410979    1.009190    3.438272    0.248317    0.126244    0.017805    0.685798    
#> 101: 0.386390    0.993397    3.423565    0.235901    0.130151    0.016915    0.705922    
#> 102: 0.393351    1.011645    3.417860    0.224106    0.124238    0.016996    0.726994    
#> 103: 0.435017    1.016974    3.438119    0.284197    0.118026    0.019635    0.687771    
#> 104: 0.416911    1.005984    3.451973    0.274627    0.127445    0.021384    0.688067    
#> 105: 0.440161    0.986461    3.457255    0.260896    0.121073    0.020315    0.691645    
#> 106: 0.447368    1.004321    3.453612    0.247851    0.118070    0.020814    0.688097    
#> 107: 0.483998    0.996517    3.469158    0.242166    0.123432    0.023739    0.710871    
#> 108: 0.493443    0.990516    3.476611    0.230058    0.117260    0.026389    0.693360    
#> 109: 0.473648    0.988088    3.479917    0.222786    0.111397    0.028358    0.692277    
#> 110: 0.456898    0.980996    3.462928    0.236687    0.105827    0.027424    0.668257    
#> 111: 0.477974    0.995016    3.467045    0.224853    0.104297    0.026053    0.685942    
#> 112: 0.437999    0.968301    3.454138    0.262909    0.099083    0.026377    0.692609    
#> 113: 0.455561    1.004800    3.462625    0.262832    0.106114    0.025058    0.682428    
#> 114: 0.445534    0.997157    3.465433    0.249691    0.115274    0.024661    0.702591    
#> 115: 0.415273    0.979119    3.456728    0.237206    0.109511    0.023428    0.734396    
#> 116: 0.449249    1.006830    3.449624    0.225346    0.122064    0.024781    0.707259    
#> 117: 0.433881    1.011338    3.466037    0.223958    0.116899    0.023542    0.712084    
#> 118: 0.474794    0.983954    3.466330    0.224932    0.118272    0.022364    0.709309    
#> 119: 0.438572    0.988576    3.465398    0.213685    0.115501    0.027949    0.716744    
#> 120: 0.433095    0.958661    3.470418    0.220959    0.109726    0.026551    0.701197    
#> 121: 0.457236    0.997300    3.467364    0.209911    0.104239    0.025224    0.703145    
#> 122: 0.480275    0.962517    3.475488    0.225184    0.120299    0.023963    0.688519    
#> 123: 0.488854    0.996587    3.466182    0.213925    0.114284    0.022764    0.697613    
#> 124: 0.482692    1.027018    3.467738    0.203229    0.124159    0.022395    0.685980    
#> 125: 0.467970    1.004504    3.465195    0.193067    0.117951    0.021275    0.704220    
#> 126: 0.439787    1.027565    3.447900    0.225481    0.112054    0.021173    0.704493    
#> 127: 0.456271    0.998427    3.456570    0.228897    0.106451    0.020115    0.705097    
#> 128: 0.419368    1.008230    3.459730    0.218625    0.110978    0.021361    0.703643    
#> 129: 0.475289    1.020782    3.467345    0.229518    0.129414    0.020293    0.712389    
#> 130: 0.497598    1.010234    3.464463    0.218042    0.123976    0.019278    0.707423    
#> 131: 0.448463    1.011120    3.443524    0.207140    0.134997    0.018314    0.702301    
#> 132: 0.403631    1.011775    3.436461    0.199490    0.128247    0.017399    0.692355    
#> 133: 0.422638    0.999287    3.451311    0.204025    0.121835    0.016847    0.705262    
#> 134: 0.475474    0.984851    3.466518    0.193824    0.139056    0.017452    0.697038    
#> 135: 0.447713    0.980640    3.470910    0.200457    0.132104    0.020648    0.683461    
#> 136: 0.450673    0.972051    3.467808    0.190434    0.125498    0.019616    0.684969    
#> 137: 0.472284    0.979203    3.468497    0.202405    0.125761    0.018635    0.679599    
#> 138: 0.442482    1.005456    3.469924    0.192285    0.119473    0.017703    0.698233    
#> 139: 0.469561    0.979004    3.478758    0.216741    0.113499    0.019984    0.706971    
#> 140: 0.457451    0.993027    3.472267    0.233514    0.122815    0.024234    0.698020    
#> 141: 0.460991    0.973099    3.470265    0.234134    0.124473    0.025181    0.690747    
#> 142: 0.468986    0.983169    3.478581    0.222428    0.118963    0.028656    0.701416    
#> 143: 0.463954    0.999658    3.481691    0.211306    0.113015    0.027223    0.702791    
#> 144: 0.509127    0.986903    3.499691    0.237359    0.110062    0.026619    0.696878    
#> 145: 0.477678    0.997170    3.467492    0.233788    0.109480    0.025288    0.682906    
#> 146: 0.435691    1.012581    3.468323    0.222098    0.115997    0.024172    0.701687    
#> 147: 0.431594    0.980442    3.455883    0.210993    0.115799    0.022963    0.703513    
#> 148: 0.417936    1.008946    3.461271    0.231537    0.110009    0.028682    0.701554    
#> 149: 0.424689    0.994562    3.449295    0.263437    0.107804    0.028780    0.686582    
#> 150: 0.476755    0.988946    3.446220    0.271682    0.102413    0.032248    0.697174    
#> 151: 0.451199    1.027497    3.459019    0.276807    0.098534    0.030635    0.690999    
#> 152: 0.430476    1.013883    3.456784    0.243275    0.109628    0.027856    0.680689    
#> 153: 0.440064    0.995013    3.476802    0.256573    0.094679    0.035381    0.694486    
#> 154: 0.454151    1.010992    3.468514    0.259777    0.097572    0.034647    0.687412    
#> 155: 0.443419    0.989072    3.461020    0.250152    0.093426    0.038505    0.691767    
#> 156: 0.449323    0.987994    3.462154    0.262664    0.122132    0.036951    0.697966    
#> 157: 0.452832    0.988657    3.473530    0.275793    0.107342    0.038308    0.691757    
#> 158: 0.486250    1.015167    3.464203    0.257068    0.105703    0.030790    0.692078    
#> 159: 0.430696    1.017104    3.470670    0.225753    0.106355    0.029096    0.708865    
#> 160: 0.462328    0.983192    3.479575    0.261514    0.112281    0.029144    0.695114    
#> 161: 0.456065    0.978302    3.466724    0.255998    0.118205    0.028132    0.709215    
#> 162: 0.456551    0.984189    3.459036    0.241809    0.128025    0.023093    0.710505    
#> 163: 0.464826    0.984723    3.451829    0.250071    0.142540    0.027174    0.704181    
#> 164: 0.470781    0.986706    3.459543    0.250333    0.129517    0.022222    0.701195    
#> 165: 0.481625    0.974317    3.461420    0.224255    0.123384    0.017960    0.715755    
#> 166: 0.495585    1.014865    3.474220    0.245843    0.122504    0.020916    0.696227    
#> 167: 0.473967    1.006435    3.479593    0.238179    0.125332    0.025667    0.697085    
#> 168: 0.479142    1.003474    3.468870    0.227721    0.120411    0.024099    0.678986    
#> 169: 0.465760    1.020377    3.459698    0.197430    0.125036    0.018408    0.699778    
#> 170: 0.461191    0.995308    3.460433    0.218713    0.126878    0.019289    0.680691    
#> 171: 0.433736    0.991939    3.449924    0.194625    0.107983    0.019329    0.686690    
#> 172: 0.408134    1.018388    3.451783    0.184512    0.094649    0.021286    0.697110    
#> 173: 0.434183    1.023645    3.449753    0.191879    0.099507    0.025841    0.679326    
#> 174: 0.431305    0.997311    3.455895    0.201021    0.086335    0.022931    0.704021    
#> 175: 0.418120    1.006310    3.447390    0.200784    0.104284    0.024717    0.703998    
#> 176: 0.402759    1.040251    3.451724    0.195466    0.107230    0.026181    0.698417    
#> 177: 0.446021    1.012062    3.461230    0.219896    0.114273    0.023655    0.702654    
#> 178: 0.465452    0.988194    3.465736    0.223987    0.117600    0.019193    0.690504    
#> 179: 0.482804    1.010763    3.466265    0.224980    0.138096    0.022378    0.727908    
#> 180: 0.450844    0.979212    3.468377    0.237941    0.110553    0.022397    0.703092    
#> 181: 0.463361    0.963969    3.459852    0.204472    0.100741    0.020731    0.703191    
#> 182: 0.401915    0.993298    3.452406    0.218806    0.102213    0.021092    0.721724    
#> 183: 0.437251    0.992003    3.460068    0.211561    0.115887    0.020139    0.716837    
#> 184: 0.472016    0.989438    3.466890    0.273922    0.132574    0.021617    0.710497    
#> 185: 0.456052    1.011118    3.463576    0.240692    0.136030    0.019828    0.695616    
#> 186: 0.421523    1.005595    3.461543    0.217646    0.108450    0.021046    0.696490    
#> 187: 0.449681    0.998811    3.465066    0.235641    0.107872    0.021357    0.688846    
#> 188: 0.425018    1.029343    3.447252    0.240133    0.108924    0.024320    0.687770    
#> 189: 0.432942    1.016781    3.461197    0.229504    0.099913    0.022073    0.696189    
#> 190: 0.436918    1.007618    3.460728    0.212953    0.094923    0.019042    0.695799    
#> 191: 0.444661    1.027148    3.454960    0.218982    0.117773    0.019940    0.687252    
#> 192: 0.435325    1.031723    3.453308    0.193990    0.115748    0.020426    0.678418    
#> 193: 0.458579    1.018884    3.457007    0.204949    0.116173    0.023114    0.685714    
#> 194: 0.411593    1.013523    3.441295    0.228921    0.104481    0.024451    0.692188    
#> 195: 0.392071    1.023095    3.442678    0.228506    0.101818    0.027870    0.694707    
#> 196: 0.408037    1.002617    3.442434    0.294009    0.102315    0.026701    0.701093    
#> 197: 0.377678    1.019356    3.454089    0.250373    0.121234    0.025328    0.709666    
#> 198: 0.445895    0.989669    3.458386    0.226327    0.138932    0.025945    0.695434    
#> 199: 0.442814    0.990253    3.466361    0.200533    0.132402    0.029498    0.707442    
#> 200: 0.453380    0.993165    3.477198    0.203563    0.123214    0.030754    0.711828    
#> 201: 0.463262    0.992557    3.481012    0.188118    0.130666    0.032408    0.707991    
#> 202: 0.465407    0.995258    3.479308    0.193069    0.126364    0.030405    0.704018    
#> 203: 0.469602    0.995409    3.475157    0.187412    0.123896    0.029249    0.704620    
#> 204: 0.470776    0.991417    3.474878    0.189456    0.122141    0.027856    0.705747    
#> 205: 0.468522    0.996372    3.474373    0.192617    0.118695    0.027581    0.709028    
#> 206: 0.473927    0.999266    3.474705    0.200459    0.115512    0.027574    0.709666    
#> 207: 0.471548    1.001427    3.473084    0.195936    0.113305    0.028007    0.707508    
#> 208: 0.469897    1.003826    3.472088    0.196689    0.112075    0.028163    0.706207    
#> 209: 0.472591    1.001256    3.471201    0.198419    0.112814    0.027845    0.704668    
#> 210: 0.474380    0.998052    3.471780    0.196519    0.111862    0.027503    0.704695    
#> 211: 0.476380    0.997194    3.472581    0.194039    0.112529    0.027016    0.703328    
#> 212: 0.476712    0.996902    3.472453    0.192606    0.113527    0.026272    0.701983    
#> 213: 0.476758    0.994768    3.472450    0.192350    0.114971    0.025547    0.703476    
#> 214: 0.479187    0.992745    3.472990    0.191893    0.115726    0.024974    0.703889    
#> 215: 0.480047    0.991644    3.474586    0.192772    0.116806    0.024791    0.704011    
#> 216: 0.481507    0.989848    3.475235    0.195989    0.116976    0.024777    0.706243    
#> 217: 0.480588    0.990662    3.475198    0.195978    0.117761    0.024775    0.705171    
#> 218: 0.479185    0.990677    3.474649    0.196025    0.117633    0.024531    0.704461    
#> 219: 0.477759    0.989578    3.473674    0.197581    0.116720    0.024433    0.703699    
#> 220: 0.475631    0.990347    3.472689    0.197404    0.116442    0.024473    0.703131    
#> 221: 0.473551    0.990280    3.472356    0.198024    0.116442    0.024645    0.702564    
#> 222: 0.473230    0.990456    3.471653    0.200020    0.116351    0.024733    0.702603    
#> 223: 0.474138    0.989218    3.471647    0.201127    0.115976    0.024857    0.702536    
#> 224: 0.474370    0.988845    3.471380    0.202581    0.115276    0.025032    0.702457    
#> 225: 0.474309    0.987242    3.472043    0.203360    0.114616    0.025161    0.702656    
#> 226: 0.473458    0.986419    3.471610    0.205304    0.114533    0.025202    0.702769    
#> 227: 0.472610    0.986528    3.471594    0.206403    0.113478    0.025263    0.702725    
#> 228: 0.471739    0.987719    3.471087    0.206998    0.112993    0.025267    0.702456    
#> 229: 0.470919    0.988022    3.470663    0.208121    0.112370    0.025223    0.701883    
#> 230: 0.470896    0.987830    3.470450    0.208457    0.112097    0.025216    0.701284    
#> 231: 0.471225    0.987849    3.470661    0.208972    0.112024    0.025142    0.700890    
#> 232: 0.470237    0.987805    3.470673    0.209714    0.111907    0.025136    0.700683    
#> 233: 0.469779    0.987695    3.470505    0.210434    0.111763    0.025061    0.700340    
#> 234: 0.469075    0.987534    3.470276    0.210864    0.111588    0.025136    0.699867    
#> 235: 0.468552    0.987218    3.470058    0.211417    0.111672    0.025089    0.699652    
#> 236: 0.468863    0.987366    3.469944    0.211141    0.112262    0.025031    0.699936    
#> 237: 0.468830    0.987267    3.469975    0.211595    0.112026    0.025008    0.700523    
#> 238: 0.469021    0.986536    3.470237    0.211928    0.111744    0.025095    0.700807    
#> 239: 0.468907    0.987016    3.469933    0.211644    0.111765    0.025040    0.701225    
#> 240: 0.468310    0.986969    3.469802    0.210701    0.111490    0.025072    0.701089    
#> 241: 0.468783    0.986248    3.469846    0.210655    0.111528    0.025244    0.700817    
#> 242: 0.468787    0.985589    3.469974    0.210606    0.111558    0.025292    0.701142    
#> 243: 0.467637    0.985834    3.469691    0.210697    0.111567    0.025347    0.701142    
#> 244: 0.467250    0.986205    3.469723    0.212031    0.111393    0.025468    0.701126    
#> 245: 0.467331    0.985667    3.469895    0.212737    0.111403    0.025570    0.700942    
#> 246: 0.467551    0.985832    3.469884    0.213603    0.111460    0.025659    0.700639    
#> 247: 0.467100    0.986048    3.469915    0.214299    0.111583    0.025705    0.700497    
#> 248: 0.467360    0.986524    3.469787    0.214670    0.111491    0.025744    0.699952    
#> 249: 0.466759    0.986714    3.469817    0.214734    0.111513    0.025759    0.699578    
#> 250: 0.467664    0.986795    3.470026    0.215271    0.111722    0.025850    0.699473    
#> 251: 0.468271    0.987181    3.470246    0.217018    0.112296    0.025823    0.699398    
#> 252: 0.469178    0.987517    3.470680    0.217394    0.112009    0.025845    0.699544    
#> 253: 0.469459    0.987665    3.470825    0.217528    0.111814    0.025828    0.699671    
#> 254: 0.469800    0.988150    3.470774    0.217262    0.111533    0.025882    0.699785    
#> 255: 0.469368    0.988620    3.470555    0.217399    0.111274    0.025870    0.699794    
#> 256: 0.468500    0.988537    3.470289    0.217448    0.111021    0.025905    0.700001    
#> 257: 0.467973    0.988291    3.470299    0.217217    0.110967    0.025892    0.700130    
#> 258: 0.468123    0.988050    3.470472    0.216812    0.111018    0.025856    0.699804    
#> 259: 0.468084    0.987925    3.470401    0.216394    0.110893    0.025890    0.699763    
#> 260: 0.467934    0.987834    3.470482    0.216701    0.110856    0.025988    0.699226    
#> 261: 0.468361    0.987845    3.470636    0.217008    0.110971    0.026010    0.699131    
#> 262: 0.468627    0.987950    3.470737    0.217207    0.110948    0.026007    0.699163    
#> 263: 0.468149    0.988330    3.470659    0.216983    0.110950    0.025978    0.699408    
#> 264: 0.467938    0.988442    3.470635    0.216707    0.111076    0.025885    0.699780    
#> 265: 0.467766    0.988291    3.470632    0.216636    0.110846    0.025861    0.699997    
#> 266: 0.468011    0.988285    3.470685    0.216582    0.110823    0.025846    0.699974    
#> 267: 0.468241    0.988207    3.470856    0.216636    0.110659    0.025793    0.700252    
#> 268: 0.468328    0.988025    3.470784    0.216505    0.110849    0.025698    0.700331    
#> 269: 0.469287    0.987869    3.470871    0.216910    0.110982    0.025675    0.700345    
#> 270: 0.469444    0.988255    3.470848    0.217247    0.110947    0.025635    0.700092    
#> 271: 0.469338    0.988389    3.470708    0.216982    0.111073    0.025606    0.700380    
#> 272: 0.469261    0.987958    3.470834    0.217284    0.111463    0.025654    0.700786    
#> 273: 0.468729    0.987998    3.470873    0.217174    0.111389    0.025631    0.701098    
#> 274: 0.468598    0.987982    3.470920    0.217125    0.111267    0.025645    0.700823    
#> 275: 0.468092    0.987966    3.470560    0.216945    0.111091    0.025592    0.700789    
#> 276: 0.468155    0.988181    3.470471    0.216878    0.111011    0.025563    0.700817    
#> 277: 0.467838    0.988756    3.470476    0.216693    0.111056    0.025549    0.700769    
#> 278: 0.467937    0.988802    3.470592    0.216204    0.110795    0.025551    0.700628    
#> 279: 0.467723    0.988643    3.470571    0.215747    0.110451    0.025555    0.700806    
#> 280: 0.467502    0.989110    3.470528    0.215294    0.110404    0.025558    0.700627    
#> 281: 0.467050    0.989568    3.470516    0.215496    0.110510    0.025509    0.700423    
#> 282: 0.466968    0.989586    3.470470    0.216093    0.110575    0.025474    0.700646    
#> 283: 0.467036    0.989720    3.470427    0.216643    0.110862    0.025392    0.700810    
#> 284: 0.467148    0.989503    3.470494    0.216682    0.111081    0.025306    0.700788    
#> 285: 0.467422    0.989538    3.470372    0.217337    0.111413    0.025273    0.700731    
#> 286: 0.467503    0.989343    3.470302    0.217787    0.111632    0.025297    0.700630    
#> 287: 0.467540    0.989332    3.470176    0.218320    0.111600    0.025275    0.700437    
#> 288: 0.467609    0.989147    3.470183    0.218635    0.111536    0.025294    0.700437    
#> 289: 0.467774    0.989125    3.470148    0.218627    0.111534    0.025305    0.700539    
#> 290: 0.467937    0.989274    3.470110    0.218904    0.111773    0.025262    0.700542    
#> 291: 0.468093    0.989505    3.470151    0.219079    0.111849    0.025238    0.700318    
#> 292: 0.467702    0.989591    3.470076    0.219191    0.111929    0.025209    0.700159    
#> 293: 0.467433    0.989621    3.470011    0.219237    0.111732    0.025186    0.700115    
#> 294: 0.467089    0.989749    3.469862    0.219134    0.111695    0.025155    0.699914    
#> 295: 0.466849    0.989577    3.469841    0.219251    0.111758    0.025106    0.699833    
#> 296: 0.466777    0.989593    3.469866    0.219219    0.111835    0.025055    0.700089    
#> 297: 0.466636    0.989761    3.469797    0.219439    0.112084    0.025009    0.700018    
#> 298: 0.466715    0.989692    3.469812    0.219526    0.112261    0.024971    0.700023    
#> 299: 0.466626    0.989695    3.469754    0.219463    0.112553    0.024916    0.700066    
#> 300: 0.466782    0.989683    3.469813    0.219239    0.112606    0.024899    0.700017    
#> 301: 0.466818    0.989541    3.469743    0.219048    0.112633    0.024862    0.700035    
#> 302: 0.466938    0.989624    3.469690    0.219020    0.112555    0.024838    0.699723    
#> 303: 0.467035    0.989756    3.469701    0.218726    0.112501    0.024818    0.699493    
#> 304: 0.467255    0.990147    3.469732    0.218564    0.112473    0.024777    0.699389    
#> 305: 0.467193    0.990033    3.469691    0.218345    0.112486    0.024742    0.699213    
#> 306: 0.467042    0.990032    3.469694    0.218263    0.112349    0.024741    0.699259    
#> 307: 0.466963    0.989829    3.469634    0.218052    0.112173    0.024748    0.699290    
#> 308: 0.466632    0.989609    3.469537    0.218056    0.112029    0.024733    0.699583    
#> 309: 0.466414    0.989270    3.469500    0.217928    0.112111    0.024721    0.699854    
#> 310: 0.466354    0.989217    3.469402    0.217694    0.112119    0.024691    0.700226    
#> 311: 0.466434    0.989081    3.469451    0.217775    0.112043    0.024687    0.700256    
#> 312: 0.466586    0.988940    3.469449    0.218083    0.112072    0.024728    0.700186    
#> 313: 0.466646    0.988665    3.469446    0.218257    0.112026    0.024766    0.700173    
#> 314: 0.466629    0.988638    3.469413    0.217946    0.112005    0.024801    0.700127    
#> 315: 0.466513    0.988775    3.469377    0.217801    0.112126    0.024792    0.700069    
#> 316: 0.466359    0.988912    3.469300    0.217720    0.112151    0.024830    0.699908    
#> 317: 0.466318    0.988953    3.469289    0.217583    0.112235    0.024845    0.699874    
#> 318: 0.466336    0.989089    3.469181    0.217331    0.112198    0.024838    0.699784    
#> 319: 0.466198    0.989086    3.469166    0.217118    0.112047    0.024871    0.699737    
#> 320: 0.465849    0.988959    3.469056    0.217343    0.112035    0.024884    0.699827    
#> 321: 0.465644    0.989036    3.468924    0.217747    0.112095    0.024922    0.699953    
#> 322: 0.465538    0.989149    3.468813    0.218028    0.112048    0.024914    0.699929    
#> 323: 0.465081    0.989209    3.468689    0.218069    0.112089    0.024904    0.699842    
#> 324: 0.464548    0.989405    3.468518    0.218123    0.112004    0.024900    0.699749    
#> 325: 0.464128    0.989651    3.468344    0.217827    0.112003    0.024892    0.699694    
#> 326: 0.463902    0.989607    3.468219    0.217869    0.111807    0.024899    0.699631    
#> 327: 0.463886    0.989777    3.468142    0.217932    0.111626    0.024927    0.699708    
#> 328: 0.463783    0.989976    3.468071    0.217860    0.111633    0.024936    0.699606    
#> 329: 0.463893    0.989959    3.468048    0.217896    0.111629    0.024927    0.699511    
#> 330: 0.463680    0.989887    3.468059    0.218007    0.111595    0.024921    0.699423    
#> 331: 0.463789    0.989895    3.468117    0.217931    0.111637    0.024906    0.699465    
#> 332: 0.463908    0.990024    3.468247    0.217686    0.111740    0.024906    0.699585    
#> 333: 0.463831    0.990167    3.468148    0.217620    0.111798    0.024839    0.699616    
#> 334: 0.463582    0.990125    3.467995    0.217611    0.111911    0.024783    0.699589    
#> 335: 0.463347    0.990175    3.467884    0.217397    0.111859    0.024733    0.699585    
#> 336: 0.463203    0.990415    3.467851    0.217053    0.111828    0.024705    0.699625    
#> 337: 0.463111    0.990827    3.467837    0.216856    0.111918    0.024685    0.699737    
#> 338: 0.463233    0.990878    3.467905    0.216666    0.112105    0.024675    0.699713    
#> 339: 0.463191    0.991113    3.467825    0.216398    0.112287    0.024617    0.699649    
#> 340: 0.462985    0.991047    3.467743    0.216356    0.112428    0.024566    0.699601    
#> 341: 0.463082    0.991130    3.467721    0.216498    0.112565    0.024505    0.699580    
#> 342: 0.462877    0.991047    3.467657    0.216379    0.112557    0.024477    0.699542    
#> 343: 0.462600    0.991037    3.467596    0.216499    0.112521    0.024466    0.699427    
#> 344: 0.462644    0.991051    3.467619    0.216664    0.112578    0.024473    0.699330    
#> 345: 0.462567    0.991082    3.467661    0.216882    0.112553    0.024473    0.699303    
#> 346: 0.462371    0.991187    3.467516    0.217045    0.112692    0.024447    0.699181    
#> 347: 0.462311    0.991194    3.467425    0.217074    0.112869    0.024419    0.699249    
#> 348: 0.462057    0.991230    3.467305    0.217320    0.112872    0.024415    0.699250    
#> 349: 0.461796    0.991148    3.467219    0.217529    0.112880    0.024429    0.699237    
#> 350: 0.461714    0.990992    3.467127    0.217490    0.112951    0.024436    0.699163    
#> 351: 0.461738    0.991196    3.467053    0.217290    0.112969    0.024448    0.699260    
#> 352: 0.461480    0.991326    3.466983    0.217448    0.112929    0.024454    0.699410    
#> 353: 0.461464    0.991472    3.466919    0.217646    0.112991    0.024434    0.699565    
#> 354: 0.461337    0.991589    3.466764    0.217800    0.113004    0.024389    0.699568    
#> 355: 0.461572    0.991674    3.466697    0.217867    0.113202    0.024353    0.699631    
#> 356: 0.461452    0.991640    3.466680    0.217761    0.113245    0.024333    0.699888    
#> 357: 0.461514    0.991784    3.466643    0.217720    0.113209    0.024323    0.699855    
#> 358: 0.461544    0.991978    3.466597    0.217883    0.113221    0.024315    0.699722    
#> 359: 0.461343    0.992141    3.466504    0.218136    0.113164    0.024311    0.699688    
#> 360: 0.461158    0.992230    3.466325    0.218262    0.113107    0.024325    0.699527    
#> 361: 0.460873    0.992281    3.466169    0.218439    0.113079    0.024325    0.699447    
#> 362: 0.460687    0.992244    3.466092    0.218575    0.113071    0.024321    0.699254    
#> 363: 0.460564    0.992211    3.466078    0.218536    0.113101    0.024329    0.699032    
#> 364: 0.460596    0.992141    3.466092    0.218561    0.113156    0.024338    0.699131    
#> 365: 0.460624    0.992046    3.466105    0.218656    0.113173    0.024370    0.699155    
#> 366: 0.460614    0.992110    3.466041    0.219066    0.113118    0.024399    0.699152    
#> 367: 0.460539    0.992204    3.465974    0.219123    0.112958    0.024402    0.699187    
#> 368: 0.460553    0.992329    3.465894    0.219003    0.112970    0.024405    0.699160    
#> 369: 0.460474    0.992317    3.465845    0.218970    0.112919    0.024408    0.699141    
#> 370: 0.460401    0.992341    3.465827    0.218798    0.112889    0.024413    0.699108    
#> 371: 0.460199    0.992415    3.465750    0.218882    0.112876    0.024392    0.698933    
#> 372: 0.460133    0.992499    3.465684    0.219018    0.112809    0.024394    0.698858    
#> 373: 0.459940    0.992565    3.465664    0.219241    0.112664    0.024402    0.698816    
#> 374: 0.459978    0.992599    3.465582    0.219381    0.112564    0.024392    0.698804    
#> 375: 0.459832    0.992629    3.465562    0.219407    0.112392    0.024405    0.698827    
#> 376: 0.459746    0.992760    3.465546    0.219307    0.112256    0.024404    0.698831    
#> 377: 0.459525    0.992922    3.465480    0.219184    0.112184    0.024427    0.698846    
#> 378: 0.459192    0.993028    3.465385    0.219225    0.112142    0.024453    0.698868    
#> 379: 0.458956    0.993019    3.465332    0.219225    0.112106    0.024445    0.698903    
#> 380: 0.458619    0.993159    3.465287    0.219124    0.112135    0.024425    0.698906    
#> 381: 0.458380    0.993163    3.465215    0.219051    0.112153    0.024439    0.698924    
#> 382: 0.458303    0.993304    3.465158    0.219138    0.112080    0.024442    0.698902    
#> 383: 0.458348    0.993272    3.465146    0.219188    0.112002    0.024475    0.698802    
#> 384: 0.458141    0.993379    3.465118    0.219203    0.111892    0.024483    0.698806    
#> 385: 0.458022    0.993517    3.465050    0.219040    0.111874    0.024478    0.698814    
#> 386: 0.457958    0.993706    3.465024    0.218886    0.112013    0.024469    0.698785    
#> 387: 0.458183    0.993939    3.465119    0.218896    0.112099    0.024457    0.698794    
#> 388: 0.458370    0.994025    3.465152    0.218973    0.112113    0.024453    0.698870    
#> 389: 0.458374    0.993885    3.465118    0.219056    0.112212    0.024427    0.698982    
#> 390: 0.458171    0.993971    3.465033    0.219373    0.112295    0.024417    0.698929    
#> 391: 0.458148    0.993995    3.464990    0.219378    0.112325    0.024407    0.698892    
#> 392: 0.458131    0.993852    3.465061    0.219440    0.112274    0.024403    0.698885    
#> 393: 0.457916    0.993812    3.464976    0.219286    0.112250    0.024380    0.698834    
#> 394: 0.457740    0.993889    3.464876    0.219302    0.112192    0.024383    0.698820    
#> 395: 0.457801    0.994031    3.464809    0.219308    0.112246    0.024368    0.698833    
#> 396: 0.457989    0.994148    3.464778    0.219329    0.112226    0.024363    0.698688    
#> 397: 0.458114    0.994105    3.464813    0.219191    0.112251    0.024380    0.698671    
#> 398: 0.458332    0.994052    3.464924    0.219080    0.112307    0.024397    0.698728    
#> 399: 0.458521    0.993995    3.465054    0.218940    0.112329    0.024392    0.698656    
#> 400: 0.458604    0.993952    3.465114    0.218625    0.112252    0.024372    0.698753    
#> 401: 0.458655    0.994059    3.465122    0.218372    0.112259    0.024383    0.698799    
#> 402: 0.458619    0.994239    3.465161    0.218221    0.112336    0.024378    0.698859    
#> 403: 0.458791    0.994269    3.465183    0.218216    0.112376    0.024368    0.698861    
#> 404: 0.458830    0.994347    3.465121    0.218112    0.112467    0.024356    0.698830    
#> 405: 0.458853    0.994380    3.465141    0.218242    0.112484    0.024361    0.698815    
#> 406: 0.458909    0.994391    3.465126    0.218198    0.112459    0.024395    0.698802    
#> 407: 0.458924    0.994433    3.465168    0.218159    0.112508    0.024428    0.698721    
#> 408: 0.458948    0.994391    3.465200    0.218104    0.112514    0.024442    0.698724    
#> 409: 0.458811    0.994385    3.465136    0.217986    0.112549    0.024424    0.698744    
#> 410: 0.458696    0.994497    3.465069    0.217900    0.112529    0.024432    0.698808    
#> 411: 0.458766    0.994357    3.465012    0.217921    0.112512    0.024437    0.698923    
#> 412: 0.458807    0.994365    3.464982    0.217871    0.112523    0.024436    0.699001    
#> 413: 0.458828    0.994382    3.464986    0.217791    0.112487    0.024428    0.699031    
#> 414: 0.458774    0.994325    3.465028    0.217889    0.112422    0.024425    0.698961    
#> 415: 0.458850    0.994289    3.465037    0.217965    0.112430    0.024406    0.698831    
#> 416: 0.458920    0.994317    3.465060    0.217790    0.112357    0.024373    0.698837    
#> 417: 0.459133    0.994252    3.465086    0.217924    0.112284    0.024357    0.698775    
#> 418: 0.459157    0.994316    3.465125    0.217930    0.112259    0.024369    0.698633    
#> 419: 0.459187    0.994468    3.465111    0.218085    0.112279    0.024368    0.698617    
#> 420: 0.459113    0.994536    3.465081    0.218162    0.112293    0.024365    0.698484    
#> 421: 0.458983    0.994552    3.465094    0.218204    0.112223    0.024379    0.698434    
#> 422: 0.459038    0.994430    3.465098    0.218255    0.112202    0.024369    0.698442    
#> 423: 0.459297    0.994360    3.465154    0.218409    0.112204    0.024379    0.698482    
#> 424: 0.459419    0.994299    3.465166    0.218644    0.112222    0.024375    0.698500    
#> 425: 0.459672    0.994306    3.465173    0.218837    0.112226    0.024368    0.698519    
#> 426: 0.459794    0.994375    3.465233    0.219124    0.112191    0.024386    0.698467    
#> 427: 0.459790    0.994367    3.465276    0.219214    0.112129    0.024371    0.698488    
#> 428: 0.459804    0.994441    3.465315    0.219064    0.112134    0.024374    0.698513    
#> 429: 0.459748    0.994557    3.465343    0.219058    0.112131    0.024386    0.698503    
#> 430: 0.459711    0.994579    3.465299    0.219170    0.112136    0.024387    0.698511    
#> 431: 0.459696    0.994556    3.465238    0.219217    0.112175    0.024386    0.698435    
#> 432: 0.459571    0.994603    3.465239    0.219270    0.112250    0.024398    0.698347    
#> 433: 0.459585    0.994662    3.465297    0.219257    0.112329    0.024416    0.698293    
#> 434: 0.459530    0.994606    3.465312    0.219196    0.112424    0.024405    0.698278    
#> 435: 0.459630    0.994545    3.465328    0.219253    0.112453    0.024405    0.698251    
#> 436: 0.459658    0.994461    3.465380    0.219164    0.112542    0.024386    0.698237    
#> 437: 0.459826    0.994295    3.465427    0.219340    0.112611    0.024366    0.698198    
#> 438: 0.459770    0.994304    3.465433    0.219581    0.112548    0.024349    0.698207    
#> 439: 0.459903    0.994362    3.465428    0.219671    0.112500    0.024344    0.698195    
#> 440: 0.459906    0.994361    3.465456    0.219659    0.112435    0.024343    0.698194    
#> 441: 0.459892    0.994271    3.465493    0.219524    0.112362    0.024365    0.698155    
#> 442: 0.459826    0.994300    3.465539    0.219588    0.112294    0.024381    0.698064    
#> 443: 0.459831    0.994372    3.465496    0.219597    0.112250    0.024400    0.697997    
#> 444: 0.459646    0.994444    3.465426    0.219605    0.112165    0.024422    0.697956    
#> 445: 0.459467    0.994534    3.465366    0.219517    0.112122    0.024444    0.697924    
#> 446: 0.459233    0.994649    3.465291    0.219545    0.112167    0.024459    0.697851    
#> 447: 0.459274    0.994736    3.465247    0.219525    0.112176    0.024469    0.697825    
#> 448: 0.459189    0.994840    3.465238    0.219441    0.112129    0.024482    0.697749    
#> 449: 0.459314    0.994887    3.465365    0.219335    0.112117    0.024496    0.697760    
#> 450: 0.459395    0.994798    3.465397    0.219291    0.112168    0.024489    0.697752    
#> 451: 0.459596    0.994768    3.465442    0.219265    0.112220    0.024496    0.697775    
#> 452: 0.459625    0.994816    3.465420    0.219113    0.112209    0.024498    0.697824    
#> 453: 0.459572    0.994846    3.465377    0.219156    0.112187    0.024495    0.697774    
#> 454: 0.459464    0.995016    3.465328    0.219170    0.112141    0.024506    0.697747    
#> 455: 0.459387    0.995089    3.465307    0.219162    0.112118    0.024501    0.697740    
#> 456: 0.459285    0.995026    3.465315    0.219228    0.112174    0.024502    0.697719    
#> 457: 0.459389    0.994928    3.465383    0.219145    0.112201    0.024485    0.697675    
#> 458: 0.459375    0.994977    3.465417    0.219112    0.112208    0.024476    0.697680    
#> 459: 0.459265    0.995143    3.465394    0.219097    0.112221    0.024470    0.697676    
#> 460: 0.459150    0.995160    3.465317    0.219097    0.112296    0.024471    0.697709    
#> 461: 0.459028    0.995174    3.465312    0.219076    0.112317    0.024470    0.697681    
#> 462: 0.458957    0.995216    3.465330    0.219112    0.112299    0.024464    0.697663    
#> 463: 0.459080    0.995198    3.465371    0.219240    0.112250    0.024469    0.697697    
#> 464: 0.459292    0.995182    3.465428    0.219348    0.112222    0.024462    0.697657    
#> 465: 0.459448    0.995089    3.465463    0.219431    0.112147    0.024468    0.697638    
#> 466: 0.459635    0.995096    3.465487    0.219618    0.112163    0.024478    0.697593    
#> 467: 0.459802    0.994993    3.465567    0.219633    0.112192    0.024467    0.697556    
#> 468: 0.459937    0.995019    3.465625    0.219663    0.112145    0.024457    0.697629    
#> 469: 0.459992    0.995102    3.465673    0.219571    0.112139    0.024428    0.697685    
#> 470: 0.460047    0.995117    3.465675    0.219476    0.112100    0.024421    0.697701    
#> 471: 0.459956    0.995132    3.465644    0.219348    0.112081    0.024419    0.697687    
#> 472: 0.459827    0.995130    3.465611    0.219270    0.112055    0.024404    0.697674    
#> 473: 0.459696    0.995175    3.465569    0.219219    0.112066    0.024405    0.697561    
#> 474: 0.459572    0.995159    3.465581    0.219270    0.112043    0.024404    0.697621    
#> 475: 0.459593    0.995251    3.465577    0.219366    0.112039    0.024405    0.697566    
#> 476: 0.459634    0.995191    3.465584    0.219547    0.112046    0.024390    0.697531    
#> 477: 0.459574    0.995196    3.465602    0.219422    0.111981    0.024378    0.697479    
#> 478: 0.459468    0.995205    3.465585    0.219311    0.111988    0.024371    0.697518    
#> 479: 0.459573    0.995274    3.465586    0.219243    0.111986    0.024359    0.697528    
#> 480: 0.459565    0.995303    3.465557    0.219117    0.111972    0.024370    0.697533    
#> 481: 0.459507    0.995333    3.465533    0.219087    0.111919    0.024379    0.697518    
#> 482: 0.459505    0.995353    3.465510    0.219028    0.111872    0.024399    0.697584    
#> 483: 0.459508    0.995332    3.465507    0.218974    0.111910    0.024415    0.697566    
#> 484: 0.459530    0.995245    3.465545    0.218958    0.111916    0.024428    0.697600    
#> 485: 0.459548    0.995279    3.465541    0.218974    0.111917    0.024426    0.697607    
#> 486: 0.459627    0.995245    3.465585    0.219054    0.111871    0.024435    0.697522    
#> 487: 0.459805    0.995217    3.465632    0.219092    0.111867    0.024442    0.697537    
#> 488: 0.459736    0.995205    3.465663    0.219052    0.111898    0.024465    0.697489    
#> 489: 0.459899    0.995240    3.465659    0.219021    0.111869    0.024483    0.697511    
#> 490: 0.460043    0.995261    3.465706    0.219160    0.111817    0.024496    0.697521    
#> 491: 0.460156    0.995292    3.465793    0.219213    0.111758    0.024513    0.697486    
#> 492: 0.460220    0.995319    3.465834    0.219182    0.111739    0.024546    0.697498    
#> 493: 0.460185    0.995317    3.465850    0.219195    0.111706    0.024554    0.697497    
#> 494: 0.460226    0.995368    3.465819    0.219184    0.111700    0.024566    0.697445    
#> 495: 0.460200    0.995409    3.465804    0.219210    0.111712    0.024569    0.697406    
#> 496: 0.460192    0.995502    3.465737    0.219288    0.111713    0.024563    0.697376    
#> 497: 0.460107    0.995523    3.465714    0.219361    0.111620    0.024566    0.697389    
#> 498: 0.460193    0.995523    3.465679    0.219529    0.111567    0.024568    0.697354    
#> 499: 0.460264    0.995500    3.465657    0.219476    0.111543    0.024562    0.697339    
#> 500: 0.460324    0.995424    3.465667    0.219468    0.111501    0.024558    0.697299    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.300895    0.966266    3.439560    0.392401    0.092051    0.016800    1.953950    
#> 002: 0.348829    0.993597    3.457363    0.372781    0.087449    0.015960    1.296681    
#> 003: 0.501112    0.918898    3.476610    0.354142    0.083076    0.015162    0.961298    
#> 004: 0.430490    0.925638    3.475429    0.336435    0.091202    0.015375    0.865464    
#> 005: 0.502148    0.916727    3.467213    0.319613    0.086642    0.014606    0.824199    
#> 006: 0.444445    0.918842    3.452834    0.310324    0.091536    0.013876    0.781059    
#> 007: 0.422612    0.938996    3.440892    0.371468    0.125312    0.013182    0.769207    
#> 008: 0.400328    0.940328    3.436245    0.352895    0.131565    0.015136    0.768081    
#> 009: 0.356658    0.940072    3.425272    0.335250    0.124987    0.014379    0.764862    
#> 010: 0.384081    0.926880    3.426434    0.328057    0.118738    0.013660    0.777238    
#> 011: 0.432642    0.959763    3.424342    0.311654    0.135476    0.012977    0.786450    
#> 012: 0.427862    0.930276    3.417164    0.319094    0.128702    0.012328    0.802267    
#> 013: 0.372199    0.950545    3.411753    0.303139    0.122267    0.012067    0.784444    
#> 014: 0.407126    0.926247    3.425537    0.287982    0.116154    0.011837    0.801826    
#> 015: 0.420262    0.936197    3.445061    0.295211    0.115938    0.012223    0.765289    
#> 016: 0.426809    0.959969    3.445285    0.401811    0.125607    0.013558    0.755452    
#> 017: 0.443147    0.939219    3.442809    0.381721    0.119326    0.012880    0.737940    
#> 018: 0.439119    0.934591    3.429162    0.362635    0.130587    0.012236    0.772020    
#> 019: 0.401298    0.928959    3.437837    0.344503    0.132076    0.011624    0.751398    
#> 020: 0.448387    0.943773    3.452704    0.327278    0.132675    0.011043    0.757047    
#> 021: 0.430026    0.923202    3.444908    0.310914    0.126041    0.010491    0.749268    
#> 022: 0.394695    0.939299    3.436678    0.295368    0.119739    0.009966    0.755437    
#> 023: 0.461408    0.951712    3.448662    0.280600    0.124502    0.009468    0.771894    
#> 024: 0.484264    0.965122    3.448286    0.305810    0.128986    0.008994    0.767913    
#> 025: 0.452914    0.921811    3.449145    0.322241    0.128926    0.008545    0.769216    
#> 026: 0.459116    0.954433    3.445060    0.368341    0.122753    0.008118    0.745838    
#> 027: 0.441174    0.974853    3.443769    0.359737    0.116615    0.009319    0.777319    
#> 028: 0.472860    0.958622    3.455050    0.341750    0.126340    0.008853    0.755639    
#> 029: 0.508180    0.951635    3.445520    0.324663    0.135544    0.008411    0.790321    
#> 030: 0.482807    0.945316    3.447213    0.342428    0.128766    0.010149    0.775295    
#> 031: 0.423124    0.929850    3.448746    0.346000    0.127799    0.009641    0.788876    
#> 032: 0.439239    0.916704    3.456995    0.328700    0.121409    0.009159    0.780146    
#> 033: 0.418370    0.946327    3.436001    0.312265    0.132452    0.008701    0.777829    
#> 034: 0.431422    0.943855    3.442100    0.311259    0.125829    0.008266    0.776304    
#> 035: 0.417985    0.921715    3.433418    0.295696    0.150469    0.007853    0.778943    
#> 036: 0.393553    0.927743    3.430131    0.280911    0.142945    0.007460    0.778262    
#> 037: 0.391661    0.950678    3.433430    0.323526    0.135798    0.007087    0.794012    
#> 038: 0.426908    0.943556    3.432302    0.307350    0.134601    0.006733    0.803246    
#> 039: 0.439360    0.934462    3.442049    0.293441    0.135388    0.006908    0.776027    
#> 040: 0.434314    0.950905    3.448893    0.278769    0.128619    0.007453    0.789984    
#> 041: 0.388985    0.913632    3.445691    0.264831    0.138535    0.007821    0.790092    
#> 042: 0.455849    0.927026    3.448634    0.309834    0.131608    0.007430    0.766698    
#> 043: 0.414125    0.939601    3.433940    0.294342    0.128828    0.007321    0.765572    
#> 044: 0.404477    0.947644    3.435494    0.329650    0.138248    0.007667    0.765677    
#> 045: 0.426000    0.976156    3.427729    0.436451    0.132195    0.007283    0.774979    
#> 046: 0.440692    0.941119    3.431120    0.463106    0.125586    0.006919    0.778036    
#> 047: 0.437875    0.950255    3.432670    0.439950    0.122779    0.006573    0.775151    
#> 048: 0.418968    0.927580    3.430262    0.417953    0.119731    0.006245    0.790937    
#> 049: 0.402145    0.935515    3.437423    0.397055    0.132588    0.006424    0.790862    
#> 050: 0.459308    0.889887    3.442312    0.377202    0.133561    0.006194    0.796658    
#> 051: 0.444839    0.931370    3.442413    0.358342    0.126883    0.007705    0.794582    
#> 052: 0.408250    0.933598    3.446279    0.340425    0.120539    0.007320    0.776349    
#> 053: 0.434501    0.921596    3.447481    0.326699    0.122226    0.007756    0.774127    
#> 054: 0.390259    0.926832    3.446649    0.310364    0.128528    0.010042    0.777366    
#> 055: 0.433392    0.902337    3.450100    0.294845    0.141334    0.009731    0.772212    
#> 056: 0.438452    0.893754    3.449400    0.303464    0.134267    0.010870    0.774972    
#> 057: 0.427847    0.899326    3.458157    0.293455    0.150658    0.010327    0.784862    
#> 058: 0.433174    0.907118    3.435585    0.296483    0.143125    0.009810    0.796424    
#> 059: 0.467655    0.890036    3.448909    0.330682    0.145114    0.009320    0.804904    
#> 060: 0.479383    0.897529    3.464106    0.330999    0.137858    0.008854    0.797226    
#> 061: 0.483551    0.920429    3.467756    0.314449    0.134428    0.009239    0.785404    
#> 062: 0.470418    0.931505    3.465964    0.298727    0.169491    0.009290    0.793370    
#> 063: 0.496657    0.871046    3.468237    0.296331    0.161017    0.011565    0.793130    
#> 064: 0.449776    0.892512    3.471077    0.281514    0.152966    0.011426    0.799273    
#> 065: 0.483433    0.893247    3.459633    0.267438    0.145318    0.010855    0.796727    
#> 066: 0.494357    0.920590    3.470545    0.261392    0.138052    0.010385    0.776105    
#> 067: 0.482778    0.897778    3.459897    0.248323    0.131149    0.016205    0.764097    
#> 068: 0.410651    0.917589    3.464468    0.245909    0.130633    0.015394    0.785975    
#> 069: 0.441663    0.919122    3.444876    0.233614    0.124102    0.014625    0.790056    
#> 070: 0.449695    0.920958    3.454331    0.249589    0.131361    0.013893    0.783077    
#> 071: 0.391167    0.946797    3.424037    0.237109    0.141854    0.013199    0.797032    
#> 072: 0.366163    0.917006    3.440723    0.242329    0.134762    0.012539    0.793932    
#> 073: 0.399392    0.929074    3.457817    0.330554    0.128024    0.011912    0.792663    
#> 074: 0.447635    0.914805    3.459297    0.314026    0.133997    0.011316    0.793140    
#> 075: 0.518434    0.896764    3.482751    0.338531    0.127297    0.010750    0.780064    
#> 076: 0.509162    0.895482    3.486656    0.321604    0.120932    0.010213    0.782016    
#> 077: 0.512327    0.880116    3.474024    0.305524    0.114885    0.009739    0.782981    
#> 078: 0.473841    0.895401    3.476356    0.353983    0.112526    0.009252    0.753677    
#> 079: 0.480708    0.929643    3.463697    0.378755    0.110143    0.009612    0.775395    
#> 080: 0.458855    0.922975    3.452746    0.360073    0.139347    0.009369    0.786657    
#> 081: 0.453726    0.936164    3.444673    0.342069    0.132379    0.008900    0.782070    
#> 082: 0.447656    0.923686    3.454845    0.324966    0.133088    0.008455    0.805603    
#> 083: 0.430823    0.928025    3.456912    0.334089    0.126433    0.008032    0.793739    
#> 084: 0.455477    0.932748    3.446145    0.317384    0.125195    0.008439    0.789155    
#> 085: 0.429495    0.953482    3.449548    0.313709    0.150504    0.008017    0.769207    
#> 086: 0.427026    0.958600    3.438296    0.313866    0.142978    0.007617    0.761401    
#> 087: 0.400842    0.951263    3.428237    0.298173    0.135829    0.007236    0.782204    
#> 088: 0.340936    0.957323    3.428327    0.283264    0.129038    0.006974    0.809628    
#> 089: 0.401395    0.967400    3.426977    0.269101    0.139152    0.006625    0.788099    
#> 090: 0.378156    0.943981    3.436402    0.255646    0.137757    0.008232    0.776236    
#> 091: 0.359351    0.937874    3.418768    0.288833    0.130869    0.007824    0.774952    
#> 092: 0.375622    0.956878    3.415180    0.274391    0.124325    0.007432    0.794662    
#> 093: 0.391106    0.951003    3.422350    0.263457    0.120460    0.007419    0.786035    
#> 094: 0.402528    0.959475    3.426464    0.250284    0.118325    0.009040    0.806314    
#> 095: 0.404301    0.958280    3.440469    0.237770    0.114963    0.008588    0.811652    
#> 096: 0.393992    0.936762    3.440381    0.270708    0.119398    0.008159    0.798689    
#> 097: 0.429829    0.940388    3.445341    0.310062    0.114699    0.007751    0.792610    
#> 098: 0.449378    0.962736    3.450005    0.305755    0.115275    0.007363    0.811476    
#> 099: 0.424831    0.924297    3.435559    0.319273    0.139659    0.006995    0.768842    
#> 100: 0.424496    0.934681    3.437716    0.307180    0.147884    0.006645    0.763461    
#> 101: 0.386586    0.920964    3.423966    0.291821    0.140490    0.006313    0.766447    
#> 102: 0.391673    0.952473    3.418172    0.277230    0.135855    0.005997    0.775443    
#> 103: 0.395119    0.959916    3.424925    0.263368    0.129139    0.005697    0.774302    
#> 104: 0.403578    0.969622    3.434774    0.333162    0.122682    0.005413    0.776634    
#> 105: 0.408126    0.933519    3.430114    0.330335    0.142352    0.005142    0.765495    
#> 106: 0.408335    0.930906    3.429045    0.347939    0.135234    0.004885    0.767201    
#> 107: 0.417612    0.942551    3.428145    0.351707    0.128472    0.005440    0.783121    
#> 108: 0.405469    0.933424    3.429210    0.334121    0.125907    0.005168    0.786142    
#> 109: 0.408086    0.956638    3.430579    0.317415    0.125144    0.004910    0.784047    
#> 110: 0.380170    0.958646    3.417602    0.301545    0.130945    0.005165    0.782601    
#> 111: 0.389915    0.940743    3.420759    0.286467    0.126153    0.004906    0.780416    
#> 112: 0.370413    0.932655    3.419131    0.272144    0.147399    0.004661    0.810740    
#> 113: 0.379236    0.959233    3.427647    0.277629    0.140029    0.004428    0.772733    
#> 114: 0.420278    0.964469    3.425537    0.301252    0.133027    0.004207    0.771058    
#> 115: 0.424536    0.931088    3.420131    0.364601    0.143980    0.003996    0.790811    
#> 116: 0.451968    0.945508    3.427052    0.403721    0.136781    0.003796    0.769715    
#> 117: 0.418158    0.954716    3.428425    0.383534    0.141014    0.003607    0.794665    
#> 118: 0.435476    0.931468    3.430716    0.374605    0.147977    0.003477    0.803133    
#> 119: 0.390904    0.971226    3.423174    0.355874    0.164236    0.003303    0.807853    
#> 120: 0.366286    0.955160    3.422420    0.338081    0.156024    0.003189    0.772814    
#> 121: 0.430858    0.969921    3.421291    0.321177    0.158952    0.003238    0.782992    
#> 122: 0.392904    0.931162    3.428370    0.305118    0.151894    0.003112    0.782617    
#> 123: 0.453814    0.972789    3.428809    0.289862    0.144299    0.003284    0.786394    
#> 124: 0.407997    0.995776    3.420777    0.275369    0.137084    0.003120    0.786777    
#> 125: 0.397072    1.002387    3.410544    0.317968    0.130230    0.003455    0.772731    
#> 126: 0.401804    0.979281    3.411202    0.377305    0.123719    0.003283    0.765696    
#> 127: 0.413689    0.969595    3.406330    0.377975    0.123667    0.003203    0.777986    
#> 128: 0.357196    0.942953    3.416323    0.359076    0.143124    0.004314    0.783496    
#> 129: 0.425418    0.962784    3.425640    0.341123    0.135968    0.005132    0.778391    
#> 130: 0.451019    0.969867    3.429153    0.324066    0.129170    0.005388    0.763391    
#> 131: 0.420356    0.949432    3.425096    0.307863    0.146416    0.005192    0.776106    
#> 132: 0.398458    0.959175    3.416346    0.325230    0.139095    0.004933    0.793914    
#> 133: 0.406344    0.938491    3.419965    0.308969    0.132140    0.004817    0.802650    
#> 134: 0.411410    0.930533    3.431279    0.293520    0.133086    0.006447    0.787533    
#> 135: 0.383769    0.942191    3.432058    0.278844    0.146223    0.006124    0.810340    
#> 136: 0.394016    0.918992    3.428189    0.264902    0.138912    0.005818    0.794842    
#> 137: 0.427039    0.917514    3.442360    0.251657    0.131966    0.006940    0.777984    
#> 138: 0.436909    0.927321    3.441196    0.253868    0.126080    0.006593    0.764944    
#> 139: 0.426604    0.936237    3.455890    0.241175    0.119776    0.007490    0.772297    
#> 140: 0.461794    0.927893    3.462496    0.261873    0.135607    0.007993    0.776599    
#> 141: 0.447486    0.894240    3.467121    0.255795    0.143644    0.007594    0.770408    
#> 142: 0.475157    0.904134    3.468400    0.247782    0.136462    0.007214    0.797925    
#> 143: 0.457308    0.919731    3.471893    0.240405    0.129639    0.008809    0.798567    
#> 144: 0.522532    0.933947    3.478393    0.259934    0.129424    0.008369    0.778794    
#> 145: 0.482208    0.925454    3.462947    0.246937    0.138744    0.007951    0.751439    
#> 146: 0.447390    0.933328    3.467020    0.242772    0.131807    0.007791    0.753335    
#> 147: 0.410762    0.917928    3.456994    0.230634    0.125217    0.008671    0.746254    
#> 148: 0.414049    0.923845    3.462931    0.219102    0.125162    0.008237    0.758357    
#> 149: 0.430424    0.917532    3.456049    0.241477    0.118904    0.008519    0.783935    
#> 150: 0.433515    0.923372    3.451028    0.248498    0.127402    0.008093    0.795122    
#> 151: 0.381748    0.945627    3.436603    0.314437    0.125678    0.007689    0.779782    
#> 152: 0.374278    0.942949    3.437226    0.260869    0.117860    0.008673    0.774998    
#> 153: 0.404671    0.955099    3.442739    0.256135    0.154080    0.007264    0.778996    
#> 154: 0.449091    0.949355    3.451498    0.253649    0.137117    0.006810    0.791519    
#> 155: 0.430763    0.931196    3.447878    0.247624    0.141040    0.006082    0.778085    
#> 156: 0.424379    0.936012    3.450946    0.212650    0.127610    0.005034    0.780909    
#> 157: 0.461346    0.913465    3.459732    0.283288    0.133594    0.004988    0.799999    
#> 158: 0.488592    0.919190    3.462849    0.250501    0.137022    0.005873    0.781291    
#> 159: 0.467760    0.922278    3.461178    0.298754    0.131453    0.006641    0.762565    
#> 160: 0.482345    0.899135    3.465543    0.317991    0.136685    0.005816    0.762130    
#> 161: 0.498646    0.914823    3.462772    0.304493    0.135011    0.007920    0.756196    
#> 162: 0.470908    0.945454    3.456828    0.292022    0.140631    0.008775    0.767330    
#> 163: 0.488397    0.935656    3.457766    0.240056    0.119841    0.009249    0.785475    
#> 164: 0.442005    0.927611    3.454535    0.260074    0.105056    0.010236    0.788039    
#> 165: 0.456335    0.907590    3.457696    0.216616    0.115107    0.011600    0.773384    
#> 166: 0.466596    0.943312    3.455206    0.249271    0.113540    0.012057    0.767934    
#> 167: 0.476079    0.957487    3.459500    0.269677    0.089918    0.013298    0.789272    
#> 168: 0.483564    0.948855    3.458799    0.271179    0.108933    0.013065    0.793394    
#> 169: 0.488717    0.967478    3.462385    0.255948    0.105353    0.012960    0.813714    
#> 170: 0.480246    0.925351    3.463181    0.219924    0.109827    0.011009    0.789929    
#> 171: 0.426762    0.922518    3.452637    0.242666    0.119282    0.009565    0.781537    
#> 172: 0.409550    0.941525    3.443193    0.221081    0.131586    0.009187    0.771972    
#> 173: 0.408670    0.952962    3.432633    0.239293    0.117621    0.009662    0.761837    
#> 174: 0.427960    0.944647    3.440526    0.313317    0.122042    0.008304    0.765378    
#> 175: 0.406919    0.946556    3.430698    0.302754    0.136640    0.008557    0.775365    
#> 176: 0.413255    0.957882    3.439113    0.318874    0.125959    0.005300    0.775885    
#> 177: 0.426304    0.935497    3.442009    0.291999    0.115401    0.005269    0.780667    
#> 178: 0.437500    0.929663    3.437632    0.265720    0.119604    0.007758    0.753802    
#> 179: 0.461190    0.942923    3.441153    0.348151    0.138326    0.007657    0.771484    
#> 180: 0.390164    0.947645    3.441963    0.265896    0.116073    0.009313    0.761734    
#> 181: 0.433006    0.951280    3.434295    0.278968    0.140422    0.008094    0.772072    
#> 182: 0.392758    0.955668    3.421363    0.272302    0.138988    0.008965    0.792525    
#> 183: 0.433366    0.958397    3.425462    0.313039    0.138613    0.007158    0.789788    
#> 184: 0.396332    0.945048    3.432262    0.274110    0.108798    0.006265    0.790907    
#> 185: 0.368331    0.971272    3.418500    0.319731    0.108392    0.006755    0.794132    
#> 186: 0.397545    0.963363    3.428366    0.305140    0.138497    0.007212    0.776021    
#> 187: 0.405954    0.953535    3.435730    0.325627    0.124029    0.005495    0.782212    
#> 188: 0.360058    0.965034    3.430630    0.286310    0.152486    0.005822    0.782837    
#> 189: 0.388412    0.975785    3.432273    0.318228    0.167395    0.005707    0.782572    
#> 190: 0.369328    0.957557    3.434909    0.200308    0.136592    0.005900    0.794856    
#> 191: 0.383907    0.955440    3.427250    0.291586    0.126241    0.004547    0.784518    
#> 192: 0.385690    0.974912    3.433267    0.303861    0.125895    0.004117    0.776217    
#> 193: 0.448440    0.982560    3.431500    0.313068    0.113957    0.003497    0.770169    
#> 194: 0.369654    0.959486    3.412999    0.334784    0.156845    0.003613    0.780538    
#> 195: 0.372194    0.949580    3.406127    0.345236    0.162735    0.002759    0.791777    
#> 196: 0.371172    0.940328    3.415465    0.319843    0.158513    0.003379    0.785825    
#> 197: 0.375643    0.933219    3.426476    0.291546    0.146962    0.003741    0.800122    
#> 198: 0.428009    0.939109    3.418426    0.301545    0.110974    0.004260    0.784129    
#> 199: 0.378831    0.933310    3.421475    0.316252    0.145251    0.003745    0.787474    
#> 200: 0.366532    0.963081    3.419212    0.311791    0.152330    0.002350    0.805980    
#> 201: 0.372194    0.958889    3.422725    0.295683    0.142506    0.003046    0.798813    
#> 202: 0.383335    0.955662    3.424457    0.297790    0.147171    0.003216    0.802073    
#> 203: 0.386508    0.954877    3.423042    0.302111    0.145287    0.003193    0.801957    
#> 204: 0.389031    0.948996    3.424137    0.302441    0.144489    0.003225    0.798997    
#> 205: 0.394977    0.950671    3.425526    0.303098    0.145133    0.003242    0.800982    
#> 206: 0.400022    0.953611    3.426578    0.308954    0.146597    0.003300    0.800365    
#> 207: 0.398610    0.951406    3.426313    0.312917    0.143065    0.003241    0.802811    
#> 208: 0.398850    0.950245    3.426530    0.305797    0.141140    0.003217    0.801433    
#> 209: 0.400038    0.947154    3.427012    0.301172    0.142196    0.003223    0.799973    
#> 210: 0.401923    0.944547    3.427454    0.299271    0.141440    0.003227    0.798482    
#> 211: 0.404417    0.944739    3.428272    0.295155    0.140967    0.003163    0.798216    
#> 212: 0.407619    0.944202    3.428752    0.294629    0.139673    0.003099    0.796703    
#> 213: 0.409463    0.942285    3.428541    0.292931    0.138495    0.003124    0.796514    
#> 214: 0.411002    0.941087    3.428518    0.288981    0.137436    0.003146    0.795946    
#> 215: 0.412306    0.942682    3.428601    0.289235    0.137267    0.003208    0.794649    
#> 216: 0.414655    0.942541    3.428836    0.287079    0.139837    0.003192    0.794916    
#> 217: 0.414930    0.943673    3.428737    0.285732    0.140225    0.003192    0.793800    
#> 218: 0.414872    0.943311    3.428409    0.283011    0.139823    0.003239    0.793654    
#> 219: 0.412460    0.942160    3.427372    0.282923    0.139893    0.003265    0.793738    
#> 220: 0.409915    0.942332    3.427262    0.279061    0.139959    0.003269    0.794151    
#> 221: 0.408220    0.942991    3.427144    0.278066    0.139644    0.003228    0.793397    
#> 222: 0.407742    0.942989    3.427009    0.277431    0.140630    0.003222    0.793418    
#> 223: 0.408051    0.941891    3.427118    0.278346    0.141949    0.003212    0.793025    
#> 224: 0.408497    0.941852    3.427454    0.279024    0.143520    0.003184    0.793758    
#> 225: 0.407887    0.939544    3.427941    0.281925    0.144379    0.003160    0.794471    
#> 226: 0.408296    0.938051    3.428189    0.281821    0.144044    0.003153    0.794882    
#> 227: 0.407976    0.937742    3.428515    0.283250    0.144214    0.003152    0.795027    
#> 228: 0.406313    0.939343    3.428426    0.282272    0.145386    0.003167    0.795029    
#> 229: 0.405524    0.938971    3.428251    0.282056    0.145124    0.003176    0.794892    
#> 230: 0.405172    0.939021    3.428071    0.280417    0.144729    0.003163    0.794514    
#> 231: 0.405534    0.939138    3.428137    0.279826    0.144419    0.003184    0.794037    
#> 232: 0.404053    0.939563    3.428315    0.278863    0.144090    0.003200    0.794040    
#> 233: 0.403416    0.939058    3.428551    0.279142    0.143947    0.003256    0.793808    
#> 234: 0.403758    0.939109    3.428795    0.279105    0.143969    0.003326    0.793676    
#> 235: 0.404588    0.938957    3.428768    0.280176    0.143609    0.003315    0.793555    
#> 236: 0.405368    0.938797    3.428744    0.280594    0.143978    0.003296    0.793837    
#> 237: 0.406499    0.938798    3.428755    0.280127    0.144495    0.003279    0.794607    
#> 238: 0.407062    0.938897    3.428762    0.280075    0.145478    0.003265    0.795243    
#> 239: 0.407321    0.940062    3.428775    0.279910    0.146343    0.003262    0.795109    
#> 240: 0.407520    0.939478    3.428864    0.280324    0.146608    0.003261    0.794591    
#> 241: 0.407801    0.938248    3.429124    0.281891    0.146675    0.003235    0.794599    
#> 242: 0.407738    0.938291    3.429113    0.281710    0.146787    0.003225    0.794756    
#> 243: 0.406623    0.938966    3.429075    0.280492    0.146823    0.003219    0.795347    
#> 244: 0.405895    0.939288    3.429156    0.279619    0.146669    0.003240    0.795456    
#> 245: 0.405751    0.938920    3.429200    0.278343    0.146669    0.003241    0.795878    
#> 246: 0.406275    0.938354    3.429276    0.278005    0.146665    0.003269    0.796218    
#> 247: 0.406744    0.938329    3.429439    0.277836    0.146522    0.003276    0.796267    
#> 248: 0.406540    0.938864    3.429486    0.277980    0.146338    0.003269    0.796152    
#> 249: 0.406606    0.939308    3.429565    0.278404    0.146353    0.003263    0.796151    
#> 250: 0.407126    0.939705    3.429627    0.278423    0.146350    0.003263    0.796192    
#> 251: 0.407572    0.940767    3.429773    0.278315    0.146388    0.003252    0.796361    
#> 252: 0.407955    0.940971    3.429990    0.277336    0.146548    0.003249    0.796269    
#> 253: 0.407861    0.941198    3.430180    0.276823    0.146654    0.003271    0.796276    
#> 254: 0.408345    0.941247    3.430436    0.276835    0.146594    0.003287    0.795774    
#> 255: 0.408281    0.941318    3.430812    0.277135    0.146554    0.003310    0.795524    
#> 256: 0.408430    0.941023    3.430920    0.276609    0.146558    0.003311    0.795424    
#> 257: 0.408541    0.940676    3.431001    0.276539    0.146472    0.003310    0.795181    
#> 258: 0.408039    0.940507    3.431046    0.276644    0.146232    0.003293    0.794974    
#> 259: 0.408044    0.940253    3.431033    0.277595    0.146461    0.003277    0.794764    
#> 260: 0.408184    0.940534    3.431073    0.277390    0.146606    0.003271    0.794599    
#> 261: 0.408241    0.940410    3.431149    0.277626    0.147053    0.003266    0.794705    
#> 262: 0.408954    0.940682    3.431272    0.279235    0.147177    0.003259    0.794815    
#> 263: 0.408485    0.941120    3.431269    0.279990    0.147237    0.003280    0.794798    
#> 264: 0.408163    0.941175    3.431103    0.280495    0.147271    0.003286    0.794766    
#> 265: 0.408203    0.941376    3.431086    0.282077    0.147385    0.003291    0.794607    
#> 266: 0.408942    0.941292    3.431132    0.283473    0.147330    0.003295    0.794339    
#> 267: 0.409381    0.941200    3.431166    0.285173    0.147223    0.003306    0.794218    
#> 268: 0.410126    0.941090    3.431022    0.286548    0.146937    0.003300    0.794226    
#> 269: 0.410826    0.941197    3.430889    0.287551    0.146873    0.003307    0.794125    
#> 270: 0.411126    0.941416    3.430696    0.287611    0.146740    0.003301    0.794012    
#> 271: 0.411067    0.941592    3.430493    0.288049    0.146685    0.003300    0.794380    
#> 272: 0.411035    0.941546    3.430380    0.288114    0.146462    0.003294    0.794535    
#> 273: 0.410811    0.941812    3.430258    0.289199    0.146583    0.003300    0.794550    
#> 274: 0.410474    0.942017    3.430304    0.289640    0.146133    0.003289    0.794506    
#> 275: 0.410318    0.942105    3.430225    0.289659    0.146046    0.003287    0.794585    
#> 276: 0.410205    0.942441    3.430324    0.290422    0.146035    0.003297    0.794386    
#> 277: 0.410115    0.942760    3.430480    0.290549    0.146195    0.003305    0.794172    
#> 278: 0.410111    0.942856    3.430601    0.290189    0.146455    0.003304    0.794087    
#> 279: 0.409891    0.942786    3.430670    0.289627    0.146859    0.003300    0.794169    
#> 280: 0.410117    0.942923    3.430778    0.289870    0.146889    0.003293    0.793946    
#> 281: 0.410009    0.942820    3.430827    0.290035    0.146879    0.003282    0.793796    
#> 282: 0.410218    0.942987    3.430937    0.290639    0.146980    0.003275    0.793742    
#> 283: 0.410526    0.942959    3.431074    0.290908    0.146740    0.003278    0.794071    
#> 284: 0.410289    0.942993    3.431089    0.291432    0.146665    0.003280    0.794052    
#> 285: 0.409979    0.943287    3.430969    0.291414    0.146581    0.003281    0.794049    
#> 286: 0.409790    0.943668    3.430860    0.291580    0.146841    0.003279    0.794014    
#> 287: 0.409718    0.943948    3.430778    0.292099    0.146777    0.003273    0.793857    
#> 288: 0.409990    0.943764    3.430693    0.292861    0.146833    0.003258    0.793823    
#> 289: 0.410364    0.943982    3.430613    0.293843    0.146882    0.003248    0.793804    
#> 290: 0.410512    0.944128    3.430515    0.295145    0.146716    0.003241    0.794165    
#> 291: 0.410682    0.944429    3.430517    0.295870    0.146685    0.003236    0.794045    
#> 292: 0.410363    0.944580    3.430478    0.295791    0.146616    0.003227    0.793992    
#> 293: 0.410008    0.944767    3.430354    0.295794    0.146530    0.003222    0.793985    
#> 294: 0.409645    0.944979    3.430182    0.296068    0.146534    0.003225    0.793811    
#> 295: 0.409390    0.944952    3.430023    0.295737    0.146466    0.003223    0.793774    
#> 296: 0.408921    0.945199    3.429907    0.295916    0.146126    0.003229    0.793986    
#> 297: 0.409106    0.945346    3.429911    0.295942    0.146035    0.003223    0.794128    
#> 298: 0.409168    0.945213    3.429904    0.296018    0.145901    0.003220    0.794144    
#> 299: 0.409584    0.945286    3.429955    0.295552    0.145813    0.003213    0.794103    
#> 300: 0.409759    0.945206    3.430056    0.295911    0.146036    0.003203    0.793833    
#> 301: 0.410036    0.945078    3.430041    0.296223    0.146063    0.003201    0.793722    
#> 302: 0.409815    0.945206    3.429995    0.296396    0.146238    0.003195    0.793698    
#> 303: 0.409508    0.945289    3.429972    0.296376    0.146204    0.003196    0.793462    
#> 304: 0.409694    0.945546    3.429939    0.296199    0.146055    0.003196    0.793384    
#> 305: 0.409914    0.945344    3.429984    0.296112    0.146087    0.003203    0.793188    
#> 306: 0.409894    0.945216    3.429940    0.295961    0.146096    0.003204    0.793022    
#> 307: 0.409953    0.945058    3.429847    0.296988    0.146432    0.003197    0.793174    
#> 308: 0.409561    0.944925    3.429790    0.297270    0.146716    0.003200    0.793179    
#> 309: 0.409540    0.944630    3.429767    0.297353    0.146940    0.003199    0.793191    
#> 310: 0.409361    0.944682    3.429649    0.296934    0.147104    0.003197    0.793261    
#> 311: 0.409025    0.944778    3.429535    0.297131    0.147232    0.003192    0.793283    
#> 312: 0.409066    0.944703    3.429450    0.297393    0.147147    0.003196    0.793211    
#> 313: 0.408639    0.944479    3.429363    0.297801    0.146950    0.003197    0.793179    
#> 314: 0.408173    0.944638    3.429234    0.298135    0.146849    0.003199    0.793149    
#> 315: 0.407767    0.944874    3.429172    0.298234    0.146748    0.003199    0.793198    
#> 316: 0.407808    0.944992    3.429128    0.298186    0.146527    0.003195    0.793195    
#> 317: 0.407879    0.945061    3.429123    0.297927    0.146380    0.003190    0.793257    
#> 318: 0.407987    0.945024    3.429066    0.298197    0.146179    0.003192    0.793119    
#> 319: 0.407933    0.944946    3.429069    0.298127    0.146051    0.003193    0.793020    
#> 320: 0.407447    0.944898    3.428978    0.298156    0.145987    0.003194    0.792943    
#> 321: 0.407242    0.945073    3.428841    0.298269    0.145882    0.003195    0.792872    
#> 322: 0.406789    0.945184    3.428688    0.297911    0.145758    0.003198    0.792964    
#> 323: 0.406245    0.945260    3.428607    0.297775    0.145611    0.003202    0.792967    
#> 324: 0.406236    0.945439    3.428617    0.297754    0.145641    0.003202    0.792741    
#> 325: 0.406278    0.945682    3.428574    0.297567    0.145582    0.003202    0.792625    
#> 326: 0.406234    0.945343    3.428551    0.297568    0.145833    0.003202    0.792532    
#> 327: 0.406496    0.945235    3.428614    0.297103    0.145903    0.003210    0.792406    
#> 328: 0.406598    0.945437    3.428605    0.296703    0.145729    0.003217    0.792235    
#> 329: 0.406787    0.945421    3.428662    0.296877    0.145771    0.003221    0.792316    
#> 330: 0.406690    0.945272    3.428715    0.296814    0.145804    0.003227    0.792336    
#> 331: 0.406773    0.945402    3.428723    0.297004    0.145823    0.003227    0.792237    
#> 332: 0.407025    0.945459    3.428763    0.297364    0.145782    0.003224    0.792181    
#> 333: 0.407168    0.945593    3.428716    0.297437    0.145806    0.003230    0.792043    
#> 334: 0.407113    0.945574    3.428611    0.297138    0.145631    0.003229    0.792059    
#> 335: 0.406803    0.945678    3.428440    0.297391    0.145550    0.003231    0.791892    
#> 336: 0.406403    0.945791    3.428324    0.297693    0.145508    0.003233    0.791939    
#> 337: 0.406374    0.946194    3.428212    0.297539    0.145385    0.003234    0.792013    
#> 338: 0.406462    0.946266    3.428194    0.297181    0.145294    0.003229    0.792074    
#> 339: 0.406404    0.946422    3.428155    0.297150    0.145233    0.003231    0.791922    
#> 340: 0.406499    0.946142    3.428232    0.297104    0.145233    0.003233    0.791859    
#> 341: 0.406621    0.945966    3.428315    0.296834    0.145227    0.003234    0.791848    
#> 342: 0.406434    0.945858    3.428332    0.296846    0.145257    0.003231    0.791760    
#> 343: 0.405972    0.945838    3.428376    0.296894    0.145380    0.003228    0.791723    
#> 344: 0.406108    0.945891    3.428405    0.297157    0.145303    0.003224    0.791800    
#> 345: 0.406091    0.945997    3.428414    0.297392    0.145304    0.003221    0.791877    
#> 346: 0.406036    0.946002    3.428401    0.297486    0.145161    0.003215    0.791890    
#> 347: 0.406092    0.946108    3.428323    0.297708    0.144933    0.003221    0.791917    
#> 348: 0.405737    0.946146    3.428270    0.297872    0.144914    0.003223    0.791938    
#> 349: 0.405596    0.946239    3.428178    0.298021    0.144913    0.003229    0.791915    
#> 350: 0.405392    0.946083    3.428132    0.298158    0.144751    0.003231    0.792034    
#> 351: 0.405406    0.946260    3.428077    0.298185    0.144795    0.003228    0.792025    
#> 352: 0.405141    0.946349    3.428072    0.297846    0.144785    0.003232    0.792091    
#> 353: 0.405142    0.946433    3.428052    0.297363    0.144634    0.003240    0.791979    
#> 354: 0.405061    0.946599    3.427964    0.297556    0.144548    0.003251    0.791808    
#> 355: 0.405327    0.946456    3.427936    0.297489    0.144415    0.003263    0.791786    
#> 356: 0.405317    0.946405    3.427968    0.297731    0.144399    0.003268    0.791793    
#> 357: 0.405595    0.946432    3.428002    0.297572    0.144314    0.003277    0.791685    
#> 358: 0.405532    0.946378    3.428041    0.297175    0.144219    0.003285    0.791601    
#> 359: 0.405396    0.946539    3.428019    0.297002    0.144224    0.003287    0.791451    
#> 360: 0.405152    0.946640    3.427950    0.297136    0.144193    0.003286    0.791318    
#> 361: 0.405138    0.946696    3.427878    0.296818    0.144122    0.003288    0.791158    
#> 362: 0.405078    0.946697    3.427809    0.296503    0.144033    0.003290    0.791033    
#> 363: 0.405075    0.946657    3.427781    0.296146    0.143839    0.003294    0.790960    
#> 364: 0.405079    0.946642    3.427769    0.295736    0.143765    0.003294    0.790943    
#> 365: 0.405100    0.946315    3.427794    0.295521    0.143789    0.003292    0.790984    
#> 366: 0.405214    0.946138    3.427783    0.295434    0.143730    0.003292    0.791095    
#> 367: 0.405169    0.946137    3.427790    0.295109    0.143825    0.003285    0.791207    
#> 368: 0.405287    0.946188    3.427800    0.294765    0.143763    0.003283    0.791280    
#> 369: 0.405298    0.946294    3.427807    0.294878    0.143771    0.003276    0.791272    
#> 370: 0.405133    0.946434    3.427774    0.294926    0.143779    0.003268    0.791286    
#> 371: 0.405119    0.946463    3.427698    0.295175    0.143820    0.003265    0.791197    
#> 372: 0.405161    0.946510    3.427650    0.295414    0.143847    0.003261    0.791251    
#> 373: 0.404931    0.946637    3.427589    0.295441    0.143837    0.003258    0.791259    
#> 374: 0.404837    0.946739    3.427542    0.295651    0.143840    0.003256    0.791245    
#> 375: 0.404594    0.946859    3.427469    0.295578    0.143955    0.003257    0.791249    
#> 376: 0.404491    0.946902    3.427432    0.295654    0.144003    0.003260    0.791241    
#> 377: 0.404321    0.947026    3.427403    0.295916    0.143957    0.003260    0.791304    
#> 378: 0.404115    0.947095    3.427334    0.296060    0.143875    0.003261    0.791213    
#> 379: 0.403916    0.946988    3.427314    0.296409    0.143892    0.003259    0.791075    
#> 380: 0.403702    0.946963    3.427287    0.296551    0.143803    0.003261    0.791034    
#> 381: 0.403443    0.947091    3.427243    0.296703    0.143788    0.003256    0.791024    
#> 382: 0.403577    0.947232    3.427210    0.297103    0.143770    0.003252    0.790878    
#> 383: 0.403911    0.947186    3.427191    0.297173    0.143698    0.003249    0.790862    
#> 384: 0.403899    0.947211    3.427188    0.297230    0.143615    0.003251    0.790781    
#> 385: 0.403941    0.947231    3.427161    0.297005    0.143623    0.003257    0.790717    
#> 386: 0.404129    0.947329    3.427190    0.297029    0.143554    0.003260    0.790659    
#> 387: 0.404310    0.947392    3.427247    0.297036    0.143517    0.003266    0.790638    
#> 388: 0.404456    0.947451    3.427277    0.297248    0.143515    0.003267    0.790622    
#> 389: 0.404500    0.947370    3.427306    0.297287    0.143446    0.003267    0.790696    
#> 390: 0.404339    0.947584    3.427240    0.297195    0.143445    0.003265    0.790850    
#> 391: 0.404245    0.947590    3.427207    0.296596    0.143464    0.003266    0.790928    
#> 392: 0.404220    0.947578    3.427199    0.296426    0.143453    0.003265    0.790909    
#> 393: 0.404112    0.947592    3.427153    0.296475    0.143346    0.003267    0.790835    
#> 394: 0.404008    0.947626    3.427105    0.296261    0.143318    0.003277    0.790764    
#> 395: 0.404057    0.947861    3.427083    0.296002    0.143236    0.003286    0.790794    
#> 396: 0.404152    0.947917    3.427061    0.295918    0.143156    0.003289    0.790787    
#> 397: 0.404210    0.947861    3.427053    0.296069    0.143126    0.003288    0.790713    
#> 398: 0.404220    0.947875    3.427026    0.296089    0.143049    0.003284    0.790776    
#> 399: 0.404161    0.947878    3.427026    0.296459    0.142948    0.003282    0.790727    
#> 400: 0.404313    0.947807    3.427063    0.296522    0.142950    0.003282    0.790709    
#> 401: 0.404486    0.947745    3.427089    0.296935    0.142981    0.003282    0.790634    
#> 402: 0.404541    0.947857    3.427127    0.296980    0.142894    0.003283    0.790657    
#> 403: 0.404872    0.947790    3.427163    0.297266    0.142956    0.003287    0.790670    
#> 404: 0.404963    0.947902    3.427135    0.297461    0.142877    0.003290    0.790610    
#> 405: 0.404860    0.948037    3.427121    0.297410    0.142764    0.003294    0.790574    
#> 406: 0.404913    0.948161    3.427121    0.297452    0.142704    0.003297    0.790571    
#> 407: 0.404943    0.948105    3.427161    0.297324    0.142623    0.003297    0.790554    
#> 408: 0.405060    0.948174    3.427184    0.297538    0.142644    0.003295    0.790578    
#> 409: 0.405029    0.948086    3.427154    0.297635    0.142672    0.003297    0.790482    
#> 410: 0.404967    0.948125    3.427094    0.297731    0.142652    0.003297    0.790480    
#> 411: 0.405018    0.947994    3.427046    0.297972    0.142721    0.003298    0.790497    
#> 412: 0.404988    0.948090    3.427006    0.298014    0.142741    0.003296    0.790428    
#> 413: 0.404873    0.948035    3.426989    0.297971    0.142758    0.003294    0.790464    
#> 414: 0.404819    0.948038    3.426986    0.298206    0.142717    0.003292    0.790509    
#> 415: 0.404899    0.947943    3.426974    0.298252    0.142752    0.003295    0.790494    
#> 416: 0.404978    0.948020    3.426949    0.298380    0.142743    0.003298    0.790442    
#> 417: 0.404842    0.948031    3.426923    0.298469    0.142791    0.003300    0.790366    
#> 418: 0.404569    0.948156    3.426900    0.298626    0.142861    0.003298    0.790377    
#> 419: 0.404509    0.948293    3.426849    0.298717    0.142915    0.003299    0.790386    
#> 420: 0.404559    0.948347    3.426848    0.298576    0.142961    0.003301    0.790373    
#> 421: 0.404422    0.948441    3.426842    0.298428    0.142976    0.003298    0.790455    
#> 422: 0.404606    0.948337    3.426828    0.298208    0.142989    0.003299    0.790505    
#> 423: 0.404632    0.948312    3.426822    0.297950    0.143021    0.003295    0.790558    
#> 424: 0.404515    0.948302    3.426800    0.297781    0.143104    0.003291    0.790543    
#> 425: 0.404542    0.948371    3.426785    0.297693    0.143150    0.003291    0.790535    
#> 426: 0.404550    0.948461    3.426797    0.297354    0.143168    0.003289    0.790588    
#> 427: 0.404324    0.948492    3.426787    0.297043    0.143162    0.003291    0.790524    
#> 428: 0.404122    0.948668    3.426769    0.296887    0.143032    0.003293    0.790576    
#> 429: 0.404142    0.948760    3.426776    0.296856    0.143049    0.003295    0.790641    
#> 430: 0.404150    0.948903    3.426755    0.296721    0.142960    0.003298    0.790545    
#> 431: 0.404000    0.948935    3.426694    0.296717    0.142952    0.003296    0.790422    
#> 432: 0.403819    0.948998    3.426662    0.296665    0.142934    0.003294    0.790335    
#> 433: 0.403831    0.949083    3.426661    0.296651    0.142824    0.003291    0.790305    
#> 434: 0.403721    0.949001    3.426681    0.296597    0.142779    0.003291    0.790226    
#> 435: 0.403787    0.949015    3.426714    0.296739    0.142901    0.003291    0.790149    
#> 436: 0.403818    0.948885    3.426741    0.296776    0.143011    0.003286    0.790210    
#> 437: 0.403833    0.948774    3.426741    0.296645    0.142971    0.003284    0.790261    
#> 438: 0.403809    0.948936    3.426731    0.296566    0.143060    0.003278    0.790238    
#> 439: 0.403838    0.949056    3.426713    0.296427    0.143129    0.003274    0.790250    
#> 440: 0.403736    0.949149    3.426735    0.296640    0.143288    0.003270    0.790244    
#> 441: 0.403702    0.949095    3.426751    0.296804    0.143371    0.003271    0.790237    
#> 442: 0.403740    0.949157    3.426777    0.296911    0.143472    0.003269    0.790222    
#> 443: 0.403748    0.949099    3.426794    0.296835    0.143493    0.003266    0.790188    
#> 444: 0.403749    0.949121    3.426789    0.297155    0.143533    0.003267    0.790168    
#> 445: 0.403751    0.949131    3.426758    0.297249    0.143572    0.003265    0.790165    
#> 446: 0.403825    0.949100    3.426757    0.297500    0.143548    0.003261    0.790088    
#> 447: 0.404074    0.949016    3.426796    0.297373    0.143562    0.003259    0.790068    
#> 448: 0.404128    0.948977    3.426829    0.297448    0.143589    0.003259    0.789964    
#> 449: 0.404116    0.948992    3.426901    0.297508    0.143636    0.003258    0.789955    
#> 450: 0.404208    0.948999    3.426939    0.297650    0.143587    0.003260    0.789984    
#> 451: 0.404276    0.949044    3.426962    0.297754    0.143581    0.003264    0.789988    
#> 452: 0.404256    0.949109    3.426940    0.298150    0.143598    0.003265    0.789915    
#> 453: 0.404177    0.949167    3.426912    0.298486    0.143533    0.003265    0.789825    
#> 454: 0.404071    0.949289    3.426873    0.298472    0.143559    0.003265    0.789741    
#> 455: 0.404124    0.949265    3.426837    0.298394    0.143515    0.003268    0.789730    
#> 456: 0.404064    0.949253    3.426820    0.298291    0.143419    0.003272    0.789747    
#> 457: 0.404061    0.949214    3.426825    0.298067    0.143394    0.003276    0.789688    
#> 458: 0.403921    0.949370    3.426863    0.298054    0.143414    0.003275    0.789728    
#> 459: 0.403840    0.949496    3.426872    0.298267    0.143308    0.003274    0.789843    
#> 460: 0.403758    0.949519    3.426869    0.298330    0.143275    0.003276    0.789849    
#> 461: 0.403692    0.949496    3.426879    0.298295    0.143229    0.003278    0.789906    
#> 462: 0.403662    0.949540    3.426897    0.298271    0.143224    0.003278    0.789830    
#> 463: 0.403605    0.949514    3.426900    0.298173    0.143209    0.003279    0.789758    
#> 464: 0.403634    0.949424    3.426925    0.298123    0.143176    0.003278    0.789616    
#> 465: 0.403671    0.949243    3.426911    0.298189    0.143200    0.003273    0.789650    
#> 466: 0.403817    0.949278    3.426887    0.298247    0.143099    0.003268    0.789658    
#> 467: 0.403807    0.949203    3.426880    0.298218    0.143175    0.003267    0.789583    
#> 468: 0.403991    0.949158    3.426896    0.298384    0.143214    0.003267    0.789575    
#> 469: 0.404040    0.949252    3.426909    0.298496    0.143192    0.003269    0.789564    
#> 470: 0.403937    0.949350    3.426901    0.298624    0.143248    0.003274    0.789482    
#> 471: 0.403746    0.949216    3.426902    0.298685    0.143224    0.003273    0.789456    
#> 472: 0.403727    0.949128    3.426933    0.298659    0.143269    0.003271    0.789431    
#> 473: 0.403594    0.949099    3.426930    0.298550    0.143223    0.003271    0.789380    
#> 474: 0.403559    0.949082    3.426938    0.298579    0.143258    0.003272    0.789357    
#> 475: 0.403631    0.949236    3.426952    0.298605    0.143298    0.003275    0.789288    
#> 476: 0.403665    0.949254    3.426920    0.298647    0.143321    0.003277    0.789349    
#> 477: 0.403717    0.949248    3.426923    0.298570    0.143416    0.003277    0.789297    
#> 478: 0.403659    0.949188    3.426924    0.298449    0.143441    0.003278    0.789261    
#> 479: 0.403703    0.949230    3.426930    0.298300    0.143483    0.003280    0.789336    
#> 480: 0.403620    0.949256    3.426965    0.298098    0.143620    0.003282    0.789361    
#> 481: 0.403803    0.949218    3.427013    0.297931    0.143681    0.003282    0.789363    
#> 482: 0.404008    0.949195    3.427042    0.297894    0.143630    0.003282    0.789389    
#> 483: 0.403950    0.949131    3.427030    0.297880    0.143662    0.003278    0.789371    
#> 484: 0.403992    0.949004    3.427036    0.297812    0.143647    0.003274    0.789431    
#> 485: 0.404121    0.948966    3.427067    0.297846    0.143635    0.003275    0.789395    
#> 486: 0.404336    0.948927    3.427081    0.297954    0.143649    0.003273    0.789408    
#> 487: 0.404490    0.948841    3.427106    0.297918    0.143684    0.003274    0.789385    
#> 488: 0.404575    0.948854    3.427130    0.298206    0.143663    0.003277    0.789364    
#> 489: 0.404633    0.948882    3.427145    0.298294    0.143689    0.003278    0.789386    
#> 490: 0.404678    0.948847    3.427174    0.298305    0.143694    0.003280    0.789356    
#> 491: 0.404717    0.948870    3.427213    0.298270    0.143672    0.003280    0.789320    
#> 492: 0.404791    0.948897    3.427241    0.298382    0.143645    0.003278    0.789449    
#> 493: 0.404893    0.948799    3.427267    0.298493    0.143662    0.003283    0.789398    
#> 494: 0.405041    0.948751    3.427284    0.298531    0.143726    0.003285    0.789319    
#> 495: 0.405020    0.948722    3.427312    0.298387    0.143754    0.003288    0.789267    
#> 496: 0.405085    0.948719    3.427322    0.298373    0.143710    0.003288    0.789291    
#> 497: 0.405075    0.948699    3.427343    0.298302    0.143778    0.003291    0.789344    
#> 498: 0.405181    0.948636    3.427353    0.298302    0.143838    0.003291    0.789342    
#> 499: 0.405268    0.948590    3.427363    0.298143    0.143860    0.003290    0.789357    
#> 500: 0.405425    0.948502    3.427377    0.298405    0.143843    0.003288    0.789287    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.307811    0.956686    3.437487    0.392401    0.089642    0.016800    1.829060    
#> 002: 0.378275    0.931623    3.456539    0.372781    0.085160    0.016751    1.191076    
#> 003: 0.429712    0.940422    3.450376    0.354142    0.080902    0.015913    1.018988    
#> 004: 0.370220    0.952023    3.454868    0.336435    0.076857    0.015118    0.867380    
#> 005: 0.455359    0.970073    3.435847    0.319613    0.076489    0.014362    0.835976    
#> 006: 0.393894    0.987388    3.420269    0.303633    0.072665    0.013644    0.802528    
#> 007: 0.354015    0.973736    3.415871    0.294754    0.069031    0.013746    0.828297    
#> 008: 0.350958    0.989941    3.417433    0.311908    0.065580    0.014788    0.833367    
#> 009: 0.342919    0.985706    3.408413    0.317839    0.069273    0.014049    0.793691    
#> 010: 0.316021    0.978482    3.405769    0.301947    0.065810    0.013346    0.829249    
#> 011: 0.404348    1.012624    3.411872    0.335356    0.062519    0.016719    0.805144    
#> 012: 0.401070    1.010487    3.404600    0.347251    0.059393    0.017816    0.789887    
#> 013: 0.334313    1.006523    3.385055    0.442377    0.056424    0.016926    0.797511    
#> 014: 0.375461    1.002352    3.392916    0.563689    0.057111    0.016937    0.814009    
#> 015: 0.368961    0.989454    3.411746    0.535504    0.058442    0.016136    0.793866    
#> 016: 0.375056    1.011895    3.406513    0.508729    0.055519    0.015329    0.830799    
#> 017: 0.391829    0.995330    3.409942    0.526011    0.052743    0.015983    0.815341    
#> 018: 0.372465    1.007202    3.396631    0.499711    0.050106    0.016044    0.819283    
#> 019: 0.357617    1.000756    3.389365    0.474725    0.047601    0.015656    0.805839    
#> 020: 0.418541    1.009741    3.408234    0.503763    0.045221    0.019158    0.795792    
#> 021: 0.440671    0.988865    3.423346    0.508198    0.046337    0.021052    0.766692    
#> 022: 0.440536    0.997990    3.437331    0.482789    0.044020    0.022798    0.743644    
#> 023: 0.497421    0.999469    3.448137    0.458649    0.046403    0.021881    0.779295    
#> 024: 0.464447    1.013392    3.443007    0.435717    0.046244    0.020787    0.794873    
#> 025: 0.412315    0.986968    3.433201    0.413931    0.056475    0.019747    0.792043    
#> 026: 0.393905    1.007502    3.420869    0.393234    0.053651    0.023351    0.784635    
#> 027: 0.385035    1.018207    3.414262    0.373573    0.050969    0.024817    0.823966    
#> 028: 0.406877    1.016202    3.416790    0.354894    0.048420    0.024602    0.797176    
#> 029: 0.419583    1.009706    3.404862    0.357624    0.045999    0.023372    0.820425    
#> 030: 0.395835    1.015254    3.418392    0.339743    0.044746    0.022203    0.807203    
#> 031: 0.378572    0.982673    3.433932    0.336496    0.055434    0.021093    0.777911    
#> 032: 0.405913    0.988360    3.431742    0.407221    0.052662    0.020038    0.770385    
#> 033: 0.383776    1.015343    3.415276    0.406954    0.050029    0.019036    0.780641    
#> 034: 0.390130    1.022334    3.419982    0.386606    0.047527    0.020034    0.777243    
#> 035: 0.395149    1.010914    3.412843    0.391964    0.045151    0.019632    0.779030    
#> 036: 0.401261    1.005257    3.415335    0.413370    0.042893    0.020611    0.804194    
#> 037: 0.407754    0.997028    3.426084    0.392702    0.041259    0.019917    0.831823    
#> 038: 0.426489    0.998698    3.412609    0.400904    0.042744    0.021978    0.815465    
#> 039: 0.411925    0.995770    3.436767    0.405060    0.043686    0.026515    0.807212    
#> 040: 0.434498    0.984254    3.443332    0.444659    0.041502    0.026168    0.790157    
#> 041: 0.402533    0.977538    3.446344    0.422426    0.039427    0.026377    0.795077    
#> 042: 0.456850    0.972229    3.439024    0.401305    0.040781    0.025058    0.794272    
#> 043: 0.447066    0.980065    3.421755    0.436273    0.038742    0.023824    0.815088    
#> 044: 0.391752    0.993155    3.420130    0.414459    0.036805    0.022632    0.818412    
#> 045: 0.351589    0.999320    3.420224    0.393736    0.034964    0.021501    0.801929    
#> 046: 0.362524    1.015968    3.406459    0.374049    0.033216    0.020426    0.800901    
#> 047: 0.403297    0.999115    3.417157    0.355347    0.039468    0.019404    0.795099    
#> 048: 0.384680    1.008990    3.417691    0.368906    0.045169    0.018434    0.814818    
#> 049: 0.394650    1.010954    3.421280    0.441509    0.054217    0.017513    0.803453    
#> 050: 0.492167    0.963452    3.438484    0.419434    0.051506    0.019601    0.813334    
#> 051: 0.435064    0.983874    3.432977    0.403810    0.048931    0.021105    0.814977    
#> 052: 0.439634    0.978311    3.448429    0.383619    0.046484    0.021022    0.807820    
#> 053: 0.432999    0.955325    3.436788    0.365258    0.047210    0.023611    0.794659    
#> 054: 0.380092    0.949687    3.447295    0.364126    0.044850    0.023743    0.799805    
#> 055: 0.394760    0.973243    3.432654    0.431266    0.042607    0.027814    0.773220    
#> 056: 0.423853    0.977033    3.424717    0.453089    0.040477    0.026424    0.790608    
#> 057: 0.430438    0.977872    3.429635    0.475626    0.039535    0.025102    0.800950    
#> 058: 0.439970    0.989821    3.410712    0.522200    0.037558    0.023847    0.810309    
#> 059: 0.448377    0.938461    3.431467    0.496090    0.041635    0.026016    0.819078    
#> 060: 0.432371    0.953482    3.433158    0.551994    0.039554    0.024715    0.814133    
#> 061: 0.436690    0.971264    3.440588    0.524394    0.039221    0.024553    0.796314    
#> 062: 0.470024    0.994336    3.440377    0.498175    0.043552    0.023325    0.815578    
#> 063: 0.487889    0.975535    3.439704    0.522443    0.046478    0.022159    0.809268    
#> 064: 0.487345    0.953263    3.458699    0.515570    0.048230    0.021051    0.815147    
#> 065: 0.483035    0.960878    3.430325    0.511595    0.060251    0.019998    0.799348    
#> 066: 0.472678    0.976795    3.443296    0.489499    0.057238    0.018999    0.817415    
#> 067: 0.430451    0.979719    3.433410    0.465024    0.054376    0.018049    0.802185    
#> 068: 0.383992    0.989556    3.437597    0.441773    0.051658    0.017146    0.826438    
#> 069: 0.436299    0.984066    3.439267    0.428984    0.049075    0.016467    0.811530    
#> 070: 0.445749    0.998923    3.442717    0.481866    0.053539    0.015644    0.799071    
#> 071: 0.390728    1.018160    3.414838    0.457772    0.050862    0.017472    0.789364    
#> 072: 0.388078    0.981102    3.423200    0.434884    0.048319    0.016598    0.793735    
#> 073: 0.413973    0.977147    3.452718    0.413140    0.045903    0.020310    0.807901    
#> 074: 0.416815    0.973035    3.442254    0.417587    0.043608    0.020025    0.791205    
#> 075: 0.464049    0.951914    3.462146    0.396708    0.044552    0.019024    0.810162    
#> 076: 0.442259    0.974574    3.453919    0.376872    0.043657    0.019051    0.813735    
#> 077: 0.481098    0.974105    3.444676    0.358029    0.041474    0.022378    0.795181    
#> 078: 0.435702    0.984284    3.448537    0.354399    0.040396    0.023726    0.779602    
#> 079: 0.445231    0.996148    3.447720    0.378424    0.038554    0.024390    0.816951    
#> 080: 0.467557    0.965421    3.447214    0.406237    0.036626    0.024294    0.833019    
#> 081: 0.448119    0.977931    3.440406    0.385925    0.034795    0.023079    0.812967    
#> 082: 0.426131    0.954310    3.438089    0.366629    0.033055    0.026303    0.820585    
#> 083: 0.421699    0.969882    3.448015    0.348297    0.032536    0.025637    0.817836    
#> 084: 0.423975    0.982007    3.438343    0.331642    0.034497    0.024355    0.815032    
#> 085: 0.437194    0.977805    3.449990    0.402580    0.035303    0.025355    0.790864    
#> 086: 0.440680    0.960966    3.447736    0.382451    0.033538    0.024088    0.798016    
#> 087: 0.398042    0.963360    3.433815    0.363328    0.031861    0.024668    0.801872    
#> 088: 0.340376    0.957972    3.419597    0.367975    0.031796    0.023434    0.809054    
#> 089: 0.407380    0.995501    3.403034    0.421700    0.033410    0.025488    0.809563    
#> 090: 0.373781    1.014495    3.402180    0.400615    0.031739    0.024213    0.797350    
#> 091: 0.344769    0.996146    3.393130    0.380585    0.031055    0.023003    0.810852    
#> 092: 0.354817    1.012230    3.397466    0.444347    0.039632    0.023081    0.789349    
#> 093: 0.345347    1.002989    3.405044    0.422129    0.039832    0.023310    0.803587    
#> 094: 0.343514    1.009128    3.405951    0.401023    0.047816    0.023543    0.793758    
#> 095: 0.365119    0.999938    3.419742    0.380972    0.045425    0.022366    0.797690    
#> 096: 0.331480    1.010266    3.411440    0.361923    0.050500    0.021248    0.809957    
#> 097: 0.382546    1.026296    3.397488    0.343827    0.048162    0.020790    0.784643    
#> 098: 0.371643    1.019962    3.419882    0.326636    0.048167    0.019750    0.796759    
#> 099: 0.340791    1.000316    3.402212    0.409211    0.052027    0.018763    0.790853    
#> 100: 0.350653    1.004227    3.410555    0.388751    0.056908    0.017824    0.785317    
#> 101: 0.331075    0.997415    3.380201    0.400044    0.054063    0.016933    0.802930    
#> 102: 0.301101    1.009282    3.373578    0.380042    0.051360    0.016087    0.814903    
#> 103: 0.334637    1.027065    3.397336    0.388350    0.048792    0.016105    0.804906    
#> 104: 0.310478    1.035886    3.392086    0.368933    0.051140    0.015300    0.817572    
#> 105: 0.317245    1.037174    3.393147    0.350486    0.048583    0.014884    0.789926    
#> 106: 0.358230    1.024147    3.392086    0.363654    0.048042    0.014140    0.801809    
#> 107: 0.361217    1.016301    3.400353    0.374156    0.057450    0.013433    0.810691    
#> 108: 0.345059    1.008263    3.386709    0.400825    0.056612    0.012762    0.827739    
#> 109: 0.347261    1.008901    3.395042    0.411982    0.057818    0.012123    0.786470    
#> 110: 0.374225    0.999363    3.381388    0.505038    0.054927    0.011517    0.780948    
#> 111: 0.373641    1.002302    3.402046    0.479786    0.052181    0.010941    0.778293    
#> 112: 0.368363    0.995402    3.391513    0.455797    0.049572    0.010615    0.811852    
#> 113: 0.345076    1.031718    3.391268    0.433007    0.047093    0.011818    0.802923    
#> 114: 0.340099    1.031709    3.390878    0.435771    0.051560    0.012073    0.801543    
#> 115: 0.386308    0.998616    3.395433    0.462480    0.055586    0.011469    0.817617    
#> 116: 0.413423    1.006117    3.415212    0.439356    0.052807    0.012529    0.822936    
#> 117: 0.364616    1.015674    3.414931    0.417388    0.057617    0.011903    0.811495    
#> 118: 0.398613    1.010822    3.409730    0.396519    0.058608    0.011308    0.799822    
#> 119: 0.386199    1.007218    3.407286    0.388067    0.055678    0.011132    0.830991    
#> 120: 0.365845    0.964446    3.417060    0.368664    0.054822    0.013130    0.805098    
#> 121: 0.398529    1.014551    3.407583    0.383744    0.069086    0.012919    0.802220    
#> 122: 0.413839    1.010470    3.427233    0.364557    0.065632    0.014268    0.795079    
#> 123: 0.465155    1.009500    3.430979    0.346329    0.062351    0.014086    0.806055    
#> 124: 0.455293    1.049974    3.422032    0.367967    0.059233    0.013381    0.818070    
#> 125: 0.425480    1.019114    3.404490    0.362323    0.056271    0.012712    0.814066    
#> 126: 0.390409    1.023198    3.402994    0.384873    0.053458    0.013182    0.820467    
#> 127: 0.378849    1.011468    3.396207    0.375865    0.053319    0.012945    0.799605    
#> 128: 0.352388    1.008893    3.407588    0.404366    0.050653    0.014168    0.811018    
#> 129: 0.414047    1.009996    3.417819    0.443405    0.048121    0.017184    0.794548    
#> 130: 0.407513    1.021502    3.413759    0.421235    0.045715    0.016325    0.799974    
#> 131: 0.416693    0.991922    3.418536    0.400173    0.043429    0.017790    0.803120    
#> 132: 0.395704    1.000641    3.407305    0.380164    0.044804    0.018533    0.818743    
#> 133: 0.422304    0.990849    3.423173    0.485507    0.047220    0.017998    0.805360    
#> 134: 0.446921    0.968496    3.439758    0.461231    0.044859    0.021590    0.809093    
#> 135: 0.449286    0.963363    3.451076    0.438170    0.042616    0.023569    0.793795    
#> 136: 0.444107    0.959184    3.438442    0.416261    0.041316    0.022390    0.777838    
#> 137: 0.465319    0.970450    3.438338    0.395448    0.039250    0.021271    0.782138    
#> 138: 0.428152    0.983370    3.426101    0.375676    0.037288    0.021132    0.780684    
#> 139: 0.418400    1.000345    3.439129    0.363988    0.041370    0.023326    0.788109    
#> 140: 0.431903    0.999924    3.429722    0.413022    0.039302    0.027207    0.805402    
#> 141: 0.397177    0.988725    3.423009    0.414055    0.037337    0.025994    0.791832    
#> 142: 0.427846    0.972144    3.437174    0.458475    0.041421    0.024695    0.798171    
#> 143: 0.412409    0.987004    3.435398    0.484651    0.039350    0.024145    0.797597    
#> 144: 0.429314    0.989418    3.447564    0.460418    0.037383    0.022938    0.788463    
#> 145: 0.369250    1.007007    3.417409    0.437397    0.035514    0.021791    0.786075    
#> 146: 0.358588    1.011751    3.424928    0.415528    0.042546    0.020701    0.801002    
#> 147: 0.326212    0.998839    3.419779    0.394751    0.043561    0.020646    0.802371    
#> 148: 0.384999    0.999413    3.433747    0.450904    0.041383    0.021489    0.786495    
#> 149: 0.387757    0.987257    3.434035    0.428359    0.039314    0.021684    0.809286    
#> 150: 0.398597    0.993844    3.414492    0.406941    0.039697    0.020599    0.815881    
#> 151: 0.353912    0.997788    3.413561    0.386594    0.037712    0.019569    0.819856    
#> 152: 0.360568    1.002791    3.416344    0.373122    0.032747    0.016720    0.800122    
#> 153: 0.376784    1.019564    3.421423    0.396676    0.035692    0.021511    0.793302    
#> 154: 0.444724    1.007409    3.425549    0.404037    0.044345    0.021887    0.786227    
#> 155: 0.396933    0.992757    3.417458    0.419770    0.044260    0.020985    0.786473    
#> 156: 0.391210    1.012917    3.419938    0.441339    0.038760    0.022303    0.819068    
#> 157: 0.369978    1.011286    3.415078    0.465408    0.043961    0.021261    0.797853    
#> 158: 0.416462    1.004658    3.415690    0.515834    0.036507    0.017116    0.788675    
#> 159: 0.396956    1.010486    3.427047    0.466584    0.026397    0.019534    0.819212    
#> 160: 0.428462    0.972480    3.435065    0.474472    0.025298    0.018551    0.805869    
#> 161: 0.406586    0.980193    3.429503    0.431337    0.022552    0.024574    0.811349    
#> 162: 0.442614    0.987806    3.428453    0.475222    0.019961    0.024688    0.799567    
#> 163: 0.408531    0.977295    3.422367    0.484725    0.017292    0.022600    0.802303    
#> 164: 0.470423    0.993125    3.423310    0.525668    0.017051    0.027784    0.793204    
#> 165: 0.422834    0.991454    3.420220    0.405662    0.019247    0.023297    0.799080    
#> 166: 0.434000    1.002743    3.427613    0.380354    0.031454    0.023405    0.794021    
#> 167: 0.472795    1.006789    3.444856    0.419995    0.035899    0.022016    0.830949    
#> 168: 0.430728    1.023773    3.421030    0.412277    0.037840    0.022465    0.811262    
#> 169: 0.425936    1.044280    3.406146    0.390851    0.044506    0.019441    0.799281    
#> 170: 0.391493    1.012956    3.409167    0.371851    0.042515    0.020237    0.811842    
#> 171: 0.398539    1.004156    3.418630    0.352417    0.040993    0.021074    0.778453    
#> 172: 0.352469    1.026431    3.410030    0.365441    0.048406    0.020212    0.783838    
#> 173: 0.372130    1.028521    3.399163    0.334556    0.041755    0.019204    0.784758    
#> 174: 0.364354    1.026637    3.406422    0.348032    0.044109    0.015120    0.811331    
#> 175: 0.361921    1.024529    3.400880    0.352661    0.047451    0.015280    0.805989    
#> 176: 0.350940    1.033188    3.404849    0.262392    0.052699    0.011394    0.799703    
#> 177: 0.388633    1.012253    3.413515    0.307291    0.062268    0.013949    0.788297    
#> 178: 0.419591    1.006004    3.416064    0.339075    0.055419    0.016545    0.795371    
#> 179: 0.418984    1.005605    3.422451    0.282796    0.051312    0.020291    0.811763    
#> 180: 0.383276    0.994708    3.415908    0.279442    0.038840    0.017926    0.812349    
#> 181: 0.407728    0.983154    3.416126    0.285825    0.035209    0.016913    0.815382    
#> 182: 0.402052    0.990547    3.412649    0.285043    0.047122    0.017363    0.799328    
#> 183: 0.420454    1.012624    3.423076    0.282679    0.041223    0.018804    0.802949    
#> 184: 0.400713    0.974742    3.421203    0.315034    0.034735    0.017982    0.801823    
#> 185: 0.377012    1.011319    3.421353    0.330332    0.027728    0.022288    0.795360    
#> 186: 0.385610    1.027682    3.416100    0.367461    0.026641    0.023065    0.812584    
#> 187: 0.406092    1.002069    3.425667    0.385728    0.027150    0.021981    0.828585    
#> 188: 0.375705    1.018415    3.416701    0.354002    0.036302    0.021806    0.804635    
#> 189: 0.395002    1.014484    3.417918    0.363237    0.041668    0.025064    0.793547    
#> 190: 0.384247    0.997835    3.416834    0.345745    0.031529    0.025190    0.782582    
#> 191: 0.365969    1.020652    3.407523    0.317098    0.030401    0.021046    0.778826    
#> 192: 0.366665    1.017011    3.411905    0.334813    0.036399    0.018143    0.775168    
#> 193: 0.409096    1.034789    3.419756    0.380634    0.030712    0.015926    0.786894    
#> 194: 0.353758    1.027113    3.405171    0.325573    0.043066    0.013739    0.821569    
#> 195: 0.323918    1.040681    3.385487    0.344045    0.043662    0.011376    0.839303    
#> 196: 0.340716    1.035452    3.402190    0.410120    0.052332    0.011384    0.822231    
#> 197: 0.338558    1.040513    3.414993    0.347813    0.048177    0.011426    0.833490    
#> 198: 0.381465    1.011246    3.415244    0.350960    0.049751    0.012673    0.783363    
#> 199: 0.382586    0.996742    3.415351    0.342953    0.050647    0.008157    0.805844    
#> 200: 0.390325    0.998926    3.414828    0.397755    0.052409    0.010607    0.811033    
#> 201: 0.392706    0.993646    3.420160    0.379335    0.054646    0.011602    0.801824    
#> 202: 0.392528    0.993924    3.420772    0.354226    0.049876    0.011261    0.805765    
#> 203: 0.401008    0.993462    3.420084    0.356440    0.048034    0.011252    0.806910    
#> 204: 0.403086    0.987614    3.421304    0.363227    0.048900    0.011319    0.808700    
#> 205: 0.402400    0.992801    3.421477    0.360476    0.049136    0.011627    0.810734    
#> 206: 0.398172    0.999621    3.422335    0.358785    0.049114    0.011979    0.813310    
#> 207: 0.393446    0.999901    3.421030    0.355134    0.050253    0.012348    0.813731    
#> 208: 0.391147    0.999198    3.420419    0.347899    0.048253    0.012521    0.814998    
#> 209: 0.393350    0.998266    3.420000    0.347924    0.046918    0.012858    0.812469    
#> 210: 0.395308    0.997752    3.420895    0.345878    0.046226    0.013140    0.810338    
#> 211: 0.399191    0.996780    3.422794    0.344764    0.045905    0.013519    0.808840    
#> 212: 0.399970    0.995808    3.423424    0.340952    0.046233    0.013693    0.809072    
#> 213: 0.401083    0.992991    3.423675    0.339203    0.047369    0.013823    0.809626    
#> 214: 0.405504    0.991020    3.424869    0.338159    0.048072    0.013925    0.808977    
#> 215: 0.406848    0.989952    3.425502    0.336146    0.048413    0.013895    0.809191    
#> 216: 0.408273    0.989125    3.425935    0.339635    0.048337    0.013746    0.811176    
#> 217: 0.408187    0.989563    3.426241    0.340920    0.048826    0.013701    0.810431    
#> 218: 0.408213    0.990358    3.425430    0.344353    0.049157    0.013604    0.808811    
#> 219: 0.407271    0.990138    3.424562    0.347173    0.048964    0.013486    0.808057    
#> 220: 0.405422    0.990686    3.424181    0.348267    0.049203    0.013422    0.807597    
#> 221: 0.404226    0.990584    3.423750    0.347500    0.049101    0.013483    0.807559    
#> 222: 0.404744    0.990981    3.423694    0.349602    0.049017    0.013725    0.806849    
#> 223: 0.405164    0.991382    3.423892    0.348222    0.048648    0.013980    0.806295    
#> 224: 0.406361    0.991626    3.424316    0.349124    0.048668    0.014139    0.805388    
#> 225: 0.405092    0.990632    3.424390    0.347927    0.048376    0.014331    0.805838    
#> 226: 0.404100    0.989707    3.423891    0.350376    0.048080    0.014392    0.806334    
#> 227: 0.401665    0.989641    3.423630    0.352889    0.047969    0.014452    0.806625    
#> 228: 0.401127    0.990882    3.423263    0.353814    0.047993    0.014449    0.806564    
#> 229: 0.401093    0.990766    3.423022    0.354745    0.047821    0.014509    0.805842    
#> 230: 0.400683    0.990378    3.423056    0.354096    0.048018    0.014499    0.805284    
#> 231: 0.399657    0.990809    3.422658    0.356278    0.047804    0.014520    0.804739    
#> 232: 0.398635    0.990797    3.422447    0.356909    0.047428    0.014545    0.804565    
#> 233: 0.398082    0.990368    3.422182    0.357757    0.047385    0.014633    0.804942    
#> 234: 0.397984    0.990678    3.422211    0.356585    0.047393    0.014709    0.805006    
#> 235: 0.398257    0.991162    3.421850    0.357056    0.047347    0.014716    0.805079    
#> 236: 0.398434    0.991725    3.421665    0.357431    0.047520    0.014722    0.805103    
#> 237: 0.399417    0.991840    3.421804    0.357979    0.047788    0.014719    0.805602    
#> 238: 0.399976    0.992071    3.421874    0.357748    0.047966    0.014728    0.806246    
#> 239: 0.400061    0.992767    3.421578    0.358158    0.048051    0.014811    0.806027    
#> 240: 0.399696    0.992749    3.421491    0.357748    0.048111    0.014812    0.805771    
#> 241: 0.399597    0.992245    3.421605    0.357011    0.048061    0.014764    0.805969    
#> 242: 0.399343    0.992287    3.421579    0.355894    0.048425    0.014835    0.806270    
#> 243: 0.398780    0.992763    3.421579    0.356041    0.048845    0.014847    0.806418    
#> 244: 0.397729    0.992491    3.421688    0.355249    0.049082    0.014879    0.806518    
#> 245: 0.397889    0.992062    3.421834    0.355037    0.049106    0.014874    0.807032    
#> 246: 0.397597    0.992055    3.421771    0.354158    0.049019    0.014921    0.807324    
#> 247: 0.397895    0.992088    3.422050    0.354761    0.048957    0.014953    0.807238    
#> 248: 0.397638    0.992615    3.422067    0.353840    0.048802    0.014943    0.807114    
#> 249: 0.396901    0.993035    3.422048    0.353198    0.048696    0.014966    0.807351    
#> 250: 0.397867    0.993667    3.422300    0.353632    0.048885    0.014990    0.807161    
#> 251: 0.397860    0.994446    3.422596    0.354097    0.048960    0.015020    0.807125    
#> 252: 0.397933    0.994520    3.422890    0.353235    0.048660    0.015073    0.807262    
#> 253: 0.397604    0.994534    3.423083    0.353680    0.048347    0.015182    0.807563    
#> 254: 0.397488    0.995178    3.423176    0.353525    0.048231    0.015241    0.807646    
#> 255: 0.397471    0.995323    3.423247    0.353804    0.048329    0.015314    0.807564    
#> 256: 0.397725    0.995203    3.423283    0.355158    0.048519    0.015338    0.807516    
#> 257: 0.397377    0.995116    3.423163    0.357112    0.048554    0.015371    0.807664    
#> 258: 0.396652    0.994700    3.422847    0.356856    0.048561    0.015329    0.807639    
#> 259: 0.396340    0.994509    3.422734    0.356645    0.048437    0.015282    0.807701    
#> 260: 0.396144    0.994737    3.422663    0.356684    0.048333    0.015207    0.807454    
#> 261: 0.395949    0.994814    3.422513    0.356442    0.048275    0.015133    0.807208    
#> 262: 0.396022    0.995026    3.422545    0.356719    0.048413    0.015073    0.806978    
#> 263: 0.395616    0.995419    3.422363    0.356342    0.048446    0.015062    0.806970    
#> 264: 0.395463    0.995926    3.422202    0.357299    0.048564    0.015019    0.807076    
#> 265: 0.395263    0.996214    3.422200    0.357155    0.048777    0.014939    0.807160    
#> 266: 0.395199    0.996608    3.422220    0.357207    0.048777    0.014905    0.807210    
#> 267: 0.395504    0.996760    3.422459    0.357523    0.048960    0.014867    0.807216    
#> 268: 0.396254    0.996606    3.422507    0.357443    0.048903    0.014819    0.807214    
#> 269: 0.397146    0.996287    3.422620    0.357763    0.048878    0.014822    0.807205    
#> 270: 0.397544    0.996154    3.422602    0.358124    0.048796    0.014810    0.806886    
#> 271: 0.397303    0.996017    3.422502    0.358250    0.048843    0.014788    0.806982    
#> 272: 0.397249    0.995690    3.422410    0.358421    0.048914    0.014727    0.807359    
#> 273: 0.397050    0.995729    3.422424    0.358078    0.049149    0.014725    0.807678    
#> 274: 0.396812    0.995900    3.422404    0.356897    0.049188    0.014643    0.807949    
#> 275: 0.396750    0.996121    3.422223    0.356205    0.049425    0.014597    0.808032    
#> 276: 0.395968    0.996368    3.422342    0.355723    0.049636    0.014555    0.808055    
#> 277: 0.395437    0.996603    3.422502    0.355782    0.049658    0.014561    0.807982    
#> 278: 0.395455    0.996774    3.422485    0.355999    0.049649    0.014567    0.808068    
#> 279: 0.395196    0.996804    3.422378    0.356236    0.049581    0.014609    0.808224    
#> 280: 0.395231    0.996837    3.422451    0.355194    0.049543    0.014611    0.808426    
#> 281: 0.395044    0.996982    3.422503    0.354984    0.049603    0.014618    0.808295    
#> 282: 0.394848    0.997158    3.422546    0.355013    0.049476    0.014695    0.808126    
#> 283: 0.394617    0.997210    3.422536    0.355155    0.049319    0.014794    0.808221    
#> 284: 0.394622    0.997160    3.422507    0.356029    0.049142    0.014918    0.808003    
#> 285: 0.394799    0.997190    3.422490    0.356913    0.048933    0.015042    0.808279    
#> 286: 0.394786    0.997481    3.422397    0.357492    0.048812    0.015153    0.808286    
#> 287: 0.394940    0.997676    3.422356    0.358528    0.048890    0.015225    0.808366    
#> 288: 0.395221    0.997504    3.422310    0.358323    0.048815    0.015303    0.808588    
#> 289: 0.395295    0.997402    3.422315    0.357945    0.048886    0.015351    0.808818    
#> 290: 0.395132    0.997403    3.422319    0.358020    0.048875    0.015340    0.808972    
#> 291: 0.395381    0.997636    3.422440    0.357858    0.048827    0.015344    0.808831    
#> 292: 0.395623    0.997669    3.422554    0.358566    0.048770    0.015345    0.808668    
#> 293: 0.395878    0.997856    3.422531    0.359455    0.048661    0.015329    0.808368    
#> 294: 0.396006    0.998077    3.422527    0.360052    0.048573    0.015323    0.808257    
#> 295: 0.396207    0.997848    3.422493    0.360992    0.048491    0.015344    0.807941    
#> 296: 0.396183    0.997718    3.422492    0.360962    0.048499    0.015382    0.808111    
#> 297: 0.396448    0.997813    3.422496    0.361174    0.048428    0.015398    0.808203    
#> 298: 0.396589    0.997701    3.422509    0.361574    0.048345    0.015400    0.808087    
#> 299: 0.396396    0.997842    3.422436    0.361366    0.048280    0.015407    0.807870    
#> 300: 0.396530    0.997678    3.422449    0.360889    0.048181    0.015410    0.807698    
#> 301: 0.396677    0.997529    3.422390    0.360021    0.048087    0.015437    0.807826    
#> 302: 0.396622    0.997595    3.422296    0.359891    0.048010    0.015440    0.807746    
#> 303: 0.396530    0.997940    3.422208    0.359520    0.047885    0.015473    0.807722    
#> 304: 0.396484    0.998077    3.422064    0.359305    0.047746    0.015539    0.807681    
#> 305: 0.396482    0.997907    3.422054    0.359121    0.047628    0.015611    0.807555    
#> 306: 0.396151    0.997769    3.421935    0.359195    0.047577    0.015664    0.807336    
#> 307: 0.396017    0.997819    3.421854    0.358477    0.047653    0.015692    0.807462    
#> 308: 0.395857    0.997627    3.421920    0.358598    0.047692    0.015745    0.807571    
#> 309: 0.395945    0.997414    3.421928    0.358570    0.047750    0.015776    0.807782    
#> 310: 0.396208    0.997291    3.421757    0.359360    0.047804    0.015776    0.807910    
#> 311: 0.396289    0.997276    3.421774    0.360405    0.047789    0.015817    0.807727    
#> 312: 0.396376    0.997113    3.421742    0.360341    0.047806    0.015834    0.807576    
#> 313: 0.396009    0.996977    3.421642    0.360022    0.047872    0.015838    0.807619    
#> 314: 0.395240    0.997027    3.421438    0.359803    0.047885    0.015853    0.807553    
#> 315: 0.394754    0.997073    3.421385    0.360380    0.047929    0.015893    0.807670    
#> 316: 0.394776    0.997142    3.421275    0.361022    0.047961    0.015900    0.807515    
#> 317: 0.394754    0.997033    3.421271    0.361206    0.048010    0.015899    0.807652    
#> 318: 0.394435    0.997221    3.421104    0.360851    0.048042    0.015904    0.807410    
#> 319: 0.394313    0.997283    3.421082    0.360541    0.048037    0.015899    0.807340    
#> 320: 0.394044    0.997327    3.420967    0.360927    0.048057    0.015898    0.807259    
#> 321: 0.393546    0.997383    3.420766    0.360419    0.048001    0.015893    0.807374    
#> 322: 0.393368    0.997419    3.420616    0.360874    0.047953    0.015899    0.807381    
#> 323: 0.393107    0.997531    3.420546    0.361253    0.047956    0.015907    0.807312    
#> 324: 0.392909    0.997682    3.420612    0.361191    0.048016    0.015913    0.807237    
#> 325: 0.393106    0.997823    3.420621    0.361324    0.048051    0.015905    0.807088    
#> 326: 0.393220    0.997820    3.420611    0.361451    0.048148    0.015887    0.806851    
#> 327: 0.393546    0.997813    3.420671    0.362256    0.048142    0.015917    0.806636    
#> 328: 0.393910    0.997911    3.420659    0.362859    0.048119    0.015907    0.806675    
#> 329: 0.393902    0.997952    3.420621    0.363415    0.048128    0.015900    0.806517    
#> 330: 0.393373    0.998021    3.420544    0.363430    0.048136    0.015884    0.806554    
#> 331: 0.393504    0.998245    3.420549    0.363030    0.048109    0.015873    0.806521    
#> 332: 0.393639    0.998164    3.420693    0.362908    0.048001    0.015879    0.806626    
#> 333: 0.393449    0.998034    3.420695    0.363152    0.047902    0.015928    0.806627    
#> 334: 0.393374    0.997960    3.420605    0.363278    0.047769    0.015969    0.806524    
#> 335: 0.393196    0.997908    3.420530    0.363082    0.047666    0.015973    0.806622    
#> 336: 0.392702    0.998009    3.420461    0.362521    0.047580    0.016011    0.806710    
#> 337: 0.392388    0.998184    3.420327    0.362553    0.047541    0.016057    0.806616    
#> 338: 0.392311    0.998240    3.420397    0.362262    0.047508    0.016108    0.806541    
#> 339: 0.392226    0.998207    3.420514    0.361732    0.047431    0.016128    0.806393    
#> 340: 0.392469    0.997910    3.420708    0.361673    0.047417    0.016163    0.806176    
#> 341: 0.393006    0.997709    3.420905    0.361786    0.047335    0.016184    0.806164    
#> 342: 0.393020    0.997468    3.421056    0.361496    0.047310    0.016199    0.806073    
#> 343: 0.392845    0.997397    3.421067    0.361862    0.047284    0.016234    0.805992    
#> 344: 0.393113    0.997373    3.421118    0.362545    0.047293    0.016259    0.805902    
#> 345: 0.393190    0.997329    3.421113    0.362859    0.047214    0.016277    0.805889    
#> 346: 0.393098    0.997394    3.421016    0.363121    0.047139    0.016300    0.805786    
#> 347: 0.392936    0.997303    3.420868    0.362799    0.047097    0.016356    0.805849    
#> 348: 0.392623    0.997410    3.420734    0.363130    0.047052    0.016386    0.805849    
#> 349: 0.392442    0.997374    3.420666    0.363013    0.047048    0.016391    0.805853    
#> 350: 0.392179    0.997232    3.420600    0.362919    0.047029    0.016393    0.805887    
#> 351: 0.391916    0.997403    3.420425    0.362855    0.047078    0.016395    0.805898    
#> 352: 0.391447    0.997575    3.420332    0.363052    0.047140    0.016420    0.805885    
#> 353: 0.391444    0.997745    3.420268    0.363409    0.047196    0.016440    0.805946    
#> 354: 0.391241    0.997801    3.420120    0.363646    0.047158    0.016470    0.805864    
#> 355: 0.391276    0.997872    3.419963    0.363929    0.047158    0.016482    0.805842    
#> 356: 0.391110    0.997885    3.419910    0.363723    0.047237    0.016495    0.805943    
#> 357: 0.391355    0.998064    3.419823    0.364250    0.047283    0.016483    0.805886    
#> 358: 0.391220    0.998260    3.419777    0.364281    0.047242    0.016479    0.805775    
#> 359: 0.390914    0.998555    3.419629    0.364090    0.047270    0.016478    0.805689    
#> 360: 0.390584    0.998734    3.419351    0.363904    0.047274    0.016461    0.805682    
#> 361: 0.390225    0.998998    3.419138    0.363761    0.047244    0.016459    0.805664    
#> 362: 0.390166    0.999072    3.419050    0.364044    0.047216    0.016460    0.805497    
#> 363: 0.390100    0.999125    3.419017    0.364165    0.047205    0.016478    0.805396    
#> 364: 0.390183    0.999175    3.419009    0.364332    0.047137    0.016503    0.805420    
#> 365: 0.389890    0.999188    3.418947    0.364494    0.047116    0.016555    0.805476    
#> 366: 0.389853    0.999243    3.418816    0.364917    0.047056    0.016593    0.805398    
#> 367: 0.389948    0.999284    3.418881    0.365058    0.047041    0.016608    0.805205    
#> 368: 0.390236    0.999342    3.418884    0.365394    0.046980    0.016638    0.805021    
#> 369: 0.390296    0.999298    3.418856    0.365801    0.046925    0.016660    0.804922    
#> 370: 0.390137    0.999424    3.418834    0.366044    0.046925    0.016690    0.804837    
#> 371: 0.389810    0.999538    3.418668    0.366205    0.046918    0.016718    0.804789    
#> 372: 0.389519    0.999686    3.418511    0.366139    0.046946    0.016743    0.804740    
#> 373: 0.389184    0.999929    3.418359    0.366344    0.047026    0.016756    0.804781    
#> 374: 0.389097    1.000099    3.418267    0.366073    0.047061    0.016731    0.804837    
#> 375: 0.388989    1.000249    3.418222    0.366003    0.047076    0.016710    0.804822    
#> 376: 0.388715    1.000433    3.418138    0.365878    0.047152    0.016683    0.804769    
#> 377: 0.388416    1.000633    3.418057    0.365915    0.047241    0.016665    0.804818    
#> 378: 0.388026    1.000749    3.417946    0.366006    0.047265    0.016631    0.804852    
#> 379: 0.387616    1.000680    3.417893    0.365948    0.047298    0.016618    0.804846    
#> 380: 0.387452    1.000725    3.417850    0.365602    0.047345    0.016610    0.804781    
#> 381: 0.387100    1.000673    3.417822    0.365342    0.047338    0.016588    0.804709    
#> 382: 0.386895    1.000590    3.417830    0.364880    0.047294    0.016597    0.804672    
#> 383: 0.386953    1.000519    3.417850    0.364788    0.047296    0.016590    0.804617    
#> 384: 0.386799    1.000524    3.417885    0.364615    0.047282    0.016600    0.804607    
#> 385: 0.386913    1.000519    3.417852    0.364817    0.047261    0.016628    0.804494    
#> 386: 0.386894    1.000741    3.417841    0.364912    0.047241    0.016637    0.804464    
#> 387: 0.386991    1.000833    3.417869    0.365187    0.047192    0.016655    0.804356    
#> 388: 0.386933    1.000890    3.417839    0.364921    0.047136    0.016692    0.804241    
#> 389: 0.386815    1.000816    3.417830    0.364638    0.047111    0.016708    0.804242    
#> 390: 0.386583    1.000887    3.417716    0.364615    0.047097    0.016733    0.804131    
#> 391: 0.386764    1.000962    3.417687    0.364832    0.047078    0.016761    0.804028    
#> 392: 0.386905    1.000940    3.417793    0.364573    0.047058    0.016771    0.804073    
#> 393: 0.386846    1.000884    3.417754    0.364361    0.047017    0.016793    0.804123    
#> 394: 0.386974    1.000793    3.417756    0.364464    0.046971    0.016793    0.804104    
#> 395: 0.387220    1.000754    3.417783    0.364582    0.046999    0.016786    0.804062    
#> 396: 0.387308    1.000808    3.417760    0.364569    0.047041    0.016787    0.804016    
#> 397: 0.387317    1.000758    3.417806    0.364502    0.047049    0.016797    0.803961    
#> 398: 0.387558    1.000619    3.417907    0.364562    0.047045    0.016823    0.803869    
#> 399: 0.387838    1.000572    3.418049    0.364670    0.046981    0.016842    0.803854    
#> 400: 0.387996    1.000615    3.418136    0.364312    0.046960    0.016867    0.803840    
#> 401: 0.388084    1.000669    3.418161    0.364081    0.046980    0.016882    0.803884    
#> 402: 0.388119    1.000688    3.418172    0.363806    0.046957    0.016910    0.803966    
#> 403: 0.388493    1.000658    3.418253    0.364186    0.046915    0.016930    0.803925    
#> 404: 0.388642    1.000675    3.418248    0.364477    0.046830    0.016943    0.803872    
#> 405: 0.388702    1.000641    3.418304    0.364754    0.046812    0.016957    0.803837    
#> 406: 0.388776    1.000609    3.418331    0.365020    0.046798    0.016979    0.803762    
#> 407: 0.388936    1.000635    3.418370    0.365391    0.046759    0.016968    0.803806    
#> 408: 0.389077    1.000736    3.418385    0.365253    0.046771    0.016974    0.803881    
#> 409: 0.388944    1.000742    3.418304    0.365081    0.046737    0.016969    0.803900    
#> 410: 0.388713    1.000781    3.418174    0.364836    0.046733    0.016972    0.803874    
#> 411: 0.388609    1.000611    3.418109    0.365299    0.046778    0.016981    0.803836    
#> 412: 0.388549    1.000650    3.418035    0.365465    0.046770    0.016993    0.803810    
#> 413: 0.388421    1.000689    3.417907    0.365236    0.046742    0.017000    0.803832    
#> 414: 0.388075    1.000679    3.417836    0.365564    0.046709    0.017019    0.803740    
#> 415: 0.388113    1.000647    3.417813    0.365887    0.046656    0.017043    0.803624    
#> 416: 0.388264    1.000626    3.417849    0.366111    0.046595    0.017061    0.803580    
#> 417: 0.388226    1.000581    3.417864    0.365827    0.046543    0.017052    0.803596    
#> 418: 0.387966    1.000591    3.417832    0.365732    0.046550    0.017025    0.803547    
#> 419: 0.387887    1.000797    3.417800    0.365403    0.046544    0.017005    0.803555    
#> 420: 0.387806    1.000874    3.417765    0.365472    0.046565    0.016990    0.803500    
#> 421: 0.387678    1.000962    3.417781    0.365198    0.046591    0.016977    0.803450    
#> 422: 0.387861    1.000841    3.417806    0.365450    0.046629    0.016981    0.803408    
#> 423: 0.388095    1.000789    3.417823    0.365538    0.046669    0.016968    0.803389    
#> 424: 0.388098    1.000719    3.417791    0.365624    0.046676    0.016960    0.803308    
#> 425: 0.388082    1.000752    3.417751    0.365604    0.046674    0.016967    0.803316    
#> 426: 0.388156    1.000844    3.417727    0.365703    0.046715    0.016957    0.803284    
#> 427: 0.388083    1.000838    3.417760    0.365669    0.046735    0.016968    0.803265    
#> 428: 0.387922    1.000920    3.417751    0.365541    0.046718    0.016969    0.803250    
#> 429: 0.387911    1.000937    3.417759    0.365343    0.046732    0.016968    0.803321    
#> 430: 0.387817    1.001027    3.417739    0.365280    0.046752    0.016976    0.803339    
#> 431: 0.387700    1.001037    3.417668    0.365029    0.046720    0.016962    0.803331    
#> 432: 0.387598    1.001124    3.417616    0.364761    0.046738    0.016975    0.803299    
#> 433: 0.387648    1.001247    3.417614    0.364573    0.046726    0.017005    0.803317    
#> 434: 0.387711    1.001190    3.417614    0.364703    0.046711    0.017034    0.803213    
#> 435: 0.387629    1.001195    3.417611    0.364435    0.046688    0.017054    0.803148    
#> 436: 0.387567    1.001207    3.417635    0.364284    0.046699    0.017047    0.803085    
#> 437: 0.387592    1.001238    3.417635    0.364384    0.046699    0.017060    0.803025    
#> 438: 0.387505    1.001428    3.417600    0.364525    0.046705    0.017067    0.802916    
#> 439: 0.387579    1.001550    3.417602    0.364538    0.046718    0.017054    0.802795    
#> 440: 0.387666    1.001674    3.417595    0.364215    0.046713    0.017037    0.802787    
#> 441: 0.387735    1.001699    3.417626    0.364098    0.046791    0.017011    0.802789    
#> 442: 0.387590    1.001785    3.417661    0.364029    0.046816    0.016990    0.802786    
#> 443: 0.387579    1.001946    3.417613    0.363898    0.046820    0.016990    0.802854    
#> 444: 0.387407    1.002044    3.417578    0.363616    0.046860    0.016992    0.802855    
#> 445: 0.387362    1.002057    3.417550    0.363534    0.046836    0.017019    0.802941    
#> 446: 0.387140    1.002081    3.417495    0.363314    0.046778    0.017040    0.803084    
#> 447: 0.387214    1.002092    3.417531    0.363261    0.046705    0.017072    0.803119    
#> 448: 0.387276    1.002013    3.417620    0.363081    0.046680    0.017103    0.803142    
#> 449: 0.387384    1.002025    3.417761    0.362714    0.046656    0.017123    0.803293    
#> 450: 0.387373    1.002078    3.417754    0.362625    0.046602    0.017147    0.803388    
#> 451: 0.387613    1.002166    3.417723    0.362690    0.046607    0.017156    0.803424    
#> 452: 0.387575    1.002269    3.417641    0.362633    0.046624    0.017143    0.803397    
#> 453: 0.387437    1.002385    3.417533    0.362529    0.046697    0.017127    0.803340    
#> 454: 0.387194    1.002514    3.417445    0.362314    0.046764    0.017122    0.803287    
#> 455: 0.387101    1.002563    3.417364    0.362283    0.046751    0.017117    0.803259    
#> 456: 0.387041    1.002525    3.417343    0.362383    0.046760    0.017121    0.803223    
#> 457: 0.386981    1.002540    3.417373    0.362506    0.046763    0.017135    0.803110    
#> 458: 0.387031    1.002669    3.417415    0.362640    0.046778    0.017153    0.803030    
#> 459: 0.386844    1.002815    3.417397    0.362506    0.046795    0.017150    0.803081    
#> 460: 0.386674    1.002867    3.417370    0.362288    0.046800    0.017147    0.803024    
#> 461: 0.386591    1.002928    3.417372    0.362153    0.046804    0.017171    0.802974    
#> 462: 0.386569    1.003003    3.417413    0.361991    0.046774    0.017197    0.802973    
#> 463: 0.386686    1.003081    3.417463    0.362058    0.046747    0.017196    0.802966    
#> 464: 0.386834    1.003086    3.417478    0.362218    0.046705    0.017206    0.802861    
#> 465: 0.386852    1.002947    3.417486    0.362360    0.046700    0.017209    0.802788    
#> 466: 0.386829    1.002915    3.417432    0.362424    0.046692    0.017198    0.802756    
#> 467: 0.386664    1.002900    3.417428    0.362553    0.046701    0.017208    0.802670    
#> 468: 0.386746    1.002870    3.417457    0.362742    0.046724    0.017198    0.802681    
#> 469: 0.386927    1.002927    3.417541    0.362684    0.046734    0.017213    0.802652    
#> 470: 0.387070    1.002918    3.417596    0.362509    0.046743    0.017243    0.802618    
#> 471: 0.387128    1.002908    3.417633    0.362368    0.046755    0.017236    0.802560    
#> 472: 0.387129    1.002909    3.417649    0.362372    0.046733    0.017255    0.802508    
#> 473: 0.387134    1.002945    3.417653    0.362295    0.046702    0.017262    0.802432    
#> 474: 0.387152    1.002945    3.417644    0.362206    0.046669    0.017277    0.802447    
#> 475: 0.387257    1.002964    3.417666    0.362043    0.046660    0.017284    0.802469    
#> 476: 0.387279    1.002978    3.417621    0.361956    0.046655    0.017290    0.802541    
#> 477: 0.387314    1.003067    3.417613    0.362001    0.046622    0.017306    0.802465    
#> 478: 0.387343    1.003126    3.417615    0.361883    0.046563    0.017326    0.802503    
#> 479: 0.387498    1.003136    3.417674    0.361753    0.046572    0.017344    0.802568    
#> 480: 0.387668    1.003169    3.417735    0.361639    0.046615    0.017356    0.802562    
#> 481: 0.387672    1.003129    3.417745    0.361528    0.046589    0.017351    0.802542    
#> 482: 0.387752    1.003075    3.417757    0.361489    0.046564    0.017346    0.802590    
#> 483: 0.387701    1.003031    3.417763    0.361305    0.046580    0.017330    0.802660    
#> 484: 0.387803    1.002946    3.417794    0.361646    0.046611    0.017321    0.802667    
#> 485: 0.387879    1.003030    3.417816    0.361826    0.046621    0.017320    0.802614    
#> 486: 0.387909    1.003106    3.417849    0.361837    0.046609    0.017311    0.802621    
#> 487: 0.388109    1.003134    3.417926    0.361789    0.046600    0.017303    0.802615    
#> 488: 0.388193    1.003104    3.417950    0.361763    0.046593    0.017301    0.802642    
#> 489: 0.388273    1.003031    3.417960    0.361766    0.046589    0.017310    0.802708    
#> 490: 0.388411    1.003048    3.417997    0.361868    0.046565    0.017305    0.802682    
#> 491: 0.388425    1.003114    3.418019    0.362031    0.046550    0.017310    0.802693    
#> 492: 0.388284    1.003167    3.418003    0.361986    0.046591    0.017300    0.802798    
#> 493: 0.388255    1.003147    3.418023    0.361808    0.046631    0.017301    0.802864    
#> 494: 0.388392    1.003255    3.417984    0.361800    0.046704    0.017304    0.802837    
#> 495: 0.388412    1.003329    3.418000    0.361878    0.046722    0.017332    0.802743    
#> 496: 0.388614    1.003419    3.417987    0.361961    0.046702    0.017352    0.802692    
#> 497: 0.388473    1.003448    3.417960    0.362107    0.046681    0.017349    0.802677    
#> 498: 0.388431    1.003501    3.417910    0.362316    0.046670    0.017359    0.802579    
#> 499: 0.388449    1.003582    3.417861    0.362427    0.046693    0.017371    0.802574    
#> 500: 0.388445    1.003574    3.417825    0.362420    0.046702    0.017364    0.802466    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.332273    0.972228    3.442745    0.392401    0.086326    0.016800    1.825289    
#> 002: 0.526052    1.013637    3.440461    0.372781    0.082009    0.015960    1.258996    
#> 003: 0.757080    0.958781    3.450667    0.354142    0.122333    0.015162    0.904453    
#> 004: 0.740900    0.990345    3.436989    0.336435    0.151948    0.014404    0.811795    
#> 005: 0.788717    0.977784    3.448195    0.319613    0.149400    0.013684    0.791503    
#> 006: 0.790179    1.007123    3.440972    0.322007    0.141930    0.013000    0.769294    
#> 007: 0.792371    0.991547    3.442174    0.374590    0.134834    0.012350    0.793067    
#> 008: 0.765589    0.982378    3.442125    0.360167    0.141679    0.011732    0.779545    
#> 009: 0.749059    0.970723    3.441718    0.342159    0.134595    0.011146    0.806574    
#> 010: 0.772135    0.979921    3.448948    0.325051    0.135348    0.010588    0.809157    
#> 011: 0.819872    0.999027    3.450075    0.317402    0.138112    0.010059    0.808488    
#> 012: 0.828995    0.986630    3.442484    0.301532    0.131206    0.009556    0.799272    
#> 013: 0.752743    0.959772    3.446530    0.286455    0.141434    0.009078    0.781898    
#> 014: 0.847022    0.982168    3.451734    0.320982    0.134510    0.008624    0.809502    
#> 015: 0.849218    0.962939    3.480367    0.304933    0.128040    0.008193    0.776769    
#> 016: 0.865105    0.966616    3.483673    0.379496    0.121638    0.009496    0.778051    
#> 017: 0.834833    0.976978    3.480097    0.360521    0.115556    0.010641    0.763382    
#> 018: 0.869424    0.988342    3.460395    0.342495    0.109778    0.011270    0.785916    
#> 019: 0.823523    0.977184    3.458796    0.329181    0.111824    0.010706    0.779528    
#> 020: 0.809105    0.988063    3.471122    0.323706    0.123679    0.010171    0.785422    
#> 021: 0.824664    0.951190    3.479932    0.307521    0.117495    0.009663    0.779709    
#> 022: 0.826343    0.958280    3.491061    0.292145    0.120236    0.009179    0.773443    
#> 023: 0.893958    0.950951    3.498111    0.277538    0.114225    0.008720    0.807655    
#> 024: 0.928354    0.973803    3.495818    0.316405    0.117608    0.008297    0.797773    
#> 025: 0.902294    0.949007    3.488773    0.334636    0.130495    0.007882    0.791845    
#> 026: 0.875979    0.986758    3.477323    0.376381    0.123970    0.009642    0.767969    
#> 027: 0.860115    1.004104    3.472713    0.357693    0.117771    0.009160    0.807220    
#> 028: 0.912448    0.976794    3.477541    0.364535    0.112942    0.008702    0.761543    
#> 029: 0.915264    0.963782    3.467552    0.458451    0.128579    0.008267    0.787648    
#> 030: 0.869278    0.979630    3.458428    0.441109    0.123201    0.007854    0.772616    
#> 031: 0.848454    0.963915    3.460543    0.447800    0.140598    0.007461    0.761144    
#> 032: 0.818704    0.946468    3.462933    0.425410    0.133568    0.007088    0.760918    
#> 033: 0.831690    0.973454    3.462227    0.404139    0.126890    0.006954    0.756090    
#> 034: 0.837856    0.978493    3.463672    0.401183    0.145321    0.006606    0.777560    
#> 035: 0.836186    0.965392    3.462368    0.381124    0.138055    0.006276    0.762769    
#> 036: 0.818007    0.991032    3.461077    0.362068    0.133824    0.006466    0.775600    
#> 037: 0.796666    0.987469    3.470984    0.408988    0.127133    0.008117    0.771877    
#> 038: 0.880044    0.978066    3.474411    0.388538    0.122508    0.007864    0.766216    
#> 039: 0.924725    0.963172    3.484285    0.433384    0.122988    0.009894    0.752760    
#> 040: 0.900696    0.954966    3.493404    0.427772    0.116838    0.009400    0.780729    
#> 041: 0.890325    0.938512    3.492395    0.406383    0.116551    0.008930    0.754821    
#> 042: 0.917743    0.974194    3.483657    0.477482    0.131079    0.008580    0.755120    
#> 043: 0.841810    0.989239    3.467742    0.453608    0.124525    0.008388    0.772816    
#> 044: 0.854558    0.992735    3.468641    0.430928    0.132697    0.008793    0.761115    
#> 045: 0.841941    1.004734    3.459646    0.454088    0.126062    0.008353    0.757606    
#> 046: 0.891686    0.984377    3.462186    0.549822    0.144708    0.009219    0.745319    
#> 047: 0.927443    0.995421    3.458932    0.591562    0.137472    0.008758    0.753506    
#> 048: 0.887839    0.984100    3.452963    0.641697    0.130599    0.008320    0.758828    
#> 049: 0.845732    0.987470    3.455423    0.609612    0.129499    0.007904    0.774038    
#> 050: 0.913231    0.936040    3.467472    0.579131    0.123627    0.007509    0.775186    
#> 051: 0.909747    0.974234    3.460496    0.550175    0.124485    0.007134    0.779826    
#> 052: 0.933665    0.989258    3.478103    0.522666    0.118261    0.006777    0.765975    
#> 053: 0.905555    0.979045    3.478644    0.496533    0.120569    0.006438    0.782847    
#> 054: 0.832041    0.978271    3.470034    0.480095    0.134390    0.006282    0.784822    
#> 055: 0.828205    0.985441    3.472662    0.456090    0.127670    0.007693    0.783099    
#> 056: 0.875747    0.958328    3.478473    0.433286    0.125143    0.007478    0.787705    
#> 057: 0.862430    0.942229    3.492131    0.411622    0.118886    0.008249    0.795931    
#> 058: 0.833947    0.961420    3.474506    0.391041    0.134836    0.007836    0.801501    
#> 059: 0.889126    0.932359    3.473041    0.419293    0.160600    0.007444    0.817035    
#> 060: 0.868717    0.929003    3.483604    0.484941    0.152570    0.007438    0.811212    
#> 061: 0.916837    0.949068    3.484813    0.516197    0.151351    0.008634    0.808743    
#> 062: 0.870126    0.974758    3.487978    0.490387    0.155461    0.009311    0.814584    
#> 063: 0.908797    0.940071    3.488384    0.546058    0.159151    0.009398    0.786086    
#> 064: 0.865683    0.953735    3.482044    0.518755    0.151193    0.008928    0.783766    
#> 065: 0.941612    0.943189    3.469292    0.495292    0.143633    0.008481    0.766945    
#> 066: 0.874754    0.982199    3.473006    0.475272    0.153139    0.008057    0.759302    
#> 067: 0.837232    0.968029    3.469994    0.451508    0.145482    0.009600    0.766132    
#> 068: 0.822067    0.989306    3.475816    0.428933    0.138208    0.010327    0.808245    
#> 069: 0.820927    0.936467    3.474584    0.407486    0.131297    0.011420    0.787261    
#> 070: 0.843641    0.942483    3.492079    0.387112    0.124733    0.012647    0.789129    
#> 071: 0.843071    0.988484    3.473299    0.367756    0.118989    0.012015    0.812923    
#> 072: 0.828467    0.932787    3.470638    0.349368    0.149771    0.012084    0.778447    
#> 073: 0.858550    0.964258    3.493142    0.331900    0.146669    0.011479    0.770499    
#> 074: 0.866073    0.947841    3.488784    0.315305    0.139335    0.010905    0.774410    
#> 075: 0.885124    0.953877    3.507280    0.354963    0.136959    0.010967    0.766598    
#> 076: 0.934380    0.965091    3.511126    0.337214    0.130111    0.012341    0.773414    
#> 077: 0.934572    0.923143    3.501758    0.320354    0.123606    0.012775    0.762492    
#> 078: 0.903563    0.954073    3.497315    0.328984    0.117425    0.012136    0.751414    
#> 079: 0.929987    0.963233    3.492899    0.423533    0.117361    0.012449    0.770224    
#> 080: 0.890362    0.960711    3.493261    0.402356    0.117819    0.015658    0.792069    
#> 081: 0.829946    0.967209    3.478097    0.382238    0.111928    0.018056    0.778025    
#> 082: 0.838928    0.964525    3.485361    0.363126    0.114157    0.017154    0.798960    
#> 083: 0.886057    0.989542    3.485004    0.352322    0.112243    0.016296    0.774700    
#> 084: 0.872143    0.978014    3.477848    0.334706    0.106631    0.015481    0.781050    
#> 085: 0.878036    0.971707    3.495457    0.342419    0.101299    0.014707    0.766254    
#> 086: 0.851500    0.972509    3.484916    0.374324    0.102920    0.014873    0.754885    
#> 087: 0.858503    0.990204    3.472838    0.355607    0.097774    0.014130    0.763741    
#> 088: 0.778112    0.974638    3.467147    0.366442    0.126728    0.013423    0.764197    
#> 089: 0.805926    0.988638    3.451508    0.348120    0.129551    0.012752    0.785695    
#> 090: 0.765051    0.975515    3.456382    0.330714    0.131856    0.012114    0.795008    
#> 091: 0.773171    0.966205    3.444343    0.314178    0.125263    0.011509    0.792860    
#> 092: 0.767415    0.993871    3.451534    0.298469    0.119000    0.010933    0.806848    
#> 093: 0.752508    0.988200    3.449298    0.322157    0.119385    0.011381    0.777439    
#> 094: 0.752042    0.997452    3.438744    0.306049    0.129408    0.010812    0.767462    
#> 095: 0.767139    0.988848    3.460301    0.344526    0.122938    0.010271    0.771814    
#> 096: 0.738433    0.992290    3.457179    0.327299    0.116791    0.009758    0.759225    
#> 097: 0.839846    0.995904    3.464285    0.341857    0.118293    0.009270    0.754526    
#> 098: 0.853392    0.998612    3.479743    0.345985    0.112378    0.009070    0.780830    
#> 099: 0.808984    0.966449    3.471657    0.328686    0.108929    0.008616    0.772600    
#> 100: 0.839968    0.975779    3.466174    0.428996    0.106988    0.008186    0.745297    
#> 101: 0.798331    0.960813    3.449248    0.407547    0.110306    0.007776    0.752620    
#> 102: 0.789283    0.972865    3.441852    0.387169    0.115462    0.007388    0.767524    
#> 103: 0.813626    0.959423    3.456472    0.367811    0.109689    0.007018    0.770011    
#> 104: 0.813933    0.963184    3.462906    0.377041    0.114368    0.006927    0.779629    
#> 105: 0.849043    0.964594    3.468033    0.412281    0.135873    0.006580    0.801904    
#> 106: 0.886742    0.959512    3.465347    0.474075    0.134101    0.006251    0.770633    
#> 107: 0.891065    0.965026    3.467926    0.456059    0.136406    0.006411    0.768933    
#> 108: 0.861464    0.975926    3.461126    0.433256    0.129586    0.006091    0.793202    
#> 109: 0.840727    0.972723    3.471402    0.411593    0.140259    0.005786    0.803878    
#> 110: 0.846347    0.969625    3.460998    0.391014    0.156417    0.005497    0.790110    
#> 111: 0.826968    0.978782    3.462265    0.371463    0.148596    0.005758    0.777563    
#> 112: 0.800516    0.958572    3.449838    0.352890    0.141166    0.005470    0.781142    
#> 113: 0.796968    1.012270    3.448681    0.335245    0.134108    0.005196    0.774635    
#> 114: 0.798592    0.965773    3.456650    0.348836    0.127403    0.004937    0.771896    
#> 115: 0.846695    0.950527    3.453481    0.406558    0.146383    0.004690    0.782265    
#> 116: 0.879027    0.977234    3.461131    0.422123    0.139064    0.004455    0.779043    
#> 117: 0.850837    0.994922    3.459489    0.401017    0.136882    0.004232    0.784970    
#> 118: 0.887260    0.964854    3.466927    0.380966    0.137170    0.004021    0.797889    
#> 119: 0.855764    0.982788    3.467859    0.361918    0.130311    0.005617    0.781950    
#> 120: 0.828633    0.939717    3.474895    0.343822    0.125176    0.006654    0.770666    
#> 121: 0.824500    0.986920    3.470084    0.326631    0.124125    0.006648    0.771334    
#> 122: 0.834194    0.960609    3.472081    0.311735    0.139187    0.006315    0.761873    
#> 123: 0.837194    0.971795    3.477808    0.296148    0.132227    0.006652    0.779565    
#> 124: 0.865123    0.989284    3.481209    0.304477    0.132659    0.008365    0.765862    
#> 125: 0.896594    0.987642    3.477431    0.416073    0.136007    0.007947    0.760302    
#> 126: 0.852920    0.977744    3.471325    0.423669    0.129206    0.007573    0.763650    
#> 127: 0.856627    0.968651    3.464708    0.490098    0.126938    0.007194    0.769951    
#> 128: 0.807874    0.979117    3.465664    0.498227    0.120591    0.008160    0.782040    
#> 129: 0.828581    0.971168    3.466518    0.473316    0.115724    0.007752    0.769111    
#> 130: 0.874319    0.987886    3.471873    0.449650    0.111467    0.007365    0.756852    
#> 131: 0.848010    0.966957    3.463969    0.427168    0.120182    0.006996    0.774316    
#> 132: 0.835352    0.973113    3.451809    0.417670    0.159031    0.007191    0.767855    
#> 133: 0.837909    0.964748    3.458197    0.397590    0.151079    0.008224    0.775791    
#> 134: 0.864954    0.965651    3.468574    0.377710    0.143525    0.011924    0.764192    
#> 135: 0.850230    0.960804    3.477001    0.358825    0.152068    0.011327    0.749385    
#> 136: 0.855204    0.938200    3.473652    0.340884    0.144465    0.010761    0.760082    
#> 137: 0.885861    0.940016    3.477876    0.356453    0.137241    0.010223    0.766186    
#> 138: 0.856569    0.977682    3.477369    0.341621    0.137049    0.009712    0.744992    
#> 139: 0.878909    0.972659    3.485450    0.387587    0.130196    0.010379    0.761458    
#> 140: 0.866355    0.975593    3.486627    0.368207    0.123686    0.009860    0.771842    
#> 141: 0.846074    0.972067    3.487478    0.349797    0.121636    0.009367    0.767327    
#> 142: 0.880671    0.926648    3.488210    0.348267    0.128446    0.008899    0.790892    
#> 143: 0.872009    0.976319    3.487018    0.421293    0.130874    0.008454    0.784807    
#> 144: 0.975592    0.964092    3.499571    0.461334    0.125924    0.008031    0.778887    
#> 145: 0.933321    0.960392    3.486620    0.486330    0.119628    0.007870    0.759643    
#> 146: 0.937417    0.956861    3.496880    0.462013    0.113647    0.009527    0.779878    
#> 147: 0.857318    0.923116    3.486031    0.438913    0.110143    0.009703    0.759153    
#> 148: 0.830712    0.943541    3.492520    0.416967    0.110679    0.010415    0.759514    
#> 149: 0.867717    0.953285    3.491424    0.396119    0.147715    0.011642    0.765093    
#> 150: 0.897625    0.958309    3.484229    0.386889    0.153330    0.011060    0.750464    
#> 151: 0.830902    0.981596    3.476483    0.376590    0.145663    0.010507    0.754041    
#> 152: 0.815741    0.968137    3.477212    0.337086    0.112359    0.008496    0.748607    
#> 153: 0.844028    0.956721    3.482008    0.313977    0.098002    0.011917    0.760408    
#> 154: 0.875427    0.986563    3.481473    0.317726    0.101150    0.012543    0.772072    
#> 155: 0.821030    0.975248    3.483099    0.278614    0.124262    0.013576    0.765702    
#> 156: 0.827909    0.985110    3.482410    0.246056    0.142026    0.011535    0.787472    
#> 157: 0.910439    0.952432    3.498236    0.294796    0.128480    0.010386    0.788071    
#> 158: 0.868137    0.962138    3.484317    0.278386    0.134522    0.011605    0.776367    
#> 159: 0.850881    0.948002    3.491580    0.336713    0.129852    0.010562    0.761019    
#> 160: 0.893185    0.935641    3.492366    0.392606    0.128701    0.013063    0.767500    
#> 161: 0.864819    0.939913    3.485015    0.392515    0.115470    0.012442    0.759474    
#> 162: 0.867537    0.966137    3.476148    0.334184    0.107806    0.013349    0.776442    
#> 163: 0.863716    0.964325    3.474947    0.292631    0.109185    0.010451    0.800943    
#> 164: 0.847753    0.966239    3.474090    0.391084    0.097031    0.011114    0.794412    
#> 165: 0.887164    0.953047    3.480793    0.459390    0.101923    0.010858    0.781842    
#> 166: 0.935523    0.984915    3.480727    0.480443    0.092866    0.011794    0.790333    
#> 167: 0.913898    0.990745    3.488104    0.525920    0.096870    0.014004    0.764106    
#> 168: 0.894235    0.994982    3.493974    0.379028    0.102768    0.015599    0.768842    
#> 169: 0.902152    1.017415    3.480059    0.371378    0.110868    0.013715    0.797091    
#> 170: 0.877377    0.974769    3.484611    0.315399    0.109408    0.012051    0.763518    
#> 171: 0.826834    0.988098    3.481383    0.289617    0.112624    0.012450    0.744934    
#> 172: 0.828328    0.990416    3.476446    0.251703    0.107644    0.012529    0.762598    
#> 173: 0.834033    0.989893    3.470417    0.295888    0.107454    0.014776    0.752928    
#> 174: 0.843271    0.977786    3.481629    0.317220    0.100703    0.016057    0.761453    
#> 175: 0.839386    0.991824    3.470829    0.286494    0.091302    0.014062    0.770424    
#> 176: 0.830486    0.988726    3.470643    0.361659    0.105795    0.014652    0.750782    
#> 177: 0.852553    0.981261    3.478634    0.298185    0.107976    0.013066    0.766644    
#> 178: 0.856872    0.961960    3.485279    0.310655    0.104467    0.012999    0.754789    
#> 179: 0.913347    0.977963    3.484913    0.438843    0.120631    0.013813    0.747059    
#> 180: 0.855494    0.970771    3.477848    0.374213    0.105133    0.011951    0.749604    
#> 181: 0.856832    0.980050    3.459336    0.350168    0.090460    0.012233    0.742995    
#> 182: 0.798025    0.978842    3.458221    0.296445    0.096452    0.011826    0.784488    
#> 183: 0.811604    1.006728    3.462334    0.325728    0.103854    0.012492    0.766570    
#> 184: 0.809995    0.974624    3.471575    0.324642    0.096902    0.011129    0.760929    
#> 185: 0.797972    1.016153    3.460046    0.298563    0.114223    0.010411    0.757549    
#> 186: 0.834805    1.004341    3.472563    0.349474    0.131918    0.010564    0.749917    
#> 187: 0.877514    0.981268    3.483337    0.411473    0.119143    0.010219    0.758703    
#> 188: 0.808148    1.003700    3.479140    0.323342    0.131572    0.010279    0.781557    
#> 189: 0.844861    0.980586    3.480367    0.307273    0.126136    0.010573    0.783821    
#> 190: 0.831485    0.976436    3.488910    0.298118    0.114274    0.008854    0.757689    
#> 191: 0.833147    0.983942    3.474959    0.317693    0.104377    0.007051    0.764375    
#> 192: 0.815134    0.997401    3.470617    0.369809    0.122022    0.005943    0.759630    
#> 193: 0.859893    1.013568    3.469381    0.356795    0.136547    0.005438    0.756427    
#> 194: 0.838378    0.982297    3.457396    0.386274    0.127511    0.004206    0.785645    
#> 195: 0.797940    0.983197    3.446792    0.382672    0.098386    0.004405    0.794993    
#> 196: 0.764556    0.990518    3.456893    0.350926    0.121211    0.004203    0.790292    
#> 197: 0.747633    0.994160    3.470459    0.325273    0.121362    0.005679    0.799811    
#> 198: 0.851214    0.961945    3.461349    0.342784    0.117526    0.006383    0.772658    
#> 199: 0.771285    0.971392    3.464800    0.334901    0.127413    0.006697    0.783104    
#> 200: 0.809789    0.971539    3.467648    0.299978    0.143654    0.009106    0.772999    
#> 201: 0.794324    0.976747    3.467580    0.304466    0.134977    0.009175    0.770002    
#> 202: 0.808862    0.972877    3.467657    0.322688    0.122477    0.009264    0.783746    
#> 203: 0.836858    0.969769    3.469380    0.342144    0.121512    0.009835    0.782766    
#> 204: 0.844032    0.963037    3.470871    0.370300    0.121319    0.009569    0.782923    
#> 205: 0.845895    0.967784    3.469793    0.383821    0.121903    0.009382    0.785309    
#> 206: 0.848686    0.973883    3.469872    0.381403    0.122581    0.009152    0.788266    
#> 207: 0.846405    0.976009    3.468515    0.386488    0.123046    0.009122    0.788212    
#> 208: 0.845463    0.978268    3.468502    0.382472    0.121451    0.009243    0.787464    
#> 209: 0.847756    0.977025    3.468780    0.373589    0.120796    0.009305    0.785946    
#> 210: 0.851505    0.974909    3.469891    0.372020    0.122561    0.009195    0.783918    
#> 211: 0.852949    0.975357    3.471385    0.366649    0.125882    0.009137    0.783105    
#> 212: 0.854751    0.974794    3.472011    0.364490    0.126535    0.009012    0.781568    
#> 213: 0.857582    0.972607    3.472465    0.363241    0.126426    0.008950    0.782207    
#> 214: 0.857314    0.972493    3.472472    0.361390    0.127589    0.008864    0.782973    
#> 215: 0.858743    0.971831    3.473116    0.363388    0.129003    0.008775    0.782307    
#> 216: 0.860330    0.970984    3.473255    0.363757    0.130446    0.008654    0.783388    
#> 217: 0.861506    0.971187    3.473228    0.367245    0.130531    0.008495    0.782686    
#> 218: 0.861532    0.971929    3.472907    0.365008    0.130417    0.008365    0.782276    
#> 219: 0.860003    0.971987    3.472084    0.364216    0.129130    0.008437    0.782042    
#> 220: 0.857195    0.972520    3.471592    0.361369    0.128559    0.008566    0.782156    
#> 221: 0.854469    0.973264    3.470800    0.360936    0.128067    0.008597    0.781106    
#> 222: 0.852500    0.973175    3.470489    0.357553    0.128575    0.008647    0.780773    
#> 223: 0.853037    0.973225    3.470403    0.357354    0.127723    0.008747    0.780065    
#> 224: 0.854325    0.973458    3.470859    0.356680    0.127304    0.008749    0.779797    
#> 225: 0.855799    0.971630    3.471413    0.359361    0.126136    0.008858    0.780099    
#> 226: 0.857460    0.970682    3.471512    0.361315    0.125886    0.008849    0.779983    
#> 227: 0.857223    0.970895    3.471735    0.360282    0.126151    0.008822    0.779676    
#> 228: 0.856160    0.971671    3.471107    0.358921    0.126205    0.008845    0.779114    
#> 229: 0.855292    0.970905    3.470767    0.357914    0.125604    0.008813    0.778029    
#> 230: 0.855474    0.970541    3.470610    0.355841    0.125309    0.008714    0.777547    
#> 231: 0.855428    0.971065    3.470621    0.353760    0.125052    0.008649    0.777427    
#> 232: 0.854118    0.971039    3.470974    0.352540    0.125033    0.008641    0.776840    
#> 233: 0.852958    0.970067    3.470976    0.354223    0.125005    0.008594    0.776713    
#> 234: 0.851749    0.969930    3.470939    0.355122    0.125172    0.008589    0.776042    
#> 235: 0.850435    0.969507    3.470694    0.353686    0.124875    0.008524    0.776417    
#> 236: 0.849957    0.969924    3.470476    0.352339    0.124729    0.008461    0.776703    
#> 237: 0.850528    0.969935    3.470440    0.352562    0.124470    0.008420    0.777192    
#> 238: 0.850149    0.969686    3.470329    0.352057    0.124652    0.008358    0.778022    
#> 239: 0.849875    0.969864    3.470282    0.350800    0.125162    0.008296    0.778094    
#> 240: 0.851824    0.969138    3.470854    0.351879    0.125869    0.008241    0.777743    
#> 241: 0.852932    0.968485    3.471157    0.352644    0.126521    0.008197    0.777244    
#> 242: 0.852408    0.968002    3.471100    0.352260    0.126513    0.008158    0.777504    
#> 243: 0.851364    0.967863    3.471117    0.351240    0.126646    0.008142    0.777653    
#> 244: 0.850569    0.968106    3.471037    0.350570    0.126633    0.008173    0.778028    
#> 245: 0.850026    0.967608    3.471241    0.350718    0.127219    0.008201    0.778374    
#> 246: 0.849914    0.967221    3.471461    0.350736    0.127073    0.008214    0.778460    
#> 247: 0.849905    0.967051    3.471816    0.349192    0.127206    0.008214    0.778701    
#> 248: 0.850033    0.967265    3.471960    0.348720    0.127237    0.008160    0.778752    
#> 249: 0.849927    0.967152    3.472081    0.348908    0.127146    0.008126    0.778688    
#> 250: 0.850567    0.967011    3.472230    0.348311    0.127299    0.008120    0.778632    
#> 251: 0.851035    0.967564    3.472563    0.348797    0.127532    0.008127    0.778704    
#> 252: 0.851626    0.967840    3.472826    0.349555    0.127788    0.008084    0.778769    
#> 253: 0.851330    0.967937    3.473030    0.349397    0.127975    0.008081    0.778507    
#> 254: 0.851446    0.968441    3.473307    0.348286    0.128143    0.008064    0.778267    
#> 255: 0.851614    0.968691    3.473643    0.348324    0.128147    0.008076    0.778224    
#> 256: 0.852013    0.968249    3.473797    0.348130    0.127788    0.008075    0.778428    
#> 257: 0.852032    0.967825    3.473940    0.347873    0.127424    0.008034    0.778406    
#> 258: 0.851826    0.967251    3.473938    0.347775    0.127313    0.007994    0.778256    
#> 259: 0.852031    0.967111    3.473899    0.348164    0.127132    0.007990    0.777834    
#> 260: 0.851899    0.967038    3.474019    0.348235    0.127002    0.008006    0.777336    
#> 261: 0.852123    0.966831    3.474065    0.348212    0.127119    0.008007    0.777152    
#> 262: 0.853046    0.966939    3.474179    0.349184    0.127384    0.007989    0.777046    
#> 263: 0.852660    0.967007    3.474155    0.349330    0.127521    0.008015    0.777116    
#> 264: 0.851872    0.967016    3.474100    0.349080    0.128133    0.008001    0.777492    
#> 265: 0.852002    0.967024    3.474148    0.350406    0.128915    0.007998    0.777495    
#> 266: 0.852439    0.967014    3.474219    0.351184    0.129183    0.007984    0.777455    
#> 267: 0.852637    0.966714    3.474334    0.352005    0.129554    0.007961    0.777397    
#> 268: 0.853142    0.966464    3.474312    0.352526    0.129253    0.007936    0.777634    
#> 269: 0.853977    0.966421    3.474315    0.352737    0.129156    0.007940    0.777642    
#> 270: 0.854110    0.966885    3.474094    0.352938    0.129177    0.007924    0.777394    
#> 271: 0.853648    0.967185    3.473821    0.352836    0.129166    0.007919    0.777510    
#> 272: 0.853302    0.967242    3.473666    0.352292    0.129274    0.007907    0.777682    
#> 273: 0.853192    0.967672    3.473698    0.352013    0.129673    0.007905    0.777968    
#> 274: 0.852544    0.967734    3.473721    0.352224    0.129568    0.007896    0.778084    
#> 275: 0.852895    0.967551    3.473718    0.351807    0.129509    0.007883    0.778179    
#> 276: 0.852964    0.967794    3.473939    0.352381    0.129710    0.007894    0.778010    
#> 277: 0.853276    0.968109    3.474161    0.352138    0.129825    0.007918    0.777997    
#> 278: 0.852809    0.968226    3.474185    0.351245    0.129996    0.007912    0.778284    
#> 279: 0.852280    0.967876    3.474194    0.349977    0.130128    0.007899    0.778684    
#> 280: 0.852182    0.967992    3.474230    0.350386    0.130052    0.007906    0.778576    
#> 281: 0.852120    0.968099    3.474298    0.350474    0.130065    0.007877    0.778456    
#> 282: 0.852370    0.968328    3.474379    0.350594    0.130313    0.007835    0.778251    
#> 283: 0.852720    0.968244    3.474374    0.350946    0.130318    0.007796    0.778359    
#> 284: 0.852658    0.968005    3.474339    0.351259    0.130098    0.007784    0.778358    
#> 285: 0.852443    0.968308    3.474139    0.350959    0.130474    0.007774    0.778518    
#> 286: 0.851587    0.968898    3.473865    0.350142    0.130673    0.007761    0.778551    
#> 287: 0.850681    0.969423    3.473586    0.350179    0.130857    0.007760    0.778520    
#> 288: 0.850883    0.969543    3.473453    0.350308    0.131039    0.007749    0.778708    
#> 289: 0.851439    0.969402    3.473425    0.350406    0.131001    0.007747    0.778758    
#> 290: 0.851939    0.969260    3.473372    0.351227    0.131235    0.007725    0.779035    
#> 291: 0.852448    0.969536    3.473379    0.352381    0.131325    0.007714    0.778870    
#> 292: 0.852168    0.969672    3.473296    0.353050    0.131414    0.007678    0.778902    
#> 293: 0.851701    0.969768    3.473081    0.352872    0.131433    0.007650    0.778643    
#> 294: 0.851145    0.969871    3.472858    0.353247    0.131429    0.007612    0.778620    
#> 295: 0.850541    0.969779    3.472706    0.352819    0.131412    0.007602    0.778497    
#> 296: 0.850259    0.969966    3.472578    0.352817    0.131359    0.007612    0.778558    
#> 297: 0.850128    0.970248    3.472568    0.352633    0.131286    0.007633    0.778622    
#> 298: 0.850232    0.970215    3.472550    0.352741    0.131150    0.007619    0.778603    
#> 299: 0.850203    0.970251    3.472451    0.352336    0.131126    0.007589    0.778612    
#> 300: 0.850505    0.970094    3.472484    0.352588    0.131116    0.007563    0.778540    
#> 301: 0.850853    0.969902    3.472446    0.352637    0.131174    0.007549    0.778399    
#> 302: 0.850637    0.969912    3.472428    0.351695    0.131184    0.007532    0.778309    
#> 303: 0.850414    0.970023    3.472435    0.351237    0.131179    0.007545    0.778162    
#> 304: 0.850346    0.970339    3.472381    0.351621    0.131219    0.007550    0.777989    
#> 305: 0.850056    0.970090    3.472431    0.351749    0.131356    0.007558    0.777959    
#> 306: 0.849897    0.969986    3.472308    0.352003    0.131445    0.007560    0.777840    
#> 307: 0.849943    0.969913    3.472182    0.353124    0.131517    0.007559    0.777736    
#> 308: 0.849483    0.969657    3.472098    0.353578    0.131529    0.007569    0.777771    
#> 309: 0.849659    0.969425    3.472069    0.353959    0.131481    0.007580    0.777760    
#> 310: 0.849939    0.969230    3.472055    0.353504    0.131459    0.007595    0.777850    
#> 311: 0.850062    0.969259    3.472079    0.353560    0.131391    0.007605    0.777695    
#> 312: 0.849818    0.969173    3.472056    0.353490    0.131283    0.007612    0.777543    
#> 313: 0.849230    0.969008    3.471962    0.353281    0.131037    0.007619    0.777596    
#> 314: 0.848793    0.969261    3.471861    0.352949    0.131006    0.007611    0.777656    
#> 315: 0.848470    0.969505    3.471777    0.352789    0.131145    0.007601    0.777824    
#> 316: 0.848502    0.969665    3.471748    0.352568    0.131214    0.007593    0.777760    
#> 317: 0.848324    0.969691    3.471809    0.352185    0.131142    0.007572    0.777926    
#> 318: 0.848368    0.969798    3.471802    0.351808    0.131167    0.007554    0.778000    
#> 319: 0.848548    0.969879    3.471791    0.351468    0.131172    0.007543    0.778090    
#> 320: 0.848252    0.969924    3.471645    0.351356    0.131145    0.007520    0.778291    
#> 321: 0.848091    0.970066    3.471473    0.351489    0.131029    0.007499    0.778373    
#> 322: 0.847786    0.970267    3.471272    0.351234    0.131064    0.007488    0.778308    
#> 323: 0.846971    0.970406    3.471178    0.350727    0.131051    0.007488    0.778316    
#> 324: 0.846781    0.970638    3.471142    0.350305    0.131134    0.007477    0.778195    
#> 325: 0.846559    0.970835    3.471092    0.349308    0.131096    0.007458    0.778166    
#> 326: 0.846321    0.970683    3.471078    0.348656    0.131098    0.007442    0.778063    
#> 327: 0.846132    0.970636    3.471106    0.347871    0.131280    0.007427    0.778211    
#> 328: 0.846073    0.970604    3.471109    0.347148    0.131270    0.007405    0.778120    
#> 329: 0.846132    0.970494    3.471116    0.347064    0.131287    0.007379    0.778142    
#> 330: 0.845665    0.970568    3.471066    0.346576    0.131121    0.007366    0.778241    
#> 331: 0.845621    0.970606    3.471041    0.346374    0.131119    0.007353    0.778282    
#> 332: 0.845804    0.970545    3.471112    0.346359    0.131085    0.007356    0.778282    
#> 333: 0.845940    0.970517    3.471084    0.346379    0.130915    0.007364    0.778263    
#> 334: 0.845889    0.970459    3.471015    0.346630    0.130729    0.007365    0.778255    
#> 335: 0.845418    0.970547    3.470857    0.346670    0.130567    0.007363    0.778236    
#> 336: 0.844889    0.970854    3.470726    0.346883    0.130611    0.007368    0.778265    
#> 337: 0.844799    0.971204    3.470647    0.347187    0.130706    0.007367    0.778235    
#> 338: 0.844767    0.971470    3.470676    0.347071    0.130858    0.007362    0.778166    
#> 339: 0.844650    0.971627    3.470666    0.347274    0.130921    0.007349    0.778017    
#> 340: 0.844722    0.971463    3.470725    0.347299    0.131041    0.007334    0.778030    
#> 341: 0.844896    0.971474    3.470734    0.347456    0.131182    0.007324    0.778128    
#> 342: 0.844560    0.971294    3.470713    0.347271    0.131292    0.007318    0.778100    
#> 343: 0.844135    0.971215    3.470752    0.347259    0.131340    0.007318    0.778161    
#> 344: 0.844244    0.971136    3.470833    0.347426    0.131382    0.007326    0.778134    
#> 345: 0.844588    0.970990    3.470942    0.347769    0.131258    0.007329    0.778122    
#> 346: 0.844579    0.970967    3.470888    0.348195    0.131273    0.007322    0.777972    
#> 347: 0.844774    0.970900    3.470831    0.348450    0.131351    0.007321    0.778076    
#> 348: 0.844444    0.970957    3.470748    0.348575    0.131480    0.007304    0.778085    
#> 349: 0.844171    0.970842    3.470688    0.348744    0.131415    0.007287    0.778126    
#> 350: 0.843665    0.970811    3.470549    0.349016    0.131436    0.007272    0.778220    
#> 351: 0.843360    0.971074    3.470431    0.348790    0.131356    0.007263    0.778459    
#> 352: 0.842753    0.971322    3.470304    0.348532    0.131399    0.007262    0.778590    
#> 353: 0.842625    0.971474    3.470182    0.348543    0.131290    0.007260    0.778684    
#> 354: 0.842235    0.971543    3.470033    0.348711    0.131117    0.007258    0.778654    
#> 355: 0.842370    0.971591    3.469917    0.348927    0.131021    0.007255    0.778660    
#> 356: 0.842405    0.971580    3.469881    0.349279    0.131002    0.007251    0.778651    
#> 357: 0.842554    0.971671    3.469829    0.349690    0.130888    0.007251    0.778666    
#> 358: 0.842473    0.971875    3.469814    0.349977    0.130770    0.007260    0.778493    
#> 359: 0.842412    0.972103    3.469782    0.349942    0.130787    0.007263    0.778481    
#> 360: 0.842155    0.972186    3.469664    0.349726    0.130746    0.007267    0.778369    
#> 361: 0.841876    0.972142    3.469617    0.349457    0.130652    0.007277    0.778365    
#> 362: 0.841731    0.972090    3.469549    0.349101    0.130538    0.007287    0.778244    
#> 363: 0.841655    0.972093    3.469524    0.348759    0.130510    0.007283    0.778197    
#> 364: 0.841490    0.972123    3.469501    0.348072    0.130525    0.007281    0.778294    
#> 365: 0.841344    0.972105    3.469492    0.348174    0.130462    0.007292    0.778405    
#> 366: 0.841465    0.972063    3.469423    0.348686    0.130450    0.007305    0.778439    
#> 367: 0.841488    0.972077    3.469375    0.349083    0.130568    0.007315    0.778479    
#> 368: 0.841649    0.972360    3.469276    0.349022    0.130525    0.007334    0.778539    
#> 369: 0.841367    0.972466    3.469186    0.349087    0.130523    0.007340    0.778638    
#> 370: 0.840915    0.972582    3.469066    0.349098    0.130556    0.007360    0.778630    
#> 371: 0.840573    0.972667    3.468919    0.349124    0.130710    0.007361    0.778594    
#> 372: 0.840330    0.972792    3.468829    0.349177    0.130846    0.007354    0.778559    
#> 373: 0.840068    0.972948    3.468725    0.349606    0.130769    0.007347    0.778600    
#> 374: 0.840116    0.973016    3.468671    0.349595    0.130714    0.007340    0.778526    
#> 375: 0.839887    0.973007    3.468623    0.349675    0.130617    0.007344    0.778423    
#> 376: 0.839553    0.973098    3.468522    0.349845    0.130637    0.007351    0.778246    
#> 377: 0.839452    0.973284    3.468440    0.350408    0.130672    0.007347    0.778103    
#> 378: 0.839099    0.973426    3.468297    0.350771    0.130615    0.007353    0.778058    
#> 379: 0.838974    0.973347    3.468223    0.351483    0.130645    0.007347    0.777918    
#> 380: 0.838645    0.973366    3.468139    0.351456    0.130558    0.007348    0.777912    
#> 381: 0.838255    0.973513    3.468023    0.351303    0.130546    0.007348    0.777936    
#> 382: 0.838115    0.973645    3.467932    0.351506    0.130446    0.007347    0.777794    
#> 383: 0.838109    0.973590    3.467872    0.351520    0.130370    0.007351    0.777818    
#> 384: 0.838093    0.973479    3.467881    0.351429    0.130316    0.007358    0.777836    
#> 385: 0.838152    0.973507    3.467907    0.351202    0.130219    0.007358    0.777787    
#> 386: 0.838436    0.973806    3.467951    0.351509    0.130144    0.007363    0.777811    
#> 387: 0.838503    0.974001    3.468013    0.351343    0.130132    0.007368    0.777887    
#> 388: 0.838443    0.974093    3.468021    0.351173    0.130154    0.007363    0.777832    
#> 389: 0.838438    0.974027    3.468004    0.351010    0.130107    0.007363    0.777918    
#> 390: 0.838307    0.974104    3.468018    0.350885    0.130120    0.007363    0.777884    
#> 391: 0.838153    0.974030    3.468014    0.350539    0.130065    0.007359    0.777888    
#> 392: 0.838245    0.973932    3.468092    0.350449    0.130062    0.007348    0.777919    
#> 393: 0.838290    0.973807    3.468110    0.350600    0.129985    0.007339    0.777835    
#> 394: 0.838281    0.973829    3.468091    0.350182    0.129882    0.007331    0.777882    
#> 395: 0.838421    0.973933    3.468093    0.350093    0.129840    0.007326    0.777843    
#> 396: 0.838491    0.973923    3.468114    0.350061    0.129770    0.007324    0.777813    
#> 397: 0.838536    0.973876    3.468171    0.349988    0.129678    0.007330    0.777771    
#> 398: 0.838804    0.973841    3.468235    0.349808    0.129626    0.007342    0.777798    
#> 399: 0.838968    0.973868    3.468291    0.349837    0.129591    0.007351    0.777801    
#> 400: 0.839105    0.973948    3.468330    0.349789    0.129576    0.007349    0.777796    
#> 401: 0.839219    0.973952    3.468348    0.349947    0.129586    0.007347    0.777828    
#> 402: 0.839081    0.974054    3.468351    0.349728    0.129663    0.007343    0.777920    
#> 403: 0.839159    0.974048    3.468335    0.349459    0.129859    0.007341    0.778019    
#> 404: 0.839307    0.974081    3.468306    0.349344    0.129914    0.007336    0.778044    
#> 405: 0.839274    0.974111    3.468344    0.349279    0.129935    0.007332    0.778035    
#> 406: 0.839395    0.974148    3.468378    0.349235    0.129907    0.007333    0.778070    
#> 407: 0.839491    0.974259    3.468410    0.349138    0.129955    0.007327    0.778021    
#> 408: 0.839545    0.974436    3.468399    0.349073    0.130027    0.007321    0.778070    
#> 409: 0.839422    0.974350    3.468355    0.348886    0.129959    0.007313    0.778045    
#> 410: 0.839435    0.974334    3.468316    0.348743    0.129899    0.007316    0.777962    
#> 411: 0.839432    0.974106    3.468282    0.348923    0.129892    0.007310    0.777987    
#> 412: 0.839477    0.974137    3.468254    0.349217    0.129871    0.007308    0.778023    
#> 413: 0.839574    0.974123    3.468212    0.349229    0.129825    0.007311    0.778047    
#> 414: 0.839349    0.974126    3.468205    0.348957    0.129750    0.007310    0.778081    
#> 415: 0.839415    0.974081    3.468153    0.348811    0.129646    0.007313    0.778087    
#> 416: 0.839607    0.974110    3.468179    0.348942    0.129666    0.007318    0.778050    
#> 417: 0.839625    0.974111    3.468142    0.349112    0.129738    0.007322    0.778035    
#> 418: 0.839459    0.974157    3.468128    0.349008    0.129787    0.007321    0.777984    
#> 419: 0.839394    0.974239    3.468065    0.349338    0.129882    0.007320    0.777956    
#> 420: 0.839469    0.974285    3.468062    0.349402    0.129962    0.007310    0.777936    
#> 421: 0.839365    0.974298    3.468085    0.349084    0.130108    0.007299    0.777930    
#> 422: 0.839557    0.974217    3.468119    0.348788    0.130183    0.007288    0.778039    
#> 423: 0.839777    0.974073    3.468202    0.348414    0.130329    0.007284    0.778115    
#> 424: 0.839878    0.973978    3.468218    0.348214    0.130468    0.007272    0.778216    
#> 425: 0.840198    0.973960    3.468253    0.348206    0.130452    0.007262    0.778293    
#> 426: 0.840217    0.974046    3.468272    0.347824    0.130508    0.007255    0.778288    
#> 427: 0.840054    0.974022    3.468289    0.347428    0.130543    0.007251    0.778257    
#> 428: 0.839732    0.974115    3.468282    0.347194    0.130558    0.007255    0.778338    
#> 429: 0.839741    0.974174    3.468331    0.346933    0.130503    0.007262    0.778353    
#> 430: 0.839784    0.974243    3.468344    0.346969    0.130505    0.007257    0.778306    
#> 431: 0.839603    0.974195    3.468295    0.346961    0.130504    0.007250    0.778219    
#> 432: 0.839518    0.974237    3.468299    0.346760    0.130523    0.007250    0.778113    
#> 433: 0.839599    0.974382    3.468320    0.346610    0.130496    0.007253    0.778088    
#> 434: 0.839474    0.974372    3.468318    0.346405    0.130399    0.007256    0.778006    
#> 435: 0.839582    0.974386    3.468305    0.346329    0.130349    0.007263    0.778015    
#> 436: 0.839570    0.974378    3.468280    0.346282    0.130368    0.007271    0.777997    
#> 437: 0.839527    0.974427    3.468219    0.346325    0.130381    0.007264    0.777972    
#> 438: 0.839321    0.974604    3.468213    0.346091    0.130385    0.007262    0.777993    
#> 439: 0.839296    0.974813    3.468185    0.345838    0.130447    0.007260    0.777988    
#> 440: 0.839278    0.974910    3.468202    0.345887    0.130418    0.007257    0.777986    
#> 441: 0.839277    0.974868    3.468217    0.345902    0.130427    0.007250    0.777970    
#> 442: 0.839214    0.974923    3.468258    0.345993    0.130454    0.007243    0.777802    
#> 443: 0.839141    0.974969    3.468246    0.345872    0.130469    0.007232    0.777724    
#> 444: 0.839033    0.975032    3.468190    0.346147    0.130523    0.007223    0.777635    
#> 445: 0.838925    0.975150    3.468129    0.346186    0.130481    0.007214    0.777698    
#> 446: 0.838770    0.975248    3.468029    0.346351    0.130426    0.007208    0.777631    
#> 447: 0.838770    0.975313    3.468005    0.346244    0.130386    0.007207    0.777575    
#> 448: 0.838685    0.975334    3.467984    0.346076    0.130361    0.007212    0.777437    
#> 449: 0.838756    0.975435    3.468061    0.346271    0.130306    0.007217    0.777389    
#> 450: 0.838833    0.975474    3.468093    0.346319    0.130253    0.007223    0.777329    
#> 451: 0.838925    0.975521    3.468114    0.346356    0.130175    0.007233    0.777305    
#> 452: 0.838968    0.975623    3.468098    0.346420    0.130144    0.007234    0.777273    
#> 453: 0.838994    0.975623    3.468100    0.346666    0.130114    0.007228    0.777168    
#> 454: 0.838985    0.975680    3.468089    0.346659    0.130122    0.007222    0.777046    
#> 455: 0.839050    0.975758    3.468072    0.346623    0.130041    0.007214    0.777073    
#> 456: 0.838908    0.975758    3.468064    0.346511    0.130019    0.007215    0.777055    
#> 457: 0.838658    0.975719    3.468062    0.346281    0.130016    0.007217    0.777004    
#> 458: 0.838432    0.975853    3.468059    0.346059    0.129952    0.007218    0.777053    
#> 459: 0.838178    0.975978    3.468031    0.346025    0.129889    0.007221    0.777087    
#> 460: 0.838042    0.976045    3.467984    0.345930    0.129906    0.007233    0.777087    
#> 461: 0.837923    0.976100    3.467973    0.345821    0.129818    0.007248    0.777114    
#> 462: 0.837874    0.976168    3.467978    0.345777    0.129750    0.007250    0.777027    
#> 463: 0.837920    0.976182    3.468012    0.345949    0.129720    0.007248    0.777011    
#> 464: 0.837969    0.976167    3.468049    0.345993    0.129718    0.007243    0.776973    
#> 465: 0.838082    0.976020    3.468090    0.345794    0.129710    0.007236    0.776987    
#> 466: 0.838250    0.976023    3.468122    0.345653    0.129739    0.007235    0.776957    
#> 467: 0.838334    0.975894    3.468171    0.345396    0.129721    0.007242    0.776927    
#> 468: 0.838558    0.975869    3.468240    0.345737    0.129718    0.007252    0.776901    
#> 469: 0.838583    0.975896    3.468263    0.345974    0.129740    0.007258    0.776856    
#> 470: 0.838555    0.975939    3.468267    0.345962    0.129742    0.007267    0.776831    
#> 471: 0.838461    0.975871    3.468248    0.345789    0.129729    0.007267    0.776850    
#> 472: 0.838431    0.975844    3.468269    0.345809    0.129673    0.007269    0.776813    
#> 473: 0.838317    0.975849    3.468261    0.345591    0.129602    0.007273    0.776801    
#> 474: 0.838275    0.975828    3.468252    0.345450    0.129638    0.007276    0.776805    
#> 475: 0.838250    0.975904    3.468213    0.345427    0.129604    0.007271    0.776727    
#> 476: 0.838116    0.975875    3.468170    0.345628    0.129644    0.007268    0.776709    
#> 477: 0.838018    0.975933    3.468156    0.345681    0.129635    0.007269    0.776624    
#> 478: 0.837924    0.975932    3.468156    0.345570    0.129549    0.007273    0.776607    
#> 479: 0.837921    0.976010    3.468147    0.345583    0.129481    0.007278    0.776620    
#> 480: 0.837916    0.975951    3.468170    0.345571    0.129548    0.007279    0.776704    
#> 481: 0.837868    0.975916    3.468163    0.345587    0.129553    0.007280    0.776693    
#> 482: 0.837981    0.975880    3.468153    0.345768    0.129549    0.007283    0.776675    
#> 483: 0.838015    0.975803    3.468155    0.345789    0.129672    0.007278    0.776632    
#> 484: 0.838085    0.975618    3.468191    0.345868    0.129695    0.007274    0.776601    
#> 485: 0.838183    0.975562    3.468224    0.345890    0.129761    0.007270    0.776590    
#> 486: 0.838281    0.975614    3.468216    0.345748    0.129758    0.007265    0.776580    
#> 487: 0.838446    0.975592    3.468239    0.345557    0.129831    0.007265    0.776537    
#> 488: 0.838498    0.975576    3.468273    0.345638    0.129858    0.007263    0.776530    
#> 489: 0.838677    0.975545    3.468299    0.345887    0.129864    0.007267    0.776509    
#> 490: 0.838864    0.975482    3.468351    0.346026    0.129862    0.007272    0.776465    
#> 491: 0.839032    0.975483    3.468399    0.346390    0.129804    0.007270    0.776466    
#> 492: 0.839146    0.975521    3.468411    0.346647    0.129771    0.007268    0.776599    
#> 493: 0.839199    0.975545    3.468436    0.347063    0.129778    0.007270    0.776614    
#> 494: 0.839388    0.975540    3.468439    0.347077    0.129782    0.007275    0.776591    
#> 495: 0.839444    0.975598    3.468460    0.346840    0.129778    0.007275    0.776588    
#> 496: 0.839509    0.975618    3.468433    0.346622    0.129771    0.007274    0.776555    
#> 497: 0.839383    0.975644    3.468439    0.346438    0.129708    0.007272    0.776597    
#> 498: 0.839492    0.975586    3.468442    0.346540    0.129713    0.007265    0.776597    
#> 499: 0.839485    0.975606    3.468426    0.346516    0.129750    0.007256    0.776530    
#> 500: 0.839524    0.975561    3.468407    0.346611    0.129701    0.007253    0.776450    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.318927    0.976065    3.446624    0.392401    0.083526    0.016800    1.687369    
#> 002: 0.416234    1.022735    3.476411    0.372781    0.079350    0.015960    1.124796    
#> 003: 0.518569    0.993549    3.469225    0.354142    0.075382    0.015162    0.821457    
#> 004: 0.494558    1.000291    3.463101    0.336435    0.091357    0.014404    0.708177    
#> 005: 0.563165    1.007481    3.467142    0.392477    0.100598    0.013684    0.668872    
#> 006: 0.489947    1.010361    3.452259    0.372853    0.098513    0.013000    0.638316    
#> 007: 0.475931    1.013419    3.453071    0.400428    0.093587    0.012350    0.653634    
#> 008: 0.507136    1.005418    3.452736    0.443412    0.112931    0.012654    0.646315    
#> 009: 0.481374    1.001450    3.451639    0.421241    0.107285    0.012171    0.653094    
#> 010: 0.474142    1.015744    3.452768    0.400179    0.101920    0.015654    0.654850    
#> 011: 0.543864    1.001022    3.463100    0.417135    0.111592    0.015210    0.630019    
#> 012: 0.549498    1.001980    3.470887    0.399015    0.106012    0.014449    0.635151    
#> 013: 0.514052    1.001371    3.460738    0.436494    0.100712    0.015775    0.639544    
#> 014: 0.521962    0.988779    3.469742    0.439326    0.098831    0.015351    0.646359    
#> 015: 0.548039    0.997558    3.476270    0.433456    0.093889    0.014583    0.628490    
#> 016: 0.536343    1.018683    3.473642    0.411784    0.089358    0.016493    0.620788    
#> 017: 0.554250    1.024415    3.478147    0.436408    0.092037    0.015669    0.618523    
#> 018: 0.529736    1.002913    3.469099    0.443693    0.102330    0.016417    0.614116    
#> 019: 0.497383    1.013022    3.465818    0.421508    0.097214    0.015596    0.618053    
#> 020: 0.518352    1.044107    3.466718    0.400433    0.092353    0.016546    0.643259    
#> 021: 0.539934    1.017808    3.472282    0.449314    0.087735    0.015719    0.618802    
#> 022: 0.542883    1.014483    3.479646    0.455394    0.083349    0.017310    0.605362    
#> 023: 0.604872    1.016335    3.492648    0.432624    0.087831    0.016444    0.634456    
#> 024: 0.601404    1.007259    3.485536    0.483866    0.083440    0.015622    0.615821    
#> 025: 0.566176    0.981046    3.479943    0.472590    0.086892    0.015160    0.625013    
#> 026: 0.556966    1.017586    3.471020    0.491053    0.082547    0.016830    0.624398    
#> 027: 0.544463    1.028400    3.473496    0.467828    0.084612    0.017447    0.614997    
#> 028: 0.559532    1.017421    3.474761    0.473461    0.080381    0.019019    0.607968    
#> 029: 0.515659    1.023795    3.465187    0.449788    0.079339    0.020967    0.628705    
#> 030: 0.530460    1.025718    3.460798    0.443795    0.075372    0.019919    0.610096    
#> 031: 0.492696    1.014264    3.471127    0.421605    0.086633    0.020408    0.607985    
#> 032: 0.500825    0.996397    3.476191    0.400525    0.082302    0.021385    0.614382    
#> 033: 0.502095    0.999352    3.476721    0.380499    0.083506    0.023213    0.616460    
#> 034: 0.512576    1.027264    3.457502    0.379688    0.081392    0.022053    0.636904    
#> 035: 0.494013    1.007757    3.448661    0.405812    0.077408    0.020950    0.632309    
#> 036: 0.485469    1.011926    3.457371    0.385522    0.073538    0.023784    0.621764    
#> 037: 0.506378    1.031054    3.461722    0.430358    0.078535    0.022595    0.648848    
#> 038: 0.534782    1.011047    3.460813    0.457290    0.082678    0.023186    0.636372    
#> 039: 0.528215    1.018524    3.467527    0.453239    0.099637    0.022026    0.601013    
#> 040: 0.521070    1.015934    3.469465    0.453854    0.094655    0.020925    0.622911    
#> 041: 0.549383    1.023876    3.466836    0.431162    0.089922    0.021807    0.615368    
#> 042: 0.566524    1.016441    3.459231    0.482998    0.085426    0.022604    0.587156    
#> 043: 0.523670    1.025005    3.454069    0.465723    0.083374    0.021474    0.579742    
#> 044: 0.493530    1.031481    3.452057    0.482617    0.080575    0.020400    0.592613    
#> 045: 0.477423    1.047977    3.443925    0.458486    0.083961    0.019380    0.595528    
#> 046: 0.498431    1.032583    3.434929    0.478492    0.090697    0.018411    0.596188    
#> 047: 0.459798    1.033812    3.438588    0.454568    0.086162    0.018314    0.603782    
#> 048: 0.473312    1.028018    3.440203    0.479121    0.094854    0.019189    0.630692    
#> 049: 0.469444    1.044426    3.443327    0.480245    0.093780    0.018555    0.625141    
#> 050: 0.476382    1.003024    3.446070    0.456233    0.089091    0.019468    0.629738    
#> 051: 0.457964    1.021719    3.443186    0.433421    0.084637    0.018495    0.631702    
#> 052: 0.497170    1.018779    3.463919    0.411750    0.085869    0.018646    0.607996    
#> 053: 0.518455    0.997144    3.453962    0.525754    0.090128    0.017714    0.613918    
#> 054: 0.529578    1.007056    3.468524    0.499466    0.085622    0.019712    0.625971    
#> 055: 0.534764    1.019575    3.463887    0.474493    0.085600    0.018727    0.623945    
#> 056: 0.524187    1.012820    3.468572    0.450768    0.092438    0.017790    0.622223    
#> 057: 0.523777    0.994911    3.468945    0.428343    0.087816    0.017465    0.629871    
#> 058: 0.531212    1.006695    3.464369    0.468507    0.083863    0.019170    0.608888    
#> 059: 0.516787    0.978753    3.469077    0.495786    0.084310    0.019384    0.617190    
#> 060: 0.551008    0.975943    3.486641    0.487800    0.080094    0.022425    0.635744    
#> 061: 0.596677    0.991371    3.489816    0.515722    0.084378    0.021543    0.641672    
#> 062: 0.548342    1.010335    3.480542    0.489986    0.081685    0.024114    0.656978    
#> 063: 0.594176    0.978680    3.481427    0.516220    0.085041    0.030394    0.638540    
#> 064: 0.579907    0.978268    3.484460    0.502796    0.084574    0.028874    0.657138    
#> 065: 0.605420    0.979080    3.465218    0.514995    0.080345    0.027431    0.643481    
#> 066: 0.569301    1.009654    3.483132    0.489245    0.082295    0.026059    0.601932    
#> 067: 0.531455    1.000675    3.466968    0.497523    0.080407    0.024756    0.582490    
#> 068: 0.504601    1.013896    3.472766    0.472647    0.092071    0.023907    0.604299    
#> 069: 0.492681    1.007951    3.460328    0.449014    0.087468    0.023686    0.625659    
#> 070: 0.493845    1.009413    3.460880    0.453999    0.083094    0.024093    0.609396    
#> 071: 0.492814    1.030316    3.436630    0.459292    0.078940    0.023127    0.630790    
#> 072: 0.500629    1.015332    3.446031    0.477492    0.086528    0.025583    0.597255    
#> 073: 0.495198    1.031444    3.463803    0.453618    0.085391    0.024304    0.597749    
#> 074: 0.479976    1.008358    3.459603    0.430937    0.088032    0.023089    0.608853    
#> 075: 0.520221    1.009003    3.476302    0.428796    0.102954    0.021934    0.605022    
#> 076: 0.545746    1.028065    3.480156    0.407357    0.097807    0.021808    0.621264    
#> 077: 0.564483    0.996076    3.470601    0.424271    0.092916    0.020718    0.621464    
#> 078: 0.542633    0.990400    3.472933    0.427218    0.089757    0.019682    0.610559    
#> 079: 0.539443    1.013284    3.475329    0.473229    0.090875    0.019808    0.616604    
#> 080: 0.543789    1.004549    3.476066    0.449568    0.100611    0.023945    0.639751    
#> 081: 0.532987    1.006114    3.474982    0.427090    0.095581    0.024835    0.625425    
#> 082: 0.553433    1.004019    3.476501    0.406175    0.090802    0.023593    0.622271    
#> 083: 0.515697    1.017834    3.473501    0.403460    0.086262    0.022413    0.632422    
#> 084: 0.528076    1.011757    3.468920    0.383287    0.085091    0.021293    0.621844    
#> 085: 0.528654    1.013024    3.484498    0.364123    0.080836    0.020228    0.629467    
#> 086: 0.539093    1.006475    3.473483    0.417767    0.082213    0.019288    0.602741    
#> 087: 0.514533    1.003202    3.459805    0.407039    0.078103    0.020221    0.609964    
#> 088: 0.452820    1.012836    3.459970    0.386687    0.080129    0.019210    0.630063    
#> 089: 0.512361    1.021786    3.456748    0.367352    0.095586    0.018249    0.634522    
#> 090: 0.476127    1.015817    3.444492    0.370474    0.099884    0.017337    0.636017    
#> 091: 0.453794    1.005700    3.441908    0.351951    0.094890    0.016470    0.643730    
#> 092: 0.478992    1.031063    3.452475    0.334353    0.094583    0.016425    0.643504    
#> 093: 0.489868    1.012081    3.455728    0.416265    0.097769    0.016106    0.646231    
#> 094: 0.514181    1.019291    3.450444    0.433504    0.096262    0.015301    0.648326    
#> 095: 0.530931    1.010681    3.463409    0.495222    0.091449    0.014853    0.641627    
#> 096: 0.495553    1.026670    3.455707    0.500576    0.090615    0.017063    0.632530    
#> 097: 0.569127    1.026410    3.459716    0.547918    0.093071    0.016210    0.630161    
#> 098: 0.546326    1.042369    3.466014    0.520522    0.091540    0.017119    0.638978    
#> 099: 0.512810    1.011518    3.455997    0.494496    0.086963    0.016374    0.637440    
#> 100: 0.493099    1.020011    3.447994    0.469771    0.085072    0.017338    0.612615    
#> 101: 0.493518    1.011842    3.439201    0.446283    0.091781    0.018403    0.614805    
#> 102: 0.511221    1.033417    3.434436    0.444280    0.090591    0.017483    0.618607    
#> 103: 0.497056    1.026013    3.447920    0.422066    0.094098    0.017271    0.618752    
#> 104: 0.509513    1.018789    3.470718    0.412525    0.089393    0.018441    0.632704    
#> 105: 0.506280    0.982133    3.465573    0.423043    0.092083    0.017519    0.631634    
#> 106: 0.514209    0.984476    3.467370    0.440611    0.095114    0.017534    0.632886    
#> 107: 0.562472    1.002909    3.480391    0.453080    0.106909    0.020710    0.618175    
#> 108: 0.555893    0.991234    3.488849    0.440715    0.101564    0.019675    0.628323    
#> 109: 0.557414    0.989541    3.494174    0.418679    0.096486    0.019189    0.616564    
#> 110: 0.552487    0.985350    3.478827    0.453688    0.091662    0.020763    0.618780    
#> 111: 0.573549    0.997401    3.478488    0.507899    0.090831    0.019725    0.617731    
#> 112: 0.560129    0.981031    3.470771    0.482504    0.086289    0.018738    0.630692    
#> 113: 0.504611    1.005068    3.471862    0.458379    0.081975    0.018179    0.631910    
#> 114: 0.504299    1.004715    3.470964    0.435460    0.077876    0.018758    0.621640    
#> 115: 0.553782    0.985104    3.470503    0.477088    0.092682    0.020491    0.602019    
#> 116: 0.555189    1.004510    3.464170    0.470542    0.100839    0.019466    0.604394    
#> 117: 0.508724    1.026127    3.459150    0.515927    0.096693    0.021776    0.605658    
#> 118: 0.506029    0.998291    3.466523    0.490130    0.091858    0.023493    0.615469    
#> 119: 0.530054    1.012421    3.460361    0.518572    0.090495    0.025461    0.630354    
#> 120: 0.541491    0.999760    3.468330    0.529985    0.085970    0.026557    0.621574    
#> 121: 0.546141    1.037432    3.468764    0.588622    0.081671    0.029155    0.624035    
#> 122: 0.546043    1.006809    3.459276    0.559191    0.077588    0.027697    0.609565    
#> 123: 0.548398    1.029294    3.456298    0.531232    0.082547    0.026312    0.610359    
#> 124: 0.501826    1.055646    3.451862    0.512155    0.078419    0.024996    0.624191    
#> 125: 0.528639    1.027692    3.451677    0.531598    0.074498    0.023747    0.620890    
#> 126: 0.493330    1.038011    3.436771    0.525837    0.085406    0.022559    0.618145    
#> 127: 0.545012    0.996007    3.453095    0.499741    0.081136    0.022036    0.619502    
#> 128: 0.540871    0.990938    3.476014    0.477237    0.077599    0.022365    0.626105    
#> 129: 0.583592    1.007108    3.474666    0.480284    0.080647    0.021246    0.618882    
#> 130: 0.621350    1.022191    3.471253    0.507601    0.076614    0.022111    0.617959    
#> 131: 0.569773    1.008635    3.458891    0.524782    0.072784    0.021005    0.619187    
#> 132: 0.509356    1.000323    3.456312    0.498542    0.098559    0.019955    0.605520    
#> 133: 0.540268    1.005793    3.472948    0.491609    0.105701    0.021963    0.598692    
#> 134: 0.555639    1.000075    3.484874    0.476497    0.100416    0.022662    0.611279    
#> 135: 0.583087    0.990735    3.491042    0.456758    0.095396    0.022705    0.602633    
#> 136: 0.566674    0.979241    3.484101    0.466035    0.090626    0.021931    0.607332    
#> 137: 0.617462    0.973434    3.495527    0.520348    0.086094    0.020835    0.609668    
#> 138: 0.575752    0.987973    3.482792    0.539643    0.081790    0.019793    0.608845    
#> 139: 0.539079    0.991836    3.489995    0.512661    0.077700    0.019639    0.621247    
#> 140: 0.567933    0.990710    3.478601    0.524296    0.083126    0.019736    0.608059    
#> 141: 0.544142    0.995997    3.476966    0.498081    0.083821    0.018885    0.615740    
#> 142: 0.555729    0.993826    3.486184    0.497850    0.082783    0.018419    0.617663    
#> 143: 0.510211    1.036436    3.468595    0.476793    0.102865    0.020877    0.628491    
#> 144: 0.570549    1.024509    3.476316    0.452953    0.097722    0.019833    0.623319    
#> 145: 0.552799    1.044948    3.451596    0.523573    0.094996    0.018842    0.608613    
#> 146: 0.537074    1.038476    3.454525    0.546766    0.090246    0.023588    0.615533    
#> 147: 0.488278    1.012032    3.444621    0.519428    0.085734    0.022408    0.604597    
#> 148: 0.458179    1.016956    3.460726    0.493457    0.085787    0.021288    0.617722    
#> 149: 0.486855    1.018670    3.462489    0.468784    0.091114    0.020621    0.616203    
#> 150: 0.518916    1.024882    3.441940    0.445345    0.089829    0.019590    0.610770    
#> 151: 0.471258    1.051230    3.442732    0.423077    0.097193    0.018610    0.611255    
#> 152: 0.469966    1.029177    3.449102    0.420570    0.079504    0.019192    0.605411    
#> 153: 0.506772    1.038058    3.474828    0.370644    0.080583    0.023295    0.613481    
#> 154: 0.551283    1.019215    3.470962    0.430282    0.085148    0.023416    0.610828    
#> 155: 0.550432    1.011957    3.471254    0.457879    0.092269    0.022750    0.618607    
#> 156: 0.556279    1.010899    3.473562    0.490531    0.092058    0.019781    0.611662    
#> 157: 0.523630    0.995493    3.479843    0.412699    0.091679    0.020171    0.622188    
#> 158: 0.550771    1.019562    3.469617    0.422135    0.092732    0.016406    0.627711    
#> 159: 0.487027    1.006238    3.473173    0.402351    0.089754    0.016047    0.640741    
#> 160: 0.551331    0.974941    3.486388    0.388297    0.103058    0.017206    0.645071    
#> 161: 0.563844    0.997918    3.482477    0.466324    0.089915    0.018040    0.641324    
#> 162: 0.528925    1.008946    3.470463    0.427836    0.100373    0.018283    0.634231    
#> 163: 0.538779    1.014074    3.470484    0.379799    0.106316    0.017495    0.636872    
#> 164: 0.545451    1.000323    3.472369    0.411192    0.084229    0.022610    0.633511    
#> 165: 0.576946    1.002054    3.473003    0.501019    0.081722    0.020991    0.620684    
#> 166: 0.595021    1.033384    3.479972    0.496169    0.084174    0.021686    0.618975    
#> 167: 0.586812    1.042694    3.476091    0.487393    0.083048    0.024001    0.627332    
#> 168: 0.582150    1.025467    3.478135    0.418499    0.084491    0.024380    0.615233    
#> 169: 0.556220    1.052438    3.469007    0.426092    0.092033    0.022339    0.626531    
#> 170: 0.540906    1.027464    3.471134    0.408186    0.085224    0.019342    0.627811    
#> 171: 0.521663    1.019665    3.470723    0.430539    0.083437    0.020226    0.609690    
#> 172: 0.503698    1.045102    3.460635    0.456913    0.077072    0.023359    0.608720    
#> 173: 0.520922    1.027925    3.446796    0.477190    0.078844    0.024034    0.607160    
#> 174: 0.495490    1.023455    3.456895    0.523616    0.088604    0.027011    0.606281    
#> 175: 0.532513    1.017001    3.447215    0.506399    0.088615    0.028138    0.624298    
#> 176: 0.529179    1.026099    3.464676    0.450514    0.083284    0.031575    0.610254    
#> 177: 0.523562    1.019527    3.465487    0.453990    0.083643    0.026659    0.608230    
#> 178: 0.521688    0.994752    3.471786    0.463744    0.072725    0.028255    0.619421    
#> 179: 0.604827    1.000291    3.480265    0.568931    0.077978    0.023746    0.624853    
#> 180: 0.579058    0.980041    3.481745    0.513010    0.076046    0.025732    0.611462    
#> 181: 0.574930    0.988461    3.471222    0.480152    0.056058    0.024599    0.613742    
#> 182: 0.506084    1.022273    3.448555    0.519958    0.081904    0.024973    0.624326    
#> 183: 0.511032    1.040544    3.449231    0.520736    0.090083    0.019609    0.620519    
#> 184: 0.491364    1.022056    3.454672    0.465167    0.090058    0.022133    0.616752    
#> 185: 0.510520    1.023604    3.456905    0.486421    0.089221    0.021177    0.621310    
#> 186: 0.506326    1.046478    3.455539    0.520974    0.091744    0.025014    0.639159    
#> 187: 0.528297    1.021963    3.461878    0.522307    0.085905    0.023217    0.625205    
#> 188: 0.480512    1.034499    3.456147    0.441316    0.088097    0.022513    0.625362    
#> 189: 0.505719    1.029878    3.473961    0.421643    0.090783    0.025714    0.637018    
#> 190: 0.522686    1.034015    3.468184    0.490665    0.072891    0.023625    0.606342    
#> 191: 0.488899    1.034286    3.457061    0.423818    0.078810    0.017180    0.610799    
#> 192: 0.503129    1.049408    3.452849    0.387004    0.082870    0.021861    0.610362    
#> 193: 0.513917    1.038992    3.459689    0.378652    0.075049    0.019601    0.618342    
#> 194: 0.523759    1.025980    3.458376    0.455380    0.080912    0.017763    0.610871    
#> 195: 0.487792    1.030375    3.453696    0.468608    0.079503    0.019382    0.619280    
#> 196: 0.489538    1.004511    3.463796    0.451611    0.085436    0.019184    0.631111    
#> 197: 0.479379    1.015001    3.476318    0.428312    0.078419    0.021696    0.637445    
#> 198: 0.523313    0.991011    3.474843    0.380740    0.084923    0.024117    0.612464    
#> 199: 0.539905    0.997606    3.471218    0.376136    0.103929    0.021961    0.601806    
#> 200: 0.530060    1.007452    3.475240    0.403117    0.088164    0.023475    0.607647    
#> 201: 0.528445    1.008693    3.474230    0.415781    0.089569    0.023600    0.597562    
#> 202: 0.522771    1.010776    3.470877    0.436608    0.088899    0.023554    0.596958    
#> 203: 0.534354    1.009293    3.467160    0.468804    0.087106    0.022947    0.599173    
#> 204: 0.539056    1.002965    3.469167    0.483279    0.086237    0.023151    0.601494    
#> 205: 0.535575    1.003885    3.468997    0.479350    0.085920    0.023340    0.606598    
#> 206: 0.531777    1.008774    3.468889    0.480407    0.086897    0.023501    0.606523    
#> 207: 0.531586    1.010851    3.468147    0.475595    0.088068    0.023109    0.607395    
#> 208: 0.534079    1.010851    3.468588    0.473148    0.087287    0.022883    0.606601    
#> 209: 0.536275    1.008286    3.468459    0.471122    0.086325    0.023020    0.607670    
#> 210: 0.538765    1.005365    3.469467    0.474696    0.085064    0.023059    0.607145    
#> 211: 0.541243    1.004683    3.470498    0.476433    0.084243    0.023187    0.606882    
#> 212: 0.543547    1.004589    3.471531    0.477438    0.084570    0.023225    0.606395    
#> 213: 0.543848    1.004194    3.471534    0.477711    0.086446    0.023174    0.606559    
#> 214: 0.543523    1.004157    3.472114    0.473885    0.087707    0.023390    0.606717    
#> 215: 0.542946    1.004559    3.472615    0.471873    0.088773    0.023402    0.607064    
#> 216: 0.546690    1.003417    3.473207    0.474656    0.089295    0.023387    0.607626    
#> 217: 0.548444    1.003123    3.473725    0.473669    0.089829    0.023096    0.607326    
#> 218: 0.548731    1.002632    3.474008    0.474194    0.090218    0.023037    0.607639    
#> 219: 0.547028    1.001918    3.472884    0.480258    0.089482    0.023058    0.608323    
#> 220: 0.545339    1.002630    3.472459    0.481287    0.088951    0.023262    0.608578    
#> 221: 0.544137    1.003023    3.471894    0.481663    0.088223    0.023279    0.608229    
#> 222: 0.541609    1.003556    3.471136    0.479629    0.087722    0.023323    0.608308    
#> 223: 0.541301    1.003842    3.470748    0.481524    0.087282    0.023344    0.608501    
#> 224: 0.541826    1.004319    3.470554    0.478722    0.087218    0.023273    0.609037    
#> 225: 0.540613    1.003010    3.470867    0.478621    0.086651    0.023387    0.609427    
#> 226: 0.540385    1.002171    3.470635    0.481246    0.086328    0.023344    0.609640    
#> 227: 0.539799    1.001921    3.470526    0.480774    0.086038    0.023386    0.609438    
#> 228: 0.539142    1.002823    3.469817    0.482920    0.085959    0.023436    0.608984    
#> 229: 0.538006    1.003551    3.469372    0.483234    0.085894    0.023359    0.608650    
#> 230: 0.537352    1.003970    3.468797    0.484023    0.085745    0.023263    0.608846    
#> 231: 0.536749    1.004658    3.468624    0.485437    0.085630    0.023189    0.608585    
#> 232: 0.535472    1.005598    3.468133    0.484768    0.085535    0.023252    0.608366    
#> 233: 0.533208    1.005741    3.467737    0.483346    0.085461    0.023359    0.608493    
#> 234: 0.532549    1.006384    3.466986    0.483497    0.085033    0.023430    0.608380    
#> 235: 0.531779    1.006777    3.466369    0.483349    0.085084    0.023462    0.608246    
#> 236: 0.530843    1.007271    3.465885    0.482875    0.085165    0.023466    0.608210    
#> 237: 0.531307    1.007773    3.465723    0.484813    0.085212    0.023523    0.608636    
#> 238: 0.532578    1.007966    3.465774    0.488231    0.085191    0.023507    0.609281    
#> 239: 0.532478    1.008309    3.465417    0.489736    0.085473    0.023401    0.609383    
#> 240: 0.532729    1.008382    3.465365    0.490874    0.085662    0.023206    0.609253    
#> 241: 0.532471    1.007832    3.465324    0.490182    0.085763    0.023072    0.609324    
#> 242: 0.531657    1.007388    3.465116    0.488171    0.085950    0.023036    0.609934    
#> 243: 0.531092    1.007689    3.465026    0.486909    0.086120    0.023045    0.610219    
#> 244: 0.530563    1.007557    3.465129    0.485270    0.086370    0.023059    0.610197    
#> 245: 0.530911    1.007142    3.465322    0.485784    0.086502    0.023150    0.610694    
#> 246: 0.531842    1.006624    3.465633    0.486315    0.086334    0.023230    0.610837    
#> 247: 0.531479    1.006549    3.465922    0.486821    0.085963    0.023283    0.610942    
#> 248: 0.531163    1.006639    3.465980    0.486429    0.085662    0.023275    0.610765    
#> 249: 0.530526    1.006797    3.465985    0.487229    0.085389    0.023306    0.610856    
#> 250: 0.530423    1.006895    3.465937    0.486576    0.085114    0.023262    0.611343    
#> 251: 0.530569    1.007471    3.466141    0.485713    0.084920    0.023195    0.611642    
#> 252: 0.530668    1.007826    3.466257    0.485433    0.084788    0.023166    0.611855    
#> 253: 0.530574    1.007915    3.466252    0.484753    0.084489    0.023099    0.612016    
#> 254: 0.530559    1.008231    3.466212    0.483158    0.084372    0.023030    0.612173    
#> 255: 0.530210    1.008621    3.466243    0.480849    0.084270    0.022974    0.612386    
#> 256: 0.529609    1.008632    3.466076    0.479403    0.084061    0.022920    0.612923    
#> 257: 0.529388    1.008612    3.465945    0.479605    0.083829    0.022905    0.613066    
#> 258: 0.528695    1.008740    3.465867    0.478687    0.083839    0.022869    0.613094    
#> 259: 0.528531    1.008685    3.465764    0.478720    0.083716    0.022875    0.613153    
#> 260: 0.528543    1.008971    3.465675    0.479122    0.083530    0.022916    0.612949    
#> 261: 0.528812    1.008871    3.465645    0.479431    0.083483    0.022976    0.612993    
#> 262: 0.529625    1.009083    3.465726    0.481953    0.083476    0.023007    0.612917    
#> 263: 0.529843    1.009346    3.465736    0.483163    0.083399    0.023027    0.613173    
#> 264: 0.529851    1.009413    3.465827    0.484095    0.083287    0.023026    0.613351    
#> 265: 0.529756    1.009438    3.465848    0.483387    0.083255    0.023014    0.613301    
#> 266: 0.529732    1.009492    3.465888    0.483189    0.083194    0.022973    0.613143    
#> 267: 0.529467    1.009396    3.466016    0.482930    0.083112    0.022984    0.612909    
#> 268: 0.529520    1.009004    3.465995    0.483279    0.083072    0.022993    0.612897    
#> 269: 0.529530    1.009115    3.465829    0.483341    0.083066    0.022975    0.612850    
#> 270: 0.529459    1.009416    3.465634    0.483260    0.083205    0.022932    0.612664    
#> 271: 0.529131    1.009473    3.465503    0.482496    0.083128    0.022874    0.612572    
#> 272: 0.529245    1.009344    3.465417    0.482321    0.083095    0.022899    0.612758    
#> 273: 0.528835    1.009556    3.465509    0.482273    0.083239    0.022879    0.612928    
#> 274: 0.529221    1.009861    3.465613    0.481984    0.083169    0.022883    0.612930    
#> 275: 0.529762    1.010127    3.465549    0.482154    0.083048    0.022929    0.612867    
#> 276: 0.530005    1.010630    3.465647    0.481555    0.083065    0.022980    0.612873    
#> 277: 0.529504    1.011044    3.465671    0.480772    0.083108    0.022972    0.613072    
#> 278: 0.529055    1.011195    3.465709    0.479918    0.083099    0.022908    0.613266    
#> 279: 0.529420    1.010981    3.465751    0.480421    0.083195    0.022868    0.613490    
#> 280: 0.529440    1.011127    3.465827    0.480178    0.083223    0.022793    0.613501    
#> 281: 0.529210    1.011306    3.465810    0.479654    0.083286    0.022755    0.613467    
#> 282: 0.528952    1.011736    3.465776    0.478404    0.083453    0.022716    0.613541    
#> 283: 0.528512    1.011974    3.465667    0.477890    0.083500    0.022697    0.613910    
#> 284: 0.528359    1.011880    3.465730    0.477802    0.083275    0.022665    0.614088    
#> 285: 0.528550    1.011821    3.465743    0.478009    0.083274    0.022614    0.614392    
#> 286: 0.528241    1.011931    3.465667    0.477461    0.083241    0.022545    0.614577    
#> 287: 0.528117    1.012073    3.465567    0.477079    0.083327    0.022511    0.614401    
#> 288: 0.528236    1.012122    3.465548    0.477349    0.083278    0.022484    0.614472    
#> 289: 0.528217    1.012104    3.465474    0.478146    0.083293    0.022474    0.614448    
#> 290: 0.528347    1.012137    3.465409    0.478709    0.083302    0.022483    0.614578    
#> 291: 0.528568    1.012304    3.465423    0.478911    0.083318    0.022474    0.614478    
#> 292: 0.528435    1.012360    3.465330    0.479099    0.083344    0.022488    0.614355    
#> 293: 0.528134    1.012456    3.465144    0.478630    0.083236    0.022472    0.614477    
#> 294: 0.527296    1.012613    3.464949    0.477961    0.083123    0.022439    0.614585    
#> 295: 0.527156    1.012616    3.464824    0.477512    0.083045    0.022417    0.614352    
#> 296: 0.527107    1.012637    3.464703    0.477591    0.083020    0.022390    0.614226    
#> 297: 0.526943    1.012820    3.464614    0.477456    0.083124    0.022379    0.614211    
#> 298: 0.526691    1.013078    3.464425    0.477747    0.083154    0.022374    0.614077    
#> 299: 0.526451    1.013342    3.464247    0.477966    0.083170    0.022408    0.613933    
#> 300: 0.526392    1.013242    3.464221    0.477870    0.083059    0.022407    0.613866    
#> 301: 0.526788    1.013180    3.464169    0.477969    0.082945    0.022415    0.613861    
#> 302: 0.527043    1.013194    3.464129    0.478072    0.082862    0.022398    0.613879    
#> 303: 0.526906    1.013406    3.464062    0.477913    0.083000    0.022393    0.613853    
#> 304: 0.526458    1.013727    3.463837    0.477507    0.083129    0.022386    0.613851    
#> 305: 0.525862    1.013749    3.463680    0.476559    0.083187    0.022359    0.613920    
#> 306: 0.525195    1.013893    3.463437    0.475893    0.083247    0.022355    0.613916    
#> 307: 0.524774    1.013994    3.463182    0.475990    0.083240    0.022331    0.613975    
#> 308: 0.523945    1.014033    3.463057    0.474918    0.083272    0.022312    0.614220    
#> 309: 0.523514    1.013973    3.462999    0.474564    0.083282    0.022323    0.614493    
#> 310: 0.523918    1.013875    3.462952    0.474953    0.083165    0.022355    0.614571    
#> 311: 0.523782    1.013755    3.462970    0.474340    0.083099    0.022363    0.614404    
#> 312: 0.523616    1.013593    3.462905    0.474303    0.083042    0.022369    0.614389    
#> 313: 0.523576    1.013166    3.462913    0.473896    0.082993    0.022405    0.614533    
#> 314: 0.523563    1.013119    3.462944    0.473312    0.082909    0.022443    0.614519    
#> 315: 0.523440    1.013214    3.463010    0.472460    0.082924    0.022424    0.614641    
#> 316: 0.523294    1.013243    3.463031    0.471399    0.082927    0.022420    0.614704    
#> 317: 0.523546    1.013203    3.463056    0.471345    0.082951    0.022401    0.614849    
#> 318: 0.523835    1.013056    3.463151    0.471523    0.083003    0.022391    0.614785    
#> 319: 0.524081    1.012867    3.463257    0.471471    0.083065    0.022402    0.614923    
#> 320: 0.523633    1.012859    3.463166    0.471224    0.083176    0.022379    0.615011    
#> 321: 0.523443    1.013013    3.463056    0.471418    0.083175    0.022337    0.615197    
#> 322: 0.523102    1.013221    3.462897    0.470890    0.083144    0.022318    0.615221    
#> 323: 0.522477    1.013238    3.462795    0.470279    0.083201    0.022297    0.615238    
#> 324: 0.522183    1.013278    3.462719    0.469709    0.083237    0.022264    0.615153    
#> 325: 0.522067    1.013338    3.462642    0.469279    0.083220    0.022221    0.615089    
#> 326: 0.522142    1.013186    3.462600    0.469787    0.083241    0.022195    0.615121    
#> 327: 0.522249    1.013121    3.462660    0.469912    0.083155    0.022147    0.615159    
#> 328: 0.522425    1.013189    3.462646    0.469623    0.083178    0.022136    0.615081    
#> 329: 0.522608    1.013212    3.462692    0.469164    0.083204    0.022094    0.615113    
#> 330: 0.522522    1.013184    3.462759    0.468719    0.083113    0.022058    0.615090    
#> 331: 0.522624    1.013229    3.462826    0.468474    0.083066    0.022065    0.615029    
#> 332: 0.522629    1.013236    3.462872    0.467918    0.083078    0.022046    0.615136    
#> 333: 0.522628    1.013233    3.462772    0.467934    0.083162    0.022024    0.615204    
#> 334: 0.522439    1.013211    3.462627    0.468159    0.083240    0.021995    0.615301    
#> 335: 0.521979    1.013351    3.462449    0.468339    0.083169    0.021974    0.615307    
#> 336: 0.521403    1.013524    3.462325    0.468250    0.083113    0.021953    0.615361    
#> 337: 0.520946    1.013721    3.462133    0.468575    0.083110    0.021946    0.615382    
#> 338: 0.520926    1.013836    3.462115    0.469060    0.083114    0.021939    0.615399    
#> 339: 0.520821    1.014036    3.462029    0.469373    0.083154    0.021914    0.615365    
#> 340: 0.520814    1.013917    3.461991    0.469411    0.083191    0.021901    0.615410    
#> 341: 0.520883    1.013942    3.462024    0.469257    0.083205    0.021878    0.615404    
#> 342: 0.520705    1.013726    3.462091    0.469127    0.083220    0.021855    0.615437    
#> 343: 0.520499    1.013701    3.462105    0.468283    0.083295    0.021808    0.615452    
#> 344: 0.520366    1.013618    3.462149    0.467705    0.083318    0.021782    0.615587    
#> 345: 0.520555    1.013551    3.462226    0.467261    0.083274    0.021753    0.615585    
#> 346: 0.520579    1.013553    3.462201    0.466650    0.083276    0.021720    0.615572    
#> 347: 0.520661    1.013415    3.462212    0.466433    0.083259    0.021717    0.615614    
#> 348: 0.520548    1.013432    3.462231    0.466281    0.083244    0.021697    0.615710    
#> 349: 0.520612    1.013263    3.462306    0.466412    0.083135    0.021689    0.615783    
#> 350: 0.520483    1.013082    3.462329    0.466327    0.083126    0.021686    0.615923    
#> 351: 0.520789    1.013085    3.462371    0.466774    0.083088    0.021680    0.615994    
#> 352: 0.520835    1.013115    3.462378    0.466862    0.083118    0.021677    0.616040    
#> 353: 0.521127    1.013205    3.462444    0.466849    0.083104    0.021686    0.616033    
#> 354: 0.521235    1.013178    3.462398    0.467588    0.083107    0.021694    0.615981    
#> 355: 0.521467    1.013022    3.462375    0.467766    0.083086    0.021701    0.616061    
#> 356: 0.521429    1.012975    3.462424    0.467375    0.083057    0.021679    0.616251    
#> 357: 0.521627    1.013076    3.462492    0.467212    0.082987    0.021694    0.616227    
#> 358: 0.521857    1.013130    3.462568    0.466891    0.082919    0.021709    0.616205    
#> 359: 0.521879    1.013331    3.462557    0.466626    0.082926    0.021721    0.616127    
#> 360: 0.521639    1.013413    3.462456    0.466169    0.082868    0.021721    0.616089    
#> 361: 0.521710    1.013452    3.462457    0.465820    0.082768    0.021715    0.616031    
#> 362: 0.521705    1.013453    3.462419    0.465595    0.082745    0.021714    0.615855    
#> 363: 0.521710    1.013400    3.462453    0.465417    0.082723    0.021689    0.615711    
#> 364: 0.521824    1.013329    3.462453    0.465316    0.082717    0.021653    0.615678    
#> 365: 0.521710    1.013279    3.462494    0.465039    0.082728    0.021641    0.615699    
#> 366: 0.521737    1.013315    3.462466    0.465063    0.082741    0.021641    0.615633    
#> 367: 0.521894    1.013337    3.462484    0.464915    0.082784    0.021630    0.615593    
#> 368: 0.522031    1.013378    3.462480    0.464762    0.082780    0.021617    0.615593    
#> 369: 0.521856    1.013337    3.462482    0.465057    0.082768    0.021605    0.615703    
#> 370: 0.521726    1.013341    3.462472    0.464889    0.082748    0.021622    0.615750    
#> 371: 0.521471    1.013487    3.462331    0.464946    0.082802    0.021611    0.615710    
#> 372: 0.521299    1.013680    3.462187    0.465172    0.082897    0.021588    0.615676    
#> 373: 0.520885    1.013892    3.462033    0.465221    0.082919    0.021572    0.615744    
#> 374: 0.520546    1.014024    3.461914    0.464965    0.082911    0.021566    0.615713    
#> 375: 0.520309    1.014183    3.461808    0.464792    0.082882    0.021559    0.615748    
#> 376: 0.520192    1.014211    3.461756    0.464666    0.082862    0.021576    0.615687    
#> 377: 0.520074    1.014223    3.461763    0.464581    0.082896    0.021555    0.615675    
#> 378: 0.519845    1.014198    3.461787    0.464363    0.082832    0.021558    0.615677    
#> 379: 0.519721    1.014064    3.461778    0.464092    0.082756    0.021542    0.615706    
#> 380: 0.519604    1.013981    3.461772    0.463885    0.082678    0.021542    0.615680    
#> 381: 0.519408    1.013970    3.461738    0.463595    0.082646    0.021534    0.615668    
#> 382: 0.519221    1.014025    3.461698    0.463481    0.082584    0.021521    0.615598    
#> 383: 0.519228    1.013952    3.461703    0.463422    0.082534    0.021506    0.615486    
#> 384: 0.519315    1.013926    3.461755    0.463794    0.082520    0.021515    0.615394    
#> 385: 0.519610    1.013909    3.461801    0.463834    0.082525    0.021504    0.615376    
#> 386: 0.519858    1.014078    3.461904    0.463765    0.082572    0.021498    0.615405    
#> 387: 0.520122    1.014240    3.461967    0.463997    0.082541    0.021482    0.615378    
#> 388: 0.520193    1.014246    3.461980    0.464304    0.082616    0.021457    0.615323    
#> 389: 0.520180    1.014131    3.461949    0.464409    0.082663    0.021444    0.615435    
#> 390: 0.520173    1.014179    3.461963    0.464364    0.082665    0.021432    0.615428    
#> 391: 0.520236    1.014155    3.461972    0.464361    0.082644    0.021433    0.615367    
#> 392: 0.520384    1.014101    3.462037    0.464127    0.082628    0.021415    0.615364    
#> 393: 0.520187    1.014044    3.461980    0.463919    0.082681    0.021411    0.615385    
#> 394: 0.520171    1.014108    3.461933    0.463772    0.082739    0.021402    0.615409    
#> 395: 0.520447    1.014168    3.461977    0.463642    0.082745    0.021415    0.615326    
#> 396: 0.520511    1.014248    3.461985    0.463403    0.082750    0.021418    0.615272    
#> 397: 0.520569    1.014241    3.462015    0.463436    0.082733    0.021424    0.615276    
#> 398: 0.520804    1.014277    3.462057    0.463600    0.082718    0.021425    0.615249    
#> 399: 0.520925    1.014297    3.462102    0.463568    0.082707    0.021410    0.615195    
#> 400: 0.521108    1.014315    3.462165    0.463595    0.082670    0.021379    0.615179    
#> 401: 0.521450    1.014329    3.462224    0.463576    0.082695    0.021369    0.615172    
#> 402: 0.521592    1.014434    3.462256    0.463407    0.082735    0.021349    0.615268    
#> 403: 0.521742    1.014487    3.462232    0.463262    0.082760    0.021323    0.615298    
#> 404: 0.521827    1.014432    3.462224    0.462895    0.082708    0.021305    0.615307    
#> 405: 0.521772    1.014465    3.462236    0.462703    0.082685    0.021291    0.615318    
#> 406: 0.521698    1.014487    3.462221    0.462604    0.082702    0.021287    0.615338    
#> 407: 0.521666    1.014523    3.462229    0.462511    0.082738    0.021268    0.615356    
#> 408: 0.521883    1.014599    3.462285    0.462538    0.082864    0.021262    0.615359    
#> 409: 0.521861    1.014547    3.462287    0.462428    0.082834    0.021260    0.615319    
#> 410: 0.521820    1.014564    3.462258    0.462244    0.082774    0.021268    0.615214    
#> 411: 0.521811    1.014385    3.462235    0.462440    0.082670    0.021275    0.615203    
#> 412: 0.521924    1.014428    3.462252    0.462669    0.082596    0.021304    0.615234    
#> 413: 0.522010    1.014494    3.462235    0.462776    0.082527    0.021311    0.615169    
#> 414: 0.521812    1.014497    3.462264    0.462734    0.082461    0.021306    0.615152    
#> 415: 0.521873    1.014512    3.462275    0.462681    0.082443    0.021301    0.615129    
#> 416: 0.522012    1.014491    3.462369    0.462736    0.082433    0.021296    0.615133    
#> 417: 0.522114    1.014418    3.462409    0.462369    0.082408    0.021290    0.615146    
#> 418: 0.522060    1.014425    3.462448    0.462224    0.082383    0.021299    0.615143    
#> 419: 0.522141    1.014449    3.462479    0.462210    0.082389    0.021290    0.615126    
#> 420: 0.522295    1.014484    3.462478    0.462345    0.082406    0.021270    0.615099    
#> 421: 0.522310    1.014488    3.462538    0.462227    0.082327    0.021264    0.615102    
#> 422: 0.522522    1.014459    3.462583    0.462141    0.082319    0.021249    0.615098    
#> 423: 0.522634    1.014439    3.462614    0.461843    0.082361    0.021237    0.615085    
#> 424: 0.522480    1.014418    3.462532    0.461595    0.082368    0.021210    0.615091    
#> 425: 0.522512    1.014504    3.462488    0.461593    0.082355    0.021200    0.615101    
#> 426: 0.522510    1.014608    3.462470    0.461724    0.082376    0.021188    0.615077    
#> 427: 0.522252    1.014599    3.462448    0.461436    0.082410    0.021176    0.615011    
#> 428: 0.522207    1.014683    3.462465    0.461282    0.082420    0.021173    0.615001    
#> 429: 0.522237    1.014725    3.462488    0.461259    0.082365    0.021186    0.614987    
#> 430: 0.522105    1.014749    3.462452    0.461406    0.082360    0.021187    0.614966    
#> 431: 0.521863    1.014760    3.462389    0.461060    0.082418    0.021179    0.614928    
#> 432: 0.521726    1.014749    3.462379    0.460991    0.082412    0.021194    0.614877    
#> 433: 0.521755    1.014814    3.462364    0.461231    0.082437    0.021198    0.614880    
#> 434: 0.521689    1.014730    3.462361    0.461529    0.082475    0.021190    0.614823    
#> 435: 0.521747    1.014679    3.462374    0.461695    0.082519    0.021199    0.614780    
#> 436: 0.521741    1.014522    3.462432    0.461341    0.082550    0.021204    0.614832    
#> 437: 0.521807    1.014312    3.462480    0.461172    0.082607    0.021195    0.614925    
#> 438: 0.521839    1.014367    3.462523    0.461059    0.082605    0.021185    0.614952    
#> 439: 0.521955    1.014426    3.462561    0.461108    0.082605    0.021168    0.614920    
#> 440: 0.522072    1.014469    3.462616    0.460859    0.082627    0.021165    0.614918    
#> 441: 0.522158    1.014353    3.462681    0.460362    0.082636    0.021172    0.614900    
#> 442: 0.522168    1.014384    3.462703    0.460208    0.082649    0.021171    0.614835    
#> 443: 0.522192    1.014468    3.462669    0.460141    0.082648    0.021167    0.614797    
#> 444: 0.522079    1.014560    3.462605    0.460135    0.082636    0.021146    0.614813    
#> 445: 0.522003    1.014593    3.462587    0.460095    0.082618    0.021121    0.614883    
#> 446: 0.521921    1.014641    3.462559    0.459926    0.082587    0.021099    0.614904    
#> 447: 0.521913    1.014660    3.462569    0.459853    0.082627    0.021086    0.614863    
#> 448: 0.521918    1.014645    3.462597    0.459611    0.082642    0.021087    0.614810    
#> 449: 0.521983    1.014695    3.462661    0.459552    0.082678    0.021091    0.614815    
#> 450: 0.522000    1.014625    3.462682    0.459479    0.082748    0.021088    0.614798    
#> 451: 0.522058    1.014618    3.462682    0.459530    0.082829    0.021078    0.614825    
#> 452: 0.522088    1.014665    3.462685    0.459345    0.082846    0.021069    0.614829    
#> 453: 0.521980    1.014723    3.462656    0.459160    0.082826    0.021060    0.614809    
#> 454: 0.521975    1.014832    3.462651    0.459138    0.082826    0.021062    0.614781    
#> 455: 0.522011    1.014878    3.462650    0.459168    0.082784    0.021064    0.614759    
#> 456: 0.521951    1.014851    3.462648    0.459074    0.082815    0.021051    0.614735    
#> 457: 0.521960    1.014827    3.462676    0.459000    0.082865    0.021030    0.614685    
#> 458: 0.522018    1.014907    3.462701    0.458865    0.082908    0.021006    0.614670    
#> 459: 0.521988    1.014978    3.462706    0.458773    0.082934    0.020978    0.614721    
#> 460: 0.521828    1.014904    3.462688    0.458526    0.082984    0.020975    0.614702    
#> 461: 0.521791    1.014842    3.462713    0.458633    0.082983    0.020976    0.614686    
#> 462: 0.521830    1.014852    3.462734    0.458733    0.082992    0.020971    0.614647    
#> 463: 0.522025    1.014869    3.462787    0.458897    0.082988    0.020983    0.614642    
#> 464: 0.522163    1.014898    3.462811    0.458963    0.083005    0.020992    0.614547    
#> 465: 0.522290    1.014808    3.462837    0.459000    0.082994    0.020987    0.614457    
#> 466: 0.522344    1.014819    3.462828    0.459101    0.082979    0.020990    0.614413    
#> 467: 0.522246    1.014800    3.462848    0.458905    0.083004    0.020973    0.614315    
#> 468: 0.522370    1.014812    3.462898    0.458865    0.082982    0.020983    0.614273    
#> 469: 0.522360    1.014926    3.462914    0.458920    0.082965    0.020995    0.614263    
#> 470: 0.522234    1.015020    3.462869    0.458914    0.082963    0.021003    0.614273    
#> 471: 0.522038    1.015073    3.462813    0.458676    0.082967    0.021002    0.614302    
#> 472: 0.521935    1.015086    3.462780    0.458654    0.082972    0.020996    0.614315    
#> 473: 0.521855    1.015098    3.462775    0.458444    0.082974    0.021001    0.614248    
#> 474: 0.521808    1.015093    3.462747    0.458571    0.082990    0.021014    0.614243    
#> 475: 0.521713    1.015193    3.462742    0.458561    0.082986    0.021022    0.614265    
#> 476: 0.521770    1.015144    3.462760    0.458866    0.082978    0.021032    0.614265    
#> 477: 0.521808    1.015085    3.462823    0.458818    0.082963    0.021046    0.614229    
#> 478: 0.521825    1.015075    3.462844    0.458910    0.082995    0.021062    0.614201    
#> 479: 0.521790    1.015112    3.462826    0.458919    0.082997    0.021067    0.614239    
#> 480: 0.521758    1.015152    3.462804    0.458843    0.083024    0.021073    0.614304    
#> 481: 0.521663    1.015192    3.462771    0.458757    0.082995    0.021083    0.614348    
#> 482: 0.521698    1.015220    3.462726    0.458764    0.082979    0.021092    0.614350    
#> 483: 0.521619    1.015278    3.462699    0.458693    0.082991    0.021106    0.614304    
#> 484: 0.521551    1.015225    3.462677    0.458647    0.082999    0.021121    0.614297    
#> 485: 0.521482    1.015232    3.462640    0.458757    0.082950    0.021125    0.614305    
#> 486: 0.521396    1.015236    3.462649    0.458571    0.082889    0.021128    0.614279    
#> 487: 0.521500    1.015224    3.462690    0.458519    0.082846    0.021140    0.614277    
#> 488: 0.521555    1.015189    3.462702    0.458404    0.082862    0.021147    0.614226    
#> 489: 0.521659    1.015191    3.462705    0.458522    0.082873    0.021156    0.614166    
#> 490: 0.521801    1.015184    3.462730    0.458623    0.082869    0.021163    0.614118    
#> 491: 0.521963    1.015207    3.462803    0.458651    0.082864    0.021167    0.614071    
#> 492: 0.522081    1.015211    3.462826    0.458686    0.082901    0.021162    0.614097    
#> 493: 0.522240    1.015186    3.462888    0.458652    0.082902    0.021169    0.614119    
#> 494: 0.522440    1.015200    3.462940    0.458503    0.082915    0.021171    0.614112    
#> 495: 0.522662    1.015245    3.462992    0.458695    0.082927    0.021170    0.614106    
#> 496: 0.522728    1.015280    3.462972    0.458644    0.082915    0.021155    0.614085    
#> 497: 0.522764    1.015279    3.462998    0.458563    0.082877    0.021140    0.614161    
#> 498: 0.522779    1.015257    3.463001    0.458480    0.082827    0.021134    0.614142    
#> 499: 0.522730    1.015280    3.462955    0.458383    0.082829    0.021126    0.614125    
#> 500: 0.522722    1.015254    3.462938    0.458297    0.082826    0.021112    0.614144    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.312933    0.965148    3.448485    0.392401    0.077832    0.016800    1.710124    
#> 002: 0.186411    0.997537    3.480342    0.372781    0.073940    0.015960    0.995968    
#> 003: 0.252008    0.949593    3.479166    0.354142    0.070243    0.015162    0.753755    
#> 004: 0.169404    0.963943    3.464969    0.336435    0.066731    0.014404    0.673760    
#> 005: 0.216324    0.969339    3.460938    0.319613    0.063395    0.013684    0.627144    
#> 006: 0.183901    0.958840    3.453960    0.303633    0.060225    0.013000    0.613969    
#> 007: 0.147396    0.974095    3.448086    0.288451    0.058525    0.012350    0.614900    
#> 008: 0.130481    0.991410    3.427006    0.274029    0.062295    0.011732    0.596677    
#> 009: 0.116294    0.973960    3.432386    0.260327    0.059181    0.011146    0.616699    
#> 010: 0.154717    0.966189    3.438256    0.247311    0.056222    0.010588    0.631581    
#> 011: 0.203353    0.964341    3.440038    0.234945    0.055720    0.010441    0.630479    
#> 012: 0.186504    0.982081    3.435392    0.223198    0.052934    0.009919    0.620513    
#> 013: 0.122441    0.996576    3.420201    0.212038    0.050513    0.010409    0.633062    
#> 014: 0.158535    0.992832    3.422653    0.208209    0.047988    0.011415    0.623976    
#> 015: 0.164502    0.995567    3.442592    0.201148    0.045588    0.013108    0.610824    
#> 016: 0.162775    0.989437    3.453475    0.191091    0.043309    0.013561    0.616233    
#> 017: 0.147738    1.002889    3.443993    0.181536    0.041143    0.013729    0.603560    
#> 018: 0.167742    0.996070    3.438878    0.172459    0.039086    0.015217    0.615795    
#> 019: 0.150133    0.981197    3.437646    0.195409    0.037132    0.014456    0.607785    
#> 020: 0.178584    0.995285    3.443521    0.185639    0.048909    0.013734    0.602562    
#> 021: 0.182266    0.980349    3.448265    0.176357    0.052934    0.013047    0.590180    
#> 022: 0.196938    0.982544    3.458703    0.225171    0.053601    0.013190    0.588651    
#> 023: 0.234978    0.980521    3.471779    0.213912    0.065064    0.012530    0.608557    
#> 024: 0.232644    0.986171    3.465157    0.203217    0.061811    0.011904    0.594056    
#> 025: 0.197896    0.964586    3.455987    0.193056    0.058720    0.011309    0.600328    
#> 026: 0.179469    0.992882    3.451581    0.183403    0.055784    0.010743    0.598966    
#> 027: 0.173463    0.992317    3.447164    0.184381    0.052995    0.011462    0.609437    
#> 028: 0.213037    0.969026    3.457182    0.175162    0.050345    0.010889    0.594707    
#> 029: 0.182663    0.978016    3.446855    0.166404    0.052930    0.010787    0.618577    
#> 030: 0.186078    0.987537    3.452987    0.199391    0.050283    0.011525    0.598306    
#> 031: 0.167356    0.980940    3.453876    0.189422    0.057086    0.010949    0.605114    
#> 032: 0.170001    0.973774    3.451213    0.179951    0.054232    0.010402    0.592248    
#> 033: 0.157557    1.008998    3.433472    0.190150    0.063144    0.009882    0.607329    
#> 034: 0.178911    1.007043    3.436456    0.204928    0.059987    0.009388    0.610967    
#> 035: 0.140443    0.978247    3.433770    0.194682    0.059762    0.008918    0.594540    
#> 036: 0.144365    1.008555    3.435804    0.184948    0.056774    0.008774    0.611352    
#> 037: 0.149888    1.018609    3.436334    0.175700    0.066125    0.008335    0.619585    
#> 038: 0.201809    0.996891    3.437053    0.196907    0.072806    0.008049    0.614214    
#> 039: 0.178870    0.991852    3.446718    0.187062    0.069165    0.008546    0.601649    
#> 040: 0.178565    0.980782    3.455322    0.184186    0.065707    0.008705    0.605748    
#> 041: 0.171035    0.982695    3.458457    0.186326    0.062422    0.009447    0.613020    
#> 042: 0.207283    0.983815    3.444566    0.198924    0.059301    0.008974    0.617345    
#> 043: 0.158881    0.997527    3.436255    0.188978    0.056336    0.008526    0.614522    
#> 044: 0.152716    1.013442    3.433777    0.179529    0.053519    0.008099    0.609478    
#> 045: 0.178673    1.012834    3.440005    0.170553    0.054321    0.007694    0.611902    
#> 046: 0.171272    0.997170    3.443077    0.162025    0.052457    0.008140    0.606244    
#> 047: 0.173193    1.005895    3.435754    0.166572    0.057472    0.008175    0.597600    
#> 048: 0.187571    0.993896    3.443406    0.193510    0.061990    0.008611    0.596021    
#> 049: 0.200937    0.999212    3.451337    0.183834    0.062642    0.008181    0.601594    
#> 050: 0.210950    0.968587    3.447917    0.179489    0.060149    0.007772    0.616797    
#> 051: 0.188658    0.992978    3.443033    0.189007    0.062817    0.007973    0.618093    
#> 052: 0.195861    1.007850    3.448241    0.179557    0.061434    0.007574    0.602312    
#> 053: 0.190755    1.005783    3.444786    0.238567    0.060471    0.007195    0.610540    
#> 054: 0.164402    0.984612    3.454644    0.226639    0.057447    0.010145    0.620279    
#> 055: 0.178201    0.981287    3.452524    0.215307    0.054575    0.009807    0.620881    
#> 056: 0.175724    0.962311    3.453229    0.204542    0.051846    0.009316    0.613123    
#> 057: 0.201722    0.960178    3.460374    0.244245    0.063947    0.008850    0.606906    
#> 058: 0.185337    0.968821    3.443050    0.232032    0.062942    0.008408    0.618399    
#> 059: 0.158630    0.961004    3.441750    0.220431    0.059975    0.007988    0.630592    
#> 060: 0.144603    0.982073    3.443825    0.209592    0.063557    0.009242    0.627224    
#> 061: 0.184926    0.977218    3.441071    0.268497    0.060379    0.009754    0.648600    
#> 062: 0.181086    0.997275    3.455203    0.255072    0.057360    0.011689    0.651369    
#> 063: 0.222216    0.963014    3.457189    0.252526    0.055349    0.011105    0.650669    
#> 064: 0.206990    0.977217    3.471610    0.239900    0.054512    0.010550    0.641923    
#> 065: 0.228424    0.956856    3.457591    0.227905    0.053533    0.010022    0.630799    
#> 066: 0.205026    0.970018    3.459821    0.216509    0.058174    0.009521    0.627058    
#> 067: 0.196124    0.975818    3.448383    0.205684    0.055265    0.009319    0.620981    
#> 068: 0.168727    0.979763    3.453050    0.195400    0.052502    0.008853    0.632680    
#> 069: 0.173049    0.982406    3.453825    0.185630    0.051705    0.008410    0.625207    
#> 070: 0.171458    0.983987    3.452954    0.176348    0.055794    0.009909    0.620080    
#> 071: 0.142025    1.013830    3.424618    0.180985    0.053004    0.009413    0.621253    
#> 072: 0.122456    0.988664    3.426611    0.182951    0.053486    0.009108    0.609170    
#> 073: 0.144007    0.998828    3.436729    0.173804    0.057081    0.008653    0.617884    
#> 074: 0.144996    0.989511    3.444170    0.165269    0.054290    0.008672    0.618982    
#> 075: 0.211477    0.964514    3.470401    0.162087    0.054200    0.008238    0.614172    
#> 076: 0.212852    0.972484    3.478013    0.171068    0.051490    0.008035    0.613815    
#> 077: 0.243042    0.958842    3.457453    0.182009    0.048916    0.009962    0.620289    
#> 078: 0.222312    0.961530    3.476140    0.172909    0.049977    0.009464    0.596961    
#> 079: 0.235940    0.962708    3.481768    0.188654    0.050126    0.011203    0.634668    
#> 080: 0.231250    0.946628    3.478720    0.202494    0.047620    0.010643    0.624818    
#> 081: 0.221647    0.963727    3.469091    0.199851    0.045239    0.011241    0.608992    
#> 082: 0.217266    0.972315    3.470469    0.189858    0.047460    0.010679    0.620076    
#> 083: 0.209984    0.994138    3.464083    0.188756    0.056579    0.010145    0.614556    
#> 084: 0.212585    0.975990    3.457904    0.179318    0.061882    0.011454    0.603610    
#> 085: 0.184786    0.985244    3.464333    0.170352    0.058788    0.011401    0.632092    
#> 086: 0.203816    0.969740    3.463455    0.169532    0.055848    0.012095    0.608977    
#> 087: 0.187675    0.975869    3.453976    0.184027    0.053056    0.011490    0.603066    
#> 088: 0.170381    0.966445    3.458224    0.203657    0.050403    0.011203    0.603035    
#> 089: 0.203932    0.987327    3.454605    0.193474    0.050941    0.014522    0.606980    
#> 090: 0.150921    0.990071    3.436691    0.202706    0.055592    0.015433    0.599191    
#> 091: 0.148260    0.991103    3.423802    0.210213    0.052812    0.014661    0.605814    
#> 092: 0.128949    1.022078    3.418169    0.208876    0.055515    0.013928    0.602257    
#> 093: 0.132324    1.011961    3.426752    0.239679    0.057323    0.013232    0.606201    
#> 094: 0.132657    1.006480    3.426055    0.227695    0.055214    0.012570    0.611419    
#> 095: 0.134940    1.015821    3.429453    0.216311    0.052453    0.012066    0.594980    
#> 096: 0.083196    1.017568    3.416381    0.222645    0.054004    0.011463    0.589794    
#> 097: 0.116986    1.021078    3.413880    0.211513    0.056481    0.010890    0.595352    
#> 098: 0.138759    1.026037    3.426812    0.200937    0.059873    0.010345    0.609256    
#> 099: 0.113524    0.990539    3.411740    0.190890    0.057228    0.009828    0.593873    
#> 100: 0.126027    1.004858    3.424739    0.181346    0.063248    0.009337    0.596346    
#> 101: 0.093812    1.005345    3.407518    0.205742    0.060085    0.008870    0.593831    
#> 102: 0.105292    1.015357    3.403430    0.197696    0.057081    0.009324    0.601707    
#> 103: 0.134487    1.006374    3.415984    0.209647    0.054227    0.008857    0.598725    
#> 104: 0.123280    1.003546    3.428368    0.214676    0.054668    0.008415    0.615434    
#> 105: 0.129922    0.996833    3.427595    0.203943    0.058969    0.007994    0.613637    
#> 106: 0.178029    0.992731    3.442667    0.193745    0.056021    0.007594    0.596158    
#> 107: 0.183704    1.001827    3.438277    0.184058    0.066647    0.007214    0.610171    
#> 108: 0.154778    1.004107    3.434354    0.187513    0.063315    0.006854    0.630668    
#> 109: 0.147108    1.003870    3.444484    0.195588    0.071817    0.006585    0.619906    
#> 110: 0.173863    1.002615    3.429375    0.185809    0.068226    0.006947    0.620403    
#> 111: 0.152593    1.004051    3.433518    0.176518    0.064815    0.006786    0.612750    
#> 112: 0.164401    0.980175    3.433901    0.167744    0.061574    0.006745    0.635390    
#> 113: 0.170736    1.011814    3.435503    0.159356    0.058495    0.007043    0.610346    
#> 114: 0.166045    1.018347    3.434097    0.153820    0.055570    0.006691    0.618552    
#> 115: 0.199932    0.975502    3.440818    0.146129    0.058016    0.007305    0.619602    
#> 116: 0.178016    0.996151    3.441205    0.152555    0.055115    0.009313    0.612516    
#> 117: 0.152996    1.007997    3.436839    0.149743    0.052359    0.008848    0.612923    
#> 118: 0.173443    0.990628    3.444553    0.168894    0.052345    0.008410    0.611986    
#> 119: 0.175851    0.993827    3.444003    0.199275    0.054619    0.008418    0.599919    
#> 120: 0.155555    0.966241    3.445494    0.189311    0.051888    0.010069    0.608036    
#> 121: 0.168666    1.002711    3.438400    0.188112    0.049294    0.010396    0.610750    
#> 122: 0.173701    0.973861    3.447723    0.191252    0.046829    0.009877    0.623755    
#> 123: 0.196713    1.008825    3.446627    0.181689    0.048914    0.009383    0.605780    
#> 124: 0.170460    1.010561    3.436279    0.196628    0.046468    0.008914    0.603069    
#> 125: 0.167664    1.012029    3.436070    0.194511    0.054350    0.008468    0.602784    
#> 126: 0.130893    1.025986    3.419856    0.203645    0.056783    0.008936    0.604034    
#> 127: 0.183441    0.998030    3.421530    0.193463    0.053944    0.008489    0.626943    
#> 128: 0.159123    0.987348    3.438695    0.183790    0.053527    0.009546    0.607353    
#> 129: 0.190526    0.996247    3.442412    0.176479    0.050851    0.011091    0.610397    
#> 130: 0.195970    1.018740    3.439411    0.200202    0.050815    0.011633    0.602978    
#> 131: 0.151163    1.013237    3.422513    0.190191    0.056442    0.011051    0.612952    
#> 132: 0.129644    1.027035    3.414550    0.180682    0.054934    0.010499    0.622012    
#> 133: 0.125335    1.007212    3.421750    0.171648    0.052187    0.009974    0.631446    
#> 134: 0.160188    0.985733    3.446731    0.163065    0.049578    0.009969    0.611769    
#> 135: 0.162586    0.985509    3.451348    0.170687    0.048596    0.009471    0.624874    
#> 136: 0.181241    0.963917    3.456526    0.167143    0.050354    0.011365    0.602687    
#> 137: 0.209402    0.965992    3.463956    0.174682    0.050405    0.012455    0.602614    
#> 138: 0.168308    0.978809    3.448545    0.187515    0.050791    0.012743    0.608016    
#> 139: 0.171209    0.998257    3.446007    0.186627    0.050404    0.012106    0.602964    
#> 140: 0.205495    1.008710    3.450202    0.213980    0.053467    0.011501    0.609963    
#> 141: 0.176545    0.983401    3.459516    0.203281    0.050794    0.011525    0.617852    
#> 142: 0.181153    0.959932    3.462995    0.193117    0.048254    0.010949    0.631549    
#> 143: 0.147161    0.995070    3.457763    0.185835    0.052463    0.010401    0.624212    
#> 144: 0.202720    0.989429    3.468381    0.176544    0.049839    0.009881    0.619040    
#> 145: 0.199105    0.995648    3.456612    0.169976    0.047347    0.009391    0.608809    
#> 146: 0.172150    1.001983    3.461348    0.166425    0.049684    0.008922    0.616450    
#> 147: 0.149483    0.984207    3.447620    0.170193    0.050522    0.008476    0.601218    
#> 148: 0.158102    0.989209    3.454024    0.169244    0.052576    0.008137    0.604538    
#> 149: 0.189438    0.973008    3.453684    0.160782    0.049947    0.009524    0.630559    
#> 150: 0.203275    0.993111    3.449194    0.194220    0.047449    0.009181    0.648120    
#> 151: 0.162093    1.018580    3.441005    0.184509    0.047522    0.008722    0.637562    
#> 152: 0.122616    1.011797    3.425109    0.177656    0.054417    0.009364    0.632938    
#> 153: 0.155389    1.000224    3.440100    0.179921    0.056824    0.009719    0.619584    
#> 154: 0.181788    1.006962    3.444922    0.175773    0.064446    0.012799    0.615718    
#> 155: 0.157294    0.981833    3.436086    0.192348    0.043524    0.012178    0.614150    
#> 156: 0.173073    0.990296    3.450774    0.184617    0.051690    0.014345    0.631942    
#> 157: 0.207669    0.995532    3.468388    0.149827    0.057535    0.014141    0.628720    
#> 158: 0.213549    0.980723    3.462305    0.166513    0.043272    0.013981    0.605503    
#> 159: 0.177785    0.984101    3.454759    0.164018    0.047082    0.011339    0.604462    
#> 160: 0.185686    0.974375    3.465452    0.170625    0.044572    0.012334    0.610120    
#> 161: 0.161446    0.988670    3.453796    0.167901    0.037584    0.013364    0.622172    
#> 162: 0.144257    1.015103    3.440459    0.171169    0.037760    0.013680    0.618676    
#> 163: 0.152906    1.004763    3.432586    0.166833    0.037829    0.011322    0.603666    
#> 164: 0.170199    1.001229    3.438496    0.176865    0.039584    0.013267    0.613941    
#> 165: 0.173592    0.995767    3.442306    0.183837    0.042607    0.014628    0.604563    
#> 166: 0.176761    1.014648    3.444264    0.193750    0.044585    0.015222    0.609067    
#> 167: 0.200425    1.018303    3.452587    0.186100    0.049887    0.011630    0.620898    
#> 168: 0.187075    1.007271    3.447833    0.187484    0.055596    0.008363    0.613694    
#> 169: 0.188060    1.020465    3.439769    0.194409    0.049407    0.009584    0.612372    
#> 170: 0.175538    1.003890    3.437639    0.173832    0.050872    0.011386    0.610299    
#> 171: 0.152116    0.991493    3.432091    0.188547    0.045957    0.009574    0.589447    
#> 172: 0.151906    1.014143    3.429635    0.192406    0.050527    0.010492    0.588080    
#> 173: 0.112737    1.027877    3.415740    0.176719    0.050047    0.009230    0.608888    
#> 174: 0.138299    1.008047    3.426161    0.155499    0.060326    0.008501    0.612312    
#> 175: 0.136832    1.016984    3.416724    0.193456    0.061415    0.008699    0.605752    
#> 176: 0.135579    1.021017    3.428346    0.191555    0.058089    0.008136    0.609084    
#> 177: 0.154052    1.001031    3.438515    0.167033    0.057365    0.009051    0.599479    
#> 178: 0.160929    0.998684    3.435129    0.174444    0.066545    0.011099    0.598126    
#> 179: 0.172956    1.022763    3.440314    0.219775    0.058943    0.011113    0.612318    
#> 180: 0.180469    1.001612    3.440758    0.202794    0.054317    0.011131    0.591209    
#> 181: 0.158834    0.988086    3.428127    0.178755    0.044704    0.009632    0.607150    
#> 182: 0.106278    1.015407    3.409783    0.174248    0.057237    0.009373    0.618801    
#> 183: 0.134533    1.024651    3.415300    0.167971    0.062851    0.009637    0.599991    
#> 184: 0.150170    0.992411    3.430786    0.173011    0.057582    0.009948    0.617528    
#> 185: 0.139824    1.001529    3.434581    0.161654    0.057141    0.012044    0.614737    
#> 186: 0.144994    1.025774    3.437670    0.196884    0.063935    0.014241    0.604489    
#> 187: 0.154764    0.995857    3.442208    0.174392    0.052055    0.012348    0.624039    
#> 188: 0.160068    1.021476    3.438061    0.190783    0.056737    0.011039    0.621055    
#> 189: 0.177481    1.008048    3.444673    0.177214    0.060736    0.010365    0.628168    
#> 190: 0.167268    0.995668    3.442462    0.189447    0.052468    0.010012    0.617538    
#> 191: 0.150292    1.004379    3.434047    0.181720    0.049208    0.009883    0.606423    
#> 192: 0.145242    1.000120    3.441192    0.156880    0.046738    0.008568    0.601443    
#> 193: 0.176931    1.007405    3.440945    0.155634    0.038501    0.008284    0.607392    
#> 194: 0.145428    1.006787    3.431022    0.155700    0.048554    0.007298    0.652375    
#> 195: 0.127434    1.002357    3.424189    0.151050    0.046223    0.007938    0.639903    
#> 196: 0.114465    1.009134    3.426760    0.138114    0.054147    0.009132    0.632070    
#> 197: 0.097767    1.019124    3.444492    0.172673    0.049434    0.012208    0.615867    
#> 198: 0.159194    0.998958    3.439135    0.148660    0.050289    0.010130    0.605581    
#> 199: 0.139883    0.998604    3.433235    0.165448    0.046884    0.008557    0.614314    
#> 200: 0.153995    0.985622    3.436732    0.165756    0.046935    0.006362    0.643821    
#> 201: 0.150603    0.979478    3.442784    0.166944    0.046299    0.007181    0.639031    
#> 202: 0.151569    0.981952    3.441393    0.170269    0.049062    0.007041    0.634539    
#> 203: 0.162587    0.980022    3.440129    0.179495    0.049994    0.007160    0.632730    
#> 204: 0.169402    0.978435    3.441823    0.180384    0.052506    0.007168    0.633958    
#> 205: 0.168514    0.981598    3.442408    0.178697    0.053972    0.007322    0.633790    
#> 206: 0.169616    0.983446    3.443731    0.175524    0.054735    0.007088    0.634758    
#> 207: 0.166956    0.981809    3.443113    0.174485    0.055542    0.007089    0.636264    
#> 208: 0.167480    0.981748    3.443550    0.175517    0.054381    0.007269    0.635427    
#> 209: 0.170378    0.981592    3.443365    0.177738    0.053806    0.007302    0.635555    
#> 210: 0.172032    0.981705    3.443056    0.180598    0.053365    0.007252    0.633743    
#> 211: 0.173368    0.984133    3.443495    0.181760    0.054242    0.007228    0.631457    
#> 212: 0.175259    0.984855    3.443767    0.183237    0.054631    0.007372    0.630047    
#> 213: 0.177808    0.984239    3.444400    0.184637    0.055338    0.007458    0.629530    
#> 214: 0.177757    0.984274    3.444967    0.184434    0.055715    0.007518    0.628795    
#> 215: 0.177661    0.984489    3.445582    0.184583    0.055630    0.007604    0.628239    
#> 216: 0.178195    0.984374    3.445929    0.185404    0.055676    0.007507    0.627905    
#> 217: 0.177086    0.985696    3.445887    0.185914    0.055563    0.007534    0.627134    
#> 218: 0.177013    0.986407    3.445356    0.186008    0.055649    0.007630    0.625726    
#> 219: 0.176116    0.986839    3.444859    0.185877    0.055179    0.007669    0.624968    
#> 220: 0.175215    0.987816    3.445194    0.185477    0.054767    0.007681    0.623935    
#> 221: 0.174600    0.987840    3.445081    0.185251    0.054252    0.007721    0.623060    
#> 222: 0.175301    0.987905    3.445315    0.185004    0.053946    0.007903    0.622582    
#> 223: 0.176572    0.987221    3.445639    0.184819    0.053714    0.007994    0.621672    
#> 224: 0.178145    0.987642    3.446012    0.184930    0.053528    0.008060    0.621238    
#> 225: 0.178865    0.986359    3.446268    0.183933    0.053310    0.008177    0.621271    
#> 226: 0.179750    0.985020    3.446302    0.183881    0.053416    0.008249    0.621511    
#> 227: 0.179275    0.984624    3.446428    0.184226    0.053359    0.008352    0.620965    
#> 228: 0.176883    0.986014    3.445525    0.184921    0.053513    0.008443    0.620933    
#> 229: 0.175814    0.986198    3.445199    0.184650    0.053629    0.008461    0.620557    
#> 230: 0.175358    0.986258    3.444895    0.184905    0.053609    0.008511    0.620203    
#> 231: 0.175428    0.986514    3.445135    0.184272    0.053474    0.008585    0.619902    
#> 232: 0.175348    0.986333    3.445480    0.184143    0.053351    0.008613    0.619410    
#> 233: 0.175570    0.985465    3.445921    0.183606    0.053296    0.008686    0.619320    
#> 234: 0.175729    0.985295    3.446335    0.183109    0.053127    0.008770    0.619311    
#> 235: 0.175390    0.985275    3.446221    0.182768    0.053120    0.008796    0.619421    
#> 236: 0.175573    0.985809    3.446047    0.182717    0.053142    0.008835    0.619237    
#> 237: 0.176072    0.985699    3.446049    0.183466    0.052997    0.008893    0.619039    
#> 238: 0.176704    0.985680    3.446131    0.184433    0.053102    0.008898    0.618922    
#> 239: 0.176906    0.985985    3.446222    0.185507    0.053316    0.008954    0.618705    
#> 240: 0.177207    0.985942    3.446245    0.186295    0.053249    0.008951    0.618497    
#> 241: 0.177270    0.985190    3.446348    0.186147    0.053426    0.008915    0.618266    
#> 242: 0.177297    0.985016    3.446129    0.186051    0.053620    0.008879    0.618268    
#> 243: 0.176975    0.985321    3.446048    0.186185    0.053818    0.008849    0.618332    
#> 244: 0.176683    0.985395    3.446210    0.185328    0.053791    0.008848    0.618411    
#> 245: 0.177115    0.985238    3.446426    0.185387    0.053677    0.008859    0.618398    
#> 246: 0.177165    0.985048    3.446673    0.184931    0.053588    0.008894    0.618555    
#> 247: 0.177257    0.984781    3.447166    0.184986    0.053505    0.008927    0.618475    
#> 248: 0.177302    0.985086    3.447415    0.184756    0.053328    0.008949    0.618323    
#> 249: 0.177081    0.985113    3.447450    0.185035    0.053233    0.008965    0.618380    
#> 250: 0.177567    0.985265    3.447566    0.185165    0.053443    0.009013    0.618072    
#> 251: 0.177545    0.985476    3.447703    0.185012    0.053453    0.009015    0.618044    
#> 252: 0.177634    0.985507    3.447834    0.185481    0.053368    0.009025    0.617638    
#> 253: 0.177247    0.985280    3.447908    0.185277    0.053213    0.009064    0.617605    
#> 254: 0.177292    0.985797    3.448033    0.185482    0.053147    0.009044    0.617221    
#> 255: 0.177577    0.986225    3.448133    0.185087    0.053038    0.009055    0.616929    
#> 256: 0.177775    0.986135    3.448151    0.184799    0.052914    0.009067    0.616639    
#> 257: 0.177796    0.985780    3.448186    0.184714    0.052900    0.009060    0.616541    
#> 258: 0.177489    0.985356    3.448193    0.184847    0.052930    0.009058    0.616498    
#> 259: 0.177339    0.985206    3.448225    0.184519    0.052946    0.009075    0.616348    
#> 260: 0.177190    0.985247    3.448240    0.184579    0.052985    0.009062    0.615983    
#> 261: 0.177289    0.985428    3.448316    0.184906    0.053015    0.009064    0.615882    
#> 262: 0.177226    0.985620    3.448305    0.185283    0.052991    0.009062    0.616002    
#> 263: 0.177067    0.985821    3.448349    0.185885    0.052957    0.009066    0.615908    
#> 264: 0.176552    0.985895    3.448224    0.186290    0.052849    0.009056    0.616363    
#> 265: 0.176221    0.986265    3.448145    0.186128    0.052949    0.009031    0.616535    
#> 266: 0.175918    0.986494    3.448024    0.186187    0.052930    0.008992    0.616636    
#> 267: 0.175843    0.986501    3.448042    0.186335    0.053006    0.008993    0.616727    
#> 268: 0.175798    0.986122    3.448020    0.186409    0.053049    0.008996    0.616683    
#> 269: 0.176133    0.985785    3.447952    0.186518    0.053078    0.008994    0.616748    
#> 270: 0.176379    0.985812    3.447839    0.186659    0.052982    0.008961    0.616609    
#> 271: 0.176184    0.985958    3.447577    0.186556    0.052919    0.008935    0.617041    
#> 272: 0.176249    0.985819    3.447491    0.185994    0.052854    0.008950    0.617330    
#> 273: 0.176037    0.986269    3.447403    0.185974    0.052938    0.008959    0.617414    
#> 274: 0.175848    0.986627    3.447442    0.186002    0.052833    0.008943    0.617498    
#> 275: 0.175902    0.986911    3.447318    0.186179    0.052891    0.008947    0.617466    
#> 276: 0.175773    0.987074    3.447422    0.186037    0.052788    0.008968    0.617504    
#> 277: 0.175373    0.987189    3.447556    0.185909    0.052650    0.009023    0.617451    
#> 278: 0.174979    0.987509    3.447564    0.185905    0.052678    0.009035    0.617419    
#> 279: 0.174917    0.987257    3.447638    0.186264    0.052596    0.009079    0.617332    
#> 280: 0.175053    0.987334    3.447787    0.186115    0.052474    0.009118    0.617029    
#> 281: 0.174709    0.987394    3.447855    0.186272    0.052348    0.009154    0.617040    
#> 282: 0.174875    0.987591    3.447976    0.185895    0.052299    0.009175    0.617008    
#> 283: 0.175215    0.987484    3.448111    0.186124    0.052222    0.009224    0.617133    
#> 284: 0.175399    0.987226    3.448211    0.186214    0.052062    0.009254    0.617183    
#> 285: 0.175583    0.987430    3.448104    0.185803    0.051879    0.009280    0.617243    
#> 286: 0.175620    0.987663    3.448124    0.185440    0.051763    0.009317    0.617259    
#> 287: 0.175729    0.987998    3.448104    0.184977    0.051705    0.009363    0.617379    
#> 288: 0.175887    0.988100    3.448045    0.184587    0.051708    0.009368    0.617655    
#> 289: 0.175973    0.988087    3.448044    0.184576    0.051795    0.009370    0.617706    
#> 290: 0.176276    0.988068    3.448049    0.184673    0.051713    0.009377    0.617810    
#> 291: 0.176673    0.988254    3.448152    0.184607    0.051608    0.009367    0.617679    
#> 292: 0.176803    0.988191    3.448212    0.184638    0.051566    0.009345    0.617726    
#> 293: 0.176803    0.988115    3.448206    0.184628    0.051608    0.009323    0.617656    
#> 294: 0.176715    0.988199    3.448189    0.184806    0.051751    0.009301    0.617589    
#> 295: 0.176760    0.987971    3.448180    0.185071    0.051689    0.009313    0.617375    
#> 296: 0.176857    0.987815    3.448204    0.185072    0.051590    0.009352    0.617323    
#> 297: 0.176990    0.987915    3.448116    0.185301    0.051514    0.009396    0.617157    
#> 298: 0.177067    0.987846    3.448136    0.185331    0.051436    0.009429    0.617039    
#> 299: 0.177097    0.987882    3.448120    0.185284    0.051452    0.009429    0.616961    
#> 300: 0.177088    0.987732    3.448154    0.185191    0.051449    0.009420    0.616810    
#> 301: 0.177250    0.987508    3.448165    0.185167    0.051402    0.009414    0.616898    
#> 302: 0.177645    0.987527    3.448258    0.184911    0.051395    0.009409    0.616756    
#> 303: 0.177952    0.987697    3.448369    0.184654    0.051362    0.009435    0.616563    
#> 304: 0.178085    0.987875    3.448333    0.184629    0.051344    0.009454    0.616461    
#> 305: 0.177747    0.987813    3.448249    0.184341    0.051313    0.009487    0.616376    
#> 306: 0.177446    0.987881    3.448091    0.184179    0.051375    0.009503    0.616411    
#> 307: 0.177119    0.987975    3.447890    0.184205    0.051433    0.009476    0.616542    
#> 308: 0.176625    0.987904    3.447738    0.183971    0.051487    0.009453    0.616718    
#> 309: 0.176552    0.987713    3.447657    0.183804    0.051485    0.009425    0.616812    
#> 310: 0.176510    0.987614    3.447586    0.183758    0.051536    0.009412    0.616931    
#> 311: 0.176508    0.987692    3.447564    0.183628    0.051485    0.009416    0.617056    
#> 312: 0.176130    0.987800    3.447383    0.183467    0.051516    0.009408    0.617026    
#> 313: 0.175676    0.987857    3.447162    0.183548    0.051647    0.009408    0.617068    
#> 314: 0.174966    0.988002    3.446919    0.183677    0.051730    0.009399    0.617041    
#> 315: 0.174582    0.988319    3.446783    0.183677    0.051735    0.009403    0.617014    
#> 316: 0.174397    0.988422    3.446655    0.183586    0.051706    0.009397    0.617023    
#> 317: 0.174225    0.988489    3.446558    0.183737    0.051753    0.009385    0.616996    
#> 318: 0.174197    0.988624    3.446371    0.183653    0.051827    0.009387    0.616907    
#> 319: 0.174096    0.988586    3.446367    0.183507    0.051870    0.009369    0.616967    
#> 320: 0.173760    0.988585    3.446257    0.183355    0.051851    0.009357    0.617186    
#> 321: 0.173484    0.988698    3.446110    0.183493    0.051873    0.009358    0.617235    
#> 322: 0.173175    0.988904    3.445914    0.183615    0.051899    0.009344    0.617143    
#> 323: 0.172413    0.989080    3.445759    0.183793    0.051899    0.009343    0.617044    
#> 324: 0.172287    0.989269    3.445742    0.183963    0.051867    0.009339    0.616870    
#> 325: 0.172197    0.989459    3.445640    0.184005    0.051835    0.009348    0.616729    
#> 326: 0.172106    0.989425    3.445587    0.184121    0.051870    0.009349    0.616669    
#> 327: 0.172193    0.989398    3.445626    0.184173    0.051849    0.009344    0.616709    
#> 328: 0.172188    0.989445    3.445570    0.184096    0.051779    0.009337    0.616652    
#> 329: 0.172343    0.989466    3.445590    0.183890    0.051755    0.009342    0.616685    
#> 330: 0.172076    0.989451    3.445533    0.183802    0.051704    0.009353    0.616669    
#> 331: 0.172056    0.989551    3.445559    0.183665    0.051657    0.009359    0.616686    
#> 332: 0.172156    0.989514    3.445734    0.183372    0.051574    0.009379    0.616709    
#> 333: 0.172264    0.989509    3.445775    0.183287    0.051596    0.009385    0.616650    
#> 334: 0.172315    0.989365    3.445794    0.183422    0.051573    0.009376    0.616637    
#> 335: 0.172140    0.989306    3.445720    0.183578    0.051628    0.009366    0.616570    
#> 336: 0.171639    0.989419    3.445600    0.183685    0.051640    0.009366    0.616547    
#> 337: 0.171457    0.989637    3.445499    0.183793    0.051641    0.009357    0.616539    
#> 338: 0.171363    0.989680    3.445497    0.183912    0.051660    0.009348    0.616600    
#> 339: 0.171097    0.989777    3.445446    0.183882    0.051629    0.009341    0.616555    
#> 340: 0.171067    0.989664    3.445470    0.183904    0.051543    0.009348    0.616499    
#> 341: 0.171241    0.989717    3.445509    0.183991    0.051464    0.009350    0.616418    
#> 342: 0.171125    0.989688    3.445474    0.184162    0.051494    0.009354    0.616282    
#> 343: 0.170868    0.989824    3.445421    0.184024    0.051530    0.009353    0.616303    
#> 344: 0.170826    0.989816    3.445403    0.184036    0.051522    0.009371    0.616297    
#> 345: 0.170729    0.989818    3.445385    0.183840    0.051469    0.009395    0.616310    
#> 346: 0.170705    0.989930    3.445287    0.183810    0.051397    0.009404    0.616234    
#> 347: 0.170642    0.989985    3.445150    0.184036    0.051357    0.009422    0.616112    
#> 348: 0.170480    0.990159    3.445080    0.184025    0.051333    0.009438    0.616121    
#> 349: 0.170417    0.990061    3.445079    0.184043    0.051310    0.009445    0.616080    
#> 350: 0.170251    0.989906    3.445053    0.183882    0.051305    0.009436    0.616170    
#> 351: 0.170345    0.990034    3.445027    0.183965    0.051317    0.009434    0.616147    
#> 352: 0.170087    0.990149    3.444971    0.184176    0.051347    0.009441    0.616113    
#> 353: 0.169947    0.990314    3.444846    0.184476    0.051338    0.009462    0.616025    
#> 354: 0.169859    0.990454    3.444678    0.184796    0.051334    0.009486    0.615897    
#> 355: 0.169904    0.990450    3.444607    0.184927    0.051288    0.009510    0.615829    
#> 356: 0.169790    0.990465    3.444544    0.184891    0.051239    0.009535    0.615885    
#> 357: 0.169839    0.990546    3.444517    0.184832    0.051231    0.009541    0.615829    
#> 358: 0.169798    0.990723    3.444538    0.184718    0.051244    0.009542    0.615727    
#> 359: 0.169642    0.990821    3.444484    0.184539    0.051225    0.009539    0.615670    
#> 360: 0.169453    0.990940    3.444361    0.184386    0.051212    0.009523    0.615603    
#> 361: 0.169249    0.991034    3.444267    0.184058    0.051164    0.009522    0.615574    
#> 362: 0.169262    0.991069    3.444226    0.183899    0.051155    0.009515    0.615433    
#> 363: 0.169258    0.991141    3.444198    0.184017    0.051181    0.009509    0.615294    
#> 364: 0.169351    0.991221    3.444228    0.184270    0.051221    0.009506    0.615297    
#> 365: 0.169230    0.991182    3.444258    0.184467    0.051295    0.009502    0.615350    
#> 366: 0.169110    0.991198    3.444155    0.184370    0.051366    0.009492    0.615398    
#> 367: 0.169045    0.991263    3.444098    0.184258    0.051430    0.009481    0.615403    
#> 368: 0.169145    0.991414    3.444029    0.184457    0.051453    0.009474    0.615249    
#> 369: 0.169091    0.991461    3.443960    0.184932    0.051476    0.009483    0.615140    
#> 370: 0.168900    0.991566    3.443884    0.185313    0.051512    0.009502    0.615052    
#> 371: 0.168636    0.991686    3.443725    0.185494    0.051500    0.009517    0.615009    
#> 372: 0.168354    0.991834    3.443563    0.185762    0.051482    0.009519    0.614986    
#> 373: 0.168229    0.991990    3.443430    0.186071    0.051508    0.009523    0.614969    
#> 374: 0.168084    0.992107    3.443334    0.186234    0.051547    0.009517    0.614964    
#> 375: 0.168079    0.992124    3.443316    0.186267    0.051638    0.009507    0.614927    
#> 376: 0.168073    0.992141    3.443342    0.186275    0.051719    0.009507    0.614906    
#> 377: 0.168023    0.992166    3.443363    0.186266    0.051695    0.009499    0.614869    
#> 378: 0.167968    0.992113    3.443335    0.186103    0.051694    0.009493    0.614988    
#> 379: 0.168019    0.991992    3.443411    0.186136    0.051711    0.009494    0.614942    
#> 380: 0.167989    0.991893    3.443429    0.186138    0.051727    0.009487    0.614903    
#> 381: 0.167876    0.991903    3.443408    0.186228    0.051734    0.009492    0.614820    
#> 382: 0.167788    0.991989    3.443359    0.186248    0.051696    0.009493    0.614687    
#> 383: 0.167784    0.992034    3.443295    0.186310    0.051690    0.009486    0.614663    
#> 384: 0.167741    0.992155    3.443282    0.186317    0.051649    0.009475    0.614700    
#> 385: 0.167823    0.992191    3.443290    0.186415    0.051601    0.009486    0.614683    
#> 386: 0.168058    0.992308    3.443354    0.186398    0.051632    0.009490    0.614648    
#> 387: 0.168244    0.992435    3.443426    0.186447    0.051639    0.009504    0.614624    
#> 388: 0.168344    0.992561    3.443476    0.186460    0.051611    0.009522    0.614618    
#> 389: 0.168337    0.992426    3.443483    0.186501    0.051581    0.009535    0.614690    
#> 390: 0.168344    0.992370    3.443510    0.186489    0.051517    0.009550    0.614685    
#> 391: 0.168447    0.992299    3.443520    0.186464    0.051481    0.009547    0.614686    
#> 392: 0.168510    0.992298    3.443571    0.186495    0.051463    0.009542    0.614740    
#> 393: 0.168535    0.992236    3.443543    0.186469    0.051449    0.009541    0.614729    
#> 394: 0.168503    0.992192    3.443523    0.186395    0.051465    0.009534    0.614704    
#> 395: 0.168693    0.992199    3.443558    0.186248    0.051481    0.009536    0.614734    
#> 396: 0.168844    0.992201    3.443606    0.186137    0.051490    0.009534    0.614693    
#> 397: 0.168855    0.992083    3.443637    0.186162    0.051533    0.009538    0.614624    
#> 398: 0.168983    0.991964    3.443703    0.186267    0.051559    0.009544    0.614624    
#> 399: 0.169238    0.991905    3.443803    0.186252    0.051613    0.009538    0.614671    
#> 400: 0.169387    0.991930    3.443866    0.186312    0.051613    0.009538    0.614672    
#> 401: 0.169448    0.991959    3.443867    0.186405    0.051676    0.009538    0.614643    
#> 402: 0.169380    0.992074    3.443836    0.186560    0.051668    0.009544    0.614542    
#> 403: 0.169423    0.992125    3.443782    0.186500    0.051626    0.009548    0.614520    
#> 404: 0.169374    0.992218    3.443686    0.186451    0.051601    0.009546    0.614443    
#> 405: 0.169278    0.992319    3.443618    0.186325    0.051599    0.009535    0.614436    
#> 406: 0.169188    0.992417    3.443570    0.186249    0.051591    0.009533    0.614428    
#> 407: 0.169074    0.992501    3.443551    0.186272    0.051628    0.009525    0.614388    
#> 408: 0.169106    0.992652    3.443521    0.186171    0.051662    0.009515    0.614416    
#> 409: 0.169101    0.992679    3.443477    0.186130    0.051668    0.009506    0.614380    
#> 410: 0.169041    0.992757    3.443379    0.186129    0.051712    0.009505    0.614389    
#> 411: 0.168966    0.992653    3.443299    0.186242    0.051737    0.009503    0.614402    
#> 412: 0.168900    0.992739    3.443243    0.186262    0.051741    0.009500    0.614451    
#> 413: 0.168805    0.992759    3.443196    0.186215    0.051741    0.009500    0.614473    
#> 414: 0.168594    0.992704    3.443191    0.186251    0.051713    0.009496    0.614400    
#> 415: 0.168611    0.992751    3.443153    0.186298    0.051703    0.009495    0.614302    
#> 416: 0.168574    0.992844    3.443127    0.186364    0.051692    0.009494    0.614220    
#> 417: 0.168541    0.992899    3.443074    0.186407    0.051677    0.009482    0.614148    
#> 418: 0.168475    0.993012    3.443013    0.186343    0.051693    0.009462    0.614109    
#> 419: 0.168485    0.993164    3.443005    0.186201    0.051675    0.009455    0.614117    
#> 420: 0.168460    0.993256    3.442985    0.186060    0.051632    0.009447    0.614128    
#> 421: 0.168438    0.993239    3.443007    0.185922    0.051622    0.009440    0.614117    
#> 422: 0.168482    0.993179    3.443011    0.185971    0.051618    0.009437    0.614137    
#> 423: 0.168629    0.993140    3.443049    0.185911    0.051595    0.009436    0.614188    
#> 424: 0.168613    0.993118    3.443024    0.185774    0.051624    0.009425    0.614193    
#> 425: 0.168688    0.993138    3.443003    0.185838    0.051689    0.009411    0.614202    
#> 426: 0.168740    0.993248    3.442989    0.185823    0.051725    0.009405    0.614202    
#> 427: 0.168631    0.993231    3.443010    0.185714    0.051731    0.009411    0.614146    
#> 428: 0.168591    0.993280    3.443021    0.185717    0.051690    0.009420    0.614042    
#> 429: 0.168555    0.993313    3.443024    0.185780    0.051665    0.009430    0.613990    
#> 430: 0.168461    0.993422    3.443013    0.185768    0.051666    0.009445    0.613939    
#> 431: 0.168324    0.993438    3.442957    0.185800    0.051713    0.009448    0.613886    
#> 432: 0.168276    0.993455    3.442992    0.185907    0.051740    0.009458    0.613849    
#> 433: 0.168344    0.993467    3.443025    0.186012    0.051754    0.009463    0.613816    
#> 434: 0.168273    0.993374    3.443036    0.186136    0.051751    0.009476    0.613743    
#> 435: 0.168339    0.993372    3.443028    0.186244    0.051772    0.009474    0.613682    
#> 436: 0.168337    0.993295    3.443065    0.186225    0.051767    0.009471    0.613645    
#> 437: 0.168196    0.993307    3.443012    0.186196    0.051761    0.009472    0.613644    
#> 438: 0.168127    0.993402    3.442971    0.186047    0.051748    0.009463    0.613621    
#> 439: 0.168134    0.993494    3.442953    0.186112    0.051759    0.009454    0.613556    
#> 440: 0.168118    0.993495    3.442966    0.186058    0.051787    0.009447    0.613542    
#> 441: 0.168150    0.993452    3.442975    0.185942    0.051829    0.009431    0.613547    
#> 442: 0.168074    0.993461    3.442986    0.185880    0.051855    0.009417    0.613501    
#> 443: 0.168051    0.993509    3.442940    0.185873    0.051911    0.009406    0.613472    
#> 444: 0.167878    0.993627    3.442849    0.185837    0.051990    0.009394    0.613424    
#> 445: 0.167679    0.993724    3.442786    0.185901    0.052010    0.009389    0.613477    
#> 446: 0.167475    0.993870    3.442688    0.185844    0.052051    0.009383    0.613448    
#> 447: 0.167448    0.993938    3.442621    0.185824    0.052086    0.009381    0.613428    
#> 448: 0.167413    0.993977    3.442607    0.185772    0.052132    0.009368    0.613379    
#> 449: 0.167461    0.993996    3.442672    0.185713    0.052186    0.009363    0.613363    
#> 450: 0.167440    0.993950    3.442666    0.185627    0.052220    0.009364    0.613323    
#> 451: 0.167523    0.993987    3.442655    0.185612    0.052276    0.009368    0.613280    
#> 452: 0.167544    0.993983    3.442619    0.185620    0.052307    0.009358    0.613259    
#> 453: 0.167549    0.994003    3.442609    0.185553    0.052308    0.009344    0.613278    
#> 454: 0.167600    0.994077    3.442616    0.185516    0.052357    0.009337    0.613220    
#> 455: 0.167598    0.994078    3.442585    0.185572    0.052349    0.009335    0.613254    
#> 456: 0.167492    0.994088    3.442536    0.185576    0.052389    0.009338    0.613233    
#> 457: 0.167380    0.994105    3.442547    0.185533    0.052397    0.009345    0.613178    
#> 458: 0.167277    0.994237    3.442539    0.185550    0.052426    0.009346    0.613191    
#> 459: 0.167113    0.994388    3.442501    0.185552    0.052404    0.009352    0.613253    
#> 460: 0.166956    0.994497    3.442425    0.185603    0.052417    0.009356    0.613244    
#> 461: 0.166873    0.994541    3.442388    0.185732    0.052415    0.009366    0.613205    
#> 462: 0.166712    0.994580    3.442374    0.185687    0.052422    0.009365    0.613159    
#> 463: 0.166688    0.994652    3.442381    0.185606    0.052428    0.009363    0.613118    
#> 464: 0.166673    0.994724    3.442360    0.185511    0.052437    0.009357    0.613059    
#> 465: 0.166686    0.994616    3.442356    0.185429    0.052452    0.009345    0.613075    
#> 466: 0.166691    0.994658    3.442326    0.185367    0.052443    0.009333    0.613065    
#> 467: 0.166565    0.994641    3.442331    0.185306    0.052480    0.009323    0.613031    
#> 468: 0.166677    0.994628    3.442364    0.185357    0.052486    0.009315    0.613056    
#> 469: 0.166722    0.994653    3.442380    0.185449    0.052513    0.009310    0.613074    
#> 470: 0.166685    0.994669    3.442371    0.185562    0.052564    0.009306    0.613047    
#> 471: 0.166649    0.994630    3.442363    0.185650    0.052574    0.009297    0.613112    
#> 472: 0.166602    0.994649    3.442370    0.185627    0.052637    0.009293    0.613130    
#> 473: 0.166502    0.994675    3.442353    0.185580    0.052636    0.009285    0.613119    
#> 474: 0.166477    0.994633    3.442347    0.185620    0.052621    0.009279    0.613137    
#> 475: 0.166551    0.994729    3.442357    0.185591    0.052609    0.009274    0.613151    
#> 476: 0.166618    0.994733    3.442334    0.185687    0.052631    0.009272    0.613159    
#> 477: 0.166552    0.994735    3.442330    0.185664    0.052642    0.009263    0.613088    
#> 478: 0.166443    0.994741    3.442312    0.185676    0.052656    0.009257    0.613063    
#> 479: 0.166440    0.994782    3.442309    0.185752    0.052699    0.009249    0.613028    
#> 480: 0.166511    0.994811    3.442300    0.185784    0.052731    0.009245    0.613047    
#> 481: 0.166441    0.994920    3.442237    0.185728    0.052740    0.009243    0.613083    
#> 482: 0.166426    0.995018    3.442178    0.185821    0.052745    0.009242    0.613098    
#> 483: 0.166315    0.995056    3.442116    0.185997    0.052745    0.009234    0.613142    
#> 484: 0.166284    0.995004    3.442110    0.186151    0.052694    0.009235    0.613236    
#> 485: 0.166286    0.995010    3.442121    0.186337    0.052684    0.009239    0.613283    
#> 486: 0.166230    0.995043    3.442120    0.186400    0.052689    0.009234    0.613299    
#> 487: 0.166280    0.995044    3.442151    0.186503    0.052694    0.009228    0.613263    
#> 488: 0.166241    0.995003    3.442166    0.186625    0.052711    0.009224    0.613215    
#> 489: 0.166285    0.994954    3.442169    0.186642    0.052695    0.009236    0.613217    
#> 490: 0.166382    0.994977    3.442192    0.186730    0.052682    0.009237    0.613170    
#> 491: 0.166387    0.995031    3.442216    0.186731    0.052723    0.009234    0.613116    
#> 492: 0.166332    0.995096    3.442200    0.186727    0.052779    0.009223    0.613166    
#> 493: 0.166290    0.995109    3.442214    0.186756    0.052826    0.009225    0.613148    
#> 494: 0.166356    0.995158    3.442205    0.186789    0.052878    0.009225    0.613107    
#> 495: 0.166473    0.995152    3.442229    0.186903    0.052897    0.009226    0.613077    
#> 496: 0.166507    0.995222    3.442180    0.186969    0.052907    0.009231    0.613006    
#> 497: 0.166341    0.995234    3.442131    0.186989    0.052891    0.009232    0.613023    
#> 498: 0.166148    0.995336    3.442013    0.186977    0.052896    0.009234    0.612958    
#> 499: 0.166000    0.995462    3.441907    0.187074    0.052878    0.009239    0.612865    
#> 500: 0.165855    0.995501    3.441811    0.187083    0.052874    0.009245    0.612819    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.248681    0.974779    3.446015    0.392401    0.083209    0.016800    1.786829    
#> 002: 0.276276    0.998768    3.465695    0.372781    0.079048    0.015960    1.163241    
#> 003: 0.372313    0.913895    3.478839    0.354142    0.086429    0.015162    0.854945    
#> 004: 0.357069    0.912228    3.481993    0.336435    0.093673    0.014404    0.743026    
#> 005: 0.399294    0.927635    3.475540    0.319613    0.103272    0.013684    0.701522    
#> 006: 0.353587    0.940632    3.463100    0.303633    0.116315    0.013000    0.626828    
#> 007: 0.336643    0.961403    3.459682    0.288451    0.127752    0.013267    0.619027    
#> 008: 0.346307    0.954067    3.458921    0.274029    0.130931    0.014295    0.622192    
#> 009: 0.275546    0.944084    3.446835    0.260327    0.124385    0.014514    0.634844    
#> 010: 0.305375    0.929233    3.451201    0.247311    0.118165    0.013788    0.639959    
#> 011: 0.350570    0.940410    3.458267    0.235720    0.112257    0.014855    0.631613    
#> 012: 0.354740    0.944479    3.453345    0.247943    0.106644    0.014986    0.608259    
#> 013: 0.333440    0.952771    3.452897    0.236906    0.109650    0.015896    0.614651    
#> 014: 0.332735    0.930150    3.454003    0.225060    0.104167    0.018187    0.632391    
#> 015: 0.366540    0.920985    3.476858    0.240162    0.102507    0.017277    0.607726    
#> 016: 0.372210    0.937550    3.472339    0.246050    0.113928    0.016414    0.614175    
#> 017: 0.357419    0.936053    3.469717    0.233748    0.108232    0.017182    0.592579    
#> 018: 0.378565    0.936444    3.465436    0.222060    0.106798    0.016323    0.613228    
#> 019: 0.332544    0.941016    3.461427    0.233021    0.109294    0.016056    0.598938    
#> 020: 0.371713    0.953052    3.468666    0.227700    0.107335    0.018609    0.604834    
#> 021: 0.408294    0.951115    3.475794    0.253030    0.116641    0.017840    0.597547    
#> 022: 0.386051    0.952135    3.476859    0.260510    0.110809    0.017452    0.596803    
#> 023: 0.441535    0.929612    3.490675    0.251520    0.105269    0.021703    0.614204    
#> 024: 0.452783    0.938516    3.492699    0.254141    0.103093    0.021176    0.611052    
#> 025: 0.438241    0.900644    3.489599    0.241434    0.097939    0.023970    0.618367    
#> 026: 0.412856    0.922044    3.480738    0.229362    0.097043    0.022771    0.612731    
#> 027: 0.387581    0.948900    3.474308    0.226365    0.093642    0.021633    0.624123    
#> 028: 0.416451    0.937007    3.485841    0.233594    0.107777    0.020551    0.613595    
#> 029: 0.376773    0.950841    3.470500    0.221914    0.109384    0.019523    0.627848    
#> 030: 0.375172    0.946238    3.461127    0.230470    0.109572    0.018547    0.620655    
#> 031: 0.357056    0.925505    3.471935    0.232281    0.113345    0.018196    0.614558    
#> 032: 0.369437    0.914788    3.483497    0.238502    0.108907    0.017286    0.618803    
#> 033: 0.367289    0.919584    3.479768    0.226577    0.103461    0.016422    0.630126    
#> 034: 0.382447    0.944878    3.475393    0.215248    0.098288    0.018047    0.621483    
#> 035: 0.356307    0.931861    3.463726    0.204486    0.101236    0.017144    0.611153    
#> 036: 0.369152    0.946709    3.462811    0.197532    0.106576    0.016287    0.633295    
#> 037: 0.363619    0.941400    3.459449    0.219467    0.101248    0.015473    0.621590    
#> 038: 0.347275    0.962308    3.451524    0.218483    0.105471    0.014699    0.626057    
#> 039: 0.368887    0.940156    3.469350    0.207559    0.100198    0.017111    0.620749    
#> 040: 0.385054    0.946991    3.481440    0.197181    0.097594    0.016255    0.643473    
#> 041: 0.375799    0.927587    3.480895    0.201479    0.109819    0.016330    0.640585    
#> 042: 0.383925    0.907202    3.483383    0.205726    0.104328    0.017256    0.625501    
#> 043: 0.345091    0.944538    3.461241    0.195605    0.099112    0.016932    0.626069    
#> 044: 0.336890    0.955086    3.459606    0.204552    0.102876    0.017378    0.613767    
#> 045: 0.328170    0.963632    3.442582    0.216767    0.115869    0.016509    0.619461    
#> 046: 0.349547    0.956169    3.443279    0.243027    0.110076    0.015684    0.619220    
#> 047: 0.365502    0.962766    3.458306    0.242350    0.108784    0.015872    0.594163    
#> 048: 0.359258    0.948659    3.459800    0.244692    0.113206    0.018915    0.597835    
#> 049: 0.345333    0.953348    3.467371    0.238082    0.107546    0.017969    0.609692    
#> 050: 0.391771    0.934556    3.480741    0.241283    0.114061    0.019958    0.628031    
#> 051: 0.394990    0.937267    3.475024    0.229219    0.108358    0.021534    0.635312    
#> 052: 0.402022    0.939569    3.489282    0.217758    0.102940    0.020458    0.607983    
#> 053: 0.368524    0.925738    3.475180    0.206870    0.106650    0.019435    0.609757    
#> 054: 0.360365    0.935362    3.471736    0.228114    0.118472    0.018853    0.609726    
#> 055: 0.348285    0.928123    3.471572    0.229880    0.123493    0.017910    0.608525    
#> 056: 0.386216    0.909044    3.480669    0.222153    0.120914    0.017155    0.624408    
#> 057: 0.357104    0.921047    3.474937    0.211046    0.120204    0.016297    0.621698    
#> 058: 0.367110    0.914973    3.461217    0.242911    0.114194    0.015482    0.619974    
#> 059: 0.362951    0.903834    3.468215    0.249559    0.114619    0.019038    0.628895    
#> 060: 0.358556    0.926494    3.475615    0.250379    0.108888    0.022365    0.625341    
#> 061: 0.373039    0.941686    3.480180    0.237860    0.103444    0.022125    0.641806    
#> 062: 0.366940    0.956153    3.468636    0.225967    0.136219    0.023225    0.652302    
#> 063: 0.370468    0.932126    3.461291    0.234489    0.129408    0.022063    0.648548    
#> 064: 0.371364    0.925512    3.470415    0.225194    0.122938    0.022845    0.629366    
#> 065: 0.377011    0.934155    3.465902    0.220351    0.116791    0.021703    0.614686    
#> 066: 0.376197    0.957521    3.471679    0.209354    0.110951    0.020618    0.611509    
#> 067: 0.366825    0.919971    3.477070    0.198887    0.105404    0.021324    0.611393    
#> 068: 0.353045    0.922832    3.476237    0.188942    0.100774    0.020258    0.619477    
#> 069: 0.341240    0.928547    3.468971    0.193244    0.098096    0.019245    0.624665    
#> 070: 0.378907    0.934605    3.471339    0.234592    0.112130    0.018283    0.616776    
#> 071: 0.329357    0.955315    3.449209    0.224820    0.122686    0.017368    0.623259    
#> 072: 0.288047    0.940314    3.449572    0.248443    0.117228    0.016500    0.619954    
#> 073: 0.334514    0.959959    3.454720    0.239088    0.111367    0.015675    0.631656    
#> 074: 0.303841    0.939859    3.449315    0.227134    0.105799    0.014891    0.627791    
#> 075: 0.358707    0.922984    3.475294    0.222851    0.103802    0.014597    0.618431    
#> 076: 0.369740    0.938284    3.481103    0.226120    0.120136    0.015316    0.611179    
#> 077: 0.402967    0.903127    3.484120    0.273974    0.114129    0.017900    0.615315    
#> 078: 0.399514    0.923883    3.485667    0.260275    0.112939    0.017005    0.612333    
#> 079: 0.404494    0.930476    3.472319    0.257336    0.107292    0.017718    0.637826    
#> 080: 0.394138    0.943934    3.468884    0.250259    0.109650    0.016832    0.640556    
#> 081: 0.346347    0.946196    3.459087    0.250594    0.109455    0.015991    0.634071    
#> 082: 0.340236    0.928220    3.463920    0.276712    0.119373    0.015191    0.634191    
#> 083: 0.349712    0.966204    3.454997    0.266079    0.126604    0.014432    0.624153    
#> 084: 0.332945    0.969138    3.453441    0.252776    0.120273    0.013710    0.618361    
#> 085: 0.305961    0.959758    3.458344    0.240137    0.124217    0.013801    0.632342    
#> 086: 0.342728    0.968477    3.458764    0.228130    0.123935    0.013881    0.599397    
#> 087: 0.344451    0.953504    3.455830    0.225467    0.117739    0.014969    0.618873    
#> 088: 0.277863    0.953926    3.451091    0.225526    0.111852    0.015085    0.630644    
#> 089: 0.331729    0.945226    3.452086    0.214250    0.107742    0.016486    0.619249    
#> 090: 0.303012    0.947420    3.446215    0.225782    0.106728    0.016704    0.616122    
#> 091: 0.277104    0.932331    3.438218    0.214492    0.101391    0.017145    0.636518    
#> 092: 0.295437    0.963714    3.439041    0.216277    0.103216    0.016444    0.635696    
#> 093: 0.308302    0.961735    3.441468    0.223398    0.106422    0.015621    0.632958    
#> 094: 0.310450    0.976246    3.444230    0.224091    0.103368    0.015274    0.638355    
#> 095: 0.332680    0.968719    3.456040    0.226665    0.128966    0.014510    0.636599    
#> 096: 0.305531    0.950217    3.453915    0.215332    0.122517    0.013785    0.633554    
#> 097: 0.343295    0.971405    3.448841    0.218779    0.116391    0.015684    0.614977    
#> 098: 0.334343    0.980694    3.452563    0.209949    0.124154    0.014900    0.628769    
#> 099: 0.302187    0.938864    3.448602    0.208129    0.118790    0.014173    0.615625    
#> 100: 0.311416    0.953730    3.446342    0.209587    0.127732    0.014406    0.597081    
#> 101: 0.299916    0.944517    3.435352    0.220013    0.121346    0.014951    0.602791    
#> 102: 0.314417    0.960695    3.440283    0.247650    0.117613    0.016245    0.613009    
#> 103: 0.323587    0.951705    3.452839    0.240973    0.111733    0.015541    0.612995    
#> 104: 0.312062    0.948903    3.457758    0.242726    0.106146    0.015771    0.620762    
#> 105: 0.326746    0.921899    3.464662    0.230590    0.120978    0.014982    0.609827    
#> 106: 0.341025    0.934707    3.458983    0.245191    0.119990    0.016521    0.595682    
#> 107: 0.359669    0.932182    3.465021    0.256914    0.113991    0.016268    0.615442    
#> 108: 0.359465    0.932348    3.471432    0.244068    0.110209    0.015951    0.618957    
#> 109: 0.333235    0.943824    3.466644    0.231865    0.104698    0.015845    0.624949    
#> 110: 0.345134    0.933268    3.457739    0.235982    0.099762    0.017191    0.604037    
#> 111: 0.358588    0.937096    3.460792    0.244020    0.108238    0.019186    0.607694    
#> 112: 0.343704    0.945595    3.451922    0.240648    0.112705    0.019450    0.606703    
#> 113: 0.337834    0.974283    3.459786    0.237487    0.107070    0.018478    0.602043    
#> 114: 0.355930    0.956302    3.460272    0.231561    0.115164    0.020013    0.607559    
#> 115: 0.371275    0.919325    3.462116    0.219983    0.109406    0.019012    0.652511    
#> 116: 0.365212    0.941112    3.461739    0.229521    0.103936    0.019347    0.631013    
#> 117: 0.352603    0.951013    3.467359    0.248498    0.117190    0.021355    0.630210    
#> 118: 0.351947    0.941607    3.466152    0.236073    0.111330    0.021516    0.630420    
#> 119: 0.355114    0.929513    3.470416    0.224269    0.108118    0.020440    0.633611    
#> 120: 0.363183    0.927773    3.470048    0.231591    0.102712    0.019479    0.619948    
#> 121: 0.373083    0.938174    3.467474    0.236756    0.103715    0.018505    0.616427    
#> 122: 0.374307    0.916471    3.479592    0.224918    0.109839    0.018033    0.611329    
#> 123: 0.399451    0.965062    3.473866    0.213941    0.112913    0.019778    0.622556    
#> 124: 0.393368    0.972191    3.466381    0.209418    0.120443    0.018789    0.633536    
#> 125: 0.373741    0.959714    3.466265    0.198947    0.114420    0.018085    0.638970    
#> 126: 0.323361    0.964237    3.445776    0.189781    0.108699    0.019966    0.621932    
#> 127: 0.342732    0.939783    3.453865    0.199883    0.103264    0.021982    0.626138    
#> 128: 0.349718    0.956396    3.468550    0.210112    0.107447    0.020883    0.622531    
#> 129: 0.373368    0.935530    3.474139    0.217898    0.102075    0.022073    0.623672    
#> 130: 0.412929    0.937327    3.476598    0.207003    0.108665    0.020969    0.601512    
#> 131: 0.377605    0.943067    3.472056    0.196653    0.118983    0.019921    0.622352    
#> 132: 0.352163    0.948577    3.449092    0.203263    0.113495    0.018925    0.642320    
#> 133: 0.337686    0.931656    3.456465    0.193100    0.107821    0.017978    0.656039    
#> 134: 0.370471    0.923438    3.475418    0.219304    0.114289    0.017079    0.618040    
#> 135: 0.363350    0.932836    3.475335    0.221337    0.108574    0.017131    0.609731    
#> 136: 0.372731    0.920814    3.475903    0.240105    0.119219    0.016371    0.594785    
#> 137: 0.383737    0.922359    3.475672    0.272300    0.113258    0.020491    0.600224    
#> 138: 0.368843    0.942583    3.474238    0.272640    0.108046    0.020976    0.593693    
#> 139: 0.367809    0.950610    3.476993    0.260482    0.103969    0.024800    0.614424    
#> 140: 0.391313    0.938137    3.477125    0.249109    0.105578    0.023560    0.619039    
#> 141: 0.377910    0.914009    3.481322    0.254037    0.100299    0.022487    0.623298    
#> 142: 0.387254    0.909962    3.488711    0.260646    0.098291    0.025800    0.623826    
#> 143: 0.338589    0.932692    3.476264    0.247614    0.093376    0.032555    0.629382    
#> 144: 0.388693    0.944403    3.479739    0.246101    0.088708    0.030927    0.618678    
#> 145: 0.376413    0.956701    3.460432    0.283551    0.090921    0.029381    0.598262    
#> 146: 0.371460    0.943377    3.475838    0.278361    0.086375    0.027912    0.616363    
#> 147: 0.333524    0.938132    3.466601    0.264443    0.092698    0.026516    0.611410    
#> 148: 0.350950    0.952946    3.477786    0.251221    0.106495    0.025190    0.615948    
#> 149: 0.332909    0.929361    3.464479    0.238660    0.101171    0.023931    0.623085    
#> 150: 0.341571    0.929920    3.454803    0.229592    0.107749    0.022734    0.623133    
#> 151: 0.325577    0.950163    3.457540    0.218113    0.102362    0.021598    0.617811    
#> 152: 0.322380    0.941175    3.467629    0.196083    0.109410    0.019045    0.608221    
#> 153: 0.350396    0.951989    3.479325    0.181650    0.129067    0.017603    0.619177    
#> 154: 0.377708    0.949670    3.464286    0.207426    0.112457    0.018796    0.626338    
#> 155: 0.331268    0.946019    3.462068    0.261952    0.102873    0.021177    0.620930    
#> 156: 0.361138    0.919430    3.474397    0.306246    0.100835    0.023449    0.643714    
#> 157: 0.367223    0.926070    3.479862    0.280979    0.093794    0.026555    0.627253    
#> 158: 0.369295    0.934882    3.470962    0.304114    0.097079    0.027337    0.614770    
#> 159: 0.341966    0.952640    3.468776    0.256653    0.095502    0.027610    0.615826    
#> 160: 0.360191    0.928210    3.469674    0.246628    0.101546    0.027681    0.607782    
#> 161: 0.358659    0.928680    3.469765    0.282101    0.103079    0.029574    0.608267    
#> 162: 0.363681    0.938014    3.464361    0.295682    0.095795    0.034448    0.627760    
#> 163: 0.372955    0.924846    3.460340    0.285725    0.089685    0.027666    0.611950    
#> 164: 0.342760    0.938818    3.457374    0.244504    0.102110    0.029224    0.625587    
#> 165: 0.350849    0.936479    3.458964    0.289269    0.106234    0.026108    0.620320    
#> 166: 0.370850    0.958164    3.462236    0.287152    0.111455    0.021477    0.619595    
#> 167: 0.369969    0.954871    3.472124    0.277203    0.095893    0.022389    0.631027    
#> 168: 0.397472    0.951122    3.472630    0.324405    0.107765    0.018917    0.623349    
#> 169: 0.362243    0.977335    3.467644    0.271461    0.109758    0.017350    0.631970    
#> 170: 0.351589    0.957354    3.459144    0.238077    0.108226    0.017977    0.605646    
#> 171: 0.332740    0.945998    3.455908    0.242041    0.110611    0.016719    0.594960    
#> 172: 0.329791    0.975722    3.454297    0.260641    0.112978    0.015570    0.611461    
#> 173: 0.318994    0.962930    3.444241    0.194687    0.113762    0.018936    0.589378    
#> 174: 0.329380    0.955776    3.461250    0.214849    0.103501    0.019543    0.595271    
#> 175: 0.365494    0.959596    3.462184    0.191159    0.108934    0.018941    0.612569    
#> 176: 0.351924    0.951320    3.474089    0.209916    0.105322    0.017768    0.603623    
#> 177: 0.354186    0.945785    3.466156    0.215974    0.111361    0.021240    0.608704    
#> 178: 0.353532    0.929654    3.465979    0.217580    0.106331    0.020269    0.608774    
#> 179: 0.374388    0.968024    3.465655    0.234460    0.125440    0.017550    0.614895    
#> 180: 0.338701    0.956558    3.468949    0.224767    0.093958    0.019511    0.611866    
#> 181: 0.332751    0.964212    3.451408    0.202687    0.109874    0.020252    0.615898    
#> 182: 0.332088    0.962680    3.442105    0.224581    0.120677    0.020115    0.638865    
#> 183: 0.304631    1.001664    3.439359    0.202895    0.115499    0.020236    0.638845    
#> 184: 0.330378    0.972064    3.442081    0.243368    0.106052    0.020095    0.637014    
#> 185: 0.302973    0.982709    3.437643    0.190916    0.100885    0.017981    0.631799    
#> 186: 0.325687    0.969623    3.445251    0.225958    0.109672    0.015776    0.621918    
#> 187: 0.326834    0.958827    3.457088    0.228806    0.106749    0.015197    0.615930    
#> 188: 0.323882    0.963904    3.450045    0.256398    0.113390    0.013685    0.628355    
#> 189: 0.329168    0.971614    3.461017    0.234443    0.115290    0.014071    0.634236    
#> 190: 0.307786    0.969807    3.455791    0.230973    0.100483    0.017083    0.615934    
#> 191: 0.319154    0.976286    3.452228    0.205474    0.103121    0.014443    0.602965    
#> 192: 0.308923    0.976548    3.453547    0.221942    0.099981    0.016353    0.609220    
#> 193: 0.350310    0.959758    3.458099    0.218207    0.098111    0.017238    0.616648    
#> 194: 0.307551    0.946592    3.447718    0.201606    0.098133    0.017497    0.626778    
#> 195: 0.296865    0.959591    3.446430    0.212750    0.114719    0.015486    0.634940    
#> 196: 0.302436    0.949523    3.455989    0.237232    0.120444    0.015632    0.617605    
#> 197: 0.321997    0.937439    3.468783    0.209337    0.097146    0.019929    0.621429    
#> 198: 0.355904    0.934405    3.458485    0.200383    0.095470    0.020646    0.609886    
#> 199: 0.336946    0.933758    3.459015    0.193350    0.088005    0.016998    0.616484    
#> 200: 0.348431    0.958349    3.457795    0.208717    0.105951    0.018329    0.624401    
#> 201: 0.328356    0.950658    3.463165    0.211007    0.095995    0.019935    0.625424    
#> 202: 0.327904    0.951369    3.462325    0.220485    0.098802    0.020501    0.623043    
#> 203: 0.346112    0.946084    3.463645    0.232088    0.100252    0.021548    0.623454    
#> 204: 0.353469    0.937634    3.466816    0.237801    0.097245    0.022074    0.620064    
#> 205: 0.358126    0.940019    3.469355    0.248302    0.096661    0.023250    0.620231    
#> 206: 0.359485    0.943499    3.469531    0.249658    0.096876    0.023667    0.620760    
#> 207: 0.358555    0.944898    3.468062    0.251427    0.097288    0.023488    0.620885    
#> 208: 0.362008    0.945712    3.467943    0.251241    0.096547    0.023539    0.619271    
#> 209: 0.365700    0.942606    3.467745    0.256637    0.096297    0.024005    0.619191    
#> 210: 0.368967    0.939929    3.468700    0.258291    0.095394    0.024140    0.617846    
#> 211: 0.372876    0.939496    3.469913    0.256546    0.095815    0.024049    0.616094    
#> 212: 0.376250    0.938820    3.471650    0.256041    0.095311    0.024069    0.614877    
#> 213: 0.378802    0.937097    3.473043    0.255056    0.093807    0.023996    0.615229    
#> 214: 0.380451    0.936396    3.473832    0.252658    0.093058    0.023946    0.615659    
#> 215: 0.379211    0.936261    3.474728    0.250459    0.091914    0.024063    0.615754    
#> 216: 0.382387    0.935593    3.475046    0.251512    0.092730    0.024019    0.616239    
#> 217: 0.383415    0.936299    3.475349    0.250458    0.092679    0.023971    0.615644    
#> 218: 0.383031    0.936899    3.475441    0.250130    0.092873    0.024127    0.615051    
#> 219: 0.381858    0.936547    3.474765    0.252699    0.092407    0.024118    0.614927    
#> 220: 0.379656    0.937314    3.474092    0.254374    0.092524    0.024028    0.614568    
#> 221: 0.377998    0.937235    3.473196    0.255671    0.092634    0.024005    0.614439    
#> 222: 0.375916    0.937300    3.472199    0.255966    0.093537    0.023885    0.614509    
#> 223: 0.375158    0.937016    3.471640    0.256734    0.094155    0.023878    0.614382    
#> 224: 0.374603    0.938015    3.471379    0.257023    0.095193    0.023815    0.614494    
#> 225: 0.372720    0.937607    3.471276    0.257414    0.095630    0.023653    0.615078    
#> 226: 0.371585    0.937954    3.470601    0.257860    0.095631    0.023522    0.614513    
#> 227: 0.369954    0.938230    3.470536    0.258563    0.096032    0.023462    0.614125    
#> 228: 0.368475    0.938941    3.469732    0.259131    0.096303    0.023578    0.613861    
#> 229: 0.366734    0.938944    3.468837    0.259884    0.095974    0.023604    0.613692    
#> 230: 0.366316    0.938727    3.468236    0.261229    0.095831    0.023698    0.613865    
#> 231: 0.365366    0.939206    3.468105    0.261409    0.095731    0.023676    0.613653    
#> 232: 0.364825    0.938798    3.468398    0.260693    0.095727    0.023553    0.613229    
#> 233: 0.364374    0.938212    3.468450    0.259794    0.095842    0.023602    0.613576    
#> 234: 0.364013    0.937916    3.468432    0.259669    0.095880    0.023619    0.613264    
#> 235: 0.363749    0.937576    3.468326    0.260250    0.095654    0.023509    0.613087    
#> 236: 0.363540    0.937426    3.468368    0.260221    0.095934    0.023429    0.612871    
#> 237: 0.364003    0.937184    3.468151    0.260795    0.096303    0.023383    0.613141    
#> 238: 0.364300    0.936676    3.468120    0.262736    0.096578    0.023297    0.613584    
#> 239: 0.364178    0.936936    3.468175    0.263021    0.096550    0.023271    0.613543    
#> 240: 0.364569    0.937016    3.468406    0.262686    0.096743    0.023281    0.613451    
#> 241: 0.364807    0.936583    3.468534    0.261273    0.097109    0.023218    0.613195    
#> 242: 0.364582    0.936233    3.468489    0.259733    0.097300    0.023127    0.613405    
#> 243: 0.363980    0.936475    3.468329    0.259012    0.097698    0.023013    0.613886    
#> 244: 0.363165    0.936823    3.468397    0.258439    0.097621    0.022951    0.614313    
#> 245: 0.363117    0.936589    3.468428    0.257955    0.097986    0.022806    0.614640    
#> 246: 0.363217    0.936311    3.468359    0.257704    0.098251    0.022713    0.614726    
#> 247: 0.362971    0.936236    3.468331    0.258214    0.098961    0.022649    0.614770    
#> 248: 0.362873    0.936570    3.468234    0.257703    0.099219    0.022584    0.614769    
#> 249: 0.362887    0.936673    3.468302    0.257924    0.099609    0.022567    0.614886    
#> 250: 0.363300    0.936885    3.468569    0.258011    0.099935    0.022514    0.614985    
#> 251: 0.364394    0.937064    3.469050    0.258016    0.100062    0.022511    0.615068    
#> 252: 0.365008    0.937132    3.469516    0.257695    0.100130    0.022551    0.615077    
#> 253: 0.365131    0.937169    3.469885    0.257629    0.100244    0.022647    0.615153    
#> 254: 0.365037    0.937287    3.469957    0.257190    0.100282    0.022616    0.615084    
#> 255: 0.364677    0.937703    3.469863    0.256406    0.100378    0.022581    0.615102    
#> 256: 0.364658    0.938229    3.469577    0.256019    0.100488    0.022523    0.615145    
#> 257: 0.364144    0.938381    3.469433    0.255464    0.100462    0.022469    0.615147    
#> 258: 0.363510    0.938512    3.469188    0.254758    0.100330    0.022413    0.615340    
#> 259: 0.362794    0.938647    3.469065    0.254751    0.100510    0.022350    0.615673    
#> 260: 0.362814    0.938900    3.468839    0.254718    0.100578    0.022290    0.615745    
#> 261: 0.362595    0.939178    3.468709    0.254556    0.100767    0.022199    0.615892    
#> 262: 0.362220    0.939611    3.468540    0.254098    0.100840    0.022097    0.615704    
#> 263: 0.361497    0.940298    3.468347    0.253333    0.100939    0.022044    0.615648    
#> 264: 0.360676    0.940916    3.468141    0.253031    0.101004    0.022021    0.615826    
#> 265: 0.360298    0.941213    3.468059    0.252082    0.101254    0.021979    0.616137    
#> 266: 0.360093    0.941303    3.468032    0.251551    0.101165    0.021917    0.616134    
#> 267: 0.359868    0.941382    3.468138    0.251103    0.101154    0.021898    0.616236    
#> 268: 0.360250    0.941120    3.468136    0.250460    0.101264    0.021874    0.616210    
#> 269: 0.361007    0.940907    3.468205    0.250048    0.101204    0.021892    0.616174    
#> 270: 0.361251    0.940911    3.468253    0.249923    0.101104    0.021913    0.615965    
#> 271: 0.361313    0.940932    3.468200    0.249464    0.101086    0.021901    0.616082    
#> 272: 0.361517    0.940825    3.468318    0.249301    0.100958    0.021870    0.616289    
#> 273: 0.361202    0.941096    3.468228    0.248929    0.101191    0.021863    0.616465    
#> 274: 0.361152    0.941215    3.468122    0.248989    0.101090    0.021859    0.616312    
#> 275: 0.360943    0.941179    3.468059    0.249200    0.101231    0.021831    0.616235    
#> 276: 0.360667    0.941617    3.468074    0.249077    0.101255    0.021833    0.616304    
#> 277: 0.360340    0.942022    3.468000    0.248627    0.101106    0.021815    0.616363    
#> 278: 0.360240    0.942017    3.468052    0.248410    0.100973    0.021794    0.616184    
#> 279: 0.360129    0.942046    3.468118    0.248455    0.101070    0.021758    0.616134    
#> 280: 0.360021    0.942172    3.468168    0.248315    0.101148    0.021718    0.616023    
#> 281: 0.359782    0.942403    3.468160    0.247908    0.101169    0.021728    0.615973    
#> 282: 0.359865    0.942502    3.468134    0.247911    0.101297    0.021699    0.615847    
#> 283: 0.359809    0.942445    3.468180    0.248629    0.101147    0.021744    0.616118    
#> 284: 0.359752    0.942321    3.468079    0.249087    0.101163    0.021746    0.616018    
#> 285: 0.359843    0.942507    3.467861    0.250405    0.101250    0.021763    0.615977    
#> 286: 0.359585    0.942600    3.467575    0.251321    0.101556    0.021780    0.615863    
#> 287: 0.359209    0.942769    3.467268    0.251894    0.101692    0.021745    0.615820    
#> 288: 0.359182    0.942915    3.467093    0.251995    0.101934    0.021683    0.615792    
#> 289: 0.359082    0.942935    3.466916    0.252084    0.101999    0.021638    0.615858    
#> 290: 0.359030    0.942744    3.466913    0.251782    0.101973    0.021608    0.616086    
#> 291: 0.358994    0.942696    3.466960    0.251471    0.102106    0.021600    0.615920    
#> 292: 0.358722    0.942762    3.466881    0.251015    0.102141    0.021550    0.615763    
#> 293: 0.358280    0.942890    3.466763    0.250541    0.102057    0.021527    0.615793    
#> 294: 0.357894    0.943056    3.466578    0.249998    0.102059    0.021511    0.615804    
#> 295: 0.357264    0.943001    3.466412    0.249966    0.102032    0.021505    0.615754    
#> 296: 0.356913    0.943019    3.466268    0.249974    0.101804    0.021514    0.615811    
#> 297: 0.356630    0.943053    3.466132    0.250151    0.101604    0.021553    0.615826    
#> 298: 0.356265    0.942974    3.465891    0.250197    0.101500    0.021554    0.615826    
#> 299: 0.355794    0.943137    3.465661    0.250075    0.101573    0.021491    0.615753    
#> 300: 0.355592    0.943076    3.465564    0.250180    0.101711    0.021444    0.615710    
#> 301: 0.355467    0.943210    3.465346    0.249747    0.101850    0.021396    0.615762    
#> 302: 0.355371    0.943324    3.465256    0.249686    0.101913    0.021352    0.615718    
#> 303: 0.355270    0.943320    3.465238    0.249906    0.101937    0.021329    0.615530    
#> 304: 0.355266    0.943652    3.465120    0.249817    0.101933    0.021304    0.615512    
#> 305: 0.355009    0.943444    3.465013    0.249964    0.101969    0.021278    0.615335    
#> 306: 0.354601    0.943426    3.464804    0.249964    0.101996    0.021253    0.615286    
#> 307: 0.354535    0.943396    3.464675    0.250185    0.102064    0.021226    0.615318    
#> 308: 0.353904    0.943381    3.464561    0.250061    0.102201    0.021194    0.615397    
#> 309: 0.353748    0.943082    3.464503    0.249936    0.102298    0.021143    0.615634    
#> 310: 0.353843    0.943127    3.464370    0.250159    0.102558    0.021085    0.615604    
#> 311: 0.353787    0.943130    3.464296    0.249897    0.102680    0.021027    0.615547    
#> 312: 0.353760    0.943083    3.464212    0.249779    0.102791    0.020958    0.615463    
#> 313: 0.353732    0.942820    3.464162    0.249699    0.102880    0.020883    0.615586    
#> 314: 0.353397    0.942960    3.464063    0.249736    0.102954    0.020817    0.615724    
#> 315: 0.353025    0.943172    3.463964    0.249506    0.103013    0.020763    0.615770    
#> 316: 0.352933    0.943313    3.463844    0.249271    0.103154    0.020701    0.615883    
#> 317: 0.353071    0.943235    3.463884    0.249027    0.103138    0.020662    0.616136    
#> 318: 0.353280    0.943165    3.463884    0.248925    0.103118    0.020640    0.616177    
#> 319: 0.353400    0.943194    3.463928    0.249098    0.103150    0.020638    0.616309    
#> 320: 0.353458    0.943140    3.463905    0.249447    0.103236    0.020612    0.616497    
#> 321: 0.353488    0.943189    3.463848    0.249804    0.103242    0.020596    0.616779    
#> 322: 0.353359    0.943219    3.463808    0.249552    0.103366    0.020561    0.616899    
#> 323: 0.353117    0.943223    3.463781    0.249296    0.103480    0.020521    0.616823    
#> 324: 0.352862    0.943240    3.463750    0.249049    0.103653    0.020486    0.616807    
#> 325: 0.352609    0.943433    3.463684    0.248683    0.103779    0.020450    0.616813    
#> 326: 0.352513    0.943295    3.463624    0.248646    0.103953    0.020423    0.616796    
#> 327: 0.352721    0.943302    3.463678    0.248814    0.104049    0.020431    0.616646    
#> 328: 0.352899    0.943359    3.463690    0.248734    0.104082    0.020414    0.616582    
#> 329: 0.352849    0.943461    3.463698    0.248445    0.104269    0.020378    0.616568    
#> 330: 0.352602    0.943517    3.463701    0.247993    0.104432    0.020349    0.616807    
#> 331: 0.352746    0.943534    3.463788    0.247838    0.104453    0.020324    0.616830    
#> 332: 0.352777    0.943593    3.463882    0.247620    0.104362    0.020299    0.616865    
#> 333: 0.352701    0.943527    3.463825    0.247857    0.104380    0.020275    0.616866    
#> 334: 0.352436    0.943312    3.463709    0.248082    0.104257    0.020272    0.616871    
#> 335: 0.352319    0.943415    3.463587    0.248015    0.104264    0.020265    0.616755    
#> 336: 0.351888    0.943707    3.463413    0.248030    0.104359    0.020272    0.616715    
#> 337: 0.351459    0.944069    3.463156    0.248112    0.104436    0.020265    0.616701    
#> 338: 0.351119    0.944294    3.463011    0.248132    0.104408    0.020263    0.616707    
#> 339: 0.350752    0.944429    3.462853    0.248198    0.104365    0.020291    0.616631    
#> 340: 0.350424    0.944403    3.462715    0.248349    0.104385    0.020315    0.616634    
#> 341: 0.350255    0.944483    3.462659    0.248478    0.104311    0.020338    0.616691    
#> 342: 0.350014    0.944384    3.462619    0.248271    0.104266    0.020343    0.616760    
#> 343: 0.349963    0.944478    3.462609    0.247933    0.104326    0.020334    0.616745    
#> 344: 0.349987    0.944377    3.462632    0.247569    0.104310    0.020330    0.616818    
#> 345: 0.349990    0.944291    3.462689    0.247370    0.104295    0.020330    0.616849    
#> 346: 0.349891    0.944165    3.462694    0.247122    0.104253    0.020334    0.616820    
#> 347: 0.349857    0.944005    3.462727    0.247019    0.104299    0.020352    0.616834    
#> 348: 0.349895    0.943995    3.462770    0.246939    0.104330    0.020366    0.616857    
#> 349: 0.349848    0.943810    3.462853    0.246980    0.104310    0.020387    0.616844    
#> 350: 0.349787    0.943669    3.462891    0.246930    0.104288    0.020375    0.616869    
#> 351: 0.349935    0.943857    3.462827    0.247187    0.104281    0.020360    0.616873    
#> 352: 0.349607    0.943901    3.462788    0.247619    0.104344    0.020369    0.617028    
#> 353: 0.349660    0.944041    3.462782    0.247834    0.104379    0.020365    0.617068    
#> 354: 0.349668    0.944191    3.462669    0.248262    0.104365    0.020395    0.617008    
#> 355: 0.349864    0.944121    3.462607    0.248428    0.104275    0.020405    0.617089    
#> 356: 0.349840    0.944088    3.462641    0.248478    0.104313    0.020413    0.617182    
#> 357: 0.349886    0.944164    3.462673    0.248398    0.104308    0.020421    0.617138    
#> 358: 0.349737    0.944239    3.462648    0.248353    0.104298    0.020412    0.617036    
#> 359: 0.349602    0.944329    3.462569    0.248376    0.104336    0.020394    0.617005    
#> 360: 0.349431    0.944375    3.462443    0.248330    0.104363    0.020371    0.616995    
#> 361: 0.349331    0.944398    3.462392    0.248177    0.104275    0.020361    0.617005    
#> 362: 0.349369    0.944324    3.462373    0.248017    0.104236    0.020357    0.616907    
#> 363: 0.349476    0.944138    3.462414    0.247847    0.104129    0.020350    0.616822    
#> 364: 0.349576    0.944021    3.462460    0.247803    0.104095    0.020364    0.616810    
#> 365: 0.349643    0.943806    3.462523    0.247719    0.104025    0.020368    0.616856    
#> 366: 0.349861    0.943840    3.462482    0.247787    0.104018    0.020355    0.616951    
#> 367: 0.349876    0.943817    3.462465    0.247774    0.104070    0.020323    0.616947    
#> 368: 0.349963    0.943881    3.462443    0.247828    0.104002    0.020306    0.616837    
#> 369: 0.350044    0.943963    3.462424    0.247934    0.104050    0.020294    0.616862    
#> 370: 0.350018    0.944016    3.462348    0.248070    0.104094    0.020289    0.616811    
#> 371: 0.350083    0.944166    3.462261    0.248317    0.104071    0.020281    0.616622    
#> 372: 0.350015    0.944267    3.462164    0.248592    0.104051    0.020278    0.616552    
#> 373: 0.349694    0.944482    3.462066    0.248629    0.104113    0.020272    0.616489    
#> 374: 0.349636    0.944545    3.462002    0.248743    0.104157    0.020254    0.616453    
#> 375: 0.349439    0.944597    3.461950    0.248552    0.104221    0.020208    0.616472    
#> 376: 0.349406    0.944668    3.461975    0.248356    0.104247    0.020187    0.616459    
#> 377: 0.349183    0.944620    3.461984    0.248190    0.104272    0.020175    0.616503    
#> 378: 0.349182    0.944739    3.461934    0.248073    0.104289    0.020146    0.616562    
#> 379: 0.349052    0.944712    3.461903    0.248051    0.104285    0.020136    0.616513    
#> 380: 0.348845    0.944708    3.461871    0.248018    0.104355    0.020106    0.616478    
#> 381: 0.348620    0.944708    3.461824    0.247859    0.104477    0.020062    0.616483    
#> 382: 0.348520    0.944673    3.461819    0.247895    0.104569    0.020039    0.616452    
#> 383: 0.348527    0.944742    3.461820    0.248013    0.104581    0.020055    0.616331    
#> 384: 0.348507    0.944672    3.461838    0.248137    0.104456    0.020071    0.616292    
#> 385: 0.348609    0.944607    3.461855    0.248218    0.104450    0.020094    0.616279    
#> 386: 0.348823    0.944658    3.461948    0.248240    0.104388    0.020126    0.616245    
#> 387: 0.349005    0.944680    3.462058    0.248255    0.104393    0.020151    0.616207    
#> 388: 0.349140    0.944783    3.462110    0.248355    0.104363    0.020164    0.616219    
#> 389: 0.349240    0.944710    3.462126    0.248515    0.104371    0.020165    0.616296    
#> 390: 0.349294    0.944790    3.462135    0.248722    0.104400    0.020180    0.616253    
#> 391: 0.349527    0.944711    3.462180    0.248841    0.104331    0.020197    0.616254    
#> 392: 0.349755    0.944654    3.462295    0.248898    0.104271    0.020225    0.616223    
#> 393: 0.349824    0.944570    3.462276    0.248884    0.104204    0.020250    0.616226    
#> 394: 0.349792    0.944581    3.462248    0.248846    0.104209    0.020274    0.616243    
#> 395: 0.349885    0.944721    3.462233    0.248822    0.104208    0.020284    0.616277    
#> 396: 0.349949    0.944770    3.462239    0.248814    0.104189    0.020290    0.616183    
#> 397: 0.350081    0.944687    3.462301    0.248963    0.104171    0.020287    0.616175    
#> 398: 0.350236    0.944689    3.462349    0.249206    0.104103    0.020261    0.616238    
#> 399: 0.350434    0.944668    3.462412    0.249307    0.104076    0.020269    0.616258    
#> 400: 0.350617    0.944677    3.462441    0.249385    0.104132    0.020251    0.616268    
#> 401: 0.350570    0.944781    3.462383    0.249502    0.104224    0.020228    0.616312    
#> 402: 0.350496    0.944831    3.462362    0.249625    0.104224    0.020212    0.616314    
#> 403: 0.350634    0.944809    3.462345    0.249482    0.104265    0.020184    0.616335    
#> 404: 0.350649    0.944812    3.462315    0.249107    0.104276    0.020166    0.616308    
#> 405: 0.350648    0.944757    3.462331    0.249046    0.104218    0.020155    0.616340    
#> 406: 0.350705    0.944753    3.462334    0.248905    0.104136    0.020148    0.616431    
#> 407: 0.350746    0.944732    3.462411    0.248743    0.104066    0.020157    0.616414    
#> 408: 0.350850    0.944783    3.462433    0.248591    0.103995    0.020156    0.616411    
#> 409: 0.350930    0.944745    3.462476    0.248441    0.103942    0.020177    0.616395    
#> 410: 0.350896    0.944762    3.462445    0.248229    0.103953    0.020186    0.616519    
#> 411: 0.350961    0.944604    3.462457    0.248091    0.104050    0.020195    0.616609    
#> 412: 0.350901    0.944629    3.462418    0.248130    0.104071    0.020182    0.616622    
#> 413: 0.350787    0.944745    3.462395    0.248055    0.104079    0.020183    0.616673    
#> 414: 0.350676    0.944735    3.462425    0.247983    0.103963    0.020202    0.616595    
#> 415: 0.350768    0.944703    3.462432    0.247857    0.103866    0.020213    0.616532    
#> 416: 0.350874    0.944727    3.462424    0.247879    0.103843    0.020211    0.616509    
#> 417: 0.350916    0.944709    3.462459    0.247838    0.103829    0.020217    0.616449    
#> 418: 0.350863    0.944736    3.462498    0.247816    0.103835    0.020225    0.616370    
#> 419: 0.350982    0.944772    3.462498    0.247946    0.103805    0.020249    0.616257    
#> 420: 0.351118    0.944805    3.462529    0.247967    0.103811    0.020266    0.616136    
#> 421: 0.350985    0.944911    3.462543    0.247940    0.103817    0.020276    0.616156    
#> 422: 0.351150    0.944813    3.462595    0.247818    0.103763    0.020299    0.616218    
#> 423: 0.351051    0.944761    3.462569    0.247724    0.103767    0.020315    0.616217    
#> 424: 0.350908    0.944747    3.462509    0.247770    0.103807    0.020341    0.616213    
#> 425: 0.350913    0.944801    3.462481    0.247962    0.103793    0.020365    0.616174    
#> 426: 0.350946    0.944871    3.462437    0.248066    0.103796    0.020368    0.616171    
#> 427: 0.350742    0.944932    3.462416    0.248016    0.103752    0.020371    0.616154    
#> 428: 0.350537    0.944952    3.462384    0.247969    0.103679    0.020375    0.616213    
#> 429: 0.350535    0.944934    3.462398    0.248028    0.103724    0.020355    0.616176    
#> 430: 0.350425    0.944928    3.462394    0.247978    0.103701    0.020350    0.616180    
#> 431: 0.350312    0.944893    3.462386    0.247791    0.103690    0.020333    0.616180    
#> 432: 0.350177    0.944903    3.462410    0.247643    0.103672    0.020325    0.616188    
#> 433: 0.350321    0.944900    3.462478    0.247624    0.103604    0.020326    0.616200    
#> 434: 0.350303    0.944781    3.462495    0.247651    0.103552    0.020330    0.616165    
#> 435: 0.350277    0.944809    3.462481    0.247503    0.103534    0.020320    0.616114    
#> 436: 0.350298    0.944786    3.462536    0.247377    0.103530    0.020308    0.616116    
#> 437: 0.350500    0.944728    3.462575    0.247379    0.103478    0.020303    0.616069    
#> 438: 0.350567    0.944842    3.462571    0.247421    0.103562    0.020286    0.616009    
#> 439: 0.350616    0.944928    3.462564    0.247408    0.103567    0.020267    0.615985    
#> 440: 0.350577    0.944979    3.462562    0.247201    0.103597    0.020245    0.615992    
#> 441: 0.350570    0.944964    3.462572    0.246994    0.103602    0.020232    0.615925    
#> 442: 0.350457    0.945036    3.462573    0.246766    0.103616    0.020212    0.615885    
#> 443: 0.350386    0.945163    3.462482    0.246601    0.103621    0.020196    0.615910    
#> 444: 0.350248    0.945356    3.462424    0.246428    0.103641    0.020190    0.615900    
#> 445: 0.350102    0.945493    3.462365    0.246330    0.103774    0.020191    0.615949    
#> 446: 0.349989    0.945586    3.462287    0.246272    0.103865    0.020178    0.615949    
#> 447: 0.349965    0.945635    3.462268    0.246229    0.103889    0.020167    0.615926    
#> 448: 0.349945    0.945594    3.462293    0.246212    0.103863    0.020152    0.615887    
#> 449: 0.350177    0.945562    3.462395    0.246119    0.103878    0.020142    0.615907    
#> 450: 0.350277    0.945512    3.462453    0.246095    0.103889    0.020137    0.615917    
#> 451: 0.350360    0.945468    3.462473    0.246110    0.103916    0.020133    0.616014    
#> 452: 0.350373    0.945485    3.462484    0.245931    0.103959    0.020113    0.616028    
#> 453: 0.350230    0.945500    3.462463    0.245718    0.104017    0.020099    0.615994    
#> 454: 0.350193    0.945648    3.462453    0.245455    0.104079    0.020083    0.615993    
#> 455: 0.350168    0.945668    3.462458    0.245262    0.104070    0.020071    0.615946    
#> 456: 0.350143    0.945624    3.462458    0.245098    0.104030    0.020050    0.615937    
#> 457: 0.350101    0.945597    3.462466    0.245028    0.104012    0.020046    0.615905    
#> 458: 0.350076    0.945685    3.462489    0.245056    0.104069    0.020049    0.615850    
#> 459: 0.349945    0.945773    3.462487    0.245057    0.104073    0.020059    0.615889    
#> 460: 0.349829    0.945724    3.462441    0.245063    0.104039    0.020075    0.615910    
#> 461: 0.349754    0.945778    3.462431    0.245175    0.104075    0.020078    0.615907    
#> 462: 0.349678    0.945856    3.462419    0.245405    0.104117    0.020075    0.615851    
#> 463: 0.349720    0.945905    3.462437    0.245523    0.104141    0.020073    0.615797    
#> 464: 0.349788    0.945942    3.462413    0.245578    0.104154    0.020064    0.615736    
#> 465: 0.349855    0.945799    3.462447    0.245574    0.104134    0.020046    0.615753    
#> 466: 0.349928    0.945766    3.462454    0.245639    0.104094    0.020033    0.615735    
#> 467: 0.349957    0.945702    3.462533    0.245512    0.104134    0.020032    0.615681    
#> 468: 0.350148    0.945647    3.462637    0.245530    0.104135    0.020037    0.615703    
#> 469: 0.350150    0.945695    3.462635    0.245360    0.104086    0.020025    0.615714    
#> 470: 0.350050    0.945741    3.462596    0.245256    0.104128    0.020010    0.615673    
#> 471: 0.349927    0.945673    3.462572    0.245067    0.104121    0.020008    0.615695    
#> 472: 0.349859    0.945561    3.462594    0.244854    0.104137    0.019996    0.615715    
#> 473: 0.349777    0.945598    3.462566    0.244722    0.104123    0.019985    0.615648    
#> 474: 0.349746    0.945561    3.462570    0.244751    0.104052    0.019980    0.615633    
#> 475: 0.349841    0.945602    3.462600    0.244746    0.104118    0.019965    0.615595    
#> 476: 0.349924    0.945546    3.462603    0.244776    0.104152    0.019946    0.615628    
#> 477: 0.349831    0.945604    3.462597    0.244553    0.104224    0.019927    0.615614    
#> 478: 0.349777    0.945625    3.462581    0.244283    0.104295    0.019900    0.615618    
#> 479: 0.349762    0.945701    3.462538    0.244071    0.104404    0.019871    0.615639    
#> 480: 0.349742    0.945684    3.462555    0.243953    0.104480    0.019854    0.615674    
#> 481: 0.349794    0.945707    3.462553    0.243744    0.104552    0.019831    0.615693    
#> 482: 0.349803    0.945733    3.462538    0.243535    0.104561    0.019810    0.615786    
#> 483: 0.349830    0.945631    3.462575    0.243415    0.104585    0.019809    0.615762    
#> 484: 0.349945    0.945542    3.462592    0.243399    0.104588    0.019793    0.615776    
#> 485: 0.350081    0.945460    3.462624    0.243296    0.104578    0.019795    0.615790    
#> 486: 0.350133    0.945422    3.462647    0.243313    0.104642    0.019786    0.615754    
#> 487: 0.350240    0.945407    3.462700    0.243382    0.104698    0.019783    0.615732    
#> 488: 0.350330    0.945404    3.462766    0.243233    0.104640    0.019786    0.615705    
#> 489: 0.350562    0.945317    3.462811    0.243282    0.104640    0.019792    0.615739    
#> 490: 0.350777    0.945294    3.462852    0.243402    0.104640    0.019792    0.615747    
#> 491: 0.350909    0.945353    3.462896    0.243394    0.104612    0.019788    0.615722    
#> 492: 0.350945    0.945443    3.462895    0.243403    0.104555    0.019789    0.615782    
#> 493: 0.350837    0.945434    3.462897    0.243202    0.104563    0.019778    0.615826    
#> 494: 0.350968    0.945425    3.462892    0.242992    0.104593    0.019761    0.615841    
#> 495: 0.351049    0.945457    3.462895    0.242843    0.104607    0.019761    0.615825    
#> 496: 0.351085    0.945548    3.462867    0.242772    0.104618    0.019756    0.615870    
#> 497: 0.351113    0.945580    3.462880    0.242686    0.104663    0.019755    0.615896    
#> 498: 0.351092    0.945561    3.462863    0.242569    0.104680    0.019748    0.615855    
#> 499: 0.351101    0.945574    3.462843    0.242548    0.104650    0.019738    0.615804    
#> 500: 0.351132    0.945574    3.462818    0.242422    0.104696    0.019718    0.615760    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.298711    0.973024    3.447798    0.392401    0.073854    0.016800    1.617925    
#> 002: 0.318132    1.039744    3.489162    0.372781    0.070161    0.015960    1.038489    
#> 003: 0.410370    1.021224    3.512217    0.354142    0.066653    0.015162    0.856397    
#> 004: 0.379469    1.035080    3.525709    0.336435    0.064430    0.014404    0.804670    
#> 005: 0.410024    1.084370    3.505527    0.319613    0.061208    0.013684    0.726442    
#> 006: 0.418330    1.101006    3.497309    0.303633    0.058148    0.013000    0.670808    
#> 007: 0.370753    1.117133    3.489927    0.288451    0.055549    0.012350    0.688832    
#> 008: 0.348532    1.111680    3.477369    0.274029    0.064069    0.011732    0.695697    
#> 009: 0.324931    1.088872    3.472980    0.260327    0.060865    0.011146    0.698722    
#> 010: 0.327234    1.104470    3.475975    0.247311    0.057822    0.010588    0.690264    
#> 011: 0.387721    1.104242    3.486482    0.236766    0.054931    0.010059    0.701925    
#> 012: 0.425366    1.105756    3.497445    0.253146    0.055014    0.009556    0.674809    
#> 013: 0.384358    1.095342    3.498176    0.240489    0.052264    0.010362    0.689562    
#> 014: 0.423257    1.085050    3.497186    0.228464    0.049792    0.011240    0.704693    
#> 015: 0.417760    1.099237    3.512528    0.217041    0.047302    0.010678    0.677450    
#> 016: 0.404564    1.110247    3.500471    0.219572    0.044937    0.013355    0.669013    
#> 017: 0.425211    1.114501    3.505177    0.258794    0.046347    0.015939    0.661064    
#> 018: 0.399116    1.114125    3.491560    0.256782    0.051382    0.015142    0.687036    
#> 019: 0.386800    1.113774    3.498531    0.243943    0.048813    0.014385    0.684222    
#> 020: 0.409276    1.111929    3.516355    0.231746    0.052664    0.013665    0.675184    
#> 021: 0.443149    1.090755    3.518065    0.238050    0.050031    0.012982    0.674807    
#> 022: 0.435881    1.081735    3.526251    0.231582    0.047529    0.012333    0.658968    
#> 023: 0.508790    1.090152    3.536231    0.233173    0.045676    0.011716    0.692629    
#> 024: 0.504636    1.109816    3.528786    0.226116    0.043392    0.011131    0.698751    
#> 025: 0.483999    1.094434    3.526837    0.231411    0.041241    0.010574    0.673517    
#> 026: 0.425841    1.140549    3.503817    0.220873    0.039179    0.011477    0.682064    
#> 027: 0.413470    1.136045    3.499004    0.213005    0.040978    0.012000    0.707188    
#> 028: 0.426132    1.125412    3.497390    0.229068    0.038930    0.011400    0.694901    
#> 029: 0.401274    1.137796    3.487924    0.285321    0.042147    0.010830    0.696497    
#> 030: 0.398157    1.137569    3.483069    0.271055    0.042278    0.010876    0.679373    
#> 031: 0.364698    1.126653    3.488677    0.259072    0.040317    0.010332    0.678290    
#> 032: 0.357549    1.119486    3.491295    0.271286    0.042254    0.009815    0.666034    
#> 033: 0.366368    1.126883    3.496095    0.257722    0.042533    0.009325    0.668753    
#> 034: 0.431018    1.136975    3.505646    0.244836    0.051929    0.008913    0.666711    
#> 035: 0.392975    1.113625    3.503608    0.248163    0.050825    0.008672    0.657620    
#> 036: 0.402542    1.111391    3.498846    0.273782    0.048481    0.008238    0.666442    
#> 037: 0.400238    1.108863    3.500265    0.260093    0.052858    0.008013    0.659593    
#> 038: 0.417966    1.116918    3.502872    0.247985    0.058256    0.007858    0.654538    
#> 039: 0.441664    1.105699    3.510623    0.235586    0.056704    0.008549    0.658620    
#> 040: 0.424874    1.106995    3.514588    0.235912    0.053869    0.008450    0.677646    
#> 041: 0.406825    1.107527    3.507763    0.276050    0.051176    0.008027    0.667704    
#> 042: 0.445902    1.097873    3.508554    0.262247    0.048617    0.007626    0.668404    
#> 043: 0.398025    1.108222    3.500008    0.249135    0.058156    0.007244    0.672878    
#> 044: 0.395827    1.116589    3.499219    0.265086    0.055248    0.006882    0.674034    
#> 045: 0.425900    1.113345    3.499543    0.285964    0.057552    0.007005    0.663210    
#> 046: 0.424175    1.108394    3.505965    0.271666    0.054674    0.006654    0.667104    
#> 047: 0.419718    1.116965    3.502243    0.258083    0.052437    0.006459    0.669042    
#> 048: 0.412815    1.104585    3.498757    0.260322    0.049815    0.009659    0.658341    
#> 049: 0.443374    1.108146    3.514255    0.247306    0.049562    0.009176    0.682380    
#> 050: 0.489074    1.084480    3.515637    0.234941    0.047084    0.008717    0.693832    
#> 051: 0.445645    1.114377    3.508531    0.251100    0.044729    0.008281    0.689658    
#> 052: 0.473675    1.119291    3.522972    0.300376    0.045078    0.007867    0.668067    
#> 053: 0.457450    1.101371    3.521575    0.285357    0.042824    0.007543    0.679358    
#> 054: 0.404049    1.088428    3.523101    0.271090    0.040778    0.010656    0.682444    
#> 055: 0.406249    1.089438    3.516304    0.257535    0.045818    0.010123    0.679687    
#> 056: 0.457569    1.086657    3.527173    0.244658    0.049977    0.009617    0.703580    
#> 057: 0.409988    1.087195    3.527888    0.235606    0.048765    0.009136    0.709724    
#> 058: 0.417924    1.082803    3.501470    0.223826    0.049188    0.008679    0.697971    
#> 059: 0.411386    1.078597    3.508307    0.254276    0.051325    0.008403    0.694706    
#> 060: 0.416020    1.092001    3.514694    0.268194    0.052366    0.010740    0.685628    
#> 061: 0.456409    1.106662    3.518237    0.254784    0.049747    0.014197    0.707580    
#> 062: 0.452137    1.115143    3.524432    0.242045    0.047260    0.016576    0.704663    
#> 063: 0.477489    1.098550    3.520198    0.231293    0.044897    0.015747    0.695493    
#> 064: 0.448436    1.095693    3.524626    0.237323    0.042652    0.015571    0.688290    
#> 065: 0.452226    1.091312    3.514483    0.237699    0.040520    0.018724    0.678639    
#> 066: 0.454374    1.098789    3.528184    0.225814    0.038494    0.017900    0.671294    
#> 067: 0.436367    1.092908    3.519816    0.214524    0.036569    0.017005    0.672313    
#> 068: 0.389443    1.108860    3.516402    0.236874    0.034740    0.016155    0.685876    
#> 069: 0.385426    1.100370    3.497218    0.245872    0.040455    0.015347    0.676642    
#> 070: 0.400473    1.103678    3.508308    0.247999    0.038432    0.014579    0.671241    
#> 071: 0.389922    1.129510    3.493079    0.247705    0.036511    0.013850    0.687308    
#> 072: 0.381318    1.112436    3.500006    0.255975    0.044503    0.013675    0.670612    
#> 073: 0.420769    1.116717    3.509091    0.261752    0.054838    0.012991    0.652826    
#> 074: 0.402531    1.099272    3.500610    0.257652    0.052097    0.012544    0.676749    
#> 075: 0.417187    1.095348    3.525060    0.249996    0.059834    0.011917    0.679168    
#> 076: 0.447806    1.116424    3.532356    0.268810    0.056842    0.011321    0.686026    
#> 077: 0.477039    1.078684    3.529221    0.280412    0.056147    0.010755    0.670699    
#> 078: 0.464152    1.092653    3.534685    0.275498    0.053340    0.010217    0.668603    
#> 079: 0.467765    1.099018    3.533288    0.261724    0.050673    0.010959    0.669986    
#> 080: 0.483395    1.088773    3.533239    0.248637    0.048139    0.012234    0.666887    
#> 081: 0.467427    1.099226    3.524800    0.252873    0.045732    0.011622    0.654959    
#> 082: 0.447489    1.097558    3.528368    0.240229    0.043446    0.011041    0.680078    
#> 083: 0.437617    1.112064    3.524694    0.228218    0.044174    0.010489    0.672461    
#> 084: 0.445587    1.103219    3.516822    0.250428    0.048676    0.010171    0.673603    
#> 085: 0.450613    1.117796    3.529186    0.280311    0.046242    0.009663    0.675917    
#> 086: 0.433227    1.113329    3.521946    0.266295    0.043930    0.012020    0.661594    
#> 087: 0.427311    1.107664    3.511716    0.252980    0.041734    0.011419    0.663248    
#> 088: 0.422110    1.095299    3.515417    0.240331    0.044936    0.011013    0.681718    
#> 089: 0.428430    1.117856    3.509101    0.228315    0.048307    0.012248    0.666285    
#> 090: 0.384536    1.117437    3.501134    0.222541    0.058928    0.011635    0.674271    
#> 091: 0.395187    1.093448    3.487610    0.211414    0.063256    0.011054    0.679191    
#> 092: 0.389914    1.138709    3.485947    0.200843    0.061034    0.010501    0.674780    
#> 093: 0.371929    1.143202    3.479717    0.218092    0.057982    0.009976    0.682192    
#> 094: 0.358481    1.146817    3.469732    0.207188    0.055083    0.009477    0.692665    
#> 095: 0.371209    1.141061    3.486045    0.211032    0.052329    0.009003    0.693156    
#> 096: 0.333132    1.127320    3.486876    0.223386    0.050455    0.008553    0.676025    
#> 097: 0.384774    1.128183    3.492355    0.271146    0.047932    0.011281    0.669514    
#> 098: 0.351141    1.143356    3.495335    0.257588    0.045536    0.010717    0.668267    
#> 099: 0.378547    1.122846    3.476715    0.279278    0.043269    0.010181    0.663176    
#> 100: 0.372819    1.131730    3.478542    0.265314    0.041382    0.009672    0.657007    
#> 101: 0.339077    1.114873    3.469178    0.257879    0.040024    0.009358    0.661553    
#> 102: 0.345598    1.113517    3.464774    0.244985    0.050251    0.008890    0.669898    
#> 103: 0.386817    1.136527    3.486776    0.266188    0.048642    0.010279    0.654379    
#> 104: 0.376330    1.138587    3.500059    0.264912    0.056742    0.009765    0.670258    
#> 105: 0.396636    1.112186    3.497572    0.261561    0.053905    0.009277    0.682114    
#> 106: 0.434337    1.117532    3.501001    0.248483    0.051210    0.011803    0.670186    
#> 107: 0.448154    1.121584    3.504608    0.267258    0.049695    0.013211    0.678527    
#> 108: 0.445411    1.113021    3.511341    0.253895    0.049085    0.012551    0.692914    
#> 109: 0.404357    1.118533    3.511069    0.241201    0.047779    0.012047    0.682379    
#> 110: 0.426323    1.092941    3.495706    0.256081    0.050321    0.011445    0.688040    
#> 111: 0.402565    1.103721    3.498435    0.247788    0.047805    0.010872    0.682958    
#> 112: 0.391896    1.085831    3.491930    0.235398    0.045415    0.010329    0.692422    
#> 113: 0.388442    1.115795    3.498073    0.241275    0.043144    0.009812    0.676044    
#> 114: 0.410378    1.124606    3.505286    0.238288    0.042411    0.009322    0.691768    
#> 115: 0.439193    1.093974    3.512020    0.249394    0.042339    0.009237    0.693860    
#> 116: 0.428722    1.111294    3.506359    0.280294    0.051848    0.009546    0.659783    
#> 117: 0.392278    1.116828    3.504843    0.266279    0.049256    0.009281    0.668042    
#> 118: 0.435408    1.104642    3.513635    0.252965    0.046793    0.009332    0.669100    
#> 119: 0.430166    1.101093    3.508202    0.241264    0.044453    0.012025    0.666362    
#> 120: 0.390846    1.099034    3.496573    0.229201    0.042231    0.012488    0.656605    
#> 121: 0.404974    1.116570    3.496740    0.257850    0.040119    0.011864    0.674129    
#> 122: 0.415266    1.102684    3.507072    0.244957    0.039596    0.011270    0.682175    
#> 123: 0.443613    1.128003    3.503462    0.232710    0.039918    0.010707    0.688160    
#> 124: 0.442980    1.131006    3.504044    0.221074    0.037922    0.010899    0.684477    
#> 125: 0.444129    1.112486    3.496782    0.235671    0.039629    0.010354    0.683876    
#> 126: 0.407584    1.128509    3.494111    0.241511    0.042736    0.011820    0.671295    
#> 127: 0.411563    1.115054    3.488475    0.229436    0.040599    0.013968    0.692056    
#> 128: 0.362174    1.103762    3.498256    0.232133    0.047667    0.013269    0.663553    
#> 129: 0.390422    1.108131    3.504938    0.224970    0.047937    0.012606    0.673943    
#> 130: 0.426942    1.130576    3.505574    0.214578    0.045541    0.011976    0.666001    
#> 131: 0.413928    1.113334    3.497081    0.203849    0.044742    0.011377    0.702095    
#> 132: 0.387143    1.103730    3.484356    0.200654    0.052992    0.010808    0.697023    
#> 133: 0.389096    1.100004    3.495283    0.242878    0.064510    0.010268    0.691228    
#> 134: 0.412036    1.103672    3.507991    0.230734    0.061284    0.009754    0.684145    
#> 135: 0.383106    1.106816    3.502776    0.219197    0.058220    0.009266    0.688321    
#> 136: 0.415314    1.097341    3.505097    0.222742    0.055309    0.008803    0.672957    
#> 137: 0.421317    1.095507    3.514083    0.251592    0.057303    0.008363    0.677288    
#> 138: 0.409488    1.106833    3.507978    0.239012    0.057956    0.007945    0.674810    
#> 139: 0.412352    1.115424    3.504956    0.227061    0.058619    0.007548    0.682061    
#> 140: 0.438605    1.130160    3.510666    0.225798    0.057599    0.007332    0.666520    
#> 141: 0.410489    1.100278    3.513418    0.245175    0.057702    0.006965    0.656773    
#> 142: 0.436242    1.080295    3.516362    0.232916    0.054817    0.006617    0.679828    
#> 143: 0.412788    1.104023    3.521145    0.221271    0.052076    0.006286    0.694512    
#> 144: 0.466428    1.109883    3.525653    0.213389    0.051725    0.005972    0.673596    
#> 145: 0.440161    1.114487    3.520544    0.202720    0.058008    0.006331    0.660188    
#> 146: 0.416998    1.108097    3.516714    0.194794    0.055107    0.006014    0.671367    
#> 147: 0.412653    1.091258    3.511395    0.185055    0.056840    0.006303    0.686980    
#> 148: 0.410875    1.105254    3.512405    0.206424    0.058592    0.005988    0.674781    
#> 149: 0.398893    1.099579    3.507523    0.234857    0.060570    0.006212    0.706375    
#> 150: 0.425953    1.117844    3.501650    0.223114    0.057542    0.006729    0.702407    
#> 151: 0.399589    1.143120    3.498267    0.237620    0.058199    0.006540    0.685783    
#> 152: 0.389443    1.134852    3.504129    0.220734    0.052554    0.007569    0.682960    
#> 153: 0.419567    1.142152    3.506544    0.208765    0.046550    0.008061    0.690754    
#> 154: 0.449668    1.118581    3.515344    0.213659    0.053749    0.008216    0.687773    
#> 155: 0.441738    1.073495    3.526344    0.214264    0.053271    0.006283    0.692058    
#> 156: 0.434068    1.087350    3.535078    0.236591    0.067245    0.006371    0.690747    
#> 157: 0.471633    1.094064    3.529103    0.251086    0.071052    0.005423    0.697730    
#> 158: 0.477379    1.101705    3.523412    0.248747    0.066987    0.005554    0.680989    
#> 159: 0.428465    1.099846    3.523437    0.243824    0.058608    0.004004    0.691288    
#> 160: 0.451771    1.070099    3.524311    0.222238    0.065085    0.003387    0.691677    
#> 161: 0.446431    1.087062    3.521918    0.223796    0.060067    0.002889    0.689957    
#> 162: 0.442928    1.105227    3.509653    0.203371    0.063323    0.002876    0.682405    
#> 163: 0.445656    1.103621    3.502478    0.218108    0.074732    0.003008    0.684483    
#> 164: 0.434992    1.107801    3.506364    0.231422    0.066778    0.004699    0.694184    
#> 165: 0.463877    1.096951    3.518327    0.229466    0.071919    0.005251    0.693083    
#> 166: 0.469802    1.122864    3.518352    0.230322    0.061948    0.004626    0.677231    
#> 167: 0.451772    1.118741    3.523147    0.227124    0.058500    0.004682    0.688303    
#> 168: 0.465168    1.113555    3.528513    0.210850    0.061288    0.003645    0.692130    
#> 169: 0.462036    1.120733    3.524430    0.216031    0.063296    0.003721    0.703806    
#> 170: 0.470431    1.098673    3.521193    0.186268    0.058421    0.003441    0.683892    
#> 171: 0.427023    1.099798    3.519440    0.196506    0.054915    0.003312    0.682378    
#> 172: 0.401616    1.113442    3.513936    0.180019    0.056410    0.002887    0.686408    
#> 173: 0.422698    1.130921    3.504210    0.204642    0.054970    0.003948    0.680036    
#> 174: 0.410646    1.114007    3.503728    0.223069    0.062412    0.003658    0.670725    
#> 175: 0.375969    1.119551    3.495475    0.210931    0.067930    0.004512    0.687357    
#> 176: 0.402562    1.117235    3.508711    0.202826    0.060409    0.004140    0.681087    
#> 177: 0.410833    1.105173    3.511442    0.218382    0.066602    0.006509    0.684480    
#> 178: 0.430026    1.096324    3.511119    0.186083    0.064636    0.006942    0.677565    
#> 179: 0.443052    1.136469    3.507913    0.201441    0.042961    0.006630    0.682938    
#> 180: 0.441103    1.126630    3.513979    0.182446    0.041617    0.005860    0.686515    
#> 181: 0.406102    1.101616    3.492222    0.171680    0.034122    0.005181    0.705944    
#> 182: 0.385937    1.104916    3.492101    0.193368    0.040396    0.006004    0.699922    
#> 183: 0.389275    1.124468    3.498521    0.197238    0.045906    0.005149    0.678638    
#> 184: 0.384674    1.098370    3.497357    0.237579    0.044754    0.005050    0.686583    
#> 185: 0.395262    1.119187    3.501752    0.215601    0.040820    0.005859    0.682210    
#> 186: 0.404619    1.127866    3.502375    0.212521    0.041425    0.008330    0.679771    
#> 187: 0.431522    1.108960    3.511578    0.260431    0.046619    0.008561    0.686126    
#> 188: 0.358704    1.132449    3.499076    0.250033    0.046923    0.008491    0.690617    
#> 189: 0.403071    1.121206    3.511497    0.258727    0.046641    0.007867    0.680884    
#> 190: 0.417062    1.107776    3.517221    0.223986    0.047618    0.008104    0.668368    
#> 191: 0.397414    1.119899    3.504165    0.255143    0.049012    0.008278    0.653651    
#> 192: 0.392118    1.133256    3.500168    0.246645    0.053682    0.008165    0.650084    
#> 193: 0.421647    1.137786    3.499817    0.279733    0.053058    0.007237    0.650605    
#> 194: 0.375316    1.127164    3.488134    0.247654    0.052719    0.006167    0.680217    
#> 195: 0.366016    1.114813    3.479070    0.258460    0.051981    0.006991    0.669441    
#> 196: 0.374426    1.118160    3.487285    0.296463    0.054914    0.005414    0.683171    
#> 197: 0.357451    1.131032    3.500880    0.234037    0.059624    0.005804    0.686060    
#> 198: 0.442121    1.110477    3.495290    0.266432    0.055652    0.007102    0.676728    
#> 199: 0.382288    1.110898    3.498914    0.209777    0.048771    0.006590    0.671886    
#> 200: 0.396695    1.106813    3.500698    0.191219    0.049485    0.006443    0.699053    
#> 201: 0.382543    1.098725    3.502444    0.186596    0.049373    0.007028    0.691879    
#> 202: 0.387260    1.102484    3.500155    0.191985    0.050018    0.007485    0.687540    
#> 203: 0.402444    1.103035    3.500509    0.191048    0.048077    0.007848    0.688140    
#> 204: 0.407643    1.100693    3.502686    0.193156    0.051170    0.007863    0.686633    
#> 205: 0.405552    1.106257    3.502542    0.199032    0.051191    0.007896    0.687016    
#> 206: 0.403346    1.111264    3.501567    0.207476    0.051546    0.007856    0.687984    
#> 207: 0.397260    1.113737    3.499686    0.203661    0.051310    0.007822    0.688666    
#> 208: 0.394405    1.113764    3.499649    0.199674    0.051098    0.007667    0.690596    
#> 209: 0.396083    1.111993    3.499480    0.201597    0.051499    0.007391    0.690696    
#> 210: 0.399865    1.109960    3.500402    0.201991    0.051745    0.007337    0.689145    
#> 211: 0.403079    1.109703    3.502000    0.200882    0.052101    0.007117    0.688575    
#> 212: 0.407496    1.108329    3.503218    0.201427    0.051871    0.006949    0.688096    
#> 213: 0.409348    1.105841    3.503730    0.200148    0.052968    0.006817    0.689649    
#> 214: 0.413115    1.103540    3.504343    0.201142    0.053722    0.006755    0.689785    
#> 215: 0.414165    1.102455    3.505378    0.202372    0.054615    0.006812    0.689489    
#> 216: 0.416673    1.100426    3.505659    0.202185    0.055675    0.006794    0.689935    
#> 217: 0.416285    1.102278    3.505282    0.203513    0.056435    0.006806    0.689100    
#> 218: 0.415329    1.103185    3.504775    0.203977    0.056544    0.006816    0.687979    
#> 219: 0.413646    1.103211    3.503988    0.205770    0.056288    0.006916    0.687658    
#> 220: 0.411928    1.104264    3.503744    0.205599    0.055522    0.006940    0.687715    
#> 221: 0.410136    1.105134    3.503551    0.205740    0.055632    0.006870    0.687955    
#> 222: 0.411997    1.105583    3.503493    0.207746    0.056106    0.006822    0.687628    
#> 223: 0.414110    1.105717    3.503738    0.208732    0.056219    0.006804    0.687516    
#> 224: 0.416076    1.106715    3.504294    0.210355    0.056232    0.006826    0.687070    
#> 225: 0.417993    1.104978    3.505306    0.211532    0.056470    0.006909    0.686660    
#> 226: 0.419182    1.103551    3.505576    0.212037    0.056638    0.006922    0.686281    
#> 227: 0.419045    1.103071    3.506081    0.214315    0.056144    0.006944    0.685633    
#> 228: 0.418020    1.104242    3.505487    0.214961    0.055955    0.007030    0.685086    
#> 229: 0.417843    1.104302    3.505163    0.216367    0.055716    0.007072    0.684014    
#> 230: 0.417873    1.103867    3.504941    0.215980    0.055395    0.007085    0.683529    
#> 231: 0.417612    1.103823    3.505152    0.216041    0.055417    0.007099    0.682916    
#> 232: 0.417420    1.103651    3.505549    0.217471    0.055370    0.007129    0.682526    
#> 233: 0.417856    1.102738    3.506002    0.218922    0.055494    0.007177    0.681996    
#> 234: 0.418140    1.102512    3.506319    0.220192    0.055489    0.007211    0.681623    
#> 235: 0.418856    1.101901    3.506523    0.220688    0.055769    0.007214    0.681431    
#> 236: 0.419622    1.101923    3.506649    0.219979    0.056090    0.007213    0.681521    
#> 237: 0.420556    1.101860    3.506886    0.220073    0.056012    0.007253    0.681826    
#> 238: 0.420966    1.101568    3.507074    0.220185    0.056046    0.007275    0.681967    
#> 239: 0.420423    1.102240    3.507070    0.220758    0.056108    0.007287    0.681812    
#> 240: 0.420830    1.102084    3.507329    0.220497    0.055870    0.007250    0.682041    
#> 241: 0.421292    1.101278    3.507675    0.220472    0.055775    0.007203    0.682455    
#> 242: 0.421760    1.100561    3.507891    0.219849    0.055792    0.007147    0.683040    
#> 243: 0.421407    1.100995    3.507955    0.219183    0.055752    0.007129    0.683375    
#> 244: 0.420632    1.100943    3.508057    0.219875    0.055852    0.007121    0.683357    
#> 245: 0.420367    1.100888    3.508168    0.219278    0.055816    0.007158    0.683181    
#> 246: 0.420950    1.100486    3.508627    0.219700    0.055517    0.007206    0.682867    
#> 247: 0.421075    1.100045    3.509068    0.219885    0.055201    0.007216    0.682889    
#> 248: 0.421222    1.100565    3.509328    0.219916    0.055035    0.007223    0.682713    
#> 249: 0.421437    1.100752    3.509569    0.220012    0.055160    0.007247    0.682555    
#> 250: 0.421752    1.101107    3.509611    0.220093    0.055179    0.007282    0.682444    
#> 251: 0.421435    1.101626    3.509609    0.220240    0.055157    0.007271    0.682493    
#> 252: 0.421506    1.101691    3.509625    0.219675    0.055136    0.007263    0.682494    
#> 253: 0.421375    1.101768    3.509722    0.219419    0.055020    0.007251    0.682519    
#> 254: 0.421470    1.102087    3.509988    0.219214    0.054980    0.007254    0.682752    
#> 255: 0.421481    1.102227    3.510179    0.218878    0.054771    0.007274    0.682782    
#> 256: 0.422190    1.102205    3.510179    0.218435    0.054457    0.007304    0.682950    
#> 257: 0.421941    1.101967    3.510171    0.218484    0.054193    0.007322    0.682888    
#> 258: 0.421429    1.101872    3.510020    0.218335    0.053987    0.007364    0.682378    
#> 259: 0.421226    1.102064    3.509841    0.218362    0.053758    0.007397    0.681958    
#> 260: 0.420803    1.102403    3.509868    0.218526    0.053536    0.007428    0.681610    
#> 261: 0.420756    1.102389    3.509939    0.218755    0.053259    0.007464    0.681609    
#> 262: 0.421235    1.102314    3.509960    0.219132    0.053157    0.007478    0.681562    
#> 263: 0.421372    1.102416    3.510014    0.219267    0.053148    0.007506    0.681712    
#> 264: 0.421333    1.102513    3.510046    0.219564    0.053087    0.007535    0.681673    
#> 265: 0.421318    1.102737    3.510027    0.220109    0.053116    0.007536    0.681686    
#> 266: 0.421653    1.103080    3.509844    0.220544    0.053217    0.007548    0.681567    
#> 267: 0.421587    1.103202    3.509756    0.220819    0.053217    0.007558    0.681782    
#> 268: 0.421424    1.102933    3.509616    0.220673    0.053242    0.007527    0.681979    
#> 269: 0.421988    1.102846    3.509640    0.220213    0.053153    0.007528    0.682052    
#> 270: 0.422530    1.102994    3.509615    0.220746    0.053224    0.007503    0.681916    
#> 271: 0.422667    1.103176    3.509446    0.221077    0.053278    0.007480    0.681996    
#> 272: 0.422760    1.103171    3.509354    0.221524    0.053351    0.007478    0.682032    
#> 273: 0.422717    1.103413    3.509377    0.221510    0.053222    0.007478    0.682062    
#> 274: 0.422485    1.103730    3.509409    0.221499    0.053232    0.007505    0.681994    
#> 275: 0.422413    1.103975    3.509327    0.221664    0.052998    0.007559    0.682016    
#> 276: 0.422285    1.104017    3.509474    0.221957    0.052733    0.007609    0.681918    
#> 277: 0.422199    1.104134    3.509666    0.222001    0.052683    0.007655    0.681954    
#> 278: 0.422112    1.104098    3.509733    0.221951    0.052755    0.007679    0.681656    
#> 279: 0.421843    1.103863    3.509717    0.221765    0.052849    0.007715    0.681690    
#> 280: 0.422111    1.103991    3.509824    0.222133    0.052893    0.007734    0.681567    
#> 281: 0.421981    1.104196    3.509947    0.222740    0.052816    0.007764    0.681499    
#> 282: 0.422055    1.104303    3.510041    0.223325    0.052798    0.007772    0.681474    
#> 283: 0.421993    1.104696    3.509940    0.224051    0.052846    0.007765    0.681636    
#> 284: 0.421651    1.104714    3.509740    0.224406    0.052735    0.007755    0.681552    
#> 285: 0.421183    1.105008    3.509420    0.224929    0.052741    0.007750    0.681417    
#> 286: 0.420868    1.105295    3.509211    0.225391    0.052758    0.007755    0.681318    
#> 287: 0.420358    1.105500    3.508937    0.225933    0.052796    0.007753    0.681263    
#> 288: 0.420321    1.105517    3.508862    0.226324    0.052708    0.007763    0.681215    
#> 289: 0.420223    1.105405    3.508732    0.226802    0.052771    0.007785    0.681280    
#> 290: 0.420036    1.105463    3.508588    0.227563    0.052844    0.007775    0.681445    
#> 291: 0.419987    1.105704    3.508556    0.227835    0.052890    0.007771    0.681351    
#> 292: 0.420064    1.105745    3.508490    0.228066    0.052913    0.007769    0.681269    
#> 293: 0.420049    1.105729    3.508429    0.228086    0.052867    0.007752    0.681134    
#> 294: 0.420026    1.105772    3.508359    0.228147    0.052810    0.007751    0.681077    
#> 295: 0.420052    1.105413    3.508374    0.228218    0.052795    0.007760    0.680910    
#> 296: 0.419885    1.105196    3.508367    0.228026    0.052843    0.007787    0.680861    
#> 297: 0.420104    1.105166    3.508373    0.228029    0.052871    0.007820    0.680730    
#> 298: 0.420265    1.105118    3.508402    0.228326    0.052786    0.007851    0.680592    
#> 299: 0.420126    1.105171    3.508426    0.228528    0.052789    0.007876    0.680409    
#> 300: 0.420007    1.105142    3.508541    0.228777    0.052788    0.007894    0.680263    
#> 301: 0.420037    1.104972    3.508582    0.228455    0.052784    0.007908    0.680450    
#> 302: 0.420265    1.104889    3.508647    0.228426    0.052713    0.007910    0.680428    
#> 303: 0.420295    1.104950    3.508638    0.228667    0.052729    0.007918    0.680190    
#> 304: 0.420349    1.105202    3.508515    0.228753    0.052739    0.007930    0.680179    
#> 305: 0.420297    1.105088    3.508500    0.228660    0.052745    0.007949    0.680142    
#> 306: 0.420192    1.105064    3.508432    0.228513    0.052706    0.007995    0.680062    
#> 307: 0.419897    1.105016    3.508277    0.228441    0.052703    0.008022    0.680216    
#> 308: 0.419377    1.105045    3.508080    0.229003    0.052727    0.008036    0.680334    
#> 309: 0.419292    1.105036    3.507938    0.229290    0.052676    0.008050    0.680365    
#> 310: 0.419189    1.105027    3.507818    0.229534    0.052543    0.008065    0.680592    
#> 311: 0.418962    1.105219    3.507678    0.229892    0.052364    0.008083    0.680610    
#> 312: 0.418476    1.105278    3.507444    0.230692    0.052316    0.008124    0.680561    
#> 313: 0.418146    1.105343    3.507317    0.231062    0.052296    0.008162    0.680610    
#> 314: 0.417646    1.105570    3.507141    0.230941    0.052259    0.008180    0.680630    
#> 315: 0.417354    1.105832    3.507017    0.230795    0.052271    0.008194    0.680689    
#> 316: 0.417316    1.106053    3.506957    0.230698    0.052192    0.008211    0.680756    
#> 317: 0.417338    1.106061    3.507002    0.230364    0.052180    0.008214    0.680820    
#> 318: 0.417315    1.106142    3.506923    0.230691    0.052107    0.008217    0.680822    
#> 319: 0.417179    1.106171    3.506924    0.231034    0.052058    0.008213    0.680864    
#> 320: 0.416844    1.106318    3.506765    0.231116    0.052060    0.008213    0.680796    
#> 321: 0.416473    1.106447    3.506595    0.231370    0.052116    0.008200    0.680777    
#> 322: 0.416195    1.106528    3.506407    0.231648    0.052103    0.008216    0.680619    
#> 323: 0.415577    1.106673    3.506259    0.231607    0.052036    0.008231    0.680695    
#> 324: 0.415206    1.106943    3.506110    0.231504    0.052063    0.008241    0.680655    
#> 325: 0.414984    1.107096    3.505971    0.231346    0.052058    0.008240    0.680539    
#> 326: 0.414867    1.106900    3.505891    0.231326    0.051990    0.008240    0.680476    
#> 327: 0.414815    1.106930    3.505880    0.231528    0.052013    0.008241    0.680446    
#> 328: 0.414777    1.107075    3.505795    0.231410    0.051984    0.008249    0.680372    
#> 329: 0.414742    1.107107    3.505765    0.231626    0.051933    0.008258    0.680373    
#> 330: 0.414261    1.107224    3.505673    0.231655    0.051831    0.008269    0.680355    
#> 331: 0.414052    1.107480    3.505604    0.231670    0.051791    0.008282    0.680217    
#> 332: 0.413994    1.107475    3.505609    0.231402    0.051820    0.008278    0.680293    
#> 333: 0.413746    1.107500    3.505477    0.231327    0.051821    0.008285    0.680238    
#> 334: 0.413411    1.107474    3.505298    0.231217    0.051872    0.008277    0.680314    
#> 335: 0.413248    1.107660    3.505177    0.231227    0.051835    0.008271    0.680427    
#> 336: 0.412788    1.107925    3.505088    0.231099    0.051764    0.008269    0.680665    
#> 337: 0.412474    1.108275    3.504912    0.231047    0.051743    0.008261    0.680675    
#> 338: 0.412290    1.108448    3.504840    0.230933    0.051689    0.008276    0.680666    
#> 339: 0.411794    1.108697    3.504732    0.230992    0.051666    0.008286    0.680585    
#> 340: 0.411674    1.108762    3.504733    0.230937    0.051569    0.008293    0.680650    
#> 341: 0.412078    1.108733    3.504792    0.230871    0.051579    0.008300    0.680658    
#> 342: 0.411947    1.108659    3.504794    0.230693    0.051587    0.008303    0.680577    
#> 343: 0.411756    1.108767    3.504800    0.230716    0.051564    0.008299    0.680607    
#> 344: 0.411810    1.108841    3.504837    0.230881    0.051504    0.008299    0.680677    
#> 345: 0.411820    1.108799    3.504837    0.231065    0.051429    0.008309    0.680692    
#> 346: 0.411755    1.108891    3.504759    0.231028    0.051416    0.008305    0.680604    
#> 347: 0.411882    1.108855    3.504673    0.230987    0.051452    0.008294    0.680649    
#> 348: 0.411629    1.109075    3.504523    0.231173    0.051558    0.008299    0.680671    
#> 349: 0.411608    1.109180    3.504418    0.231201    0.051590    0.008292    0.680687    
#> 350: 0.411470    1.109179    3.504343    0.231255    0.051632    0.008289    0.680669    
#> 351: 0.411611    1.109304    3.504305    0.231103    0.051633    0.008275    0.680628    
#> 352: 0.411399    1.109389    3.504339    0.230906    0.051642    0.008277    0.680681    
#> 353: 0.411357    1.109365    3.504350    0.230771    0.051572    0.008298    0.680565    
#> 354: 0.411406    1.109345    3.504300    0.230824    0.051489    0.008312    0.680444    
#> 355: 0.411790    1.109229    3.504294    0.230872    0.051442    0.008327    0.680291    
#> 356: 0.411843    1.109192    3.504312    0.230777    0.051370    0.008332    0.680432    
#> 357: 0.412018    1.109247    3.504321    0.231070    0.051297    0.008325    0.680398    
#> 358: 0.412066    1.109343    3.504340    0.231134    0.051380    0.008315    0.680378    
#> 359: 0.411851    1.109503    3.504297    0.230898    0.051302    0.008304    0.680411    
#> 360: 0.411543    1.109536    3.504189    0.230904    0.051264    0.008290    0.680348    
#> 361: 0.411383    1.109481    3.504159    0.230690    0.051195    0.008280    0.680365    
#> 362: 0.411544    1.109485    3.504134    0.230625    0.051190    0.008261    0.680271    
#> 363: 0.411583    1.109401    3.504154    0.230335    0.051206    0.008243    0.680264    
#> 364: 0.411673    1.109436    3.504167    0.230127    0.051264    0.008229    0.680236    
#> 365: 0.411741    1.109400    3.504225    0.230045    0.051297    0.008230    0.680274    
#> 366: 0.411900    1.109484    3.504205    0.230066    0.051301    0.008228    0.680252    
#> 367: 0.411955    1.109494    3.504234    0.230307    0.051266    0.008231    0.680182    
#> 368: 0.412143    1.109475    3.504252    0.230241    0.051234    0.008251    0.680138    
#> 369: 0.412141    1.109448    3.504242    0.230175    0.051214    0.008270    0.680145    
#> 370: 0.412064    1.109532    3.504251    0.230080    0.051164    0.008297    0.680082    
#> 371: 0.411802    1.109736    3.504127    0.230076    0.051141    0.008306    0.679937    
#> 372: 0.411518    1.109890    3.504022    0.230166    0.051112    0.008310    0.679941    
#> 373: 0.411243    1.110119    3.503885    0.230274    0.051045    0.008324    0.679980    
#> 374: 0.411156    1.110218    3.503768    0.230579    0.050960    0.008335    0.679908    
#> 375: 0.410992    1.110212    3.503736    0.230756    0.050928    0.008351    0.679804    
#> 376: 0.410823    1.110342    3.503673    0.230768    0.050889    0.008371    0.679730    
#> 377: 0.410754    1.110352    3.503678    0.230681    0.050811    0.008397    0.679685    
#> 378: 0.410597    1.110276    3.503618    0.230766    0.050756    0.008411    0.679679    
#> 379: 0.410527    1.110056    3.503644    0.230824    0.050732    0.008431    0.679645    
#> 380: 0.410427    1.110129    3.503589    0.230707    0.050679    0.008448    0.679637    
#> 381: 0.410237    1.110187    3.503517    0.230660    0.050671    0.008448    0.679558    
#> 382: 0.410184    1.110239    3.503495    0.230556    0.050638    0.008450    0.679494    
#> 383: 0.410224    1.110245    3.503484    0.230314    0.050620    0.008449    0.679469    
#> 384: 0.410141    1.110182    3.503506    0.230229    0.050579    0.008460    0.679470    
#> 385: 0.410256    1.110146    3.503541    0.230137    0.050567    0.008470    0.679471    
#> 386: 0.410417    1.110201    3.503610    0.230039    0.050552    0.008478    0.679448    
#> 387: 0.410807    1.110149    3.503752    0.230086    0.050534    0.008485    0.679397    
#> 388: 0.411114    1.110130    3.503867    0.230215    0.050491    0.008502    0.679302    
#> 389: 0.411139    1.109985    3.503889    0.230158    0.050458    0.008515    0.679326    
#> 390: 0.411186    1.109995    3.503916    0.229990    0.050418    0.008512    0.679378    
#> 391: 0.411317    1.109968    3.503952    0.229852    0.050421    0.008508    0.679335    
#> 392: 0.411430    1.109991    3.504025    0.229886    0.050394    0.008504    0.679411    
#> 393: 0.411459    1.109983    3.504031    0.229890    0.050404    0.008505    0.679342    
#> 394: 0.411298    1.109964    3.503983    0.229752    0.050353    0.008505    0.679354    
#> 395: 0.411392    1.110029    3.503981    0.229722    0.050364    0.008511    0.679349    
#> 396: 0.411645    1.110027    3.504043    0.229772    0.050423    0.008507    0.679187    
#> 397: 0.411819    1.109940    3.504147    0.229815    0.050396    0.008516    0.679145    
#> 398: 0.412052    1.109800    3.504251    0.229988    0.050381    0.008524    0.679160    
#> 399: 0.412106    1.109830    3.504317    0.230194    0.050370    0.008535    0.679296    
#> 400: 0.412119    1.109957    3.504350    0.230080    0.050372    0.008541    0.679398    
#> 401: 0.412086    1.110088    3.504319    0.230089    0.050363    0.008549    0.679429    
#> 402: 0.412094    1.110077    3.504348    0.229993    0.050363    0.008551    0.679493    
#> 403: 0.412354    1.110017    3.504393    0.229966    0.050306    0.008540    0.679597    
#> 404: 0.412560    1.110034    3.504396    0.229967    0.050234    0.008534    0.679588    
#> 405: 0.412655    1.110046    3.504407    0.230140    0.050203    0.008532    0.679542    
#> 406: 0.412636    1.110013    3.504410    0.230052    0.050185    0.008533    0.679572    
#> 407: 0.412673    1.110013    3.504471    0.229815    0.050256    0.008534    0.679556    
#> 408: 0.413028    1.109941    3.504572    0.229867    0.050351    0.008526    0.679605    
#> 409: 0.413119    1.109863    3.504589    0.229751    0.050387    0.008524    0.679628    
#> 410: 0.412951    1.109907    3.504473    0.229556    0.050409    0.008522    0.679686    
#> 411: 0.412958    1.109790    3.504392    0.229566    0.050385    0.008518    0.679801    
#> 412: 0.412871    1.109865    3.504318    0.229482    0.050446    0.008499    0.679840    
#> 413: 0.412872    1.109960    3.504255    0.229137    0.050428    0.008487    0.679961    
#> 414: 0.412750    1.109971    3.504240    0.229212    0.050410    0.008471    0.679945    
#> 415: 0.412794    1.110005    3.504213    0.229159    0.050407    0.008461    0.679951    
#> 416: 0.412942    1.110071    3.504210    0.229020    0.050401    0.008458    0.679914    
#> 417: 0.412973    1.110047    3.504199    0.229000    0.050369    0.008462    0.679879    
#> 418: 0.412850    1.110080    3.504222    0.228964    0.050361    0.008468    0.679821    
#> 419: 0.412836    1.110162    3.504246    0.229212    0.050360    0.008471    0.679760    
#> 420: 0.413040    1.110140    3.504304    0.229284    0.050333    0.008467    0.679658    
#> 421: 0.413001    1.110195    3.504348    0.229398    0.050274    0.008463    0.679610    
#> 422: 0.413245    1.110106    3.504410    0.229314    0.050256    0.008455    0.679585    
#> 423: 0.413345    1.110009    3.504444    0.229364    0.050265    0.008452    0.679555    
#> 424: 0.413187    1.109958    3.504405    0.229522    0.050215    0.008442    0.679567    
#> 425: 0.413368    1.109889    3.504400    0.229692    0.050189    0.008432    0.679630    
#> 426: 0.413452    1.109935    3.504425    0.229752    0.050213    0.008428    0.679570    
#> 427: 0.413453    1.109912    3.504473    0.229788    0.050239    0.008423    0.679526    
#> 428: 0.413375    1.109981    3.504481    0.229696    0.050254    0.008417    0.679530    
#> 429: 0.413531    1.110012    3.504538    0.229748    0.050250    0.008414    0.679530    
#> 430: 0.413576    1.110050    3.504559    0.229671    0.050269    0.008409    0.679511    
#> 431: 0.413543    1.110079    3.504527    0.229575    0.050289    0.008400    0.679478    
#> 432: 0.413474    1.110145    3.504542    0.229559    0.050307    0.008401    0.679477    
#> 433: 0.413499    1.110266    3.504536    0.229472    0.050312    0.008394    0.679514    
#> 434: 0.413332    1.110258    3.504512    0.229391    0.050340    0.008391    0.679491    
#> 435: 0.413472    1.110257    3.504517    0.229474    0.050373    0.008386    0.679450    
#> 436: 0.413528    1.110221    3.504549    0.229472    0.050384    0.008381    0.679481    
#> 437: 0.413451    1.110272    3.504523    0.229500    0.050386    0.008378    0.679546    
#> 438: 0.413282    1.110452    3.504489    0.229617    0.050364    0.008380    0.679463    
#> 439: 0.413259    1.110546    3.504480    0.229516    0.050352    0.008383    0.679396    
#> 440: 0.413244    1.110538    3.504523    0.229582    0.050326    0.008386    0.679328    
#> 441: 0.413307    1.110480    3.504586    0.229520    0.050310    0.008384    0.679348    
#> 442: 0.413280    1.110458    3.504626    0.229534    0.050353    0.008380    0.679290    
#> 443: 0.413323    1.110498    3.504604    0.229564    0.050410    0.008375    0.679308    
#> 444: 0.413200    1.110551    3.504517    0.229675    0.050442    0.008376    0.679307    
#> 445: 0.412986    1.110623    3.504427    0.229781    0.050397    0.008383    0.679310    
#> 446: 0.412661    1.110716    3.504334    0.229963    0.050365    0.008386    0.679327    
#> 447: 0.412653    1.110788    3.504293    0.230054    0.050362    0.008389    0.679348    
#> 448: 0.412575    1.110806    3.504269    0.229978    0.050363    0.008392    0.679340    
#> 449: 0.412577    1.110922    3.504340    0.229991    0.050387    0.008407    0.679344    
#> 450: 0.412714    1.110940    3.504381    0.229931    0.050392    0.008419    0.679331    
#> 451: 0.412778    1.110949    3.504381    0.229970    0.050424    0.008430    0.679314    
#> 452: 0.412843    1.110986    3.504373    0.229975    0.050434    0.008435    0.679282    
#> 453: 0.412844    1.110994    3.504390    0.230128    0.050388    0.008440    0.679239    
#> 454: 0.412832    1.111058    3.504389    0.230143    0.050351    0.008434    0.679227    
#> 455: 0.412850    1.111072    3.504383    0.230147    0.050325    0.008434    0.679234    
#> 456: 0.412770    1.111055    3.504349    0.230237    0.050337    0.008425    0.679240    
#> 457: 0.412723    1.111040    3.504361    0.230226    0.050363    0.008418    0.679161    
#> 458: 0.412665    1.111129    3.504373    0.230309    0.050378    0.008408    0.679157    
#> 459: 0.412581    1.111287    3.504354    0.230399    0.050422    0.008403    0.679079    
#> 460: 0.412527    1.111314    3.504301    0.230354    0.050458    0.008402    0.679088    
#> 461: 0.412470    1.111338    3.504294    0.230342    0.050453    0.008400    0.679095    
#> 462: 0.412332    1.111419    3.504273    0.230544    0.050469    0.008402    0.679056    
#> 463: 0.412317    1.111453    3.504258    0.230749    0.050459    0.008409    0.678946    
#> 464: 0.412353    1.111472    3.504245    0.231035    0.050470    0.008410    0.678884    
#> 465: 0.412277    1.111346    3.504213    0.231253    0.050503    0.008406    0.678872    
#> 466: 0.412287    1.111400    3.504163    0.231334    0.050525    0.008407    0.678825    
#> 467: 0.412186    1.111406    3.504154    0.231329    0.050532    0.008398    0.678801    
#> 468: 0.412300    1.111402    3.504178    0.231441    0.050520    0.008398    0.678827    
#> 469: 0.412413    1.111492    3.504207    0.231417    0.050532    0.008393    0.678786    
#> 470: 0.412326    1.111473    3.504202    0.231438    0.050531    0.008393    0.678768    
#> 471: 0.412199    1.111466    3.504162    0.231344    0.050498    0.008394    0.678771    
#> 472: 0.412140    1.111525    3.504170    0.231235    0.050514    0.008391    0.678803    
#> 473: 0.411992    1.111591    3.504159    0.231164    0.050530    0.008384    0.678760    
#> 474: 0.412081    1.111512    3.504185    0.231188    0.050509    0.008384    0.678782    
#> 475: 0.412193    1.111547    3.504225    0.231225    0.050498    0.008380    0.678767    
#> 476: 0.412228    1.111522    3.504203    0.231308    0.050505    0.008374    0.678751    
#> 477: 0.412260    1.111549    3.504217    0.231191    0.050505    0.008370    0.678714    
#> 478: 0.412117    1.111486    3.504220    0.231003    0.050518    0.008373    0.678681    
#> 479: 0.412140    1.111508    3.504229    0.231041    0.050527    0.008372    0.678681    
#> 480: 0.412081    1.111561    3.504213    0.231012    0.050567    0.008378    0.678682    
#> 481: 0.412111    1.111564    3.504222    0.231092    0.050569    0.008374    0.678685    
#> 482: 0.412269    1.111575    3.504224    0.231256    0.050590    0.008372    0.678674    
#> 483: 0.412241    1.111561    3.504247    0.231359    0.050600    0.008371    0.678619    
#> 484: 0.412190    1.111476    3.504274    0.231389    0.050585    0.008377    0.678564    
#> 485: 0.412210    1.111476    3.504284    0.231418    0.050576    0.008379    0.678532    
#> 486: 0.412235    1.111495    3.504287    0.231476    0.050543    0.008380    0.678532    
#> 487: 0.412424    1.111526    3.504337    0.231421    0.050506    0.008376    0.678489    
#> 488: 0.412400    1.111526    3.504364    0.231317    0.050496    0.008370    0.678446    
#> 489: 0.412515    1.111564    3.504352    0.231329    0.050480    0.008368    0.678423    
#> 490: 0.412593    1.111644    3.504398    0.231374    0.050482    0.008370    0.678429    
#> 491: 0.412609    1.111697    3.504448    0.231362    0.050470    0.008370    0.678398    
#> 492: 0.412599    1.111722    3.504448    0.231401    0.050503    0.008372    0.678432    
#> 493: 0.412525    1.111693    3.504458    0.231483    0.050506    0.008380    0.678477    
#> 494: 0.412568    1.111698    3.504448    0.231401    0.050495    0.008383    0.678467    
#> 495: 0.412549    1.111739    3.504457    0.231364    0.050483    0.008379    0.678421    
#> 496: 0.412616    1.111777    3.504416    0.231476    0.050463    0.008380    0.678412    
#> 497: 0.412600    1.111756    3.504403    0.231646    0.050425    0.008381    0.678390    
#> 498: 0.412585    1.111719    3.504381    0.231854    0.050410    0.008385    0.678311    
#> 499: 0.412549    1.111769    3.504334    0.231767    0.050422    0.008386    0.678256    
#> 500: 0.412598    1.111800    3.504308    0.231807    0.050400    0.008386    0.678202    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.323038    0.976496    3.441443    0.392401    0.081435    0.016800    1.647315    
#> 002: 0.456219    0.984498    3.480603    0.372781    0.077363    0.015960    1.148447    
#> 003: 0.562094    0.958317    3.484255    0.354142    0.073495    0.015162    0.971834    
#> 004: 0.555402    1.004539    3.483834    0.336435    0.069820    0.014404    0.871632    
#> 005: 0.655079    1.015776    3.477297    0.319613    0.066329    0.013684    0.840093    
#> 006: 0.614876    1.037318    3.462676    0.309109    0.063013    0.013000    0.800032    
#> 007: 0.537554    1.041296    3.457775    0.293654    0.059862    0.012350    0.822605    
#> 008: 0.557658    1.046243    3.449342    0.316491    0.056869    0.011732    0.831276    
#> 009: 0.538538    1.037987    3.448902    0.354041    0.054026    0.011146    0.838350    
#> 010: 0.546578    1.047572    3.444061    0.336339    0.051324    0.010588    0.862687    
#> 011: 0.603589    1.065960    3.451429    0.348275    0.048758    0.010059    0.845340    
#> 012: 0.601130    1.045106    3.450779    0.330861    0.046320    0.009556    0.804624    
#> 013: 0.555122    1.033693    3.448064    0.335817    0.044004    0.009314    0.804605    
#> 014: 0.600812    1.028926    3.460621    0.393662    0.041804    0.009219    0.831993    
#> 015: 0.597122    1.050297    3.471774    0.373979    0.039714    0.009333    0.816979    
#> 016: 0.609170    1.046983    3.484324    0.355280    0.037728    0.008866    0.822992    
#> 017: 0.599358    1.025982    3.480158    0.337516    0.035842    0.009965    0.810047    
#> 018: 0.648672    1.020655    3.470965    0.323990    0.034050    0.012158    0.831114    
#> 019: 0.606889    1.017802    3.474197    0.307790    0.032347    0.011550    0.818894    
#> 020: 0.631367    1.018172    3.483342    0.342035    0.030730    0.011876    0.807292    
#> 021: 0.645212    1.028614    3.487921    0.324933    0.029193    0.012185    0.783286    
#> 022: 0.628793    1.022921    3.492023    0.308686    0.027734    0.011575    0.787997    
#> 023: 0.673036    1.018317    3.494769    0.293252    0.026347    0.010997    0.824513    
#> 024: 0.648568    1.047035    3.490652    0.278589    0.025030    0.011505    0.833471    
#> 025: 0.619783    1.022352    3.480872    0.264660    0.027908    0.010930    0.811332    
#> 026: 0.598484    1.060698    3.474583    0.268814    0.026513    0.010826    0.805853    
#> 027: 0.577947    1.071683    3.458940    0.300865    0.025187    0.010543    0.803219    
#> 028: 0.636588    1.053271    3.467872    0.296043    0.023928    0.010016    0.806005    
#> 029: 0.622925    1.053551    3.458025    0.294304    0.022731    0.010229    0.827860    
#> 030: 0.587155    1.064067    3.457377    0.279589    0.021595    0.010971    0.832878    
#> 031: 0.541807    1.044125    3.467497    0.266387    0.020515    0.010422    0.825059    
#> 032: 0.556347    1.032855    3.469699    0.258205    0.019489    0.010839    0.830687    
#> 033: 0.582967    1.068823    3.457287    0.280574    0.018515    0.010370    0.817249    
#> 034: 0.591546    1.076209    3.456188    0.283480    0.017589    0.009852    0.822623    
#> 035: 0.545547    1.063665    3.453666    0.269306    0.016710    0.009809    0.796822    
#> 036: 0.554121    1.091395    3.448252    0.293233    0.017047    0.009319    0.803941    
#> 037: 0.551128    1.076153    3.456004    0.278571    0.019346    0.010754    0.817925    
#> 038: 0.582601    1.063745    3.455236    0.264643    0.018378    0.011225    0.797253    
#> 039: 0.594499    1.048134    3.467840    0.324081    0.017459    0.011124    0.803620    
#> 040: 0.581026    1.040628    3.478278    0.317341    0.016586    0.013893    0.801477    
#> 041: 0.558427    1.033306    3.468299    0.301474    0.015757    0.013325    0.811909    
#> 042: 0.612195    1.031459    3.467419    0.286400    0.017027    0.014520    0.801964    
#> 043: 0.593965    1.050064    3.455987    0.346374    0.017657    0.013794    0.807543    
#> 044: 0.559284    1.067753    3.457794    0.329056    0.016774    0.013104    0.816310    
#> 045: 0.539012    1.080204    3.441775    0.312603    0.015935    0.012741    0.812119    
#> 046: 0.575797    1.073726    3.440211    0.296973    0.015546    0.012104    0.819647    
#> 047: 0.601814    1.068839    3.443372    0.319652    0.018760    0.014076    0.808419    
#> 048: 0.548198    1.054817    3.440678    0.331694    0.023242    0.015390    0.815196    
#> 049: 0.601186    1.050019    3.459373    0.349860    0.022953    0.014620    0.829489    
#> 050: 0.655127    1.032908    3.477129    0.332367    0.021806    0.017443    0.850044    
#> 051: 0.615549    1.029925    3.491019    0.315748    0.022284    0.016571    0.840195    
#> 052: 0.603660    1.053816    3.484385    0.299961    0.021170    0.015742    0.829028    
#> 053: 0.644666    1.034127    3.482881    0.284963    0.020111    0.015009    0.838651    
#> 054: 0.569400    1.028181    3.484870    0.270715    0.019106    0.016214    0.815759    
#> 055: 0.582899    1.040603    3.469713    0.284678    0.019812    0.015873    0.795907    
#> 056: 0.622735    1.036455    3.480124    0.346905    0.018821    0.016962    0.809729    
#> 057: 0.623019    1.033562    3.482705    0.329560    0.020348    0.016114    0.825762    
#> 058: 0.668570    1.042878    3.472285    0.331621    0.019331    0.015308    0.832373    
#> 059: 0.645428    1.031326    3.465771    0.351843    0.020574    0.018018    0.843138    
#> 060: 0.648159    1.020971    3.493206    0.351170    0.020315    0.018412    0.807374    
#> 061: 0.686504    1.006389    3.506947    0.333611    0.019299    0.021856    0.837891    
#> 062: 0.642129    1.016191    3.501681    0.316931    0.022523    0.020763    0.831084    
#> 063: 0.664797    1.004807    3.488328    0.341480    0.021397    0.019725    0.828330    
#> 064: 0.666561    1.006773    3.501943    0.348145    0.020327    0.018739    0.833453    
#> 065: 0.664706    1.002593    3.485016    0.330738    0.022427    0.017892    0.821657    
#> 066: 0.668779    1.008625    3.493783    0.314201    0.021306    0.016998    0.821148    
#> 067: 0.666196    1.011390    3.489653    0.329060    0.020241    0.016148    0.832333    
#> 068: 0.592362    1.026648    3.491014    0.312607    0.019229    0.015340    0.850414    
#> 069: 0.571276    1.047882    3.461955    0.330564    0.018267    0.014573    0.832509    
#> 070: 0.593064    1.051778    3.477736    0.340055    0.018121    0.013845    0.815136    
#> 071: 0.590862    1.080412    3.462290    0.323908    0.017796    0.013152    0.843367    
#> 072: 0.526315    1.056203    3.453893    0.307713    0.022152    0.012495    0.819225    
#> 073: 0.602380    1.062685    3.471366    0.292327    0.021044    0.014024    0.817189    
#> 074: 0.587328    1.059828    3.480928    0.277711    0.019992    0.014225    0.804765    
#> 075: 0.623804    1.039501    3.499523    0.263825    0.023312    0.013513    0.805185    
#> 076: 0.623205    1.034029    3.504476    0.274691    0.023705    0.012838    0.813811    
#> 077: 0.668481    1.024599    3.486919    0.261880    0.022520    0.013576    0.808307    
#> 078: 0.660122    1.035395    3.496747    0.248786    0.021394    0.015970    0.817025    
#> 079: 0.679230    1.041943    3.500535    0.257427    0.021613    0.017431    0.822799    
#> 080: 0.658000    1.050746    3.490713    0.244556    0.020757    0.016717    0.828663    
#> 081: 0.656682    1.042269    3.495588    0.232328    0.021978    0.015881    0.811344    
#> 082: 0.642693    1.026700    3.496160    0.220712    0.020879    0.015087    0.838265    
#> 083: 0.615214    1.023731    3.498519    0.224265    0.019835    0.014332    0.842079    
#> 084: 0.605634    1.032977    3.478760    0.225848    0.018844    0.013616    0.837178    
#> 085: 0.596062    1.036331    3.474746    0.261297    0.017901    0.012935    0.840589    
#> 086: 0.600973    1.024838    3.472712    0.282799    0.017006    0.012288    0.831689    
#> 087: 0.571790    1.016976    3.460315    0.268659    0.016156    0.011674    0.833183    
#> 088: 0.532555    1.012104    3.470827    0.292760    0.015348    0.014160    0.848045    
#> 089: 0.594431    1.027882    3.463321    0.314151    0.014581    0.013992    0.828376    
#> 090: 0.596277    1.035806    3.464138    0.304891    0.013852    0.013292    0.817053    
#> 091: 0.598664    1.029621    3.454240    0.289646    0.013159    0.013499    0.819329    
#> 092: 0.576819    1.051433    3.453514    0.318101    0.014608    0.013992    0.793765    
#> 093: 0.559677    1.038147    3.450789    0.302196    0.013877    0.014067    0.813152    
#> 094: 0.543681    1.057688    3.441754    0.287086    0.013334    0.013622    0.810785    
#> 095: 0.576507    1.051538    3.463846    0.288306    0.013987    0.012941    0.823586    
#> 096: 0.537144    1.061805    3.458961    0.273891    0.017106    0.012294    0.824192    
#> 097: 0.577246    1.078133    3.460250    0.260196    0.016288    0.011679    0.822669    
#> 098: 0.561249    1.078559    3.468363    0.255820    0.015473    0.011095    0.869050    
#> 099: 0.541364    1.064647    3.450280    0.243029    0.015132    0.010540    0.848571    
#> 100: 0.553497    1.065119    3.453528    0.252408    0.014376    0.011031    0.830471    
#> 101: 0.537749    1.055765    3.442501    0.257293    0.013657    0.012033    0.801749    
#> 102: 0.535112    1.057889    3.431787    0.244428    0.012974    0.011431    0.826466    
#> 103: 0.585424    1.055421    3.458023    0.260155    0.012325    0.010860    0.820267    
#> 104: 0.584323    1.053399    3.470179    0.265338    0.013767    0.010317    0.831317    
#> 105: 0.563964    1.049867    3.464829    0.252071    0.014968    0.009801    0.824302    
#> 106: 0.586822    1.043105    3.460753    0.239468    0.016641    0.009311    0.843034    
#> 107: 0.622798    1.045270    3.464474    0.296880    0.016886    0.008845    0.860668    
#> 108: 0.607272    1.037675    3.449585    0.282036    0.016042    0.008403    0.858533    
#> 109: 0.587280    1.035729    3.472158    0.289937    0.023385    0.007983    0.836797    
#> 110: 0.593026    1.044918    3.448971    0.337348    0.025633    0.007584    0.826543    
#> 111: 0.605101    1.056113    3.456292    0.320481    0.024352    0.007205    0.816418    
#> 112: 0.559236    1.037502    3.447373    0.304457    0.027089    0.006844    0.825171    
#> 113: 0.616376    1.052921    3.464824    0.317697    0.027728    0.006502    0.794693    
#> 114: 0.622444    1.067094    3.460019    0.328091    0.034701    0.006177    0.799475    
#> 115: 0.635567    1.055622    3.458927    0.368169    0.035211    0.005868    0.812712    
#> 116: 0.631539    1.053713    3.465103    0.349761    0.033450    0.006543    0.814786    
#> 117: 0.606083    1.072972    3.476784    0.332273    0.031778    0.007963    0.805491    
#> 118: 0.653028    1.059542    3.479749    0.315659    0.030189    0.008777    0.810370    
#> 119: 0.646920    1.044875    3.482457    0.299876    0.035259    0.008668    0.822918    
#> 120: 0.617315    1.021418    3.474923    0.284882    0.033496    0.009181    0.822281    
#> 121: 0.616233    1.056465    3.470328    0.282159    0.031821    0.009435    0.815127    
#> 122: 0.619522    1.023616    3.481098    0.268051    0.030230    0.009450    0.826905    
#> 123: 0.656561    1.039032    3.480225    0.287447    0.028719    0.009096    0.818704    
#> 124: 0.633032    1.064718    3.468207    0.273074    0.027283    0.009046    0.817448    
#> 125: 0.643043    1.077024    3.458157    0.268566    0.025918    0.008593    0.828225    
#> 126: 0.562819    1.084482    3.449441    0.276187    0.024623    0.008444    0.845711    
#> 127: 0.587374    1.063357    3.439754    0.366217    0.023391    0.011216    0.824884    
#> 128: 0.579468    1.062949    3.464658    0.347906    0.025279    0.011606    0.815531    
#> 129: 0.629617    1.076145    3.462962    0.358220    0.026315    0.011025    0.811239    
#> 130: 0.648209    1.084691    3.459068    0.340309    0.024999    0.010588    0.803433    
#> 131: 0.590650    1.084575    3.443383    0.323294    0.023749    0.010146    0.818242    
#> 132: 0.556280    1.076929    3.441213    0.307129    0.022562    0.009639    0.799303    
#> 133: 0.572092    1.090491    3.443824    0.375741    0.023888    0.009157    0.822243    
#> 134: 0.609544    1.064581    3.458001    0.406896    0.022693    0.008699    0.805847    
#> 135: 0.616529    1.055208    3.464728    0.386551    0.028316    0.008436    0.804406    
#> 136: 0.590946    1.033107    3.461664    0.367223    0.029818    0.008014    0.787572    
#> 137: 0.605794    1.033888    3.459891    0.348862    0.028327    0.008421    0.800239    
#> 138: 0.576839    1.059847    3.455523    0.331419    0.026910    0.008000    0.815764    
#> 139: 0.602572    1.064729    3.464775    0.314848    0.025565    0.008720    0.811233    
#> 140: 0.618077    1.076598    3.462580    0.299106    0.024287    0.011196    0.816405    
#> 141: 0.570953    1.064244    3.469507    0.284150    0.024035    0.010636    0.804978    
#> 142: 0.610832    1.053071    3.477883    0.290069    0.031215    0.010105    0.797426    
#> 143: 0.594167    1.068522    3.475097    0.299386    0.029655    0.010298    0.815887    
#> 144: 0.678144    1.046085    3.492441    0.329630    0.028172    0.009783    0.796523    
#> 145: 0.621725    1.039585    3.473746    0.366666    0.026763    0.009992    0.794832    
#> 146: 0.607343    1.044757    3.486459    0.348333    0.025425    0.009493    0.820694    
#> 147: 0.592512    1.033301    3.473819    0.330916    0.024154    0.009018    0.800236    
#> 148: 0.617466    1.028368    3.484116    0.319987    0.022946    0.011614    0.801531    
#> 149: 0.603489    1.028243    3.477995    0.303988    0.021799    0.011171    0.836606    
#> 150: 0.627509    1.026114    3.472740    0.288788    0.020709    0.010613    0.814981    
#> 151: 0.597940    1.037291    3.466788    0.308768    0.019674    0.010604    0.819289    
#> 152: 0.589231    1.032185    3.477551    0.271743    0.018355    0.008431    0.818289    
#> 153: 0.622951    1.063374    3.481132    0.313070    0.019264    0.013723    0.816657    
#> 154: 0.638150    1.061984    3.479371    0.389560    0.020486    0.013025    0.809871    
#> 155: 0.603170    1.026170    3.470041    0.297772    0.013788    0.012004    0.818637    
#> 156: 0.602933    1.037253    3.477135    0.274502    0.015093    0.012077    0.828692    
#> 157: 0.614825    1.034832    3.483478    0.311966    0.017031    0.012263    0.820631    
#> 158: 0.652373    1.055653    3.477229    0.317748    0.016754    0.015212    0.804788    
#> 159: 0.589987    1.065770    3.476449    0.285602    0.015631    0.011682    0.826593    
#> 160: 0.649361    1.044381    3.484300    0.329928    0.016678    0.012897    0.829076    
#> 161: 0.607094    1.033104    3.476538    0.279423    0.020214    0.011972    0.841313    
#> 162: 0.612467    1.062539    3.456963    0.307741    0.015919    0.011800    0.810543    
#> 163: 0.601641    1.058977    3.456882    0.300821    0.012587    0.011972    0.819419    
#> 164: 0.631515    1.060871    3.469499    0.373424    0.011972    0.013385    0.810754    
#> 165: 0.646518    1.060378    3.477418    0.414437    0.011002    0.018265    0.794251    
#> 166: 0.636938    1.071506    3.478939    0.324150    0.009380    0.015534    0.810091    
#> 167: 0.621620    1.070086    3.470699    0.358334    0.008480    0.009471    0.817560    
#> 168: 0.643037    1.076738    3.478914    0.301338    0.010227    0.009835    0.808439    
#> 169: 0.606063    1.087623    3.460235    0.265398    0.011185    0.009539    0.833584    
#> 170: 0.599392    1.070753    3.466965    0.289552    0.011683    0.012072    0.824238    
#> 171: 0.607111    1.063941    3.475709    0.279031    0.010926    0.014746    0.812552    
#> 172: 0.590837    1.068187    3.467491    0.270655    0.010719    0.016075    0.809372    
#> 173: 0.566741    1.069615    3.443084    0.266670    0.012299    0.015403    0.822735    
#> 174: 0.556552    1.085027    3.453609    0.321403    0.016372    0.017000    0.833431    
#> 175: 0.552035    1.073867    3.441764    0.318769    0.017455    0.017247    0.824923    
#> 176: 0.543239    1.081301    3.453405    0.232346    0.015816    0.013718    0.812874    
#> 177: 0.532047    1.089913    3.458880    0.223799    0.013598    0.017174    0.813651    
#> 178: 0.577365    1.086183    3.456673    0.272399    0.014113    0.014306    0.795925    
#> 179: 0.603659    1.079388    3.465034    0.203755    0.020196    0.015156    0.823368    
#> 180: 0.554754    1.061686    3.465237    0.281665    0.020502    0.015298    0.822405    
#> 181: 0.581478    1.029921    3.451986    0.253943    0.021678    0.014068    0.808094    
#> 182: 0.559759    1.043115    3.445672    0.288344    0.022836    0.011991    0.811342    
#> 183: 0.570743    1.064220    3.439072    0.316477    0.018812    0.011135    0.816550    
#> 184: 0.575485    1.052142    3.445141    0.287229    0.019677    0.009862    0.817098    
#> 185: 0.545835    1.074790    3.444098    0.295369    0.016925    0.013720    0.821297    
#> 186: 0.533707    1.091583    3.445402    0.283880    0.015819    0.016670    0.818315    
#> 187: 0.570523    1.081935    3.453923    0.260546    0.013254    0.014927    0.828010    
#> 188: 0.553871    1.094896    3.448492    0.253227    0.014656    0.013458    0.851402    
#> 189: 0.589848    1.100384    3.455042    0.270121    0.017085    0.013006    0.863590    
#> 190: 0.582446    1.083822    3.466945    0.297017    0.015907    0.013404    0.843376    
#> 191: 0.549455    1.091798    3.451715    0.248134    0.014599    0.013269    0.841152    
#> 192: 0.541448    1.091978    3.453465    0.244421    0.012857    0.012099    0.832054    
#> 193: 0.584922    1.099728    3.454827    0.225708    0.012098    0.011016    0.838129    
#> 194: 0.560391    1.081207    3.450081    0.270919    0.014541    0.011232    0.858873    
#> 195: 0.553402    1.071150    3.444279    0.288577    0.013223    0.009960    0.832934    
#> 196: 0.572726    1.078534    3.452136    0.316899    0.016227    0.011088    0.818806    
#> 197: 0.543910    1.088436    3.467441    0.299236    0.013255    0.013591    0.818594    
#> 198: 0.596008    1.074028    3.468671    0.244051    0.015312    0.011372    0.812830    
#> 199: 0.583787    1.039238    3.473323    0.246954    0.014624    0.011916    0.798200    
#> 200: 0.602180    1.032965    3.480220    0.307487    0.012266    0.013794    0.807629    
#> 201: 0.603330    1.028958    3.483291    0.288307    0.011547    0.013738    0.811326    
#> 202: 0.599859    1.029268    3.483869    0.274304    0.011338    0.013639    0.815479    
#> 203: 0.613294    1.028204    3.482893    0.273704    0.011110    0.014310    0.819370    
#> 204: 0.619639    1.022075    3.482728    0.281867    0.011688    0.014177    0.822643    
#> 205: 0.617468    1.022098    3.484709    0.289211    0.011668    0.014837    0.825377    
#> 206: 0.621716    1.024313    3.486599    0.282633    0.011624    0.014993    0.832173    
#> 207: 0.617649    1.023363    3.485982    0.282805    0.011282    0.014981    0.830537    
#> 208: 0.617461    1.021141    3.485787    0.284571    0.010951    0.014972    0.828803    
#> 209: 0.621612    1.019412    3.485510    0.279467    0.010706    0.014837    0.828414    
#> 210: 0.624781    1.018852    3.486117    0.277333    0.010500    0.014675    0.826617    
#> 211: 0.627817    1.019979    3.487073    0.273360    0.010656    0.014572    0.825067    
#> 212: 0.628674    1.021171    3.487678    0.272525    0.010460    0.014834    0.825270    
#> 213: 0.631419    1.019250    3.488098    0.279285    0.010678    0.014613    0.827126    
#> 214: 0.633776    1.018360    3.488277    0.281042    0.010851    0.014407    0.827842    
#> 215: 0.634353    1.017512    3.489055    0.279600    0.010845    0.014426    0.829308    
#> 216: 0.635047    1.016500    3.489206    0.278372    0.010732    0.014496    0.829918    
#> 217: 0.636250    1.016778    3.489531    0.276086    0.010710    0.014545    0.830123    
#> 218: 0.636790    1.017826    3.489060    0.276376    0.010813    0.014545    0.829423    
#> 219: 0.637458    1.018857    3.487714    0.278204    0.010825    0.014395    0.829319    
#> 220: 0.635765    1.019521    3.487225    0.279004    0.010730    0.014353    0.829413    
#> 221: 0.633869    1.019949    3.486809    0.279321    0.010769    0.014343    0.829214    
#> 222: 0.634103    1.019641    3.486853    0.279350    0.010760    0.014328    0.829145    
#> 223: 0.635450    1.019978    3.486743    0.277165    0.010765    0.014276    0.828534    
#> 224: 0.637201    1.020600    3.486944    0.274785    0.010887    0.014269    0.827925    
#> 225: 0.637155    1.020148    3.487231    0.273404    0.010889    0.014288    0.827565    
#> 226: 0.636728    1.019584    3.486495    0.272721    0.010843    0.014335    0.827797    
#> 227: 0.634846    1.019485    3.486206    0.270521    0.010755    0.014366    0.827535    
#> 228: 0.633247    1.020404    3.485325    0.269948    0.010696    0.014372    0.827305    
#> 229: 0.631824    1.020442    3.484741    0.270004    0.010621    0.014448    0.826598    
#> 230: 0.632958    1.020499    3.484428    0.270655    0.010626    0.014467    0.825804    
#> 231: 0.633233    1.020829    3.484438    0.272175    0.010666    0.014510    0.825194    
#> 232: 0.631076    1.020883    3.484548    0.270486    0.010685    0.014547    0.824956    
#> 233: 0.630532    1.020303    3.484657    0.270087    0.010698    0.014544    0.825070    
#> 234: 0.629385    1.020368    3.484791    0.269262    0.010684    0.014546    0.825287    
#> 235: 0.629191    1.020605    3.484740    0.267994    0.010700    0.014598    0.825075    
#> 236: 0.629644    1.021227    3.484546    0.268030    0.010774    0.014608    0.825094    
#> 237: 0.630887    1.021352    3.484536    0.267422    0.010763    0.014656    0.824873    
#> 238: 0.631765    1.021562    3.484719    0.265172    0.010810    0.014637    0.825092    
#> 239: 0.631090    1.022207    3.484566    0.264059    0.010900    0.014639    0.825108    
#> 240: 0.631576    1.022291    3.484627    0.264116    0.010935    0.014606    0.824879    
#> 241: 0.631597    1.022432    3.484516    0.263622    0.010973    0.014557    0.824686    
#> 242: 0.631145    1.022179    3.484207    0.263918    0.011139    0.014560    0.824829    
#> 243: 0.630101    1.022623    3.484158    0.264814    0.011290    0.014539    0.824794    
#> 244: 0.629772    1.022751    3.484376    0.266148    0.011399    0.014599    0.825405    
#> 245: 0.629230    1.022861    3.484215    0.266817    0.011456    0.014645    0.825641    
#> 246: 0.628870    1.022749    3.484318    0.266817    0.011522    0.014745    0.825814    
#> 247: 0.629095    1.022430    3.484835    0.266647    0.011498    0.014769    0.825883    
#> 248: 0.628984    1.022502    3.484972    0.265936    0.011438    0.014808    0.825495    
#> 249: 0.629069    1.022617    3.485127    0.266258    0.011427    0.014842    0.825693    
#> 250: 0.629245    1.022860    3.485180    0.266180    0.011500    0.014913    0.825431    
#> 251: 0.628484    1.023121    3.485152    0.266449    0.011540    0.014948    0.825558    
#> 252: 0.628764    1.023458    3.485365    0.265674    0.011540    0.014991    0.825668    
#> 253: 0.628108    1.023890    3.485196    0.266129    0.011528    0.014977    0.825615    
#> 254: 0.627938    1.024433    3.485261    0.266015    0.011525    0.014949    0.825843    
#> 255: 0.627263    1.024536    3.485270    0.265885    0.011464    0.014978    0.826003    
#> 256: 0.627987    1.024376    3.485268    0.266914    0.011430    0.015055    0.825756    
#> 257: 0.627954    1.024117    3.485209    0.267626    0.011422    0.015031    0.825781    
#> 258: 0.628519    1.023942    3.485261    0.267716    0.011421    0.015004    0.825658    
#> 259: 0.628494    1.023832    3.485297    0.268279    0.011440    0.015004    0.825650    
#> 260: 0.628634    1.024009    3.485619    0.268788    0.011422    0.015004    0.825455    
#> 261: 0.629047    1.024110    3.485803    0.268297    0.011403    0.014990    0.825772    
#> 262: 0.628909    1.024136    3.485955    0.267910    0.011382    0.014942    0.826007    
#> 263: 0.628656    1.024343    3.485748    0.268660    0.011352    0.014954    0.825997    
#> 264: 0.628128    1.024735    3.485445    0.269412    0.011337    0.014936    0.826473    
#> 265: 0.627735    1.024990    3.485217    0.269483    0.011362    0.014916    0.826926    
#> 266: 0.628212    1.025489    3.485144    0.270191    0.011372    0.014927    0.827271    
#> 267: 0.627593    1.025805    3.485050    0.270446    0.011414    0.014890    0.827366    
#> 268: 0.627226    1.025930    3.484758    0.270580    0.011394    0.014831    0.827594    
#> 269: 0.627752    1.025978    3.484645    0.270757    0.011439    0.014812    0.827344    
#> 270: 0.628184    1.025948    3.484474    0.270594    0.011425    0.014776    0.827100    
#> 271: 0.627803    1.025850    3.484323    0.270979    0.011394    0.014810    0.827263    
#> 272: 0.627502    1.025908    3.484073    0.272105    0.011405    0.014787    0.827119    
#> 273: 0.627558    1.026271    3.483890    0.272148    0.011489    0.014795    0.827055    
#> 274: 0.627091    1.026611    3.483800    0.272413    0.011515    0.014760    0.826892    
#> 275: 0.626694    1.026737    3.483590    0.272544    0.011539    0.014725    0.826632    
#> 276: 0.626293    1.026917    3.483587    0.272692    0.011578    0.014662    0.826980    
#> 277: 0.625596    1.027101    3.483459    0.272615    0.011614    0.014608    0.827029    
#> 278: 0.625402    1.027263    3.483511    0.272047    0.011625    0.014571    0.826987    
#> 279: 0.625417    1.027232    3.483590    0.271388    0.011634    0.014617    0.827188    
#> 280: 0.625717    1.027431    3.483748    0.270712    0.011628    0.014653    0.827052    
#> 281: 0.625446    1.027448    3.483879    0.270246    0.011599    0.014677    0.827061    
#> 282: 0.625703    1.027559    3.484063    0.269768    0.011551    0.014699    0.827130    
#> 283: 0.625716    1.027635    3.484209    0.269833    0.011496    0.014729    0.827469    
#> 284: 0.625857    1.027752    3.484235    0.269626    0.011456    0.014771    0.827238    
#> 285: 0.625820    1.027937    3.484036    0.269587    0.011421    0.014810    0.827421    
#> 286: 0.625937    1.027981    3.483932    0.269677    0.011453    0.014883    0.827629    
#> 287: 0.625815    1.028142    3.483773    0.269958    0.011458    0.014885    0.827718    
#> 288: 0.626053    1.028161    3.483748    0.269950    0.011477    0.014921    0.827738    
#> 289: 0.626248    1.028340    3.483659    0.270271    0.011466    0.014932    0.827764    
#> 290: 0.625977    1.028453    3.483517    0.269972    0.011476    0.014937    0.828080    
#> 291: 0.625768    1.028653    3.483462    0.269121    0.011503    0.014898    0.828113    
#> 292: 0.625172    1.028943    3.483348    0.269235    0.011523    0.014873    0.828000    
#> 293: 0.624828    1.029076    3.483143    0.269327    0.011499    0.014850    0.827708    
#> 294: 0.624458    1.029237    3.482921    0.269084    0.011486    0.014814    0.827705    
#> 295: 0.624517    1.029193    3.482851    0.269220    0.011472    0.014797    0.827673    
#> 296: 0.624509    1.029146    3.482817    0.269309    0.011494    0.014822    0.827708    
#> 297: 0.624751    1.029228    3.482792    0.269699    0.011509    0.014839    0.827620    
#> 298: 0.624783    1.029123    3.482782    0.270100    0.011491    0.014844    0.827485    
#> 299: 0.625161    1.029167    3.482760    0.270079    0.011470    0.014832    0.827583    
#> 300: 0.625300    1.029112    3.482873    0.270046    0.011439    0.014820    0.827474    
#> 301: 0.625465    1.028927    3.482864    0.269957    0.011417    0.014849    0.827427    
#> 302: 0.625327    1.028934    3.482748    0.269983    0.011415    0.014839    0.827367    
#> 303: 0.625109    1.028961    3.482728    0.269727    0.011372    0.014890    0.827364    
#> 304: 0.624914    1.029019    3.482556    0.269743    0.011343    0.014919    0.827311    
#> 305: 0.624618    1.029018    3.482419    0.269915    0.011334    0.014980    0.827158    
#> 306: 0.624328    1.029021    3.482365    0.270680    0.011319    0.015007    0.827029    
#> 307: 0.624265    1.028928    3.482343    0.271012    0.011317    0.014997    0.827162    
#> 308: 0.623886    1.028918    3.482257    0.271205    0.011307    0.014975    0.827238    
#> 309: 0.623855    1.028948    3.482138    0.271426    0.011309    0.015007    0.827324    
#> 310: 0.624018    1.028883    3.481940    0.271796    0.011333    0.014994    0.827405    
#> 311: 0.623856    1.028832    3.481903    0.272511    0.011340    0.015004    0.827183    
#> 312: 0.623521    1.028821    3.481744    0.272288    0.011354    0.015027    0.827001    
#> 313: 0.623599    1.028717    3.481809    0.271895    0.011355    0.015034    0.826995    
#> 314: 0.622952    1.028697    3.481705    0.271568    0.011331    0.015031    0.827185    
#> 315: 0.622544    1.028669    3.481617    0.271291    0.011312    0.015025    0.827296    
#> 316: 0.622484    1.028671    3.481535    0.271296    0.011292    0.014997    0.827354    
#> 317: 0.622465    1.028580    3.481594    0.271495    0.011290    0.015001    0.827524    
#> 318: 0.622343    1.028669    3.481443    0.271928    0.011278    0.015018    0.827378    
#> 319: 0.622630    1.028562    3.481455    0.271927    0.011261    0.015051    0.827387    
#> 320: 0.622131    1.028692    3.481278    0.272331    0.011255    0.015059    0.827417    
#> 321: 0.621863    1.028817    3.481097    0.272407    0.011234    0.015130    0.827563    
#> 322: 0.621497    1.028887    3.480857    0.272229    0.011196    0.015111    0.827691    
#> 323: 0.620664    1.028914    3.480745    0.272135    0.011171    0.015150    0.827850    
#> 324: 0.620685    1.028973    3.480732    0.271612    0.011167    0.015155    0.827795    
#> 325: 0.620496    1.029195    3.480649    0.271467    0.011188    0.015139    0.827696    
#> 326: 0.620551    1.029173    3.480637    0.271386    0.011225    0.015120    0.827589    
#> 327: 0.620620    1.029250    3.480705    0.271141    0.011256    0.015131    0.827385    
#> 328: 0.620639    1.029457    3.480661    0.271372    0.011268    0.015126    0.827220    
#> 329: 0.620603    1.029539    3.480631    0.271761    0.011273    0.015136    0.827033    
#> 330: 0.620179    1.029587    3.480610    0.271969    0.011283    0.015138    0.827147    
#> 331: 0.620260    1.029812    3.480604    0.272016    0.011278    0.015135    0.827159    
#> 332: 0.620267    1.029770    3.480662    0.272119    0.011254    0.015160    0.827240    
#> 333: 0.620257    1.029805    3.480594    0.272296    0.011232    0.015178    0.827176    
#> 334: 0.620007    1.029800    3.480446    0.272477    0.011218    0.015185    0.826915    
#> 335: 0.619763    1.029817    3.480266    0.272130    0.011215    0.015196    0.826831    
#> 336: 0.619247    1.029995    3.480172    0.271950    0.011235    0.015236    0.826863    
#> 337: 0.619001    1.030096    3.480088    0.271862    0.011243    0.015254    0.826781    
#> 338: 0.618969    1.030207    3.480069    0.271888    0.011251    0.015280    0.826591    
#> 339: 0.618911    1.030268    3.480053    0.271851    0.011229    0.015282    0.826405    
#> 340: 0.618781    1.030260    3.480101    0.271748    0.011237    0.015280    0.826222    
#> 341: 0.619081    1.030229    3.480206    0.271869    0.011238    0.015270    0.826135    
#> 342: 0.618905    1.030194    3.480191    0.271867    0.011217    0.015270    0.826108    
#> 343: 0.618802    1.030201    3.480192    0.272050    0.011187    0.015223    0.826040    
#> 344: 0.619077    1.030195    3.480297    0.272628    0.011182    0.015232    0.826059    
#> 345: 0.619621    1.030223    3.480403    0.273049    0.011164    0.015240    0.826041    
#> 346: 0.619537    1.030293    3.480313    0.273137    0.011156    0.015237    0.825930    
#> 347: 0.619545    1.030239    3.480194    0.272443    0.011161    0.015250    0.825983    
#> 348: 0.619068    1.030282    3.480079    0.272402    0.011159    0.015263    0.825997    
#> 349: 0.618892    1.030370    3.479992    0.272370    0.011149    0.015269    0.826028    
#> 350: 0.618541    1.030324    3.479957    0.271925    0.011120    0.015283    0.826026    
#> 351: 0.618365    1.030512    3.479829    0.271680    0.011101    0.015310    0.825979    
#> 352: 0.617693    1.030715    3.479715    0.271813    0.011114    0.015337    0.826101    
#> 353: 0.617517    1.030912    3.479572    0.271806    0.011129    0.015347    0.826108    
#> 354: 0.617355    1.031089    3.479447    0.271854    0.011121    0.015355    0.826067    
#> 355: 0.617757    1.031199    3.479430    0.272059    0.011135    0.015354    0.826129    
#> 356: 0.617850    1.031262    3.479440    0.272061    0.011164    0.015350    0.826071    
#> 357: 0.617892    1.031338    3.479384    0.272611    0.011170    0.015312    0.825981    
#> 358: 0.617907    1.031485    3.479350    0.272813    0.011202    0.015289    0.825869    
#> 359: 0.617789    1.031640    3.479292    0.273102    0.011216    0.015265    0.825782    
#> 360: 0.617452    1.031713    3.479119    0.272852    0.011234    0.015245    0.825667    
#> 361: 0.617067    1.031846    3.478988    0.273297    0.011252    0.015220    0.825622    
#> 362: 0.617068    1.031838    3.478958    0.273407    0.011244    0.015221    0.825498    
#> 363: 0.617066    1.031701    3.479004    0.273600    0.011227    0.015235    0.825400    
#> 364: 0.617378    1.031663    3.479068    0.273373    0.011205    0.015244    0.825423    
#> 365: 0.617308    1.031704    3.479082    0.273165    0.011200    0.015287    0.825551    
#> 366: 0.617531    1.031726    3.478983    0.273625    0.011173    0.015310    0.825602    
#> 367: 0.617438    1.031708    3.479057    0.273442    0.011155    0.015317    0.825643    
#> 368: 0.617823    1.031759    3.479077    0.273461    0.011136    0.015337    0.825614    
#> 369: 0.617864    1.031728    3.479070    0.273315    0.011123    0.015335    0.825730    
#> 370: 0.617627    1.031824    3.479032    0.273027    0.011129    0.015346    0.825596    
#> 371: 0.617333    1.031928    3.478889    0.272958    0.011135    0.015337    0.825496    
#> 372: 0.617031    1.032036    3.478770    0.272724    0.011149    0.015351    0.825408    
#> 373: 0.616691    1.032213    3.478632    0.272835    0.011158    0.015357    0.825333    
#> 374: 0.616537    1.032220    3.478479    0.272771    0.011169    0.015346    0.825271    
#> 375: 0.616460    1.032156    3.478458    0.272959    0.011171    0.015329    0.825261    
#> 376: 0.616271    1.032156    3.478435    0.272737    0.011164    0.015296    0.825244    
#> 377: 0.616168    1.032278    3.478393    0.272668    0.011182    0.015285    0.825100    
#> 378: 0.615949    1.032308    3.478282    0.272742    0.011186    0.015259    0.825107    
#> 379: 0.615664    1.032332    3.478204    0.272599    0.011185    0.015248    0.825016    
#> 380: 0.615354    1.032395    3.478076    0.272355    0.011203    0.015231    0.824998    
#> 381: 0.615193    1.032345    3.478054    0.272451    0.011203    0.015237    0.824923    
#> 382: 0.615154    1.032296    3.478032    0.272276    0.011197    0.015243    0.824815    
#> 383: 0.615255    1.032245    3.478049    0.272270    0.011194    0.015226    0.824639    
#> 384: 0.614897    1.032234    3.478071    0.272152    0.011181    0.015210    0.824608    
#> 385: 0.614988    1.032204    3.478085    0.271989    0.011173    0.015208    0.824599    
#> 386: 0.615132    1.032279    3.478181    0.271843    0.011174    0.015213    0.824531    
#> 387: 0.615404    1.032318    3.478283    0.271860    0.011164    0.015227    0.824510    
#> 388: 0.615500    1.032320    3.478327    0.271519    0.011170    0.015227    0.824507    
#> 389: 0.615424    1.032230    3.478280    0.271505    0.011181    0.015230    0.824516    
#> 390: 0.615314    1.032210    3.478251    0.271873    0.011167    0.015248    0.824422    
#> 391: 0.615354    1.032192    3.478222    0.272052    0.011151    0.015235    0.824330    
#> 392: 0.615535    1.032168    3.478281    0.271679    0.011144    0.015234    0.824300    
#> 393: 0.615527    1.032147    3.478251    0.271413    0.011141    0.015224    0.824265    
#> 394: 0.615485    1.032158    3.478220    0.271406    0.011123    0.015204    0.824287    
#> 395: 0.615747    1.032162    3.478258    0.271576    0.011110    0.015188    0.824252    
#> 396: 0.616022    1.032212    3.478341    0.271526    0.011119    0.015177    0.824164    
#> 397: 0.616270    1.032082    3.478458    0.271614    0.011138    0.015182    0.824172    
#> 398: 0.616443    1.031972    3.478535    0.271726    0.011141    0.015188    0.824149    
#> 399: 0.616554    1.031950    3.478596    0.271560    0.011155    0.015183    0.824204    
#> 400: 0.616602    1.032061    3.478659    0.271427    0.011177    0.015187    0.824172    
#> 401: 0.616621    1.032209    3.478642    0.271377    0.011206    0.015193    0.824173    
#> 402: 0.616625    1.032281    3.478651    0.271034    0.011205    0.015213    0.824190    
#> 403: 0.616765    1.032310    3.478619    0.270922    0.011213    0.015210    0.824235    
#> 404: 0.616904    1.032366    3.478608    0.270878    0.011213    0.015223    0.824144    
#> 405: 0.616839    1.032446    3.478603    0.270958    0.011222    0.015236    0.824186    
#> 406: 0.616974    1.032594    3.478562    0.271045    0.011231    0.015264    0.824152    
#> 407: 0.617040    1.032710    3.478640    0.271017    0.011225    0.015272    0.824164    
#> 408: 0.617032    1.032790    3.478651    0.270757    0.011216    0.015276    0.824217    
#> 409: 0.616959    1.032785    3.478612    0.270532    0.011220    0.015284    0.824138    
#> 410: 0.616687    1.032800    3.478497    0.270247    0.011217    0.015285    0.824065    
#> 411: 0.616767    1.032688    3.478462    0.269981    0.011225    0.015278    0.824078    
#> 412: 0.616664    1.032681    3.478387    0.270073    0.011229    0.015269    0.823998    
#> 413: 0.616504    1.032729    3.478302    0.270342    0.011239    0.015266    0.823913    
#> 414: 0.616222    1.032774    3.478277    0.270518    0.011236    0.015262    0.823815    
#> 415: 0.616246    1.032802    3.478234    0.270480    0.011219    0.015261    0.823819    
#> 416: 0.616341    1.032802    3.478264    0.270542    0.011200    0.015261    0.823807    
#> 417: 0.616330    1.032709    3.478256    0.270459    0.011203    0.015260    0.823826    
#> 418: 0.616199    1.032643    3.478261    0.270654    0.011208    0.015245    0.823795    
#> 419: 0.616230    1.032733    3.478253    0.270607    0.011209    0.015248    0.823854    
#> 420: 0.616330    1.032815    3.478280    0.270640    0.011216    0.015230    0.823816    
#> 421: 0.616136    1.032879    3.478320    0.270568    0.011218    0.015219    0.823802    
#> 422: 0.616392    1.032841    3.478360    0.270534    0.011215    0.015214    0.823751    
#> 423: 0.616542    1.032782    3.478378    0.270459    0.011218    0.015219    0.823750    
#> 424: 0.616411    1.032733    3.478313    0.270384    0.011221    0.015207    0.823809    
#> 425: 0.616551    1.032745    3.478296    0.270183    0.011243    0.015201    0.823940    
#> 426: 0.616416    1.032782    3.478263    0.270106    0.011256    0.015206    0.823868    
#> 427: 0.616340    1.032744    3.478265    0.270037    0.011253    0.015209    0.823794    
#> 428: 0.616132    1.032765    3.478268    0.270013    0.011243    0.015220    0.823875    
#> 429: 0.616132    1.032825    3.478244    0.269981    0.011238    0.015212    0.823961    
#> 430: 0.616003    1.032862    3.478222    0.270092    0.011250    0.015206    0.823937    
#> 431: 0.615879    1.032970    3.478154    0.270032    0.011249    0.015195    0.823921    
#> 432: 0.615936    1.033080    3.478171    0.269964    0.011249    0.015203    0.823889    
#> 433: 0.615871    1.033179    3.478112    0.270142    0.011247    0.015222    0.823919    
#> 434: 0.615766    1.033182    3.478129    0.270127    0.011245    0.015238    0.823859    
#> 435: 0.615896    1.033234    3.478129    0.270022    0.011240    0.015224    0.823914    
#> 436: 0.616024    1.033185    3.478207    0.269908    0.011247    0.015218    0.823941    
#> 437: 0.616176    1.033192    3.478234    0.270181    0.011247    0.015230    0.823946    
#> 438: 0.616248    1.033306    3.478206    0.270473    0.011247    0.015228    0.823949    
#> 439: 0.616446    1.033311    3.478191    0.270549    0.011254    0.015206    0.823947    
#> 440: 0.616440    1.033347    3.478193    0.270437    0.011262    0.015186    0.823940    
#> 441: 0.616323    1.033301    3.478184    0.270319    0.011280    0.015165    0.823872    
#> 442: 0.616119    1.033328    3.478143    0.270269    0.011288    0.015144    0.823813    
#> 443: 0.616020    1.033444    3.478062    0.270135    0.011292    0.015121    0.823859    
#> 444: 0.615882    1.033440    3.478023    0.269718    0.011314    0.015107    0.823851    
#> 445: 0.615828    1.033429    3.477988    0.269368    0.011341    0.015114    0.823870    
#> 446: 0.615698    1.033458    3.477955    0.269269    0.011379    0.015112    0.823760    
#> 447: 0.615849    1.033487    3.477939    0.269180    0.011408    0.015114    0.823657    
#> 448: 0.615729    1.033478    3.477955    0.269057    0.011426    0.015105    0.823609    
#> 449: 0.615694    1.033502    3.478049    0.268962    0.011441    0.015102    0.823653    
#> 450: 0.615640    1.033537    3.478045    0.268907    0.011439    0.015094    0.823727    
#> 451: 0.615554    1.033640    3.478036    0.268858    0.011449    0.015095    0.823820    
#> 452: 0.615361    1.033768    3.477956    0.268875    0.011460    0.015085    0.823783    
#> 453: 0.615185    1.033859    3.477886    0.268852    0.011468    0.015084    0.823706    
#> 454: 0.615058    1.033963    3.477807    0.268725    0.011471    0.015089    0.823615    
#> 455: 0.614954    1.034006    3.477754    0.268465    0.011465    0.015098    0.823628    
#> 456: 0.614809    1.034033    3.477732    0.268491    0.011456    0.015102    0.823645    
#> 457: 0.614650    1.034046    3.477679    0.268640    0.011449    0.015088    0.823668    
#> 458: 0.614554    1.034162    3.477686    0.268741    0.011462    0.015090    0.823679    
#> 459: 0.614536    1.034282    3.477707    0.268630    0.011469    0.015090    0.823758    
#> 460: 0.614507    1.034272    3.477699    0.268595    0.011482    0.015102    0.823756    
#> 461: 0.614459    1.034338    3.477724    0.268421    0.011482    0.015114    0.823759    
#> 462: 0.614318    1.034440    3.477731    0.268477    0.011496    0.015114    0.823717    
#> 463: 0.614505    1.034487    3.477775    0.268687    0.011493    0.015101    0.823691    
#> 464: 0.614609    1.034522    3.477795    0.268594    0.011490    0.015089    0.823620    
#> 465: 0.614538    1.034473    3.477829    0.268533    0.011490    0.015087    0.823639    
#> 466: 0.614693    1.034485    3.477859    0.268550    0.011490    0.015087    0.823581    
#> 467: 0.614672    1.034504    3.477892    0.268645    0.011495    0.015082    0.823490    
#> 468: 0.614853    1.034517    3.477967    0.268896    0.011496    0.015084    0.823522    
#> 469: 0.614907    1.034557    3.478005    0.268759    0.011499    0.015093    0.823547    
#> 470: 0.614864    1.034615    3.478004    0.268420    0.011507    0.015093    0.823535    
#> 471: 0.614855    1.034638    3.477992    0.268263    0.011510    0.015088    0.823510    
#> 472: 0.614901    1.034577    3.478029    0.268111    0.011510    0.015087    0.823516    
#> 473: 0.614725    1.034558    3.478000    0.267868    0.011509    0.015083    0.823562    
#> 474: 0.614686    1.034511    3.478008    0.267614    0.011507    0.015087    0.823655    
#> 475: 0.614841    1.034555    3.478001    0.267404    0.011504    0.015080    0.823698    
#> 476: 0.614875    1.034544    3.478006    0.267359    0.011512    0.015089    0.823708    
#> 477: 0.615000    1.034510    3.478042    0.267354    0.011504    0.015088    0.823609    
#> 478: 0.614942    1.034464    3.478048    0.267213    0.011500    0.015096    0.823628    
#> 479: 0.614964    1.034440    3.478051    0.266986    0.011502    0.015091    0.823667    
#> 480: 0.615023    1.034473    3.478073    0.266999    0.011510    0.015101    0.823744    
#> 481: 0.614756    1.034541    3.478009    0.266948    0.011508    0.015109    0.823835    
#> 482: 0.614705    1.034523    3.477907    0.266881    0.011500    0.015105    0.823869    
#> 483: 0.614553    1.034531    3.477845    0.266758    0.011493    0.015100    0.823904    
#> 484: 0.614378    1.034453    3.477792    0.266655    0.011494    0.015099    0.823956    
#> 485: 0.614370    1.034472    3.477798    0.266520    0.011492    0.015102    0.823970    
#> 486: 0.614220    1.034519    3.477793    0.266346    0.011499    0.015094    0.823933    
#> 487: 0.614415    1.034530    3.477843    0.266246    0.011514    0.015087    0.823837    
#> 488: 0.614434    1.034479    3.477877    0.266012    0.011517    0.015080    0.823775    
#> 489: 0.614464    1.034435    3.477853    0.265903    0.011523    0.015085    0.823798    
#> 490: 0.614634    1.034467    3.477895    0.265955    0.011524    0.015086    0.823840    
#> 491: 0.614731    1.034533    3.477978    0.265951    0.011537    0.015101    0.823817    
#> 492: 0.614799    1.034589    3.478001    0.265855    0.011556    0.015106    0.823841    
#> 493: 0.614691    1.034641    3.477989    0.265972    0.011575    0.015098    0.823847    
#> 494: 0.614777    1.034706    3.477945    0.266073    0.011588    0.015083    0.823809    
#> 495: 0.614901    1.034746    3.477962    0.266054    0.011590    0.015092    0.823725    
#> 496: 0.615016    1.034844    3.477883    0.266130    0.011597    0.015103    0.823652    
#> 497: 0.614941    1.034864    3.477883    0.266116    0.011599    0.015113    0.823646    
#> 498: 0.614988    1.034853    3.477863    0.266162    0.011595    0.015107    0.823558    
#> 499: 0.614998    1.034864    3.477823    0.266139    0.011602    0.015097    0.823474    
#> 500: 0.615012    1.034850    3.477793    0.266026    0.011606    0.015090    0.823405    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.333750    0.988652    3.445490    0.392401    0.087616    0.016800    1.713901    
#> 002: 0.541515    1.052522    3.475230    0.372781    0.083235    0.015960    1.146129    
#> 003: 0.763358    1.034584    3.501819    0.354142    0.079073    0.015162    0.827514    
#> 004: 0.726870    1.093074    3.510485    0.336435    0.075119    0.014404    0.725363    
#> 005: 0.784599    1.104615    3.505815    0.319613    0.071363    0.013684    0.669737    
#> 006: 0.752177    1.106005    3.512804    0.303633    0.075969    0.013000    0.631875    
#> 007: 0.751661    1.100514    3.519120    0.288451    0.072170    0.012350    0.660693    
#> 008: 0.740948    1.090319    3.512068    0.274029    0.068562    0.013816    0.668267    
#> 009: 0.730535    1.065861    3.503950    0.260327    0.065134    0.013125    0.657505    
#> 010: 0.752463    1.066056    3.511831    0.247311    0.061877    0.013103    0.655590    
#> 011: 0.801974    1.075482    3.515492    0.234945    0.058783    0.012876    0.662368    
#> 012: 0.789657    1.064317    3.519368    0.223198    0.064238    0.012233    0.646107    
#> 013: 0.770786    1.063540    3.520389    0.212038    0.061027    0.011621    0.646407    
#> 014: 0.808369    1.063353    3.531220    0.212141    0.069997    0.011040    0.647137    
#> 015: 0.791739    1.067723    3.531043    0.225102    0.066498    0.011871    0.628795    
#> 016: 0.797730    1.079891    3.538133    0.213847    0.063173    0.016075    0.650563    
#> 017: 0.802649    1.091818    3.531010    0.218366    0.072394    0.015271    0.632751    
#> 018: 0.806833    1.081833    3.521356    0.257114    0.079739    0.014743    0.646879    
#> 019: 0.759412    1.086851    3.525471    0.244258    0.075752    0.014006    0.650906    
#> 020: 0.786974    1.075504    3.532371    0.232045    0.071965    0.013306    0.652941    
#> 021: 0.784619    1.073390    3.533980    0.220443    0.068367    0.012640    0.651419    
#> 022: 0.802335    1.073743    3.537980    0.239194    0.064948    0.012008    0.650079    
#> 023: 0.851637    1.070902    3.544532    0.234723    0.067285    0.013797    0.665709    
#> 024: 0.857544    1.078593    3.544957    0.222986    0.063921    0.013107    0.664131    
#> 025: 0.842875    1.048801    3.545146    0.211837    0.067738    0.012451    0.685332    
#> 026: 0.801878    1.092219    3.523940    0.201245    0.064351    0.011829    0.653429    
#> 027: 0.802227    1.086654    3.522244    0.220552    0.061134    0.013021    0.661053    
#> 028: 0.816565    1.094889    3.528572    0.270337    0.058077    0.012370    0.634776    
#> 029: 0.796015    1.087546    3.517043    0.256820    0.058570    0.011752    0.660713    
#> 030: 0.817711    1.091731    3.520183    0.253779    0.055642    0.011164    0.641692    
#> 031: 0.809588    1.071117    3.539831    0.241090    0.056259    0.012390    0.636035    
#> 032: 0.815307    1.056873    3.543248    0.229036    0.053446    0.012123    0.627457    
#> 033: 0.802960    1.080116    3.522320    0.262728    0.055318    0.011620    0.652072    
#> 034: 0.833760    1.088359    3.532394    0.254471    0.052552    0.011039    0.650381    
#> 035: 0.813310    1.070183    3.522235    0.265491    0.049925    0.010487    0.640548    
#> 036: 0.782583    1.078615    3.521081    0.252216    0.053544    0.010773    0.653286    
#> 037: 0.779705    1.088470    3.525404    0.258285    0.050866    0.010638    0.661791    
#> 038: 0.836196    1.078832    3.519510    0.335886    0.061519    0.011024    0.647478    
#> 039: 0.844218    1.059432    3.533384    0.319091    0.068456    0.010473    0.642931    
#> 040: 0.807289    1.068337    3.535367    0.303137    0.065033    0.009949    0.642229    
#> 041: 0.795726    1.065370    3.533817    0.287980    0.061782    0.009452    0.645730    
#> 042: 0.832301    1.080238    3.527650    0.273581    0.058693    0.008979    0.630973    
#> 043: 0.790056    1.081156    3.514189    0.263378    0.062601    0.008530    0.632809    
#> 044: 0.754668    1.103648    3.510648    0.250209    0.063914    0.008606    0.628282    
#> 045: 0.772398    1.109476    3.508583    0.253792    0.061664    0.009164    0.626760    
#> 046: 0.784655    1.088901    3.519043    0.241103    0.058581    0.009241    0.635175    
#> 047: 0.795219    1.099131    3.511949    0.229048    0.064443    0.008900    0.632355    
#> 048: 0.803057    1.088210    3.518485    0.229488    0.063002    0.008455    0.643724    
#> 049: 0.787932    1.082575    3.529008    0.218014    0.062335    0.009043    0.651711    
#> 050: 0.849755    1.059508    3.528877    0.232391    0.068791    0.009605    0.675951    
#> 051: 0.806914    1.062664    3.521615    0.267569    0.065351    0.009125    0.668001    
#> 052: 0.821248    1.071637    3.525477    0.298799    0.062084    0.008669    0.651330    
#> 053: 0.821054    1.073065    3.526816    0.283859    0.068423    0.008235    0.651928    
#> 054: 0.752393    1.068171    3.531109    0.269666    0.067531    0.009018    0.653537    
#> 055: 0.767499    1.075673    3.525100    0.256182    0.064155    0.010091    0.640448    
#> 056: 0.794043    1.066729    3.525097    0.256254    0.074793    0.009763    0.642221    
#> 057: 0.789995    1.073895    3.529493    0.286757    0.071053    0.009475    0.645177    
#> 058: 0.796444    1.071729    3.524706    0.282466    0.067500    0.010352    0.657252    
#> 059: 0.839041    1.041990    3.538577    0.284486    0.064125    0.012169    0.656573    
#> 060: 0.805963    1.048572    3.539462    0.286508    0.070039    0.013893    0.663660    
#> 061: 0.885840    1.081859    3.535841    0.341708    0.080157    0.013198    0.671322    
#> 062: 0.825509    1.095904    3.539225    0.324622    0.076149    0.012538    0.676034    
#> 063: 0.830497    1.060606    3.534422    0.308391    0.072342    0.012670    0.675878    
#> 064: 0.837649    1.079004    3.535766    0.292972    0.078574    0.012037    0.667228    
#> 065: 0.833178    1.057025    3.532075    0.278323    0.074646    0.011435    0.658753    
#> 066: 0.824247    1.088654    3.530866    0.264407    0.070913    0.010863    0.660874    
#> 067: 0.785549    1.075300    3.513878    0.251187    0.067368    0.010320    0.647443    
#> 068: 0.747113    1.092604    3.519229    0.238627    0.073705    0.009804    0.653075    
#> 069: 0.758986    1.105421    3.514780    0.269974    0.072640    0.011303    0.646388    
#> 070: 0.810944    1.094301    3.533402    0.272643    0.075113    0.014011    0.632345    
#> 071: 0.795414    1.101966    3.509590    0.262897    0.071358    0.013311    0.651213    
#> 072: 0.754944    1.075633    3.512446    0.267697    0.067790    0.012645    0.648262    
#> 073: 0.813192    1.098750    3.525376    0.291250    0.064400    0.012013    0.646384    
#> 074: 0.801121    1.069323    3.524267    0.294766    0.068377    0.011412    0.649617    
#> 075: 0.814197    1.066929    3.546370    0.280028    0.064958    0.010842    0.658132    
#> 076: 0.828190    1.080980    3.553119    0.266027    0.061710    0.010300    0.665437    
#> 077: 0.886562    1.061001    3.548129    0.282766    0.058624    0.009785    0.668362    
#> 078: 0.852544    1.059468    3.548547    0.268628    0.057560    0.009295    0.645063    
#> 079: 0.839471    1.059209    3.540641    0.286382    0.073858    0.008831    0.664679    
#> 080: 0.861646    1.060462    3.536770    0.340746    0.072190    0.009623    0.656276    
#> 081: 0.847344    1.077205    3.526612    0.327138    0.068580    0.012265    0.639347    
#> 082: 0.831002    1.061791    3.533450    0.310782    0.065151    0.011652    0.645710    
#> 083: 0.832955    1.077731    3.524495    0.295242    0.061894    0.011069    0.665311    
#> 084: 0.828975    1.076404    3.522450    0.280480    0.066171    0.010516    0.641241    
#> 085: 0.808882    1.078284    3.532775    0.287373    0.062863    0.010935    0.640894    
#> 086: 0.814408    1.074864    3.526121    0.273004    0.059720    0.010597    0.649345    
#> 087: 0.788087    1.079765    3.511502    0.261184    0.056734    0.010067    0.639706    
#> 088: 0.755069    1.075240    3.519404    0.248125    0.055239    0.009563    0.647613    
#> 089: 0.777115    1.089324    3.510127    0.235719    0.060991    0.010030    0.647402    
#> 090: 0.768039    1.083933    3.510516    0.265318    0.057941    0.009742    0.641519    
#> 091: 0.766228    1.077852    3.504153    0.287770    0.055152    0.010627    0.626295    
#> 092: 0.769572    1.095919    3.503797    0.275356    0.053987    0.012011    0.631400    
#> 093: 0.760871    1.083677    3.507948    0.261588    0.056893    0.011559    0.647079    
#> 094: 0.752885    1.124645    3.501134    0.248509    0.063060    0.010981    0.646317    
#> 095: 0.776640    1.104291    3.515541    0.236083    0.067113    0.010432    0.653583    
#> 096: 0.746884    1.097788    3.514802    0.250436    0.063757    0.011444    0.657607    
#> 097: 0.779125    1.097596    3.514062    0.237914    0.060569    0.010872    0.646781    
#> 098: 0.817980    1.104814    3.522523    0.254969    0.057541    0.010575    0.654487    
#> 099: 0.768071    1.082096    3.506565    0.295292    0.055801    0.010047    0.649954    
#> 100: 0.764119    1.076944    3.520084    0.280527    0.055900    0.009544    0.638962    
#> 101: 0.756415    1.056832    3.510905    0.266501    0.053105    0.009067    0.642015    
#> 102: 0.782353    1.067434    3.508994    0.253176    0.050450    0.009565    0.642972    
#> 103: 0.789367    1.084309    3.516677    0.290188    0.054123    0.009087    0.639008    
#> 104: 0.805493    1.084841    3.530223    0.283520    0.052599    0.008632    0.648240    
#> 105: 0.834295    1.057758    3.534830    0.269344    0.068881    0.008201    0.646186    
#> 106: 0.802162    1.073644    3.529189    0.255877    0.068436    0.007791    0.640396    
#> 107: 0.834020    1.075564    3.529149    0.265853    0.065014    0.007401    0.657414    
#> 108: 0.835164    1.084083    3.532319    0.252560    0.073672    0.007031    0.656029    
#> 109: 0.809660    1.075070    3.541885    0.247610    0.079505    0.006680    0.653149    
#> 110: 0.796563    1.065769    3.516774    0.262868    0.078585    0.006346    0.648402    
#> 111: 0.781573    1.094042    3.521192    0.249725    0.074656    0.006028    0.640622    
#> 112: 0.782573    1.073891    3.505788    0.253585    0.078778    0.005727    0.659781    
#> 113: 0.758348    1.110173    3.506567    0.240906    0.074839    0.005441    0.658447    
#> 114: 0.778023    1.109802    3.512437    0.228860    0.073561    0.005711    0.654304    
#> 115: 0.781182    1.065216    3.512893    0.217417    0.089452    0.006354    0.654055    
#> 116: 0.777394    1.092100    3.513347    0.232175    0.084980    0.007670    0.641333    
#> 117: 0.756562    1.100123    3.517932    0.220566    0.080731    0.008438    0.660437    
#> 118: 0.791754    1.090546    3.515585    0.218729    0.076694    0.008016    0.658732    
#> 119: 0.789619    1.101563    3.512708    0.339412    0.072859    0.009320    0.650776    
#> 120: 0.767823    1.097761    3.510152    0.325529    0.069216    0.008960    0.643341    
#> 121: 0.770813    1.111564    3.512113    0.309253    0.065756    0.009824    0.653583    
#> 122: 0.809147    1.083181    3.528453    0.293790    0.062468    0.010894    0.662371    
#> 123: 0.835506    1.106179    3.522612    0.279101    0.059344    0.010758    0.648878    
#> 124: 0.822883    1.127464    3.523276    0.271646    0.056377    0.010220    0.639367    
#> 125: 0.795206    1.106363    3.511803    0.258064    0.053558    0.009709    0.648917    
#> 126: 0.802928    1.112557    3.511512    0.245160    0.053952    0.009763    0.649570    
#> 127: 0.802017    1.098182    3.517654    0.232902    0.051255    0.009275    0.671095    
#> 128: 0.743564    1.096261    3.509271    0.221257    0.048692    0.010664    0.661549    
#> 129: 0.784971    1.103798    3.522400    0.227149    0.057986    0.010130    0.647074    
#> 130: 0.805591    1.125747    3.523359    0.215792    0.055086    0.010393    0.642900    
#> 131: 0.792765    1.084167    3.518233    0.210383    0.055831    0.010607    0.640157    
#> 132: 0.735539    1.096977    3.507633    0.199864    0.057532    0.010077    0.645647    
#> 133: 0.769079    1.087218    3.516841    0.207673    0.068481    0.010781    0.645584    
#> 134: 0.819187    1.058087    3.536635    0.205109    0.070973    0.010946    0.656457    
#> 135: 0.806365    1.052017    3.543135    0.194854    0.068138    0.011454    0.654856    
#> 136: 0.827855    1.036673    3.537390    0.206632    0.064731    0.010881    0.664311    
#> 137: 0.858067    1.039235    3.542783    0.244941    0.061495    0.011914    0.647460    
#> 138: 0.824576    1.068002    3.536830    0.239125    0.058420    0.011318    0.642069    
#> 139: 0.822917    1.068413    3.537329    0.237030    0.057454    0.010752    0.644046    
#> 140: 0.817052    1.084179    3.538850    0.234998    0.063329    0.011860    0.659816    
#> 141: 0.819449    1.073160    3.536387    0.280164    0.066976    0.012074    0.629882    
#> 142: 0.839937    1.054133    3.551757    0.266156    0.071825    0.011470    0.636943    
#> 143: 0.809507    1.084497    3.536927    0.255418    0.075026    0.010896    0.638600    
#> 144: 0.818465    1.080893    3.534935    0.242647    0.071275    0.010352    0.647459    
#> 145: 0.814321    1.080189    3.524862    0.230514    0.068460    0.009834    0.634329    
#> 146: 0.781049    1.091867    3.530736    0.233338    0.065037    0.009342    0.642762    
#> 147: 0.783483    1.078277    3.522645    0.221671    0.061785    0.011808    0.636585    
#> 148: 0.780407    1.086299    3.537291    0.210587    0.058696    0.013783    0.635799    
#> 149: 0.823905    1.068097    3.546953    0.243834    0.059564    0.015002    0.641053    
#> 150: 0.814064    1.058731    3.530019    0.275549    0.058801    0.014252    0.643649    
#> 151: 0.751915    1.086545    3.523026    0.261772    0.062274    0.013540    0.641075    
#> 152: 0.761626    1.089107    3.532535    0.201966    0.061474    0.011261    0.636971    
#> 153: 0.797100    1.106413    3.535436    0.256178    0.068668    0.012067    0.646129    
#> 154: 0.819214    1.091364    3.541937    0.219288    0.060416    0.013659    0.640872    
#> 155: 0.808301    1.063691    3.532550    0.236141    0.064765    0.010033    0.634140    
#> 156: 0.825657    1.078767    3.541830    0.229559    0.067105    0.008930    0.654839    
#> 157: 0.824906    1.070416    3.540829    0.204613    0.080169    0.009890    0.648741    
#> 158: 0.821346    1.086989    3.524280    0.212017    0.071144    0.007295    0.647788    
#> 159: 0.759704    1.103934    3.522796    0.197065    0.068152    0.006483    0.644152    
#> 160: 0.782525    1.064588    3.527929    0.254790    0.072802    0.008501    0.629399    
#> 161: 0.780251    1.069810    3.526343    0.199582    0.071449    0.007918    0.650258    
#> 162: 0.784204    1.097379    3.512760    0.232460    0.055614    0.008153    0.638710    
#> 163: 0.826735    1.082805    3.517330    0.288024    0.067845    0.008547    0.636314    
#> 164: 0.811009    1.077940    3.520245    0.251822    0.068176    0.008453    0.637864    
#> 165: 0.814307    1.071569    3.532953    0.221280    0.067483    0.008218    0.642785    
#> 166: 0.831898    1.103307    3.533837    0.267812    0.076594    0.007424    0.636095    
#> 167: 0.826519    1.100555    3.533121    0.216740    0.065006    0.007131    0.657352    
#> 168: 0.857781    1.087726    3.534210    0.252595    0.064815    0.008188    0.661300    
#> 169: 0.792304    1.117588    3.520336    0.267032    0.075062    0.008292    0.672159    
#> 170: 0.810643    1.092563    3.521118    0.220278    0.067422    0.008647    0.660051    
#> 171: 0.794270    1.092141    3.525304    0.238871    0.077932    0.007350    0.636831    
#> 172: 0.789513    1.110103    3.524744    0.248952    0.058213    0.009538    0.631785    
#> 173: 0.785730    1.100007    3.515740    0.221178    0.059076    0.008107    0.647027    
#> 174: 0.779899    1.103354    3.521757    0.238532    0.055523    0.008882    0.636980    
#> 175: 0.774557    1.092721    3.511943    0.239890    0.063223    0.007930    0.652229    
#> 176: 0.746710    1.105598    3.517188    0.222971    0.073028    0.007773    0.642247    
#> 177: 0.783192    1.104239    3.520236    0.257443    0.076389    0.006432    0.636068    
#> 178: 0.781127    1.089256    3.515694    0.228397    0.060483    0.006631    0.644714    
#> 179: 0.807088    1.098875    3.525418    0.215366    0.050719    0.009085    0.644970    
#> 180: 0.782503    1.093864    3.525230    0.194940    0.050464    0.010904    0.643974    
#> 181: 0.799339    1.088708    3.510981    0.189547    0.046138    0.010312    0.657664    
#> 182: 0.755227    1.093245    3.506672    0.200562    0.059046    0.008489    0.678086    
#> 183: 0.756589    1.111705    3.506716    0.200962    0.051293    0.005941    0.666265    
#> 184: 0.788284    1.080665    3.515449    0.215012    0.054012    0.007415    0.662058    
#> 185: 0.737519    1.115200    3.509696    0.209147    0.063997    0.007251    0.652565    
#> 186: 0.722442    1.144112    3.500252    0.210110    0.059416    0.008058    0.659515    
#> 187: 0.765695    1.102017    3.509490    0.255167    0.051213    0.009454    0.653791    
#> 188: 0.764773    1.121841    3.510929    0.268187    0.054034    0.010735    0.657875    
#> 189: 0.807579    1.129368    3.519595    0.250179    0.049784    0.010097    0.662441    
#> 190: 0.805142    1.099942    3.531692    0.245714    0.051417    0.007689    0.649994    
#> 191: 0.771774    1.087245    3.520414    0.194696    0.049517    0.007626    0.644014    
#> 192: 0.770496    1.107863    3.521559    0.182982    0.055256    0.008563    0.647844    
#> 193: 0.815524    1.099587    3.524064    0.198179    0.053850    0.007869    0.652215    
#> 194: 0.790125    1.081149    3.517527    0.193588    0.058724    0.010322    0.670786    
#> 195: 0.777586    1.083137    3.519882    0.188324    0.049403    0.009408    0.654904    
#> 196: 0.784209    1.076394    3.523399    0.204384    0.058924    0.008356    0.661438    
#> 197: 0.746562    1.098582    3.529783    0.199169    0.058703    0.007345    0.667598    
#> 198: 0.820405    1.084111    3.522771    0.257874    0.057820    0.009048    0.646797    
#> 199: 0.799858    1.072133    3.523081    0.236414    0.057208    0.008563    0.641316    
#> 200: 0.791628    1.066204    3.530318    0.220434    0.068429    0.008970    0.673422    
#> 201: 0.794469    1.061260    3.532539    0.218803    0.067982    0.008421    0.662289    
#> 202: 0.794560    1.063072    3.532816    0.207025    0.065162    0.009235    0.666762    
#> 203: 0.804458    1.061394    3.531923    0.209140    0.063512    0.009545    0.664456    
#> 204: 0.807714    1.061416    3.533187    0.207729    0.064300    0.009610    0.665078    
#> 205: 0.805899    1.069662    3.533499    0.209828    0.064625    0.009705    0.665769    
#> 206: 0.811539    1.074357    3.535202    0.211640    0.064134    0.009539    0.668877    
#> 207: 0.806148    1.074467    3.534259    0.211069    0.064005    0.009264    0.669151    
#> 208: 0.804241    1.075653    3.533777    0.208638    0.063447    0.009310    0.667132    
#> 209: 0.808731    1.075453    3.532844    0.212441    0.061583    0.009365    0.665657    
#> 210: 0.809981    1.073802    3.532506    0.214896    0.061670    0.009442    0.664328    
#> 211: 0.809371    1.074931    3.532419    0.218437    0.061368    0.009383    0.662059    
#> 212: 0.808030    1.073987    3.532655    0.219072    0.061327    0.009315    0.660926    
#> 213: 0.810993    1.072011    3.532861    0.219533    0.061070    0.009336    0.661352    
#> 214: 0.812724    1.072194    3.532572    0.221470    0.061831    0.009477    0.660497    
#> 215: 0.812874    1.072887    3.532430    0.222446    0.062318    0.009699    0.659846    
#> 216: 0.815817    1.071966    3.532485    0.224741    0.062331    0.009812    0.660628    
#> 217: 0.817512    1.073116    3.532386    0.225780    0.061633    0.009804    0.660702    
#> 218: 0.818400    1.073714    3.531881    0.226391    0.061545    0.009705    0.660007    
#> 219: 0.819329    1.072870    3.531246    0.228898    0.061455    0.009740    0.659192    
#> 220: 0.817277    1.074000    3.530785    0.229449    0.061412    0.009785    0.658143    
#> 221: 0.815830    1.074788    3.530481    0.228857    0.061279    0.009828    0.658088    
#> 222: 0.816862    1.074570    3.530585    0.231030    0.061028    0.009915    0.657859    
#> 223: 0.818872    1.075023    3.530729    0.231781    0.060676    0.009936    0.656994    
#> 224: 0.819805    1.076217    3.530972    0.232578    0.060649    0.009975    0.656470    
#> 225: 0.819589    1.075067    3.531235    0.233909    0.060773    0.009950    0.655867    
#> 226: 0.820561    1.073978    3.530961    0.234839    0.060885    0.009807    0.656170    
#> 227: 0.819309    1.074190    3.530577    0.237281    0.060926    0.009753    0.655652    
#> 228: 0.817019    1.075111    3.529425    0.237742    0.061034    0.009767    0.655229    
#> 229: 0.816449    1.074798    3.528754    0.239399    0.061023    0.009769    0.654958    
#> 230: 0.815553    1.074853    3.528064    0.238949    0.060707    0.009733    0.655108    
#> 231: 0.814799    1.075758    3.527982    0.238612    0.061012    0.009728    0.654571    
#> 232: 0.813597    1.076295    3.527990    0.238503    0.061201    0.009677    0.654040    
#> 233: 0.812438    1.076037    3.527934    0.239761    0.061362    0.009666    0.653969    
#> 234: 0.811671    1.076013    3.527930    0.240069    0.061724    0.009645    0.653667    
#> 235: 0.811411    1.075871    3.527722    0.241760    0.061674    0.009561    0.653417    
#> 236: 0.811767    1.076365    3.527617    0.241910    0.061831    0.009571    0.653383    
#> 237: 0.812778    1.076394    3.527579    0.241836    0.061861    0.009655    0.653671    
#> 238: 0.813242    1.076209    3.527798    0.241930    0.061954    0.009757    0.654229    
#> 239: 0.813712    1.076157    3.527967    0.242790    0.061884    0.009747    0.654076    
#> 240: 0.813932    1.076009    3.528115    0.242306    0.062004    0.009721    0.653580    
#> 241: 0.815231    1.075204    3.528442    0.243427    0.061744    0.009760    0.653563    
#> 242: 0.815407    1.074513    3.528608    0.243531    0.061690    0.009811    0.653645    
#> 243: 0.814690    1.074561    3.528595    0.243050    0.061518    0.009865    0.654031    
#> 244: 0.814257    1.074507    3.528718    0.242057    0.061395    0.009960    0.654245    
#> 245: 0.814403    1.074532    3.528762    0.241581    0.061079    0.010046    0.654380    
#> 246: 0.814656    1.074232    3.529136    0.240708    0.060676    0.010160    0.654505    
#> 247: 0.815302    1.074066    3.529386    0.242093    0.060183    0.010237    0.654416    
#> 248: 0.815863    1.074358    3.529425    0.242954    0.060052    0.010280    0.653944    
#> 249: 0.815319    1.074385    3.529397    0.243273    0.059857    0.010331    0.653962    
#> 250: 0.815985    1.074621    3.529485    0.244301    0.059479    0.010386    0.653727    
#> 251: 0.816333    1.074994    3.529701    0.244478    0.059154    0.010398    0.653809    
#> 252: 0.817111    1.074965    3.529973    0.244942    0.059061    0.010400    0.653604    
#> 253: 0.817502    1.075184    3.529973    0.244736    0.059081    0.010431    0.653710    
#> 254: 0.817767    1.075928    3.529910    0.244928    0.059041    0.010464    0.653617    
#> 255: 0.817601    1.076378    3.530001    0.244322    0.059194    0.010527    0.653581    
#> 256: 0.817359    1.076374    3.529814    0.244416    0.059091    0.010609    0.653711    
#> 257: 0.816680    1.076221    3.529697    0.244165    0.058994    0.010627    0.653999    
#> 258: 0.816464    1.075835    3.529523    0.243757    0.059159    0.010592    0.654084    
#> 259: 0.815635    1.075938    3.529361    0.243660    0.059290    0.010560    0.654056    
#> 260: 0.815385    1.076224    3.529352    0.243131    0.059345    0.010534    0.653769    
#> 261: 0.815417    1.076034    3.529466    0.242930    0.059227    0.010521    0.653664    
#> 262: 0.815538    1.075961    3.529647    0.242582    0.059205    0.010516    0.653605    
#> 263: 0.814983    1.076227    3.529680    0.242676    0.059211    0.010546    0.653420    
#> 264: 0.814815    1.076399    3.529572    0.242946    0.059142    0.010529    0.653588    
#> 265: 0.815258    1.076571    3.529647    0.242687    0.059092    0.010529    0.653842    
#> 266: 0.815486    1.076911    3.529660    0.242603    0.059020    0.010546    0.653972    
#> 267: 0.816019    1.077033    3.529889    0.243414    0.059012    0.010559    0.653894    
#> 268: 0.816032    1.076963    3.529825    0.243917    0.059090    0.010571    0.653813    
#> 269: 0.816689    1.076950    3.529850    0.243841    0.059120    0.010550    0.653812    
#> 270: 0.817125    1.077026    3.529780    0.244632    0.059041    0.010520    0.653646    
#> 271: 0.817047    1.077082    3.529650    0.245278    0.058891    0.010497    0.653675    
#> 272: 0.817018    1.076930    3.529558    0.245375    0.058789    0.010479    0.653959    
#> 273: 0.816554    1.077228    3.529464    0.245093    0.058799    0.010450    0.654158    
#> 274: 0.816139    1.077469    3.529440    0.244632    0.058799    0.010451    0.654203    
#> 275: 0.815668    1.077763    3.529275    0.244163    0.058711    0.010453    0.654212    
#> 276: 0.815081    1.077991    3.529350    0.244308    0.058620    0.010487    0.654344    
#> 277: 0.814614    1.078244    3.529431    0.244085    0.058684    0.010493    0.654366    
#> 278: 0.814209    1.078359    3.529461    0.244396    0.058705    0.010470    0.654255    
#> 279: 0.813668    1.078283    3.529311    0.244961    0.058785    0.010487    0.654197    
#> 280: 0.813212    1.078747    3.529190    0.245224    0.058828    0.010479    0.654057    
#> 281: 0.812365    1.078768    3.529093    0.245678    0.058814    0.010459    0.654284    
#> 282: 0.812239    1.079066    3.529109    0.246406    0.058808    0.010435    0.654308    
#> 283: 0.812352    1.079148    3.529140    0.247054    0.058817    0.010430    0.654366    
#> 284: 0.812329    1.079086    3.529066    0.247408    0.058788    0.010415    0.654228    
#> 285: 0.812059    1.079236    3.528865    0.247366    0.058791    0.010411    0.654050    
#> 286: 0.811596    1.079557    3.528643    0.247578    0.058642    0.010410    0.654160    
#> 287: 0.811042    1.079925    3.528491    0.247760    0.058588    0.010415    0.654031    
#> 288: 0.810753    1.080136    3.528332    0.247875    0.058496    0.010406    0.653999    
#> 289: 0.810757    1.080018    3.528323    0.247611    0.058422    0.010410    0.654127    
#> 290: 0.810993    1.079905    3.528373    0.248085    0.058542    0.010415    0.654040    
#> 291: 0.811479    1.079900    3.528552    0.248388    0.058468    0.010402    0.653792    
#> 292: 0.811565    1.079750    3.528743    0.248556    0.058469    0.010424    0.653569    
#> 293: 0.811808    1.079489    3.528802    0.248448    0.058444    0.010432    0.653241    
#> 294: 0.811910    1.079413    3.528787    0.248379    0.058387    0.010425    0.653071    
#> 295: 0.812188    1.078995    3.528830    0.248753    0.058449    0.010398    0.652865    
#> 296: 0.812343    1.078928    3.528815    0.248963    0.058403    0.010384    0.652818    
#> 297: 0.812241    1.079106    3.528632    0.249397    0.058418    0.010376    0.652713    
#> 298: 0.812046    1.079059    3.528510    0.249206    0.058507    0.010362    0.652651    
#> 299: 0.812023    1.079320    3.528338    0.249217    0.058527    0.010355    0.652387    
#> 300: 0.812284    1.079158    3.528372    0.249521    0.058484    0.010346    0.652208    
#> 301: 0.812430    1.078996    3.528368    0.249224    0.058455    0.010330    0.652372    
#> 302: 0.812157    1.079280    3.528284    0.249284    0.058481    0.010299    0.652298    
#> 303: 0.811647    1.079436    3.528170    0.249604    0.058477    0.010292    0.652128    
#> 304: 0.811669    1.079566    3.528041    0.250050    0.058415    0.010281    0.652061    
#> 305: 0.811554    1.079321    3.527982    0.250345    0.058397    0.010277    0.651996    
#> 306: 0.811208    1.078908    3.528017    0.249906    0.058365    0.010275    0.651975    
#> 307: 0.811278    1.078597    3.528122    0.249571    0.058307    0.010264    0.651983    
#> 308: 0.811117    1.078373    3.528172    0.249801    0.058324    0.010260    0.652140    
#> 309: 0.810995    1.078164    3.528134    0.249693    0.058274    0.010266    0.652272    
#> 310: 0.811014    1.078091    3.527972    0.250031    0.058210    0.010264    0.652473    
#> 311: 0.810999    1.077929    3.527922    0.250044    0.058208    0.010274    0.652546    
#> 312: 0.811009    1.077886    3.527838    0.250184    0.058174    0.010292    0.652468    
#> 313: 0.810930    1.077759    3.527747    0.250759    0.058116    0.010313    0.652553    
#> 314: 0.810570    1.077787    3.527653    0.251429    0.058095    0.010325    0.652513    
#> 315: 0.810303    1.077880    3.527630    0.252197    0.058120    0.010337    0.652471    
#> 316: 0.810300    1.077950    3.527583    0.252457    0.058122    0.010331    0.652360    
#> 317: 0.810148    1.077804    3.527638    0.251961    0.058180    0.010341    0.652386    
#> 318: 0.810272    1.077821    3.527604    0.251761    0.058269    0.010333    0.652211    
#> 319: 0.810482    1.077691    3.527699    0.251490    0.058340    0.010323    0.652237    
#> 320: 0.810097    1.077634    3.527571    0.251567    0.058427    0.010293    0.652326    
#> 321: 0.809597    1.077706    3.527364    0.251636    0.058491    0.010280    0.652378    
#> 322: 0.809543    1.077884    3.527195    0.252041    0.058577    0.010261    0.652287    
#> 323: 0.809102    1.078030    3.527047    0.252089    0.058535    0.010265    0.652302    
#> 324: 0.808980    1.078161    3.527062    0.252135    0.058497    0.010275    0.652174    
#> 325: 0.808930    1.078318    3.526989    0.251978    0.058499    0.010278    0.652206    
#> 326: 0.808908    1.078296    3.526902    0.251739    0.058497    0.010263    0.652232    
#> 327: 0.809073    1.078501    3.526890    0.251996    0.058491    0.010262    0.652244    
#> 328: 0.809159    1.078694    3.526878    0.252071    0.058530    0.010255    0.652169    
#> 329: 0.809366    1.078774    3.526916    0.251971    0.058599    0.010255    0.652057    
#> 330: 0.809036    1.078762    3.526867    0.251524    0.058577    0.010259    0.652107    
#> 331: 0.808927    1.078904    3.526855    0.251045    0.058563    0.010247    0.652096    
#> 332: 0.808916    1.078922    3.526904    0.250777    0.058580    0.010230    0.652117    
#> 333: 0.808758    1.078973    3.526875    0.250858    0.058596    0.010214    0.652132    
#> 334: 0.808620    1.078863    3.526789    0.250863    0.058579    0.010209    0.652027    
#> 335: 0.808664    1.078911    3.526761    0.250837    0.058579    0.010212    0.651917    
#> 336: 0.808392    1.079005    3.526735    0.250617    0.058598    0.010216    0.651856    
#> 337: 0.808215    1.079251    3.526674    0.250574    0.058585    0.010209    0.651840    
#> 338: 0.808273    1.079382    3.526651    0.250493    0.058585    0.010199    0.651820    
#> 339: 0.808059    1.079496    3.526557    0.250048    0.058573    0.010192    0.651749    
#> 340: 0.807836    1.079530    3.526590    0.249935    0.058571    0.010199    0.651695    
#> 341: 0.808176    1.079570    3.526661    0.249720    0.058581    0.010205    0.651651    
#> 342: 0.808010    1.079431    3.526662    0.249569    0.058561    0.010206    0.651586    
#> 343: 0.807808    1.079408    3.526659    0.249353    0.058486    0.010203    0.651480    
#> 344: 0.808078    1.079369    3.526702    0.249436    0.058483    0.010210    0.651424    
#> 345: 0.808197    1.079214    3.526727    0.249397    0.058484    0.010225    0.651362    
#> 346: 0.808035    1.079245    3.526661    0.249131    0.058442    0.010234    0.651361    
#> 347: 0.808243    1.079154    3.526605    0.249272    0.058402    0.010253    0.651416    
#> 348: 0.807912    1.079232    3.526551    0.249348    0.058302    0.010270    0.651513    
#> 349: 0.808071    1.079154    3.526536    0.249647    0.058255    0.010292    0.651571    
#> 350: 0.808036    1.078938    3.526473    0.249743    0.058302    0.010287    0.651618    
#> 351: 0.807942    1.079023    3.526414    0.249711    0.058314    0.010296    0.651546    
#> 352: 0.807759    1.079155    3.526422    0.249889    0.058298    0.010322    0.651556    
#> 353: 0.807886    1.079246    3.526394    0.250067    0.058337    0.010334    0.651462    
#> 354: 0.807979    1.079265    3.526337    0.250031    0.058294    0.010352    0.651414    
#> 355: 0.808098    1.079191    3.526297    0.250071    0.058304    0.010358    0.651268    
#> 356: 0.807931    1.079185    3.526280    0.249976    0.058361    0.010355    0.651293    
#> 357: 0.807841    1.079378    3.526252    0.250004    0.058287    0.010341    0.651177    
#> 358: 0.807841    1.079559    3.526260    0.249891    0.058217    0.010348    0.651038    
#> 359: 0.807689    1.079687    3.526269    0.249497    0.058167    0.010365    0.650963    
#> 360: 0.807510    1.079691    3.526171    0.249216    0.058146    0.010372    0.650897    
#> 361: 0.807247    1.079724    3.526075    0.248871    0.058106    0.010371    0.650952    
#> 362: 0.807173    1.079767    3.526021    0.248754    0.058074    0.010369    0.650871    
#> 363: 0.806941    1.079738    3.525989    0.248525    0.058092    0.010368    0.650718    
#> 364: 0.806993    1.079796    3.526008    0.248489    0.058077    0.010384    0.650574    
#> 365: 0.806921    1.079710    3.526062    0.248260    0.058062    0.010408    0.650555    
#> 366: 0.806943    1.079660    3.526016    0.248198    0.057996    0.010427    0.650564    
#> 367: 0.807020    1.079592    3.526030    0.248287    0.057966    0.010434    0.650585    
#> 368: 0.807171    1.079672    3.525989    0.248733    0.057934    0.010431    0.650473    
#> 369: 0.807127    1.079696    3.525953    0.249046    0.057905    0.010437    0.650477    
#> 370: 0.807106    1.079728    3.525898    0.249360    0.057885    0.010456    0.650486    
#> 371: 0.807139    1.079824    3.525844    0.249359    0.057880    0.010463    0.650500    
#> 372: 0.807046    1.079953    3.525784    0.249303    0.057856    0.010469    0.650478    
#> 373: 0.806916    1.080157    3.525698    0.249327    0.057835    0.010466    0.650544    
#> 374: 0.807014    1.080229    3.525636    0.249568    0.057803    0.010465    0.650531    
#> 375: 0.806939    1.080237    3.525615    0.249623    0.057806    0.010465    0.650550    
#> 376: 0.806799    1.080319    3.525600    0.249405    0.057831    0.010456    0.650530    
#> 377: 0.806651    1.080408    3.525561    0.249210    0.057929    0.010448    0.650499    
#> 378: 0.806254    1.080473    3.525509    0.248919    0.057928    0.010455    0.650569    
#> 379: 0.805969    1.080403    3.525484    0.248663    0.057890    0.010450    0.650591    
#> 380: 0.805741    1.080410    3.525464    0.248569    0.057947    0.010447    0.650534    
#> 381: 0.805639    1.080383    3.525434    0.248634    0.057910    0.010454    0.650430    
#> 382: 0.805650    1.080385    3.525421    0.248639    0.057898    0.010455    0.650238    
#> 383: 0.805669    1.080400    3.525395    0.248439    0.057888    0.010450    0.650093    
#> 384: 0.805497    1.080467    3.525415    0.248096    0.057929    0.010442    0.650054    
#> 385: 0.805562    1.080525    3.525445    0.248123    0.057926    0.010435    0.650010    
#> 386: 0.805508    1.080681    3.525473    0.248206    0.057943    0.010432    0.650047    
#> 387: 0.805562    1.080802    3.525556    0.248026    0.057912    0.010439    0.650096    
#> 388: 0.805841    1.080809    3.525615    0.248231    0.057868    0.010437    0.650083    
#> 389: 0.805947    1.080722    3.525651    0.248408    0.057875    0.010442    0.650199    
#> 390: 0.805847    1.080821    3.525622    0.248305    0.057848    0.010460    0.650188    
#> 391: 0.805834    1.080862    3.525584    0.248218    0.057819    0.010475    0.650214    
#> 392: 0.805938    1.080935    3.525635    0.248446    0.057780    0.010480    0.650300    
#> 393: 0.806002    1.080932    3.525629    0.248517    0.057773    0.010483    0.650342    
#> 394: 0.806151    1.080933    3.525656    0.248650    0.057784    0.010484    0.650262    
#> 395: 0.806463    1.081022    3.525708    0.248614    0.057755    0.010481    0.650234    
#> 396: 0.806627    1.081079    3.525718    0.248623    0.057774    0.010485    0.650174    
#> 397: 0.806664    1.081055    3.525759    0.248722    0.057761    0.010487    0.650133    
#> 398: 0.806781    1.081014    3.525772    0.248945    0.057690    0.010493    0.650188    
#> 399: 0.806781    1.080999    3.525841    0.249188    0.057643    0.010492    0.650114    
#> 400: 0.806937    1.081009    3.525857    0.249468    0.057614    0.010498    0.650060    
#> 401: 0.807034    1.081071    3.525863    0.249530    0.057634    0.010511    0.650101    
#> 402: 0.806875    1.081209    3.525838    0.249438    0.057644    0.010508    0.650146    
#> 403: 0.807034    1.081191    3.525856    0.249569    0.057662    0.010503    0.650191    
#> 404: 0.807107    1.081216    3.525816    0.249706    0.057674    0.010498    0.650199    
#> 405: 0.807151    1.081277    3.525773    0.249750    0.057701    0.010491    0.650203    
#> 406: 0.807322    1.081289    3.525808    0.249788    0.057763    0.010491    0.650181    
#> 407: 0.807364    1.081309    3.525860    0.249738    0.057829    0.010490    0.650150    
#> 408: 0.807539    1.081400    3.525902    0.249820    0.057882    0.010487    0.650162    
#> 409: 0.807485    1.081390    3.525916    0.249600    0.057849    0.010483    0.650175    
#> 410: 0.807560    1.081416    3.525884    0.249704    0.057868    0.010490    0.650183    
#> 411: 0.807590    1.081246    3.525876    0.249749    0.057836    0.010489    0.650236    
#> 412: 0.807594    1.081330    3.525837    0.249510    0.057842    0.010490    0.650193    
#> 413: 0.807545    1.081353    3.525811    0.249210    0.057850    0.010478    0.650215    
#> 414: 0.807463    1.081407    3.525809    0.249396    0.057887    0.010471    0.650136    
#> 415: 0.807460    1.081341    3.525822    0.249439    0.057901    0.010468    0.650055    
#> 416: 0.807445    1.081296    3.525818    0.249234    0.057935    0.010469    0.649998    
#> 417: 0.807572    1.081161    3.525834    0.249414    0.057944    0.010459    0.649984    
#> 418: 0.807474    1.081206    3.525836    0.249356    0.057955    0.010453    0.650002    
#> 419: 0.807469    1.081283    3.525819    0.249408    0.057943    0.010445    0.650087    
#> 420: 0.807605    1.081328    3.525851    0.249476    0.057957    0.010431    0.650103    
#> 421: 0.807603    1.081304    3.525861    0.249641    0.057993    0.010419    0.650068    
#> 422: 0.807808    1.081218    3.525882    0.249677    0.058014    0.010411    0.650098    
#> 423: 0.807927    1.081148    3.525895    0.249777    0.058032    0.010415    0.650105    
#> 424: 0.807909    1.081121    3.525873    0.249859    0.058023    0.010405    0.650104    
#> 425: 0.808077    1.081140    3.525858    0.250098    0.057966    0.010406    0.650234    
#> 426: 0.808327    1.081169    3.525867    0.250226    0.057945    0.010407    0.650199    
#> 427: 0.808430    1.081173    3.525884    0.250373    0.057929    0.010415    0.650125    
#> 428: 0.808258    1.081219    3.525873    0.250456    0.057947    0.010411    0.650070    
#> 429: 0.808210    1.081242    3.525882    0.250685    0.057911    0.010410    0.650046    
#> 430: 0.808148    1.081300    3.525878    0.250600    0.057925    0.010414    0.650020    
#> 431: 0.807950    1.081233    3.525822    0.250475    0.057901    0.010417    0.650002    
#> 432: 0.807803    1.081305    3.525810    0.250524    0.057893    0.010418    0.649968    
#> 433: 0.807863    1.081393    3.525845    0.250509    0.057885    0.010419    0.649959    
#> 434: 0.807758    1.081386    3.525848    0.250668    0.057923    0.010414    0.649885    
#> 435: 0.807773    1.081362    3.525853    0.250741    0.057902    0.010411    0.649799    
#> 436: 0.807789    1.081292    3.525861    0.250762    0.057814    0.010410    0.649833    
#> 437: 0.807823    1.081260    3.525865    0.250666    0.057798    0.010413    0.649870    
#> 438: 0.807731    1.081407    3.525875    0.250611    0.057773    0.010405    0.649828    
#> 439: 0.807664    1.081484    3.525849    0.250519    0.057719    0.010401    0.649789    
#> 440: 0.807553    1.081494    3.525855    0.250267    0.057691    0.010396    0.649766    
#> 441: 0.807572    1.081496    3.525875    0.250120    0.057696    0.010397    0.649694    
#> 442: 0.807527    1.081547    3.525907    0.249812    0.057713    0.010393    0.649644    
#> 443: 0.807512    1.081591    3.525913    0.249789    0.057714    0.010389    0.649604    
#> 444: 0.807572    1.081600    3.525901    0.249583    0.057694    0.010387    0.649605    
#> 445: 0.807621    1.081578    3.525888    0.249756    0.057699    0.010382    0.649590    
#> 446: 0.807552    1.081582    3.525882    0.249824    0.057688    0.010383    0.649564    
#> 447: 0.807717    1.081545    3.525945    0.249818    0.057663    0.010385    0.649563    
#> 448: 0.807704    1.081565    3.525977    0.249833    0.057645    0.010395    0.649532    
#> 449: 0.807732    1.081619    3.526098    0.249655    0.057659    0.010395    0.649586    
#> 450: 0.807770    1.081622    3.526134    0.249635    0.057641    0.010391    0.649620    
#> 451: 0.807824    1.081685    3.526128    0.249801    0.057667    0.010386    0.649651    
#> 452: 0.807731    1.081729    3.526100    0.249781    0.057662    0.010378    0.649651    
#> 453: 0.807613    1.081743    3.526078    0.249628    0.057635    0.010370    0.649651    
#> 454: 0.807426    1.081871    3.526027    0.249540    0.057630    0.010364    0.649619    
#> 455: 0.807346    1.081841    3.525982    0.249637    0.057666    0.010360    0.649549    
#> 456: 0.807275    1.081836    3.525959    0.249665    0.057677    0.010357    0.649482    
#> 457: 0.807185    1.081882    3.525947    0.249692    0.057675    0.010351    0.649431    
#> 458: 0.807094    1.082037    3.525946    0.249711    0.057668    0.010347    0.649423    
#> 459: 0.806888    1.082165    3.525917    0.249739    0.057719    0.010340    0.649354    
#> 460: 0.806839    1.082186    3.525860    0.249693    0.057740    0.010343    0.649289    
#> 461: 0.806803    1.082269    3.525870    0.249688    0.057746    0.010346    0.649273    
#> 462: 0.806672    1.082340    3.525885    0.249726    0.057739    0.010334    0.649287    
#> 463: 0.806605    1.082447    3.525884    0.249635    0.057719    0.010324    0.649277    
#> 464: 0.806652    1.082556    3.525857    0.249565    0.057710    0.010320    0.649248    
#> 465: 0.806642    1.082484    3.525843    0.249435    0.057688    0.010316    0.649215    
#> 466: 0.806583    1.082535    3.525786    0.249388    0.057671    0.010318    0.649206    
#> 467: 0.806398    1.082583    3.525727    0.249268    0.057649    0.010313    0.649150    
#> 468: 0.806451    1.082568    3.525750    0.249145    0.057639    0.010318    0.649196    
#> 469: 0.806544    1.082553    3.525826    0.249211    0.057615    0.010345    0.649258    
#> 470: 0.806544    1.082558    3.525836    0.249276    0.057566    0.010353    0.649235    
#> 471: 0.806433    1.082536    3.525826    0.249252    0.057585    0.010343    0.649250    
#> 472: 0.806440    1.082498    3.525841    0.249191    0.057557    0.010340    0.649316    
#> 473: 0.806417    1.082466    3.525846    0.249075    0.057574    0.010343    0.649247    
#> 474: 0.806428    1.082357    3.525852    0.248995    0.057621    0.010343    0.649260    
#> 475: 0.806511    1.082421    3.525862    0.248837    0.057587    0.010348    0.649233    
#> 476: 0.806621    1.082388    3.525877    0.248921    0.057568    0.010346    0.649285    
#> 477: 0.806711    1.082404    3.525940    0.248944    0.057547    0.010350    0.649248    
#> 478: 0.806738    1.082401    3.525947    0.248917    0.057558    0.010349    0.649234    
#> 479: 0.806803    1.082482    3.525945    0.248890    0.057554    0.010351    0.649218    
#> 480: 0.806949    1.082511    3.525949    0.248863    0.057516    0.010363    0.649251    
#> 481: 0.806900    1.082538    3.525932    0.248721    0.057477    0.010370    0.649322    
#> 482: 0.806944    1.082546    3.525906    0.248676    0.057461    0.010375    0.649308    
#> 483: 0.806904    1.082518    3.525891    0.248826    0.057438    0.010374    0.649259    
#> 484: 0.806812    1.082361    3.525888    0.248969    0.057469    0.010367    0.649278    
#> 485: 0.806852    1.082399    3.525879    0.249135    0.057512    0.010359    0.649281    
#> 486: 0.806850    1.082473    3.525887    0.249090    0.057502    0.010352    0.649252    
#> 487: 0.807049    1.082529    3.525947    0.249032    0.057482    0.010356    0.649187    
#> 488: 0.807117    1.082514    3.525992    0.249050    0.057471    0.010362    0.649128    
#> 489: 0.807238    1.082526    3.526006    0.248940    0.057489    0.010370    0.649096    
#> 490: 0.807250    1.082545    3.526033    0.249024    0.057470    0.010377    0.649035    
#> 491: 0.807342    1.082589    3.526081    0.248900    0.057473    0.010383    0.649027    
#> 492: 0.807232    1.082620    3.526077    0.248812    0.057477    0.010381    0.649113    
#> 493: 0.807219    1.082572    3.526089    0.248645    0.057475    0.010392    0.649130    
#> 494: 0.807406    1.082570    3.526084    0.248543    0.057436    0.010400    0.649124    
#> 495: 0.807508    1.082574    3.526097    0.248535    0.057395    0.010412    0.649092    
#> 496: 0.807663    1.082555    3.526086    0.248690    0.057385    0.010415    0.649100    
#> 497: 0.807608    1.082562    3.526056    0.248795    0.057400    0.010413    0.649029    
#> 498: 0.807562    1.082553    3.526009    0.248841    0.057371    0.010414    0.648983    
#> 499: 0.807545    1.082606    3.525971    0.248915    0.057393    0.010413    0.648942    
#> 500: 0.807580    1.082594    3.525949    0.249049    0.057403    0.010412    0.648915    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.261823    0.980269    3.445969    0.392401    0.080445    0.016800    1.663993    
#> 002: 0.212490    1.057996    3.485601    0.372781    0.076423    0.016863    1.121110    
#> 003: 0.232876    0.993237    3.500451    0.354142    0.072602    0.016020    0.864397    
#> 004: 0.224741    1.043653    3.496510    0.336435    0.072735    0.015219    0.789287    
#> 005: 0.276157    1.069789    3.478785    0.319613    0.073656    0.014458    0.741264    
#> 006: 0.229449    1.082397    3.470126    0.303633    0.069973    0.017466    0.678358    
#> 007: 0.179003    1.094233    3.451166    0.300741    0.087969    0.019767    0.669557    
#> 008: 0.196078    1.100420    3.451639    0.285704    0.093289    0.018779    0.676964    
#> 009: 0.172422    1.088268    3.450868    0.271419    0.088624    0.020918    0.672420    
#> 010: 0.210883    1.078407    3.460122    0.257848    0.084193    0.019872    0.680558    
#> 011: 0.285933    1.069528    3.484098    0.244955    0.079983    0.022433    0.694316    
#> 012: 0.286053    1.066100    3.470905    0.268459    0.075984    0.024762    0.671843    
#> 013: 0.230227    1.075110    3.461389    0.312310    0.072185    0.030661    0.671803    
#> 014: 0.261504    1.068302    3.477613    0.307872    0.068576    0.030846    0.669602    
#> 015: 0.281000    1.079187    3.490491    0.292478    0.065147    0.031409    0.655587    
#> 016: 0.230777    1.101185    3.475691    0.288478    0.066332    0.029839    0.668509    
#> 017: 0.249164    1.101253    3.469629    0.314586    0.063015    0.034106    0.640310    
#> 018: 0.243753    1.075728    3.459462    0.298857    0.059864    0.032401    0.671354    
#> 019: 0.202390    1.088516    3.455512    0.287324    0.056871    0.032810    0.658094    
#> 020: 0.263053    1.081576    3.477498    0.320192    0.054714    0.032665    0.649907    
#> 021: 0.241963    1.088021    3.475413    0.324437    0.054599    0.031032    0.643523    
#> 022: 0.240980    1.091613    3.477979    0.308215    0.059167    0.031652    0.649681    
#> 023: 0.324720    1.097439    3.484144    0.292804    0.058424    0.030069    0.688007    
#> 024: 0.303942    1.109692    3.487651    0.298662    0.055503    0.030028    0.670654    
#> 025: 0.279018    1.083640    3.475285    0.314788    0.055852    0.032456    0.662823    
#> 026: 0.250763    1.119666    3.458823    0.307453    0.059863    0.031345    0.657406    
#> 027: 0.214341    1.121559    3.448942    0.320960    0.062324    0.029778    0.655228    
#> 028: 0.233385    1.100764    3.459112    0.323336    0.059208    0.030314    0.648334    
#> 029: 0.256953    1.111424    3.451625    0.307170    0.056247    0.029611    0.679283    
#> 030: 0.259276    1.111321    3.465279    0.304310    0.061064    0.034619    0.669100    
#> 031: 0.221156    1.100535    3.470533    0.289094    0.063752    0.032888    0.662360    
#> 032: 0.233836    1.099114    3.478077    0.289434    0.068494    0.033983    0.644147    
#> 033: 0.214933    1.106390    3.463487    0.304442    0.065070    0.032284    0.661848    
#> 034: 0.239153    1.101445    3.473286    0.289568    0.073087    0.036196    0.641014    
#> 035: 0.241853    1.085865    3.465077    0.275089    0.069433    0.034386    0.646589    
#> 036: 0.238488    1.114208    3.460382    0.261335    0.065961    0.032667    0.672288    
#> 037: 0.199894    1.116304    3.456934    0.271773    0.067991    0.031644    0.649409    
#> 038: 0.240235    1.111957    3.457902    0.314777    0.064591    0.033681    0.644251    
#> 039: 0.229544    1.101199    3.463159    0.316111    0.061362    0.035223    0.646816    
#> 040: 0.238523    1.104265    3.476365    0.311443    0.059825    0.042010    0.659240    
#> 041: 0.190488    1.097502    3.451616    0.295871    0.056833    0.039910    0.635297    
#> 042: 0.234305    1.106794    3.439707    0.337269    0.053992    0.037914    0.636828    
#> 043: 0.183753    1.118746    3.420860    0.320406    0.052259    0.036019    0.657083    
#> 044: 0.168813    1.115296    3.423576    0.312529    0.050216    0.034218    0.671132    
#> 045: 0.154465    1.139068    3.430805    0.296903    0.067026    0.032507    0.656778    
#> 046: 0.209619    1.123870    3.441887    0.299509    0.067160    0.036265    0.657311    
#> 047: 0.215863    1.126022    3.440603    0.303501    0.063802    0.034452    0.652658    
#> 048: 0.188733    1.114159    3.443426    0.288326    0.060612    0.034656    0.645072    
#> 049: 0.181137    1.136862    3.439743    0.340220    0.057582    0.032923    0.657005    
#> 050: 0.205932    1.100809    3.453676    0.348097    0.054703    0.036524    0.671380    
#> 051: 0.206725    1.104164    3.452073    0.330693    0.051967    0.038386    0.657942    
#> 052: 0.252465    1.101886    3.474286    0.314158    0.051630    0.036467    0.649118    
#> 053: 0.234409    1.082304    3.462743    0.342413    0.049049    0.042963    0.657313    
#> 054: 0.231139    1.085418    3.455913    0.341162    0.058667    0.041240    0.657195    
#> 055: 0.245837    1.088870    3.464548    0.362003    0.059778    0.039178    0.658803    
#> 056: 0.259036    1.086803    3.465588    0.343902    0.056789    0.037219    0.667953    
#> 057: 0.237665    1.085670    3.476059    0.326707    0.053950    0.035358    0.679955    
#> 058: 0.226702    1.091622    3.459294    0.328018    0.051252    0.036084    0.672449    
#> 059: 0.221659    1.063545    3.460885    0.369383    0.051050    0.043657    0.664654    
#> 060: 0.220868    1.072671    3.456643    0.433379    0.054227    0.045096    0.675200    
#> 061: 0.209719    1.085426    3.468965    0.411710    0.051516    0.042841    0.694398    
#> 062: 0.263739    1.082982    3.476528    0.414542    0.053375    0.045075    0.700005    
#> 063: 0.283071    1.060399    3.474615    0.393815    0.052803    0.042821    0.686325    
#> 064: 0.241542    1.078970    3.477069    0.374124    0.050163    0.044516    0.670111    
#> 065: 0.272667    1.081617    3.471860    0.355418    0.051064    0.042290    0.659549    
#> 066: 0.263113    1.103992    3.474505    0.337647    0.051372    0.040176    0.650337    
#> 067: 0.229414    1.091995    3.462733    0.320765    0.048804    0.038167    0.644602    
#> 068: 0.192390    1.106814    3.465668    0.304727    0.046364    0.036258    0.668047    
#> 069: 0.209001    1.108802    3.443388    0.289490    0.047653    0.034639    0.664921    
#> 070: 0.215019    1.098274    3.454724    0.303681    0.055506    0.032907    0.646398    
#> 071: 0.194082    1.122398    3.437592    0.303162    0.061824    0.031261    0.655260    
#> 072: 0.178910    1.100605    3.444476    0.307071    0.058733    0.029698    0.665922    
#> 073: 0.214574    1.090851    3.464474    0.299600    0.057522    0.028213    0.663139    
#> 074: 0.217070    1.080678    3.464766    0.284620    0.055587    0.026803    0.660931    
#> 075: 0.247227    1.091955    3.484894    0.286542    0.062046    0.025462    0.654806    
#> 076: 0.266929    1.092137    3.491366    0.272215    0.063699    0.026486    0.668606    
#> 077: 0.304785    1.062598    3.495488    0.258604    0.063216    0.031827    0.665481    
#> 078: 0.282356    1.065447    3.493519    0.282965    0.060055    0.035212    0.662252    
#> 079: 0.272056    1.078191    3.487778    0.295311    0.057052    0.033451    0.671608    
#> 080: 0.266472    1.066288    3.482914    0.280545    0.055261    0.031779    0.690860    
#> 081: 0.250561    1.080383    3.472554    0.316542    0.052498    0.030190    0.665525    
#> 082: 0.224605    1.073234    3.475168    0.300715    0.054294    0.033268    0.678692    
#> 083: 0.290107    1.081754    3.482676    0.285680    0.056836    0.034932    0.660159    
#> 084: 0.276216    1.089241    3.480072    0.271396    0.053994    0.033445    0.645849    
#> 085: 0.260990    1.100038    3.488936    0.257826    0.055625    0.035891    0.655664    
#> 086: 0.254221    1.068914    3.482688    0.250767    0.052942    0.040027    0.661245    
#> 087: 0.242576    1.078302    3.480202    0.255560    0.060708    0.038026    0.666750    
#> 088: 0.191635    1.081927    3.481684    0.242782    0.057673    0.036125    0.678538    
#> 089: 0.226104    1.089137    3.461111    0.255722    0.054789    0.036360    0.669855    
#> 090: 0.183129    1.100141    3.454232    0.285365    0.052049    0.035859    0.667804    
#> 091: 0.176332    1.092573    3.437643    0.271097    0.055438    0.034814    0.680873    
#> 092: 0.167390    1.112372    3.422146    0.320286    0.064928    0.033073    0.676356    
#> 093: 0.172667    1.105198    3.439949    0.304272    0.061682    0.033719    0.665311    
#> 094: 0.195057    1.132339    3.446844    0.289058    0.058598    0.034587    0.650700    
#> 095: 0.208758    1.132668    3.447360    0.325224    0.065951    0.033869    0.650338    
#> 096: 0.188800    1.118783    3.439849    0.309022    0.063570    0.032175    0.656397    
#> 097: 0.239867    1.122125    3.455588    0.357130    0.060392    0.033842    0.634848    
#> 098: 0.230614    1.120364    3.455803    0.339273    0.061629    0.032150    0.649788    
#> 099: 0.196488    1.111344    3.447663    0.322674    0.061018    0.033948    0.645982    
#> 100: 0.163082    1.126419    3.442106    0.310230    0.057967    0.035819    0.644412    
#> 101: 0.145715    1.111070    3.419263    0.294719    0.055069    0.034028    0.646410    
#> 102: 0.150375    1.114816    3.418334    0.291784    0.055499    0.032327    0.643999    
#> 103: 0.168307    1.118390    3.440223    0.277195    0.052724    0.030780    0.652877    
#> 104: 0.153413    1.121668    3.447230    0.263335    0.061411    0.030609    0.664053    
#> 105: 0.193804    1.106183    3.453588    0.297368    0.058340    0.030711    0.656619    
#> 106: 0.247446    1.092234    3.458572    0.350966    0.055423    0.039209    0.663138    
#> 107: 0.236113    1.100868    3.468630    0.368556    0.052652    0.041026    0.659367    
#> 108: 0.242838    1.094439    3.481717    0.357051    0.057675    0.038974    0.667572    
#> 109: 0.200828    1.101745    3.473866    0.339198    0.054792    0.037026    0.671849    
#> 110: 0.243363    1.085019    3.459326    0.357147    0.052052    0.039157    0.653466    
#> 111: 0.227686    1.097721    3.459256    0.349631    0.049450    0.041440    0.641074    
#> 112: 0.173360    1.106139    3.432210    0.332150    0.055228    0.039368    0.658454    
#> 113: 0.188608    1.126964    3.438974    0.359203    0.052467    0.037399    0.637490    
#> 114: 0.207254    1.123438    3.448235    0.341243    0.053719    0.036435    0.657145    
#> 115: 0.226566    1.091883    3.438624    0.379064    0.051033    0.037942    0.689664    
#> 116: 0.245201    1.115319    3.444155    0.360111    0.048481    0.041094    0.666014    
#> 117: 0.185467    1.115659    3.456817    0.348100    0.046057    0.039102    0.662352    
#> 118: 0.173650    1.107698    3.438581    0.330695    0.047681    0.038093    0.665756    
#> 119: 0.180831    1.106575    3.444025    0.387298    0.045297    0.038464    0.669299    
#> 120: 0.134846    1.101019    3.429790    0.367934    0.056605    0.041194    0.659494    
#> 121: 0.197492    1.121720    3.439628    0.381880    0.054983    0.040311    0.652337    
#> 122: 0.189191    1.101296    3.451514    0.362786    0.052234    0.038688    0.655286    
#> 123: 0.251798    1.128542    3.450897    0.344646    0.056686    0.036754    0.662134    
#> 124: 0.234380    1.138003    3.448981    0.327414    0.067175    0.034916    0.666386    
#> 125: 0.211957    1.122117    3.438693    0.327698    0.063817    0.033335    0.660213    
#> 126: 0.197725    1.125046    3.434877    0.311313    0.060626    0.038112    0.663520    
#> 127: 0.213586    1.125945    3.436383    0.314223    0.057594    0.037041    0.668688    
#> 128: 0.190096    1.121138    3.460237    0.300024    0.054715    0.035189    0.667156    
#> 129: 0.199047    1.117144    3.445088    0.323535    0.051979    0.036456    0.661942    
#> 130: 0.234568    1.125469    3.448421    0.308928    0.057666    0.034633    0.656589    
#> 131: 0.179440    1.110536    3.443517    0.293481    0.058019    0.032902    0.670843    
#> 132: 0.173075    1.104193    3.424682    0.287688    0.055119    0.031257    0.680129    
#> 133: 0.165455    1.107223    3.425902    0.290749    0.052363    0.029694    0.676707    
#> 134: 0.204971    1.080031    3.457751    0.320780    0.055155    0.030800    0.672568    
#> 135: 0.222153    1.075300    3.465325    0.306308    0.063319    0.029260    0.670706    
#> 136: 0.233654    1.084863    3.467615    0.363789    0.086914    0.027797    0.663260    
#> 137: 0.281720    1.084578    3.481048    0.345600    0.082568    0.028104    0.675803    
#> 138: 0.241075    1.095339    3.465163    0.328320    0.078440    0.029498    0.659199    
#> 139: 0.217480    1.087928    3.470396    0.328999    0.074518    0.028400    0.660221    
#> 140: 0.240861    1.087521    3.471114    0.353274    0.070792    0.031149    0.683219    
#> 141: 0.262973    1.062754    3.479567    0.357136    0.067252    0.036103    0.664731    
#> 142: 0.266624    1.069809    3.489941    0.383359    0.063890    0.038142    0.680020    
#> 143: 0.221113    1.078064    3.476004    0.373602    0.060695    0.040875    0.685816    
#> 144: 0.261354    1.076145    3.485294    0.354921    0.057661    0.047117    0.672494    
#> 145: 0.247231    1.090287    3.478251    0.337175    0.054778    0.044761    0.658340    
#> 146: 0.226299    1.113323    3.458843    0.333473    0.052039    0.042523    0.671323    
#> 147: 0.140382    1.109850    3.430156    0.316800    0.053789    0.040397    0.658092    
#> 148: 0.159114    1.125420    3.438494    0.324520    0.055919    0.038377    0.649876    
#> 149: 0.176609    1.108349    3.444444    0.308294    0.053123    0.036458    0.663249    
#> 150: 0.206506    1.090788    3.442631    0.292879    0.054286    0.034635    0.659883    
#> 151: 0.162719    1.120203    3.448715    0.278235    0.051572    0.036707    0.656015    
#> 152: 0.151285    1.118191    3.437911    0.277643    0.049792    0.039211    0.657858    
#> 153: 0.193747    1.121122    3.454272    0.282869    0.053336    0.041153    0.674456    
#> 154: 0.209719    1.114033    3.449670    0.263395    0.060976    0.033861    0.665662    
#> 155: 0.217848    1.094530    3.458473    0.304148    0.048207    0.037877    0.655220    
#> 156: 0.215841    1.106862    3.461414    0.282621    0.049134    0.039853    0.669254    
#> 157: 0.213335    1.094167    3.466411    0.323979    0.050021    0.038241    0.679265    
#> 158: 0.222035    1.110566    3.453693    0.344774    0.045453    0.038028    0.678955    
#> 159: 0.169662    1.115831    3.461636    0.299430    0.043692    0.037661    0.677138    
#> 160: 0.215604    1.087380    3.473615    0.305861    0.044289    0.041725    0.667632    
#> 161: 0.197248    1.093125    3.453054    0.339078    0.050507    0.043138    0.667420    
#> 162: 0.163467    1.114380    3.436254    0.323678    0.047863    0.042087    0.674591    
#> 163: 0.189685    1.110508    3.440408    0.296631    0.053093    0.037077    0.679071    
#> 164: 0.210311    1.112593    3.451538    0.347377    0.055627    0.036660    0.662286    
#> 165: 0.255360    1.082768    3.460622    0.427999    0.045617    0.043283    0.665490    
#> 166: 0.266199    1.112567    3.464087    0.392598    0.048959    0.041742    0.664213    
#> 167: 0.250840    1.129812    3.462915    0.384210    0.048976    0.044319    0.663929    
#> 168: 0.238161    1.125954    3.461648    0.389971    0.052339    0.042651    0.659207    
#> 169: 0.217215    1.146408    3.446783    0.380398    0.050367    0.042181    0.678567    
#> 170: 0.202394    1.122982    3.451350    0.310334    0.051767    0.038387    0.658971    
#> 171: 0.185381    1.106753    3.445917    0.310067    0.041477    0.035636    0.653700    
#> 172: 0.170818    1.122441    3.444573    0.288065    0.047850    0.030692    0.653489    
#> 173: 0.187777    1.136330    3.437374    0.291752    0.045145    0.035370    0.653788    
#> 174: 0.180684    1.134293    3.448144    0.253411    0.046144    0.032735    0.670698    
#> 175: 0.212578    1.131668    3.444055    0.310033    0.045376    0.033989    0.674500    
#> 176: 0.185966    1.119881    3.462226    0.237006    0.046612    0.029369    0.674413    
#> 177: 0.210293    1.097854    3.469525    0.267057    0.057060    0.035604    0.656254    
#> 178: 0.221367    1.099962    3.470215    0.288288    0.053885    0.031078    0.660279    
#> 179: 0.275363    1.108010    3.468972    0.297613    0.065715    0.031280    0.668052    
#> 180: 0.224420    1.096831    3.470045    0.262686    0.056286    0.024781    0.687991    
#> 181: 0.200895    1.096147    3.444606    0.236131    0.067595    0.024269    0.656790    
#> 182: 0.180661    1.096097    3.444108    0.295841    0.058866    0.030940    0.673381    
#> 183: 0.225498    1.109794    3.462260    0.276863    0.057071    0.035097    0.665210    
#> 184: 0.237239    1.105455    3.464812    0.272852    0.054269    0.036266    0.653202    
#> 185: 0.223451    1.112596    3.453788    0.277430    0.045441    0.029495    0.653961    
#> 186: 0.208555    1.127656    3.448341    0.355441    0.045797    0.035592    0.668998    
#> 187: 0.222546    1.108161    3.458145    0.320940    0.057506    0.036315    0.674316    
#> 188: 0.193059    1.118116    3.448009    0.299844    0.062561    0.034082    0.677850    
#> 189: 0.215068    1.111781    3.460483    0.261704    0.065342    0.036426    0.669436    
#> 190: 0.194710    1.128068    3.454859    0.304039    0.053824    0.039654    0.641556    
#> 191: 0.197229    1.127553    3.452700    0.237586    0.049983    0.034989    0.655237    
#> 192: 0.186783    1.116952    3.450902    0.284211    0.046148    0.039478    0.651942    
#> 193: 0.220572    1.117784    3.467070    0.282126    0.041817    0.041347    0.657602    
#> 194: 0.192477    1.097786    3.451949    0.298591    0.048542    0.039507    0.650977    
#> 195: 0.189871    1.106319    3.459484    0.296484    0.056457    0.041170    0.640007    
#> 196: 0.215138    1.117877    3.457758    0.330978    0.058707    0.039438    0.650023    
#> 197: 0.194216    1.119235    3.478390    0.290791    0.054290    0.042715    0.655771    
#> 198: 0.241980    1.089270    3.467881    0.294137    0.039523    0.044112    0.652570    
#> 199: 0.211176    1.079712    3.465146    0.271927    0.040199    0.041211    0.670537    
#> 200: 0.223874    1.071716    3.466807    0.323061    0.040588    0.040544    0.675486    
#> 201: 0.206140    1.073336    3.471721    0.332182    0.041666    0.043893    0.675532    
#> 202: 0.206572    1.077209    3.467347    0.328288    0.043018    0.043576    0.672592    
#> 203: 0.216753    1.077878    3.463985    0.336889    0.043972    0.043303    0.672227    
#> 204: 0.219366    1.078012    3.465376    0.340364    0.045751    0.042216    0.669952    
#> 205: 0.221052    1.082559    3.464840    0.350319    0.047300    0.042842    0.670093    
#> 206: 0.221084    1.089939    3.464745    0.348456    0.046872    0.043617    0.669007    
#> 207: 0.220593    1.093773    3.460892    0.349015    0.046084    0.042954    0.669102    
#> 208: 0.215712    1.098673    3.458805    0.344676    0.045697    0.042155    0.668483    
#> 209: 0.216729    1.098677    3.458127    0.339547    0.046094    0.041672    0.667092    
#> 210: 0.218228    1.098222    3.459615    0.339579    0.046033    0.041485    0.663413    
#> 211: 0.220684    1.099429    3.460049    0.339869    0.046400    0.041264    0.661369    
#> 212: 0.222763    1.099270    3.461329    0.337834    0.046656    0.040945    0.660226    
#> 213: 0.223169    1.097096    3.462568    0.333131    0.047128    0.040573    0.660817    
#> 214: 0.225053    1.097623    3.462370    0.329366    0.047425    0.039894    0.661665    
#> 215: 0.224781    1.098523    3.461852    0.326841    0.047829    0.039313    0.661538    
#> 216: 0.227310    1.098002    3.462109    0.325909    0.048391    0.039162    0.661816    
#> 217: 0.228630    1.099853    3.462251    0.323943    0.049338    0.038739    0.660844    
#> 218: 0.229573    1.100382    3.461899    0.324341    0.049744    0.038434    0.660112    
#> 219: 0.228611    1.099705    3.460956    0.328662    0.050022    0.038113    0.660147    
#> 220: 0.227230    1.099980    3.460097    0.333638    0.050329    0.037765    0.659673    
#> 221: 0.224869    1.101200    3.459340    0.335276    0.051018    0.037373    0.659169    
#> 222: 0.223701    1.102162    3.458268    0.335161    0.051266    0.037433    0.659605    
#> 223: 0.222571    1.102155    3.457672    0.333061    0.051482    0.037489    0.659818    
#> 224: 0.222984    1.102774    3.457640    0.330965    0.051185    0.037383    0.659507    
#> 225: 0.222777    1.101939    3.458001    0.329773    0.051225    0.037278    0.658899    
#> 226: 0.222516    1.101254    3.457562    0.329490    0.051039    0.037311    0.658445    
#> 227: 0.221832    1.100807    3.457429    0.330686    0.050824    0.037681    0.658572    
#> 228: 0.220535    1.101235    3.456744    0.333679    0.050560    0.037702    0.658501    
#> 229: 0.220265    1.100871    3.456743    0.334078    0.050337    0.037899    0.658002    
#> 230: 0.221680    1.100675    3.457189    0.333393    0.050472    0.038026    0.657815    
#> 231: 0.222214    1.100797    3.457681    0.333054    0.050471    0.038016    0.657940    
#> 232: 0.222215    1.100708    3.458175    0.331763    0.050408    0.037891    0.657893    
#> 233: 0.222082    1.099840    3.458140    0.329989    0.050261    0.037824    0.658238    
#> 234: 0.221352    1.099928    3.458123    0.329638    0.050142    0.037812    0.658349    
#> 235: 0.222346    1.099514    3.458449    0.328523    0.050181    0.037763    0.658155    
#> 236: 0.222602    1.099544    3.458309    0.328087    0.050177    0.037595    0.657892    
#> 237: 0.222846    1.098957    3.458426    0.326261    0.050252    0.037373    0.658833    
#> 238: 0.223991    1.098693    3.458833    0.325911    0.050352    0.037203    0.659250    
#> 239: 0.224120    1.098970    3.459150    0.325742    0.050329    0.037230    0.659225    
#> 240: 0.223831    1.098926    3.459386    0.326860    0.050377    0.037193    0.659243    
#> 241: 0.223187    1.098528    3.459182    0.326127    0.050467    0.037034    0.659330    
#> 242: 0.222803    1.098417    3.458866    0.323611    0.050695    0.036812    0.659801    
#> 243: 0.222596    1.098706    3.458810    0.322686    0.051060    0.036665    0.660272    
#> 244: 0.221771    1.098679    3.458865    0.321939    0.051152    0.036509    0.660757    
#> 245: 0.222491    1.098395    3.459033    0.321908    0.051405    0.036385    0.661681    
#> 246: 0.223205    1.098280    3.459418    0.321895    0.051832    0.036331    0.662054    
#> 247: 0.222750    1.098219    3.459709    0.321403    0.052117    0.036286    0.661598    
#> 248: 0.222792    1.098621    3.459852    0.320182    0.052239    0.036178    0.661477    
#> 249: 0.222319    1.098417    3.459834    0.320462    0.052256    0.036093    0.661260    
#> 250: 0.222904    1.098619    3.460162    0.320339    0.052556    0.036098    0.661366    
#> 251: 0.223715    1.098935    3.460442    0.320079    0.052695    0.036044    0.661682    
#> 252: 0.224194    1.098940    3.460999    0.319890    0.052780    0.036051    0.661649    
#> 253: 0.224374    1.098674    3.461341    0.319580    0.052855    0.035976    0.661761    
#> 254: 0.224620    1.099112    3.461453    0.319026    0.052876    0.035836    0.661990    
#> 255: 0.224368    1.099376    3.461337    0.317948    0.052815    0.035705    0.662207    
#> 256: 0.224454    1.099363    3.461341    0.317294    0.053000    0.035571    0.662224    
#> 257: 0.224316    1.099166    3.461372    0.317010    0.053382    0.035483    0.662242    
#> 258: 0.223984    1.098743    3.461403    0.316770    0.053559    0.035483    0.662215    
#> 259: 0.223557    1.098454    3.461402    0.316057    0.053621    0.035411    0.662895    
#> 260: 0.223375    1.098626    3.461490    0.316181    0.053797    0.035269    0.663079    
#> 261: 0.223190    1.098564    3.461466    0.315902    0.053914    0.035111    0.663180    
#> 262: 0.223452    1.098679    3.461600    0.315082    0.053994    0.035054    0.663079    
#> 263: 0.223574    1.098801    3.461694    0.315126    0.053993    0.034962    0.663079    
#> 264: 0.223509    1.098930    3.461653    0.315380    0.054353    0.034928    0.663018    
#> 265: 0.223513    1.098962    3.461545    0.315601    0.054579    0.034904    0.662941    
#> 266: 0.223725    1.099034    3.461538    0.315768    0.054651    0.034916    0.662868    
#> 267: 0.223896    1.098922    3.461871    0.316256    0.054574    0.034925    0.662673    
#> 268: 0.224097    1.098692    3.461828    0.316573    0.054568    0.034966    0.662672    
#> 269: 0.224522    1.098548    3.461763    0.316744    0.054483    0.035059    0.662709    
#> 270: 0.224436    1.098880    3.461553    0.316146    0.054459    0.035062    0.662615    
#> 271: 0.224189    1.098759    3.461332    0.316404    0.054583    0.035021    0.662597    
#> 272: 0.224041    1.098482    3.461195    0.316843    0.054660    0.034963    0.662913    
#> 273: 0.223219    1.098752    3.460908    0.316351    0.054706    0.035028    0.663096    
#> 274: 0.222481    1.099121    3.460705    0.315903    0.054794    0.035041    0.662943    
#> 275: 0.221858    1.099470    3.460265    0.315465    0.054893    0.034995    0.662803    
#> 276: 0.221369    1.099889    3.460128    0.315114    0.054896    0.034947    0.662672    
#> 277: 0.220726    1.100083    3.459946    0.314851    0.054822    0.034914    0.662399    
#> 278: 0.220635    1.100218    3.459846    0.314995    0.054772    0.034912    0.662122    
#> 279: 0.220628    1.100102    3.459861    0.315440    0.054801    0.034877    0.661872    
#> 280: 0.220998    1.100181    3.460069    0.314783    0.054874    0.034870    0.661827    
#> 281: 0.221128    1.100374    3.460262    0.313885    0.055025    0.034891    0.661761    
#> 282: 0.221784    1.100509    3.460531    0.313235    0.055078    0.034915    0.662021    
#> 283: 0.221719    1.100650    3.460649    0.312783    0.055111    0.034977    0.662286    
#> 284: 0.221742    1.100542    3.460685    0.312588    0.055120    0.035008    0.662017    
#> 285: 0.221982    1.100475    3.460639    0.312875    0.055010    0.035124    0.661908    
#> 286: 0.221769    1.100673    3.460449    0.312439    0.055116    0.035184    0.661749    
#> 287: 0.221174    1.101006    3.460172    0.312505    0.055176    0.035182    0.661624    
#> 288: 0.220834    1.101214    3.460037    0.312483    0.055135    0.035300    0.661738    
#> 289: 0.220909    1.101253    3.459941    0.312488    0.055159    0.035299    0.661687    
#> 290: 0.220781    1.101060    3.459999    0.311815    0.055052    0.035375    0.661867    
#> 291: 0.220764    1.101103    3.459992    0.310914    0.054927    0.035404    0.661774    
#> 292: 0.220904    1.101082    3.459957    0.310860    0.054816    0.035427    0.661695    
#> 293: 0.220866    1.101090    3.459809    0.311074    0.054702    0.035391    0.661574    
#> 294: 0.220630    1.101309    3.459598    0.310923    0.054630    0.035401    0.661531    
#> 295: 0.220437    1.101081    3.459490    0.311138    0.054547    0.035420    0.661504    
#> 296: 0.220518    1.101027    3.459414    0.311459    0.054588    0.035429    0.661461    
#> 297: 0.220690    1.101104    3.459491    0.311330    0.054528    0.035449    0.661519    
#> 298: 0.221270    1.100925    3.459544    0.311666    0.054443    0.035463    0.661314    
#> 299: 0.221579    1.101062    3.459532    0.311980    0.054410    0.035425    0.660998    
#> 300: 0.221832    1.101035    3.459698    0.311670    0.054340    0.035391    0.660860    
#> 301: 0.221873    1.101086    3.459660    0.311417    0.054339    0.035308    0.660885    
#> 302: 0.222074    1.101221    3.459571    0.310986    0.054299    0.035268    0.660847    
#> 303: 0.221913    1.101428    3.459339    0.310419    0.054323    0.035209    0.660780    
#> 304: 0.221685    1.101761    3.459277    0.309832    0.054330    0.035186    0.660789    
#> 305: 0.221438    1.101764    3.459171    0.309480    0.054290    0.035184    0.660808    
#> 306: 0.220954    1.101893    3.458930    0.309329    0.054321    0.035168    0.660717    
#> 307: 0.220299    1.101975    3.458783    0.309220    0.054324    0.035175    0.660806    
#> 308: 0.219919    1.101941    3.458783    0.308945    0.054332    0.035185    0.660977    
#> 309: 0.220015    1.101723    3.458824    0.308941    0.054460    0.035210    0.661165    
#> 310: 0.220162    1.101666    3.458759    0.309588    0.054550    0.035181    0.661240    
#> 311: 0.220165    1.101616    3.458754    0.309479    0.054546    0.035137    0.661198    
#> 312: 0.220126    1.101471    3.458766    0.309138    0.054563    0.035095    0.661292    
#> 313: 0.219794    1.101274    3.458643    0.308556    0.054578    0.035069    0.661462    
#> 314: 0.219268    1.101302    3.458461    0.308099    0.054539    0.035035    0.661714    
#> 315: 0.218712    1.101430    3.458260    0.307740    0.054423    0.035032    0.662041    
#> 316: 0.218536    1.101554    3.458063    0.307191    0.054380    0.035048    0.662118    
#> 317: 0.218539    1.101423    3.458157    0.307017    0.054287    0.035040    0.662316    
#> 318: 0.218780    1.101448    3.458121    0.306867    0.054224    0.035012    0.662305    
#> 319: 0.219115    1.101302    3.458266    0.306583    0.054175    0.035028    0.662456    
#> 320: 0.218993    1.101194    3.458277    0.306286    0.054166    0.034996    0.662580    
#> 321: 0.218711    1.101258    3.458170    0.305879    0.054133    0.034974    0.662618    
#> 322: 0.218570    1.101244    3.458125    0.305260    0.054126    0.034952    0.662592    
#> 323: 0.218129    1.101306    3.458035    0.304820    0.054203    0.034911    0.662594    
#> 324: 0.217924    1.101222    3.458041    0.304452    0.054266    0.034903    0.662618    
#> 325: 0.217726    1.101348    3.457940    0.304354    0.054335    0.034894    0.662586    
#> 326: 0.217552    1.101366    3.457879    0.304608    0.054300    0.034945    0.662463    
#> 327: 0.217800    1.101314    3.457956    0.304943    0.054255    0.035015    0.662414    
#> 328: 0.217843    1.101397    3.457968    0.305091    0.054250    0.035042    0.662313    
#> 329: 0.217890    1.101486    3.458011    0.305151    0.054172    0.035030    0.662145    
#> 330: 0.217768    1.101498    3.458023    0.305238    0.054265    0.035044    0.662181    
#> 331: 0.218012    1.101601    3.458048    0.305620    0.054353    0.035063    0.662058    
#> 332: 0.218283    1.101559    3.458167    0.305974    0.054360    0.035106    0.662094    
#> 333: 0.218226    1.101604    3.458170    0.306203    0.054343    0.035137    0.662051    
#> 334: 0.218123    1.101400    3.458016    0.306339    0.054316    0.035177    0.662091    
#> 335: 0.217930    1.101444    3.457852    0.306471    0.054314    0.035165    0.662094    
#> 336: 0.217510    1.101593    3.457680    0.306423    0.054277    0.035181    0.662162    
#> 337: 0.217275    1.101959    3.457476    0.307042    0.054343    0.035200    0.662170    
#> 338: 0.217187    1.101990    3.457498    0.307090    0.054303    0.035257    0.662045    
#> 339: 0.216984    1.102199    3.457397    0.307387    0.054302    0.035273    0.661967    
#> 340: 0.216882    1.102096    3.457349    0.307621    0.054405    0.035277    0.661872    
#> 341: 0.216844    1.102138    3.457377    0.307778    0.054515    0.035244    0.661852    
#> 342: 0.216530    1.102037    3.457347    0.307688    0.054603    0.035225    0.661856    
#> 343: 0.216365    1.102057    3.457367    0.307294    0.054686    0.035212    0.661934    
#> 344: 0.216473    1.101999    3.457411    0.306881    0.054769    0.035194    0.662105    
#> 345: 0.216373    1.101925    3.457452    0.306643    0.054798    0.035206    0.662178    
#> 346: 0.216183    1.101894    3.457423    0.306576    0.054789    0.035231    0.662165    
#> 347: 0.216145    1.101776    3.457491    0.306570    0.054809    0.035254    0.662151    
#> 348: 0.216015    1.101867    3.457458    0.306923    0.054839    0.035286    0.662092    
#> 349: 0.215869    1.101864    3.457381    0.307273    0.054861    0.035280    0.661990    
#> 350: 0.215584    1.101795    3.457252    0.307504    0.054812    0.035280    0.661981    
#> 351: 0.215484    1.101954    3.457131    0.308081    0.054809    0.035282    0.661934    
#> 352: 0.215235    1.102085    3.457084    0.308400    0.054737    0.035303    0.662051    
#> 353: 0.215359    1.102197    3.457108    0.308481    0.054725    0.035328    0.662080    
#> 354: 0.215280    1.102316    3.457031    0.308789    0.054730    0.035303    0.661995    
#> 355: 0.215180    1.102198    3.456899    0.308571    0.054754    0.035257    0.662091    
#> 356: 0.215015    1.102142    3.456836    0.308439    0.054754    0.035231    0.662229    
#> 357: 0.215056    1.102228    3.456785    0.308351    0.054841    0.035184    0.662126    
#> 358: 0.214960    1.102344    3.456731    0.308276    0.054868    0.035154    0.662028    
#> 359: 0.214990    1.102510    3.456671    0.308037    0.054838    0.035090    0.661994    
#> 360: 0.214833    1.102705    3.456506    0.307706    0.054817    0.035024    0.661920    
#> 361: 0.214616    1.102824    3.456378    0.307617    0.054793    0.034967    0.661789    
#> 362: 0.214623    1.102885    3.456262    0.307674    0.054829    0.034899    0.661658    
#> 363: 0.214542    1.102849    3.456211    0.307697    0.054852    0.034855    0.661558    
#> 364: 0.214560    1.102948    3.456193    0.307610    0.054869    0.034830    0.661549    
#> 365: 0.214605    1.102886    3.456240    0.307425    0.054801    0.034826    0.661551    
#> 366: 0.214854    1.102838    3.456308    0.307382    0.054763    0.034819    0.661582    
#> 367: 0.214901    1.102846    3.456375    0.307332    0.054743    0.034819    0.661617    
#> 368: 0.214961    1.103009    3.456321    0.307368    0.054758    0.034854    0.661531    
#> 369: 0.214888    1.103077    3.456256    0.307454    0.054784    0.034871    0.661538    
#> 370: 0.214683    1.103171    3.456100    0.307509    0.054812    0.034838    0.661575    
#> 371: 0.214239    1.103367    3.455832    0.307631    0.054836    0.034803    0.661621    
#> 372: 0.213963    1.103585    3.455664    0.307645    0.054828    0.034808    0.661663    
#> 373: 0.213497    1.103898    3.455473    0.307922    0.054838    0.034812    0.661698    
#> 374: 0.213217    1.104035    3.455345    0.307874    0.054849    0.034830    0.661627    
#> 375: 0.212911    1.104070    3.455215    0.307744    0.054787    0.034820    0.661688    
#> 376: 0.212753    1.104130    3.455167    0.307779    0.054744    0.034822    0.661631    
#> 377: 0.212463    1.104194    3.455061    0.307895    0.054693    0.034814    0.661622    
#> 378: 0.212385    1.104190    3.454966    0.308062    0.054653    0.034782    0.661597    
#> 379: 0.212453    1.103970    3.455034    0.308179    0.054660    0.034826    0.661598    
#> 380: 0.212446    1.103877    3.455081    0.308011    0.054679    0.034809    0.661517    
#> 381: 0.212283    1.103808    3.455054    0.307983    0.054727    0.034797    0.661528    
#> 382: 0.212197    1.103787    3.455060    0.307764    0.054723    0.034792    0.661410    
#> 383: 0.212298    1.103873    3.455082    0.307791    0.054756    0.034800    0.661202    
#> 384: 0.212161    1.103887    3.455092    0.307888    0.054680    0.034813    0.661179    
#> 385: 0.212253    1.103902    3.455109    0.308179    0.054635    0.034863    0.661153    
#> 386: 0.212277    1.104032    3.455111    0.308232    0.054653    0.034887    0.661287    
#> 387: 0.212364    1.104151    3.455171    0.308535    0.054693    0.034882    0.661252    
#> 388: 0.212407    1.104181    3.455121    0.308505    0.054700    0.034870    0.661170    
#> 389: 0.212213    1.104103    3.455056    0.308499    0.054756    0.034835    0.661206    
#> 390: 0.212122    1.104154    3.455020    0.308541    0.054822    0.034799    0.661226    
#> 391: 0.212162    1.104172    3.455009    0.308767    0.054862    0.034776    0.661283    
#> 392: 0.212113    1.104134    3.455000    0.308739    0.054892    0.034787    0.661262    
#> 393: 0.212086    1.104049    3.454953    0.308696    0.054901    0.034790    0.661211    
#> 394: 0.212157    1.103996    3.454939    0.308851    0.054839    0.034796    0.661263    
#> 395: 0.212417    1.104054    3.454945    0.308944    0.054840    0.034793    0.661290    
#> 396: 0.212710    1.103972    3.455074    0.308883    0.054860    0.034803    0.661229    
#> 397: 0.212914    1.103913    3.455201    0.308832    0.054896    0.034784    0.661259    
#> 398: 0.213121    1.103834    3.455343    0.308937    0.054946    0.034781    0.661225    
#> 399: 0.213352    1.103799    3.455439    0.309069    0.055015    0.034784    0.661219    
#> 400: 0.213443    1.103797    3.455504    0.308962    0.055010    0.034770    0.661181    
#> 401: 0.213595    1.103804    3.455548    0.308917    0.055027    0.034767    0.661286    
#> 402: 0.213708    1.103821    3.455610    0.308755    0.054996    0.034780    0.661329    
#> 403: 0.214163    1.103808    3.455690    0.308738    0.054936    0.034793    0.661367    
#> 404: 0.214282    1.103795    3.455718    0.308539    0.054946    0.034776    0.661267    
#> 405: 0.214447    1.103760    3.455819    0.308510    0.054906    0.034792    0.661256    
#> 406: 0.214657    1.103727    3.455840    0.308608    0.054869    0.034788    0.661285    
#> 407: 0.214679    1.103789    3.455827    0.308724    0.054840    0.034790    0.661229    
#> 408: 0.214795    1.103875    3.455874    0.308603    0.054801    0.034781    0.661265    
#> 409: 0.214806    1.103923    3.455862    0.308672    0.054836    0.034766    0.661186    
#> 410: 0.214822    1.103994    3.455833    0.308469    0.054879    0.034730    0.661175    
#> 411: 0.214944    1.103891    3.455854    0.308571    0.054942    0.034719    0.661144    
#> 412: 0.214990    1.103924    3.455856    0.308470    0.054973    0.034681    0.661197    
#> 413: 0.214920    1.103961    3.455824    0.308352    0.054989    0.034648    0.661269    
#> 414: 0.214767    1.103982    3.455878    0.308270    0.054984    0.034650    0.661309    
#> 415: 0.214818    1.103920    3.455883    0.308302    0.054976    0.034637    0.661294    
#> 416: 0.214861    1.104005    3.455891    0.308317    0.054985    0.034634    0.661213    
#> 417: 0.214900    1.104023    3.455895    0.308183    0.054997    0.034618    0.661178    
#> 418: 0.214688    1.104023    3.455917    0.308180    0.055000    0.034606    0.661133    
#> 419: 0.214694    1.104115    3.455903    0.308132    0.054943    0.034619    0.661064    
#> 420: 0.214800    1.104196    3.455891    0.308117    0.054925    0.034648    0.661070    
#> 421: 0.214760    1.104221    3.455954    0.307946    0.054913    0.034678    0.661029    
#> 422: 0.214949    1.104164    3.456009    0.308030    0.054879    0.034704    0.660994    
#> 423: 0.215123    1.104028    3.456073    0.307817    0.054875    0.034689    0.660986    
#> 424: 0.215187    1.103897    3.456080    0.307727    0.054864    0.034691    0.660933    
#> 425: 0.215377    1.103924    3.456116    0.307797    0.054898    0.034719    0.660935    
#> 426: 0.215488    1.103938    3.456148    0.307722    0.054876    0.034727    0.660884    
#> 427: 0.215411    1.103893    3.456202    0.307587    0.054860    0.034712    0.660883    
#> 428: 0.215268    1.103921    3.456223    0.307758    0.054801    0.034694    0.660864    
#> 429: 0.215270    1.103916    3.456248    0.307954    0.054788    0.034676    0.660920    
#> 430: 0.215370    1.103946    3.456268    0.308110    0.054759    0.034654    0.661019    
#> 431: 0.215347    1.103919    3.456259    0.307883    0.054720    0.034623    0.661032    
#> 432: 0.215290    1.103972    3.456300    0.307801    0.054736    0.034597    0.661049    
#> 433: 0.215375    1.103978    3.456316    0.307878    0.054753    0.034575    0.661055    
#> 434: 0.215456    1.103820    3.456357    0.307903    0.054775    0.034564    0.661033    
#> 435: 0.215471    1.103819    3.456367    0.307745    0.054794    0.034544    0.660976    
#> 436: 0.215486    1.103827    3.456440    0.307555    0.054898    0.034541    0.660992    
#> 437: 0.215715    1.103773    3.456540    0.307704    0.054936    0.034542    0.660972    
#> 438: 0.215884    1.103876    3.456602    0.307885    0.054985    0.034559    0.660865    
#> 439: 0.216020    1.103922    3.456647    0.307806    0.055002    0.034560    0.660769    
#> 440: 0.215937    1.103956    3.456674    0.307556    0.055039    0.034539    0.660787    
#> 441: 0.215993    1.103895    3.456695    0.307294    0.055014    0.034544    0.660788    
#> 442: 0.215926    1.103884    3.456666    0.307226    0.054979    0.034526    0.660762    
#> 443: 0.215901    1.103926    3.456624    0.307241    0.054952    0.034542    0.660683    
#> 444: 0.215809    1.104023    3.456522    0.307188    0.054909    0.034557    0.660608    
#> 445: 0.215714    1.104053    3.456467    0.307203    0.054898    0.034593    0.660563    
#> 446: 0.215543    1.104112    3.456406    0.307238    0.054841    0.034606    0.660536    
#> 447: 0.215508    1.104166    3.456382    0.307197    0.054802    0.034613    0.660607    
#> 448: 0.215421    1.104250    3.456371    0.307119    0.054777    0.034613    0.660528    
#> 449: 0.215312    1.104389    3.456377    0.307133    0.054741    0.034612    0.660468    
#> 450: 0.215231    1.104419    3.456342    0.307088    0.054722    0.034636    0.660435    
#> 451: 0.215348    1.104437    3.456322    0.307156    0.054668    0.034670    0.660435    
#> 452: 0.215354    1.104444    3.456339    0.307150    0.054637    0.034662    0.660421    
#> 453: 0.215384    1.104453    3.456333    0.307000    0.054630    0.034678    0.660358    
#> 454: 0.215345    1.104592    3.456286    0.306895    0.054612    0.034683    0.660302    
#> 455: 0.215340    1.104648    3.456250    0.306926    0.054593    0.034683    0.660271    
#> 456: 0.215348    1.104624    3.456250    0.306926    0.054592    0.034690    0.660296    
#> 457: 0.215223    1.104601    3.456254    0.306985    0.054580    0.034717    0.660259    
#> 458: 0.215184    1.104717    3.456295    0.306878    0.054595    0.034747    0.660219    
#> 459: 0.215115    1.104743    3.456298    0.306752    0.054561    0.034761    0.660157    
#> 460: 0.214933    1.104750    3.456216    0.306596    0.054526    0.034765    0.660137    
#> 461: 0.214716    1.104791    3.456163    0.306649    0.054495    0.034770    0.660126    
#> 462: 0.214552    1.104883    3.456165    0.306691    0.054471    0.034789    0.660072    
#> 463: 0.214488    1.104985    3.456160    0.306770    0.054468    0.034785    0.660020    
#> 464: 0.214471    1.105051    3.456092    0.306884    0.054444    0.034766    0.660012    
#> 465: 0.214431    1.104974    3.456081    0.306826    0.054434    0.034744    0.660012    
#> 466: 0.214447    1.104981    3.456052    0.306950    0.054416    0.034729    0.660006    
#> 467: 0.214346    1.104926    3.456056    0.306971    0.054413    0.034717    0.659972    
#> 468: 0.214533    1.104914    3.456115    0.307201    0.054431    0.034696    0.660002    
#> 469: 0.214615    1.104930    3.456091    0.307238    0.054469    0.034654    0.660034    
#> 470: 0.214566    1.104949    3.456057    0.307161    0.054454    0.034648    0.659997    
#> 471: 0.214450    1.104926    3.456064    0.307004    0.054424    0.034648    0.659982    
#> 472: 0.214396    1.104883    3.456058    0.306809    0.054428    0.034623    0.659949    
#> 473: 0.214330    1.104870    3.456024    0.306733    0.054412    0.034609    0.659912    
#> 474: 0.214320    1.104857    3.456050    0.306878    0.054344    0.034620    0.659997    
#> 475: 0.214410    1.104960    3.456054    0.306913    0.054333    0.034613    0.659991    
#> 476: 0.214544    1.104969    3.456087    0.306838    0.054310    0.034608    0.660062    
#> 477: 0.214413    1.105030    3.456074    0.306789    0.054314    0.034607    0.659991    
#> 478: 0.214384    1.105006    3.456119    0.306574    0.054274    0.034602    0.660006    
#> 479: 0.214538    1.105036    3.456195    0.306375    0.054273    0.034609    0.659969    
#> 480: 0.214622    1.105010    3.456228    0.306204    0.054305    0.034585    0.659968    
#> 481: 0.214596    1.105042    3.456227    0.306023    0.054305    0.034571    0.659914    
#> 482: 0.214684    1.105120    3.456192    0.305983    0.054325    0.034565    0.659928    
#> 483: 0.214630    1.105127    3.456181    0.305880    0.054366    0.034565    0.659910    
#> 484: 0.214605    1.105065    3.456179    0.305708    0.054376    0.034558    0.659927    
#> 485: 0.214661    1.105081    3.456182    0.305641    0.054393    0.034561    0.659982    
#> 486: 0.214642    1.105169    3.456184    0.305486    0.054422    0.034554    0.659954    
#> 487: 0.214701    1.105180    3.456221    0.305385    0.054445    0.034557    0.659923    
#> 488: 0.214709    1.105195    3.456230    0.305233    0.054446    0.034547    0.659893    
#> 489: 0.214860    1.105174    3.456247    0.305238    0.054451    0.034531    0.659922    
#> 490: 0.214952    1.105207    3.456267    0.305195    0.054454    0.034507    0.659905    
#> 491: 0.215003    1.105259    3.456306    0.305249    0.054432    0.034505    0.659847    
#> 492: 0.215122    1.105296    3.456322    0.305352    0.054452    0.034509    0.659924    
#> 493: 0.215077    1.105288    3.456301    0.305333    0.054453    0.034504    0.659896    
#> 494: 0.215138    1.105366    3.456285    0.305281    0.054494    0.034489    0.659878    
#> 495: 0.215200    1.105405    3.456281    0.305286    0.054501    0.034489    0.659806    
#> 496: 0.215225    1.105406    3.456290    0.305352    0.054495    0.034498    0.659760    
#> 497: 0.215173    1.105416    3.456252    0.305395    0.054501    0.034512    0.659784    
#> 498: 0.215037    1.105433    3.456163    0.305577    0.054520    0.034536    0.659743    
#> 499: 0.214908    1.105494    3.456066    0.305746    0.054531    0.034556    0.659679    
#> 500: 0.214865    1.105518    3.455990    0.305782    0.054517    0.034565    0.659629    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.303012    0.971773    3.453782    0.392401    0.084026    0.016800    1.826781    
#> 002: 0.212347    1.039875    3.491475    0.372781    0.079825    0.016713    1.070736    
#> 003: 0.311724    0.989806    3.499428    0.354142    0.087444    0.015877    0.801818    
#> 004: 0.256716    1.001657    3.489192    0.348522    0.094836    0.015083    0.678603    
#> 005: 0.325092    1.005044    3.485416    0.422360    0.093181    0.014329    0.606755    
#> 006: 0.291491    1.004707    3.476118    0.405954    0.094366    0.013613    0.566658    
#> 007: 0.238023    1.023852    3.466368    0.395167    0.089987    0.012932    0.561432    
#> 008: 0.258929    1.024160    3.463259    0.458662    0.089796    0.012285    0.567216    
#> 009: 0.249871    0.999989    3.464159    0.496487    0.093272    0.011671    0.558574    
#> 010: 0.247843    1.006325    3.465077    0.487115    0.088608    0.015638    0.561429    
#> 011: 0.326070    1.003502    3.475854    0.504896    0.096899    0.016086    0.546797    
#> 012: 0.291737    1.007620    3.469836    0.479651    0.092332    0.016790    0.554591    
#> 013: 0.280216    1.018639    3.459961    0.455668    0.095272    0.016064    0.544934    
#> 014: 0.280860    1.018394    3.465715    0.497603    0.102175    0.015261    0.534486    
#> 015: 0.302382    1.015134    3.475235    0.472723    0.097066    0.017730    0.506874    
#> 016: 0.328144    1.019939    3.481085    0.526799    0.099331    0.016843    0.520518    
#> 017: 0.280138    1.021030    3.472449    0.514031    0.105589    0.016001    0.520547    
#> 018: 0.283287    1.013637    3.466612    0.488330    0.110925    0.016021    0.525126    
#> 019: 0.248316    1.025706    3.468323    0.463913    0.105379    0.015418    0.513194    
#> 020: 0.299282    1.023608    3.470614    0.552653    0.100110    0.016373    0.516809    
#> 021: 0.297512    1.005353    3.482766    0.538958    0.095105    0.016548    0.503780    
#> 022: 0.338299    1.005450    3.494609    0.624156    0.090349    0.019945    0.497564    
#> 023: 0.386052    1.023270    3.498096    0.658041    0.090525    0.020850    0.512062    
#> 024: 0.380681    1.017849    3.494915    0.628464    0.085999    0.020506    0.500911    
#> 025: 0.322682    1.012579    3.482181    0.597041    0.085944    0.020301    0.509103    
#> 026: 0.298956    1.030368    3.474610    0.567189    0.081647    0.022110    0.512902    
#> 027: 0.313835    1.037267    3.486628    0.538829    0.086651    0.022436    0.519724    
#> 028: 0.326233    1.012108    3.485968    0.546546    0.082319    0.024379    0.514398    
#> 029: 0.291159    1.019609    3.479597    0.519219    0.085665    0.026707    0.515649    
#> 030: 0.299239    1.015406    3.474409    0.493258    0.081382    0.025372    0.510432    
#> 031: 0.295539    1.006526    3.489121    0.511993    0.085498    0.024103    0.512925    
#> 032: 0.306627    0.992803    3.489840    0.561829    0.081223    0.022898    0.523950    
#> 033: 0.305572    1.005578    3.487262    0.547657    0.079403    0.024146    0.508452    
#> 034: 0.339995    1.021545    3.488325    0.520274    0.075433    0.022939    0.516196    
#> 035: 0.326425    1.002534    3.498996    0.494261    0.072803    0.021792    0.508113    
#> 036: 0.336527    1.015459    3.497254    0.469548    0.085655    0.020702    0.507875    
#> 037: 0.335417    1.010596    3.502293    0.446245    0.092501    0.021129    0.522021    
#> 038: 0.324718    1.008491    3.495907    0.431375    0.087876    0.021004    0.519909    
#> 039: 0.327496    1.017583    3.493127    0.445433    0.085807    0.019954    0.514338    
#> 040: 0.304175    1.010244    3.494588    0.423161    0.081516    0.018956    0.519644    
#> 041: 0.299586    1.008281    3.488054    0.402003    0.077440    0.020371    0.516301    
#> 042: 0.319989    1.006585    3.484166    0.429158    0.084668    0.020598    0.514156    
#> 043: 0.291335    1.017766    3.478842    0.439727    0.080434    0.020095    0.519263    
#> 044: 0.304107    1.022598    3.479274    0.455505    0.092725    0.019090    0.524653    
#> 045: 0.270609    1.027019    3.473255    0.432730    0.088089    0.018136    0.517815    
#> 046: 0.284109    1.008906    3.481672    0.411094    0.085802    0.017229    0.512533    
#> 047: 0.290496    1.036590    3.479118    0.433722    0.083281    0.016368    0.515934    
#> 048: 0.291203    1.023904    3.480572    0.466129    0.096194    0.019178    0.519005    
#> 049: 0.282366    1.028263    3.478900    0.442823    0.091384    0.019168    0.524347    
#> 050: 0.306519    0.996789    3.482896    0.498956    0.090358    0.018209    0.535686    
#> 051: 0.290550    1.002583    3.482852    0.474008    0.099364    0.017299    0.531992    
#> 052: 0.345629    1.002321    3.498331    0.468611    0.094396    0.016434    0.522433    
#> 053: 0.328139    0.996931    3.491719    0.473065    0.095973    0.015612    0.518311    
#> 054: 0.306251    1.001450    3.493771    0.449412    0.091175    0.017112    0.528830    
#> 055: 0.327274    1.010858    3.492933    0.426941    0.086616    0.018238    0.525533    
#> 056: 0.353346    1.011118    3.498877    0.509533    0.087523    0.021059    0.510195    
#> 057: 0.349484    1.002774    3.498899    0.546287    0.083146    0.021767    0.514281    
#> 058: 0.308294    1.010549    3.483521    0.518972    0.078989    0.023964    0.514620    
#> 059: 0.300074    0.980469    3.481453    0.493024    0.077528    0.024933    0.530844    
#> 060: 0.313150    0.999523    3.490505    0.491041    0.076972    0.023686    0.531952    
#> 061: 0.350415    1.000527    3.504804    0.491977    0.088939    0.022502    0.532881    
#> 062: 0.346082    1.007506    3.501521    0.543658    0.100215    0.021546    0.537430    
#> 063: 0.368379    0.986472    3.497209    0.558784    0.095204    0.025580    0.533548    
#> 064: 0.292980    1.021054    3.482835    0.530845    0.090444    0.024301    0.536923    
#> 065: 0.311495    1.019117    3.475595    0.504302    0.085922    0.023086    0.520597    
#> 066: 0.317790    1.024236    3.482790    0.563173    0.087688    0.021931    0.523930    
#> 067: 0.290467    1.018838    3.467158    0.573200    0.084664    0.020835    0.517093    
#> 068: 0.267745    1.041840    3.476860    0.566583    0.111108    0.021481    0.532298    
#> 069: 0.270208    1.023158    3.458552    0.559013    0.105553    0.023578    0.526516    
#> 070: 0.297311    1.020160    3.485309    0.588824    0.100275    0.025223    0.527395    
#> 071: 0.296701    1.028648    3.464367    0.559382    0.095261    0.024720    0.525867    
#> 072: 0.281430    1.019471    3.466749    0.531413    0.090498    0.023867    0.511365    
#> 073: 0.281300    1.039498    3.486846    0.504843    0.091070    0.023593    0.528108    
#> 074: 0.297429    1.007874    3.482610    0.479601    0.086516    0.022413    0.516734    
#> 075: 0.313550    1.011329    3.502405    0.455621    0.083494    0.021293    0.507243    
#> 076: 0.344534    1.006636    3.509803    0.436142    0.079319    0.023334    0.510677    
#> 077: 0.353662    0.983452    3.513981    0.453964    0.075353    0.022468    0.522192    
#> 078: 0.344823    0.993937    3.506977    0.487019    0.086657    0.021345    0.504316    
#> 079: 0.330718    1.002193    3.504690    0.462668    0.096784    0.023556    0.516241    
#> 080: 0.330401    0.989602    3.504513    0.439534    0.091945    0.026733    0.516902    
#> 081: 0.310519    1.002782    3.501472    0.430500    0.087348    0.026094    0.512610    
#> 082: 0.334881    0.992415    3.494845    0.444368    0.088992    0.024790    0.515365    
#> 083: 0.358036    1.002204    3.497221    0.516786    0.084542    0.023550    0.520225    
#> 084: 0.335126    1.019354    3.490597    0.502355    0.082061    0.022373    0.513694    
#> 085: 0.340591    1.015701    3.508157    0.492302    0.077958    0.025631    0.518109    
#> 086: 0.346111    1.017271    3.493049    0.506174    0.081833    0.025344    0.508257    
#> 087: 0.331194    1.005185    3.485037    0.500732    0.077742    0.027404    0.511636    
#> 088: 0.284779    1.013527    3.486637    0.525986    0.079228    0.026034    0.519412    
#> 089: 0.285114    1.035904    3.461661    0.527571    0.091576    0.024732    0.520514    
#> 090: 0.251862    1.033200    3.453668    0.501192    0.095087    0.023496    0.524551    
#> 091: 0.244789    1.025001    3.446668    0.557776    0.092140    0.022321    0.536491    
#> 092: 0.245880    1.034618    3.454257    0.529887    0.097970    0.021205    0.528525    
#> 093: 0.224723    1.033829    3.452764    0.503393    0.096189    0.020145    0.533878    
#> 094: 0.249016    1.046473    3.448231    0.487158    0.104487    0.019137    0.531478    
#> 095: 0.262046    1.041524    3.466480    0.485307    0.113060    0.018181    0.531541    
#> 096: 0.240375    1.041478    3.458528    0.468551    0.107407    0.017271    0.528555    
#> 097: 0.280408    1.032284    3.464900    0.477433    0.106139    0.016408    0.533731    
#> 098: 0.285029    1.039017    3.472701    0.456628    0.109941    0.015588    0.533961    
#> 099: 0.252933    1.011748    3.466653    0.433797    0.105240    0.014808    0.532533    
#> 100: 0.258330    1.028551    3.471323    0.416627    0.099978    0.014068    0.522595    
#> 101: 0.244217    1.012211    3.452148    0.423217    0.100811    0.013364    0.526876    
#> 102: 0.258332    1.015996    3.455967    0.434217    0.102503    0.012696    0.531646    
#> 103: 0.260491    1.017100    3.469001    0.464663    0.103500    0.012873    0.530379    
#> 104: 0.261610    1.030906    3.479456    0.441430    0.101448    0.012229    0.531796    
#> 105: 0.292561    1.012065    3.480290    0.442286    0.103808    0.011618    0.543532    
#> 106: 0.289486    1.005419    3.484193    0.420172    0.107779    0.011037    0.530445    
#> 107: 0.264681    1.022148    3.479178    0.404596    0.115624    0.011037    0.526903    
#> 108: 0.249829    0.992243    3.477475    0.411240    0.109843    0.012673    0.547349    
#> 109: 0.288643    1.008472    3.487719    0.422831    0.118826    0.012040    0.547988    
#> 110: 0.289748    1.012600    3.483201    0.401690    0.115207    0.011438    0.536377    
#> 111: 0.299836    1.004409    3.486312    0.393732    0.119638    0.010866    0.526808    
#> 112: 0.282081    1.002274    3.472453    0.409532    0.113656    0.011619    0.518707    
#> 113: 0.277651    1.032173    3.472940    0.545574    0.111814    0.011038    0.531380    
#> 114: 0.283975    1.022764    3.477050    0.518295    0.117662    0.012786    0.523400    
#> 115: 0.288064    0.998176    3.475708    0.492380    0.111779    0.013689    0.532333    
#> 116: 0.279288    1.016314    3.477819    0.467761    0.106190    0.016015    0.521785    
#> 117: 0.282001    1.031983    3.481454    0.444373    0.101962    0.015383    0.522051    
#> 118: 0.309151    1.003207    3.481481    0.459917    0.096864    0.014758    0.517322    
#> 119: 0.309311    1.015348    3.483158    0.465456    0.098967    0.019561    0.532078    
#> 120: 0.294370    1.004825    3.487017    0.442183    0.094018    0.021632    0.527950    
#> 121: 0.299685    1.023965    3.485145    0.458255    0.089317    0.020884    0.526189    
#> 122: 0.304292    1.006579    3.487977    0.553699    0.104390    0.019840    0.520549    
#> 123: 0.376876    1.022846    3.487679    0.593315    0.099170    0.018848    0.522577    
#> 124: 0.302048    1.044515    3.486809    0.563650    0.094212    0.017905    0.534298    
#> 125: 0.320717    1.037892    3.486294    0.535467    0.091539    0.017010    0.532932    
#> 126: 0.301936    1.037762    3.472294    0.508694    0.086963    0.016160    0.536073    
#> 127: 0.320606    1.002562    3.486562    0.483259    0.082614    0.017088    0.527116    
#> 128: 0.307087    0.996139    3.496742    0.464187    0.092122    0.018886    0.514330    
#> 129: 0.280959    1.005369    3.481875    0.440977    0.096310    0.017942    0.507809    
#> 130: 0.311753    0.998164    3.476415    0.465052    0.096670    0.017045    0.509852    
#> 131: 0.287017    0.996694    3.467344    0.483020    0.107185    0.016192    0.517542    
#> 132: 0.241762    1.027637    3.456143    0.458869    0.107046    0.015383    0.521983    
#> 133: 0.248640    1.031294    3.464198    0.467815    0.110367    0.017791    0.515053    
#> 134: 0.272089    1.006157    3.480610    0.459243    0.104849    0.021997    0.517921    
#> 135: 0.321947    1.007891    3.490967    0.483873    0.099606    0.022649    0.507600    
#> 136: 0.314277    0.994478    3.484768    0.481529    0.094626    0.021517    0.514329    
#> 137: 0.317670    1.006242    3.493732    0.458320    0.089895    0.022327    0.523944    
#> 138: 0.316817    1.020832    3.496482    0.435404    0.085400    0.022371    0.521242    
#> 139: 0.278511    1.009382    3.495877    0.416690    0.081130    0.024593    0.521934    
#> 140: 0.330512    1.020746    3.497405    0.453130    0.077094    0.027866    0.517737    
#> 141: 0.296689    0.998216    3.495553    0.430474    0.087191    0.026473    0.512760    
#> 142: 0.284079    1.000503    3.494638    0.408950    0.097689    0.025149    0.510440    
#> 143: 0.282962    1.025836    3.488106    0.417753    0.106077    0.023891    0.512595    
#> 144: 0.321195    1.022769    3.491902    0.424453    0.100773    0.022697    0.508768    
#> 145: 0.299177    1.026359    3.480592    0.436652    0.099771    0.021562    0.508400    
#> 146: 0.302630    1.014227    3.485920    0.451899    0.094782    0.020484    0.515792    
#> 147: 0.287882    1.005739    3.478472    0.475877    0.097393    0.019460    0.513393    
#> 148: 0.314413    1.029734    3.489948    0.530650    0.095321    0.019300    0.520364    
#> 149: 0.331600    1.005948    3.494763    0.504117    0.096250    0.020013    0.524047    
#> 150: 0.351926    0.988799    3.490065    0.478911    0.091438    0.019012    0.544753    
#> 151: 0.292633    1.019044    3.489645    0.454966    0.093403    0.018061    0.530088    
#> 152: 0.288499    1.015955    3.484305    0.477237    0.098851    0.015438    0.524081    
#> 153: 0.264656    1.006943    3.488098    0.446379    0.091599    0.017032    0.527052    
#> 154: 0.303250    1.020514    3.480728    0.454374    0.091576    0.018318    0.534430    
#> 155: 0.270052    1.017508    3.474672    0.438552    0.102669    0.016160    0.527457    
#> 156: 0.294812    1.029328    3.483658    0.407772    0.104441    0.013566    0.535678    
#> 157: 0.312949    1.018124    3.495174    0.441292    0.095835    0.013304    0.549797    
#> 158: 0.347873    1.005861    3.500449    0.431984    0.087145    0.015377    0.542504    
#> 159: 0.333134    1.007521    3.504256    0.460728    0.085317    0.016556    0.534375    
#> 160: 0.358061    0.985013    3.509842    0.412131    0.090740    0.016745    0.530938    
#> 161: 0.368748    0.975736    3.512077    0.427854    0.092230    0.016795    0.542430    
#> 162: 0.339828    0.984373    3.501586    0.438175    0.103687    0.015887    0.538243    
#> 163: 0.328738    0.994319    3.489506    0.413186    0.108857    0.015933    0.525489    
#> 164: 0.328969    1.005524    3.485940    0.446183    0.093115    0.015618    0.520044    
#> 165: 0.308487    1.004855    3.493677    0.440206    0.097448    0.017220    0.511221    
#> 166: 0.332795    1.030071    3.486906    0.447752    0.096932    0.017927    0.517173    
#> 167: 0.324770    1.026560    3.493366    0.464051    0.091943    0.018451    0.518740    
#> 168: 0.310972    1.016277    3.491368    0.442094    0.087696    0.018956    0.513535    
#> 169: 0.291567    1.043230    3.478805    0.426837    0.097346    0.016696    0.518069    
#> 170: 0.317678    1.023838    3.486147    0.429791    0.095248    0.015055    0.519602    
#> 171: 0.303814    1.020293    3.485681    0.429779    0.092311    0.016394    0.510644    
#> 172: 0.279525    1.035805    3.476875    0.462587    0.092424    0.017990    0.507825    
#> 173: 0.281040    1.032180    3.471574    0.429805    0.096296    0.017689    0.511868    
#> 174: 0.294068    1.027582    3.487982    0.409080    0.092634    0.017236    0.521071    
#> 175: 0.284407    1.025608    3.475475    0.459005    0.092142    0.018402    0.515952    
#> 176: 0.281378    1.029980    3.480846    0.454435    0.087305    0.019734    0.510674    
#> 177: 0.303458    1.026243    3.485695    0.462856    0.079261    0.020629    0.518818    
#> 178: 0.317203    1.006827    3.491858    0.476503    0.080832    0.023023    0.514048    
#> 179: 0.322811    1.015477    3.486043    0.472603    0.080055    0.024508    0.515617    
#> 180: 0.315978    1.016662    3.490220    0.447198    0.091131    0.022698    0.515401    
#> 181: 0.306900    1.008016    3.475326    0.420669    0.062414    0.019991    0.524024    
#> 182: 0.291017    1.016819    3.474779    0.435471    0.078908    0.020927    0.528096    
#> 183: 0.304415    1.031654    3.485563    0.386896    0.078056    0.018744    0.534632    
#> 184: 0.294200    1.020373    3.478303    0.404028    0.084732    0.018176    0.528913    
#> 185: 0.261159    1.034860    3.463059    0.420171    0.101164    0.018770    0.525510    
#> 186: 0.250231    1.034280    3.464312    0.388781    0.103495    0.018505    0.527585    
#> 187: 0.264843    1.027131    3.468471    0.409004    0.097035    0.015255    0.538143    
#> 188: 0.244486    1.030901    3.466689    0.388645    0.091107    0.016341    0.538866    
#> 189: 0.317404    1.029739    3.485959    0.423357    0.074662    0.017779    0.548423    
#> 190: 0.311455    1.027819    3.486439    0.392396    0.072338    0.015561    0.516664    
#> 191: 0.330278    1.023272    3.484753    0.436014    0.086536    0.012616    0.511801    
#> 192: 0.306720    1.027992    3.486032    0.460974    0.087365    0.014837    0.507041    
#> 193: 0.309325    1.031757    3.483296    0.431467    0.099384    0.012824    0.512099    
#> 194: 0.297765    1.013825    3.483786    0.406722    0.096483    0.012613    0.513284    
#> 195: 0.261304    1.009582    3.480283    0.395929    0.094908    0.013594    0.513590    
#> 196: 0.287080    0.998493    3.488278    0.415188    0.092167    0.015692    0.521684    
#> 197: 0.295786    1.014281    3.501782    0.415344    0.090414    0.017883    0.533458    
#> 198: 0.338403    0.992874    3.500880    0.400120    0.094254    0.014001    0.523450    
#> 199: 0.333097    0.989035    3.504835    0.381002    0.090158    0.016703    0.542225    
#> 200: 0.347918    0.984940    3.507558    0.364245    0.090060    0.018598    0.548763    
#> 201: 0.346634    0.989884    3.508073    0.391530    0.093293    0.018112    0.544352    
#> 202: 0.337263    0.996689    3.503679    0.415336    0.091601    0.018011    0.541845    
#> 203: 0.334281    0.996999    3.499658    0.409703    0.092708    0.018330    0.541300    
#> 204: 0.332524    0.995926    3.499633    0.419570    0.092518    0.018231    0.542124    
#> 205: 0.327854    1.000553    3.499274    0.415084    0.091053    0.017937    0.544273    
#> 206: 0.328809    1.004631    3.498276    0.429609    0.091065    0.017746    0.542118    
#> 207: 0.329757    1.005952    3.497125    0.425645    0.092510    0.017611    0.540684    
#> 208: 0.329396    1.008177    3.496012    0.424801    0.092710    0.017461    0.536951    
#> 209: 0.329259    1.007610    3.494966    0.423651    0.092622    0.017386    0.534527    
#> 210: 0.328207    1.007096    3.494575    0.423663    0.092372    0.017258    0.531894    
#> 211: 0.329251    1.006568    3.495307    0.423038    0.092599    0.017191    0.530324    
#> 212: 0.329899    1.006013    3.495781    0.421872    0.092393    0.017151    0.529613    
#> 213: 0.331970    1.003927    3.496163    0.426478    0.093265    0.017082    0.530348    
#> 214: 0.333083    1.002128    3.496407    0.426532    0.094099    0.016980    0.530199    
#> 215: 0.333534    1.002217    3.496731    0.424506    0.094267    0.016897    0.531061    
#> 216: 0.336902    1.001523    3.497661    0.424321    0.094685    0.016847    0.532270    
#> 217: 0.337365    1.001397    3.498356    0.421354    0.094904    0.016721    0.532012    
#> 218: 0.338067    1.001083    3.498567    0.420550    0.094623    0.016567    0.531525    
#> 219: 0.337213    1.000409    3.498279    0.419359    0.094009    0.016489    0.531462    
#> 220: 0.334571    1.000582    3.497747    0.419793    0.093823    0.016538    0.531119    
#> 221: 0.332403    1.001306    3.496990    0.420611    0.093576    0.016514    0.530782    
#> 222: 0.331229    1.001485    3.496459    0.420893    0.093958    0.016560    0.530515    
#> 223: 0.330046    1.001897    3.495861    0.421458    0.093488    0.016584    0.530736    
#> 224: 0.329946    1.002528    3.495807    0.422194    0.093630    0.016635    0.530036    
#> 225: 0.329973    1.001385    3.496208    0.424327    0.092949    0.016769    0.530136    
#> 226: 0.329406    1.000868    3.496104    0.425465    0.092524    0.016811    0.529706    
#> 227: 0.329303    1.000799    3.496018    0.426553    0.092318    0.016868    0.529500    
#> 228: 0.328354    1.001340    3.495313    0.426872    0.092384    0.016952    0.528900    
#> 229: 0.327056    1.001976    3.494590    0.427751    0.092219    0.016984    0.528600    
#> 230: 0.325786    1.002528    3.494014    0.428971    0.092069    0.016944    0.528718    
#> 231: 0.324389    1.003408    3.493681    0.429129    0.092189    0.016944    0.528136    
#> 232: 0.323609    1.003835    3.493567    0.430861    0.092347    0.016933    0.527614    
#> 233: 0.322828    1.003435    3.493669    0.431991    0.092360    0.016908    0.527504    
#> 234: 0.322950    1.003559    3.493500    0.433667    0.092273    0.016997    0.527448    
#> 235: 0.322290    1.004014    3.493184    0.433811    0.092304    0.016991    0.527242    
#> 236: 0.322070    1.004518    3.492934    0.433985    0.092408    0.017039    0.527021    
#> 237: 0.322199    1.004569    3.492966    0.433951    0.092236    0.017141    0.527197    
#> 238: 0.322924    1.004543    3.493066    0.433877    0.091873    0.017198    0.527776    
#> 239: 0.322801    1.005253    3.492917    0.432652    0.092150    0.017099    0.528297    
#> 240: 0.322225    1.005145    3.492961    0.432108    0.092582    0.017023    0.528359    
#> 241: 0.321997    1.004258    3.493095    0.431547    0.092718    0.016989    0.528522    
#> 242: 0.321377    1.003450    3.492954    0.430279    0.092831    0.017005    0.528939    
#> 243: 0.320984    1.003642    3.492803    0.429742    0.093093    0.017006    0.528973    
#> 244: 0.320810    1.003650    3.492912    0.430353    0.093253    0.017011    0.529144    
#> 245: 0.320894    1.002702    3.493254    0.430365    0.093316    0.017085    0.529729    
#> 246: 0.321253    1.002335    3.493419    0.430199    0.093196    0.017156    0.529889    
#> 247: 0.321413    1.002001    3.493425    0.430625    0.093135    0.017272    0.530146    
#> 248: 0.320860    1.002518    3.493073    0.431391    0.093136    0.017304    0.530039    
#> 249: 0.320292    1.002792    3.492933    0.432135    0.092912    0.017324    0.529944    
#> 250: 0.319998    1.003029    3.492902    0.432946    0.092893    0.017443    0.529682    
#> 251: 0.320666    1.003332    3.493072    0.435038    0.093067    0.017521    0.529749    
#> 252: 0.321009    1.003824    3.493252    0.436495    0.093203    0.017529    0.529899    
#> 253: 0.321133    1.004027    3.493164    0.436974    0.093037    0.017597    0.529676    
#> 254: 0.321249    1.004173    3.493001    0.437704    0.093119    0.017622    0.529500    
#> 255: 0.321566    1.004325    3.493012    0.439440    0.093265    0.017675    0.529223    
#> 256: 0.321729    1.004251    3.492901    0.440378    0.093195    0.017766    0.529038    
#> 257: 0.321677    1.004268    3.492838    0.440758    0.093147    0.017817    0.528894    
#> 258: 0.321612    1.004323    3.492699    0.442521    0.093103    0.017824    0.528944    
#> 259: 0.322012    1.004498    3.492548    0.444603    0.093126    0.017879    0.528868    
#> 260: 0.322176    1.004562    3.492695    0.445475    0.093218    0.017925    0.528818    
#> 261: 0.321927    1.004494    3.492683    0.445113    0.093314    0.017952    0.528982    
#> 262: 0.322007    1.004433    3.492902    0.445168    0.093401    0.017990    0.529008    
#> 263: 0.322325    1.004440    3.493010    0.445190    0.093090    0.018039    0.529175    
#> 264: 0.321803    1.004541    3.492850    0.445056    0.092724    0.017992    0.529503    
#> 265: 0.321428    1.004626    3.492761    0.445163    0.092557    0.017953    0.529488    
#> 266: 0.321108    1.004811    3.492643    0.445204    0.092476    0.017900    0.529358    
#> 267: 0.320765    1.004935    3.492701    0.444999    0.092451    0.017857    0.529333    
#> 268: 0.320780    1.004888    3.492654    0.445949    0.092383    0.017811    0.529154    
#> 269: 0.321152    1.004989    3.492662    0.448062    0.092517    0.017772    0.529107    
#> 270: 0.321462    1.005288    3.492510    0.449349    0.092581    0.017745    0.528958    
#> 271: 0.321715    1.005454    3.492406    0.450315    0.092566    0.017712    0.529040    
#> 272: 0.322180    1.005269    3.492378    0.451599    0.092452    0.017704    0.529032    
#> 273: 0.321956    1.005357    3.492279    0.452146    0.092448    0.017700    0.528955    
#> 274: 0.321510    1.005567    3.492249    0.450854    0.092583    0.017663    0.528977    
#> 275: 0.321426    1.005688    3.492130    0.450819    0.092550    0.017640    0.528901    
#> 276: 0.320954    1.006004    3.492168    0.449934    0.092424    0.017662    0.528865    
#> 277: 0.320799    1.006265    3.492256    0.449707    0.092224    0.017693    0.528940    
#> 278: 0.320490    1.006306    3.492363    0.449165    0.092069    0.017706    0.528993    
#> 279: 0.320240    1.006095    3.492427    0.448833    0.091946    0.017782    0.529095    
#> 280: 0.320028    1.006145    3.492394    0.449022    0.091853    0.017814    0.529042    
#> 281: 0.319526    1.006297    3.492271    0.449131    0.091787    0.017796    0.529067    
#> 282: 0.319122    1.006513    3.492279    0.448809    0.091944    0.017771    0.529214    
#> 283: 0.319115    1.006560    3.492190    0.449101    0.092174    0.017764    0.529460    
#> 284: 0.318778    1.006624    3.492063    0.449136    0.092272    0.017788    0.529481    
#> 285: 0.318291    1.006668    3.491952    0.448772    0.092306    0.017810    0.529491    
#> 286: 0.317659    1.006741    3.491768    0.448140    0.092280    0.017841    0.529496    
#> 287: 0.317056    1.006814    3.491683    0.447531    0.092360    0.017871    0.529559    
#> 288: 0.317134    1.006708    3.491699    0.446945    0.092471    0.017905    0.529716    
#> 289: 0.317392    1.006637    3.491733    0.446924    0.092582    0.017906    0.529611    
#> 290: 0.317494    1.006673    3.491738    0.447033    0.092757    0.017877    0.529671    
#> 291: 0.317502    1.006756    3.491766    0.446831    0.092868    0.017861    0.529628    
#> 292: 0.317184    1.006777    3.491653    0.446619    0.093005    0.017848    0.529527    
#> 293: 0.316986    1.006818    3.491541    0.446686    0.093000    0.017815    0.529449    
#> 294: 0.316963    1.007006    3.491443    0.446695    0.092998    0.017773    0.529433    
#> 295: 0.316483    1.006816    3.491350    0.446296    0.093027    0.017716    0.529414    
#> 296: 0.316394    1.006843    3.491323    0.445769    0.093037    0.017669    0.529606    
#> 297: 0.316541    1.007052    3.491410    0.445420    0.093148    0.017653    0.529691    
#> 298: 0.316590    1.007051    3.491338    0.445663    0.093233    0.017609    0.529577    
#> 299: 0.316516    1.007136    3.491206    0.445922    0.093296    0.017556    0.529422    
#> 300: 0.316452    1.007069    3.491122    0.445880    0.093350    0.017506    0.529340    
#> 301: 0.316468    1.007112    3.490964    0.446375    0.093266    0.017488    0.529313    
#> 302: 0.316277    1.007213    3.490818    0.446819    0.093243    0.017481    0.529217    
#> 303: 0.315979    1.007371    3.490673    0.446617    0.093201    0.017490    0.528969    
#> 304: 0.316070    1.007664    3.490629    0.447325    0.093220    0.017512    0.528833    
#> 305: 0.315855    1.007795    3.490517    0.447153    0.093177    0.017519    0.528647    
#> 306: 0.315725    1.007982    3.490327    0.447771    0.093059    0.017502    0.528571    
#> 307: 0.315306    1.008064    3.490085    0.447828    0.093082    0.017467    0.528643    
#> 308: 0.314910    1.008068    3.489846    0.448634    0.093097    0.017431    0.528678    
#> 309: 0.314616    1.007908    3.489696    0.449332    0.093002    0.017444    0.528945    
#> 310: 0.314311    1.007927    3.489539    0.449445    0.092941    0.017467    0.528925    
#> 311: 0.314390    1.008089    3.489456    0.450195    0.092916    0.017490    0.528811    
#> 312: 0.314217    1.008169    3.489365    0.450762    0.092827    0.017515    0.528706    
#> 313: 0.314098    1.008114    3.489312    0.450943    0.092710    0.017532    0.528705    
#> 314: 0.313890    1.008170    3.489205    0.451096    0.092685    0.017546    0.528659    
#> 315: 0.313537    1.008373    3.489128    0.450925    0.092753    0.017545    0.528657    
#> 316: 0.313463    1.008691    3.489001    0.450683    0.092802    0.017553    0.528588    
#> 317: 0.313499    1.008879    3.488990    0.450956    0.092840    0.017554    0.528666    
#> 318: 0.313374    1.009001    3.488945    0.450446    0.092793    0.017559    0.528786    
#> 319: 0.313231    1.009072    3.488946    0.450275    0.092790    0.017555    0.528832    
#> 320: 0.312612    1.008979    3.488850    0.449780    0.092857    0.017540    0.528904    
#> 321: 0.312328    1.008972    3.488783    0.449158    0.092958    0.017559    0.528913    
#> 322: 0.312213    1.008916    3.488655    0.448961    0.092943    0.017564    0.528904    
#> 323: 0.311851    1.008969    3.488556    0.448233    0.092982    0.017574    0.528746    
#> 324: 0.311802    1.008980    3.488577    0.448357    0.092996    0.017562    0.528539    
#> 325: 0.311712    1.009002    3.488605    0.448113    0.093028    0.017549    0.528391    
#> 326: 0.311598    1.008886    3.488571    0.448068    0.093107    0.017528    0.528314    
#> 327: 0.311613    1.009030    3.488539    0.447737    0.093144    0.017513    0.528227    
#> 328: 0.311649    1.009242    3.488526    0.448018    0.093102    0.017499    0.527973    
#> 329: 0.311748    1.009272    3.488556    0.448344    0.093080    0.017488    0.527768    
#> 330: 0.311940    1.009159    3.488617    0.449249    0.092960    0.017496    0.527638    
#> 331: 0.312283    1.009180    3.488678    0.450436    0.092888    0.017515    0.527455    
#> 332: 0.312456    1.009156    3.488749    0.450547    0.092834    0.017533    0.527425    
#> 333: 0.312475    1.009174    3.488706    0.450258    0.092806    0.017526    0.527503    
#> 334: 0.312533    1.009105    3.488641    0.450505    0.092738    0.017488    0.527629    
#> 335: 0.312522    1.009141    3.488594    0.451034    0.092640    0.017478    0.527669    
#> 336: 0.312165    1.009301    3.488559    0.450547    0.092664    0.017473    0.527662    
#> 337: 0.311725    1.009567    3.488444    0.449938    0.092699    0.017462    0.527659    
#> 338: 0.311638    1.009767    3.488338    0.450351    0.092712    0.017448    0.527654    
#> 339: 0.311600    1.009915    3.488193    0.450769    0.092810    0.017425    0.527628    
#> 340: 0.311373    1.009871    3.488107    0.450661    0.092900    0.017419    0.527687    
#> 341: 0.311458    1.009872    3.488079    0.450753    0.093057    0.017412    0.527661    
#> 342: 0.311303    1.009657    3.488101    0.450657    0.093106    0.017412    0.527704    
#> 343: 0.311268    1.009543    3.488137    0.450576    0.093128    0.017413    0.527718    
#> 344: 0.311257    1.009500    3.488204    0.450309    0.093128    0.017426    0.527735    
#> 345: 0.311410    1.009440    3.488289    0.450370    0.093081    0.017459    0.527825    
#> 346: 0.311706    1.009405    3.488296    0.451110    0.093195    0.017435    0.527878    
#> 347: 0.311958    1.009318    3.488325    0.451362    0.093306    0.017452    0.527984    
#> 348: 0.311983    1.009340    3.488246    0.451740    0.093309    0.017478    0.528003    
#> 349: 0.311866    1.009184    3.488235    0.451659    0.093235    0.017485    0.528110    
#> 350: 0.311664    1.009028    3.488190    0.451493    0.093319    0.017488    0.528201    
#> 351: 0.311600    1.009038    3.488151    0.451578    0.093381    0.017507    0.528280    
#> 352: 0.311424    1.009188    3.488087    0.451307    0.093476    0.017526    0.528281    
#> 353: 0.311553    1.009306    3.488025    0.451470    0.093494    0.017521    0.528186    
#> 354: 0.311481    1.009364    3.487929    0.451452    0.093472    0.017510    0.528170    
#> 355: 0.311597    1.009298    3.487827    0.451372    0.093497    0.017509    0.528277    
#> 356: 0.311508    1.009347    3.487807    0.450941    0.093526    0.017511    0.528338    
#> 357: 0.311506    1.009383    3.487789    0.450805    0.093457    0.017497    0.528297    
#> 358: 0.311574    1.009516    3.487744    0.450988    0.093446    0.017509    0.528220    
#> 359: 0.311463    1.009656    3.487671    0.450917    0.093437    0.017500    0.528202    
#> 360: 0.311306    1.009685    3.487567    0.450582    0.093449    0.017493    0.528227    
#> 361: 0.311180    1.009638    3.487494    0.450566    0.093441    0.017500    0.528221    
#> 362: 0.311168    1.009599    3.487482    0.450543    0.093465    0.017510    0.528101    
#> 363: 0.311002    1.009563    3.487439    0.450485    0.093439    0.017498    0.527974    
#> 364: 0.310957    1.009581    3.487411    0.450269    0.093436    0.017498    0.527971    
#> 365: 0.310862    1.009503    3.487426    0.450301    0.093418    0.017516    0.527902    
#> 366: 0.310714    1.009506    3.487377    0.450406    0.093384    0.017532    0.527902    
#> 367: 0.310797    1.009517    3.487406    0.450925    0.093315    0.017566    0.527854    
#> 368: 0.311065    1.009581    3.487398    0.450903    0.093236    0.017594    0.527784    
#> 369: 0.310865    1.009691    3.487374    0.450817    0.093175    0.017608    0.527733    
#> 370: 0.310735    1.009798    3.487327    0.450884    0.093158    0.017645    0.527659    
#> 371: 0.310505    1.009977    3.487198    0.451024    0.093199    0.017647    0.527610    
#> 372: 0.310104    1.010163    3.487030    0.451360    0.093246    0.017652    0.527503    
#> 373: 0.309674    1.010271    3.486846    0.451721    0.093245    0.017651    0.527526    
#> 374: 0.309462    1.010401    3.486731    0.451513    0.093258    0.017642    0.527523    
#> 375: 0.309216    1.010503    3.486618    0.451787    0.093283    0.017651    0.527493    
#> 376: 0.309057    1.010650    3.486486    0.452264    0.093359    0.017652    0.527469    
#> 377: 0.308733    1.010824    3.486362    0.452681    0.093472    0.017666    0.527418    
#> 378: 0.308564    1.010849    3.486249    0.453381    0.093425    0.017695    0.527397    
#> 379: 0.308484    1.010811    3.486179    0.453736    0.093362    0.017703    0.527397    
#> 380: 0.308310    1.010804    3.486124    0.453891    0.093307    0.017730    0.527406    
#> 381: 0.308100    1.010837    3.486055    0.453923    0.093212    0.017768    0.527390    
#> 382: 0.308015    1.010880    3.486039    0.454288    0.093217    0.017763    0.527251    
#> 383: 0.308078    1.010825    3.486056    0.454406    0.093228    0.017735    0.527180    
#> 384: 0.307996    1.010864    3.486042    0.454575    0.093258    0.017725    0.527148    
#> 385: 0.308072    1.010882    3.486054    0.454838    0.093274    0.017719    0.527074    
#> 386: 0.308258    1.011071    3.486077    0.455109    0.093369    0.017709    0.527029    
#> 387: 0.308336    1.011134    3.486139    0.455104    0.093363    0.017710    0.526959    
#> 388: 0.308363    1.011138    3.486175    0.454848    0.093363    0.017697    0.526908    
#> 389: 0.308246    1.011082    3.486180    0.454627    0.093434    0.017684    0.526919    
#> 390: 0.308115    1.011145    3.486123    0.454581    0.093428    0.017673    0.526922    
#> 391: 0.308129    1.011210    3.486110    0.454744    0.093394    0.017674    0.526861    
#> 392: 0.308204    1.011211    3.486140    0.454786    0.093330    0.017668    0.526777    
#> 393: 0.308168    1.011158    3.486122    0.454563    0.093252    0.017671    0.526729    
#> 394: 0.308332    1.011093    3.486126    0.454547    0.093154    0.017673    0.526760    
#> 395: 0.308407    1.011167    3.486099    0.454738    0.093114    0.017670    0.526726    
#> 396: 0.308422    1.011284    3.486088    0.454658    0.093134    0.017664    0.526680    
#> 397: 0.308441    1.011303    3.486114    0.454490    0.093168    0.017675    0.526649    
#> 398: 0.308577    1.011291    3.486190    0.454250    0.093138    0.017706    0.526673    
#> 399: 0.308644    1.011261    3.486268    0.454034    0.093084    0.017718    0.526640    
#> 400: 0.308786    1.011208    3.486320    0.453949    0.093003    0.017730    0.526552    
#> 401: 0.308926    1.011179    3.486366    0.453850    0.092974    0.017752    0.526487    
#> 402: 0.309054    1.011243    3.486411    0.453827    0.092950    0.017770    0.526513    
#> 403: 0.309246    1.011238    3.486434    0.453952    0.092922    0.017789    0.526472    
#> 404: 0.309245    1.011238    3.486426    0.453961    0.092870    0.017800    0.526435    
#> 405: 0.309301    1.011295    3.486457    0.454236    0.092834    0.017800    0.526425    
#> 406: 0.309419    1.011297    3.486476    0.454433    0.092847    0.017825    0.526431    
#> 407: 0.309459    1.011343    3.486517    0.454753    0.092872    0.017820    0.526409    
#> 408: 0.309560    1.011343    3.486539    0.454756    0.092913    0.017828    0.526380    
#> 409: 0.309570    1.011303    3.486533    0.454757    0.092894    0.017824    0.526368    
#> 410: 0.309477    1.011307    3.486509    0.454655    0.092887    0.017832    0.526416    
#> 411: 0.309481    1.011134    3.486527    0.454598    0.092882    0.017836    0.526443    
#> 412: 0.309576    1.011181    3.486522    0.454798    0.092872    0.017840    0.526442    
#> 413: 0.309648    1.011258    3.486477    0.455045    0.092856    0.017836    0.526498    
#> 414: 0.309468    1.011284    3.486450    0.455106    0.092802    0.017834    0.526528    
#> 415: 0.309607    1.011328    3.486419    0.455303    0.092802    0.017837    0.526621    
#> 416: 0.309689    1.011327    3.486463    0.455347    0.092791    0.017849    0.526609    
#> 417: 0.309812    1.011257    3.486480    0.455156    0.092744    0.017853    0.526591    
#> 418: 0.309724    1.011253    3.486498    0.455095    0.092710    0.017848    0.526575    
#> 419: 0.309708    1.011334    3.486496    0.454961    0.092721    0.017840    0.526616    
#> 420: 0.309771    1.011367    3.486499    0.454908    0.092742    0.017828    0.526545    
#> 421: 0.309744    1.011368    3.486519    0.454649    0.092769    0.017815    0.526453    
#> 422: 0.309809    1.011342    3.486540    0.454482    0.092813    0.017799    0.526405    
#> 423: 0.309887    1.011344    3.486548    0.454579    0.092928    0.017790    0.526324    
#> 424: 0.309812    1.011279    3.486509    0.454745    0.093010    0.017760    0.526321    
#> 425: 0.309804    1.011297    3.486457    0.454831    0.093023    0.017733    0.526343    
#> 426: 0.309804    1.011369    3.486450    0.454775    0.093049    0.017732    0.526321    
#> 427: 0.309728    1.011368    3.486473    0.454471    0.092979    0.017726    0.526316    
#> 428: 0.309690    1.011431    3.486493    0.454371    0.092954    0.017731    0.526282    
#> 429: 0.309755    1.011496    3.486536    0.454214    0.092912    0.017731    0.526264    
#> 430: 0.309744    1.011533    3.486523    0.453838    0.092957    0.017725    0.526263    
#> 431: 0.309725    1.011585    3.486517    0.453864    0.092996    0.017718    0.526249    
#> 432: 0.309698    1.011630    3.486518    0.454043    0.093002    0.017721    0.526183    
#> 433: 0.309720    1.011634    3.486555    0.453873    0.092976    0.017732    0.526232    
#> 434: 0.309586    1.011532    3.486587    0.453725    0.092971    0.017728    0.526264    
#> 435: 0.309616    1.011532    3.486590    0.453604    0.092973    0.017722    0.526299    
#> 436: 0.309719    1.011450    3.486636    0.453548    0.092943    0.017703    0.526369    
#> 437: 0.309879    1.011322    3.486688    0.453495    0.092919    0.017692    0.526434    
#> 438: 0.309982    1.011279    3.486744    0.453433    0.092844    0.017685    0.526427    
#> 439: 0.310015    1.011303    3.486790    0.453305    0.092850    0.017677    0.526398    
#> 440: 0.310105    1.011324    3.486846    0.453217    0.092833    0.017679    0.526351    
#> 441: 0.310264    1.011244    3.486921    0.453099    0.092860    0.017668    0.526269    
#> 442: 0.310432    1.011229    3.486979    0.453180    0.092847    0.017673    0.526151    
#> 443: 0.310591    1.011231    3.486974    0.453183    0.092798    0.017669    0.526064    
#> 444: 0.310596    1.011300    3.486913    0.453214    0.092734    0.017664    0.525997    
#> 445: 0.310497    1.011334    3.486876    0.453181    0.092714    0.017655    0.525966    
#> 446: 0.310331    1.011397    3.486834    0.453091    0.092713    0.017641    0.525928    
#> 447: 0.310300    1.011391    3.486845    0.453178    0.092692    0.017644    0.525872    
#> 448: 0.310278    1.011351    3.486902    0.452997    0.092689    0.017640    0.525799    
#> 449: 0.310349    1.011361    3.487012    0.452905    0.092692    0.017645    0.525767    
#> 450: 0.310428    1.011288    3.487066    0.452732    0.092676    0.017645    0.525791    
#> 451: 0.310499    1.011241    3.487094    0.452653    0.092674    0.017647    0.525828    
#> 452: 0.310465    1.011242    3.487088    0.452623    0.092622    0.017640    0.525852    
#> 453: 0.310441    1.011213    3.487082    0.452516    0.092562    0.017635    0.525827    
#> 454: 0.310433    1.011333    3.487034    0.453117    0.092530    0.017631    0.525810    
#> 455: 0.310405    1.011390    3.486970    0.453420    0.092502    0.017634    0.525807    
#> 456: 0.310278    1.011331    3.486944    0.453612    0.092509    0.017638    0.525774    
#> 457: 0.310236    1.011349    3.486914    0.453711    0.092527    0.017620    0.525753    
#> 458: 0.310089    1.011441    3.486896    0.453596    0.092531    0.017606    0.525743    
#> 459: 0.309928    1.011587    3.486843    0.453439    0.092522    0.017588    0.525736    
#> 460: 0.309773    1.011690    3.486797    0.453377    0.092556    0.017581    0.525669    
#> 461: 0.309708    1.011716    3.486781    0.453471    0.092592    0.017576    0.525606    
#> 462: 0.309694    1.011752    3.486794    0.453529    0.092597    0.017576    0.525553    
#> 463: 0.309787    1.011792    3.486824    0.453774    0.092588    0.017575    0.525504    
#> 464: 0.309907    1.011804    3.486815    0.454050    0.092581    0.017574    0.525417    
#> 465: 0.309942    1.011638    3.486842    0.454196    0.092552    0.017568    0.525403    
#> 466: 0.309944    1.011599    3.486814    0.453920    0.092578    0.017563    0.525394    
#> 467: 0.309927    1.011586    3.486815    0.453862    0.092581    0.017548    0.525311    
#> 468: 0.309945    1.011569    3.486836    0.453846    0.092554    0.017539    0.525254    
#> 469: 0.309923    1.011593    3.486859    0.453667    0.092522    0.017541    0.525259    
#> 470: 0.309843    1.011615    3.486846    0.453372    0.092536    0.017553    0.525288    
#> 471: 0.309766    1.011577    3.486834    0.453133    0.092533    0.017555    0.525355    
#> 472: 0.309632    1.011497    3.486847    0.452924    0.092516    0.017565    0.525307    
#> 473: 0.309551    1.011487    3.486848    0.452893    0.092512    0.017573    0.525222    
#> 474: 0.309492    1.011492    3.486848    0.452838    0.092556    0.017574    0.525152    
#> 475: 0.309456    1.011553    3.486830    0.452912    0.092548    0.017575    0.525134    
#> 476: 0.309359    1.011550    3.486828    0.452946    0.092565    0.017571    0.525153    
#> 477: 0.309400    1.011506    3.486893    0.452911    0.092536    0.017580    0.525113    
#> 478: 0.309495    1.011474    3.486934    0.452936    0.092526    0.017589    0.525100    
#> 479: 0.309552    1.011450    3.486991    0.452979    0.092494    0.017598    0.525087    
#> 480: 0.309671    1.011344    3.487029    0.452999    0.092444    0.017624    0.525119    
#> 481: 0.309715    1.011311    3.487052    0.453018    0.092360    0.017653    0.525139    
#> 482: 0.309767    1.011261    3.487054    0.453220    0.092289    0.017668    0.525184    
#> 483: 0.309644    1.011183    3.487046    0.453245    0.092287    0.017674    0.525202    
#> 484: 0.309491    1.011111    3.487023    0.453098    0.092332    0.017672    0.525227    
#> 485: 0.309487    1.011110    3.487014    0.453289    0.092362    0.017669    0.525358    
#> 486: 0.309502    1.011154    3.487001    0.453435    0.092350    0.017663    0.525391    
#> 487: 0.309638    1.011142    3.487031    0.453562    0.092329    0.017667    0.525405    
#> 488: 0.309607    1.011151    3.487051    0.453507    0.092345    0.017659    0.525415    
#> 489: 0.309602    1.011204    3.487037    0.453490    0.092339    0.017664    0.525411    
#> 490: 0.309638    1.011195    3.487067    0.453375    0.092308    0.017660    0.525352    
#> 491: 0.309646    1.011242    3.487079    0.453332    0.092316    0.017652    0.525315    
#> 492: 0.309629    1.011277    3.487047    0.453270    0.092287    0.017653    0.525344    
#> 493: 0.309572    1.011314    3.487049    0.453354    0.092243    0.017659    0.525298    
#> 494: 0.309737    1.011350    3.487060    0.453457    0.092181    0.017660    0.525240    
#> 495: 0.309728    1.011380    3.487057    0.453548    0.092121    0.017668    0.525175    
#> 496: 0.309774    1.011486    3.487029    0.453415    0.092064    0.017678    0.525171    
#> 497: 0.309734    1.011514    3.487044    0.453147    0.091991    0.017687    0.525203    
#> 498: 0.309628    1.011476    3.487027    0.452950    0.091945    0.017685    0.525180    
#> 499: 0.309521    1.011512    3.486985    0.452789    0.091948    0.017676    0.525121    
#> 500: 0.309450    1.011535    3.486969    0.452631    0.091946    0.017672    0.525074    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.288913    0.958520    3.444380    0.392401    0.077119    0.016800    1.752091    
#> 002: 0.249092    0.969110    3.462528    0.372781    0.073263    0.015960    1.247275    
#> 003: 0.300580    0.850016    3.469514    0.354142    0.073615    0.015162    0.898787    
#> 004: 0.264727    0.822885    3.458761    0.336435    0.085994    0.014404    0.755754    
#> 005: 0.253612    0.824382    3.441815    0.319613    0.091287    0.013684    0.714514    
#> 006: 0.227965    0.814210    3.424902    0.303633    0.103689    0.013401    0.626083    
#> 007: 0.211548    0.840011    3.419942    0.288451    0.136906    0.013842    0.603162    
#> 008: 0.178349    0.831552    3.407954    0.274029    0.130650    0.015503    0.588408    
#> 009: 0.156432    0.844339    3.403508    0.260327    0.124117    0.017822    0.599126    
#> 010: 0.153834    0.841458    3.398209    0.247311    0.117911    0.017483    0.613695    
#> 011: 0.193764    0.843007    3.409357    0.255735    0.121373    0.018957    0.622030    
#> 012: 0.189890    0.843353    3.397175    0.242949    0.115304    0.018738    0.609311    
#> 013: 0.149907    0.854343    3.392176    0.230801    0.109539    0.017801    0.614173    
#> 014: 0.192113    0.836742    3.413708    0.219261    0.116106    0.016911    0.618110    
#> 015: 0.198613    0.819385    3.422903    0.218002    0.110301    0.017541    0.585642    
#> 016: 0.217962    0.843100    3.432278    0.212929    0.111826    0.016664    0.598564    
#> 017: 0.226865    0.843149    3.427762    0.211242    0.106235    0.017361    0.567576    
#> 018: 0.226128    0.843785    3.412822    0.200680    0.118528    0.016560    0.577385    
#> 019: 0.197766    0.838174    3.410033    0.199392    0.119667    0.017285    0.571582    
#> 020: 0.186421    0.872767    3.402440    0.216237    0.137683    0.016421    0.578584    
#> 021: 0.216026    0.851128    3.408977    0.207716    0.130799    0.015666    0.573746    
#> 022: 0.205665    0.860575    3.418351    0.238752    0.124259    0.014882    0.567351    
#> 023: 0.238396    0.853921    3.419967    0.236825    0.118046    0.016409    0.587704    
#> 024: 0.241886    0.850526    3.426031    0.255135    0.112144    0.018147    0.580458    
#> 025: 0.228717    0.827011    3.422671    0.243674    0.106536    0.020799    0.568993    
#> 026: 0.231410    0.851460    3.414284    0.231490    0.115221    0.019759    0.570283    
#> 027: 0.209525    0.870599    3.410284    0.219916    0.126880    0.018771    0.576011    
#> 028: 0.195084    0.847437    3.411815    0.234599    0.120536    0.018726    0.561636    
#> 029: 0.208499    0.842363    3.404879    0.232926    0.115679    0.017789    0.584380    
#> 030: 0.194404    0.855489    3.407340    0.221280    0.111916    0.016900    0.572053    
#> 031: 0.190497    0.847700    3.417543    0.242005    0.116257    0.017296    0.584344    
#> 032: 0.208765    0.838293    3.417582    0.233589    0.111252    0.020186    0.564877    
#> 033: 0.180811    0.828922    3.418260    0.224729    0.126448    0.020506    0.580654    
#> 034: 0.210696    0.856676    3.418813    0.235294    0.120126    0.021422    0.571066    
#> 035: 0.194089    0.845849    3.416101    0.223529    0.114120    0.020842    0.565117    
#> 036: 0.193040    0.857581    3.405610    0.212353    0.112078    0.024323    0.577710    
#> 037: 0.185029    0.857612    3.399748    0.210870    0.133258    0.023107    0.584190    
#> 038: 0.172750    0.861049    3.396737    0.208939    0.126843    0.021952    0.576283    
#> 039: 0.192820    0.870410    3.399214    0.221805    0.120501    0.020971    0.556938    
#> 040: 0.185092    0.860144    3.402390    0.210715    0.123559    0.019922    0.573102    
#> 041: 0.156670    0.860344    3.388709    0.219331    0.123531    0.019405    0.575814    
#> 042: 0.187474    0.853706    3.400298    0.266339    0.117354    0.019032    0.566235    
#> 043: 0.151493    0.867945    3.387471    0.253022    0.117132    0.018080    0.562318    
#> 044: 0.120417    0.883066    3.374514    0.246102    0.124752    0.017176    0.574852    
#> 045: 0.161222    0.888681    3.380295    0.235378    0.136100    0.016317    0.580968    
#> 046: 0.166288    0.857398    3.389799    0.223609    0.129295    0.015501    0.578225    
#> 047: 0.182644    0.873504    3.389708    0.226051    0.126338    0.014726    0.579135    
#> 048: 0.193101    0.863031    3.404931    0.214748    0.120021    0.016908    0.577743    
#> 049: 0.186921    0.868597    3.408973    0.204011    0.114020    0.016670    0.582137    
#> 050: 0.241179    0.821190    3.419455    0.193810    0.108319    0.015837    0.615831    
#> 051: 0.233438    0.835953    3.419636    0.184120    0.110888    0.016199    0.605141    
#> 052: 0.232678    0.839665    3.431020    0.180177    0.120634    0.015389    0.573242    
#> 053: 0.227618    0.822341    3.423540    0.210513    0.114602    0.015413    0.571027    
#> 054: 0.213326    0.815751    3.424150    0.199987    0.108872    0.015561    0.593143    
#> 055: 0.207727    0.839171    3.422376    0.190658    0.110712    0.016306    0.585429    
#> 056: 0.222381    0.820382    3.423180    0.223149    0.117819    0.017397    0.600791    
#> 057: 0.222410    0.810724    3.435405    0.219496    0.111928    0.018498    0.594061    
#> 058: 0.222926    0.823379    3.423735    0.208521    0.106332    0.017989    0.611908    
#> 059: 0.228331    0.808001    3.426542    0.211521    0.101015    0.017317    0.608042    
#> 060: 0.210682    0.822170    3.416990    0.200945    0.114435    0.016451    0.599322    
#> 061: 0.237097    0.838111    3.421970    0.206875    0.109871    0.015628    0.610400    
#> 062: 0.213040    0.875882    3.418510    0.197911    0.122306    0.014847    0.625003    
#> 063: 0.235435    0.834030    3.415438    0.201130    0.116191    0.014105    0.613206    
#> 064: 0.216841    0.844652    3.430622    0.191073    0.118510    0.013399    0.599554    
#> 065: 0.233727    0.824866    3.418646    0.181519    0.112585    0.015354    0.592441    
#> 066: 0.227429    0.848908    3.418430    0.191060    0.112423    0.016037    0.576591    
#> 067: 0.215758    0.847895    3.417282    0.230182    0.115858    0.017121    0.564613    
#> 068: 0.189564    0.861086    3.415398    0.237070    0.138605    0.018850    0.583406    
#> 069: 0.191895    0.846699    3.404400    0.239051    0.137111    0.017907    0.593841    
#> 070: 0.194388    0.849420    3.411017    0.258292    0.130256    0.021092    0.579346    
#> 071: 0.180810    0.846332    3.397081    0.249043    0.123743    0.020082    0.577163    
#> 072: 0.168796    0.834497    3.402689    0.236591    0.117556    0.020697    0.557433    
#> 073: 0.175846    0.845122    3.410215    0.224761    0.124089    0.021636    0.566113    
#> 074: 0.164994    0.831084    3.391407    0.229005    0.117884    0.020554    0.579545    
#> 075: 0.166992    0.844959    3.416336    0.217555    0.123507    0.019527    0.583161    
#> 076: 0.200984    0.857866    3.414749    0.216430    0.119643    0.018901    0.588052    
#> 077: 0.251813    0.837521    3.417959    0.209815    0.117008    0.021521    0.577404    
#> 078: 0.208309    0.836852    3.419777    0.215403    0.111157    0.020822    0.575443    
#> 079: 0.206434    0.837081    3.420242    0.204633    0.114647    0.019781    0.592998    
#> 080: 0.214198    0.845096    3.419537    0.216843    0.122225    0.018792    0.598241    
#> 081: 0.213759    0.841435    3.419515    0.213510    0.117103    0.017852    0.594045    
#> 082: 0.239884    0.822070    3.432708    0.219700    0.111248    0.019320    0.588000    
#> 083: 0.225752    0.849213    3.428186    0.233332    0.108055    0.018947    0.583681    
#> 084: 0.219042    0.846952    3.421086    0.250725    0.118318    0.018767    0.580776    
#> 085: 0.218125    0.854944    3.426453    0.238188    0.122535    0.017829    0.582376    
#> 086: 0.213354    0.854247    3.412854    0.226279    0.116408    0.016938    0.568402    
#> 087: 0.194236    0.852200    3.406611    0.214965    0.134533    0.016091    0.579067    
#> 088: 0.149170    0.849659    3.409274    0.204217    0.127806    0.015286    0.589490    
#> 089: 0.178659    0.859668    3.391788    0.221740    0.136760    0.014522    0.579140    
#> 090: 0.165959    0.849576    3.396920    0.221581    0.129922    0.013796    0.572996    
#> 091: 0.167496    0.851029    3.389894    0.226816    0.123426    0.017188    0.576527    
#> 092: 0.174776    0.855919    3.390900    0.234058    0.117255    0.021810    0.574309    
#> 093: 0.137768    0.858944    3.391880    0.238224    0.111392    0.020720    0.590109    
#> 094: 0.151397    0.867991    3.394132    0.226312    0.105822    0.019684    0.580481    
#> 095: 0.171038    0.852402    3.416750    0.214997    0.100531    0.023659    0.563333    
#> 096: 0.159030    0.851111    3.406595    0.222662    0.096964    0.022476    0.557659    
#> 097: 0.192105    0.846272    3.402283    0.236112    0.092116    0.021823    0.556985    
#> 098: 0.180099    0.879987    3.397644    0.246676    0.093285    0.024323    0.572797    
#> 099: 0.182742    0.851533    3.399710    0.234343    0.096634    0.024521    0.571805    
#> 100: 0.158322    0.869373    3.392352    0.243129    0.091802    0.023295    0.565836    
#> 101: 0.170757    0.843313    3.400964    0.230972    0.089318    0.022811    0.566684    
#> 102: 0.182275    0.855510    3.399779    0.219424    0.111766    0.022739    0.557325    
#> 103: 0.192436    0.855266    3.399418    0.232533    0.106421    0.022432    0.562466    
#> 104: 0.175327    0.858320    3.407938    0.224355    0.101100    0.023063    0.575266    
#> 105: 0.180043    0.839318    3.403928    0.223306    0.096729    0.024029    0.585119    
#> 106: 0.171245    0.857922    3.402907    0.212141    0.099636    0.022828    0.592239    
#> 107: 0.184012    0.858551    3.409223    0.201534    0.108424    0.021686    0.594869    
#> 108: 0.196028    0.837713    3.420616    0.194328    0.106990    0.020602    0.606804    
#> 109: 0.218915    0.837450    3.428389    0.221827    0.101641    0.019572    0.596796    
#> 110: 0.221302    0.828039    3.417331    0.210736    0.097578    0.019624    0.575306    
#> 111: 0.219635    0.828345    3.424995    0.200199    0.093451    0.018642    0.574042    
#> 112: 0.177413    0.827431    3.408287    0.190189    0.113240    0.017745    0.568209    
#> 113: 0.198887    0.868837    3.409284    0.210243    0.108645    0.017939    0.565337    
#> 114: 0.189897    0.849901    3.408567    0.199731    0.108779    0.017042    0.573237    
#> 115: 0.216711    0.818337    3.414972    0.189745    0.103340    0.018187    0.609496    
#> 116: 0.213957    0.823764    3.426282    0.180275    0.118726    0.021309    0.590711    
#> 117: 0.209858    0.857935    3.422776    0.177828    0.112789    0.020243    0.605007    
#> 118: 0.209470    0.843178    3.422722    0.196806    0.107150    0.019231    0.601155    
#> 119: 0.208507    0.819911    3.424953    0.212307    0.104154    0.018269    0.603728    
#> 120: 0.199824    0.818462    3.416941    0.201692    0.105737    0.017356    0.595137    
#> 121: 0.207394    0.865575    3.407545    0.221648    0.116380    0.016488    0.603583    
#> 122: 0.232179    0.840356    3.420473    0.239564    0.115413    0.015664    0.569754    
#> 123: 0.235526    0.866728    3.412294    0.238404    0.120702    0.014881    0.579661    
#> 124: 0.211158    0.879924    3.406461    0.226484    0.114667    0.014137    0.587428    
#> 125: 0.224136    0.882426    3.406373    0.215160    0.112083    0.013430    0.597212    
#> 126: 0.192795    0.880496    3.392231    0.204402    0.117789    0.014503    0.590399    
#> 127: 0.181700    0.872697    3.389826    0.194182    0.111899    0.014179    0.598189    
#> 128: 0.166753    0.862513    3.404752    0.221276    0.132730    0.014546    0.590550    
#> 129: 0.191894    0.866780    3.403594    0.210213    0.140935    0.014310    0.589088    
#> 130: 0.217072    0.872284    3.399851    0.217040    0.133889    0.013594    0.589655    
#> 131: 0.192414    0.867292    3.390407    0.219081    0.141530    0.012914    0.584587    
#> 132: 0.156286    0.863679    3.385876    0.208127    0.135221    0.012476    0.580473    
#> 133: 0.173006    0.860931    3.393346    0.213843    0.128540    0.011852    0.569933    
#> 134: 0.173858    0.835131    3.401978    0.203151    0.122113    0.013265    0.578283    
#> 135: 0.173283    0.854074    3.401059    0.204998    0.122959    0.013335    0.570407    
#> 136: 0.167012    0.843665    3.401448    0.223930    0.116811    0.013760    0.575198    
#> 137: 0.220460    0.855527    3.405148    0.230849    0.119364    0.013072    0.582898    
#> 138: 0.192196    0.865920    3.404291    0.235741    0.136908    0.013628    0.584505    
#> 139: 0.187219    0.862515    3.408779    0.223954    0.133177    0.014856    0.580547    
#> 140: 0.206678    0.844121    3.421250    0.222851    0.126519    0.015005    0.586965    
#> 141: 0.221416    0.818132    3.430504    0.211708    0.125868    0.014520    0.591230    
#> 142: 0.231699    0.812759    3.437441    0.201123    0.119575    0.014785    0.594908    
#> 143: 0.204470    0.842494    3.428898    0.198291    0.120560    0.017228    0.604080    
#> 144: 0.221395    0.836820    3.434450    0.188376    0.114968    0.016778    0.591866    
#> 145: 0.208182    0.834097    3.421523    0.226771    0.117519    0.017078    0.577773    
#> 146: 0.181762    0.847318    3.412842    0.217145    0.117309    0.017325    0.583277    
#> 147: 0.180033    0.847015    3.399076    0.232565    0.111443    0.021973    0.578237    
#> 148: 0.172373    0.866536    3.409166    0.240621    0.118997    0.020874    0.578750    
#> 149: 0.169838    0.840112    3.405738    0.228590    0.113047    0.020259    0.587535    
#> 150: 0.176180    0.834636    3.404102    0.217160    0.108279    0.020128    0.581042    
#> 151: 0.159403    0.870472    3.401522    0.206302    0.117197    0.019122    0.582328    
#> 152: 0.160499    0.855165    3.401357    0.231759    0.107678    0.018477    0.569484    
#> 153: 0.172861    0.855633    3.407340    0.210172    0.105577    0.017556    0.572421    
#> 154: 0.184477    0.861267    3.395938    0.219011    0.109424    0.017026    0.574409    
#> 155: 0.162623    0.851808    3.398370    0.202029    0.106698    0.015409    0.575935    
#> 156: 0.164391    0.854492    3.397079    0.204149    0.110483    0.015331    0.588401    
#> 157: 0.210594    0.853289    3.413437    0.207665    0.119051    0.015509    0.584663    
#> 158: 0.237516    0.838944    3.418295    0.190445    0.124093    0.015000    0.574553    
#> 159: 0.205705    0.840695    3.424182    0.217860    0.110336    0.018262    0.570290    
#> 160: 0.204558    0.817599    3.419875    0.182212    0.120219    0.019410    0.591172    
#> 161: 0.198702    0.833884    3.418462    0.197628    0.121332    0.015897    0.581461    
#> 162: 0.199929    0.843823    3.415509    0.200271    0.125350    0.014467    0.606001    
#> 163: 0.207486    0.843980    3.406960    0.216629    0.138189    0.013556    0.594985    
#> 164: 0.197936    0.854948    3.403027    0.256340    0.119368    0.013624    0.585693    
#> 165: 0.222678    0.834424    3.421202    0.224385    0.123470    0.017819    0.579078    
#> 166: 0.227284    0.859616    3.412851    0.239093    0.117363    0.021064    0.579851    
#> 167: 0.195507    0.857397    3.411315    0.231746    0.101120    0.022283    0.567509    
#> 168: 0.198851    0.861290    3.399940    0.228745    0.095623    0.019758    0.574048    
#> 169: 0.195209    0.882720    3.401314    0.227152    0.099593    0.021614    0.585454    
#> 170: 0.185121    0.868022    3.402822    0.255591    0.102715    0.020367    0.570364    
#> 171: 0.176003    0.858867    3.401964    0.222400    0.103429    0.016339    0.561342    
#> 172: 0.173117    0.866945    3.402356    0.200494    0.102608    0.015805    0.577193    
#> 173: 0.181298    0.866464    3.399396    0.198305    0.104789    0.015344    0.573384    
#> 174: 0.170520    0.863642    3.399339    0.194612    0.109072    0.016094    0.581737    
#> 175: 0.159210    0.863938    3.389132    0.196101    0.102398    0.018973    0.594108    
#> 176: 0.166986    0.867588    3.401589    0.192606    0.111560    0.015838    0.577854    
#> 177: 0.200849    0.853718    3.407976    0.197595    0.118685    0.014553    0.593846    
#> 178: 0.209557    0.824007    3.414103    0.194679    0.126493    0.017474    0.582971    
#> 179: 0.211546    0.877384    3.407990    0.228949    0.128642    0.014920    0.605815    
#> 180: 0.187640    0.860196    3.409151    0.205245    0.145930    0.014089    0.584816    
#> 181: 0.178681    0.873377    3.392452    0.216391    0.139083    0.014085    0.567565    
#> 182: 0.157553    0.871977    3.388576    0.228848    0.114919    0.016559    0.568426    
#> 183: 0.153843    0.896663    3.389040    0.217959    0.130294    0.018724    0.573436    
#> 184: 0.146178    0.888548    3.383058    0.226857    0.108786    0.021080    0.573196    
#> 185: 0.144247    0.900386    3.380636    0.210688    0.108815    0.018661    0.580378    
#> 186: 0.137190    0.897534    3.376323    0.204863    0.119318    0.017170    0.586588    
#> 187: 0.143607    0.865992    3.385886    0.199400    0.110226    0.014333    0.570339    
#> 188: 0.122622    0.869401    3.390768    0.202627    0.104156    0.014702    0.571781    
#> 189: 0.167247    0.874217    3.397770    0.219727    0.109832    0.014384    0.575998    
#> 190: 0.161215    0.867855    3.400608    0.218768    0.106931    0.016007    0.568605    
#> 191: 0.183445    0.874568    3.398239    0.223282    0.110262    0.017610    0.558336    
#> 192: 0.169433    0.868740    3.407846    0.232447    0.106423    0.019057    0.548196    
#> 193: 0.198280    0.864379    3.408904    0.229672    0.114525    0.017421    0.555046    
#> 194: 0.207027    0.843732    3.419389    0.230662    0.102873    0.017984    0.562578    
#> 195: 0.183075    0.851389    3.415089    0.211528    0.100711    0.018681    0.579903    
#> 196: 0.179206    0.848295    3.417917    0.220784    0.105299    0.020364    0.570887    
#> 197: 0.197856    0.844178    3.428826    0.201886    0.120103    0.021559    0.589167    
#> 198: 0.242204    0.829766    3.431155    0.204218    0.093790    0.022248    0.571156    
#> 199: 0.199143    0.846023    3.423863    0.196366    0.103300    0.023998    0.570471    
#> 200: 0.207269    0.836641    3.418538    0.180559    0.089551    0.021821    0.576295    
#> 201: 0.203397    0.833880    3.419836    0.186898    0.097220    0.022882    0.573218    
#> 202: 0.201498    0.840755    3.422389    0.185090    0.102557    0.021538    0.578496    
#> 203: 0.209404    0.841009    3.421429    0.186829    0.104141    0.020244    0.584016    
#> 204: 0.212248    0.835284    3.423107    0.189406    0.104871    0.019958    0.583125    
#> 205: 0.214664    0.841179    3.423396    0.187761    0.103975    0.019943    0.586808    
#> 206: 0.211386    0.844307    3.422847    0.187985    0.103396    0.019553    0.588089    
#> 207: 0.208859    0.843936    3.420557    0.187720    0.102195    0.019244    0.588241    
#> 208: 0.209729    0.844270    3.420675    0.187295    0.102126    0.019008    0.587753    
#> 209: 0.208577    0.842341    3.419362    0.187145    0.103972    0.018571    0.587643    
#> 210: 0.207395    0.841623    3.418931    0.187179    0.106760    0.018054    0.587246    
#> 211: 0.206540    0.842909    3.418808    0.184060    0.107680    0.017731    0.587416    
#> 212: 0.208533    0.842592    3.418988    0.183409    0.106947    0.017597    0.587878    
#> 213: 0.211257    0.842140    3.419351    0.185582    0.106641    0.017722    0.587705    
#> 214: 0.211944    0.841400    3.419694    0.186167    0.106690    0.017668    0.587085    
#> 215: 0.211658    0.841695    3.420121    0.187789    0.106906    0.017709    0.587204    
#> 216: 0.212684    0.841254    3.420142    0.188528    0.107684    0.017670    0.587700    
#> 217: 0.212689    0.841881    3.419925    0.187900    0.107834    0.017487    0.587387    
#> 218: 0.212234    0.842805    3.419598    0.189264    0.107664    0.017382    0.587007    
#> 219: 0.211823    0.843094    3.418933    0.189471    0.108144    0.017207    0.586034    
#> 220: 0.210077    0.843873    3.418429    0.191033    0.108127    0.017270    0.585622    
#> 221: 0.208458    0.845125    3.417517    0.192597    0.108638    0.017279    0.584765    
#> 222: 0.208288    0.845190    3.416827    0.194011    0.109298    0.017298    0.584940    
#> 223: 0.208745    0.845385    3.416260    0.195534    0.110103    0.017231    0.584665    
#> 224: 0.209567    0.845326    3.416347    0.194342    0.110673    0.016978    0.585139    
#> 225: 0.209725    0.843486    3.417285    0.192966    0.111098    0.016936    0.586042    
#> 226: 0.210410    0.842052    3.417502    0.192291    0.111320    0.016860    0.586930    
#> 227: 0.210145    0.841909    3.417841    0.191028    0.111568    0.016779    0.587730    
#> 228: 0.209577    0.842246    3.417474    0.189402    0.111545    0.016696    0.588541    
#> 229: 0.208780    0.842486    3.417287    0.188493    0.111204    0.016534    0.588900    
#> 230: 0.208479    0.842273    3.417177    0.188022    0.111585    0.016438    0.588781    
#> 231: 0.208532    0.842186    3.417359    0.187716    0.112362    0.016434    0.588729    
#> 232: 0.208086    0.842100    3.417582    0.187912    0.112408    0.016479    0.588849    
#> 233: 0.207654    0.841782    3.417671    0.187554    0.112063    0.016542    0.589002    
#> 234: 0.206810    0.841491    3.417577    0.187983    0.112095    0.016621    0.588936    
#> 235: 0.206301    0.841979    3.417536    0.186940    0.112128    0.016633    0.588961    
#> 236: 0.205144    0.842634    3.417110    0.186284    0.112116    0.016631    0.589120    
#> 237: 0.204989    0.843145    3.416933    0.186408    0.112126    0.016678    0.589349    
#> 238: 0.204992    0.843257    3.416901    0.186545    0.112424    0.016703    0.589580    
#> 239: 0.204531    0.843504    3.416820    0.186811    0.112350    0.016736    0.589310    
#> 240: 0.204640    0.843464    3.416973    0.187295    0.112098    0.016761    0.588995    
#> 241: 0.205059    0.842743    3.417176    0.187694    0.111909    0.016818    0.588754    
#> 242: 0.204864    0.842363    3.417080    0.187489    0.111806    0.016861    0.589021    
#> 243: 0.204216    0.842630    3.416960    0.187149    0.111403    0.016967    0.589414    
#> 244: 0.204213    0.842658    3.416987    0.187644    0.111251    0.017030    0.589512    
#> 245: 0.203972    0.842193    3.416922    0.187594    0.111199    0.017026    0.590071    
#> 246: 0.204030    0.842271    3.416807    0.187662    0.111286    0.016990    0.590014    
#> 247: 0.204307    0.842050    3.416877    0.188041    0.111044    0.016990    0.589969    
#> 248: 0.204991    0.842085    3.417070    0.188710    0.111089    0.016979    0.589860    
#> 249: 0.205404    0.842279    3.417364    0.189276    0.111605    0.016985    0.589640    
#> 250: 0.205993    0.842442    3.417600    0.189418    0.111770    0.017031    0.589765    
#> 251: 0.206727    0.842802    3.417871    0.189803    0.111768    0.017032    0.589733    
#> 252: 0.207435    0.843037    3.418239    0.190180    0.111901    0.017003    0.589580    
#> 253: 0.208092    0.843014    3.418597    0.190259    0.112102    0.017020    0.589647    
#> 254: 0.208561    0.843346    3.418771    0.190310    0.112075    0.017016    0.589435    
#> 255: 0.208768    0.843624    3.418832    0.190194    0.111908    0.017024    0.589576    
#> 256: 0.208889    0.843303    3.418981    0.189890    0.111866    0.016961    0.589863    
#> 257: 0.208977    0.843122    3.418844    0.190328    0.111817    0.016963    0.589759    
#> 258: 0.208870    0.843144    3.418716    0.190387    0.111659    0.016931    0.589834    
#> 259: 0.208786    0.843135    3.418678    0.190815    0.111779    0.016959    0.589680    
#> 260: 0.208950    0.843181    3.418740    0.191055    0.112061    0.016987    0.589405    
#> 261: 0.209256    0.842812    3.418874    0.191402    0.111887    0.017001    0.589476    
#> 262: 0.209520    0.842855    3.419057    0.191380    0.111887    0.017022    0.589320    
#> 263: 0.209498    0.843107    3.419086    0.191528    0.111846    0.016989    0.589395    
#> 264: 0.209528    0.842873    3.419192    0.191795    0.112034    0.017014    0.589346    
#> 265: 0.209689    0.842835    3.419316    0.192397    0.111897    0.017050    0.589286    
#> 266: 0.209794    0.842900    3.419316    0.192564    0.111977    0.017028    0.589368    
#> 267: 0.209726    0.842845    3.419436    0.192630    0.111750    0.017006    0.589287    
#> 268: 0.209875    0.842665    3.419391    0.193227    0.111872    0.017032    0.588992    
#> 269: 0.210264    0.842724    3.419302    0.193413    0.111916    0.017044    0.589051    
#> 270: 0.210471    0.843045    3.419199    0.193821    0.111842    0.017071    0.588850    
#> 271: 0.210185    0.843369    3.418968    0.194030    0.111984    0.017106    0.588858    
#> 272: 0.210224    0.843273    3.418909    0.194418    0.112038    0.017166    0.588933    
#> 273: 0.210017    0.843451    3.418782    0.194769    0.111832    0.017254    0.588887    
#> 274: 0.209871    0.843650    3.418783    0.194609    0.111631    0.017288    0.588948    
#> 275: 0.209917    0.843767    3.418633    0.194521    0.111486    0.017319    0.588958    
#> 276: 0.210017    0.843860    3.418713    0.194421    0.111427    0.017321    0.588853    
#> 277: 0.209980    0.843923    3.418827    0.194574    0.111399    0.017346    0.588716    
#> 278: 0.209692    0.844111    3.418801    0.194542    0.111510    0.017355    0.588675    
#> 279: 0.209463    0.844139    3.418846    0.194722    0.111824    0.017317    0.588898    
#> 280: 0.209450    0.844096    3.418883    0.194800    0.112000    0.017251    0.588845    
#> 281: 0.209257    0.844279    3.418869    0.194714    0.112033    0.017195    0.588765    
#> 282: 0.209376    0.844392    3.418963    0.194377    0.112008    0.017185    0.588799    
#> 283: 0.209233    0.844434    3.419025    0.194338    0.111994    0.017197    0.588965    
#> 284: 0.208769    0.844301    3.418907    0.194435    0.111928    0.017170    0.589032    
#> 285: 0.208422    0.844400    3.418670    0.194187    0.112016    0.017152    0.589128    
#> 286: 0.208002    0.844553    3.418441    0.193913    0.112029    0.017128    0.589060    
#> 287: 0.207658    0.844758    3.418252    0.193739    0.112021    0.017112    0.588982    
#> 288: 0.207698    0.844862    3.418185    0.193561    0.111943    0.017095    0.589129    
#> 289: 0.207832    0.844962    3.418142    0.193360    0.111990    0.017101    0.589068    
#> 290: 0.207700    0.845078    3.418033    0.193191    0.111852    0.017122    0.589114    
#> 291: 0.207659    0.845319    3.418076    0.193197    0.111764    0.017148    0.588871    
#> 292: 0.207552    0.845323    3.417980    0.193207    0.111677    0.017117    0.588788    
#> 293: 0.207485    0.845494    3.417914    0.193325    0.111669    0.017085    0.588755    
#> 294: 0.207231    0.845537    3.417826    0.193357    0.111737    0.017079    0.588820    
#> 295: 0.207014    0.845453    3.417788    0.193459    0.111630    0.017089    0.588482    
#> 296: 0.206783    0.845485    3.417804    0.193282    0.111546    0.017111    0.588282    
#> 297: 0.206767    0.845611    3.417791    0.193161    0.111604    0.017128    0.588129    
#> 298: 0.206750    0.845651    3.417699    0.193353    0.111657    0.017147    0.587945    
#> 299: 0.206754    0.845864    3.417505    0.193726    0.111662    0.017166    0.587773    
#> 300: 0.206621    0.846116    3.417406    0.193809    0.111705    0.017175    0.587592    
#> 301: 0.206455    0.846196    3.417209    0.194057    0.111764    0.017161    0.587611    
#> 302: 0.206151    0.846319    3.417038    0.194198    0.111787    0.017162    0.587346    
#> 303: 0.205813    0.846474    3.416900    0.194091    0.111829    0.017168    0.587174    
#> 304: 0.205537    0.846893    3.416663    0.194263    0.111996    0.017153    0.587129    
#> 305: 0.205378    0.846863    3.416545    0.194250    0.112051    0.017155    0.586985    
#> 306: 0.205126    0.846936    3.416414    0.194215    0.111977    0.017164    0.586891    
#> 307: 0.204841    0.847000    3.416266    0.194079    0.112138    0.017164    0.587023    
#> 308: 0.204489    0.847023    3.416124    0.194176    0.112253    0.017147    0.587059    
#> 309: 0.204211    0.846776    3.415987    0.194350    0.112269    0.017132    0.587292    
#> 310: 0.204322    0.846657    3.415896    0.194582    0.112341    0.017108    0.587381    
#> 311: 0.204407    0.846657    3.415907    0.194580    0.112207    0.017120    0.587294    
#> 312: 0.204200    0.846639    3.415862    0.194312    0.112206    0.017114    0.587344    
#> 313: 0.203847    0.846511    3.415730    0.194297    0.112266    0.017092    0.587520    
#> 314: 0.203380    0.846788    3.415523    0.194540    0.112339    0.017065    0.587520    
#> 315: 0.202958    0.846998    3.415296    0.194945    0.112411    0.017050    0.587493    
#> 316: 0.202660    0.847346    3.415067    0.195122    0.112570    0.017035    0.587521    
#> 317: 0.202510    0.847689    3.414936    0.195406    0.112681    0.017018    0.587735    
#> 318: 0.202278    0.847804    3.414724    0.195612    0.112677    0.017031    0.587674    
#> 319: 0.202043    0.847762    3.414619    0.195847    0.112806    0.017031    0.587642    
#> 320: 0.201724    0.847695    3.414487    0.195737    0.112795    0.017036    0.587771    
#> 321: 0.201397    0.847878    3.414274    0.195495    0.112918    0.017004    0.587952    
#> 322: 0.200889    0.847972    3.414038    0.195457    0.112770    0.016980    0.588053    
#> 323: 0.200196    0.848002    3.413849    0.195496    0.112662    0.016961    0.588069    
#> 324: 0.199921    0.847975    3.413748    0.195782    0.112669    0.016932    0.587937    
#> 325: 0.199730    0.848138    3.413639    0.196102    0.112669    0.016922    0.587825    
#> 326: 0.199489    0.848062    3.413511    0.196306    0.112591    0.016917    0.587709    
#> 327: 0.199300    0.848204    3.413417    0.196435    0.112607    0.016902    0.587610    
#> 328: 0.199358    0.848338    3.413359    0.196590    0.112604    0.016903    0.587449    
#> 329: 0.199559    0.848385    3.413394    0.196711    0.112521    0.016908    0.587295    
#> 330: 0.199572    0.848294    3.413407    0.197187    0.112435    0.016917    0.587119    
#> 331: 0.199747    0.848323    3.413458    0.197674    0.112406    0.016926    0.587021    
#> 332: 0.199994    0.848215    3.413596    0.197975    0.112418    0.016966    0.586858    
#> 333: 0.200103    0.848217    3.413529    0.198109    0.112515    0.016976    0.586770    
#> 334: 0.199850    0.848188    3.413426    0.198275    0.112588    0.016975    0.586649    
#> 335: 0.199500    0.848311    3.413255    0.198399    0.112565    0.016957    0.586525    
#> 336: 0.198911    0.848638    3.413077    0.198324    0.112510    0.016925    0.586578    
#> 337: 0.198416    0.849054    3.412819    0.198305    0.112612    0.016893    0.586610    
#> 338: 0.198106    0.849252    3.412663    0.198369    0.112665    0.016863    0.586666    
#> 339: 0.197861    0.849450    3.412510    0.198582    0.112731    0.016850    0.586703    
#> 340: 0.197620    0.849368    3.412417    0.198713    0.112663    0.016847    0.586663    
#> 341: 0.197568    0.849449    3.412378    0.198828    0.112649    0.016866    0.586663    
#> 342: 0.197340    0.849344    3.412339    0.198936    0.112656    0.016890    0.586580    
#> 343: 0.197152    0.849322    3.412268    0.199157    0.112641    0.016937    0.586507    
#> 344: 0.197033    0.849276    3.412204    0.199289    0.112626    0.016965    0.586490    
#> 345: 0.196936    0.849303    3.412144    0.199643    0.112658    0.016981    0.586544    
#> 346: 0.196922    0.849283    3.412028    0.199875    0.112659    0.016983    0.586593    
#> 347: 0.196790    0.849322    3.411947    0.199986    0.112742    0.016984    0.586626    
#> 348: 0.196656    0.849394    3.411878    0.200099    0.112881    0.016977    0.586610    
#> 349: 0.196385    0.849424    3.411806    0.200085    0.112914    0.016978    0.586486    
#> 350: 0.196012    0.849297    3.411721    0.200131    0.112986    0.016961    0.586423    
#> 351: 0.195908    0.849427    3.411616    0.200105    0.113038    0.016944    0.586413    
#> 352: 0.195696    0.849531    3.411603    0.200058    0.113082    0.016914    0.586548    
#> 353: 0.195799    0.849661    3.411596    0.200045    0.113042    0.016911    0.586583    
#> 354: 0.195918    0.849672    3.411584    0.199931    0.113109    0.016889    0.586647    
#> 355: 0.196216    0.849483    3.411570    0.199785    0.113254    0.016869    0.586662    
#> 356: 0.196303    0.849466    3.411613    0.199690    0.113193    0.016872    0.586623    
#> 357: 0.196450    0.849474    3.411642    0.199808    0.113122    0.016893    0.586609    
#> 358: 0.196455    0.849524    3.411624    0.199956    0.113119    0.016912    0.586474    
#> 359: 0.196416    0.849561    3.411589    0.200078    0.113019    0.016938    0.586379    
#> 360: 0.196249    0.849577    3.411487    0.200115    0.112992    0.016929    0.586309    
#> 361: 0.196126    0.849583    3.411467    0.200202    0.113033    0.016933    0.586221    
#> 362: 0.196137    0.849558    3.411418    0.200219    0.113037    0.016913    0.586174    
#> 363: 0.196109    0.849485    3.411384    0.200155    0.113042    0.016904    0.586037    
#> 364: 0.196157    0.849392    3.411401    0.200110    0.113083    0.016903    0.586067    
#> 365: 0.196195    0.849234    3.411437    0.200153    0.113066    0.016901    0.586086    
#> 366: 0.196110    0.849322    3.411333    0.200284    0.113054    0.016923    0.586083    
#> 367: 0.196213    0.849318    3.411324    0.200295    0.113121    0.016922    0.586086    
#> 368: 0.196327    0.849348    3.411329    0.200227    0.113181    0.016924    0.586134    
#> 369: 0.196294    0.849323    3.411318    0.200121    0.113218    0.016931    0.586151    
#> 370: 0.196254    0.849454    3.411295    0.200152    0.113241    0.016916    0.586182    
#> 371: 0.196284    0.849493    3.411215    0.200125    0.113288    0.016886    0.586173    
#> 372: 0.196259    0.849464    3.411183    0.200100    0.113239    0.016865    0.586209    
#> 373: 0.196248    0.849497    3.411177    0.200046    0.113246    0.016854    0.586250    
#> 374: 0.196336    0.849500    3.411181    0.200045    0.113307    0.016859    0.586251    
#> 375: 0.196350    0.849535    3.411210    0.200105    0.113324    0.016871    0.586293    
#> 376: 0.196417    0.849531    3.411282    0.200100    0.113261    0.016891    0.586257    
#> 377: 0.196264    0.849553    3.411253    0.200076    0.113122    0.016899    0.586212    
#> 378: 0.196181    0.849667    3.411195    0.200210    0.113102    0.016902    0.586156    
#> 379: 0.196166    0.849645    3.411184    0.200094    0.113109    0.016899    0.586098    
#> 380: 0.196159    0.849560    3.411199    0.199993    0.113012    0.016894    0.586124    
#> 381: 0.195891    0.849591    3.411155    0.199872    0.112988    0.016887    0.586157    
#> 382: 0.195770    0.849613    3.411122    0.199859    0.113026    0.016871    0.586039    
#> 383: 0.195907    0.849489    3.411143    0.200010    0.113010    0.016861    0.585916    
#> 384: 0.195862    0.849472    3.411177    0.200056    0.113005    0.016841    0.585824    
#> 385: 0.195833    0.849507    3.411174    0.200081    0.113113    0.016835    0.585784    
#> 386: 0.195929    0.849584    3.411200    0.200095    0.113221    0.016837    0.585755    
#> 387: 0.196148    0.849614    3.411288    0.200029    0.113257    0.016825    0.585678    
#> 388: 0.196281    0.849584    3.411383    0.199958    0.113231    0.016829    0.585631    
#> 389: 0.196246    0.849538    3.411395    0.199878    0.113122    0.016829    0.585671    
#> 390: 0.196162    0.849596    3.411333    0.199712    0.113056    0.016833    0.585721    
#> 391: 0.196257    0.849601    3.411286    0.199747    0.113056    0.016832    0.585712    
#> 392: 0.196318    0.849555    3.411331    0.199743    0.112982    0.016845    0.585732    
#> 393: 0.196320    0.849442    3.411312    0.199729    0.112979    0.016844    0.585694    
#> 394: 0.196329    0.849443    3.411264    0.199731    0.112952    0.016856    0.585692    
#> 395: 0.196483    0.849556    3.411259    0.199845    0.112983    0.016872    0.585645    
#> 396: 0.196657    0.849623    3.411256    0.199938    0.112962    0.016881    0.585565    
#> 397: 0.196693    0.849631    3.411273    0.199905    0.113014    0.016883    0.585533    
#> 398: 0.196861    0.849568    3.411309    0.199941    0.113113    0.016886    0.585463    
#> 399: 0.197129    0.849527    3.411379    0.199912    0.113194    0.016884    0.585424    
#> 400: 0.197234    0.849549    3.411400    0.199784    0.113172    0.016875    0.585428    
#> 401: 0.197259    0.849513    3.411399    0.199744    0.113124    0.016889    0.585489    
#> 402: 0.197286    0.849570    3.411426    0.199718    0.113065    0.016912    0.585502    
#> 403: 0.197486    0.849531    3.411479    0.199753    0.112955    0.016931    0.585468    
#> 404: 0.197572    0.849522    3.411468    0.199880    0.112976    0.016930    0.585358    
#> 405: 0.197562    0.849504    3.411500    0.199809    0.112893    0.016933    0.585398    
#> 406: 0.197575    0.849500    3.411469    0.199708    0.112923    0.016930    0.585444    
#> 407: 0.197484    0.849485    3.411450    0.199670    0.112999    0.016924    0.585461    
#> 408: 0.197522    0.849420    3.411436    0.199527    0.113079    0.016929    0.585478    
#> 409: 0.197565    0.849305    3.411426    0.199491    0.113173    0.016927    0.585459    
#> 410: 0.197531    0.849279    3.411360    0.199569    0.113283    0.016911    0.585502    
#> 411: 0.197645    0.849186    3.411348    0.199668    0.113229    0.016925    0.585495    
#> 412: 0.197753    0.849265    3.411336    0.199802    0.113244    0.016929    0.585448    
#> 413: 0.197833    0.849264    3.411351    0.200057    0.113120    0.016933    0.585482    
#> 414: 0.197767    0.849272    3.411359    0.200046    0.113065    0.016922    0.585511    
#> 415: 0.197880    0.849350    3.411340    0.200108    0.113063    0.016909    0.585518    
#> 416: 0.197954    0.849433    3.411359    0.200200    0.113104    0.016909    0.585472    
#> 417: 0.197906    0.849367    3.411362    0.200119    0.113075    0.016919    0.585476    
#> 418: 0.197864    0.849386    3.411400    0.200031    0.113050    0.016923    0.585430    
#> 419: 0.197870    0.849448    3.411413    0.199933    0.113107    0.016928    0.585376    
#> 420: 0.197862    0.849529    3.411401    0.199920    0.113082    0.016936    0.585296    
#> 421: 0.197847    0.849527    3.411433    0.199778    0.113052    0.016935    0.585232    
#> 422: 0.197925    0.849444    3.411441    0.199765    0.113050    0.016938    0.585219    
#> 423: 0.198061    0.849364    3.411445    0.199802    0.113078    0.016926    0.585268    
#> 424: 0.198075    0.849291    3.411436    0.199810    0.113056    0.016914    0.585226    
#> 425: 0.198097    0.849288    3.411450    0.199751    0.113056    0.016905    0.585208    
#> 426: 0.198155    0.849345    3.411468    0.199696    0.113107    0.016890    0.585136    
#> 427: 0.198132    0.849307    3.411522    0.199609    0.113159    0.016874    0.585124    
#> 428: 0.198095    0.849303    3.411531    0.199730    0.113139    0.016873    0.585136    
#> 429: 0.198074    0.849283    3.411539    0.199790    0.113152    0.016881    0.585074    
#> 430: 0.198054    0.849299    3.411517    0.199769    0.113141    0.016884    0.585039    
#> 431: 0.198020    0.849279    3.411488    0.199870    0.113142    0.016877    0.584995    
#> 432: 0.197889    0.849320    3.411495    0.199907    0.113144    0.016888    0.584970    
#> 433: 0.197897    0.849354    3.411508    0.199993    0.113157    0.016884    0.584938    
#> 434: 0.197836    0.849291    3.411518    0.199955    0.113205    0.016868    0.584922    
#> 435: 0.197905    0.849287    3.411513    0.199970    0.113192    0.016857    0.584905    
#> 436: 0.197925    0.849230    3.411572    0.199947    0.113214    0.016861    0.584914    
#> 437: 0.198003    0.849155    3.411576    0.199914    0.113208    0.016851    0.584906    
#> 438: 0.198086    0.849251    3.411578    0.199849    0.113235    0.016833    0.584964    
#> 439: 0.198099    0.849280    3.411606    0.199759    0.113254    0.016818    0.584933    
#> 440: 0.198044    0.849300    3.411658    0.199649    0.113246    0.016818    0.584902    
#> 441: 0.198016    0.849252    3.411666    0.199601    0.113182    0.016827    0.584865    
#> 442: 0.197938    0.849353    3.411647    0.199598    0.113182    0.016817    0.584819    
#> 443: 0.197916    0.849430    3.411605    0.199588    0.113150    0.016821    0.584752    
#> 444: 0.197843    0.849601    3.411516    0.199570    0.113126    0.016828    0.584678    
#> 445: 0.197678    0.849667    3.411462    0.199521    0.113101    0.016828    0.584677    
#> 446: 0.197486    0.849752    3.411400    0.199468    0.113032    0.016828    0.584631    
#> 447: 0.197502    0.849781    3.411377    0.199550    0.113001    0.016838    0.584574    
#> 448: 0.197490    0.849787    3.411416    0.199498    0.112952    0.016859    0.584486    
#> 449: 0.197493    0.849838    3.411479    0.199562    0.112952    0.016874    0.584454    
#> 450: 0.197512    0.849806    3.411491    0.199569    0.113011    0.016888    0.584493    
#> 451: 0.197526    0.849801    3.411516    0.199642    0.113012    0.016893    0.584510    
#> 452: 0.197522    0.849773    3.411522    0.199676    0.113064    0.016890    0.584473    
#> 453: 0.197451    0.849719    3.411521    0.199672    0.113011    0.016886    0.584419    
#> 454: 0.197451    0.849855    3.411466    0.199809    0.113014    0.016880    0.584414    
#> 455: 0.197427    0.849913    3.411451    0.199898    0.112998    0.016870    0.584400    
#> 456: 0.197346    0.849857    3.411452    0.199961    0.113028    0.016867    0.584442    
#> 457: 0.197255    0.849903    3.411446    0.199982    0.113096    0.016865    0.584394    
#> 458: 0.197201    0.849999    3.411418    0.199981    0.113132    0.016854    0.584350    
#> 459: 0.197070    0.850065    3.411392    0.199898    0.113164    0.016846    0.584305    
#> 460: 0.196938    0.850145    3.411313    0.199900    0.113170    0.016848    0.584293    
#> 461: 0.196836    0.850170    3.411286    0.199981    0.113146    0.016842    0.584297    
#> 462: 0.196825    0.850163    3.411304    0.200070    0.113163    0.016849    0.584228    
#> 463: 0.196840    0.850184    3.411329    0.200129    0.113181    0.016870    0.584166    
#> 464: 0.196924    0.850162    3.411310    0.200244    0.113154    0.016877    0.584075    
#> 465: 0.196944    0.850100    3.411316    0.200305    0.113116    0.016889    0.584013    
#> 466: 0.196890    0.850161    3.411267    0.200281    0.113054    0.016897    0.584000    
#> 467: 0.196793    0.850138    3.411262    0.200385    0.113015    0.016906    0.583922    
#> 468: 0.196898    0.850137    3.411287    0.200522    0.113015    0.016913    0.583902    
#> 469: 0.196914    0.850163    3.411273    0.200591    0.113026    0.016910    0.583921    
#> 470: 0.196716    0.850226    3.411173    0.200689    0.113018    0.016917    0.583863    
#> 471: 0.196543    0.850207    3.411120    0.200654    0.112993    0.016905    0.583885    
#> 472: 0.196392    0.850169    3.411056    0.200650    0.113057    0.016895    0.583876    
#> 473: 0.196248    0.850188    3.411003    0.200651    0.113062    0.016887    0.583803    
#> 474: 0.196083    0.850293    3.410970    0.200583    0.113105    0.016877    0.583815    
#> 475: 0.196014    0.850415    3.410941    0.200510    0.113135    0.016873    0.583846    
#> 476: 0.195934    0.850366    3.410914    0.200465    0.113149    0.016874    0.583836    
#> 477: 0.195914    0.850320    3.410914    0.200517    0.113139    0.016868    0.583774    
#> 478: 0.195756    0.850304    3.410900    0.200585    0.113154    0.016864    0.583790    
#> 479: 0.195748    0.850300    3.410900    0.200647    0.113113    0.016855    0.583790    
#> 480: 0.195717    0.850321    3.410891    0.200678    0.113182    0.016852    0.583819    
#> 481: 0.195660    0.850341    3.410894    0.200671    0.113224    0.016844    0.583823    
#> 482: 0.195635    0.850277    3.410855    0.200738    0.113257    0.016839    0.583884    
#> 483: 0.195624    0.850200    3.410850    0.200770    0.113231    0.016837    0.583828    
#> 484: 0.195550    0.850133    3.410849    0.200762    0.113192    0.016828    0.583835    
#> 485: 0.195547    0.850152    3.410814    0.200812    0.113200    0.016812    0.583770    
#> 486: 0.195546    0.850159    3.410829    0.200788    0.113161    0.016807    0.583689    
#> 487: 0.195667    0.850136    3.410873    0.200804    0.113164    0.016803    0.583614    
#> 488: 0.195741    0.850040    3.410925    0.200731    0.113137    0.016806    0.583601    
#> 489: 0.195843    0.850044    3.410942    0.200653    0.113149    0.016799    0.583630    
#> 490: 0.195882    0.850052    3.410960    0.200460    0.113164    0.016793    0.583638    
#> 491: 0.195918    0.850118    3.411026    0.200405    0.113156    0.016807    0.583619    
#> 492: 0.195942    0.850185    3.411047    0.200354    0.113213    0.016816    0.583676    
#> 493: 0.195946    0.850210    3.411047    0.200421    0.113203    0.016837    0.583684    
#> 494: 0.196036    0.850261    3.411039    0.200478    0.113192    0.016851    0.583623    
#> 495: 0.196090    0.850255    3.411028    0.200548    0.113178    0.016858    0.583573    
#> 496: 0.196127    0.850322    3.410984    0.200637    0.113196    0.016863    0.583571    
#> 497: 0.196021    0.850346    3.410949    0.200625    0.113243    0.016871    0.583581    
#> 498: 0.195956    0.850384    3.410906    0.200679    0.113272    0.016867    0.583509    
#> 499: 0.195913    0.850403    3.410855    0.200764    0.113269    0.016865    0.583437    
#> 500: 0.195893    0.850423    3.410812    0.200837    0.113239    0.016873    0.583355    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.282238    0.975883    3.452717    0.392401    0.076213    0.016800    1.716017    
#> 002: 0.328998    1.022751    3.489423    0.372781    0.072403    0.015960    1.186324    
#> 003: 0.480147    0.958088    3.497983    0.354142    0.068782    0.015162    0.916401    
#> 004: 0.448496    0.976742    3.502569    0.336435    0.070408    0.014404    0.824571    
#> 005: 0.501133    0.989009    3.496462    0.319613    0.082783    0.015940    0.785375    
#> 006: 0.479075    0.997937    3.479583    0.303633    0.090482    0.018292    0.726906    
#> 007: 0.405403    1.022039    3.466136    0.288451    0.092180    0.018147    0.731020    
#> 008: 0.388706    1.021510    3.455006    0.274029    0.096143    0.019500    0.710219    
#> 009: 0.361819    1.026187    3.444900    0.269341    0.116622    0.018911    0.708696    
#> 010: 0.364547    1.023075    3.438258    0.271100    0.110791    0.019491    0.730183    
#> 011: 0.418963    1.019532    3.450576    0.259118    0.105251    0.023021    0.730006    
#> 012: 0.411627    1.022657    3.453065    0.285184    0.099989    0.021870    0.721554    
#> 013: 0.352506    1.046075    3.427725    0.309339    0.094989    0.022390    0.721514    
#> 014: 0.374055    1.047589    3.440678    0.293872    0.090387    0.021271    0.747182    
#> 015: 0.394903    1.040134    3.447685    0.284896    0.085867    0.021207    0.719538    
#> 016: 0.392843    1.043730    3.447909    0.289163    0.085164    0.022530    0.744196    
#> 017: 0.391576    1.040996    3.458433    0.295754    0.082694    0.022681    0.734337    
#> 018: 0.376928    1.061804    3.437367    0.310987    0.087731    0.021547    0.715425    
#> 019: 0.328891    1.051351    3.433928    0.308561    0.085179    0.020470    0.713701    
#> 020: 0.376097    1.043860    3.448397    0.315428    0.080960    0.019446    0.725664    
#> 021: 0.444026    1.015663    3.469947    0.341595    0.086354    0.018474    0.721105    
#> 022: 0.446040    1.009075    3.481910    0.324515    0.096281    0.022096    0.721720    
#> 023: 0.509859    1.016478    3.500306    0.311567    0.099740    0.026507    0.721478    
#> 024: 0.499751    1.019263    3.490785    0.351888    0.094753    0.026110    0.706937    
#> 025: 0.492324    0.998709    3.491872    0.341672    0.090016    0.028726    0.692183    
#> 026: 0.451160    1.014500    3.477912    0.333916    0.085515    0.028479    0.699586    
#> 027: 0.431433    1.030628    3.463030    0.330256    0.086062    0.029673    0.715369    
#> 028: 0.470178    1.011783    3.475794    0.313743    0.081759    0.030606    0.705793    
#> 029: 0.449980    1.015875    3.468359    0.298056    0.079619    0.031968    0.720129    
#> 030: 0.446062    1.031399    3.461604    0.377645    0.075638    0.034860    0.703826    
#> 031: 0.415157    1.013626    3.475640    0.381293    0.084608    0.033117    0.707223    
#> 032: 0.411830    1.012528    3.472100    0.362229    0.080378    0.031971    0.693692    
#> 033: 0.400335    1.029215    3.460029    0.350238    0.076359    0.038891    0.696482    
#> 034: 0.429031    1.043402    3.461431    0.358987    0.072541    0.036946    0.699605    
#> 035: 0.373993    1.025358    3.450845    0.341038    0.069842    0.035099    0.694556    
#> 036: 0.405721    1.045621    3.453986    0.323986    0.082224    0.033344    0.681942    
#> 037: 0.418913    1.030418    3.454600    0.354371    0.082439    0.031694    0.690927    
#> 038: 0.422810    1.038327    3.456580    0.340174    0.086196    0.033758    0.693201    
#> 039: 0.424811    1.030117    3.465477    0.323165    0.088164    0.032070    0.689437    
#> 040: 0.422658    1.019764    3.476054    0.332370    0.083756    0.030466    0.717669    
#> 041: 0.416811    1.007931    3.470136    0.365310    0.079568    0.030704    0.697386    
#> 042: 0.425439    1.023113    3.456777    0.352798    0.075590    0.034821    0.706464    
#> 043: 0.395214    1.043171    3.447152    0.335158    0.071810    0.034641    0.707547    
#> 044: 0.367784    1.056602    3.448413    0.320854    0.068915    0.032909    0.713529    
#> 045: 0.374387    1.058215    3.441789    0.304812    0.071829    0.031263    0.700282    
#> 046: 0.364759    1.038973    3.433646    0.337605    0.069812    0.031681    0.703298    
#> 047: 0.389664    1.042631    3.452162    0.359318    0.068285    0.033227    0.686080    
#> 048: 0.415361    1.026574    3.459154    0.355989    0.087233    0.031566    0.695795    
#> 049: 0.367226    1.052637    3.443982    0.338189    0.087705    0.029987    0.699130    
#> 050: 0.408082    1.019597    3.456868    0.329110    0.086759    0.028488    0.727981    
#> 051: 0.382891    1.048288    3.439973    0.312654    0.099066    0.027064    0.711161    
#> 052: 0.394907    1.046210    3.458117    0.297022    0.094112    0.025711    0.706554    
#> 053: 0.380724    1.017819    3.453062    0.282170    0.107853    0.024425    0.723932    
#> 054: 0.375733    1.022069    3.455101    0.299964    0.102460    0.028323    0.719274    
#> 055: 0.404341    1.015228    3.464801    0.284966    0.097337    0.030201    0.707726    
#> 056: 0.438025    1.008762    3.476694    0.270718    0.092470    0.028691    0.730915    
#> 057: 0.436583    1.017264    3.485821    0.257182    0.087847    0.027256    0.724373    
#> 058: 0.407023    1.051398    3.460994    0.297878    0.090701    0.026704    0.698076    
#> 059: 0.393443    1.001465    3.467348    0.283920    0.086781    0.031129    0.714372    
#> 060: 0.388243    0.995150    3.466948    0.269724    0.092592    0.029572    0.727006    
#> 061: 0.441677    1.007011    3.471504    0.268276    0.088180    0.028094    0.732977    
#> 062: 0.427152    1.021581    3.478366    0.299724    0.085065    0.028139    0.734864    
#> 063: 0.465226    0.983197    3.477070    0.289216    0.080812    0.026732    0.743321    
#> 064: 0.475103    0.985920    3.488354    0.318923    0.076772    0.025395    0.729507    
#> 065: 0.508433    0.985417    3.478935    0.320299    0.082166    0.024125    0.727652    
#> 066: 0.478138    1.032051    3.471684    0.304284    0.078057    0.023993    0.714373    
#> 067: 0.416486    1.008774    3.464342    0.294148    0.081951    0.022793    0.705428    
#> 068: 0.403350    1.004397    3.468468    0.287717    0.102521    0.023201    0.709370    
#> 069: 0.411018    1.021664    3.474010    0.273331    0.097395    0.025552    0.719095    
#> 070: 0.430119    1.020743    3.475970    0.275458    0.094232    0.031114    0.713766    
#> 071: 0.391832    1.026783    3.457984    0.261685    0.093961    0.029559    0.723565    
#> 072: 0.350730    1.028708    3.443513    0.248600    0.089263    0.028081    0.720526    
#> 073: 0.369774    1.028448    3.461105    0.254770    0.084800    0.028213    0.710602    
#> 074: 0.369889    1.022222    3.453800    0.242031    0.082752    0.026802    0.728262    
#> 075: 0.390514    0.990583    3.479738    0.278012    0.082863    0.025462    0.728451    
#> 076: 0.470767    0.995153    3.492909    0.324955    0.089883    0.029002    0.714398    
#> 077: 0.479773    0.985060    3.487444    0.314943    0.085389    0.028766    0.710589    
#> 078: 0.444755    1.009288    3.472484    0.299196    0.081120    0.027327    0.700449    
#> 079: 0.441727    1.019955    3.473736    0.336905    0.095371    0.025961    0.712068    
#> 080: 0.467993    1.001644    3.482058    0.320060    0.090602    0.028306    0.716733    
#> 081: 0.409351    1.024385    3.471997    0.304057    0.086072    0.030708    0.712458    
#> 082: 0.412462    1.024478    3.465621    0.288854    0.089807    0.029172    0.719486    
#> 083: 0.404706    1.041207    3.461615    0.303357    0.085316    0.027714    0.718804    
#> 084: 0.411638    1.033215    3.450962    0.288189    0.083846    0.026328    0.708864    
#> 085: 0.393035    1.040713    3.463511    0.273779    0.079654    0.027646    0.708423    
#> 086: 0.424281    1.043436    3.464813    0.275040    0.086182    0.026263    0.700781    
#> 087: 0.412442    1.040476    3.446572    0.302475    0.084849    0.024950    0.701513    
#> 088: 0.357275    1.036475    3.450648    0.290881    0.080606    0.023703    0.732428    
#> 089: 0.359754    1.062199    3.431700    0.276337    0.102377    0.023113    0.733605    
#> 090: 0.343977    1.040880    3.433683    0.262520    0.097258    0.021958    0.736205    
#> 091: 0.339817    1.031413    3.424199    0.249394    0.092395    0.021156    0.719917    
#> 092: 0.368931    1.047414    3.437595    0.246779    0.087775    0.023034    0.742438    
#> 093: 0.375122    1.025672    3.451594    0.252277    0.083387    0.029762    0.757139    
#> 094: 0.406111    1.041501    3.448057    0.316118    0.079217    0.028274    0.739055    
#> 095: 0.381906    1.039222    3.454908    0.300312    0.088919    0.026860    0.724806    
#> 096: 0.368668    1.028847    3.455753    0.285297    0.108904    0.025517    0.716319    
#> 097: 0.423998    1.044829    3.455582    0.281245    0.103458    0.024241    0.705030    
#> 098: 0.415580    1.057036    3.464283    0.267183    0.106533    0.023029    0.724577    
#> 099: 0.403311    1.040471    3.449182    0.253824    0.124040    0.021878    0.701914    
#> 100: 0.369140    1.039001    3.448872    0.264721    0.117838    0.020784    0.702663    
#> 101: 0.366410    1.026808    3.436928    0.273547    0.111946    0.019744    0.700182    
#> 102: 0.388227    1.035184    3.441606    0.307414    0.106349    0.018757    0.723591    
#> 103: 0.395986    1.038693    3.450674    0.292044    0.101031    0.018250    0.722623    
#> 104: 0.387628    1.031955    3.467931    0.287069    0.096535    0.018138    0.727022    
#> 105: 0.426320    1.033718    3.465511    0.307565    0.100751    0.017932    0.745100    
#> 106: 0.438572    1.027774    3.462642    0.326301    0.095714    0.020079    0.727018    
#> 107: 0.425273    1.054392    3.445521    0.360203    0.092142    0.019075    0.705597    
#> 108: 0.386969    1.019646    3.443879    0.342193    0.091353    0.018122    0.717810    
#> 109: 0.368046    1.016445    3.466543    0.325083    0.100560    0.017646    0.755136    
#> 110: 0.400497    1.012871    3.452558    0.317124    0.095532    0.016763    0.726483    
#> 111: 0.404315    1.018130    3.451931    0.317324    0.090756    0.018020    0.710865    
#> 112: 0.359907    1.012124    3.442283    0.346363    0.086218    0.018129    0.733758    
#> 113: 0.407179    1.037978    3.461825    0.336238    0.081907    0.020494    0.710138    
#> 114: 0.434232    1.031323    3.460545    0.342303    0.077812    0.023165    0.713406    
#> 115: 0.483134    1.011868    3.462596    0.370056    0.075647    0.029765    0.736717    
#> 116: 0.470653    1.019416    3.461632    0.351554    0.076663    0.031717    0.704282    
#> 117: 0.399604    1.033583    3.462554    0.344490    0.072830    0.030131    0.719033    
#> 118: 0.452198    1.016311    3.458509    0.327265    0.082956    0.028625    0.703105    
#> 119: 0.412757    1.033499    3.456494    0.310902    0.081958    0.027193    0.704775    
#> 120: 0.414495    1.030495    3.460097    0.355075    0.090805    0.026751    0.691958    
#> 121: 0.415648    1.046181    3.469926    0.341621    0.112395    0.026398    0.697073    
#> 122: 0.441229    1.025608    3.467632    0.324540    0.106776    0.025078    0.696940    
#> 123: 0.450327    1.038414    3.458401    0.308313    0.101437    0.023865    0.705561    
#> 124: 0.433842    1.057653    3.453016    0.357138    0.096365    0.024787    0.701902    
#> 125: 0.407223    1.054081    3.449265    0.339281    0.091547    0.028197    0.698067    
#> 126: 0.388541    1.053286    3.448192    0.322317    0.086969    0.026787    0.702466    
#> 127: 0.417031    1.042269    3.442697    0.382281    0.082621    0.028569    0.711324    
#> 128: 0.369773    1.029820    3.457226    0.363166    0.086303    0.027781    0.714569    
#> 129: 0.418577    1.047851    3.451231    0.351271    0.086695    0.029325    0.711378    
#> 130: 0.436333    1.045475    3.452224    0.349200    0.098010    0.027859    0.695451    
#> 131: 0.426861    1.040497    3.446975    0.331740    0.115987    0.026466    0.704827    
#> 132: 0.380790    1.049306    3.439166    0.319201    0.110187    0.025142    0.727110    
#> 133: 0.348488    1.044439    3.440452    0.303241    0.104678    0.025725    0.732616    
#> 134: 0.413699    1.029384    3.466233    0.314216    0.099444    0.033553    0.708498    
#> 135: 0.413671    1.017948    3.471595    0.365457    0.094472    0.033752    0.707339    
#> 136: 0.432518    1.012617    3.477663    0.347184    0.099182    0.032502    0.711582    
#> 137: 0.483439    1.009653    3.484526    0.352706    0.094223    0.031758    0.727537    
#> 138: 0.435249    1.024812    3.472873    0.335071    0.089512    0.034016    0.722938    
#> 139: 0.436756    1.022149    3.486421    0.324611    0.085036    0.034574    0.712599    
#> 140: 0.474431    1.020468    3.491653    0.308380    0.084043    0.032846    0.732344    
#> 141: 0.448723    0.995673    3.485370    0.292961    0.079841    0.031203    0.714998    
#> 142: 0.472894    0.999004    3.496284    0.347717    0.079384    0.029643    0.714467    
#> 143: 0.418127    1.014223    3.470101    0.330332    0.095078    0.028161    0.723652    
#> 144: 0.433556    1.015805    3.478915    0.319446    0.090324    0.026753    0.699008    
#> 145: 0.422121    1.025494    3.457189    0.358074    0.085807    0.025415    0.700805    
#> 146: 0.381324    1.034779    3.456771    0.370556    0.083728    0.024145    0.711096    
#> 147: 0.387161    1.025887    3.450430    0.352028    0.091683    0.025955    0.708827    
#> 148: 0.394143    1.034536    3.461413    0.334427    0.089480    0.024657    0.704949    
#> 149: 0.375717    1.022387    3.458345    0.317705    0.085006    0.025707    0.712587    
#> 150: 0.426952    1.015206    3.458559    0.301820    0.080755    0.026770    0.714852    
#> 151: 0.372085    1.048641    3.448134    0.304830    0.076718    0.025431    0.711582    
#> 152: 0.366217    1.051693    3.452374    0.278626    0.063134    0.022862    0.703132    
#> 153: 0.423266    1.047501    3.469199    0.276125    0.081090    0.026377    0.717962    
#> 154: 0.449615    1.034896    3.465217    0.300069    0.078155    0.027465    0.705167    
#> 155: 0.434691    1.022892    3.463016    0.324705    0.071769    0.022919    0.708879    
#> 156: 0.454796    1.037439    3.467530    0.345804    0.068915    0.023662    0.733179    
#> 157: 0.436712    1.021300    3.475462    0.308759    0.079454    0.023174    0.721460    
#> 158: 0.469657    1.045704    3.460418    0.330938    0.082330    0.020397    0.711771    
#> 159: 0.412678    1.052727    3.468131    0.259653    0.098380    0.022698    0.714803    
#> 160: 0.437554    1.001294    3.481484    0.284548    0.089775    0.024738    0.709020    
#> 161: 0.450942    1.014967    3.475747    0.272363    0.078391    0.023348    0.710788    
#> 162: 0.422894    1.024952    3.470205    0.274933    0.082753    0.021731    0.716386    
#> 163: 0.426527    1.017717    3.462938    0.266094    0.098672    0.024377    0.725328    
#> 164: 0.430133    1.040355    3.452751    0.248046    0.090686    0.019849    0.714253    
#> 165: 0.451266    1.014015    3.472820    0.313409    0.079819    0.027751    0.694517    
#> 166: 0.423176    1.034821    3.471808    0.299857    0.086731    0.030164    0.709064    
#> 167: 0.423738    1.049677    3.468891    0.287705    0.086922    0.027672    0.731562    
#> 168: 0.455031    1.047765    3.454727    0.297990    0.091434    0.023400    0.724354    
#> 169: 0.390721    1.075845    3.445449    0.246896    0.077479    0.023468    0.733524    
#> 170: 0.404615    1.043534    3.459724    0.243134    0.084783    0.024348    0.723957    
#> 171: 0.363033    1.051113    3.447695    0.278084    0.076975    0.026134    0.714049    
#> 172: 0.375484    1.059048    3.454024    0.253584    0.082971    0.026948    0.714478    
#> 173: 0.382713    1.050167    3.443018    0.250101    0.093562    0.016481    0.708091    
#> 174: 0.397617    1.034328    3.451092    0.263200    0.088679    0.018240    0.713148    
#> 175: 0.385137    1.048298    3.441781    0.278039    0.085942    0.017040    0.721147    
#> 176: 0.410491    1.057146    3.458116    0.272768    0.087503    0.020419    0.713920    
#> 177: 0.425055    1.051761    3.465666    0.298272    0.084519    0.017597    0.715012    
#> 178: 0.395315    1.038142    3.463140    0.321620    0.088773    0.020806    0.703124    
#> 179: 0.458648    1.045166    3.468375    0.311277    0.089146    0.026913    0.716160    
#> 180: 0.408808    1.050098    3.465173    0.269027    0.079731    0.025932    0.699972    
#> 181: 0.380114    1.053486    3.440033    0.256571    0.075507    0.023671    0.698415    
#> 182: 0.387913    1.053338    3.438115    0.325434    0.090428    0.023038    0.727988    
#> 183: 0.375777    1.078959    3.442261    0.306036    0.109274    0.020533    0.718452    
#> 184: 0.400697    1.039957    3.448360    0.306897    0.101828    0.021912    0.711846    
#> 185: 0.381969    1.061969    3.442799    0.272028    0.115636    0.018360    0.710418    
#> 186: 0.369598    1.063535    3.441720    0.270002    0.120139    0.020533    0.718219    
#> 187: 0.384512    1.037559    3.454302    0.267141    0.111043    0.018988    0.733268    
#> 188: 0.387746    1.047183    3.457913    0.247164    0.096821    0.017504    0.737108    
#> 189: 0.435810    1.053034    3.465490    0.251696    0.095514    0.017544    0.757040    
#> 190: 0.415981    1.035863    3.469548    0.236289    0.077571    0.016760    0.722259    
#> 191: 0.368125    1.051495    3.449476    0.274793    0.085145    0.015854    0.705276    
#> 192: 0.364649    1.047620    3.445873    0.260912    0.077427    0.022680    0.710657    
#> 193: 0.409356    1.067945    3.447384    0.255903    0.079903    0.017906    0.707067    
#> 194: 0.367017    1.053040    3.437520    0.245567    0.091490    0.019425    0.725949    
#> 195: 0.353630    1.065328    3.432563    0.269889    0.092621    0.018765    0.719831    
#> 196: 0.327254    1.046742    3.441106    0.228665    0.091090    0.017272    0.733659    
#> 197: 0.335368    1.043171    3.455442    0.262435    0.086480    0.018718    0.735202    
#> 198: 0.399664    1.025284    3.444893    0.295894    0.091314    0.022161    0.734411    
#> 199: 0.379189    1.043697    3.450556    0.256447    0.092900    0.020506    0.744422    
#> 200: 0.382282    1.044015    3.455447    0.316908    0.100226    0.021754    0.747909    
#> 201: 0.376314    1.038961    3.452842    0.311467    0.102722    0.022159    0.740788    
#> 202: 0.383808    1.040717    3.452549    0.306678    0.100390    0.021423    0.739033    
#> 203: 0.400233    1.035303    3.453078    0.326278    0.100574    0.021634    0.733889    
#> 204: 0.407147    1.027321    3.456669    0.335495    0.103224    0.022648    0.733550    
#> 205: 0.405385    1.030345    3.455997    0.355059    0.101302    0.023281    0.734549    
#> 206: 0.398061    1.035115    3.455698    0.365654    0.098985    0.023369    0.733203    
#> 207: 0.396280    1.037138    3.454043    0.368410    0.099219    0.023474    0.730243    
#> 208: 0.398886    1.038979    3.453219    0.367681    0.098686    0.023741    0.728052    
#> 209: 0.404723    1.038169    3.453373    0.365041    0.096902    0.023811    0.724221    
#> 210: 0.405731    1.036266    3.454578    0.361601    0.095362    0.023530    0.722311    
#> 211: 0.409024    1.036251    3.455399    0.359280    0.095457    0.023619    0.719602    
#> 212: 0.411449    1.034401    3.456084    0.357436    0.094985    0.023819    0.718527    
#> 213: 0.414245    1.033057    3.456856    0.354657    0.094817    0.023808    0.718774    
#> 214: 0.416625    1.031113    3.458120    0.349444    0.093992    0.023892    0.718267    
#> 215: 0.418165    1.030852    3.459481    0.344843    0.093362    0.023934    0.717920    
#> 216: 0.420493    1.030293    3.460380    0.341695    0.093000    0.024031    0.719410    
#> 217: 0.420838    1.030781    3.460749    0.340484    0.092772    0.023903    0.719716    
#> 218: 0.419745    1.032578    3.460002    0.338957    0.094039    0.023898    0.719310    
#> 219: 0.417567    1.032675    3.458630    0.339348    0.093158    0.024009    0.719200    
#> 220: 0.415251    1.032889    3.458300    0.338788    0.093096    0.024172    0.718178    
#> 221: 0.412484    1.033502    3.457364    0.337474    0.092450    0.024298    0.717655    
#> 222: 0.410866    1.033597    3.456539    0.335184    0.091628    0.024428    0.718492    
#> 223: 0.410881    1.033454    3.456134    0.335852    0.090923    0.024450    0.718917    
#> 224: 0.411523    1.033731    3.456234    0.334612    0.090398    0.024267    0.719111    
#> 225: 0.411254    1.032448    3.456373    0.335865    0.090109    0.024295    0.719060    
#> 226: 0.410130    1.031940    3.455620    0.337016    0.089738    0.024268    0.718950    
#> 227: 0.409391    1.033003    3.455155    0.337556    0.089829    0.024267    0.718117    
#> 228: 0.408712    1.034217    3.454312    0.339967    0.089630    0.024337    0.717559    
#> 229: 0.407071    1.034446    3.453790    0.341026    0.089619    0.024439    0.717035    
#> 230: 0.407281    1.034550    3.453296    0.343413    0.089260    0.024466    0.716867    
#> 231: 0.407452    1.035213    3.453217    0.343935    0.089182    0.024427    0.716313    
#> 232: 0.406985    1.034894    3.453765    0.342696    0.088799    0.024565    0.716564    
#> 233: 0.407084    1.034063    3.454077    0.345479    0.088311    0.024863    0.716612    
#> 234: 0.406878    1.033581    3.454079    0.345882    0.088418    0.024999    0.716238    
#> 235: 0.405762    1.033319    3.453832    0.346530    0.087859    0.025105    0.716286    
#> 236: 0.404437    1.034059    3.453415    0.348141    0.087504    0.025255    0.716403    
#> 237: 0.404920    1.034282    3.453533    0.348692    0.086931    0.025392    0.717205    
#> 238: 0.405396    1.034536    3.453437    0.350965    0.086905    0.025483    0.718218    
#> 239: 0.404724    1.035464    3.453191    0.352055    0.087027    0.025496    0.718462    
#> 240: 0.405311    1.034898    3.453464    0.352481    0.086986    0.025447    0.718248    
#> 241: 0.405847    1.033733    3.453819    0.352686    0.086884    0.025452    0.718138    
#> 242: 0.405669    1.032945    3.453838    0.352551    0.087217    0.025532    0.718029    
#> 243: 0.405283    1.033311    3.453894    0.351230    0.087695    0.025523    0.717826    
#> 244: 0.405104    1.033285    3.454212    0.349940    0.087702    0.025611    0.717730    
#> 245: 0.405602    1.032610    3.454572    0.349530    0.087767    0.025664    0.718245    
#> 246: 0.406599    1.032139    3.455017    0.348604    0.087670    0.025791    0.718352    
#> 247: 0.407071    1.031793    3.455376    0.347881    0.087612    0.025867    0.718537    
#> 248: 0.407113    1.032158    3.455496    0.346502    0.087689    0.025800    0.718496    
#> 249: 0.407156    1.032071    3.455468    0.345702    0.087716    0.025823    0.718516    
#> 250: 0.407366    1.032420    3.455610    0.345725    0.087954    0.025889    0.718654    
#> 251: 0.407397    1.032779    3.455852    0.344891    0.087724    0.025937    0.718945    
#> 252: 0.408321    1.033183    3.456014    0.345208    0.087530    0.025880    0.719108    
#> 253: 0.408282    1.033522    3.456005    0.346077    0.087334    0.025984    0.719067    
#> 254: 0.408399    1.033895    3.455994    0.345530    0.087271    0.025927    0.719001    
#> 255: 0.408324    1.034137    3.456081    0.345213    0.086939    0.025893    0.719214    
#> 256: 0.408616    1.033952    3.456092    0.345146    0.086712    0.025856    0.719135    
#> 257: 0.409097    1.033718    3.456187    0.344428    0.087083    0.025869    0.719171    
#> 258: 0.409091    1.033010    3.456574    0.342629    0.087216    0.025777    0.719325    
#> 259: 0.409156    1.032481    3.456769    0.340923    0.087126    0.025729    0.719495    
#> 260: 0.409552    1.032050    3.457066    0.339331    0.086905    0.025709    0.719182    
#> 261: 0.410407    1.031533    3.457465    0.338629    0.086691    0.025678    0.719559    
#> 262: 0.410420    1.031618    3.457595    0.338071    0.086242    0.025660    0.719787    
#> 263: 0.410303    1.031668    3.457753    0.336881    0.086089    0.025623    0.719967    
#> 264: 0.410120    1.031737    3.457744    0.336113    0.085798    0.025628    0.720429    
#> 265: 0.410461    1.031796    3.457683    0.335898    0.085565    0.025604    0.720472    
#> 266: 0.411068    1.031807    3.457737    0.336874    0.085466    0.025559    0.720490    
#> 267: 0.411335    1.031825    3.457876    0.338040    0.085517    0.025577    0.720285    
#> 268: 0.410759    1.031596    3.457756    0.337083    0.085643    0.025531    0.720251    
#> 269: 0.411048    1.031520    3.457752    0.336955    0.085644    0.025438    0.720249    
#> 270: 0.411030    1.031651    3.457686    0.337241    0.085425    0.025398    0.720029    
#> 271: 0.411130    1.031921    3.457670    0.337126    0.085408    0.025385    0.720162    
#> 272: 0.411389    1.031701    3.457701    0.336674    0.085274    0.025421    0.720508    
#> 273: 0.411556    1.031855    3.457757    0.336610    0.085342    0.025430    0.720761    
#> 274: 0.411712    1.032001    3.457874    0.336344    0.085083    0.025446    0.720702    
#> 275: 0.411813    1.031960    3.457877    0.336815    0.085197    0.025485    0.720630    
#> 276: 0.411579    1.032206    3.457889    0.336913    0.085097    0.025505    0.720536    
#> 277: 0.411113    1.032471    3.457937    0.336397    0.084981    0.025525    0.720499    
#> 278: 0.410785    1.032352    3.457992    0.336347    0.084776    0.025563    0.720255    
#> 279: 0.410315    1.032172    3.458009    0.335669    0.084708    0.025573    0.720460    
#> 280: 0.409961    1.032137    3.457982    0.334467    0.084738    0.025543    0.720438    
#> 281: 0.409444    1.032188    3.457888    0.333859    0.084806    0.025460    0.720460    
#> 282: 0.409415    1.032553    3.457859    0.334122    0.084886    0.025499    0.720259    
#> 283: 0.409179    1.032695    3.457954    0.334202    0.085007    0.025610    0.720272    
#> 284: 0.409224    1.032599    3.458024    0.334516    0.084838    0.025681    0.719934    
#> 285: 0.409604    1.032675    3.457961    0.335238    0.084647    0.025709    0.719676    
#> 286: 0.410140    1.032579    3.458117    0.336183    0.084532    0.025828    0.719417    
#> 287: 0.410798    1.032402    3.458375    0.336443    0.084340    0.025936    0.719338    
#> 288: 0.411363    1.032193    3.458506    0.336318    0.084375    0.025964    0.719469    
#> 289: 0.412011    1.032037    3.458691    0.336300    0.084359    0.025980    0.719442    
#> 290: 0.412705    1.031922    3.458977    0.336375    0.084372    0.025968    0.719394    
#> 291: 0.413063    1.032073    3.459099    0.336175    0.084284    0.025917    0.719282    
#> 292: 0.413007    1.032085    3.459146    0.335595    0.084214    0.025899    0.719212    
#> 293: 0.413018    1.032128    3.459119    0.335041    0.084049    0.025867    0.719232    
#> 294: 0.412916    1.032273    3.459053    0.334853    0.084035    0.025821    0.719220    
#> 295: 0.413094    1.031953    3.459120    0.334516    0.084008    0.025805    0.719014    
#> 296: 0.413159    1.031772    3.459138    0.334289    0.083857    0.025794    0.718996    
#> 297: 0.413600    1.031923    3.459163    0.334505    0.083816    0.025816    0.718863    
#> 298: 0.413737    1.032051    3.459106    0.334497    0.083826    0.025829    0.718700    
#> 299: 0.413859    1.032239    3.459065    0.334223    0.083746    0.025845    0.718510    
#> 300: 0.413956    1.032157    3.459122    0.333649    0.083687    0.025798    0.718404    
#> 301: 0.414146    1.031968    3.459096    0.333194    0.083489    0.025738    0.718496    
#> 302: 0.414189    1.032040    3.459099    0.332612    0.083433    0.025723    0.718441    
#> 303: 0.414127    1.032220    3.459017    0.332296    0.083328    0.025709    0.718326    
#> 304: 0.414232    1.032574    3.458958    0.331559    0.083274    0.025672    0.718521    
#> 305: 0.414108    1.032340    3.458994    0.331052    0.083260    0.025651    0.718436    
#> 306: 0.414048    1.032252    3.458839    0.330986    0.083179    0.025642    0.718324    
#> 307: 0.413836    1.032292    3.458639    0.331273    0.083116    0.025641    0.718258    
#> 308: 0.413270    1.032261    3.458466    0.331225    0.083030    0.025628    0.718451    
#> 309: 0.413169    1.031945    3.458357    0.331404    0.082921    0.025603    0.718815    
#> 310: 0.413426    1.031747    3.458345    0.331970    0.082890    0.025620    0.718819    
#> 311: 0.413353    1.031657    3.458375    0.331900    0.082805    0.025645    0.718714    
#> 312: 0.413206    1.031447    3.458373    0.331855    0.082772    0.025608    0.718704    
#> 313: 0.413235    1.031040    3.458345    0.331657    0.082886    0.025634    0.718816    
#> 314: 0.412746    1.031067    3.458280    0.331134    0.082873    0.025606    0.718879    
#> 315: 0.412304    1.031258    3.458218    0.330239    0.082854    0.025619    0.718965    
#> 316: 0.412189    1.031544    3.458158    0.329565    0.082823    0.025612    0.718939    
#> 317: 0.412290    1.031672    3.458106    0.329304    0.082813    0.025570    0.719002    
#> 318: 0.412315    1.032001    3.457938    0.329470    0.082846    0.025596    0.718875    
#> 319: 0.412304    1.031994    3.457907    0.329579    0.082800    0.025608    0.718994    
#> 320: 0.411983    1.031980    3.457839    0.330176    0.082829    0.025578    0.719075    
#> 321: 0.411844    1.032208    3.457660    0.330445    0.082887    0.025575    0.719178    
#> 322: 0.411356    1.032460    3.457446    0.330047    0.082955    0.025571    0.719276    
#> 323: 0.410589    1.032601    3.457228    0.329837    0.082976    0.025589    0.719256    
#> 324: 0.409999    1.032748    3.457067    0.329577    0.082958    0.025540    0.719150    
#> 325: 0.409632    1.032732    3.457016    0.329110    0.082926    0.025511    0.719128    
#> 326: 0.409732    1.032600    3.456989    0.328898    0.082997    0.025472    0.719158    
#> 327: 0.409932    1.032584    3.457051    0.328902    0.082855    0.025450    0.719090    
#> 328: 0.409951    1.032607    3.457074    0.328332    0.082811    0.025433    0.719005    
#> 329: 0.409948    1.032664    3.457093    0.327924    0.082821    0.025380    0.719021    
#> 330: 0.409758    1.032690    3.457085    0.327891    0.082852    0.025353    0.718944    
#> 331: 0.409813    1.032777    3.457167    0.327557    0.082781    0.025353    0.718920    
#> 332: 0.409681    1.032771    3.457204    0.327416    0.082700    0.025400    0.719015    
#> 333: 0.409634    1.032788    3.457183    0.327404    0.082566    0.025425    0.718950    
#> 334: 0.409562    1.032553    3.457130    0.327638    0.082438    0.025444    0.718913    
#> 335: 0.409481    1.032469    3.457080    0.327723    0.082295    0.025472    0.718809    
#> 336: 0.409312    1.032635    3.457033    0.327979    0.082192    0.025511    0.718741    
#> 337: 0.409065    1.032913    3.456924    0.328308    0.082161    0.025503    0.718778    
#> 338: 0.408928    1.032980    3.456887    0.328398    0.082146    0.025516    0.718828    
#> 339: 0.408712    1.033119    3.456797    0.328258    0.082057    0.025517    0.718723    
#> 340: 0.408475    1.033038    3.456741    0.328063    0.082070    0.025516    0.718652    
#> 341: 0.408396    1.033008    3.456762    0.328045    0.082080    0.025523    0.718628    
#> 342: 0.408219    1.032896    3.456733    0.328023    0.081988    0.025548    0.718457    
#> 343: 0.408061    1.032910    3.456784    0.327876    0.081922    0.025569    0.718445    
#> 344: 0.408112    1.032944    3.456871    0.327909    0.081878    0.025597    0.718451    
#> 345: 0.408057    1.032780    3.456914    0.327773    0.082004    0.025607    0.718447    
#> 346: 0.408021    1.032708    3.456867    0.327432    0.082057    0.025577    0.718340    
#> 347: 0.408121    1.032692    3.456872    0.327331    0.082171    0.025568    0.718361    
#> 348: 0.407888    1.032810    3.456862    0.327000    0.082185    0.025546    0.718525    
#> 349: 0.407813    1.032730    3.456866    0.327101    0.082190    0.025543    0.718430    
#> 350: 0.407684    1.032586    3.456828    0.327083    0.082247    0.025523    0.718357    
#> 351: 0.407839    1.032750    3.456797    0.327356    0.082310    0.025521    0.718314    
#> 352: 0.407651    1.032844    3.456717    0.327544    0.082375    0.025523    0.718334    
#> 353: 0.407742    1.032981    3.456707    0.327420    0.082425    0.025519    0.718246    
#> 354: 0.407670    1.033144    3.456572    0.327647    0.082434    0.025547    0.718101    
#> 355: 0.407866    1.033226    3.456519    0.327878    0.082386    0.025562    0.718058    
#> 356: 0.407916    1.033107    3.456559    0.327929    0.082354    0.025586    0.717997    
#> 357: 0.408284    1.033125    3.456619    0.328080    0.082312    0.025622    0.717831    
#> 358: 0.408563    1.033145    3.456717    0.328184    0.082247    0.025644    0.717670    
#> 359: 0.408645    1.033323    3.456706    0.328496    0.082327    0.025647    0.717512    
#> 360: 0.408307    1.033460    3.456511    0.328740    0.082420    0.025631    0.717381    
#> 361: 0.407965    1.033541    3.456387    0.328303    0.082487    0.025613    0.717297    
#> 362: 0.407719    1.033589    3.456276    0.327803    0.082545    0.025571    0.717169    
#> 363: 0.407645    1.033638    3.456258    0.327607    0.082554    0.025547    0.716999    
#> 364: 0.407638    1.033568    3.456264    0.327531    0.082508    0.025536    0.717007    
#> 365: 0.407599    1.033547    3.456273    0.327467    0.082543    0.025523    0.716914    
#> 366: 0.407799    1.033517    3.456265    0.327319    0.082557    0.025521    0.716977    
#> 367: 0.407867    1.033663    3.456306    0.327070    0.082553    0.025503    0.717024    
#> 368: 0.407944    1.033757    3.456279    0.326949    0.082628    0.025499    0.717058    
#> 369: 0.407798    1.033775    3.456288    0.326872    0.082655    0.025485    0.717085    
#> 370: 0.407579    1.033797    3.456251    0.326672    0.082779    0.025478    0.717121    
#> 371: 0.407495    1.033740    3.456132    0.326827    0.082747    0.025454    0.717137    
#> 372: 0.407348    1.033736    3.456091    0.326935    0.082811    0.025446    0.717000    
#> 373: 0.407138    1.033794    3.456069    0.326923    0.082853    0.025438    0.716913    
#> 374: 0.407149    1.033870    3.456043    0.326739    0.082866    0.025424    0.716876    
#> 375: 0.407214    1.033928    3.456032    0.326506    0.082875    0.025412    0.716775    
#> 376: 0.407336    1.033993    3.456035    0.326451    0.082975    0.025391    0.716648    
#> 377: 0.407249    1.034049    3.456053    0.326161    0.083040    0.025368    0.716666    
#> 378: 0.407122    1.034020    3.456043    0.325784    0.083056    0.025365    0.716701    
#> 379: 0.406969    1.033876    3.456078    0.325312    0.083067    0.025349    0.716665    
#> 380: 0.406874    1.033840    3.456130    0.325103    0.083121    0.025309    0.716653    
#> 381: 0.406660    1.033737    3.456139    0.324947    0.083104    0.025282    0.716679    
#> 382: 0.406622    1.033680    3.456113    0.324964    0.083106    0.025288    0.716507    
#> 383: 0.406613    1.033689    3.456091    0.324991    0.083197    0.025259    0.716359    
#> 384: 0.406428    1.033730    3.456091    0.324955    0.083284    0.025224    0.716361    
#> 385: 0.406430    1.033720    3.456131    0.324647    0.083399    0.025188    0.716451    
#> 386: 0.406557    1.033854    3.456187    0.324258    0.083593    0.025164    0.716516    
#> 387: 0.406614    1.033981    3.456269    0.324055    0.083684    0.025132    0.716509    
#> 388: 0.406606    1.033917    3.456290    0.324029    0.083727    0.025109    0.716463    
#> 389: 0.406673    1.033690    3.456299    0.323991    0.083679    0.025090    0.716495    
#> 390: 0.406632    1.033740    3.456275    0.324035    0.083697    0.025083    0.716456    
#> 391: 0.406664    1.033794    3.456273    0.323826    0.083698    0.025095    0.716417    
#> 392: 0.406565    1.033828    3.456252    0.323751    0.083736    0.025104    0.716382    
#> 393: 0.406399    1.033766    3.456143    0.323594    0.083708    0.025107    0.716360    
#> 394: 0.406335    1.033896    3.456089    0.323361    0.083756    0.025098    0.716300    
#> 395: 0.406455    1.034025    3.456078    0.323230    0.083881    0.025100    0.716244    
#> 396: 0.406664    1.034046    3.456109    0.323196    0.083922    0.025092    0.716080    
#> 397: 0.406833    1.033964    3.456185    0.323235    0.084021    0.025090    0.716009    
#> 398: 0.407057    1.033886    3.456293    0.323338    0.084016    0.025108    0.715957    
#> 399: 0.407143    1.033849    3.456399    0.323365    0.084056    0.025096    0.715899    
#> 400: 0.407259    1.033770    3.456477    0.323240    0.084028    0.025068    0.715895    
#> 401: 0.407334    1.033831    3.456487    0.322972    0.084107    0.025033    0.715995    
#> 402: 0.407373    1.033988    3.456484    0.322712    0.084178    0.025017    0.716029    
#> 403: 0.407401    1.033981    3.456504    0.322342    0.084202    0.025014    0.716013    
#> 404: 0.407344    1.033922    3.456424    0.321925    0.084212    0.024991    0.716013    
#> 405: 0.407287    1.033943    3.456413    0.321761    0.084221    0.024981    0.716035    
#> 406: 0.407400    1.034023    3.456406    0.321836    0.084338    0.024971    0.716030    
#> 407: 0.407403    1.034142    3.456406    0.321930    0.084387    0.024944    0.716006    
#> 408: 0.407516    1.034187    3.456410    0.321907    0.084336    0.024940    0.716085    
#> 409: 0.407486    1.034128    3.456392    0.321775    0.084248    0.024939    0.716007    
#> 410: 0.407391    1.034262    3.456327    0.321663    0.084275    0.024950    0.715936    
#> 411: 0.407441    1.034146    3.456321    0.321673    0.084260    0.024964    0.715889    
#> 412: 0.407317    1.034247    3.456269    0.321595    0.084177    0.024992    0.715930    
#> 413: 0.407273    1.034325    3.456247    0.321409    0.084161    0.025001    0.715982    
#> 414: 0.407122    1.034309    3.456248    0.321264    0.084150    0.025004    0.715990    
#> 415: 0.407290    1.034225    3.456270    0.321183    0.084184    0.025018    0.715942    
#> 416: 0.407445    1.034244    3.456329    0.321041    0.084188    0.025030    0.715882    
#> 417: 0.407442    1.034229    3.456323    0.321135    0.084146    0.025031    0.715868    
#> 418: 0.407296    1.034315    3.456313    0.321192    0.084161    0.025017    0.715874    
#> 419: 0.407384    1.034390    3.456280    0.321571    0.084134    0.025007    0.715899    
#> 420: 0.407266    1.034434    3.456271    0.321625    0.084113    0.024989    0.715923    
#> 421: 0.407067    1.034463    3.456292    0.321718    0.084119    0.024970    0.715957    
#> 422: 0.407178    1.034462    3.456318    0.321784    0.084144    0.024961    0.715876    
#> 423: 0.407390    1.034428    3.456357    0.321833    0.084167    0.024965    0.715838    
#> 424: 0.407332    1.034421    3.456296    0.322111    0.084265    0.024951    0.715832    
#> 425: 0.407469    1.034444    3.456267    0.322173    0.084327    0.024928    0.715952    
#> 426: 0.407448    1.034524    3.456228    0.322101    0.084328    0.024904    0.715900    
#> 427: 0.407296    1.034529    3.456224    0.321857    0.084254    0.024881    0.715860    
#> 428: 0.407012    1.034593    3.456222    0.321572    0.084228    0.024865    0.715926    
#> 429: 0.406998    1.034640    3.456227    0.321322    0.084252    0.024846    0.715951    
#> 430: 0.407133    1.034648    3.456247    0.321311    0.084251    0.024844    0.715919    
#> 431: 0.407196    1.034535    3.456263    0.321151    0.084227    0.024843    0.715819    
#> 432: 0.407278    1.034511    3.456336    0.320991    0.084223    0.024847    0.715732    
#> 433: 0.407452    1.034521    3.456414    0.320996    0.084241    0.024847    0.715660    
#> 434: 0.407443    1.034390    3.456456    0.320964    0.084206    0.024843    0.715616    
#> 435: 0.407530    1.034298    3.456458    0.320998    0.084165    0.024844    0.715524    
#> 436: 0.407603    1.034211    3.456561    0.320808    0.084156    0.024840    0.715496    
#> 437: 0.407792    1.034094    3.456656    0.320764    0.084191    0.024846    0.715403    
#> 438: 0.408009    1.034108    3.456711    0.320667    0.084139    0.024856    0.715356    
#> 439: 0.408158    1.034124    3.456801    0.320888    0.084106    0.024869    0.715320    
#> 440: 0.408223    1.034086    3.456875    0.320814    0.084103    0.024871    0.715267    
#> 441: 0.408271    1.034026    3.456920    0.320663    0.084122    0.024871    0.715192    
#> 442: 0.408147    1.034087    3.456979    0.320585    0.084153    0.024876    0.715132    
#> 443: 0.408269    1.034142    3.456982    0.320541    0.084049    0.024901    0.715088    
#> 444: 0.408157    1.034211    3.456889    0.320651    0.083989    0.024924    0.715026    
#> 445: 0.408072    1.034278    3.456848    0.320840    0.083937    0.024939    0.714968    
#> 446: 0.407873    1.034363    3.456789    0.320880    0.083869    0.024955    0.714909    
#> 447: 0.407904    1.034390    3.456800    0.320760    0.083784    0.024994    0.714912    
#> 448: 0.407937    1.034368    3.456827    0.320733    0.083761    0.025026    0.714832    
#> 449: 0.408076    1.034377    3.456939    0.320670    0.083781    0.025047    0.714832    
#> 450: 0.408160    1.034323    3.456977    0.320488    0.083805    0.025065    0.714800    
#> 451: 0.408297    1.034292    3.456994    0.320527    0.083838    0.025075    0.714752    
#> 452: 0.408355    1.034317    3.457016    0.320604    0.083860    0.025074    0.714731    
#> 453: 0.408284    1.034327    3.457011    0.320624    0.083888    0.025061    0.714652    
#> 454: 0.408254    1.034458    3.456982    0.320465    0.083944    0.025068    0.714582    
#> 455: 0.408267    1.034609    3.456943    0.320344    0.083904    0.025079    0.714528    
#> 456: 0.408154    1.034624    3.456932    0.320291    0.083930    0.025081    0.714486    
#> 457: 0.408117    1.034636    3.456944    0.320147    0.083933    0.025076    0.714428    
#> 458: 0.408097    1.034743    3.456963    0.319985    0.083917    0.025078    0.714371    
#> 459: 0.407987    1.034832    3.456963    0.319774    0.083885    0.025080    0.714332    
#> 460: 0.407912    1.034887    3.456914    0.319723    0.083906    0.025084    0.714290    
#> 461: 0.407860    1.034927    3.456945    0.319583    0.083914    0.025113    0.714309    
#> 462: 0.407748    1.034983    3.456982    0.319473    0.083875    0.025137    0.714296    
#> 463: 0.407768    1.034962    3.457034    0.319480    0.083841    0.025158    0.714320    
#> 464: 0.407912    1.034974    3.457050    0.319358    0.083786    0.025169    0.714325    
#> 465: 0.408048    1.034798    3.457082    0.319239    0.083744    0.025156    0.714340    
#> 466: 0.408085    1.034764    3.457087    0.319146    0.083731    0.025151    0.714305    
#> 467: 0.408105    1.034757    3.457145    0.318986    0.083722    0.025163    0.714204    
#> 468: 0.408349    1.034723    3.457244    0.318965    0.083718    0.025179    0.714255    
#> 469: 0.408325    1.034781    3.457295    0.318809    0.083753    0.025200    0.714282    
#> 470: 0.408233    1.034869    3.457249    0.318859    0.083772    0.025228    0.714240    
#> 471: 0.408068    1.034947    3.457194    0.318764    0.083744    0.025230    0.714220    
#> 472: 0.407937    1.034968    3.457171    0.318567    0.083746    0.025232    0.714192    
#> 473: 0.407907    1.035032    3.457164    0.318403    0.083759    0.025249    0.714157    
#> 474: 0.407860    1.035030    3.457166    0.318397    0.083779    0.025252    0.714203    
#> 475: 0.407945    1.035116    3.457188    0.318398    0.083788    0.025252    0.714180    
#> 476: 0.408034    1.035087    3.457201    0.318598    0.083754    0.025271    0.714238    
#> 477: 0.408031    1.035158    3.457266    0.318425    0.083717    0.025282    0.714214    
#> 478: 0.407979    1.035224    3.457291    0.318231    0.083702    0.025284    0.714237    
#> 479: 0.408043    1.035296    3.457332    0.318148    0.083680    0.025281    0.714234    
#> 480: 0.408172    1.035320    3.457347    0.318068    0.083656    0.025295    0.714307    
#> 481: 0.408182    1.035358    3.457324    0.318045    0.083663    0.025308    0.714330    
#> 482: 0.408239    1.035366    3.457264    0.317987    0.083658    0.025316    0.714373    
#> 483: 0.408066    1.035339    3.457218    0.317893    0.083651    0.025309    0.714402    
#> 484: 0.407993    1.035277    3.457227    0.317905    0.083652    0.025312    0.714432    
#> 485: 0.408025    1.035299    3.457208    0.317856    0.083667    0.025309    0.714438    
#> 486: 0.408024    1.035313    3.457242    0.318014    0.083619    0.025325    0.714386    
#> 487: 0.408276    1.035280    3.457337    0.318168    0.083556    0.025348    0.714403    
#> 488: 0.408245    1.035323    3.457342    0.317994    0.083528    0.025354    0.714397    
#> 489: 0.408384    1.035285    3.457338    0.318187    0.083535    0.025348    0.714395    
#> 490: 0.408469    1.035266    3.457363    0.318340    0.083504    0.025331    0.714394    
#> 491: 0.408609    1.035297    3.457409    0.318467    0.083501    0.025325    0.714358    
#> 492: 0.408617    1.035340    3.457400    0.318625    0.083518    0.025308    0.714426    
#> 493: 0.408595    1.035398    3.457401    0.318489    0.083572    0.025305    0.714399    
#> 494: 0.408631    1.035450    3.457383    0.318397    0.083625    0.025301    0.714332    
#> 495: 0.408617    1.035477    3.457354    0.318451    0.083631    0.025302    0.714248    
#> 496: 0.408661    1.035522    3.457315    0.318395    0.083626    0.025303    0.714217    
#> 497: 0.408455    1.035495    3.457266    0.318276    0.083676    0.025298    0.714241    
#> 498: 0.408288    1.035533    3.457194    0.318254    0.083739    0.025285    0.714186    
#> 499: 0.408201    1.035591    3.457140    0.318189    0.083764    0.025265    0.714136    
#> 500: 0.408123    1.035600    3.457087    0.318084    0.083741    0.025248    0.714097    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.258448    0.978938    3.440723    0.392401    0.074088    0.016800    1.579766    
#> 002: 0.116808    0.967195    3.465233    0.372781    0.070383    0.015960    1.053651    
#> 003: 0.176888    0.932066    3.468136    0.354142    0.066864    0.016832    0.854790    
#> 004: 0.115193    0.941329    3.459692    0.336435    0.076833    0.015990    0.808408    
#> 005: 0.155950    0.952480    3.453119    0.319613    0.097174    0.015191    0.743748    
#> 006: 0.085894    0.961790    3.445890    0.303633    0.097206    0.014431    0.713035    
#> 007: 0.074674    0.973099    3.434905    0.288451    0.112600    0.016466    0.700261    
#> 008: 0.060360    0.960251    3.426370    0.274029    0.116103    0.016897    0.694711    
#> 009: 0.022735    0.969911    3.411458    0.260327    0.110298    0.016807    0.709325    
#> 010: 0.011015    0.973870    3.410065    0.247311    0.104783    0.015967    0.719575    
#> 011: 0.093010    0.984489    3.427631    0.234945    0.099544    0.016212    0.736722    
#> 012: 0.065070    0.993858    3.402663    0.223198    0.098724    0.015402    0.711056    
#> 013: 0.002815    0.993500    3.395098    0.212038    0.094550    0.016793    0.705483    
#> 014: 0.015158    0.983605    3.400996    0.201436    0.089822    0.021740    0.722785    
#> 015: 0.032595    0.995749    3.415479    0.191364    0.085331    0.020653    0.700754    
#> 016: 0.041282    0.998947    3.426517    0.181796    0.087667    0.024025    0.708145    
#> 017: 0.058557    1.005927    3.430600    0.172706    0.083284    0.025625    0.696184    
#> 018: 0.057810    0.993812    3.408532    0.164071    0.085124    0.024343    0.728389    
#> 019: 0.010485    0.989339    3.403891    0.155867    0.089058    0.023126    0.730503    
#> 020: 0.032184    0.988587    3.418260    0.148074    0.084605    0.024515    0.721515    
#> 021: 0.055511    0.987993    3.426683    0.140670    0.084049    0.023289    0.694117    
#> 022: 0.051528    0.997745    3.426219    0.133637    0.087385    0.022125    0.712882    
#> 023: 0.128145    0.985021    3.428937    0.156813    0.083016    0.021018    0.726318    
#> 024: 0.126038    0.988832    3.441845    0.148973    0.085713    0.019968    0.719777    
#> 025: 0.122943    0.977792    3.440560    0.169848    0.082576    0.018969    0.698200    
#> 026: 0.099295    1.011930    3.433329    0.161356    0.078448    0.018021    0.709671    
#> 027: 0.065802    1.024700    3.425305    0.170900    0.090280    0.017120    0.724334    
#> 028: 0.097444    0.989524    3.440021    0.162355    0.092153    0.016264    0.713211    
#> 029: 0.113369    0.975440    3.431958    0.175576    0.091776    0.015451    0.734476    
#> 030: 0.116854    0.991736    3.436471    0.166797    0.091762    0.016668    0.711814    
#> 031: 0.067824    0.976963    3.431884    0.158458    0.104843    0.015834    0.707969    
#> 032: 0.055403    0.976383    3.426031    0.150535    0.101292    0.015043    0.707908    
#> 033: 0.059298    0.968887    3.425365    0.143008    0.096227    0.014291    0.727816    
#> 034: 0.066235    1.005214    3.420364    0.141861    0.091416    0.013591    0.720236    
#> 035: 0.027940    0.995697    3.409155    0.150788    0.090368    0.012912    0.709566    
#> 036: 0.041247    1.007483    3.411264    0.177518    0.086093    0.012266    0.719727    
#> 037: 0.029290    1.004577    3.407352    0.176645    0.087344    0.011653    0.718363    
#> 038: 0.072229    1.015261    3.402298    0.175428    0.097504    0.011884    0.707824    
#> 039: 0.074690    1.002451    3.411125    0.166657    0.092629    0.013818    0.694876    
#> 040: 0.022703    1.030462    3.413731    0.158324    0.087998    0.014630    0.709674    
#> 041: 0.020465    1.012218    3.399705    0.159998    0.090204    0.016174    0.687301    
#> 042: 0.062786    0.998134    3.407221    0.181857    0.085693    0.015702    0.684147    
#> 043: 0.006550    1.024014    3.388314    0.198402    0.087987    0.014917    0.702416    
#> 044: -0.009046   1.027735    3.385499    0.188482    0.098931    0.015423    0.698215    
#> 045: -0.012767   1.047749    3.373616    0.184956    0.093984    0.014652    0.721065    
#> 046: 0.029378    1.038109    3.382736    0.175708    0.089285    0.014910    0.709158    
#> 047: 0.025929    1.038561    3.383934    0.166922    0.084821    0.016242    0.720283    
#> 048: 0.010869    1.029288    3.387926    0.158576    0.084988    0.018067    0.723262    
#> 049: 0.009086    1.024194    3.398217    0.154736    0.090575    0.017164    0.728212    
#> 050: 0.077024    0.986488    3.411041    0.155541    0.091308    0.018401    0.746882    
#> 051: 0.057350    1.000116    3.408875    0.147764    0.089640    0.019349    0.734786    
#> 052: 0.055865    1.004661    3.419897    0.149767    0.085158    0.018758    0.709542    
#> 053: 0.091300    0.996191    3.431491    0.142278    0.103142    0.023006    0.723048    
#> 054: 0.020160    0.999668    3.428061    0.135164    0.115205    0.024637    0.751945    
#> 055: 0.040490    0.997416    3.414167    0.132385    0.119106    0.023405    0.730536    
#> 056: 0.055611    0.988917    3.421839    0.126875    0.113150    0.022235    0.738668    
#> 057: 0.047517    0.977297    3.437129    0.120564    0.107493    0.021123    0.739378    
#> 058: 0.065712    0.973439    3.418940    0.136150    0.102325    0.020067    0.709476    
#> 059: 0.098957    0.937712    3.434372    0.142921    0.097209    0.023267    0.724303    
#> 060: 0.089407    0.940011    3.447198    0.135775    0.092349    0.026662    0.733082    
#> 061: 0.121416    0.950319    3.457778    0.149825    0.087731    0.029748    0.736177    
#> 062: 0.131742    0.960175    3.464059    0.142334    0.087335    0.028261    0.736862    
#> 063: 0.153769    0.931550    3.461677    0.142747    0.083162    0.026848    0.735159    
#> 064: 0.146568    0.939113    3.472084    0.135609    0.079004    0.025505    0.738996    
#> 065: 0.151373    0.946635    3.456237    0.128829    0.082153    0.024230    0.725062    
#> 066: 0.147873    0.971662    3.455656    0.156527    0.093330    0.023019    0.722584    
#> 067: 0.106265    0.956150    3.446801    0.148701    0.088663    0.025124    0.709400    
#> 068: 0.077315    0.957418    3.440154    0.152159    0.084230    0.023868    0.741056    
#> 069: 0.064819    0.995234    3.419987    0.171381    0.080019    0.022675    0.723957    
#> 070: 0.090062    0.982855    3.430894    0.162812    0.087264    0.021541    0.715696    
#> 071: 0.081261    1.009961    3.417053    0.154672    0.084706    0.020464    0.757157    
#> 072: 0.025489    0.950849    3.419759    0.178983    0.080470    0.025609    0.744242    
#> 073: 0.063523    0.988692    3.435365    0.171428    0.076447    0.024328    0.735503    
#> 074: 0.040166    0.975343    3.411264    0.182400    0.085082    0.026977    0.723179    
#> 075: 0.070562    0.963431    3.443830    0.181292    0.099060    0.025628    0.712577    
#> 076: 0.065613    0.989740    3.438322    0.172228    0.094107    0.024347    0.713214    
#> 077: 0.112171    0.963326    3.441081    0.163616    0.089401    0.023130    0.716579    
#> 078: 0.124739    0.967572    3.447225    0.155435    0.084931    0.022776    0.708494    
#> 079: 0.133890    0.969524    3.451680    0.165012    0.080685    0.028936    0.732782    
#> 080: 0.105626    0.965916    3.455965    0.187260    0.076650    0.027489    0.736862    
#> 081: 0.054966    0.991855    3.419147    0.177897    0.072818    0.026115    0.712563    
#> 082: 0.037118    0.977386    3.417697    0.169002    0.074773    0.025330    0.729036    
#> 083: 0.041254    1.001103    3.414464    0.160882    0.072386    0.026334    0.709675    
#> 084: 0.048088    1.019242    3.410807    0.152838    0.075267    0.026243    0.718331    
#> 085: 0.034804    1.023760    3.420306    0.145196    0.079401    0.024930    0.731894    
#> 086: 0.032712    1.019691    3.410510    0.155983    0.077833    0.023851    0.701641    
#> 087: 0.016152    1.005909    3.406297    0.148184    0.073942    0.022659    0.717631    
#> 088: -0.037388   1.018688    3.398404    0.149792    0.084229    0.021526    0.735805    
#> 089: 0.007232    1.025272    3.388271    0.142302    0.080018    0.020449    0.717388    
#> 090: -0.022636   1.018392    3.390229    0.135187    0.090897    0.019427    0.711274    
#> 091: -0.007776   1.017814    3.384901    0.142106    0.087270    0.018456    0.717164    
#> 092: -0.021946   1.036580    3.380344    0.135001    0.092225    0.017533    0.732502    
#> 093: -0.047537   1.017100    3.377794    0.128251    0.107265    0.016656    0.742829    
#> 094: -0.042151   1.031279    3.384969    0.121838    0.101902    0.015823    0.761017    
#> 095: -0.028111   1.043926    3.388110    0.115746    0.099274    0.015032    0.760405    
#> 096: -0.019824   1.029045    3.385300    0.109959    0.108619    0.014281    0.742108    
#> 097: 0.008577    1.041237    3.388605    0.106405    0.107747    0.013567    0.732079    
#> 098: -0.017277   1.046919    3.395028    0.101794    0.102360    0.012888    0.740313    
#> 099: -0.017813   1.024354    3.378161    0.126682    0.103941    0.012244    0.723834    
#> 100: -0.008085   1.031479    3.384165    0.138192    0.101980    0.015117    0.708739    
#> 101: -0.054454   1.009509    3.366961    0.137629    0.096881    0.014377    0.722304    
#> 102: -0.043031   1.045778    3.363110    0.139814    0.096184    0.014502    0.721298    
#> 103: -0.003647   1.034699    3.378190    0.164041    0.093136    0.015273    0.702275    
#> 104: -0.015129   1.025341    3.386706    0.199107    0.097199    0.014510    0.712409    
#> 105: 0.012102    1.031561    3.381032    0.189152    0.092339    0.013784    0.707162    
#> 106: 0.023069    1.021563    3.390107    0.181646    0.089200    0.013095    0.702926    
#> 107: 0.025496    1.047737    3.383429    0.174116    0.085540    0.012440    0.724455    
#> 108: 0.003097    1.025777    3.381038    0.165411    0.101332    0.011818    0.732886    
#> 109: -0.032031   1.022237    3.388186    0.182570    0.098462    0.011227    0.730980    
#> 110: -0.004025   1.018691    3.377210    0.173441    0.093539    0.012712    0.718228    
#> 111: -0.018000   1.023400    3.384568    0.165391    0.088862    0.012076    0.715811    
#> 112: 0.013585    1.012300    3.386021    0.169227    0.084419    0.011725    0.738728    
#> 113: 0.010115    1.037219    3.388083    0.160806    0.094442    0.011138    0.731565    
#> 114: 0.008525    1.034648    3.388484    0.171559    0.096076    0.010581    0.739372    
#> 115: 0.025194    0.996070    3.388385    0.180482    0.091272    0.012008    0.738448    
#> 116: 0.002231    1.013069    3.381128    0.171458    0.105196    0.011408    0.725588    
#> 117: -0.004374   1.030177    3.397574    0.162885    0.099936    0.010837    0.728540    
#> 118: 0.036158    1.017421    3.400689    0.157739    0.094939    0.010664    0.721606    
#> 119: 0.024724    1.024991    3.406781    0.152294    0.090192    0.012964    0.728509    
#> 120: 0.031019    0.992969    3.409574    0.148285    0.085683    0.017276    0.705563    
#> 121: 0.024489    1.022610    3.401819    0.159212    0.081398    0.019088    0.694564    
#> 122: 0.013681    1.020498    3.394318    0.154447    0.081726    0.018134    0.699300    
#> 123: 0.068580    1.037911    3.396476    0.146725    0.095165    0.017227    0.726030    
#> 124: 0.048084    1.032836    3.404739    0.145706    0.090407    0.018647    0.731064    
#> 125: 0.079376    1.017622    3.410300    0.157694    0.091892    0.017715    0.713515    
#> 126: 0.050967    1.017084    3.407665    0.153785    0.088013    0.024882    0.709430    
#> 127: 0.075078    1.006417    3.401655    0.199485    0.087305    0.023638    0.726462    
#> 128: 0.030857    1.006186    3.416219    0.189511    0.082939    0.027313    0.723823    
#> 129: 0.045905    1.013543    3.420120    0.180035    0.078792    0.025947    0.717652    
#> 130: 0.081711    1.012440    3.418616    0.171034    0.074853    0.029975    0.703299    
#> 131: 0.071496    1.001097    3.405732    0.162482    0.071110    0.028477    0.727069    
#> 132: 0.041133    0.999268    3.402434    0.158785    0.071636    0.027053    0.716543    
#> 133: 0.030410    0.988453    3.413067    0.168965    0.068055    0.025700    0.719668    
#> 134: 0.068342    0.967965    3.431851    0.179799    0.069103    0.024415    0.722983    
#> 135: 0.042972    0.976991    3.414032    0.170809    0.068809    0.023194    0.720913    
#> 136: 0.061311    0.981356    3.419322    0.164192    0.069258    0.022061    0.703667    
#> 137: 0.090774    0.975937    3.432803    0.174174    0.071787    0.020958    0.720225    
#> 138: 0.071770    0.993698    3.421745    0.200355    0.077295    0.023396    0.697698    
#> 139: 0.051545    1.022763    3.418308    0.190337    0.076945    0.026617    0.695465    
#> 140: 0.044974    1.015654    3.409836    0.188996    0.073298    0.025338    0.718103    
#> 141: 0.018716    1.002573    3.401413    0.197823    0.069633    0.024071    0.710771    
#> 142: 0.047437    0.988151    3.420146    0.187932    0.066152    0.022867    0.731538    
#> 143: 0.043546    1.009735    3.429084    0.178535    0.074388    0.024000    0.745877    
#> 144: 0.081603    1.012756    3.434107    0.173476    0.079998    0.022800    0.720519    
#> 145: 0.067556    1.018713    3.414605    0.164802    0.082731    0.021660    0.715987    
#> 146: 0.044022    0.994796    3.424263    0.156562    0.078595    0.020577    0.715393    
#> 147: 0.006339    0.985933    3.402928    0.148734    0.076217    0.019548    0.712273    
#> 148: 0.039990    0.998301    3.421550    0.145499    0.085739    0.018570    0.707381    
#> 149: 0.030105    0.973655    3.413216    0.164009    0.098818    0.017642    0.729148    
#> 150: 0.069258    0.985502    3.401894    0.155808    0.112971    0.016760    0.741144    
#> 151: 0.006355    1.020446    3.404638    0.169867    0.107322    0.015922    0.731740    
#> 152: 0.002579    0.999421    3.414041    0.155768    0.080103    0.016822    0.731825    
#> 153: 0.028233    1.014173    3.423592    0.137443    0.105240    0.018813    0.735143    
#> 154: 0.069889    1.006051    3.425262    0.120913    0.096814    0.020889    0.737175    
#> 155: 0.041314    0.984189    3.410747    0.094791    0.090999    0.015691    0.734636    
#> 156: 0.027434    1.004178    3.415647    0.120980    0.090429    0.015875    0.733022    
#> 157: 0.029839    1.002331    3.411798    0.139497    0.093612    0.013145    0.713385    
#> 158: 0.056478    1.016915    3.417395    0.119740    0.099594    0.015924    0.717062    
#> 159: 0.024328    1.023905    3.418611    0.127272    0.106951    0.013276    0.720895    
#> 160: 0.043442    0.989087    3.414673    0.128004    0.112376    0.013900    0.731107    
#> 161: 0.019025    0.998247    3.417220    0.125060    0.088165    0.015899    0.720861    
#> 162: 0.021913    1.026854    3.395251    0.117434    0.088937    0.017973    0.723570    
#> 163: 0.048298    0.989599    3.404413    0.159603    0.071563    0.020806    0.721067    
#> 164: 0.073452    0.993392    3.410873    0.158697    0.074209    0.026559    0.727674    
#> 165: 0.080004    0.988435    3.426854    0.131003    0.083050    0.022808    0.708073    
#> 166: 0.110912    1.007759    3.434157    0.155136    0.075294    0.018750    0.716179    
#> 167: 0.113499    1.019380    3.429179    0.158277    0.087943    0.016154    0.728634    
#> 168: 0.067254    1.014607    3.421034    0.183223    0.098520    0.014244    0.702733    
#> 169: 0.061475    1.045561    3.410612    0.174133    0.103411    0.013946    0.723769    
#> 170: 0.052940    1.017728    3.409290    0.171423    0.086579    0.013712    0.701333    
#> 171: 0.006750    1.012883    3.402431    0.152602    0.090624    0.011885    0.690892    
#> 172: 0.008226    1.026289    3.399679    0.132405    0.098813    0.011518    0.702172    
#> 173: 0.033041    1.020867    3.390216    0.159290    0.077019    0.015308    0.702326    
#> 174: 0.027001    1.007983    3.397758    0.189900    0.096386    0.017234    0.686356    
#> 175: -0.000260   1.024344    3.379748    0.167827    0.094145    0.018292    0.705168    
#> 176: -0.000261   1.040040    3.386361    0.187594    0.087823    0.016700    0.689142    
#> 177: 0.034258    1.019207    3.404906    0.166729    0.092165    0.019529    0.700098    
#> 178: 0.057959    1.011013    3.415925    0.162249    0.083917    0.018976    0.704448    
#> 179: 0.091995    1.016150    3.421452    0.138868    0.088762    0.016519    0.711633    
#> 180: 0.055901    1.001502    3.411350    0.169868    0.083787    0.015345    0.730279    
#> 181: 0.087622    0.990709    3.414105    0.143359    0.084053    0.015746    0.727279    
#> 182: 0.040825    1.001713    3.398612    0.156301    0.084241    0.015095    0.724455    
#> 183: 0.031844    1.013149    3.405381    0.164510    0.099428    0.017183    0.705020    
#> 184: 0.033536    1.006311    3.415770    0.149729    0.088556    0.016130    0.706664    
#> 185: 0.039555    0.991637    3.416608    0.156652    0.086240    0.015859    0.695971    
#> 186: 0.065361    1.001560    3.426895    0.147417    0.096242    0.020151    0.706686    
#> 187: 0.058803    1.003082    3.427543    0.159974    0.091475    0.026522    0.697584    
#> 188: 0.054693    1.022262    3.417834    0.140251    0.093077    0.021790    0.703270    
#> 189: 0.064489    1.024731    3.428001    0.126739    0.078848    0.024339    0.718008    
#> 190: 0.047615    1.007332    3.430733    0.151609    0.073177    0.021941    0.702720    
#> 191: 0.041864    1.002464    3.419680    0.144005    0.060971    0.021087    0.697076    
#> 192: 0.037927    1.007751    3.418332    0.154552    0.081174    0.017498    0.695637    
#> 193: 0.064174    1.004618    3.424031    0.154327    0.068225    0.016537    0.695122    
#> 194: 0.055851    1.014018    3.405460    0.159741    0.072424    0.017058    0.705343    
#> 195: 0.033417    0.992856    3.409286    0.145766    0.069703    0.015934    0.706682    
#> 196: 0.036548    0.996564    3.424534    0.147175    0.081658    0.018067    0.715799    
#> 197: 0.020863    0.992009    3.437557    0.135729    0.078247    0.020541    0.730582    
#> 198: 0.085683    0.981871    3.415739    0.108639    0.080165    0.019022    0.711316    
#> 199: 0.060723    0.986625    3.421557    0.120545    0.086002    0.014910    0.710192    
#> 200: 0.061667    0.996580    3.420317    0.149044    0.094782    0.013778    0.720643    
#> 201: 0.066629    0.990139    3.425805    0.160978    0.087313    0.015212    0.719145    
#> 202: 0.072181    0.989484    3.427008    0.161869    0.086801    0.015777    0.717973    
#> 203: 0.078728    0.989403    3.426888    0.155109    0.085959    0.016077    0.716167    
#> 204: 0.078721    0.985742    3.427198    0.151872    0.087009    0.015992    0.719343    
#> 205: 0.076661    0.988681    3.428290    0.149893    0.085984    0.016711    0.722472    
#> 206: 0.075525    0.993779    3.427914    0.151482    0.086809    0.016843    0.726858    
#> 207: 0.069724    0.995048    3.425030    0.156591    0.088891    0.016287    0.727037    
#> 208: 0.065399    0.996256    3.422825    0.160287    0.088529    0.015831    0.726562    
#> 209: 0.064920    0.994034    3.421350    0.159672    0.088464    0.015662    0.725642    
#> 210: 0.064676    0.992775    3.420656    0.158297    0.088558    0.015747    0.723173    
#> 211: 0.062088    0.995290    3.419451    0.156390    0.089589    0.015780    0.721204    
#> 212: 0.060455    0.996608    3.418799    0.154764    0.089978    0.016048    0.720603    
#> 213: 0.059989    0.995721    3.418896    0.153919    0.089403    0.016385    0.721712    
#> 214: 0.061459    0.995664    3.418979    0.153693    0.089038    0.016651    0.721617    
#> 215: 0.061337    0.996287    3.418995    0.154085    0.088621    0.016819    0.720526    
#> 216: 0.062342    0.996312    3.418716    0.152337    0.089066    0.016895    0.720028    
#> 217: 0.062654    0.997344    3.418505    0.150396    0.088982    0.016902    0.718784    
#> 218: 0.062290    0.997952    3.418276    0.148760    0.089341    0.016951    0.716856    
#> 219: 0.061284    0.997629    3.416884    0.148164    0.088889    0.016822    0.716502    
#> 220: 0.059664    0.998374    3.416444    0.149271    0.087983    0.016665    0.716855    
#> 221: 0.058085    0.999441    3.415681    0.150323    0.087703    0.016736    0.716539    
#> 222: 0.057621    1.000689    3.415094    0.150984    0.088145    0.016874    0.716196    
#> 223: 0.057947    1.001406    3.415098    0.151268    0.087926    0.016982    0.715537    
#> 224: 0.059064    1.002569    3.415245    0.151990    0.087838    0.017063    0.715581    
#> 225: 0.059620    1.001122    3.416217    0.153236    0.087433    0.017244    0.715553    
#> 226: 0.060665    0.999757    3.416184    0.153303    0.087263    0.017251    0.716130    
#> 227: 0.059829    0.999799    3.415978    0.153985    0.087917    0.017160    0.716756    
#> 228: 0.060045    1.000670    3.415605    0.153733    0.087929    0.017081    0.716891    
#> 229: 0.059326    1.000579    3.415061    0.153278    0.087942    0.017090    0.716512    
#> 230: 0.058755    0.999834    3.414984    0.152412    0.087506    0.017005    0.716212    
#> 231: 0.058891    1.000018    3.415486    0.151555    0.086908    0.016947    0.716352    
#> 232: 0.059184    0.999299    3.415951    0.150660    0.086527    0.016872    0.716199    
#> 233: 0.059398    0.998015    3.416602    0.149674    0.086649    0.016913    0.716468    
#> 234: 0.059968    0.997519    3.417175    0.149074    0.086722    0.016876    0.716184    
#> 235: 0.060251    0.996543    3.417421    0.148440    0.086577    0.016869    0.716149    
#> 236: 0.060994    0.995996    3.417666    0.148768    0.086492    0.017021    0.716836    
#> 237: 0.062712    0.995181    3.418259    0.148927    0.086568    0.017182    0.717664    
#> 238: 0.063205    0.994809    3.418214    0.148772    0.086722    0.017176    0.718336    
#> 239: 0.063212    0.995244    3.418226    0.148476    0.087060    0.017358    0.718093    
#> 240: 0.063451    0.994970    3.418267    0.148105    0.087028    0.017417    0.717614    
#> 241: 0.063307    0.994158    3.418450    0.147669    0.087223    0.017400    0.717487    
#> 242: 0.063109    0.993893    3.418359    0.147635    0.087461    0.017385    0.717809    
#> 243: 0.063290    0.994305    3.418592    0.147257    0.087632    0.017330    0.718071    
#> 244: 0.063517    0.994175    3.419049    0.147291    0.087618    0.017268    0.718686    
#> 245: 0.063460    0.993363    3.419318    0.146914    0.087805    0.017182    0.719392    
#> 246: 0.063959    0.992739    3.419790    0.146358    0.087569    0.017191    0.719594    
#> 247: 0.064267    0.992400    3.420283    0.145411    0.087842    0.017156    0.719355    
#> 248: 0.064076    0.992769    3.420222    0.145097    0.088074    0.017079    0.718955    
#> 249: 0.063930    0.992785    3.420368    0.144745    0.088297    0.017029    0.718663    
#> 250: 0.064630    0.992892    3.420618    0.144605    0.088737    0.016968    0.718646    
#> 251: 0.065344    0.993133    3.421021    0.144403    0.088958    0.016913    0.719092    
#> 252: 0.066250    0.993279    3.421408    0.144329    0.089198    0.016929    0.718854    
#> 253: 0.066512    0.993492    3.421448    0.144479    0.089456    0.016930    0.718650    
#> 254: 0.066462    0.993865    3.421684    0.144632    0.089550    0.016900    0.718578    
#> 255: 0.066448    0.994289    3.421810    0.144762    0.089636    0.016892    0.718272    
#> 256: 0.066439    0.994311    3.421654    0.144641    0.089733    0.016886    0.718247    
#> 257: 0.065836    0.994051    3.421485    0.144598    0.089648    0.016887    0.718294    
#> 258: 0.065171    0.993975    3.421307    0.144434    0.089596    0.016905    0.718187    
#> 259: 0.064669    0.994043    3.421134    0.144689    0.089536    0.016906    0.718087    
#> 260: 0.064389    0.994355    3.420909    0.145306    0.089441    0.016892    0.717560    
#> 261: 0.064071    0.994623    3.420878    0.146228    0.089406    0.016891    0.717328    
#> 262: 0.064144    0.994855    3.420874    0.146572    0.089167    0.016920    0.717320    
#> 263: 0.063494    0.995598    3.420582    0.146812    0.089415    0.016919    0.717285    
#> 264: 0.062799    0.996057    3.420303    0.146687    0.089795    0.016878    0.717173    
#> 265: 0.062521    0.996312    3.420173    0.146676    0.090194    0.016885    0.717130    
#> 266: 0.062245    0.996505    3.420098    0.146630    0.090111    0.016955    0.717134    
#> 267: 0.062529    0.996576    3.420151    0.146696    0.090126    0.017017    0.717113    
#> 268: 0.062432    0.996503    3.419996    0.146679    0.090096    0.017008    0.717074    
#> 269: 0.062894    0.996345    3.419973    0.146701    0.090059    0.017011    0.717129    
#> 270: 0.062820    0.996420    3.419771    0.146608    0.090037    0.016960    0.717007    
#> 271: 0.062861    0.996464    3.419720    0.146677    0.089959    0.016955    0.717206    
#> 272: 0.062574    0.996345    3.419586    0.146860    0.089767    0.016958    0.717589    
#> 273: 0.062241    0.996833    3.419498    0.147185    0.089761    0.016946    0.717847    
#> 274: 0.061621    0.997035    3.419308    0.147670    0.089608    0.016931    0.717934    
#> 275: 0.061195    0.997211    3.419074    0.147595    0.089506    0.016911    0.717899    
#> 276: 0.060579    0.997395    3.418985    0.148245    0.089322    0.016914    0.717708    
#> 277: 0.060139    0.997726    3.418960    0.148253    0.089248    0.016881    0.717689    
#> 278: 0.059772    0.997828    3.418975    0.148321    0.089375    0.016843    0.717493    
#> 279: 0.059527    0.997718    3.418954    0.148427    0.089441    0.016842    0.717517    
#> 280: 0.059494    0.997733    3.418942    0.148574    0.089416    0.016878    0.717153    
#> 281: 0.059140    0.997921    3.418923    0.148633    0.089335    0.016905    0.716943    
#> 282: 0.059176    0.998181    3.418956    0.148798    0.089214    0.016955    0.717092    
#> 283: 0.059634    0.998277    3.419035    0.148956    0.088947    0.017004    0.717479    
#> 284: 0.059639    0.998115    3.419001    0.148693    0.088754    0.017024    0.717491    
#> 285: 0.059684    0.998164    3.418877    0.148445    0.088723    0.017041    0.717680    
#> 286: 0.059687    0.998355    3.418717    0.148211    0.088591    0.017039    0.717693    
#> 287: 0.059385    0.998597    3.418586    0.147948    0.088498    0.017036    0.717830    
#> 288: 0.059433    0.998485    3.418588    0.148161    0.088668    0.017016    0.717903    
#> 289: 0.059573    0.998376    3.418568    0.148210    0.088757    0.017003    0.717958    
#> 290: 0.059506    0.998449    3.418561    0.148076    0.088751    0.016969    0.718275    
#> 291: 0.059805    0.998723    3.418712    0.147931    0.088681    0.016997    0.718254    
#> 292: 0.059740    0.998805    3.418668    0.147960    0.088573    0.017022    0.718221    
#> 293: 0.059603    0.998885    3.418554    0.147885    0.088605    0.017032    0.717985    
#> 294: 0.059217    0.998926    3.418459    0.147713    0.088572    0.017002    0.717814    
#> 295: 0.059040    0.998818    3.418365    0.147532    0.088458    0.016988    0.717733    
#> 296: 0.058833    0.998870    3.418271    0.147826    0.088266    0.017035    0.717614    
#> 297: 0.059030    0.999025    3.418199    0.147871    0.088027    0.017087    0.717640    
#> 298: 0.058871    0.999036    3.418085    0.147754    0.087919    0.017087    0.717560    
#> 299: 0.058587    0.999184    3.417928    0.147665    0.087858    0.017077    0.717632    
#> 300: 0.058571    0.999149    3.417973    0.147578    0.087781    0.017103    0.717544    
#> 301: 0.058705    0.999126    3.417837    0.147542    0.087749    0.017120    0.717601    
#> 302: 0.058519    0.999420    3.417678    0.147575    0.087700    0.017096    0.717507    
#> 303: 0.058299    0.999657    3.417572    0.147455    0.087648    0.017084    0.717392    
#> 304: 0.058322    0.999900    3.417420    0.147215    0.087652    0.017069    0.717401    
#> 305: 0.058032    0.999648    3.417336    0.146896    0.087622    0.017067    0.717461    
#> 306: 0.057593    0.999699    3.417107    0.146854    0.087696    0.017079    0.717435    
#> 307: 0.057127    0.999819    3.416871    0.147249    0.087786    0.017102    0.717615    
#> 308: 0.056501    0.999815    3.416676    0.147455    0.087844    0.017156    0.717720    
#> 309: 0.056244    0.999550    3.416556    0.147643    0.087898    0.017191    0.717719    
#> 310: 0.056022    0.999404    3.416434    0.147775    0.087947    0.017205    0.717779    
#> 311: 0.055764    0.999519    3.416385    0.148125    0.087927    0.017199    0.717713    
#> 312: 0.055702    0.999450    3.416285    0.148181    0.087913    0.017202    0.717635    
#> 313: 0.055532    0.999197    3.416246    0.148447    0.088017    0.017211    0.717700    
#> 314: 0.055118    0.999304    3.416155    0.148708    0.088051    0.017223    0.717592    
#> 315: 0.054719    0.999482    3.416022    0.148867    0.088094    0.017233    0.717482    
#> 316: 0.054718    0.999745    3.415948    0.148950    0.088130    0.017234    0.717371    
#> 317: 0.054735    0.999746    3.416009    0.149068    0.088097    0.017219    0.717515    
#> 318: 0.054558    0.999755    3.415866    0.149126    0.088177    0.017212    0.717370    
#> 319: 0.054593    0.999762    3.415840    0.149245    0.088167    0.017241    0.717282    
#> 320: 0.054117    0.999824    3.415698    0.149267    0.088056    0.017243    0.717264    
#> 321: 0.053597    0.999924    3.415525    0.149408    0.087886    0.017238    0.717428    
#> 322: 0.053444    0.999921    3.415423    0.149503    0.087829    0.017253    0.717430    
#> 323: 0.052718    0.999951    3.415318    0.149795    0.087718    0.017286    0.717485    
#> 324: 0.052459    1.000203    3.415198    0.149995    0.087750    0.017315    0.717336    
#> 325: 0.052301    1.000490    3.415062    0.150058    0.087674    0.017318    0.717257    
#> 326: 0.052359    1.000204    3.414975    0.150001    0.087599    0.017332    0.717186    
#> 327: 0.052556    1.000191    3.415027    0.149745    0.087605    0.017370    0.717289    
#> 328: 0.052791    1.000207    3.415121    0.149466    0.087457    0.017374    0.717344    
#> 329: 0.052933    1.000054    3.415298    0.149218    0.087438    0.017358    0.717263    
#> 330: 0.052935    1.000036    3.415341    0.148858    0.087427    0.017314    0.717283    
#> 331: 0.053145    1.000127    3.415400    0.148753    0.087388    0.017293    0.717175    
#> 332: 0.053293    1.000121    3.415511    0.148650    0.087347    0.017257    0.717233    
#> 333: 0.053446    1.000043    3.415608    0.148503    0.087252    0.017282    0.717238    
#> 334: 0.053355    0.999995    3.415565    0.148466    0.087303    0.017292    0.717218    
#> 335: 0.053348    1.000000    3.415454    0.148238    0.087283    0.017266    0.717191    
#> 336: 0.053141    1.000218    3.415304    0.148199    0.087280    0.017269    0.717129    
#> 337: 0.052933    1.000628    3.415159    0.148294    0.087332    0.017272    0.717146    
#> 338: 0.052830    1.000808    3.415140    0.148223    0.087335    0.017289    0.717198    
#> 339: 0.052549    1.000937    3.415086    0.148335    0.087323    0.017335    0.717166    
#> 340: 0.052365    1.000692    3.415062    0.148280    0.087294    0.017372    0.717102    
#> 341: 0.052387    1.000623    3.415058    0.148207    0.087230    0.017395    0.717077    
#> 342: 0.052131    1.000553    3.414996    0.148150    0.087366    0.017384    0.716913    
#> 343: 0.051815    1.000490    3.414969    0.148199    0.087381    0.017357    0.716910    
#> 344: 0.051917    1.000464    3.414991    0.148028    0.087340    0.017351    0.717037    
#> 345: 0.052022    1.000416    3.414967    0.147855    0.087285    0.017348    0.717026    
#> 346: 0.051973    1.000512    3.414878    0.147666    0.087192    0.017369    0.716904    
#> 347: 0.052105    1.000535    3.414817    0.147670    0.087139    0.017383    0.716914    
#> 348: 0.052079    1.000566    3.414787    0.147563    0.087102    0.017404    0.716861    
#> 349: 0.052060    1.000457    3.414772    0.147578    0.087007    0.017398    0.716786    
#> 350: 0.051834    1.000367    3.414719    0.147773    0.086985    0.017380    0.716770    
#> 351: 0.051774    1.000535    3.414641    0.147801    0.086975    0.017353    0.716788    
#> 352: 0.051442    1.000653    3.414623    0.147710    0.087007    0.017367    0.716968    
#> 353: 0.051359    1.000891    3.414575    0.147503    0.086977    0.017379    0.716944    
#> 354: 0.051283    1.000994    3.414456    0.147397    0.086966    0.017404    0.716813    
#> 355: 0.051408    1.001012    3.414410    0.147396    0.086894    0.017415    0.716850    
#> 356: 0.051340    1.000895    3.414472    0.147534    0.086890    0.017416    0.716977    
#> 357: 0.051389    1.000978    3.414427    0.147557    0.086874    0.017421    0.717003    
#> 358: 0.051357    1.001032    3.414448    0.147635    0.086852    0.017410    0.716874    
#> 359: 0.051130    1.001023    3.414418    0.147541    0.086743    0.017408    0.716911    
#> 360: 0.050856    1.001033    3.414333    0.147412    0.086738    0.017412    0.716897    
#> 361: 0.050741    1.001020    3.414282    0.147332    0.086658    0.017383    0.716970    
#> 362: 0.050614    1.001014    3.414171    0.147371    0.086704    0.017352    0.716810    
#> 363: 0.050463    1.000986    3.414141    0.147097    0.086781    0.017324    0.716765    
#> 364: 0.050505    1.001003    3.414161    0.146936    0.086865    0.017319    0.716802    
#> 365: 0.050454    1.000845    3.414184    0.146945    0.086995    0.017308    0.716801    
#> 366: 0.050413    1.000736    3.414137    0.146858    0.087069    0.017288    0.716823    
#> 367: 0.050432    1.000636    3.414161    0.146939    0.087204    0.017256    0.716828    
#> 368: 0.050706    1.000538    3.414221    0.147040    0.087117    0.017254    0.716754    
#> 369: 0.050750    1.000411    3.414233    0.147002    0.087107    0.017230    0.716776    
#> 370: 0.050659    1.000439    3.414228    0.146982    0.087067    0.017236    0.716710    
#> 371: 0.050458    1.000529    3.414090    0.146758    0.087096    0.017231    0.716715    
#> 372: 0.050297    1.000613    3.413985    0.146661    0.087093    0.017223    0.716706    
#> 373: 0.050027    1.000749    3.413841    0.146665    0.087082    0.017216    0.716691    
#> 374: 0.049938    1.000863    3.413714    0.146869    0.087067    0.017208    0.716631    
#> 375: 0.049737    1.000910    3.413642    0.147058    0.087091    0.017185    0.716580    
#> 376: 0.049633    1.000968    3.413638    0.147154    0.087110    0.017171    0.716467    
#> 377: 0.049520    1.000982    3.413623    0.147228    0.087087    0.017147    0.716512    
#> 378: 0.049278    1.001029    3.413513    0.147187    0.087079    0.017121    0.716572    
#> 379: 0.049251    1.000912    3.413497    0.147180    0.087019    0.017126    0.716537    
#> 380: 0.048953    1.000971    3.413364    0.147314    0.086999    0.017145    0.716452    
#> 381: 0.048493    1.001122    3.413239    0.147331    0.087109    0.017148    0.716456    
#> 382: 0.048411    1.001248    3.413178    0.147480    0.087004    0.017179    0.716381    
#> 383: 0.048443    1.001385    3.413147    0.147534    0.087026    0.017203    0.716324    
#> 384: 0.048318    1.001329    3.413126    0.147573    0.086945    0.017230    0.716349    
#> 385: 0.048339    1.001236    3.413208    0.147522    0.086870    0.017253    0.716440    
#> 386: 0.048580    1.001392    3.413337    0.147467    0.086835    0.017281    0.716536    
#> 387: 0.048977    1.001396    3.413586    0.147410    0.086788    0.017322    0.716628    
#> 388: 0.049165    1.001345    3.413730    0.147338    0.086774    0.017333    0.716626    
#> 389: 0.049241    1.001117    3.413777    0.147375    0.086739    0.017346    0.716717    
#> 390: 0.049147    1.001121    3.413778    0.147336    0.086755    0.017338    0.716678    
#> 391: 0.049168    1.001000    3.413819    0.147367    0.086760    0.017332    0.716639    
#> 392: 0.049151    1.001059    3.413851    0.147553    0.086751    0.017314    0.716694    
#> 393: 0.049162    1.000975    3.413797    0.147602    0.086661    0.017320    0.716628    
#> 394: 0.049038    1.000936    3.413758    0.147808    0.086641    0.017320    0.716616    
#> 395: 0.049152    1.000971    3.413733    0.147895    0.086606    0.017321    0.716654    
#> 396: 0.049388    1.000990    3.413816    0.147812    0.086569    0.017308    0.716574    
#> 397: 0.049563    1.000896    3.413900    0.147728    0.086494    0.017309    0.716621    
#> 398: 0.049788    1.000794    3.413973    0.147772    0.086460    0.017306    0.716640    
#> 399: 0.050040    1.000682    3.414074    0.147926    0.086458    0.017322    0.716564    
#> 400: 0.050348    1.000634    3.414180    0.147967    0.086500    0.017348    0.716545    
#> 401: 0.050447    1.000641    3.414165    0.148039    0.086517    0.017347    0.716510    
#> 402: 0.050406    1.000703    3.414177    0.147961    0.086473    0.017353    0.716444    
#> 403: 0.050587    1.000696    3.414121    0.147908    0.086490    0.017328    0.716462    
#> 404: 0.050537    1.000738    3.414016    0.147920    0.086423    0.017318    0.716477    
#> 405: 0.050490    1.000744    3.414006    0.147928    0.086453    0.017296    0.716398    
#> 406: 0.050585    1.000787    3.414002    0.147958    0.086375    0.017282    0.716447    
#> 407: 0.050649    1.000841    3.414027    0.147898    0.086425    0.017263    0.716457    
#> 408: 0.050676    1.000849    3.414023    0.148034    0.086434    0.017244    0.716491    
#> 409: 0.050622    1.000793    3.413977    0.148183    0.086375    0.017230    0.716472    
#> 410: 0.050568    1.000866    3.413889    0.148328    0.086305    0.017222    0.716581    
#> 411: 0.050547    1.000829    3.413859    0.148354    0.086298    0.017201    0.716748    
#> 412: 0.050506    1.000873    3.413829    0.148470    0.086330    0.017186    0.716826    
#> 413: 0.050534    1.000923    3.413797    0.148634    0.086343    0.017175    0.716913    
#> 414: 0.050480    1.000898    3.413833    0.148719    0.086362    0.017158    0.716928    
#> 415: 0.050622    1.000732    3.413896    0.148662    0.086340    0.017162    0.716895    
#> 416: 0.050799    1.000780    3.413960    0.148609    0.086304    0.017171    0.716832    
#> 417: 0.050943    1.000744    3.413998    0.148569    0.086274    0.017181    0.716757    
#> 418: 0.050825    1.000773    3.414032    0.148580    0.086316    0.017178    0.716696    
#> 419: 0.050826    1.000879    3.413982    0.148641    0.086327    0.017189    0.716623    
#> 420: 0.050736    1.001009    3.413940    0.148636    0.086314    0.017198    0.716549    
#> 421: 0.050413    1.001087    3.413928    0.148724    0.086337    0.017195    0.716574    
#> 422: 0.050428    1.000999    3.413921    0.148665    0.086293    0.017184    0.716621    
#> 423: 0.050350    1.000946    3.413902    0.148524    0.086206    0.017181    0.716714    
#> 424: 0.050137    1.000992    3.413845    0.148591    0.086181    0.017185    0.716733    
#> 425: 0.050212    1.000996    3.413804    0.148757    0.086113    0.017200    0.716698    
#> 426: 0.050174    1.001124    3.413735    0.148883    0.086098    0.017196    0.716617    
#> 427: 0.049979    1.001204    3.413650    0.148968    0.086085    0.017201    0.716564    
#> 428: 0.049716    1.001316    3.413584    0.149170    0.086094    0.017192    0.716592    
#> 429: 0.049589    1.001395    3.413578    0.149236    0.086140    0.017165    0.716549    
#> 430: 0.049578    1.001437    3.413592    0.149395    0.086168    0.017159    0.716509    
#> 431: 0.049456    1.001375    3.413511    0.149557    0.086211    0.017148    0.716472    
#> 432: 0.049446    1.001428    3.413507    0.149570    0.086226    0.017145    0.716436    
#> 433: 0.049523    1.001538    3.413534    0.149629    0.086213    0.017138    0.716422    
#> 434: 0.049525    1.001472    3.413582    0.149548    0.086151    0.017152    0.716365    
#> 435: 0.049582    1.001434    3.413590    0.149515    0.086135    0.017167    0.716296    
#> 436: 0.049578    1.001349    3.413644    0.149549    0.086200    0.017162    0.716334    
#> 437: 0.049595    1.001291    3.413644    0.149566    0.086205    0.017149    0.716258    
#> 438: 0.049476    1.001408    3.413636    0.149543    0.086182    0.017141    0.716158    
#> 439: 0.049490    1.001443    3.413647    0.149529    0.086151    0.017137    0.716086    
#> 440: 0.049395    1.001481    3.413683    0.149572    0.086147    0.017121    0.716043    
#> 441: 0.049436    1.001437    3.413735    0.149671    0.086193    0.017102    0.715998    
#> 442: 0.049365    1.001502    3.413729    0.149685    0.086225    0.017087    0.715982    
#> 443: 0.049298    1.001567    3.413678    0.149667    0.086263    0.017071    0.715919    
#> 444: 0.049237    1.001614    3.413587    0.149734    0.086385    0.017059    0.715902    
#> 445: 0.049100    1.001741    3.413504    0.149645    0.086463    0.017057    0.715932    
#> 446: 0.048993    1.001791    3.413451    0.149572    0.086491    0.017059    0.715896    
#> 447: 0.049007    1.001783    3.413411    0.149638    0.086500    0.017058    0.715860    
#> 448: 0.048910    1.001789    3.413422    0.149779    0.086514    0.017047    0.715755    
#> 449: 0.048929    1.001819    3.413514    0.149938    0.086538    0.017043    0.715742    
#> 450: 0.048944    1.001767    3.413536    0.150155    0.086614    0.017047    0.715703    
#> 451: 0.048997    1.001812    3.413528    0.150321    0.086695    0.017057    0.715786    
#> 452: 0.048893    1.001903    3.413444    0.150446    0.086735    0.017053    0.715792    
#> 453: 0.048734    1.001962    3.413385    0.150537    0.086772    0.017049    0.715750    
#> 454: 0.048605    1.002093    3.413311    0.150512    0.086825    0.017027    0.715729    
#> 455: 0.048583    1.002098    3.413278    0.150442    0.086847    0.017012    0.715700    
#> 456: 0.048444    1.002046    3.413249    0.150316    0.086838    0.017000    0.715709    
#> 457: 0.048323    1.002006    3.413229    0.150330    0.086856    0.016986    0.715683    
#> 458: 0.048264    1.002110    3.413233    0.150230    0.086877    0.016989    0.715609    
#> 459: 0.048136    1.002249    3.413223    0.150285    0.086887    0.016994    0.715558    
#> 460: 0.048053    1.002232    3.413238    0.150250    0.086831    0.017020    0.715527    
#> 461: 0.047994    1.002279    3.413284    0.150262    0.086838    0.017035    0.715503    
#> 462: 0.047949    1.002314    3.413292    0.150323    0.086816    0.017026    0.715431    
#> 463: 0.047980    1.002395    3.413306    0.150383    0.086798    0.017012    0.715442    
#> 464: 0.048061    1.002414    3.413292    0.150382    0.086815    0.017004    0.715435    
#> 465: 0.048010    1.002256    3.413327    0.150389    0.086848    0.016999    0.715478    
#> 466: 0.047998    1.002216    3.413289    0.150436    0.086877    0.016986    0.715444    
#> 467: 0.047893    1.002184    3.413310    0.150428    0.086901    0.016975    0.715359    
#> 468: 0.047993    1.002207    3.413355    0.150430    0.086881    0.016974    0.715331    
#> 469: 0.048040    1.002287    3.413394    0.150329    0.086887    0.016976    0.715319    
#> 470: 0.047997    1.002315    3.413392    0.150291    0.086892    0.016983    0.715241    
#> 471: 0.047943    1.002258    3.413381    0.150301    0.086860    0.016986    0.715226    
#> 472: 0.047869    1.002255    3.413380    0.150234    0.086880    0.016991    0.715240    
#> 473: 0.047783    1.002229    3.413356    0.150231    0.086844    0.016985    0.715152    
#> 474: 0.047774    1.002235    3.413327    0.150282    0.086810    0.016995    0.715158    
#> 475: 0.047838    1.002305    3.413282    0.150319    0.086762    0.016990    0.715137    
#> 476: 0.047816    1.002264    3.413257    0.150263    0.086744    0.016987    0.715192    
#> 477: 0.047730    1.002289    3.413218    0.150347    0.086772    0.016983    0.715139    
#> 478: 0.047620    1.002331    3.413163    0.150399    0.086833    0.016985    0.715095    
#> 479: 0.047596    1.002355    3.413128    0.150462    0.086853    0.016986    0.715096    
#> 480: 0.047582    1.002344    3.413118    0.150519    0.086872    0.016978    0.715159    
#> 481: 0.047493    1.002356    3.413111    0.150532    0.086918    0.016966    0.715150    
#> 482: 0.047595    1.002360    3.413104    0.150539    0.086949    0.016963    0.715146    
#> 483: 0.047613    1.002277    3.413088    0.150457    0.086989    0.016960    0.715106    
#> 484: 0.047645    1.002134    3.413113    0.150449    0.086977    0.016951    0.715193    
#> 485: 0.047713    1.002162    3.413122    0.150436    0.086983    0.016958    0.715216    
#> 486: 0.047683    1.002224    3.413150    0.150388    0.087012    0.016945    0.715230    
#> 487: 0.047885    1.002203    3.413219    0.150410    0.087028    0.016933    0.715152    
#> 488: 0.047991    1.002186    3.413274    0.150473    0.087042    0.016923    0.715109    
#> 489: 0.048141    1.002155    3.413285    0.150495    0.087061    0.016919    0.715171    
#> 490: 0.048230    1.002207    3.413327    0.150516    0.087078    0.016923    0.715160    
#> 491: 0.048304    1.002254    3.413378    0.150494    0.087134    0.016918    0.715127    
#> 492: 0.048330    1.002305    3.413371    0.150503    0.087160    0.016916    0.715187    
#> 493: 0.048403    1.002343    3.413420    0.150470    0.087180    0.016925    0.715187    
#> 494: 0.048465    1.002360    3.413393    0.150503    0.087191    0.016925    0.715137    
#> 495: 0.048560    1.002392    3.413397    0.150462    0.087170    0.016931    0.715119    
#> 496: 0.048633    1.002426    3.413343    0.150569    0.087183    0.016922    0.715145    
#> 497: 0.048530    1.002387    3.413292    0.150684    0.087207    0.016918    0.715144    
#> 498: 0.048477    1.002300    3.413240    0.150678    0.087233    0.016906    0.715177    
#> 499: 0.048415    1.002316    3.413183    0.150643    0.087266    0.016887    0.715151    
#> 500: 0.048437    1.002233    3.413177    0.150636    0.087290    0.016877    0.715129    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.316772    0.963990    3.443137    0.392401    0.071436    0.016800    1.681184    
#> 002: 0.535955    1.091164    3.459785    0.372781    0.067864    0.016802    1.126902    
#> 003: 0.708438    1.052744    3.481691    0.354142    0.064471    0.015962    0.851574    
#> 004: 0.716585    1.095134    3.493920    0.336435    0.061247    0.016330    0.796586    
#> 005: 0.805715    1.091574    3.489611    0.363573    0.058185    0.015513    0.775450    
#> 006: 0.743803    1.092202    3.477731    0.345394    0.055276    0.014737    0.711193    
#> 007: 0.715472    1.101114    3.476245    0.328124    0.057065    0.014001    0.694936    
#> 008: 0.718703    1.096480    3.468041    0.375237    0.057414    0.015150    0.699455    
#> 009: 0.686737    1.065180    3.472167    0.356475    0.054544    0.014392    0.707331    
#> 010: 0.720888    1.070874    3.483044    0.338651    0.051817    0.013672    0.691904    
#> 011: 0.775659    1.078299    3.494456    0.321719    0.050350    0.012989    0.700309    
#> 012: 0.771060    1.065644    3.483618    0.327454    0.047832    0.012339    0.698542    
#> 013: 0.737742    1.051170    3.477643    0.391011    0.045441    0.013965    0.693344    
#> 014: 0.746808    1.054659    3.494530    0.371460    0.043169    0.014844    0.712400    
#> 015: 0.764449    1.065383    3.498886    0.352887    0.054300    0.014102    0.683190    
#> 016: 0.746152    1.077161    3.502895    0.335243    0.055348    0.013397    0.682850    
#> 017: 0.740048    1.087814    3.489951    0.318481    0.055534    0.013102    0.678633    
#> 018: 0.748872    1.093824    3.475469    0.358403    0.064039    0.012446    0.695945    
#> 019: 0.750736    1.105819    3.479607    0.380389    0.060837    0.011824    0.662495    
#> 020: 0.795769    1.083992    3.489063    0.425041    0.058614    0.011233    0.682267    
#> 021: 0.798579    1.081315    3.493460    0.403789    0.056632    0.010671    0.667890    
#> 022: 0.755796    1.073986    3.500968    0.383599    0.053800    0.010521    0.680285    
#> 023: 0.835381    1.075313    3.519014    0.364420    0.051110    0.012671    0.687094    
#> 024: 0.843267    1.088417    3.517995    0.363592    0.048554    0.012799    0.677753    
#> 025: 0.809958    1.056816    3.509768    0.393801    0.048402    0.013484    0.672104    
#> 026: 0.802864    1.087120    3.502490    0.374111    0.052660    0.012810    0.688220    
#> 027: 0.766055    1.087123    3.496808    0.371106    0.050027    0.013958    0.701174    
#> 028: 0.823358    1.068127    3.520015    0.352551    0.053985    0.013260    0.684199    
#> 029: 0.822392    1.075738    3.510763    0.334923    0.059165    0.014784    0.715274    
#> 030: 0.803769    1.072671    3.507661    0.322018    0.056207    0.014044    0.694024    
#> 031: 0.799977    1.066976    3.513865    0.305917    0.053397    0.013603    0.680993    
#> 032: 0.773078    1.065357    3.506950    0.290621    0.050727    0.012923    0.695348    
#> 033: 0.740964    1.077816    3.487112    0.276090    0.053232    0.012277    0.717422    
#> 034: 0.748216    1.087941    3.491842    0.264813    0.051848    0.012145    0.704508    
#> 035: 0.743082    1.070644    3.500021    0.251572    0.049256    0.011538    0.696028    
#> 036: 0.758611    1.088136    3.501379    0.238993    0.047216    0.010961    0.703951    
#> 037: 0.747302    1.081220    3.502442    0.230112    0.044855    0.010413    0.727777    
#> 038: 0.752196    1.085647    3.493738    0.236594    0.052414    0.010019    0.717382    
#> 039: 0.763877    1.063900    3.497347    0.252448    0.049793    0.010478    0.707186    
#> 040: 0.755854    1.059475    3.501421    0.294281    0.047797    0.009954    0.704712    
#> 041: 0.748441    1.071714    3.496762    0.279567    0.049018    0.010231    0.692639    
#> 042: 0.774061    1.076169    3.499010    0.291669    0.049442    0.012958    0.673010    
#> 043: 0.719078    1.083619    3.484756    0.277085    0.051289    0.013722    0.679630    
#> 044: 0.708694    1.107502    3.487021    0.263231    0.048724    0.013036    0.685467    
#> 045: 0.740324    1.102574    3.478371    0.257117    0.054842    0.012384    0.677206    
#> 046: 0.762038    1.081885    3.484512    0.276687    0.052100    0.011765    0.686861    
#> 047: 0.739524    1.084152    3.488346    0.272026    0.057362    0.011177    0.669349    
#> 048: 0.722308    1.069608    3.478644    0.258424    0.054494    0.011810    0.683595    
#> 049: 0.695655    1.073327    3.487653    0.255934    0.051770    0.011905    0.694957    
#> 050: 0.753542    1.054486    3.498254    0.243138    0.053646    0.014431    0.716890    
#> 051: 0.714075    1.068731    3.486825    0.230981    0.050964    0.014983    0.702141    
#> 052: 0.769916    1.077836    3.504893    0.233934    0.048416    0.015502    0.688962    
#> 053: 0.789557    1.074335    3.500934    0.293887    0.050736    0.014727    0.683483    
#> 054: 0.743638    1.076870    3.496796    0.279192    0.062714    0.014654    0.696271    
#> 055: 0.753420    1.077405    3.496323    0.278305    0.068942    0.013921    0.712465    
#> 056: 0.764224    1.051385    3.503086    0.268968    0.065495    0.013225    0.705414    
#> 057: 0.755748    1.053016    3.509146    0.266349    0.069137    0.013714    0.701794    
#> 058: 0.759108    1.064046    3.487879    0.305281    0.065680    0.013029    0.725024    
#> 059: 0.758627    1.040905    3.502995    0.342783    0.065098    0.013066    0.721157    
#> 060: 0.784936    1.038854    3.511554    0.325644    0.061843    0.015385    0.714596    
#> 061: 0.793087    1.034777    3.517212    0.309362    0.058751    0.018405    0.728728    
#> 062: 0.770971    1.060838    3.516460    0.293894    0.063141    0.019458    0.728168    
#> 063: 0.815067    1.037713    3.516155    0.279199    0.059984    0.023451    0.716528    
#> 064: 0.818483    1.057198    3.526481    0.265239    0.056985    0.022279    0.699044    
#> 065: 0.839469    1.038923    3.513879    0.287989    0.054136    0.021165    0.685931    
#> 066: 0.831730    1.054613    3.519924    0.287271    0.051429    0.022566    0.690081    
#> 067: 0.760338    1.070945    3.506939    0.272908    0.048858    0.021438    0.678106    
#> 068: 0.730984    1.081227    3.507705    0.259262    0.047842    0.020366    0.695096    
#> 069: 0.728013    1.082881    3.495769    0.254642    0.049516    0.019348    0.710779    
#> 070: 0.744983    1.068433    3.504311    0.264826    0.073115    0.018380    0.693235    
#> 071: 0.737306    1.105133    3.484624    0.276315    0.075422    0.017461    0.696099    
#> 072: 0.691132    1.055525    3.482495    0.266513    0.075565    0.016588    0.698824    
#> 073: 0.758818    1.069634    3.499220    0.295638    0.071787    0.015759    0.694677    
#> 074: 0.725345    1.066313    3.498841    0.280856    0.068198    0.015856    0.684823    
#> 075: 0.788841    1.059940    3.524503    0.315248    0.064788    0.015063    0.691222    
#> 076: 0.776420    1.065076    3.519043    0.321289    0.061549    0.014310    0.689354    
#> 077: 0.814124    1.066599    3.512616    0.321302    0.058471    0.013594    0.681048    
#> 078: 0.795183    1.063822    3.515077    0.324785    0.058598    0.012915    0.688001    
#> 079: 0.820064    1.079013    3.514984    0.316924    0.055668    0.012269    0.717129    
#> 080: 0.773799    1.081964    3.507177    0.301078    0.068117    0.011656    0.738696    
#> 081: 0.768651    1.076173    3.508300    0.286024    0.064712    0.011073    0.714520    
#> 082: 0.789409    1.044208    3.517456    0.315845    0.061476    0.010519    0.708773    
#> 083: 0.811670    1.061932    3.518570    0.355115    0.058402    0.010555    0.718458    
#> 084: 0.781345    1.081304    3.500413    0.357321    0.063560    0.010027    0.682620    
#> 085: 0.747524    1.082408    3.505035    0.339455    0.071620    0.010548    0.689486    
#> 086: 0.783647    1.074323    3.497819    0.322482    0.068039    0.012156    0.666594    
#> 087: 0.765935    1.067182    3.493263    0.306358    0.064637    0.011548    0.673526    
#> 088: 0.699903    1.063450    3.495917    0.291040    0.061405    0.011588    0.698822    
#> 089: 0.750789    1.071974    3.489811    0.276488    0.058335    0.015004    0.696500    
#> 090: 0.781204    1.074767    3.498258    0.289096    0.055418    0.014254    0.688938    
#> 091: 0.700457    1.071916    3.484680    0.274642    0.052647    0.013541    0.705045    
#> 092: 0.735293    1.099727    3.479114    0.301627    0.050015    0.012930    0.707946    
#> 093: 0.690057    1.098834    3.467462    0.346963    0.047802    0.012283    0.695055    
#> 094: 0.718556    1.100196    3.471725    0.332273    0.045412    0.011701    0.699120    
#> 095: 0.748133    1.098203    3.483276    0.315660    0.047473    0.011116    0.710679    
#> 096: 0.702762    1.111588    3.470916    0.317265    0.045099    0.010717    0.698488    
#> 097: 0.790500    1.114292    3.481586    0.322473    0.043432    0.010253    0.699188    
#> 098: 0.771279    1.119547    3.493173    0.316965    0.042761    0.009741    0.730186    
#> 099: 0.697528    1.083735    3.480603    0.301117    0.046423    0.009254    0.728124    
#> 100: 0.700407    1.079471    3.475884    0.291313    0.044102    0.011230    0.693079    
#> 101: 0.668469    1.078376    3.462879    0.298829    0.047940    0.011554    0.707736    
#> 102: 0.712768    1.085211    3.472570    0.308807    0.062485    0.012420    0.691281    
#> 103: 0.735192    1.089435    3.486551    0.305707    0.059361    0.011799    0.672026    
#> 104: 0.740392    1.087953    3.499426    0.290422    0.056393    0.011209    0.708774    
#> 105: 0.735850    1.076523    3.495455    0.275901    0.062629    0.011193    0.698219    
#> 106: 0.789584    1.075669    3.501475    0.262106    0.059498    0.010941    0.686024    
#> 107: 0.824196    1.086391    3.507455    0.274890    0.056523    0.012537    0.692384    
#> 108: 0.797747    1.069860    3.505096    0.290124    0.053697    0.013929    0.690674    
#> 109: 0.761956    1.070656    3.506401    0.275618    0.051012    0.013233    0.692508    
#> 110: 0.785865    1.071888    3.490262    0.311702    0.052000    0.012571    0.689639    
#> 111: 0.759333    1.073544    3.498635    0.296116    0.049400    0.011943    0.666241    
#> 112: 0.762361    1.065313    3.490750    0.294018    0.061759    0.011809    0.672368    
#> 113: 0.752685    1.091160    3.493849    0.290521    0.067646    0.011291    0.673785    
#> 114: 0.763268    1.103014    3.489283    0.281183    0.064263    0.010726    0.680004    
#> 115: 0.776479    1.071453    3.486929    0.313625    0.066184    0.011445    0.681539    
#> 116: 0.764121    1.090434    3.497018    0.317798    0.062875    0.012194    0.695421    
#> 117: 0.733963    1.097437    3.495462    0.322230    0.063070    0.013453    0.679556    
#> 118: 0.754219    1.075032    3.491078    0.306118    0.059917    0.012781    0.688086    
#> 119: 0.733642    1.085535    3.497626    0.290812    0.056921    0.013766    0.711110    
#> 120: 0.725436    1.075404    3.482321    0.293096    0.055666    0.014885    0.682421    
#> 121: 0.741161    1.107863    3.498280    0.296776    0.052883    0.014141    0.702018    
#> 122: 0.778748    1.066687    3.508233    0.281937    0.052205    0.013434    0.700325    
#> 123: 0.782379    1.080055    3.493919    0.314963    0.057081    0.012830    0.693028    
#> 124: 0.759074    1.098371    3.490678    0.351010    0.064878    0.017055    0.689426    
#> 125: 0.718474    1.102542    3.477256    0.335796    0.061634    0.017821    0.694685    
#> 126: 0.714606    1.107633    3.462823    0.365672    0.058553    0.017760    0.705968    
#> 127: 0.760385    1.087946    3.480418    0.347388    0.055625    0.019379    0.719634    
#> 128: 0.753484    1.077953    3.496505    0.353401    0.057989    0.018410    0.702097    
#> 129: 0.772598    1.100848    3.505405    0.335731    0.057989    0.017489    0.690338    
#> 130: 0.795141    1.096281    3.503334    0.318944    0.055090    0.019376    0.676201    
#> 131: 0.769398    1.078852    3.482081    0.346927    0.052335    0.018407    0.690164    
#> 132: 0.742082    1.092141    3.475380    0.329581    0.049768    0.017487    0.686213    
#> 133: 0.744085    1.090831    3.483185    0.313102    0.047428    0.016613    0.694492    
#> 134: 0.781595    1.078284    3.494885    0.297447    0.054916    0.015782    0.682574    
#> 135: 0.759283    1.063265    3.497160    0.289901    0.067313    0.014993    0.682105    
#> 136: 0.767803    1.064021    3.499747    0.275406    0.063947    0.014243    0.677224    
#> 137: 0.799399    1.048992    3.509301    0.261636    0.060750    0.013531    0.709141    
#> 138: 0.772997    1.065242    3.494085    0.291693    0.057712    0.012854    0.682382    
#> 139: 0.777906    1.067583    3.507061    0.306674    0.054827    0.014823    0.689217    
#> 140: 0.781936    1.083846    3.504351    0.291340    0.056089    0.014082    0.704260    
#> 141: 0.758302    1.059894    3.507662    0.276773    0.070561    0.013378    0.687006    
#> 142: 0.795266    1.053504    3.519903    0.294959    0.067033    0.012709    0.689684    
#> 143: 0.756258    1.082853    3.501712    0.286661    0.063681    0.015209    0.673120    
#> 144: 0.802017    1.068307    3.517261    0.272328    0.060497    0.014449    0.680872    
#> 145: 0.739598    1.097011    3.492178    0.281802    0.057473    0.013786    0.681007    
#> 146: 0.733757    1.089454    3.498861    0.330836    0.054599    0.016864    0.670873    
#> 147: 0.711743    1.073615    3.479871    0.314294    0.051869    0.016021    0.672685    
#> 148: 0.708880    1.082195    3.490863    0.298579    0.050419    0.015220    0.682972    
#> 149: 0.720511    1.069861    3.496201    0.283650    0.055190    0.014459    0.704319    
#> 150: 0.766646    1.076346    3.491839    0.269468    0.063627    0.013736    0.709292    
#> 151: 0.708023    1.105350    3.486971    0.255994    0.060446    0.013049    0.677228    
#> 152: 0.709678    1.103269    3.488042    0.292166    0.057853    0.013100    0.699176    
#> 153: 0.697671    1.119566    3.479415    0.265274    0.078277    0.010250    0.729113    
#> 154: 0.739927    1.108576    3.482075    0.277492    0.069707    0.008923    0.721488    
#> 155: 0.743966    1.075428    3.486819    0.327224    0.084146    0.008072    0.689317    
#> 156: 0.757003    1.068553    3.502779    0.294464    0.091572    0.008677    0.685319    
#> 157: 0.758496    1.069974    3.505400    0.240305    0.085484    0.009945    0.690420    
#> 158: 0.773400    1.091000    3.494632    0.287105    0.074807    0.011308    0.667547    
#> 159: 0.728148    1.094169    3.495160    0.297215    0.055366    0.011527    0.683120    
#> 160: 0.759584    1.075149    3.503239    0.279523    0.056428    0.011435    0.685767    
#> 161: 0.742271    1.081945    3.492975    0.315976    0.063723    0.011869    0.677367    
#> 162: 0.731552    1.100341    3.483227    0.332832    0.058104    0.012158    0.684813    
#> 163: 0.728997    1.093128    3.475622    0.273085    0.048067    0.012216    0.687139    
#> 164: 0.728548    1.088571    3.486041    0.216753    0.053775    0.013344    0.683542    
#> 165: 0.762154    1.083429    3.499682    0.291405    0.054834    0.014276    0.673773    
#> 166: 0.771148    1.112174    3.496008    0.297880    0.059872    0.009586    0.684975    
#> 167: 0.777217    1.108309    3.497008    0.309037    0.050920    0.010193    0.692414    
#> 168: 0.791584    1.087242    3.501812    0.323341    0.048841    0.012754    0.678252    
#> 169: 0.771688    1.099819    3.490779    0.304581    0.056883    0.013188    0.691323    
#> 170: 0.759027    1.074483    3.497031    0.269498    0.052262    0.011416    0.694385    
#> 171: 0.731586    1.069046    3.492409    0.282844    0.057883    0.010392    0.685101    
#> 172: 0.716843    1.103875    3.480778    0.301969    0.052739    0.008423    0.680977    
#> 173: 0.704361    1.124337    3.471794    0.293897    0.055933    0.012133    0.684034    
#> 174: 0.708118    1.085470    3.488070    0.274273    0.053324    0.012684    0.680853    
#> 175: 0.732846    1.098404    3.479213    0.286012    0.060709    0.014006    0.691438    
#> 176: 0.743029    1.096841    3.496361    0.262064    0.056599    0.013351    0.678402    
#> 177: 0.766058    1.084079    3.501833    0.287401    0.060239    0.010122    0.685215    
#> 178: 0.749843    1.081926    3.491993    0.318623    0.053335    0.010993    0.692419    
#> 179: 0.778064    1.090925    3.484942    0.336434    0.050490    0.010349    0.697235    
#> 180: 0.736318    1.088681    3.494876    0.236370    0.054763    0.010079    0.683655    
#> 181: 0.731227    1.071863    3.473872    0.273282    0.066862    0.012980    0.671006    
#> 182: 0.752543    1.074495    3.477083    0.386818    0.062452    0.013928    0.682145    
#> 183: 0.748055    1.090182    3.476403    0.331618    0.051582    0.012074    0.677380    
#> 184: 0.702963    1.065830    3.479266    0.324960    0.052234    0.011253    0.685883    
#> 185: 0.689081    1.102595    3.482113    0.254058    0.053832    0.012582    0.696458    
#> 186: 0.729436    1.108573    3.490537    0.293048    0.050966    0.009872    0.704749    
#> 187: 0.758500    1.071068    3.500734    0.238835    0.053540    0.011786    0.696693    
#> 188: 0.743530    1.087988    3.496529    0.247705    0.056297    0.010875    0.717504    
#> 189: 0.757993    1.092237    3.499162    0.261478    0.051230    0.008824    0.707985    
#> 190: 0.751573    1.090679    3.495576    0.303862    0.047776    0.009147    0.683577    
#> 191: 0.728764    1.089515    3.480847    0.292774    0.042118    0.009613    0.685258    
#> 192: 0.712941    1.084240    3.487416    0.279314    0.045729    0.010208    0.696868    
#> 193: 0.750091    1.097963    3.482471    0.269201    0.042356    0.011113    0.678825    
#> 194: 0.736606    1.094374    3.484532    0.266349    0.059608    0.010089    0.699841    
#> 195: 0.682884    1.111236    3.474523    0.240643    0.065144    0.009936    0.707932    
#> 196: 0.709935    1.092187    3.485702    0.271251    0.072280    0.009847    0.698049    
#> 197: 0.657359    1.107424    3.487494    0.252901    0.058933    0.012238    0.706329    
#> 198: 0.730796    1.084657    3.476124    0.287159    0.051296    0.013107    0.692978    
#> 199: 0.726034    1.079529    3.487356    0.259486    0.059591    0.012292    0.669928    
#> 200: 0.731688    1.086732    3.496181    0.266476    0.070486    0.012128    0.692545    
#> 201: 0.722720    1.086286    3.498679    0.265869    0.061918    0.014298    0.690553    
#> 202: 0.724132    1.087062    3.498605    0.278323    0.060157    0.015879    0.686097    
#> 203: 0.740851    1.084986    3.496365    0.298806    0.057794    0.016464    0.683403    
#> 204: 0.754674    1.076940    3.499493    0.310273    0.055257    0.016787    0.683391    
#> 205: 0.760141    1.080578    3.500298    0.320162    0.054499    0.017154    0.685957    
#> 206: 0.762013    1.085195    3.500921    0.324451    0.054533    0.016397    0.687179    
#> 207: 0.760091    1.085114    3.499428    0.324354    0.053855    0.015929    0.686524    
#> 208: 0.756800    1.085471    3.499039    0.318769    0.053470    0.015718    0.684649    
#> 209: 0.755855    1.084478    3.498066    0.313570    0.053744    0.015483    0.682643    
#> 210: 0.753213    1.083915    3.497714    0.312702    0.053729    0.015266    0.680175    
#> 211: 0.755596    1.082182    3.498722    0.314370    0.053401    0.014886    0.679900    
#> 212: 0.759033    1.080456    3.498830    0.313551    0.052935    0.015013    0.679601    
#> 213: 0.762003    1.077719    3.499315    0.311349    0.052227    0.015186    0.680228    
#> 214: 0.764764    1.076161    3.500024    0.314269    0.052141    0.015118    0.680698    
#> 215: 0.763971    1.076162    3.500515    0.311931    0.051558    0.015275    0.680971    
#> 216: 0.766064    1.075761    3.500608    0.311615    0.052038    0.015168    0.681721    
#> 217: 0.766950    1.076253    3.501012    0.310164    0.052006    0.015066    0.681229    
#> 218: 0.766283    1.076972    3.500510    0.308266    0.051713    0.015184    0.681034    
#> 219: 0.764436    1.076755    3.498980    0.308249    0.051699    0.015176    0.681255    
#> 220: 0.761105    1.076838    3.498028    0.308939    0.051555    0.015108    0.681302    
#> 221: 0.758286    1.077174    3.497128    0.309069    0.051494    0.014993    0.680687    
#> 222: 0.756356    1.077600    3.496757    0.306889    0.051857    0.014807    0.680573    
#> 223: 0.757458    1.077438    3.496751    0.306784    0.051909    0.014811    0.680143    
#> 224: 0.758253    1.077498    3.496950    0.304583    0.051646    0.014812    0.680589    
#> 225: 0.757922    1.076131    3.496965    0.302860    0.051678    0.014727    0.680971    
#> 226: 0.758401    1.075429    3.496852    0.301671    0.051436    0.014702    0.681280    
#> 227: 0.759058    1.075798    3.496967    0.300033    0.051433    0.014757    0.681521    
#> 228: 0.757550    1.077354    3.496117    0.298497    0.051790    0.014818    0.681734    
#> 229: 0.756167    1.077469    3.495744    0.296877    0.052088    0.014775    0.681786    
#> 230: 0.757383    1.077058    3.495736    0.296821    0.052459    0.014686    0.681642    
#> 231: 0.758540    1.077114    3.496034    0.297876    0.052595    0.014591    0.681352    
#> 232: 0.756992    1.077057    3.496011    0.296706    0.052766    0.014525    0.680981    
#> 233: 0.755396    1.076435    3.496068    0.296334    0.053046    0.014604    0.681054    
#> 234: 0.755467    1.076580    3.496047    0.296598    0.053162    0.014639    0.681051    
#> 235: 0.754587    1.076031    3.495692    0.296158    0.053069    0.014538    0.681545    
#> 236: 0.754872    1.075949    3.495548    0.295687    0.053207    0.014484    0.682096    
#> 237: 0.756384    1.075712    3.495715    0.296711    0.053208    0.014431    0.682639    
#> 238: 0.757571    1.076246    3.495862    0.299242    0.053384    0.014357    0.682771    
#> 239: 0.757309    1.077231    3.495685    0.301545    0.053561    0.014294    0.682370    
#> 240: 0.758090    1.077783    3.495800    0.304272    0.053497    0.014221    0.682263    
#> 241: 0.759950    1.077496    3.495949    0.307334    0.053356    0.014171    0.682506    
#> 242: 0.760293    1.077134    3.495735    0.307950    0.053297    0.014154    0.683257    
#> 243: 0.760295    1.077597    3.495675    0.307763    0.053189    0.014169    0.683975    
#> 244: 0.759942    1.077800    3.495645    0.308278    0.053150    0.014180    0.684613    
#> 245: 0.760073    1.077404    3.495669    0.308625    0.053084    0.014183    0.685081    
#> 246: 0.759632    1.077554    3.495636    0.307303    0.053240    0.014168    0.685365    
#> 247: 0.759885    1.077599    3.495827    0.306704    0.053555    0.014176    0.685368    
#> 248: 0.759806    1.077786    3.495794    0.306103    0.053749    0.014150    0.685324    
#> 249: 0.760043    1.077695    3.495925    0.306693    0.053840    0.014092    0.685124    
#> 250: 0.760641    1.077762    3.496081    0.307441    0.053795    0.014062    0.685272    
#> 251: 0.761191    1.077965    3.496369    0.307338    0.053952    0.014005    0.685454    
#> 252: 0.761783    1.077811    3.496686    0.306761    0.054107    0.013973    0.685521    
#> 253: 0.761929    1.077685    3.496972    0.305716    0.054179    0.014017    0.685690    
#> 254: 0.762490    1.078207    3.497196    0.305508    0.054085    0.014078    0.685671    
#> 255: 0.762206    1.078358    3.497273    0.304756    0.053964    0.014145    0.685725    
#> 256: 0.762560    1.078415    3.497340    0.303513    0.053835    0.014172    0.685986    
#> 257: 0.762304    1.078193    3.497374    0.302617    0.053647    0.014136    0.686256    
#> 258: 0.761590    1.077947    3.497363    0.301310    0.053437    0.014088    0.686698    
#> 259: 0.761236    1.077806    3.497407    0.300194    0.053391    0.014030    0.687081    
#> 260: 0.761248    1.078011    3.497402    0.299276    0.053451    0.013972    0.686826    
#> 261: 0.761730    1.077761    3.497633    0.299055    0.053474    0.013970    0.686673    
#> 262: 0.762971    1.077733    3.497883    0.300677    0.053583    0.013965    0.686552    
#> 263: 0.763289    1.078110    3.498031    0.300174    0.053541    0.014014    0.686630    
#> 264: 0.763299    1.078288    3.497955    0.300667    0.053444    0.014007    0.686938    
#> 265: 0.763803    1.078216    3.497981    0.301307    0.053474    0.014049    0.687189    
#> 266: 0.764714    1.078407    3.498064    0.302156    0.053601    0.014068    0.687242    
#> 267: 0.764918    1.078403    3.498280    0.302896    0.053622    0.014115    0.687469    
#> 268: 0.764959    1.078310    3.498200    0.303388    0.053589    0.014097    0.687806    
#> 269: 0.765475    1.077858    3.498246    0.303762    0.053655    0.014120    0.688273    
#> 270: 0.766449    1.077799    3.498319    0.304513    0.053635    0.014099    0.688320    
#> 271: 0.766564    1.077663    3.498256    0.304967    0.053771    0.014114    0.688667    
#> 272: 0.766860    1.077276    3.498260    0.305501    0.053703    0.014116    0.689060    
#> 273: 0.766753    1.077361    3.498218    0.305820    0.053745    0.014134    0.689135    
#> 274: 0.766464    1.077526    3.498117    0.305579    0.053642    0.014120    0.689145    
#> 275: 0.766539    1.077824    3.497939    0.305457    0.053595    0.014101    0.689071    
#> 276: 0.765933    1.077977    3.497949    0.305150    0.053636    0.014092    0.688962    
#> 277: 0.765677    1.078307    3.497946    0.304963    0.053726    0.014067    0.688944    
#> 278: 0.765533    1.078467    3.497934    0.304315    0.053757    0.014048    0.688924    
#> 279: 0.765650    1.078272    3.498013    0.303791    0.053906    0.014041    0.689043    
#> 280: 0.765461    1.078252    3.498031    0.303163    0.053879    0.014024    0.689014    
#> 281: 0.765404    1.078211    3.498203    0.302681    0.053801    0.014046    0.689108    
#> 282: 0.765680    1.078356    3.498283    0.302489    0.053830    0.014019    0.689209    
#> 283: 0.765766    1.078479    3.498325    0.301929    0.053723    0.014033    0.689556    
#> 284: 0.765571    1.078216    3.498364    0.301327    0.053746    0.014027    0.689483    
#> 285: 0.765141    1.078387    3.498112    0.301395    0.053752    0.013979    0.689460    
#> 286: 0.764882    1.078584    3.497902    0.301131    0.053709    0.013943    0.689505    
#> 287: 0.764433    1.078713    3.497720    0.301061    0.053725    0.013904    0.689418    
#> 288: 0.764781    1.078894    3.497636    0.301708    0.053758    0.013840    0.689429    
#> 289: 0.765328    1.078740    3.497634    0.302695    0.053763    0.013814    0.689458    
#> 290: 0.765663    1.078420    3.497683    0.302716    0.053660    0.013828    0.689529    
#> 291: 0.765932    1.078525    3.497770    0.303131    0.053615    0.013877    0.689245    
#> 292: 0.765769    1.078737    3.497709    0.302779    0.053581    0.013887    0.689186    
#> 293: 0.765702    1.078916    3.497627    0.302757    0.053550    0.013890    0.689018    
#> 294: 0.765527    1.079075    3.497566    0.302311    0.053482    0.013902    0.689010    
#> 295: 0.765518    1.078910    3.497537    0.302323    0.053464    0.013875    0.688858    
#> 296: 0.765225    1.078631    3.497596    0.301733    0.053384    0.013890    0.688903    
#> 297: 0.765367    1.078639    3.497610    0.301677    0.053281    0.013923    0.688716    
#> 298: 0.765375    1.078653    3.497606    0.301980    0.053154    0.013929    0.688750    
#> 299: 0.765639    1.078691    3.497647    0.302489    0.053071    0.013935    0.688715    
#> 300: 0.765998    1.078531    3.497833    0.302323    0.053148    0.013934    0.688525    
#> 301: 0.766345    1.078360    3.497837    0.302227    0.053170    0.013906    0.688604    
#> 302: 0.766278    1.078382    3.497802    0.301965    0.053234    0.013882    0.688428    
#> 303: 0.766263    1.078470    3.497770    0.302094    0.053280    0.013877    0.688254    
#> 304: 0.766409    1.078794    3.497720    0.301831    0.053289    0.013865    0.688244    
#> 305: 0.766167    1.078695    3.497655    0.301531    0.053230    0.013830    0.688242    
#> 306: 0.766064    1.078628    3.497593    0.300896    0.053188    0.013801    0.688318    
#> 307: 0.766179    1.078511    3.497536    0.300574    0.053271    0.013758    0.688436    
#> 308: 0.765419    1.078290    3.497433    0.300188    0.053413    0.013731    0.688707    
#> 309: 0.765099    1.078244    3.497309    0.300216    0.053505    0.013713    0.688844    
#> 310: 0.765291    1.078219    3.497289    0.300193    0.053691    0.013674    0.689090    
#> 311: 0.765038    1.078258    3.497296    0.300016    0.053766    0.013639    0.689225    
#> 312: 0.764804    1.078322    3.497254    0.300113    0.053878    0.013627    0.689235    
#> 313: 0.764495    1.078115    3.497205    0.299874    0.053954    0.013619    0.689361    
#> 314: 0.764053    1.078206    3.497089    0.299523    0.054001    0.013595    0.689351    
#> 315: 0.763319    1.078389    3.496950    0.299028    0.054013    0.013574    0.689425    
#> 316: 0.763235    1.078452    3.496920    0.298834    0.053923    0.013558    0.689407    
#> 317: 0.763573    1.078394    3.497022    0.299039    0.053861    0.013578    0.689267    
#> 318: 0.763466    1.078405    3.496921    0.299530    0.053788    0.013565    0.689241    
#> 319: 0.763770    1.078325    3.496981    0.300033    0.053779    0.013574    0.689185    
#> 320: 0.763132    1.078491    3.496801    0.299938    0.053878    0.013567    0.689284    
#> 321: 0.762507    1.078598    3.496529    0.299575    0.053875    0.013547    0.689433    
#> 322: 0.762076    1.078805    3.496245    0.299035    0.053857    0.013540    0.689627    
#> 323: 0.761002    1.078976    3.496054    0.298627    0.053787    0.013514    0.689841    
#> 324: 0.760293    1.079205    3.495915    0.298087    0.053837    0.013479    0.689770    
#> 325: 0.760193    1.079381    3.495874    0.297976    0.053875    0.013469    0.689625    
#> 326: 0.760147    1.079311    3.495821    0.298145    0.053889    0.013447    0.689482    
#> 327: 0.760131    1.079360    3.495798    0.298290    0.054005    0.013440    0.689389    
#> 328: 0.759943    1.079467    3.495686    0.298000    0.054060    0.013443    0.689469    
#> 329: 0.759903    1.079524    3.495653    0.297702    0.054083    0.013458    0.689516    
#> 330: 0.759633    1.079705    3.495600    0.297492    0.054069    0.013456    0.689427    
#> 331: 0.759912    1.079802    3.495590    0.297603    0.054065    0.013450    0.689328    
#> 332: 0.759701    1.079772    3.495561    0.297619    0.054001    0.013441    0.689236    
#> 333: 0.759455    1.079809    3.495465    0.297485    0.054005    0.013406    0.689275    
#> 334: 0.759271    1.079653    3.495382    0.297456    0.054026    0.013391    0.689286    
#> 335: 0.759353    1.079706    3.495381    0.297547    0.054092    0.013389    0.689310    
#> 336: 0.759294    1.079826    3.495372    0.297624    0.054191    0.013384    0.689421    
#> 337: 0.759427    1.080004    3.495318    0.297708    0.054206    0.013371    0.689633    
#> 338: 0.759532    1.080018    3.495361    0.297906    0.054189    0.013358    0.689627    
#> 339: 0.759282    1.080202    3.495333    0.297832    0.054163    0.013369    0.689578    
#> 340: 0.759301    1.080091    3.495405    0.297588    0.054234    0.013381    0.689572    
#> 341: 0.759334    1.080159    3.495429    0.297159    0.054263    0.013390    0.689612    
#> 342: 0.759229    1.080016    3.495432    0.296899    0.054257    0.013378    0.689532    
#> 343: 0.758971    1.080067    3.495480    0.296457    0.054289    0.013345    0.689592    
#> 344: 0.758932    1.079998    3.495525    0.296331    0.054384    0.013332    0.689706    
#> 345: 0.758813    1.080065    3.495532    0.295940    0.054423    0.013303    0.689721    
#> 346: 0.758513    1.080204    3.495436    0.295414    0.054445    0.013279    0.689591    
#> 347: 0.758577    1.080073    3.495329    0.295495    0.054351    0.013281    0.689713    
#> 348: 0.758400    1.080267    3.495261    0.295650    0.054361    0.013278    0.689680    
#> 349: 0.758463    1.080171    3.495298    0.296089    0.054331    0.013306    0.689609    
#> 350: 0.758146    1.080011    3.495288    0.296090    0.054302    0.013303    0.689575    
#> 351: 0.758295    1.080155    3.495297    0.296233    0.054302    0.013286    0.689590    
#> 352: 0.757987    1.080287    3.495316    0.296109    0.054340    0.013279    0.689738    
#> 353: 0.758002    1.080418    3.495318    0.295705    0.054314    0.013260    0.689878    
#> 354: 0.758045    1.080495    3.495244    0.295528    0.054260    0.013265    0.689855    
#> 355: 0.758098    1.080407    3.495233    0.294972    0.054274    0.013270    0.689915    
#> 356: 0.758095    1.080322    3.495265    0.294669    0.054276    0.013271    0.689998    
#> 357: 0.758090    1.080416    3.495253    0.294305    0.054290    0.013274    0.690001    
#> 358: 0.757930    1.080480    3.495311    0.293963    0.054385    0.013270    0.689937    
#> 359: 0.757814    1.080565    3.495324    0.293710    0.054462    0.013263    0.689818    
#> 360: 0.757527    1.080542    3.495212    0.293486    0.054471    0.013261    0.689782    
#> 361: 0.757393    1.080583    3.495185    0.293127    0.054432    0.013247    0.689784    
#> 362: 0.757452    1.080628    3.495138    0.292866    0.054400    0.013231    0.689720    
#> 363: 0.757487    1.080561    3.495124    0.292692    0.054363    0.013212    0.689654    
#> 364: 0.757381    1.080679    3.495080    0.292665    0.054384    0.013207    0.689663    
#> 365: 0.757257    1.080629    3.495102    0.292611    0.054332    0.013202    0.689711    
#> 366: 0.757184    1.080692    3.495009    0.292478    0.054324    0.013191    0.689659    
#> 367: 0.757174    1.080722    3.494984    0.292369    0.054309    0.013172    0.689609    
#> 368: 0.757224    1.080815    3.494906    0.292139    0.054231    0.013160    0.689592    
#> 369: 0.757090    1.080880    3.494854    0.291974    0.054269    0.013145    0.689576    
#> 370: 0.756864    1.080994    3.494823    0.291556    0.054325    0.013154    0.689632    
#> 371: 0.756742    1.081026    3.494746    0.291382    0.054318    0.013134    0.689633    
#> 372: 0.756696    1.081123    3.494680    0.291449    0.054311    0.013131    0.689589    
#> 373: 0.756456    1.081215    3.494605    0.291101    0.054337    0.013117    0.689595    
#> 374: 0.756201    1.081260    3.494583    0.290814    0.054330    0.013106    0.689511    
#> 375: 0.755965    1.081328    3.494520    0.290479    0.054356    0.013087    0.689508    
#> 376: 0.755800    1.081473    3.494481    0.290171    0.054334    0.013084    0.689433    
#> 377: 0.755759    1.081573    3.494479    0.289930    0.054372    0.013085    0.689420    
#> 378: 0.755629    1.081583    3.494435    0.289797    0.054352    0.013089    0.689388    
#> 379: 0.755518    1.081481    3.494470    0.289465    0.054316    0.013082    0.689412    
#> 380: 0.755253    1.081433    3.494392    0.289310    0.054331    0.013072    0.689408    
#> 381: 0.754785    1.081432    3.494306    0.288907    0.054309    0.013051    0.689517    
#> 382: 0.754691    1.081466    3.494290    0.288651    0.054266    0.013041    0.689480    
#> 383: 0.754750    1.081514    3.494263    0.288757    0.054217    0.013051    0.689395    
#> 384: 0.754723    1.081380    3.494280    0.288847    0.054153    0.013059    0.689373    
#> 385: 0.754506    1.081369    3.494274    0.288580    0.054085    0.013066    0.689502    
#> 386: 0.754503    1.081391    3.494323    0.288675    0.054000    0.013077    0.689599    
#> 387: 0.754610    1.081393    3.494434    0.288461    0.053918    0.013110    0.689642    
#> 388: 0.754771    1.081464    3.494464    0.288618    0.053860    0.013127    0.689627    
#> 389: 0.754715    1.081242    3.494475    0.288584    0.053815    0.013151    0.689655    
#> 390: 0.754649    1.081204    3.494460    0.288525    0.053777    0.013165    0.689618    
#> 391: 0.754669    1.081077    3.494453    0.288529    0.053768    0.013174    0.689615    
#> 392: 0.754708    1.081061    3.494526    0.288576    0.053749    0.013177    0.689642    
#> 393: 0.754713    1.080921    3.494535    0.288675    0.053714    0.013185    0.689661    
#> 394: 0.754700    1.080849    3.494553    0.288659    0.053688    0.013196    0.689667    
#> 395: 0.754981    1.080876    3.494601    0.288872    0.053642    0.013217    0.689671    
#> 396: 0.755084    1.080877    3.494645    0.288930    0.053639    0.013235    0.689632    
#> 397: 0.755274    1.080818    3.494694    0.289252    0.053622    0.013246    0.689652    
#> 398: 0.755483    1.080691    3.494710    0.289899    0.053595    0.013249    0.689732    
#> 399: 0.755735    1.080665    3.494745    0.290451    0.053562    0.013254    0.689730    
#> 400: 0.755839    1.080675    3.494765    0.290740    0.053591    0.013251    0.689716    
#> 401: 0.755828    1.080778    3.494724    0.291137    0.053626    0.013253    0.689748    
#> 402: 0.755819    1.080919    3.494718    0.291498    0.053588    0.013253    0.689720    
#> 403: 0.755868    1.080951    3.494672    0.291839    0.053661    0.013241    0.689697    
#> 404: 0.755856    1.080985    3.494606    0.291927    0.053625    0.013236    0.689675    
#> 405: 0.755713    1.081006    3.494578    0.291852    0.053582    0.013228    0.689731    
#> 406: 0.755635    1.081036    3.494548    0.291888    0.053513    0.013227    0.689865    
#> 407: 0.755525    1.081118    3.494525    0.291965    0.053471    0.013231    0.689903    
#> 408: 0.755624    1.081241    3.494491    0.291858    0.053458    0.013219    0.690018    
#> 409: 0.755424    1.081323    3.494389    0.291695    0.053486    0.013209    0.689933    
#> 410: 0.755247    1.081398    3.494283    0.291629    0.053527    0.013197    0.689929    
#> 411: 0.755235    1.081290    3.494224    0.291868    0.053570    0.013186    0.690001    
#> 412: 0.755174    1.081319    3.494181    0.291880    0.053652    0.013181    0.690033    
#> 413: 0.755132    1.081351    3.494144    0.292042    0.053687    0.013172    0.689983    
#> 414: 0.754969    1.081361    3.494146    0.292011    0.053631    0.013162    0.689948    
#> 415: 0.755069    1.081308    3.494144    0.291891    0.053569    0.013159    0.689924    
#> 416: 0.755203    1.081341    3.494186    0.291685    0.053574    0.013155    0.689921    
#> 417: 0.755239    1.081341    3.494219    0.291459    0.053597    0.013151    0.689899    
#> 418: 0.755032    1.081341    3.494226    0.291293    0.053647    0.013150    0.689926    
#> 419: 0.755047    1.081451    3.494189    0.291347    0.053671    0.013156    0.689926    
#> 420: 0.755004    1.081511    3.494154    0.291395    0.053682    0.013151    0.689794    
#> 421: 0.754866    1.081530    3.494156    0.291354    0.053671    0.013141    0.689747    
#> 422: 0.755059    1.081442    3.494176    0.291520    0.053663    0.013129    0.689742    
#> 423: 0.755180    1.081376    3.494189    0.291323    0.053684    0.013124    0.689739    
#> 424: 0.755139    1.081360    3.494152    0.291246    0.053714    0.013134    0.689702    
#> 425: 0.755295    1.081364    3.494166    0.291124    0.053689    0.013141    0.689761    
#> 426: 0.755444    1.081409    3.494208    0.291040    0.053709    0.013130    0.689759    
#> 427: 0.755317    1.081410    3.494265    0.290935    0.053711    0.013141    0.689755    
#> 428: 0.755182    1.081389    3.494258    0.290865    0.053693    0.013138    0.689857    
#> 429: 0.755157    1.081389    3.494285    0.290811    0.053724    0.013132    0.689894    
#> 430: 0.754997    1.081396    3.494284    0.290656    0.053688    0.013136    0.689910    
#> 431: 0.754886    1.081420    3.494237    0.290562    0.053603    0.013134    0.689863    
#> 432: 0.754801    1.081531    3.494232    0.290637    0.053546    0.013154    0.689801    
#> 433: 0.754742    1.081687    3.494198    0.290763    0.053479    0.013160    0.689851    
#> 434: 0.754702    1.081619    3.494171    0.290933    0.053441    0.013161    0.689796    
#> 435: 0.754784    1.081612    3.494185    0.290998    0.053427    0.013171    0.689694    
#> 436: 0.754811    1.081525    3.494240    0.290980    0.053391    0.013180    0.689710    
#> 437: 0.754964    1.081445    3.494297    0.291079    0.053348    0.013174    0.689715    
#> 438: 0.755180    1.081533    3.494329    0.291151    0.053352    0.013161    0.689723    
#> 439: 0.755267    1.081602    3.494325    0.291349    0.053326    0.013157    0.689724    
#> 440: 0.755149    1.081713    3.494270    0.291309    0.053300    0.013156    0.689708    
#> 441: 0.755123    1.081710    3.494262    0.291200    0.053284    0.013156    0.689643    
#> 442: 0.755032    1.081708    3.494271    0.291088    0.053253    0.013150    0.689590    
#> 443: 0.754933    1.081768    3.494231    0.291125    0.053257    0.013141    0.689575    
#> 444: 0.754853    1.081836    3.494146    0.291125    0.053244    0.013135    0.689542    
#> 445: 0.754712    1.081890    3.494088    0.291204    0.053299    0.013124    0.689563    
#> 446: 0.754548    1.081904    3.494021    0.291354    0.053334    0.013108    0.689594    
#> 447: 0.754575    1.081874    3.494057    0.291295    0.053367    0.013094    0.689551    
#> 448: 0.754460    1.081887    3.494055    0.291395    0.053376    0.013093    0.689506    
#> 449: 0.754380    1.081979    3.494090    0.291514    0.053396    0.013097    0.689534    
#> 450: 0.754271    1.082039    3.494068    0.291543    0.053386    0.013102    0.689524    
#> 451: 0.754175    1.082131    3.494011    0.291675    0.053385    0.013096    0.689514    
#> 452: 0.754126    1.082178    3.493965    0.291955    0.053389    0.013099    0.689448    
#> 453: 0.753990    1.082259    3.493903    0.292053    0.053383    0.013104    0.689368    
#> 454: 0.753818    1.082458    3.493846    0.292044    0.053347    0.013091    0.689345    
#> 455: 0.753734    1.082537    3.493787    0.292056    0.053357    0.013086    0.689350    
#> 456: 0.753566    1.082558    3.493742    0.292083    0.053302    0.013072    0.689400    
#> 457: 0.753443    1.082581    3.493726    0.291986    0.053268    0.013058    0.689428    
#> 458: 0.753398    1.082690    3.493764    0.291862    0.053274    0.013053    0.689507    
#> 459: 0.753197    1.082811    3.493728    0.291748    0.053286    0.013049    0.689547    
#> 460: 0.753078    1.082847    3.493666    0.291683    0.053247    0.013050    0.689530    
#> 461: 0.753003    1.082868    3.493694    0.291573    0.053254    0.013040    0.689604    
#> 462: 0.752852    1.082929    3.493693    0.291590    0.053262    0.013025    0.689680    
#> 463: 0.752805    1.082933    3.493706    0.291632    0.053283    0.013013    0.689665    
#> 464: 0.752798    1.082934    3.493667    0.291646    0.053319    0.012992    0.689641    
#> 465: 0.752762    1.082800    3.493641    0.291548    0.053333    0.012972    0.689677    
#> 466: 0.752762    1.082811    3.493600    0.291456    0.053306    0.012953    0.689749    
#> 467: 0.752668    1.082784    3.493581    0.291428    0.053298    0.012932    0.689735    
#> 468: 0.752750    1.082794    3.493590    0.291501    0.053254    0.012929    0.689779    
#> 469: 0.752809    1.082831    3.493638    0.291432    0.053192    0.012929    0.689873    
#> 470: 0.752796    1.082851    3.493622    0.291462    0.053145    0.012929    0.689927    
#> 471: 0.752803    1.082819    3.493646    0.291272    0.053110    0.012934    0.689968    
#> 472: 0.752830    1.082843    3.493654    0.291203    0.053124    0.012928    0.690002    
#> 473: 0.752744    1.082793    3.493641    0.291024    0.053133    0.012919    0.689984    
#> 474: 0.752651    1.082722    3.493582    0.291014    0.053134    0.012911    0.690076    
#> 475: 0.752707    1.082772    3.493592    0.290908    0.053157    0.012906    0.690052    
#> 476: 0.752780    1.082800    3.493563    0.290855    0.053178    0.012902    0.690089    
#> 477: 0.752795    1.082811    3.493557    0.290808    0.053216    0.012892    0.690017    
#> 478: 0.752675    1.082823    3.493549    0.290893    0.053239    0.012881    0.690047    
#> 479: 0.752780    1.082831    3.493529    0.291014    0.053273    0.012874    0.690033    
#> 480: 0.752783    1.082811    3.493526    0.291108    0.053299    0.012873    0.690080    
#> 481: 0.752752    1.082796    3.493524    0.291008    0.053309    0.012864    0.690076    
#> 482: 0.752823    1.082760    3.493490    0.291006    0.053287    0.012855    0.690131    
#> 483: 0.752648    1.082756    3.493460    0.291038    0.053309    0.012841    0.690111    
#> 484: 0.752668    1.082653    3.493457    0.291134    0.053310    0.012833    0.690124    
#> 485: 0.752793    1.082604    3.493488    0.291233    0.053304    0.012824    0.690124    
#> 486: 0.752965    1.082620    3.493540    0.291250    0.053289    0.012823    0.690120    
#> 487: 0.753181    1.082599    3.493603    0.291181    0.053276    0.012821    0.690097    
#> 488: 0.753293    1.082579    3.493639    0.291192    0.053201    0.012817    0.690098    
#> 489: 0.753436    1.082532    3.493637    0.291270    0.053184    0.012814    0.690110    
#> 490: 0.753444    1.082658    3.493624    0.291214    0.053208    0.012816    0.690086    
#> 491: 0.753406    1.082752    3.493636    0.291167    0.053223    0.012815    0.690089    
#> 492: 0.753387    1.082845    3.493616    0.291287    0.053208    0.012819    0.690122    
#> 493: 0.753318    1.082844    3.493591    0.291242    0.053179    0.012830    0.690140    
#> 494: 0.753329    1.082901    3.493537    0.291156    0.053165    0.012833    0.690134    
#> 495: 0.753440    1.082969    3.493534    0.291335    0.053160    0.012825    0.690122    
#> 496: 0.753567    1.082950    3.493512    0.291399    0.053152    0.012807    0.690146    
#> 497: 0.753461    1.082931    3.493494    0.291377    0.053162    0.012803    0.690180    
#> 498: 0.753345    1.082911    3.493489    0.291248    0.053171    0.012792    0.690150    
#> 499: 0.753266    1.082968    3.493430    0.291214    0.053184    0.012781    0.690109    
#> 500: 0.753190    1.082930    3.493403    0.291064    0.053207    0.012773    0.690069    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.338777    0.973351    3.443973    0.392401    0.083056    0.016800    1.810206    
#> 002: 0.539572    1.050057    3.454124    0.372781    0.078903    0.015960    1.243916    
#> 003: 0.667014    1.029278    3.465120    0.354142    0.074958    0.015162    0.899796    
#> 004: 0.700716    1.031079    3.480633    0.483668    0.071210    0.014404    0.757047    
#> 005: 0.812537    1.003131    3.478356    0.499209    0.067650    0.013684    0.693406    
#> 006: 0.821941    1.036164    3.475205    0.593975    0.064267    0.013000    0.637649    
#> 007: 0.802377    1.045782    3.472639    0.622634    0.063635    0.012350    0.655350    
#> 008: 0.828597    1.040958    3.474873    0.662274    0.080361    0.011732    0.646988    
#> 009: 0.811736    1.014278    3.476906    0.721742    0.076343    0.011146    0.655248    
#> 010: 0.816883    1.009607    3.474572    0.685655    0.072526    0.010588    0.646529    
#> 011: 0.886350    1.015113    3.489646    0.694389    0.068900    0.010059    0.640008    
#> 012: 0.887499    1.006359    3.489998    0.665992    0.071939    0.009556    0.628976    
#> 013: 0.885654    0.999756    3.486678    0.680237    0.069104    0.009078    0.643896    
#> 014: 0.979133    0.990767    3.497863    0.987970    0.067754    0.008624    0.647274    
#> 015: 0.970149    0.991575    3.509851    0.938571    0.064366    0.008193    0.649656    
#> 016: 0.971796    1.011334    3.506454    0.891643    0.062776    0.007783    0.657919    
#> 017: 0.943470    1.023326    3.503178    0.847060    0.064264    0.007394    0.633366    
#> 018: 0.932730    1.017584    3.494820    0.804707    0.063576    0.007025    0.630292    
#> 019: 0.886118    1.005309    3.498123    0.764472    0.061988    0.006673    0.621278    
#> 020: 0.947047    1.009357    3.506279    0.762640    0.069987    0.006340    0.619454    
#> 021: 0.925556    0.990326    3.508413    0.724508    0.070882    0.006153    0.616422    
#> 022: 0.928667    0.994574    3.507922    0.815459    0.067338    0.006221    0.611886    
#> 023: 0.963693    1.022211    3.509375    0.780100    0.073578    0.007002    0.626752    
#> 024: 0.957471    1.017172    3.509243    0.746293    0.071538    0.006683    0.614302    
#> 025: 0.914013    1.005216    3.498917    0.728534    0.079704    0.006348    0.624839    
#> 026: 0.914142    1.029485    3.494213    0.692108    0.090524    0.006031    0.643951    
#> 027: 0.858766    1.043422    3.491734    0.657502    0.085998    0.005729    0.651720    
#> 028: 0.928029    1.010458    3.500708    0.722856    0.081698    0.005443    0.643671    
#> 029: 0.944040    1.020550    3.496701    0.770555    0.077613    0.005315    0.630321    
#> 030: 0.919069    1.022530    3.494759    0.732028    0.073732    0.005049    0.624678    
#> 031: 0.910694    1.008554    3.501143    0.714808    0.070739    0.004924    0.629623    
#> 032: 0.932655    0.998453    3.503101    0.876234    0.074986    0.005098    0.605551    
#> 033: 0.946727    1.012160    3.502961    0.859319    0.077110    0.004843    0.610265    
#> 034: 1.012491    1.025086    3.500069    0.947667    0.073255    0.005308    0.618520    
#> 035: 0.942780    1.012207    3.496617    0.900284    0.069592    0.005043    0.615818    
#> 036: 0.958456    1.014574    3.498733    0.855270    0.069960    0.005090    0.624533    
#> 037: 0.951097    1.023544    3.502424    0.812506    0.066462    0.004858    0.649463    
#> 038: 0.959495    1.023210    3.502007    0.885366    0.078557    0.004615    0.626987    
#> 039: 0.921979    1.004977    3.508034    0.841098    0.075462    0.004384    0.632727    
#> 040: 0.902934    1.016553    3.507842    0.799043    0.086797    0.004612    0.628929    
#> 041: 0.904641    0.996124    3.508992    0.759091    0.082457    0.004381    0.642807    
#> 042: 0.974384    1.002022    3.499079    0.805942    0.078334    0.004162    0.617310    
#> 043: 0.918768    1.025647    3.486672    0.765644    0.077499    0.004143    0.644021    
#> 044: 0.892114    1.031721    3.488615    0.727362    0.073624    0.004050    0.644034    
#> 045: 0.857946    1.029215    3.481575    0.690994    0.082667    0.004715    0.609643    
#> 046: 0.887947    1.021338    3.484348    0.665391    0.078534    0.004501    0.626900    
#> 047: 0.902360    1.030813    3.482976    0.659121    0.077406    0.004297    0.631454    
#> 048: 0.875318    1.021482    3.482457    0.729492    0.086144    0.004082    0.630542    
#> 049: 0.911537    1.014758    3.492502    0.765604    0.081837    0.003878    0.623073    
#> 050: 0.967853    0.992697    3.489243    0.836429    0.090230    0.004537    0.633345    
#> 051: 0.924853    1.006444    3.489510    0.794608    0.085718    0.004310    0.631620    
#> 052: 0.947855    1.003950    3.495700    0.754878    0.085344    0.004094    0.617213    
#> 053: 0.949281    0.998233    3.496797    0.787864    0.081076    0.003890    0.623003    
#> 054: 0.879226    0.996200    3.501603    0.748471    0.077023    0.003695    0.647286    
#> 055: 0.911713    1.001885    3.496452    0.712484    0.077205    0.003510    0.645340    
#> 056: 0.970612    0.989051    3.497738    0.935788    0.077703    0.003426    0.664166    
#> 057: 0.956809    1.004034    3.501018    0.888998    0.083375    0.003278    0.660256    
#> 058: 0.958726    0.994988    3.493052    0.844549    0.085628    0.003307    0.660174    
#> 059: 0.916249    0.946343    3.500058    0.802321    0.094255    0.004335    0.673259    
#> 060: 0.948248    0.981712    3.502624    0.762205    0.089542    0.004233    0.669049    
#> 061: 0.986265    0.995865    3.504533    0.771347    0.085065    0.004308    0.639833    
#> 062: 0.983749    1.016718    3.506900    0.828917    0.081462    0.004965    0.662129    
#> 063: 0.955220    0.982565    3.503151    0.787471    0.079728    0.004717    0.651519    
#> 064: 0.962619    0.993427    3.509242    0.864669    0.090001    0.004565    0.651523    
#> 065: 0.935087    0.996307    3.495620    0.821435    0.088085    0.004337    0.633949    
#> 066: 0.896360    1.022492    3.492818    0.795342    0.091180    0.004120    0.621363    
#> 067: 0.918020    1.001282    3.485855    0.852319    0.086621    0.004870    0.619136    
#> 068: 0.836273    1.021895    3.487233    0.809703    0.082290    0.004627    0.638799    
#> 069: 0.914786    1.029055    3.479114    0.883150    0.082793    0.004849    0.635249    
#> 070: 0.945079    1.024329    3.493297    0.992513    0.078653    0.006329    0.625195    
#> 071: 0.952396    1.044854    3.477144    0.992730    0.076870    0.006012    0.632724    
#> 072: 0.897685    1.008670    3.491385    0.943094    0.080681    0.005712    0.630424    
#> 073: 0.912821    1.006433    3.499463    0.895939    0.076647    0.005426    0.628792    
#> 074: 0.930639    0.985129    3.494966    0.851142    0.072815    0.005155    0.624998    
#> 075: 0.910252    0.984983    3.511439    0.808585    0.082889    0.004897    0.630418    
#> 076: 0.929429    1.016142    3.512763    0.768156    0.084111    0.004652    0.647357    
#> 077: 0.979875    1.001835    3.503771    0.808951    0.079905    0.004420    0.636577    
#> 078: 1.002195    0.988398    3.506255    0.933026    0.083825    0.004199    0.614425    
#> 079: 0.922496    1.001354    3.507417    0.886375    0.079633    0.004492    0.643887    
#> 080: 0.946892    0.997632    3.493505    0.891092    0.075652    0.004267    0.656895    
#> 081: 0.931969    1.030626    3.490486    0.846537    0.071869    0.004054    0.654709    
#> 082: 0.932900    1.022292    3.503897    0.804210    0.068276    0.004779    0.659459    
#> 083: 0.946558    1.036923    3.506098    0.848760    0.079738    0.004540    0.646383    
#> 084: 0.999421    1.030937    3.505658    0.888622    0.093073    0.004313    0.637472    
#> 085: 0.972470    1.026095    3.509775    0.844191    0.088419    0.004097    0.641984    
#> 086: 0.947719    1.023713    3.499866    0.801982    0.083998    0.003892    0.633427    
#> 087: 0.921677    1.003102    3.492313    0.761883    0.079798    0.003698    0.619797    
#> 088: 0.877721    0.998223    3.497330    0.724892    0.084668    0.003513    0.635603    
#> 089: 0.928833    1.017482    3.492911    0.771529    0.080435    0.003337    0.640565    
#> 090: 0.892770    1.004178    3.493293    0.732953    0.076413    0.003170    0.637675    
#> 091: 0.945840    0.989574    3.486739    0.821603    0.082045    0.003364    0.637551    
#> 092: 0.924199    1.010156    3.488480    0.849771    0.082069    0.003665    0.627932    
#> 093: 0.882612    0.998165    3.487898    0.807282    0.081670    0.003482    0.622057    
#> 094: 0.872236    1.049211    3.476212    0.766918    0.077587    0.003345    0.634942    
#> 095: 0.864633    1.038490    3.480952    0.751715    0.075454    0.003178    0.622794    
#> 096: 0.878217    1.046541    3.480153    0.795452    0.071681    0.003019    0.631567    
#> 097: 0.838180    1.066312    3.471844    0.763325    0.076128    0.002868    0.621602    
#> 098: 0.842667    1.070902    3.472227    0.725159    0.088407    0.002724    0.634000    
#> 099: 0.884411    1.034719    3.467182    0.766785    0.083987    0.002588    0.636580    
#> 100: 0.837181    1.039744    3.467647    0.728446    0.079788    0.002459    0.644118    
#> 101: 0.830431    1.030310    3.459433    0.709456    0.084938    0.002336    0.652611    
#> 102: 0.822197    1.038126    3.455626    0.673983    0.082021    0.002271    0.650775    
#> 103: 0.849145    1.043693    3.462983    0.841024    0.077920    0.002380    0.635708    
#> 104: 0.876196    1.034775    3.472813    0.866259    0.074969    0.002261    0.631702    
#> 105: 0.909624    1.018996    3.473813    0.967649    0.081502    0.002319    0.627807    
#> 106: 0.870160    1.028426    3.471706    0.919266    0.084023    0.002203    0.624720    
#> 107: 0.867775    1.042272    3.472518    0.873303    0.095816    0.002093    0.628121    
#> 108: 0.855870    1.023410    3.466349    0.829638    0.091025    0.001989    0.641663    
#> 109: 0.879221    1.030643    3.472145    0.788156    0.094528    0.001889    0.632070    
#> 110: 0.908124    1.042712    3.466731    0.837795    0.089801    0.001905    0.639001    
#> 111: 0.841355    1.039484    3.470229    0.795905    0.089538    0.001810    0.631616    
#> 112: 0.847737    1.020515    3.468585    0.756110    0.097129    0.001719    0.649234    
#> 113: 0.886086    1.063955    3.469840    0.814720    0.093470    0.001633    0.639260    
#> 114: 0.905918    1.051884    3.471830    0.903863    0.088796    0.001552    0.628849    
#> 115: 0.883852    1.006700    3.473513    0.858670    0.088254    0.001474    0.634139    
#> 116: 0.902718    1.027472    3.476523    0.826111    0.083841    0.001548    0.632443    
#> 117: 0.895226    1.022563    3.476219    0.796309    0.079649    0.001480    0.635036    
#> 118: 0.952834    1.018554    3.478592    0.968620    0.084377    0.001691    0.639225    
#> 119: 0.952448    1.039111    3.481017    1.021806    0.084568    0.002050    0.624437    
#> 120: 0.867678    1.041120    3.479774    0.970716    0.095390    0.002250    0.630499    
#> 121: 0.944450    1.042197    3.485839    0.922180    0.090620    0.002372    0.647891    
#> 122: 0.896093    1.024029    3.484654    0.876071    0.086089    0.002589    0.634304    
#> 123: 0.936296    1.024579    3.490341    0.832267    0.091031    0.002680    0.619141    
#> 124: 0.913803    1.054717    3.481654    0.790654    0.086479    0.002546    0.638441    
#> 125: 0.884600    1.071008    3.474447    0.751121    0.096244    0.002460    0.620572    
#> 126: 0.847763    1.067921    3.469000    0.713565    0.097639    0.002529    0.630454    
#> 127: 0.902120    1.027658    3.472014    0.728375    0.092757    0.002402    0.619631    
#> 128: 0.847860    1.043190    3.475261    0.714222    0.088119    0.002660    0.627996    
#> 129: 0.886107    1.024359    3.479581    0.758982    0.095658    0.003262    0.619195    
#> 130: 0.892217    1.043385    3.483006    0.722731    0.090875    0.003099    0.625697    
#> 131: 0.841844    1.011422    3.479165    0.736486    0.091865    0.003571    0.630277    
#> 132: 0.831048    1.026504    3.472353    0.699662    0.089942    0.003393    0.643557    
#> 133: 0.887031    1.018553    3.474211    0.891640    0.090518    0.003223    0.645845    
#> 134: 0.914698    1.005040    3.481832    0.959046    0.085992    0.003508    0.638588    
#> 135: 0.887493    1.010685    3.482179    0.911094    0.081693    0.003532    0.647167    
#> 136: 0.877686    1.001218    3.482303    0.865539    0.087660    0.003356    0.642514    
#> 137: 0.951426    1.020916    3.486046    0.829466    0.083277    0.003188    0.644731    
#> 138: 0.902541    0.999405    3.490597    0.787993    0.079113    0.004107    0.636993    
#> 139: 0.879668    1.028079    3.487335    0.836884    0.083578    0.004714    0.624165    
#> 140: 0.926661    1.034465    3.495485    0.907805    0.079399    0.004542    0.627584    
#> 141: 0.892294    1.000540    3.494596    0.872284    0.075429    0.004315    0.639355    
#> 142: 0.921391    0.989588    3.505309    0.828670    0.076101    0.004099    0.645320    
#> 143: 0.891466    1.011211    3.509781    0.787236    0.076612    0.004541    0.652646    
#> 144: 0.915478    1.017289    3.502956    0.747875    0.077801    0.004314    0.645905    
#> 145: 0.934398    1.026368    3.491718    0.802710    0.075744    0.004098    0.630116    
#> 146: 0.917858    1.029435    3.497382    0.762574    0.071957    0.004297    0.631184    
#> 147: 0.854954    1.019053    3.487301    0.733366    0.078421    0.004082    0.612127    
#> 148: 0.891802    1.038607    3.486995    0.831172    0.074500    0.003878    0.614589    
#> 149: 0.901736    1.006597    3.488793    0.789614    0.073645    0.003684    0.617301    
#> 150: 0.875185    1.005972    3.483781    0.750133    0.075460    0.003500    0.638548    
#> 151: 0.824590    1.038024    3.477954    0.712626    0.079205    0.003325    0.629053    
#> 152: 0.851862    1.038101    3.478449    0.687511    0.088012    0.002208    0.613709    
#> 153: 0.878969    1.036573    3.477446    0.700206    0.089179    0.002667    0.624011    
#> 154: 0.904014    1.034099    3.486431    0.794960    0.086964    0.003334    0.632400    
#> 155: 0.849998    1.016941    3.480397    0.689018    0.069560    0.003828    0.626878    
#> 156: 0.881436    1.025203    3.491990    0.681503    0.066580    0.004700    0.624678    
#> 157: 0.940499    1.004735    3.496979    0.853652    0.061289    0.005178    0.626449    
#> 158: 0.988329    1.018939    3.495872    0.914099    0.066425    0.005276    0.621111    
#> 159: 0.905276    1.038659    3.495648    0.776395    0.058748    0.004599    0.622043    
#> 160: 0.922004    0.998665    3.500132    0.755907    0.065302    0.003882    0.627261    
#> 161: 0.917507    1.000132    3.501743    0.779352    0.063426    0.004434    0.625565    
#> 162: 0.891026    1.016273    3.489789    0.687549    0.064899    0.004399    0.631210    
#> 163: 0.903578    1.017753    3.486526    0.765834    0.058134    0.004727    0.630188    
#> 164: 0.920618    1.018890    3.488320    0.889919    0.066390    0.004692    0.622565    
#> 165: 0.920350    1.007345    3.491361    0.920456    0.059238    0.004412    0.634503    
#> 166: 0.987818    1.029276    3.488348    0.914891    0.062257    0.003676    0.643367    
#> 167: 0.920437    1.023149    3.490427    0.822418    0.069130    0.003889    0.634189    
#> 168: 0.889585    1.025747    3.497420    0.721229    0.071224    0.004199    0.616428    
#> 169: 0.890691    1.050836    3.488191    0.699220    0.069991    0.003713    0.640134    
#> 170: 0.898883    1.025678    3.486632    0.727791    0.067120    0.003678    0.636225    
#> 171: 0.882306    1.034948    3.490832    0.639134    0.071425    0.003192    0.618500    
#> 172: 0.872657    1.037752    3.488229    0.687182    0.064063    0.003131    0.621054    
#> 173: 0.865490    1.039366    3.483242    0.687362    0.077686    0.003159    0.629619    
#> 174: 0.840363    1.040485    3.483364    0.601675    0.074742    0.002942    0.616311    
#> 175: 0.843588    1.037947    3.476576    0.659439    0.076288    0.003242    0.617230    
#> 176: 0.841510    1.063289    3.484590    0.629811    0.072369    0.002552    0.620794    
#> 177: 0.902390    1.045313    3.486371    0.737935    0.090027    0.003065    0.617794    
#> 178: 0.899352    1.036838    3.484153    0.762401    0.101829    0.002592    0.626382    
#> 179: 0.875147    1.046343    3.478921    0.675040    0.084256    0.002351    0.624508    
#> 180: 0.877749    1.045118    3.481326    0.683228    0.085980    0.002341    0.625682    
#> 181: 0.884762    1.039506    3.474123    0.747724    0.084815    0.002024    0.623208    
#> 182: 0.815725    1.057760    3.467551    0.665121    0.098280    0.001672    0.637942    
#> 183: 0.819880    1.071020    3.463535    0.648493    0.089257    0.001522    0.642158    
#> 184: 0.856575    1.054074    3.466518    0.765077    0.087214    0.001545    0.644329    
#> 185: 0.841472    1.048776    3.460823    0.773136    0.067782    0.001916    0.663046    
#> 186: 0.848117    1.052198    3.465352    0.758930    0.079091    0.001773    0.658833    
#> 187: 0.846408    1.041172    3.469470    0.792817    0.080691    0.002069    0.646779    
#> 188: 0.859833    1.043213    3.470534    0.895930    0.077486    0.001895    0.642801    
#> 189: 0.896881    1.047089    3.478414    0.819921    0.066824    0.002227    0.643353    
#> 190: 0.884363    1.025142    3.486561    0.770927    0.081616    0.002067    0.627549    
#> 191: 0.876414    1.041941    3.478739    0.771925    0.091837    0.001949    0.620089    
#> 192: 0.861752    1.034133    3.477909    0.771022    0.083352    0.001783    0.622286    
#> 193: 0.903818    1.034383    3.476624    0.890152    0.081922    0.001462    0.619466    
#> 194: 0.868605    1.031784    3.472909    0.794969    0.083207    0.001545    0.632308    
#> 195: 0.820957    1.033046    3.467446    0.744134    0.085201    0.001423    0.629448    
#> 196: 0.880459    1.013829    3.477089    0.730956    0.100639    0.001207    0.647029    
#> 197: 0.825797    1.037549    3.486771    0.605557    0.079036    0.001391    0.655351    
#> 198: 0.886577    1.024397    3.482059    0.742616    0.085893    0.001847    0.636611    
#> 199: 0.833434    1.015553    3.481571    0.664559    0.094419    0.001436    0.652109    
#> 200: 0.843295    1.025738    3.481553    0.690782    0.075669    0.001670    0.675011    
#> 201: 0.843496    1.018145    3.483936    0.679992    0.078553    0.002097    0.661949    
#> 202: 0.858714    1.018720    3.483479    0.689744    0.080276    0.002076    0.657988    
#> 203: 0.877688    1.017621    3.483227    0.709899    0.081029    0.002108    0.654819    
#> 204: 0.883083    1.014882    3.484715    0.724085    0.082255    0.002054    0.653711    
#> 205: 0.880350    1.020327    3.484594    0.723219    0.086021    0.002133    0.649802    
#> 206: 0.886085    1.024387    3.484621    0.740418    0.085882    0.002143    0.649504    
#> 207: 0.883709    1.024216    3.484447    0.726470    0.086062    0.002176    0.648789    
#> 208: 0.877393    1.024576    3.484509    0.701905    0.086652    0.002127    0.646488    
#> 209: 0.880508    1.023018    3.484846    0.701171    0.086980    0.002165    0.642827    
#> 210: 0.882102    1.020213    3.485439    0.694352    0.085782    0.002186    0.641791    
#> 211: 0.884924    1.020205    3.486137    0.690119    0.084805    0.002168    0.641414    
#> 212: 0.884812    1.019447    3.486412    0.686324    0.084267    0.002126    0.640703    
#> 213: 0.885677    1.018708    3.486402    0.693162    0.084493    0.002116    0.640462    
#> 214: 0.886455    1.017848    3.486403    0.689407    0.084812    0.002093    0.640655    
#> 215: 0.886175    1.017905    3.486764    0.690324    0.084478    0.002107    0.639822    
#> 216: 0.890601    1.017532    3.486887    0.700758    0.084185    0.002116    0.639536    
#> 217: 0.890618    1.017719    3.486878    0.706170    0.083467    0.002102    0.639438    
#> 218: 0.892676    1.018471    3.486683    0.715213    0.082863    0.002089    0.639281    
#> 219: 0.893145    1.018080    3.486012    0.723880    0.082582    0.002104    0.639030    
#> 220: 0.891542    1.018451    3.485824    0.724868    0.082337    0.002095    0.638885    
#> 221: 0.890416    1.019264    3.485668    0.723188    0.082308    0.002080    0.638985    
#> 222: 0.891208    1.019575    3.485558    0.726660    0.082012    0.002097    0.639103    
#> 223: 0.892204    1.020202    3.485419    0.726472    0.081872    0.002112    0.638509    
#> 224: 0.894005    1.021031    3.485692    0.729380    0.081876    0.002126    0.637692    
#> 225: 0.893674    1.019788    3.485982    0.729906    0.081741    0.002146    0.637094    
#> 226: 0.894135    1.018516    3.485991    0.730897    0.081755    0.002152    0.636828    
#> 227: 0.893860    1.018164    3.486033    0.731290    0.081823    0.002134    0.636398    
#> 228: 0.892741    1.019078    3.485789    0.732146    0.081764    0.002128    0.636027    
#> 229: 0.893533    1.019293    3.485475    0.733807    0.081591    0.002130    0.635819    
#> 230: 0.894080    1.019344    3.485296    0.735233    0.081897    0.002133    0.635554    
#> 231: 0.893512    1.019348    3.485357    0.736064    0.081840    0.002145    0.635818    
#> 232: 0.892383    1.019613    3.485574    0.738382    0.082155    0.002156    0.635884    
#> 233: 0.891980    1.019076    3.485631    0.740259    0.081845    0.002172    0.636479    
#> 234: 0.891074    1.019202    3.485706    0.739995    0.081251    0.002185    0.636966    
#> 235: 0.890810    1.018794    3.485668    0.738352    0.081148    0.002186    0.636833    
#> 236: 0.890225    1.018751    3.485563    0.738198    0.080820    0.002191    0.636963    
#> 237: 0.890404    1.018712    3.485296    0.739164    0.080515    0.002205    0.637310    
#> 238: 0.890640    1.018550    3.485250    0.737535    0.080648    0.002232    0.637353    
#> 239: 0.891151    1.018681    3.485150    0.738814    0.080553    0.002248    0.637056    
#> 240: 0.891331    1.018722    3.485094    0.739130    0.080450    0.002254    0.636985    
#> 241: 0.890899    1.018194    3.485119    0.737687    0.080305    0.002262    0.636868    
#> 242: 0.890107    1.017532    3.485095    0.734852    0.080581    0.002292    0.636993    
#> 243: 0.889525    1.017771    3.485217    0.733901    0.080646    0.002323    0.636924    
#> 244: 0.889127    1.017725    3.485271    0.733125    0.080963    0.002356    0.636903    
#> 245: 0.888509    1.017731    3.485089    0.731730    0.080979    0.002358    0.637184    
#> 246: 0.888770    1.018038    3.485090    0.730624    0.081234    0.002382    0.636935    
#> 247: 0.888946    1.018173    3.485124    0.730728    0.081177    0.002408    0.636602    
#> 248: 0.889290    1.018539    3.485158    0.731999    0.080889    0.002427    0.636428    
#> 249: 0.889076    1.018996    3.485182    0.734459    0.080623    0.002441    0.636311    
#> 250: 0.889377    1.019098    3.485216    0.734836    0.080531    0.002451    0.636048    
#> 251: 0.890221    1.019453    3.485268    0.736294    0.080521    0.002452    0.635891    
#> 252: 0.890393    1.019871    3.485344    0.736406    0.080557    0.002458    0.635901    
#> 253: 0.889522    1.020360    3.485305    0.735924    0.080554    0.002465    0.635776    
#> 254: 0.889112    1.020961    3.485288    0.735490    0.080527    0.002482    0.635659    
#> 255: 0.889279    1.021382    3.485404    0.736572    0.080449    0.002512    0.635620    
#> 256: 0.889543    1.021493    3.485331    0.738152    0.080246    0.002544    0.635529    
#> 257: 0.889813    1.021102    3.485252    0.739655    0.079960    0.002561    0.635623    
#> 258: 0.889257    1.020889    3.485169    0.740318    0.079998    0.002556    0.635500    
#> 259: 0.889115    1.020900    3.485136    0.740732    0.080133    0.002552    0.635347    
#> 260: 0.889480    1.021105    3.485238    0.741161    0.079953    0.002549    0.635394    
#> 261: 0.889393    1.020774    3.485413    0.739724    0.079808    0.002540    0.635546    
#> 262: 0.889172    1.020818    3.485509    0.739955    0.079841    0.002522    0.635440    
#> 263: 0.889296    1.020817    3.485564    0.740731    0.079772    0.002520    0.635230    
#> 264: 0.889550    1.020656    3.485553    0.742728    0.079629    0.002513    0.635444    
#> 265: 0.889803    1.020718    3.485561    0.743389    0.079757    0.002506    0.635450    
#> 266: 0.890062    1.020902    3.485499    0.744179    0.079839    0.002507    0.635296    
#> 267: 0.890508    1.020828    3.485551    0.744940    0.079818    0.002500    0.635315    
#> 268: 0.890999    1.020518    3.485502    0.746049    0.080046    0.002496    0.635373    
#> 269: 0.892026    1.020521    3.485495    0.749168    0.080038    0.002493    0.635349    
#> 270: 0.893181    1.020699    3.485410    0.751928    0.080006    0.002488    0.635289    
#> 271: 0.893755    1.020796    3.485308    0.753370    0.080048    0.002476    0.635435    
#> 272: 0.893934    1.020619    3.485220    0.753648    0.080140    0.002479    0.635538    
#> 273: 0.893206    1.020732    3.485150    0.753096    0.080265    0.002479    0.635517    
#> 274: 0.892267    1.021142    3.485194    0.750280    0.080258    0.002474    0.635559    
#> 275: 0.892315    1.021466    3.485092    0.749371    0.080364    0.002470    0.635485    
#> 276: 0.891764    1.021729    3.485173    0.749256    0.080395    0.002467    0.635597    
#> 277: 0.891481    1.021998    3.485232    0.749696    0.080341    0.002467    0.635821    
#> 278: 0.892040    1.021916    3.485341    0.751133    0.080341    0.002465    0.636097    
#> 279: 0.892698    1.021685    3.485389    0.753450    0.080368    0.002462    0.636464    
#> 280: 0.892925    1.021691    3.485443    0.754179    0.080464    0.002461    0.636471    
#> 281: 0.892793    1.021784    3.485457    0.754325    0.080415    0.002463    0.636455    
#> 282: 0.892960    1.021937    3.485503    0.755282    0.080243    0.002463    0.636387    
#> 283: 0.892552    1.022160    3.485535    0.755554    0.080136    0.002471    0.636575    
#> 284: 0.892335    1.022075    3.485533    0.755547    0.080129    0.002473    0.636570    
#> 285: 0.892807    1.021948    3.485510    0.756187    0.080146    0.002484    0.636393    
#> 286: 0.893191    1.022041    3.485508    0.756857    0.080218    0.002495    0.636368    
#> 287: 0.893345    1.022159    3.485457    0.757924    0.080396    0.002504    0.636253    
#> 288: 0.893026    1.022153    3.485414    0.756623    0.080289    0.002513    0.636295    
#> 289: 0.892905    1.022084    3.485382    0.755200    0.080285    0.002517    0.636312    
#> 290: 0.892321    1.022014    3.485301    0.754029    0.080304    0.002520    0.636509    
#> 291: 0.892673    1.022180    3.485323    0.754184    0.080314    0.002522    0.636425    
#> 292: 0.893150    1.022196    3.485308    0.756962    0.080391    0.002521    0.636330    
#> 293: 0.893814    1.022301    3.485268    0.760356    0.080394    0.002523    0.636285    
#> 294: 0.894610    1.022309    3.485210    0.762693    0.080395    0.002528    0.636177    
#> 295: 0.895181    1.022045    3.485192    0.764076    0.080372    0.002530    0.635980    
#> 296: 0.894959    1.022003    3.485199    0.763476    0.080373    0.002530    0.635998    
#> 297: 0.895257    1.021958    3.485265    0.763553    0.080340    0.002538    0.635974    
#> 298: 0.895669    1.021940    3.485323    0.764294    0.080410    0.002540    0.635939    
#> 299: 0.895862    1.022029    3.485364    0.764608    0.080426    0.002536    0.635825    
#> 300: 0.895794    1.021976    3.485447    0.764457    0.080408    0.002536    0.635766    
#> 301: 0.896017    1.021841    3.485468    0.764371    0.080431    0.002531    0.635881    
#> 302: 0.896319    1.021848    3.485479    0.764687    0.080340    0.002529    0.635933    
#> 303: 0.896448    1.021966    3.485521    0.764148    0.080276    0.002535    0.635873    
#> 304: 0.897116    1.022122    3.485529    0.766260    0.080036    0.002541    0.635817    
#> 305: 0.897702    1.021790    3.485603    0.768047    0.080017    0.002547    0.635660    
#> 306: 0.897464    1.021604    3.485623    0.767904    0.080092    0.002547    0.635565    
#> 307: 0.897216    1.021545    3.485617    0.767179    0.080188    0.002544    0.635541    
#> 308: 0.896898    1.021470    3.485579    0.767719    0.080176    0.002543    0.635540    
#> 309: 0.897115    1.021285    3.485531    0.768669    0.080217    0.002547    0.635688    
#> 310: 0.897356    1.021323    3.485392    0.769149    0.080202    0.002546    0.635792    
#> 311: 0.897849    1.021231    3.485354    0.770295    0.080177    0.002542    0.635978    
#> 312: 0.897505    1.021118    3.485333    0.770098    0.080255    0.002537    0.636063    
#> 313: 0.897186    1.020932    3.485298    0.769588    0.080363    0.002533    0.636265    
#> 314: 0.896741    1.020958    3.485217    0.769181    0.080396    0.002529    0.636423    
#> 315: 0.896646    1.021204    3.485171    0.770245    0.080330    0.002526    0.636512    
#> 316: 0.896814    1.021233    3.485155    0.771087    0.080258    0.002522    0.636581    
#> 317: 0.897391    1.021330    3.485143    0.773106    0.080245    0.002519    0.636739    
#> 318: 0.897448    1.021450    3.485122    0.772297    0.080284    0.002515    0.636683    
#> 319: 0.897698    1.021573    3.485129    0.771997    0.080337    0.002512    0.636669    
#> 320: 0.897563    1.021609    3.485064    0.771216    0.080326    0.002509    0.636730    
#> 321: 0.897136    1.021776    3.484961    0.770401    0.080326    0.002509    0.636790    
#> 322: 0.897229    1.021824    3.484811    0.771316    0.080341    0.002507    0.636839    
#> 323: 0.896807    1.021968    3.484706    0.772019    0.080412    0.002506    0.636863    
#> 324: 0.896432    1.022266    3.484679    0.771803    0.080422    0.002505    0.636708    
#> 325: 0.896466    1.022467    3.484612    0.772734    0.080461    0.002504    0.636591    
#> 326: 0.896710    1.022397    3.484533    0.773407    0.080437    0.002503    0.636491    
#> 327: 0.897205    1.022428    3.484494    0.775307    0.080323    0.002511    0.636427    
#> 328: 0.897740    1.022557    3.484477    0.777063    0.080386    0.002515    0.636289    
#> 329: 0.898304    1.022516    3.484505    0.777644    0.080406    0.002518    0.636196    
#> 330: 0.898611    1.022558    3.484533    0.778260    0.080417    0.002517    0.636246    
#> 331: 0.898972    1.022792    3.484544    0.779118    0.080429    0.002514    0.636272    
#> 332: 0.899142    1.022803    3.484547    0.779623    0.080375    0.002512    0.636398    
#> 333: 0.899310    1.022752    3.484518    0.779962    0.080365    0.002510    0.636437    
#> 334: 0.899409    1.022612    3.484471    0.780938    0.080326    0.002509    0.636457    
#> 335: 0.899242    1.022589    3.484421    0.780391    0.080351    0.002506    0.636471    
#> 336: 0.898572    1.022640    3.484397    0.778879    0.080342    0.002505    0.636468    
#> 337: 0.898355    1.022914    3.484342    0.778422    0.080347    0.002505    0.636404    
#> 338: 0.898410    1.022994    3.484350    0.778119    0.080350    0.002504    0.636404    
#> 339: 0.898313    1.023202    3.484370    0.777687    0.080273    0.002507    0.636333    
#> 340: 0.897930    1.023015    3.484434    0.776843    0.080226    0.002507    0.636338    
#> 341: 0.897988    1.023001    3.484486    0.776080    0.080227    0.002508    0.636303    
#> 342: 0.897522    1.022888    3.484491    0.774929    0.080204    0.002509    0.636269    
#> 343: 0.897685    1.022817    3.484544    0.774941    0.080173    0.002511    0.636182    
#> 344: 0.897937    1.022666    3.484635    0.774793    0.080098    0.002517    0.636165    
#> 345: 0.898123    1.022567    3.484684    0.774538    0.080025    0.002530    0.636071    
#> 346: 0.898270    1.022606    3.484657    0.774426    0.079970    0.002532    0.635990    
#> 347: 0.898164    1.022606    3.484586    0.773688    0.079983    0.002542    0.635927    
#> 348: 0.898130    1.022755    3.484506    0.774149    0.079946    0.002547    0.635906    
#> 349: 0.898287    1.022685    3.484417    0.775050    0.079982    0.002550    0.635882    
#> 350: 0.898079    1.022592    3.484373    0.774800    0.080025    0.002552    0.635936    
#> 351: 0.898045    1.022719    3.484350    0.774343    0.080064    0.002552    0.635959    
#> 352: 0.897868    1.022795    3.484359    0.773985    0.080064    0.002554    0.635930    
#> 353: 0.897890    1.022852    3.484376    0.773838    0.080090    0.002551    0.635755    
#> 354: 0.897760    1.022868    3.484321    0.773264    0.080108    0.002550    0.635666    
#> 355: 0.897869    1.022744    3.484288    0.773262    0.080082    0.002547    0.635635    
#> 356: 0.897693    1.022630    3.484298    0.772027    0.080066    0.002542    0.635700    
#> 357: 0.898013    1.022688    3.484295    0.772652    0.080052    0.002534    0.635690    
#> 358: 0.898083    1.022668    3.484339    0.772247    0.079992    0.002533    0.635611    
#> 359: 0.897723    1.022832    3.484346    0.771330    0.079986    0.002531    0.635590    
#> 360: 0.897487    1.022875    3.484294    0.770918    0.080011    0.002533    0.635601    
#> 361: 0.897216    1.022877    3.484236    0.770551    0.079933    0.002532    0.635516    
#> 362: 0.897546    1.022822    3.484181    0.771957    0.079851    0.002535    0.635411    
#> 363: 0.897495    1.022795    3.484117    0.772480    0.079791    0.002545    0.635307    
#> 364: 0.897464    1.022805    3.484057    0.772736    0.079703    0.002554    0.635313    
#> 365: 0.897312    1.022741    3.484051    0.772645    0.079619    0.002563    0.635296    
#> 366: 0.897308    1.022849    3.483990    0.772552    0.079638    0.002565    0.635368    
#> 367: 0.897433    1.022862    3.483979    0.773132    0.079623    0.002560    0.635325    
#> 368: 0.897588    1.022852    3.483982    0.772985    0.079601    0.002556    0.635255    
#> 369: 0.897554    1.022773    3.484020    0.772796    0.079634    0.002552    0.635216    
#> 370: 0.897485    1.022789    3.484049    0.772553    0.079611    0.002550    0.635224    
#> 371: 0.897303    1.022877    3.484009    0.772390    0.079623    0.002546    0.635213    
#> 372: 0.897020    1.022862    3.483979    0.772074    0.079584    0.002543    0.635287    
#> 373: 0.896656    1.023043    3.483924    0.771883    0.079639    0.002540    0.635283    
#> 374: 0.896635    1.023111    3.483847    0.772389    0.079690    0.002536    0.635303    
#> 375: 0.896514    1.023209    3.483755    0.773047    0.079698    0.002533    0.635410    
#> 376: 0.896477    1.023343    3.483711    0.773045    0.079759    0.002531    0.635440    
#> 377: 0.896313    1.023360    3.483673    0.773132    0.079814    0.002530    0.635499    
#> 378: 0.896363    1.023374    3.483627    0.773584    0.079896    0.002528    0.635508    
#> 379: 0.896066    1.023236    3.483606    0.773261    0.079986    0.002522    0.635503    
#> 380: 0.895748    1.023161    3.483593    0.772475    0.080161    0.002518    0.635526    
#> 381: 0.895618    1.023108    3.483575    0.772537    0.080210    0.002516    0.635491    
#> 382: 0.895109    1.023128    3.483563    0.771615    0.080270    0.002513    0.635408    
#> 383: 0.894933    1.023112    3.483588    0.771091    0.080301    0.002515    0.635368    
#> 384: 0.894663    1.023068    3.483628    0.770607    0.080254    0.002515    0.635307    
#> 385: 0.894563    1.023122    3.483649    0.770597    0.080265    0.002520    0.635237    
#> 386: 0.894642    1.023363    3.483645    0.770294    0.080285    0.002526    0.635267    
#> 387: 0.894546    1.023505    3.483661    0.770005    0.080286    0.002536    0.635316    
#> 388: 0.894546    1.023691    3.483652    0.769673    0.080231    0.002540    0.635343    
#> 389: 0.894562    1.023594    3.483621    0.769905    0.080212    0.002541    0.635344    
#> 390: 0.894294    1.023672    3.483560    0.769544    0.080199    0.002545    0.635314    
#> 391: 0.894183    1.023662    3.483528    0.769706    0.080194    0.002547    0.635204    
#> 392: 0.894153    1.023757    3.483532    0.769978    0.080146    0.002550    0.635225    
#> 393: 0.893999    1.023685    3.483509    0.770047    0.080096    0.002550    0.635184    
#> 394: 0.894094    1.023620    3.483483    0.770255    0.080067    0.002552    0.635122    
#> 395: 0.894179    1.023677    3.483474    0.770076    0.080004    0.002555    0.635160    
#> 396: 0.894139    1.023715    3.483486    0.769687    0.080017    0.002554    0.635154    
#> 397: 0.894078    1.023689    3.483509    0.769327    0.079976    0.002553    0.635112    
#> 398: 0.894430    1.023660    3.483556    0.769702    0.080011    0.002552    0.635193    
#> 399: 0.894539    1.023614    3.483607    0.769711    0.080042    0.002551    0.635227    
#> 400: 0.894493    1.023660    3.483643    0.769027    0.080018    0.002552    0.635230    
#> 401: 0.894344    1.023734    3.483651    0.768567    0.080020    0.002555    0.635224    
#> 402: 0.894245    1.023833    3.483645    0.767988    0.079975    0.002559    0.635236    
#> 403: 0.894419    1.023880    3.483612    0.768380    0.079953    0.002562    0.635175    
#> 404: 0.894460    1.023901    3.483549    0.768731    0.079943    0.002564    0.635123    
#> 405: 0.894470    1.023997    3.483522    0.769388    0.079933    0.002565    0.635083    
#> 406: 0.894443    1.024041    3.483518    0.769442    0.079928    0.002566    0.635051    
#> 407: 0.894472    1.023995    3.483561    0.769622    0.079985    0.002569    0.635003    
#> 408: 0.894741    1.024006    3.483595    0.769737    0.080010    0.002571    0.634971    
#> 409: 0.894885    1.023873    3.483598    0.769783    0.079958    0.002570    0.634903    
#> 410: 0.894591    1.023864    3.483566    0.769334    0.079964    0.002569    0.634836    
#> 411: 0.894524    1.023667    3.483549    0.769518    0.080031    0.002567    0.634817    
#> 412: 0.894411    1.023695    3.483513    0.769460    0.080017    0.002567    0.634775    
#> 413: 0.894178    1.023682    3.483451    0.769081    0.079978    0.002565    0.634796    
#> 414: 0.894284    1.023735    3.483414    0.769924    0.079977    0.002566    0.634786    
#> 415: 0.894513    1.023747    3.483403    0.770406    0.079947    0.002566    0.634727    
#> 416: 0.894673    1.023838    3.483391    0.770573    0.079963    0.002567    0.634646    
#> 417: 0.894778    1.023819    3.483389    0.770742    0.079994    0.002566    0.634629    
#> 418: 0.894604    1.023874    3.483364    0.770712    0.080076    0.002567    0.634586    
#> 419: 0.894546    1.023968    3.483334    0.771158    0.080111    0.002570    0.634590    
#> 420: 0.894817    1.023984    3.483304    0.771582    0.080142    0.002569    0.634589    
#> 421: 0.894729    1.023971    3.483313    0.771458    0.080093    0.002570    0.634580    
#> 422: 0.894768    1.023862    3.483321    0.771286    0.080073    0.002570    0.634581    
#> 423: 0.894905    1.023689    3.483354    0.771457    0.080041    0.002569    0.634613    
#> 424: 0.894875    1.023610    3.483350    0.771126    0.080061    0.002567    0.634632    
#> 425: 0.894789    1.023649    3.483342    0.770946    0.080098    0.002567    0.634630    
#> 426: 0.895118    1.023701    3.483353    0.771784    0.080119    0.002566    0.634736    
#> 427: 0.895180    1.023625    3.483364    0.772090    0.080196    0.002565    0.634672    
#> 428: 0.895162    1.023711    3.483351    0.772231    0.080223    0.002566    0.634649    
#> 429: 0.895099    1.023785    3.483346    0.772108    0.080219    0.002564    0.634666    
#> 430: 0.894848    1.023918    3.483319    0.771550    0.080204    0.002565    0.634640    
#> 431: 0.894828    1.023944    3.483282    0.771527    0.080178    0.002563    0.634555    
#> 432: 0.894918    1.024034    3.483276    0.771851    0.080122    0.002564    0.634490    
#> 433: 0.895021    1.024145    3.483292    0.771801    0.080112    0.002566    0.634424    
#> 434: 0.894740    1.024142    3.483293    0.771499    0.080113    0.002568    0.634367    
#> 435: 0.894715    1.024113    3.483291    0.771065    0.080142    0.002568    0.634361    
#> 436: 0.894714    1.024081    3.483288    0.770775    0.080131    0.002567    0.634444    
#> 437: 0.894650    1.024062    3.483257    0.770602    0.080128    0.002569    0.634415    
#> 438: 0.894532    1.024137    3.483230    0.770710    0.080170    0.002566    0.634354    
#> 439: 0.894494    1.024175    3.483198    0.770883    0.080130    0.002564    0.634330    
#> 440: 0.894418    1.024218    3.483206    0.770433    0.080129    0.002560    0.634373    
#> 441: 0.894400    1.024175    3.483207    0.770463    0.080127    0.002557    0.634399    
#> 442: 0.894196    1.024264    3.483222    0.770464    0.080126    0.002556    0.634434    
#> 443: 0.894128    1.024312    3.483200    0.770337    0.080181    0.002552    0.634481    
#> 444: 0.893844    1.024374    3.483163    0.769861    0.080162    0.002549    0.634529    
#> 445: 0.893628    1.024450    3.483103    0.769946    0.080218    0.002547    0.634529    
#> 446: 0.893387    1.024539    3.483053    0.769803    0.080245    0.002544    0.634545    
#> 447: 0.893406    1.024567    3.483025    0.769844    0.080313    0.002543    0.634542    
#> 448: 0.893437    1.024532    3.483026    0.769857    0.080291    0.002541    0.634558    
#> 449: 0.893318    1.024532    3.483094    0.769428    0.080208    0.002542    0.634617    
#> 450: 0.893431    1.024497    3.483130    0.769597    0.080203    0.002541    0.634635    
#> 451: 0.893704    1.024477    3.483141    0.770310    0.080181    0.002538    0.634628    
#> 452: 0.893722    1.024497    3.483139    0.770518    0.080223    0.002536    0.634648    
#> 453: 0.893721    1.024512    3.483107    0.770729    0.080239    0.002534    0.634630    
#> 454: 0.893959    1.024552    3.483078    0.772005    0.080196    0.002532    0.634585    
#> 455: 0.894140    1.024537    3.483045    0.772887    0.080167    0.002531    0.634530    
#> 456: 0.894221    1.024510    3.483024    0.773298    0.080127    0.002532    0.634529    
#> 457: 0.894333    1.024457    3.483029    0.773700    0.080100    0.002533    0.634485    
#> 458: 0.894317    1.024532    3.483043    0.774087    0.080096    0.002532    0.634472    
#> 459: 0.894150    1.024586    3.483039    0.774175    0.080094    0.002534    0.634492    
#> 460: 0.893970    1.024627    3.483032    0.774036    0.080066    0.002536    0.634508    
#> 461: 0.893802    1.024687    3.483041    0.773735    0.080023    0.002541    0.634536    
#> 462: 0.893786    1.024720    3.483065    0.773324    0.080055    0.002543    0.634505    
#> 463: 0.893809    1.024819    3.483064    0.773112    0.080041    0.002540    0.634498    
#> 464: 0.894034    1.024872    3.483059    0.773379    0.080036    0.002537    0.634465    
#> 465: 0.894071    1.024789    3.483046    0.773639    0.080023    0.002535    0.634461    
#> 466: 0.894029    1.024825    3.483003    0.773671    0.080019    0.002535    0.634445    
#> 467: 0.893695    1.024800    3.482961    0.773253    0.080076    0.002533    0.634393    
#> 468: 0.893686    1.024763    3.482964    0.773218    0.080063    0.002533    0.634376    
#> 469: 0.893698    1.024798    3.482966    0.773311    0.080068    0.002534    0.634355    
#> 470: 0.893617    1.024803    3.482945    0.773192    0.080087    0.002536    0.634332    
#> 471: 0.893524    1.024801    3.482886    0.773008    0.080092    0.002535    0.634358    
#> 472: 0.893496    1.024821    3.482879    0.772969    0.080079    0.002533    0.634351    
#> 473: 0.893329    1.024771    3.482868    0.772721    0.080051    0.002532    0.634342    
#> 474: 0.893296    1.024734    3.482871    0.772458    0.079981    0.002533    0.634376    
#> 475: 0.893399    1.024805    3.482863    0.772659    0.079924    0.002532    0.634363    
#> 476: 0.893394    1.024799    3.482846    0.772891    0.079861    0.002532    0.634412    
#> 477: 0.893314    1.024840    3.482838    0.772822    0.079827    0.002532    0.634384    
#> 478: 0.893163    1.024865    3.482843    0.772601    0.079876    0.002529    0.634356    
#> 479: 0.893130    1.024926    3.482845    0.772345    0.079897    0.002528    0.634376    
#> 480: 0.893045    1.024966    3.482861    0.771899    0.079936    0.002529    0.634435    
#> 481: 0.892962    1.024978    3.482864    0.771786    0.079960    0.002535    0.634479    
#> 482: 0.893055    1.024999    3.482860    0.772079    0.079972    0.002539    0.634509    
#> 483: 0.893162    1.024984    3.482860    0.772285    0.079967    0.002541    0.634524    
#> 484: 0.893157    1.024882    3.482880    0.771985    0.079966    0.002544    0.634527    
#> 485: 0.893284    1.024840    3.482906    0.772439    0.079945    0.002547    0.634559    
#> 486: 0.893386    1.024860    3.482930    0.772461    0.079956    0.002547    0.634558    
#> 487: 0.893592    1.024848    3.482993    0.772513    0.079930    0.002550    0.634490    
#> 488: 0.893567    1.024898    3.483044    0.772087    0.079918    0.002554    0.634432    
#> 489: 0.893473    1.024889    3.483074    0.771675    0.079892    0.002559    0.634453    
#> 490: 0.893522    1.024905    3.483094    0.771396    0.079865    0.002564    0.634433    
#> 491: 0.893504    1.024910    3.483118    0.771284    0.079864    0.002566    0.634395    
#> 492: 0.893425    1.024955    3.483118    0.771374    0.079919    0.002569    0.634426    
#> 493: 0.893288    1.024948    3.483114    0.771264    0.079905    0.002572    0.634431    
#> 494: 0.893342    1.025052    3.483081    0.771193    0.079897    0.002573    0.634423    
#> 495: 0.893226    1.025060    3.483063    0.770780    0.079888    0.002575    0.634397    
#> 496: 0.893218    1.025138    3.483047    0.770615    0.079891    0.002576    0.634388    
#> 497: 0.893209    1.025170    3.483038    0.770716    0.079884    0.002578    0.634338    
#> 498: 0.893211    1.025185    3.483021    0.770867    0.079830    0.002580    0.634296    
#> 499: 0.893197    1.025220    3.482996    0.770867    0.079821    0.002579    0.634263    
#> 500: 0.893168    1.025189    3.482986    0.770714    0.079847    0.002579    0.634212    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.300716    0.956222    3.444543    0.392401    0.073632    0.016800    1.639460    
#> 002: 0.388162    1.036227    3.453317    0.372781    0.069950    0.017275    1.153066    
#> 003: 0.557384    0.975519    3.475189    0.354142    0.085825    0.016411    0.893398    
#> 004: 0.531304    0.992791    3.487627    0.336435    0.081534    0.015590    0.832426    
#> 005: 0.580705    1.001625    3.479933    0.319613    0.091650    0.014811    0.807175    
#> 006: 0.551774    0.983948    3.476782    0.303633    0.087068    0.014070    0.764176    
#> 007: 0.540472    1.001663    3.471654    0.288451    0.102393    0.013367    0.770382    
#> 008: 0.519369    0.981981    3.468070    0.274029    0.097273    0.012698    0.770311    
#> 009: 0.497297    0.976071    3.464460    0.260327    0.092410    0.012064    0.764023    
#> 010: 0.547087    0.964457    3.472715    0.247311    0.095051    0.011460    0.753605    
#> 011: 0.604577    0.985842    3.483791    0.234945    0.102835    0.010887    0.779964    
#> 012: 0.586567    0.975857    3.479543    0.223198    0.097694    0.010343    0.765923    
#> 013: 0.527326    0.987172    3.466150    0.212038    0.100941    0.010106    0.762817    
#> 014: 0.562773    0.988155    3.475998    0.217580    0.095893    0.009601    0.757484    
#> 015: 0.578888    0.994298    3.484150    0.206701    0.094130    0.010221    0.736148    
#> 016: 0.560664    1.006704    3.484276    0.204476    0.113554    0.009710    0.747531    
#> 017: 0.525952    1.021061    3.476666    0.194252    0.107876    0.010853    0.742306    
#> 018: 0.527154    1.018708    3.461133    0.184540    0.102482    0.010310    0.753857    
#> 019: 0.494587    1.009239    3.459707    0.175313    0.097358    0.009795    0.735099    
#> 020: 0.513092    1.045521    3.463000    0.211758    0.105898    0.009736    0.734513    
#> 021: 0.519342    1.002236    3.472188    0.201170    0.108670    0.010561    0.747060    
#> 022: 0.550287    1.011567    3.477504    0.191111    0.125163    0.010033    0.754639    
#> 023: 0.611895    1.005480    3.486071    0.183866    0.118905    0.009531    0.789305    
#> 024: 0.598976    1.023815    3.482048    0.177847    0.112960    0.011323    0.758302    
#> 025: 0.541195    0.997130    3.468560    0.192438    0.107312    0.010757    0.747552    
#> 026: 0.551694    1.028118    3.466224    0.216243    0.101946    0.010219    0.738573    
#> 027: 0.536554    1.043414    3.462797    0.205431    0.096849    0.010643    0.756374    
#> 028: 0.577786    1.021218    3.465120    0.195159    0.096415    0.011372    0.743866    
#> 029: 0.560233    1.015948    3.468005    0.195143    0.103410    0.014422    0.746234    
#> 030: 0.577314    1.005068    3.473785    0.198892    0.098240    0.013701    0.736473    
#> 031: 0.519452    0.998854    3.473948    0.188947    0.093328    0.013016    0.757911    
#> 032: 0.533975    0.973434    3.480719    0.179500    0.088661    0.012755    0.748938    
#> 033: 0.511852    1.015981    3.467257    0.187238    0.084228    0.012688    0.753945    
#> 034: 0.542682    1.015680    3.470747    0.189645    0.083618    0.012054    0.759003    
#> 035: 0.542528    1.003526    3.479541    0.180163    0.079437    0.013534    0.736979    
#> 036: 0.545239    1.021377    3.479026    0.171155    0.094027    0.014095    0.741713    
#> 037: 0.552272    1.011748    3.485762    0.162597    0.107286    0.014774    0.743192    
#> 038: 0.580476    1.018637    3.477287    0.154467    0.101922    0.014251    0.775172    
#> 039: 0.589877    0.991775    3.494081    0.192395    0.096826    0.015595    0.747021    
#> 040: 0.568330    1.004351    3.492840    0.183638    0.091984    0.016645    0.755443    
#> 041: 0.535011    0.991739    3.483186    0.174456    0.087385    0.015813    0.763463    
#> 042: 0.588028    0.984772    3.482474    0.225257    0.083016    0.015022    0.753971    
#> 043: 0.534434    0.999131    3.468444    0.213995    0.085467    0.014551    0.746637    
#> 044: 0.515833    1.015569    3.470464    0.203295    0.083048    0.013823    0.749908    
#> 045: 0.543575    1.039548    3.460768    0.210696    0.078895    0.013132    0.761437    
#> 046: 0.541222    1.029336    3.461461    0.202639    0.106336    0.012475    0.749848    
#> 047: 0.569424    1.007232    3.465080    0.193363    0.101019    0.012181    0.744482    
#> 048: 0.545596    0.997797    3.472339    0.183695    0.095968    0.012689    0.749094    
#> 049: 0.557006    1.015761    3.482565    0.174510    0.091170    0.012054    0.752146    
#> 050: 0.622512    0.984676    3.485282    0.194914    0.095044    0.011451    0.773256    
#> 051: 0.590300    0.984370    3.487364    0.185168    0.100497    0.013126    0.751138    
#> 052: 0.571351    1.010716    3.490243    0.175910    0.095473    0.012469    0.732789    
#> 053: 0.575397    0.996017    3.475078    0.169682    0.090699    0.012011    0.742059    
#> 054: 0.527689    0.984013    3.473508    0.162713    0.093085    0.012254    0.750007    
#> 055: 0.562099    0.994658    3.474760    0.154577    0.089502    0.013048    0.755839    
#> 056: 0.578156    0.988474    3.479311    0.194955    0.086265    0.012396    0.757451    
#> 057: 0.588673    0.988365    3.485454    0.195292    0.086926    0.012524    0.778436    
#> 058: 0.565991    0.988654    3.473386    0.205855    0.082580    0.011898    0.782798    
#> 059: 0.569106    0.958817    3.481555    0.206855    0.098146    0.012460    0.776155    
#> 060: 0.559715    0.963788    3.489893    0.219307    0.124603    0.011837    0.782001    
#> 061: 0.566599    0.996979    3.478332    0.208342    0.118373    0.011245    0.790300    
#> 062: 0.564376    1.003815    3.486324    0.212782    0.121314    0.012320    0.779196    
#> 063: 0.604989    0.960602    3.491518    0.232297    0.115248    0.011704    0.788155    
#> 064: 0.588946    0.975513    3.499222    0.220682    0.109486    0.013605    0.773302    
#> 065: 0.599455    0.955390    3.484830    0.209648    0.104012    0.013567    0.731996    
#> 066: 0.596446    1.003612    3.491196    0.199165    0.098811    0.013386    0.720249    
#> 067: 0.593157    0.972199    3.493049    0.189207    0.093870    0.012856    0.726297    
#> 068: 0.572022    0.990462    3.501023    0.184992    0.089177    0.014865    0.757849    
#> 069: 0.570360    1.007952    3.480456    0.195975    0.084718    0.017991    0.751287    
#> 070: 0.590740    1.004787    3.499246    0.209268    0.081729    0.017092    0.745446    
#> 071: 0.551179    1.018864    3.468248    0.215243    0.096598    0.016237    0.769210    
#> 072: 0.489564    0.973529    3.475394    0.204481    0.091768    0.015425    0.772062    
#> 073: 0.563381    1.001846    3.493029    0.194257    0.094015    0.014654    0.772516    
#> 074: 0.546417    0.991470    3.490665    0.184544    0.089314    0.013921    0.753740    
#> 075: 0.587918    0.989067    3.503745    0.175317    0.084848    0.013225    0.757562    
#> 076: 0.614721    0.997977    3.511533    0.166551    0.080606    0.014642    0.764534    
#> 077: 0.627189    0.973837    3.498892    0.158224    0.076576    0.017599    0.757520    
#> 078: 0.624495    0.985940    3.507971    0.170300    0.072747    0.018636    0.743322    
#> 079: 0.622712    0.990742    3.508781    0.176196    0.088557    0.017704    0.752115    
#> 080: 0.605589    0.989745    3.502714    0.167386    0.084129    0.016819    0.775039    
#> 081: 0.572510    0.999826    3.489208    0.159017    0.088215    0.015978    0.748434    
#> 082: 0.563966    0.987128    3.496441    0.151066    0.101373    0.015179    0.755882    
#> 083: 0.585946    1.015172    3.499542    0.156718    0.096304    0.014420    0.763904    
#> 084: 0.585067    0.991129    3.489863    0.148882    0.095297    0.014329    0.745644    
#> 085: 0.577931    0.986447    3.496815    0.141438    0.090532    0.013671    0.756527    
#> 086: 0.587314    0.992877    3.495134    0.134366    0.092049    0.017342    0.754497    
#> 087: 0.563880    0.998575    3.471825    0.151979    0.110973    0.016475    0.755901    
#> 088: 0.495235    0.994551    3.475238    0.189109    0.112033    0.015651    0.766014    
#> 089: 0.544983    1.017663    3.457622    0.192489    0.106432    0.014868    0.746209    
#> 090: 0.499657    1.009294    3.461680    0.182864    0.111176    0.014125    0.756769    
#> 091: 0.490712    1.002217    3.444271    0.192207    0.106319    0.015443    0.764525    
#> 092: 0.512931    1.033508    3.443118    0.182597    0.101003    0.014670    0.758317    
#> 093: 0.500939    1.016451    3.458163    0.176102    0.095953    0.013937    0.755672    
#> 094: 0.499015    1.030709    3.451637    0.167297    0.107910    0.013240    0.768831    
#> 095: 0.514994    1.040129    3.466670    0.186997    0.107808    0.013894    0.760631    
#> 096: 0.508962    1.027398    3.464037    0.213361    0.111992    0.013607    0.737964    
#> 097: 0.547600    1.044901    3.464286    0.202693    0.106392    0.012927    0.746621    
#> 098: 0.549162    1.055756    3.480661    0.192558    0.101072    0.012280    0.763213    
#> 099: 0.543114    1.000159    3.472778    0.182930    0.099461    0.011666    0.731980    
#> 100: 0.537444    1.017351    3.467603    0.210948    0.097263    0.011083    0.728009    
#> 101: 0.508163    1.014866    3.447740    0.200400    0.105042    0.010529    0.738467    
#> 102: 0.481025    1.019792    3.444496    0.190380    0.100992    0.011251    0.752603    
#> 103: 0.540241    1.011831    3.460940    0.180861    0.095942    0.010688    0.746833    
#> 104: 0.529131    1.006136    3.471119    0.171818    0.104053    0.010154    0.780404    
#> 105: 0.580482    0.980128    3.468723    0.169515    0.098850    0.009646    0.763836    
#> 106: 0.547492    1.000371    3.468469    0.166704    0.093908    0.011188    0.750733    
#> 107: 0.565955    1.016111    3.470529    0.187779    0.089212    0.010629    0.743153    
#> 108: 0.536383    1.019216    3.462069    0.212548    0.084752    0.010618    0.761977    
#> 109: 0.498299    1.015316    3.470458    0.207592    0.086986    0.010087    0.745511    
#> 110: 0.533956    1.002778    3.460613    0.203301    0.082637    0.012475    0.721296    
#> 111: 0.550764    1.004048    3.465563    0.193136    0.078505    0.013802    0.725124    
#> 112: 0.552143    1.004653    3.460986    0.183479    0.074579    0.013623    0.747728    
#> 113: 0.566008    1.031456    3.469867    0.174305    0.080721    0.012942    0.732254    
#> 114: 0.579238    1.017513    3.480458    0.179566    0.084546    0.012412    0.752536    
#> 115: 0.619126    0.993953    3.482517    0.202879    0.080318    0.014536    0.762301    
#> 116: 0.584974    1.004729    3.484469    0.192735    0.081257    0.017455    0.759671    
#> 117: 0.541365    1.007721    3.480833    0.183098    0.088273    0.016582    0.760997    
#> 118: 0.556621    1.000287    3.480111    0.173943    0.097812    0.015753    0.751838    
#> 119: 0.560418    1.017779    3.485009    0.176461    0.093435    0.014965    0.767038    
#> 120: 0.513617    0.974031    3.476940    0.167638    0.095923    0.014217    0.750779    
#> 121: 0.544554    1.026159    3.472989    0.159256    0.107420    0.013506    0.764430    
#> 122: 0.563114    0.981431    3.483906    0.160368    0.102049    0.012831    0.761205    
#> 123: 0.605156    1.012499    3.477096    0.177839    0.096946    0.012189    0.764171    
#> 124: 0.593722    1.031297    3.474606    0.199531    0.096437    0.011580    0.756148    
#> 125: 0.601910    1.015108    3.466925    0.221048    0.113028    0.011001    0.743691    
#> 126: 0.506583    1.023942    3.449782    0.230769    0.107377    0.010852    0.742908    
#> 127: 0.524606    1.006108    3.450609    0.231049    0.102008    0.013046    0.769092    
#> 128: 0.527769    0.999254    3.469393    0.219497    0.114357    0.012393    0.746871    
#> 129: 0.561285    1.000862    3.467728    0.208522    0.115690    0.011774    0.750700    
#> 130: 0.543878    1.030207    3.464635    0.210507    0.122705    0.011185    0.732351    
#> 131: 0.542719    1.014826    3.453682    0.203126    0.136475    0.010626    0.744773    
#> 132: 0.494415    1.034214    3.441940    0.192970    0.129652    0.010094    0.766665    
#> 133: 0.521830    1.028861    3.450010    0.201079    0.123169    0.009590    0.761999    
#> 134: 0.548850    1.006167    3.465130    0.191025    0.117011    0.011060    0.754467    
#> 135: 0.514062    1.013044    3.467056    0.181474    0.111640    0.010507    0.754507    
#> 136: 0.545651    0.994612    3.465066    0.172400    0.107288    0.009981    0.749836    
#> 137: 0.557753    0.992312    3.471081    0.163780    0.106269    0.009482    0.754925    
#> 138: 0.546050    1.030787    3.465696    0.155591    0.108607    0.009008    0.759862    
#> 139: 0.567935    1.003465    3.475639    0.149302    0.110893    0.008558    0.747044    
#> 140: 0.544413    1.015308    3.478634    0.156902    0.111211    0.008547    0.749548    
#> 141: 0.543926    1.001415    3.479083    0.149057    0.108330    0.008195    0.747776    
#> 142: 0.578311    0.961811    3.491057    0.162047    0.102914    0.007786    0.769079    
#> 143: 0.541252    0.982328    3.488793    0.192393    0.097768    0.009385    0.757461    
#> 144: 0.577006    0.999960    3.486504    0.182773    0.092880    0.010902    0.745386    
#> 145: 0.549826    1.010945    3.476050    0.173635    0.088236    0.011551    0.740440    
#> 146: 0.532058    1.015297    3.475131    0.185898    0.090418    0.010974    0.748257    
#> 147: 0.480797    1.023844    3.460693    0.176603    0.098243    0.012923    0.730427    
#> 148: 0.538251    1.026315    3.478315    0.167773    0.093331    0.013341    0.730893    
#> 149: 0.553274    1.014373    3.475323    0.159384    0.088664    0.012674    0.766819    
#> 150: 0.589595    0.987244    3.474112    0.151415    0.095556    0.012226    0.776215    
#> 151: 0.524175    1.011820    3.472282    0.143844    0.090779    0.011615    0.751496    
#> 152: 0.539044    1.003140    3.479265    0.151690    0.079427    0.008826    0.756118    
#> 153: 0.545086    1.001176    3.484185    0.168829    0.068349    0.011958    0.773622    
#> 154: 0.596148    1.009559    3.497464    0.155889    0.088101    0.012180    0.769779    
#> 155: 0.562107    0.991667    3.483356    0.134341    0.091546    0.012446    0.758504    
#> 156: 0.553718    1.015229    3.478352    0.123154    0.081368    0.015227    0.761712    
#> 157: 0.560445    0.993861    3.492359    0.128947    0.091583    0.012478    0.779388    
#> 158: 0.593267    1.003465    3.488691    0.136363    0.084395    0.010598    0.747290    
#> 159: 0.567559    1.002078    3.488636    0.150853    0.091701    0.012743    0.741261    
#> 160: 0.629122    0.980722    3.502339    0.179975    0.085547    0.015346    0.742320    
#> 161: 0.604219    0.988929    3.496303    0.161458    0.091097    0.013024    0.771490    
#> 162: 0.592972    1.017854    3.478047    0.154850    0.093608    0.011436    0.756599    
#> 163: 0.607750    0.999822    3.477488    0.136285    0.097989    0.012322    0.755117    
#> 164: 0.592192    0.992721    3.478791    0.136550    0.090012    0.012548    0.762995    
#> 165: 0.608203    0.983524    3.491039    0.142492    0.079987    0.013574    0.757689    
#> 166: 0.636426    1.010370    3.495290    0.141094    0.060963    0.015104    0.779610    
#> 167: 0.615944    1.009613    3.502087    0.161408    0.072214    0.014320    0.760537    
#> 168: 0.627788    1.025619    3.499975    0.164159    0.081652    0.012714    0.750625    
#> 169: 0.591373    1.034545    3.488667    0.156689    0.081236    0.013014    0.770106    
#> 170: 0.562243    0.994691    3.482479    0.166715    0.090345    0.012911    0.751002    
#> 171: 0.566442    0.996718    3.483974    0.155524    0.067474    0.012550    0.736576    
#> 172: 0.537836    1.020902    3.467500    0.140377    0.089239    0.009566    0.748732    
#> 173: 0.538413    1.011750    3.464195    0.157095    0.094580    0.010353    0.741549    
#> 174: 0.548009    1.009693    3.476262    0.163140    0.077499    0.011458    0.748805    
#> 175: 0.536810    1.009219    3.466691    0.162374    0.086388    0.011702    0.748396    
#> 176: 0.517497    1.034372    3.469155    0.135194    0.092982    0.011240    0.758734    
#> 177: 0.544324    1.015289    3.480825    0.132173    0.075389    0.014277    0.761688    
#> 178: 0.577711    0.997079    3.483082    0.152599    0.106729    0.010971    0.768865    
#> 179: 0.583728    1.022540    3.478745    0.146213    0.125903    0.010376    0.773926    
#> 180: 0.569466    1.007565    3.488871    0.125439    0.095715    0.009187    0.759306    
#> 181: 0.568084    0.995584    3.471215    0.160299    0.104043    0.011093    0.729635    
#> 182: 0.544544    0.997559    3.468597    0.174410    0.103751    0.012078    0.753451    
#> 183: 0.551382    1.018776    3.472096    0.175242    0.102715    0.013569    0.741223    
#> 184: 0.573394    1.000139    3.479513    0.135050    0.105033    0.012572    0.752159    
#> 185: 0.534071    1.027471    3.473328    0.170000    0.103327    0.013479    0.758830    
#> 186: 0.513880    1.034716    3.459518    0.166312    0.112225    0.013330    0.740746    
#> 187: 0.546950    1.030148    3.470666    0.151937    0.101592    0.011727    0.743865    
#> 188: 0.532770    1.033522    3.472713    0.133478    0.092192    0.015155    0.751350    
#> 189: 0.553382    1.024385    3.480508    0.137959    0.097249    0.012643    0.766865    
#> 190: 0.533419    1.022530    3.484123    0.135703    0.083586    0.013370    0.772462    
#> 191: 0.487232    1.008366    3.461294    0.147593    0.085086    0.011305    0.767856    
#> 192: 0.505355    1.028196    3.460175    0.146868    0.078799    0.011466    0.740720    
#> 193: 0.529025    1.037004    3.462103    0.124520    0.090054    0.013099    0.736938    
#> 194: 0.531405    1.033187    3.461354    0.159373    0.073133    0.015379    0.781112    
#> 195: 0.477950    1.040413    3.455320    0.140576    0.085308    0.016463    0.759611    
#> 196: 0.501533    1.022141    3.469756    0.138018    0.084622    0.020381    0.759787    
#> 197: 0.519234    1.015799    3.487005    0.165282    0.084852    0.020103    0.758091    
#> 198: 0.577914    0.991595    3.473391    0.174363    0.082429    0.017872    0.752081    
#> 199: 0.534445    0.996614    3.476194    0.191700    0.078608    0.016844    0.737103    
#> 200: 0.550308    1.005153    3.484027    0.205589    0.084695    0.017500    0.764645    
#> 201: 0.557352    1.002036    3.488747    0.197485    0.084760    0.017279    0.758108    
#> 202: 0.561940    0.999185    3.486586    0.195737    0.080195    0.016659    0.758969    
#> 203: 0.570678    1.001366    3.484185    0.195039    0.082759    0.016047    0.754185    
#> 204: 0.586386    0.991963    3.487055    0.197856    0.088273    0.015214    0.752001    
#> 205: 0.584106    0.996992    3.485618    0.198607    0.089742    0.015586    0.753215    
#> 206: 0.579477    0.999718    3.485026    0.198625    0.088680    0.015153    0.754121    
#> 207: 0.576038    1.001225    3.483295    0.203436    0.086217    0.015188    0.753743    
#> 208: 0.575515    1.002141    3.483333    0.200096    0.085479    0.015041    0.753058    
#> 209: 0.578429    1.002328    3.482776    0.196700    0.086593    0.014593    0.753044    
#> 210: 0.580809    1.001795    3.482314    0.196147    0.086794    0.014289    0.752835    
#> 211: 0.581723    1.003531    3.482829    0.195011    0.087826    0.013856    0.752160    
#> 212: 0.582987    1.002906    3.483128    0.194784    0.087606    0.013670    0.752424    
#> 213: 0.584678    1.001271    3.483465    0.195100    0.087711    0.013437    0.755027    
#> 214: 0.585625    1.000920    3.483257    0.194566    0.087492    0.013251    0.755569    
#> 215: 0.584693    1.001298    3.483757    0.192097    0.087045    0.013254    0.756513    
#> 216: 0.583982    1.001089    3.483628    0.189135    0.087358    0.013231    0.757886    
#> 217: 0.582526    1.002262    3.483389    0.186024    0.088049    0.013201    0.756714    
#> 218: 0.582725    1.002823    3.482919    0.184424    0.088009    0.013117    0.755876    
#> 219: 0.580568    1.002831    3.481899    0.181868    0.087946    0.012946    0.756602    
#> 220: 0.578761    1.003753    3.481577    0.181300    0.088223    0.012842    0.755929    
#> 221: 0.577127    1.004454    3.481208    0.180457    0.088680    0.012672    0.755669    
#> 222: 0.576981    1.004148    3.481108    0.179184    0.088616    0.012619    0.755719    
#> 223: 0.577210    1.004121    3.480948    0.177500    0.088571    0.012549    0.755848    
#> 224: 0.577707    1.004498    3.481100    0.177230    0.088520    0.012510    0.755979    
#> 225: 0.577315    1.003404    3.481501    0.175616    0.088263    0.012511    0.756652    
#> 226: 0.576868    1.002312    3.481300    0.174578    0.088389    0.012533    0.756891    
#> 227: 0.575048    1.001404    3.481342    0.173564    0.088753    0.012546    0.757298    
#> 228: 0.572613    1.002572    3.480555    0.172490    0.088916    0.012496    0.757329    
#> 229: 0.571480    1.002218    3.480284    0.171186    0.088698    0.012565    0.756582    
#> 230: 0.571855    1.001689    3.480425    0.170538    0.088586    0.012592    0.756535    
#> 231: 0.573003    1.001881    3.481002    0.170310    0.088643    0.012722    0.756504    
#> 232: 0.572334    1.002151    3.481525    0.169163    0.088669    0.012789    0.755956    
#> 233: 0.572394    1.001432    3.481891    0.167923    0.088628    0.012775    0.755730    
#> 234: 0.572047    1.000848    3.482100    0.167079    0.088606    0.012837    0.755059    
#> 235: 0.572524    1.000657    3.482093    0.165803    0.088309    0.012908    0.754888    
#> 236: 0.572337    1.001147    3.481984    0.165488    0.088186    0.012898    0.755440    
#> 237: 0.573354    1.001048    3.482083    0.164279    0.087909    0.012930    0.756499    
#> 238: 0.573733    1.000768    3.482282    0.162253    0.087775    0.012913    0.757565    
#> 239: 0.574061    1.001604    3.482412    0.161015    0.087694    0.012895    0.757806    
#> 240: 0.573957    1.001379    3.482561    0.161272    0.087833    0.012846    0.757449    
#> 241: 0.573701    1.000432    3.482892    0.160865    0.088081    0.012825    0.757390    
#> 242: 0.574110    0.999377    3.482987    0.160242    0.088015    0.012791    0.757748    
#> 243: 0.572980    0.999533    3.482972    0.160087    0.088152    0.012785    0.757847    
#> 244: 0.572620    0.999357    3.483153    0.160061    0.087757    0.012829    0.758103    
#> 245: 0.572579    0.998998    3.483358    0.160156    0.087740    0.012794    0.758210    
#> 246: 0.572798    0.998607    3.483587    0.160091    0.087820    0.012736    0.758186    
#> 247: 0.572519    0.998150    3.483874    0.160356    0.088127    0.012735    0.757808    
#> 248: 0.572334    0.998617    3.483656    0.160882    0.088256    0.012721    0.757451    
#> 249: 0.571657    0.998808    3.483665    0.161484    0.088394    0.012717    0.757723    
#> 250: 0.572123    0.999094    3.483856    0.161726    0.088589    0.012769    0.757765    
#> 251: 0.572925    0.999812    3.484101    0.161610    0.088831    0.012773    0.757871    
#> 252: 0.573423    0.999876    3.484402    0.161010    0.088907    0.012788    0.758043    
#> 253: 0.573693    0.999653    3.484428    0.161157    0.088782    0.012840    0.758141    
#> 254: 0.573432    1.000188    3.484424    0.161464    0.088752    0.012880    0.757942    
#> 255: 0.573165    1.000516    3.484539    0.161893    0.088551    0.012957    0.758091    
#> 256: 0.573150    1.000390    3.484407    0.161946    0.088486    0.013025    0.758253    
#> 257: 0.572878    1.000075    3.484210    0.162281    0.088848    0.013009    0.758495    
#> 258: 0.573413    0.999401    3.484339    0.162793    0.088932    0.013054    0.758467    
#> 259: 0.573786    0.999280    3.484403    0.162930    0.088936    0.013111    0.758381    
#> 260: 0.573833    0.999486    3.484546    0.162354    0.088966    0.013117    0.757814    
#> 261: 0.574055    0.999343    3.484819    0.161902    0.088989    0.013148    0.757790    
#> 262: 0.574772    0.999023    3.485028    0.161989    0.088970    0.013214    0.757864    
#> 263: 0.574982    0.999168    3.485033    0.161935    0.089072    0.013251    0.757897    
#> 264: 0.574767    0.999318    3.484870    0.162011    0.089252    0.013257    0.757965    
#> 265: 0.574787    0.999547    3.484723    0.162484    0.089235    0.013328    0.758009    
#> 266: 0.575536    0.999673    3.484717    0.163043    0.089042    0.013336    0.758077    
#> 267: 0.575801    0.999772    3.484772    0.163743    0.089029    0.013313    0.757990    
#> 268: 0.575614    0.999603    3.484582    0.164722    0.088970    0.013297    0.757907    
#> 269: 0.575866    0.999776    3.484424    0.165850    0.089032    0.013299    0.758002    
#> 270: 0.576434    0.999863    3.484201    0.166405    0.088924    0.013289    0.757893    
#> 271: 0.576271    0.999568    3.483991    0.166942    0.089018    0.013281    0.758097    
#> 272: 0.576174    0.999434    3.483814    0.167065    0.089071    0.013325    0.758189    
#> 273: 0.575836    0.999871    3.483734    0.167423    0.089076    0.013332    0.758021    
#> 274: 0.575273    1.000172    3.483704    0.167421    0.089247    0.013311    0.757803    
#> 275: 0.575295    1.000525    3.483508    0.167109    0.089398    0.013311    0.757665    
#> 276: 0.575114    1.000910    3.483597    0.167403    0.089452    0.013311    0.757554    
#> 277: 0.575218    1.000995    3.483705    0.167517    0.089539    0.013303    0.757464    
#> 278: 0.574949    1.001064    3.483682    0.167416    0.089587    0.013245    0.757254    
#> 279: 0.574452    1.000985    3.483664    0.167347    0.089418    0.013225    0.757231    
#> 280: 0.574161    1.001361    3.483637    0.167381    0.089356    0.013198    0.757106    
#> 281: 0.574007    1.001495    3.483664    0.167209    0.089506    0.013173    0.756980    
#> 282: 0.573990    1.001609    3.483735    0.167224    0.089703    0.013140    0.757047    
#> 283: 0.574014    1.001608    3.483709    0.166718    0.089987    0.013127    0.757200    
#> 284: 0.574312    1.001497    3.483772    0.166600    0.090012    0.013101    0.757002    
#> 285: 0.574331    1.001539    3.483610    0.166203    0.090083    0.013098    0.757025    
#> 286: 0.574325    1.001597    3.483510    0.165934    0.090258    0.013088    0.756882    
#> 287: 0.574097    1.001653    3.483364    0.165923    0.090108    0.013106    0.756810    
#> 288: 0.574237    1.001464    3.483384    0.165757    0.090222    0.013135    0.756670    
#> 289: 0.574545    1.001361    3.483504    0.165923    0.090273    0.013148    0.756547    
#> 290: 0.574726    1.001294    3.483558    0.165636    0.090141    0.013179    0.756696    
#> 291: 0.574995    1.001442    3.483613    0.165373    0.090008    0.013210    0.756458    
#> 292: 0.575000    1.001425    3.483696    0.165768    0.090004    0.013202    0.756335    
#> 293: 0.574930    1.001311    3.483657    0.166242    0.090045    0.013180    0.756169    
#> 294: 0.574863    1.001547    3.483539    0.166704    0.090084    0.013159    0.755986    
#> 295: 0.574846    1.001204    3.483527    0.166472    0.090066    0.013180    0.755803    
#> 296: 0.574865    1.001020    3.483523    0.166127    0.090082    0.013222    0.755839    
#> 297: 0.575262    1.000934    3.483584    0.166104    0.090107    0.013231    0.755746    
#> 298: 0.575451    1.000695    3.483650    0.166230    0.090103    0.013216    0.755651    
#> 299: 0.575604    1.000653    3.483645    0.166456    0.090114    0.013181    0.755546    
#> 300: 0.575594    1.000468    3.483714    0.166588    0.090162    0.013168    0.755354    
#> 301: 0.575488    1.000415    3.483598    0.166854    0.090163    0.013132    0.755383    
#> 302: 0.575476    1.000353    3.483516    0.166972    0.090131    0.013155    0.755294    
#> 303: 0.575233    1.000643    3.483426    0.166828    0.089946    0.013171    0.755175    
#> 304: 0.575289    1.001064    3.483266    0.166957    0.089927    0.013182    0.755092    
#> 305: 0.574829    1.000941    3.483119    0.167405    0.090080    0.013190    0.754909    
#> 306: 0.574413    1.000868    3.482958    0.167584    0.089955    0.013202    0.754872    
#> 307: 0.574563    1.000918    3.482931    0.167915    0.089797    0.013195    0.754857    
#> 308: 0.574513    1.000639    3.482930    0.168028    0.089665    0.013168    0.754995    
#> 309: 0.574309    1.000445    3.482830    0.168076    0.089710    0.013173    0.755186    
#> 310: 0.574202    1.000299    3.482642    0.167822    0.089859    0.013144    0.755217    
#> 311: 0.574184    1.000355    3.482673    0.167999    0.089830    0.013155    0.755041    
#> 312: 0.574289    1.000273    3.482671    0.167911    0.089868    0.013163    0.755065    
#> 313: 0.574196    1.000016    3.482626    0.167738    0.089827    0.013147    0.755179    
#> 314: 0.573895    1.000013    3.482530    0.167934    0.089784    0.013151    0.755139    
#> 315: 0.573619    1.000141    3.482511    0.168213    0.089751    0.013163    0.755117    
#> 316: 0.573559    1.000246    3.482468    0.168539    0.089666    0.013169    0.755148    
#> 317: 0.573404    1.000194    3.482443    0.168725    0.089563    0.013169    0.755247    
#> 318: 0.573327    1.000277    3.482303    0.168633    0.089474    0.013180    0.755167    
#> 319: 0.573230    1.000260    3.482275    0.168506    0.089332    0.013182    0.755142    
#> 320: 0.572682    1.000474    3.482110    0.168486    0.089308    0.013169    0.755184    
#> 321: 0.572128    1.000716    3.481884    0.168324    0.089361    0.013171    0.755281    
#> 322: 0.571846    1.000879    3.481723    0.168359    0.089395    0.013150    0.755267    
#> 323: 0.571228    1.000964    3.481658    0.168530    0.089438    0.013151    0.755377    
#> 324: 0.571204    1.000930    3.481744    0.168602    0.089325    0.013151    0.755228    
#> 325: 0.571101    1.001155    3.481687    0.168728    0.089253    0.013165    0.754974    
#> 326: 0.571272    1.001067    3.481667    0.168912    0.089256    0.013159    0.755004    
#> 327: 0.571390    1.001106    3.481631    0.168956    0.089342    0.013138    0.755026    
#> 328: 0.571523    1.001196    3.481616    0.169162    0.089321    0.013105    0.754977    
#> 329: 0.571722    1.001254    3.481686    0.169249    0.089314    0.013104    0.754900    
#> 330: 0.571622    1.001084    3.481782    0.169225    0.089442    0.013125    0.754842    
#> 331: 0.571829    1.001071    3.481858    0.169388    0.089586    0.013121    0.754691    
#> 332: 0.572029    1.000890    3.481978    0.169755    0.089575    0.013140    0.754563    
#> 333: 0.571932    1.000856    3.481893    0.169734    0.089602    0.013111    0.754564    
#> 334: 0.571830    1.000820    3.481790    0.169548    0.089613    0.013078    0.754611    
#> 335: 0.571651    1.000984    3.481682    0.169412    0.089581    0.013053    0.754746    
#> 336: 0.571318    1.001283    3.481603    0.169203    0.089618    0.013055    0.754837    
#> 337: 0.571194    1.001588    3.481525    0.169002    0.089643    0.013037    0.754901    
#> 338: 0.571192    1.001598    3.481616    0.168865    0.089714    0.013019    0.755015    
#> 339: 0.571116    1.001656    3.481652    0.168673    0.089718    0.012996    0.754978    
#> 340: 0.571014    1.001433    3.481695    0.168645    0.089822    0.012976    0.754916    
#> 341: 0.570973    1.001455    3.481673    0.168675    0.089983    0.012957    0.754779    
#> 342: 0.570743    1.001301    3.481674    0.168595    0.090095    0.012961    0.754670    
#> 343: 0.570533    1.001225    3.481671    0.168682    0.090124    0.012967    0.754524    
#> 344: 0.570647    1.001249    3.481722    0.168867    0.090144    0.012991    0.754488    
#> 345: 0.570958    1.001150    3.481795    0.168788    0.090131    0.013022    0.754321    
#> 346: 0.571042    1.001164    3.481722    0.168808    0.090143    0.013030    0.754148    
#> 347: 0.571032    1.001083    3.481638    0.168653    0.090184    0.013016    0.754161    
#> 348: 0.570780    1.001271    3.481501    0.168646    0.090199    0.013024    0.754217    
#> 349: 0.570801    1.001373    3.481412    0.168621    0.090256    0.013023    0.754311    
#> 350: 0.570756    1.001277    3.481415    0.168489    0.090239    0.013021    0.754328    
#> 351: 0.570701    1.001280    3.481387    0.168459    0.090165    0.013005    0.754362    
#> 352: 0.570356    1.001478    3.481384    0.168463    0.090145    0.012990    0.754558    
#> 353: 0.570234    1.001601    3.481324    0.168307    0.090170    0.012977    0.754574    
#> 354: 0.570121    1.001723    3.481184    0.168161    0.090216    0.012957    0.754564    
#> 355: 0.570386    1.001664    3.481181    0.168192    0.090280    0.012946    0.754580    
#> 356: 0.570320    1.001561    3.481228    0.168332    0.090253    0.012964    0.754547    
#> 357: 0.570380    1.001754    3.481207    0.168617    0.090363    0.012970    0.754362    
#> 358: 0.570419    1.001932    3.481259    0.168575    0.090456    0.012963    0.754255    
#> 359: 0.570298    1.002092    3.481248    0.168582    0.090437    0.012959    0.754255    
#> 360: 0.570176    1.002163    3.481152    0.168582    0.090442    0.012961    0.754169    
#> 361: 0.569969    1.002139    3.481147    0.168578    0.090531    0.012944    0.754118    
#> 362: 0.569877    1.002039    3.481118    0.168565    0.090527    0.012929    0.753991    
#> 363: 0.569976    1.002006    3.481131    0.168679    0.090468    0.012909    0.753856    
#> 364: 0.570102    1.002017    3.481114    0.168650    0.090443    0.012906    0.753838    
#> 365: 0.570077    1.001930    3.481124    0.168631    0.090358    0.012911    0.753853    
#> 366: 0.569856    1.001920    3.481003    0.168404    0.090258    0.012897    0.753936    
#> 367: 0.569492    1.001993    3.480920    0.168128    0.090203    0.012883    0.754052    
#> 368: 0.569380    1.002051    3.480841    0.167943    0.090189    0.012880    0.753948    
#> 369: 0.569131    1.002081    3.480776    0.167922    0.090168    0.012872    0.753990    
#> 370: 0.568991    1.002085    3.480758    0.167892    0.090248    0.012865    0.754070    
#> 371: 0.568723    1.002031    3.480620    0.167787    0.090336    0.012843    0.754070    
#> 372: 0.568511    1.002040    3.480562    0.167804    0.090362    0.012836    0.754055    
#> 373: 0.568246    1.002173    3.480485    0.167719    0.090368    0.012838    0.754025    
#> 374: 0.567982    1.002258    3.480371    0.167586    0.090374    0.012823    0.754068    
#> 375: 0.567752    1.002385    3.480292    0.167549    0.090428    0.012818    0.754077    
#> 376: 0.567524    1.002382    3.480256    0.167477    0.090348    0.012816    0.753954    
#> 377: 0.567294    1.002509    3.480241    0.167473    0.090276    0.012825    0.753872    
#> 378: 0.567096    1.002584    3.480137    0.167648    0.090193    0.012835    0.753847    
#> 379: 0.566926    1.002545    3.480143    0.167752    0.090247    0.012834    0.753726    
#> 380: 0.566683    1.002545    3.480138    0.167685    0.090215    0.012825    0.753687    
#> 381: 0.566678    1.002573    3.480092    0.167737    0.090240    0.012830    0.753704    
#> 382: 0.566661    1.002586    3.480090    0.167607    0.090255    0.012819    0.753633    
#> 383: 0.566826    1.002608    3.480152    0.167835    0.090241    0.012819    0.753573    
#> 384: 0.566710    1.002522    3.480174    0.167816    0.090177    0.012799    0.753609    
#> 385: 0.566835    1.002441    3.480239    0.167932    0.090155    0.012789    0.753586    
#> 386: 0.567053    1.002596    3.480271    0.168164    0.090226    0.012783    0.753479    
#> 387: 0.567157    1.002749    3.480293    0.168185    0.090266    0.012776    0.753471    
#> 388: 0.567087    1.002967    3.480238    0.168205    0.090354    0.012780    0.753379    
#> 389: 0.567132    1.002737    3.480290    0.168080    0.090439    0.012788    0.753422    
#> 390: 0.566997    1.002700    3.480276    0.167943    0.090425    0.012788    0.753459    
#> 391: 0.567045    1.002717    3.480286    0.167856    0.090369    0.012781    0.753456    
#> 392: 0.567091    1.002705    3.480342    0.167838    0.090348    0.012774    0.753461    
#> 393: 0.566896    1.002651    3.480271    0.167825    0.090303    0.012770    0.753369    
#> 394: 0.566751    1.002670    3.480180    0.167764    0.090214    0.012781    0.753330    
#> 395: 0.566933    1.002760    3.480201    0.167917    0.090227    0.012789    0.753217    
#> 396: 0.567195    1.002794    3.480249    0.167984    0.090189    0.012794    0.753127    
#> 397: 0.567322    1.002723    3.480307    0.168158    0.090167    0.012801    0.753018    
#> 398: 0.567506    1.002664    3.480360    0.168226    0.090106    0.012817    0.753006    
#> 399: 0.567757    1.002627    3.480461    0.168327    0.090084    0.012828    0.752913    
#> 400: 0.568009    1.002694    3.480523    0.168378    0.090014    0.012837    0.752931    
#> 401: 0.568042    1.002687    3.480558    0.168408    0.089977    0.012844    0.752949    
#> 402: 0.567914    1.002778    3.480530    0.168426    0.089998    0.012849    0.752948    
#> 403: 0.568030    1.002701    3.480537    0.168494    0.090013    0.012855    0.752876    
#> 404: 0.568040    1.002677    3.480462    0.168667    0.090055    0.012844    0.752768    
#> 405: 0.567995    1.002736    3.480471    0.168555    0.090137    0.012841    0.752741    
#> 406: 0.568042    1.002843    3.480467    0.168675    0.090208    0.012838    0.752757    
#> 407: 0.568091    1.002859    3.480530    0.168836    0.090229    0.012839    0.752660    
#> 408: 0.568112    1.002861    3.480572    0.168863    0.090190    0.012841    0.752719    
#> 409: 0.567901    1.002805    3.480485    0.168971    0.090225    0.012834    0.752660    
#> 410: 0.567849    1.002844    3.480369    0.169003    0.090263    0.012828    0.752712    
#> 411: 0.567766    1.002691    3.480317    0.169043    0.090315    0.012825    0.752720    
#> 412: 0.567864    1.002762    3.480308    0.169049    0.090282    0.012828    0.752693    
#> 413: 0.567940    1.002827    3.480247    0.169140    0.090236    0.012830    0.752659    
#> 414: 0.567802    1.002817    3.480253    0.169125    0.090185    0.012829    0.752740    
#> 415: 0.567781    1.002704    3.480244    0.169010    0.090153    0.012817    0.752706    
#> 416: 0.568030    1.002754    3.480295    0.169057    0.090154    0.012812    0.752619    
#> 417: 0.568154    1.002743    3.480321    0.168857    0.090157    0.012824    0.752620    
#> 418: 0.568004    1.002819    3.480318    0.168755    0.090078    0.012843    0.752640    
#> 419: 0.567981    1.002997    3.480316    0.168700    0.090099    0.012874    0.752673    
#> 420: 0.568115    1.003110    3.480343    0.168549    0.090102    0.012889    0.752611    
#> 421: 0.568023    1.003174    3.480360    0.168374    0.090093    0.012907    0.752550    
#> 422: 0.568180    1.003071    3.480421    0.168381    0.090106    0.012912    0.752546    
#> 423: 0.568414    1.002894    3.480472    0.168268    0.090117    0.012906    0.752615    
#> 424: 0.568473    1.002767    3.480485    0.168096    0.090196    0.012899    0.752585    
#> 425: 0.568683    1.002757    3.480524    0.167955    0.090263    0.012895    0.752684    
#> 426: 0.568870    1.002842    3.480533    0.167961    0.090268    0.012897    0.752734    
#> 427: 0.568776    1.002875    3.480553    0.167968    0.090204    0.012894    0.752706    
#> 428: 0.568710    1.003009    3.480562    0.168103    0.090152    0.012895    0.752706    
#> 429: 0.568639    1.003061    3.480555    0.168077    0.090141    0.012903    0.752723    
#> 430: 0.568637    1.003152    3.480518    0.168004    0.090156    0.012906    0.752697    
#> 431: 0.568544    1.003126    3.480490    0.167946    0.090124    0.012908    0.752597    
#> 432: 0.568496    1.003173    3.480516    0.167835    0.090154    0.012917    0.752492    
#> 433: 0.568502    1.003282    3.480542    0.167638    0.090210    0.012923    0.752507    
#> 434: 0.568337    1.003157    3.480573    0.167516    0.090175    0.012929    0.752548    
#> 435: 0.568376    1.003158    3.480542    0.167391    0.090189    0.012930    0.752570    
#> 436: 0.568421    1.003017    3.480608    0.167356    0.090369    0.012933    0.752547    
#> 437: 0.568298    1.002936    3.480584    0.167324    0.090441    0.012933    0.752586    
#> 438: 0.568366    1.003045    3.480604    0.167282    0.090425    0.012925    0.752596    
#> 439: 0.568355    1.003143    3.480619    0.167209    0.090431    0.012916    0.752524    
#> 440: 0.568316    1.003198    3.480664    0.167103    0.090357    0.012916    0.752489    
#> 441: 0.568376    1.003186    3.480707    0.167155    0.090356    0.012914    0.752424    
#> 442: 0.568302    1.003220    3.480709    0.167199    0.090330    0.012908    0.752326    
#> 443: 0.568282    1.003252    3.480709    0.167270    0.090250    0.012907    0.752314    
#> 444: 0.568272    1.003260    3.480685    0.167296    0.090264    0.012902    0.752313    
#> 445: 0.568218    1.003305    3.480659    0.167288    0.090251    0.012893    0.752316    
#> 446: 0.568032    1.003371    3.480590    0.167251    0.090296    0.012887    0.752312    
#> 447: 0.568037    1.003508    3.480555    0.167193    0.090292    0.012874    0.752296    
#> 448: 0.567843    1.003472    3.480576    0.167188    0.090317    0.012865    0.752228    
#> 449: 0.567777    1.003556    3.480639    0.167119    0.090333    0.012868    0.752184    
#> 450: 0.567650    1.003544    3.480612    0.167100    0.090308    0.012878    0.752169    
#> 451: 0.567667    1.003535    3.480578    0.167182    0.090269    0.012883    0.752217    
#> 452: 0.567629    1.003576    3.480533    0.167396    0.090246    0.012884    0.752138    
#> 453: 0.567493    1.003596    3.480462    0.167442    0.090264    0.012891    0.752051    
#> 454: 0.567366    1.003702    3.480417    0.167471    0.090291    0.012886    0.752011    
#> 455: 0.567336    1.003707    3.480368    0.167547    0.090231    0.012876    0.752051    
#> 456: 0.567262    1.003673    3.480335    0.167614    0.090219    0.012881    0.752108    
#> 457: 0.567259    1.003597    3.480389    0.167530    0.090159    0.012887    0.752102    
#> 458: 0.567241    1.003657    3.480414    0.167417    0.090104    0.012893    0.752075    
#> 459: 0.567053    1.003801    3.480371    0.167359    0.090029    0.012899    0.752095    
#> 460: 0.566801    1.003894    3.480267    0.167333    0.089993    0.012906    0.752139    
#> 461: 0.566595    1.003995    3.480200    0.167310    0.089948    0.012910    0.752230    
#> 462: 0.566385    1.004141    3.480156    0.167198    0.089916    0.012918    0.752301    
#> 463: 0.566302    1.004260    3.480140    0.167095    0.089898    0.012923    0.752281    
#> 464: 0.566328    1.004343    3.480138    0.167047    0.089843    0.012921    0.752246    
#> 465: 0.566344    1.004227    3.480137    0.167029    0.089794    0.012923    0.752224    
#> 466: 0.566350    1.004272    3.480081    0.166989    0.089810    0.012921    0.752188    
#> 467: 0.566268    1.004339    3.480055    0.167068    0.089791    0.012921    0.752112    
#> 468: 0.566419    1.004453    3.480080    0.167141    0.089802    0.012917    0.752192    
#> 469: 0.566495    1.004585    3.480097    0.167206    0.089866    0.012901    0.752211    
#> 470: 0.566531    1.004579    3.480110    0.167252    0.089857    0.012895    0.752161    
#> 471: 0.566478    1.004543    3.480124    0.167305    0.089804    0.012890    0.752098    
#> 472: 0.566527    1.004532    3.480136    0.167302    0.089822    0.012885    0.752094    
#> 473: 0.566461    1.004556    3.480124    0.167244    0.089820    0.012877    0.752088    
#> 474: 0.566433    1.004556    3.480113    0.167145    0.089832    0.012866    0.752145    
#> 475: 0.566433    1.004580    3.480096    0.167032    0.089775    0.012851    0.752182    
#> 476: 0.566412    1.004536    3.480090    0.166881    0.089790    0.012839    0.752265    
#> 477: 0.566337    1.004525    3.480117    0.166899    0.089795    0.012831    0.752230    
#> 478: 0.566286    1.004519    3.480140    0.166914    0.089729    0.012830    0.752294    
#> 479: 0.566321    1.004567    3.480171    0.167008    0.089761    0.012829    0.752277    
#> 480: 0.566304    1.004560    3.480200    0.166897    0.089796    0.012830    0.752359    
#> 481: 0.566085    1.004594    3.480126    0.166784    0.089834    0.012818    0.752365    
#> 482: 0.566189    1.004615    3.480101    0.166777    0.089866    0.012811    0.752483    
#> 483: 0.566157    1.004635    3.480104    0.166713    0.089916    0.012801    0.752500    
#> 484: 0.566158    1.004448    3.480116    0.166736    0.089910    0.012792    0.752539    
#> 485: 0.566223    1.004434    3.480120    0.166832    0.089964    0.012790    0.752548    
#> 486: 0.566321    1.004450    3.480140    0.166880    0.090030    0.012791    0.752543    
#> 487: 0.566484    1.004531    3.480194    0.166955    0.090064    0.012795    0.752512    
#> 488: 0.566476    1.004561    3.480210    0.167065    0.090094    0.012795    0.752475    
#> 489: 0.566569    1.004574    3.480201    0.167030    0.090107    0.012794    0.752485    
#> 490: 0.566636    1.004626    3.480193    0.166947    0.090145    0.012788    0.752497    
#> 491: 0.566611    1.004715    3.480240    0.166942    0.090152    0.012786    0.752477    
#> 492: 0.566626    1.004757    3.480253    0.166909    0.090139    0.012786    0.752583    
#> 493: 0.566554    1.004788    3.480249    0.166851    0.090147    0.012793    0.752617    
#> 494: 0.566613    1.004842    3.480220    0.166842    0.090168    0.012793    0.752583    
#> 495: 0.566640    1.004805    3.480257    0.166780    0.090167    0.012790    0.752571    
#> 496: 0.566792    1.004823    3.480257    0.166674    0.090158    0.012796    0.752583    
#> 497: 0.566780    1.004809    3.480239    0.166593    0.090112    0.012814    0.752622    
#> 498: 0.566848    1.004805    3.480203    0.166617    0.090140    0.012811    0.752601    
#> 499: 0.566882    1.004865    3.480177    0.166560    0.090080    0.012803    0.752609    
#> 500: 0.566914    1.004768    3.480153    0.166492    0.090053    0.012806    0.752551    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.278743    0.972016    3.443947    0.392401    0.084877    0.016800    1.659722    
#> 002: 0.380442    0.972214    3.451518    0.372781    0.080633    0.015960    1.176241    
#> 003: 0.438263    0.965136    3.439358    0.354142    0.076602    0.015162    0.944802    
#> 004: 0.379542    1.005743    3.431877    0.336435    0.072772    0.014789    0.869482    
#> 005: 0.411765    0.996011    3.417058    0.319613    0.081335    0.014050    0.823822    
#> 006: 0.405271    1.024300    3.418298    0.303633    0.077268    0.013669    0.797890    
#> 007: 0.394303    1.024480    3.423060    0.289745    0.073404    0.014075    0.798272    
#> 008: 0.367612    1.018696    3.409172    0.286195    0.069734    0.016128    0.812839    
#> 009: 0.326495    1.005363    3.408353    0.271885    0.066247    0.017081    0.812383    
#> 010: 0.361442    1.006769    3.402551    0.314495    0.068203    0.018456    0.816676    
#> 011: 0.406104    1.018042    3.403409    0.311984    0.068920    0.020458    0.836757    
#> 012: 0.430125    1.008282    3.413319    0.306681    0.065474    0.019435    0.789297    
#> 013: 0.358183    1.013209    3.408380    0.291347    0.062200    0.019419    0.812659    
#> 014: 0.421375    1.014127    3.419018    0.304673    0.072937    0.018448    0.813820    
#> 015: 0.429900    1.005679    3.433064    0.289439    0.069290    0.017526    0.788089    
#> 016: 0.427740    1.012801    3.433805    0.285112    0.065825    0.019799    0.798391    
#> 017: 0.422941    1.025228    3.433358    0.333849    0.062534    0.018809    0.776528    
#> 018: 0.401122    1.017721    3.410590    0.317157    0.059407    0.018244    0.789404    
#> 019: 0.367082    1.021584    3.406972    0.301299    0.056437    0.017331    0.785055    
#> 020: 0.375364    1.031469    3.407926    0.328362    0.053787    0.019607    0.787986    
#> 021: 0.440487    1.022125    3.420665    0.339419    0.051097    0.018843    0.789908    
#> 022: 0.457123    0.997966    3.445819    0.369778    0.048542    0.018851    0.768693    
#> 023: 0.528937    0.994655    3.464051    0.366884    0.050477    0.022456    0.801143    
#> 024: 0.540165    1.004068    3.455910    0.348540    0.047954    0.021483    0.797744    
#> 025: 0.490534    0.996307    3.450381    0.347990    0.045556    0.021199    0.804898    
#> 026: 0.455197    1.011692    3.430704    0.330591    0.043278    0.025005    0.821770    
#> 027: 0.423621    1.019148    3.434499    0.321583    0.050392    0.023755    0.837627    
#> 028: 0.460412    1.024087    3.427294    0.338437    0.048889    0.026401    0.800569    
#> 029: 0.492973    1.019489    3.421286    0.366795    0.048438    0.025081    0.812038    
#> 030: 0.469314    1.023146    3.430574    0.348455    0.058270    0.026633    0.794818    
#> 031: 0.444063    1.019330    3.426890    0.383982    0.055356    0.025301    0.785867    
#> 032: 0.434546    1.017908    3.433989    0.425428    0.056237    0.029028    0.773779    
#> 033: 0.419713    1.028190    3.418656    0.404156    0.053425    0.034694    0.790272    
#> 034: 0.452765    1.022159    3.432268    0.383948    0.050754    0.032959    0.795648    
#> 035: 0.456712    0.996421    3.436337    0.364751    0.048216    0.031311    0.781475    
#> 036: 0.447344    1.000692    3.425337    0.346513    0.045805    0.030215    0.797153    
#> 037: 0.419801    1.004462    3.427043    0.329188    0.043515    0.028704    0.808682    
#> 038: 0.407748    1.021309    3.410784    0.409486    0.044143    0.027269    0.805507    
#> 039: 0.416117    1.008502    3.420032    0.389012    0.053567    0.025905    0.780465    
#> 040: 0.396718    1.009189    3.424932    0.369561    0.050888    0.027471    0.786922    
#> 041: 0.418653    0.993269    3.431149    0.381453    0.048344    0.031306    0.785438    
#> 042: 0.437389    0.987222    3.427278    0.368431    0.045927    0.029741    0.783522    
#> 043: 0.413272    1.005232    3.414838    0.350009    0.046427    0.028254    0.767504    
#> 044: 0.394494    1.016315    3.412753    0.355633    0.044295    0.026841    0.785835    
#> 045: 0.417351    1.044552    3.409038    0.337851    0.048854    0.025499    0.769225    
#> 046: 0.424165    1.030500    3.421518    0.327488    0.046411    0.025292    0.783200    
#> 047: 0.415871    1.025998    3.413788    0.311114    0.044091    0.024027    0.781669    
#> 048: 0.437744    1.002858    3.426719    0.296486    0.041886    0.026191    0.791350    
#> 049: 0.413267    0.997828    3.434880    0.297045    0.042643    0.026126    0.820476    
#> 050: 0.486738    0.972297    3.443067    0.326666    0.046753    0.024991    0.822099    
#> 051: 0.469984    0.984348    3.431908    0.329410    0.052177    0.026768    0.812175    
#> 052: 0.477348    0.984694    3.443948    0.348781    0.052798    0.025430    0.782824    
#> 053: 0.446138    0.972988    3.426682    0.376945    0.053617    0.024837    0.774640    
#> 054: 0.387557    1.001475    3.430767    0.358098    0.050936    0.027931    0.795378    
#> 055: 0.411365    1.006823    3.420666    0.340193    0.048389    0.026534    0.796366    
#> 056: 0.439919    1.008311    3.428371    0.323397    0.051266    0.025207    0.808478    
#> 057: 0.396243    0.996244    3.434091    0.348291    0.048703    0.023947    0.805935    
#> 058: 0.429321    0.998622    3.426513    0.330876    0.046268    0.022750    0.816191    
#> 059: 0.414423    0.962422    3.432857    0.314333    0.043955    0.028205    0.808189    
#> 060: 0.386783    0.964923    3.430756    0.310150    0.041757    0.026795    0.844930    
#> 061: 0.451684    0.972564    3.444742    0.346122    0.042445    0.026277    0.848667    
#> 062: 0.459142    0.977177    3.449753    0.347071    0.040323    0.032244    0.832576    
#> 063: 0.486268    0.963703    3.441833    0.335550    0.038307    0.030631    0.831497    
#> 064: 0.466409    0.975643    3.442172    0.330443    0.036391    0.029100    0.833464    
#> 065: 0.450110    0.975012    3.427634    0.328420    0.034572    0.027645    0.801191    
#> 066: 0.460873    0.985854    3.432501    0.311999    0.032843    0.026263    0.809373    
#> 067: 0.421460    0.995062    3.430324    0.301894    0.037938    0.024950    0.797909    
#> 068: 0.380529    1.001501    3.437541    0.305543    0.041794    0.032831    0.788140    
#> 069: 0.396617    1.020595    3.422821    0.366630    0.039705    0.037299    0.805140    
#> 070: 0.433318    1.017969    3.432580    0.381254    0.037719    0.037639    0.782611    
#> 071: 0.371870    1.032226    3.409361    0.376841    0.042040    0.035757    0.794750    
#> 072: 0.368033    1.000733    3.411486    0.357999    0.039938    0.033970    0.805395    
#> 073: 0.427025    1.013535    3.425967    0.357372    0.039648    0.032271    0.787068    
#> 074: 0.396665    1.012908    3.420631    0.373540    0.039301    0.030658    0.781009    
#> 075: 0.460348    0.990292    3.455719    0.354863    0.037336    0.029125    0.802015    
#> 076: 0.483587    0.996262    3.464538    0.348094    0.035469    0.029139    0.802028    
#> 077: 0.536282    0.978236    3.456415    0.416182    0.043063    0.027682    0.789362    
#> 078: 0.517152    0.978284    3.454817    0.395373    0.040910    0.026298    0.783450    
#> 079: 0.485949    0.999191    3.450604    0.386775    0.038865    0.025865    0.822546    
#> 080: 0.531967    0.981545    3.466625    0.405132    0.036922    0.029670    0.816489    
#> 081: 0.503542    0.977851    3.453912    0.384876    0.035075    0.030312    0.799433    
#> 082: 0.460888    0.981548    3.449356    0.428622    0.037983    0.031699    0.805928    
#> 083: 0.461799    0.999553    3.441730    0.407191    0.036084    0.031764    0.795737    
#> 084: 0.431524    1.021830    3.425039    0.399937    0.042462    0.031672    0.785077    
#> 085: 0.431866    1.009042    3.431250    0.379940    0.044090    0.030089    0.785997    
#> 086: 0.419085    1.019803    3.426622    0.360943    0.041886    0.028584    0.795954    
#> 087: 0.406347    1.017108    3.417975    0.342896    0.042744    0.027155    0.785434    
#> 088: 0.384758    0.994609    3.420560    0.338466    0.049213    0.025797    0.793563    
#> 089: 0.391056    1.032413    3.401780    0.335925    0.057367    0.024508    0.790288    
#> 090: 0.382402    1.030483    3.400946    0.352380    0.054498    0.023282    0.783953    
#> 091: 0.379724    1.028235    3.384738    0.404902    0.051773    0.022118    0.782155    
#> 092: 0.374715    1.044205    3.385953    0.409368    0.049185    0.023087    0.789822    
#> 093: 0.359385    1.036339    3.396945    0.388900    0.047294    0.027683    0.792612    
#> 094: 0.355181    1.034952    3.396733    0.379490    0.044929    0.026299    0.781145    
#> 095: 0.382804    1.038422    3.402514    0.363650    0.042682    0.031314    0.790462    
#> 096: 0.328133    1.046498    3.405629    0.364445    0.048882    0.029748    0.780459    
#> 097: 0.409865    1.048556    3.411482    0.408788    0.054539    0.028261    0.777820    
#> 098: 0.412349    1.053323    3.421094    0.411017    0.051812    0.028226    0.777651    
#> 099: 0.391433    1.031564    3.395061    0.463833    0.049221    0.026815    0.770442    
#> 100: 0.358709    1.040070    3.394994    0.440641    0.046760    0.025474    0.775306    
#> 101: 0.334841    1.028580    3.371473    0.438512    0.044422    0.024201    0.778951    
#> 102: 0.353980    1.020113    3.375692    0.416586    0.042201    0.022990    0.789461    
#> 103: 0.359755    1.028865    3.394930    0.395757    0.044689    0.022196    0.790361    
#> 104: 0.359538    1.031590    3.409777    0.375969    0.042454    0.026654    0.810674    
#> 105: 0.385635    1.021628    3.412725    0.382021    0.044235    0.025959    0.799406    
#> 106: 0.369850    1.033839    3.402291    0.362920    0.042404    0.025192    0.793939    
#> 107: 0.439522    1.039883    3.425057    0.373328    0.041375    0.023933    0.801668    
#> 108: 0.400444    1.009938    3.422565    0.390790    0.047449    0.023505    0.812087    
#> 109: 0.420138    1.005172    3.433667    0.383375    0.050835    0.022329    0.789468    
#> 110: 0.454593    1.001814    3.425099    0.364206    0.050338    0.021213    0.791114    
#> 111: 0.409063    1.010549    3.426684    0.345996    0.047846    0.020152    0.773859    
#> 112: 0.402781    0.995408    3.413275    0.363125    0.045454    0.019145    0.805439    
#> 113: 0.400699    1.013706    3.424575    0.378619    0.043181    0.023221    0.782432    
#> 114: 0.438120    1.022082    3.429022    0.359688    0.041022    0.024178    0.807702    
#> 115: 0.426028    0.999156    3.429083    0.341704    0.039652    0.025793    0.802793    
#> 116: 0.424754    1.004847    3.431389    0.324619    0.048960    0.024504    0.789094    
#> 117: 0.426638    1.032567    3.438313    0.341500    0.046512    0.023278    0.803687    
#> 118: 0.444541    1.016154    3.432503    0.324425    0.055774    0.022114    0.795700    
#> 119: 0.453007    1.007251    3.439129    0.376468    0.052985    0.024599    0.803990    
#> 120: 0.438061    0.987755    3.439864    0.357645    0.052329    0.026267    0.794258    
#> 121: 0.455252    1.015640    3.433296    0.339762    0.053352    0.024953    0.813363    
#> 122: 0.458286    0.993814    3.435977    0.369323    0.050684    0.023706    0.799941    
#> 123: 0.532974    1.025886    3.433802    0.350857    0.052229    0.022520    0.807537    
#> 124: 0.452492    1.054618    3.430121    0.333314    0.055015    0.021394    0.806789    
#> 125: 0.437015    1.051511    3.423886    0.316649    0.052264    0.020325    0.806339    
#> 126: 0.377676    1.048864    3.404078    0.300816    0.052265    0.019308    0.825045    
#> 127: 0.433369    1.005731    3.421576    0.285775    0.049652    0.018343    0.831732    
#> 128: 0.399995    0.989111    3.432425    0.311761    0.047169    0.020417    0.815848    
#> 129: 0.420585    1.014064    3.434078    0.298026    0.044811    0.019396    0.825900    
#> 130: 0.450556    1.029622    3.432634    0.298007    0.054203    0.018426    0.790050    
#> 131: 0.420502    1.019954    3.418289    0.319531    0.051493    0.020960    0.787589    
#> 132: 0.367489    1.017407    3.405063    0.303554    0.048918    0.022148    0.801372    
#> 133: 0.345188    1.018070    3.406747    0.306962    0.048032    0.023591    0.806690    
#> 134: 0.440247    0.986507    3.432339    0.410520    0.045631    0.023987    0.805070    
#> 135: 0.444824    0.977527    3.439364    0.389994    0.043349    0.025589    0.803118    
#> 136: 0.447727    0.982614    3.432373    0.370495    0.043514    0.024310    0.801020    
#> 137: 0.499221    0.987943    3.440247    0.362950    0.047240    0.024044    0.810644    
#> 138: 0.455809    1.005996    3.427609    0.365603    0.049604    0.022980    0.788753    
#> 139: 0.433335    1.003449    3.436148    0.374279    0.047124    0.030000    0.803294    
#> 140: 0.437097    1.015931    3.432326    0.397726    0.044767    0.038285    0.822402    
#> 141: 0.421205    0.997631    3.422723    0.378236    0.042529    0.036371    0.800540    
#> 142: 0.427832    0.991050    3.452889    0.359324    0.040403    0.034552    0.813177    
#> 143: 0.415110    1.002711    3.443318    0.341358    0.038920    0.032825    0.809586    
#> 144: 0.480152    0.994714    3.462493    0.324290    0.039845    0.031184    0.792997    
#> 145: 0.426454    1.009953    3.434038    0.347715    0.038348    0.029624    0.795332    
#> 146: 0.421312    1.005824    3.433796    0.330491    0.047487    0.028143    0.802505    
#> 147: 0.388237    1.006781    3.427197    0.319652    0.045113    0.027516    0.804674    
#> 148: 0.396907    1.015875    3.429760    0.362107    0.046090    0.028874    0.778439    
#> 149: 0.396408    1.009313    3.428374    0.344002    0.043785    0.027430    0.783805    
#> 150: 0.434299    0.995665    3.423864    0.326802    0.046880    0.026258    0.801590    
#> 151: 0.352887    1.029122    3.405164    0.310462    0.046933    0.024945    0.794983    
#> 152: 0.384630    1.016786    3.414507    0.342324    0.046438    0.020750    0.795630    
#> 153: 0.396993    1.044017    3.422354    0.323947    0.057238    0.022296    0.803732    
#> 154: 0.442434    1.032465    3.421663    0.318278    0.051235    0.017674    0.815359    
#> 155: 0.409701    1.013131    3.422297    0.290597    0.058615    0.013153    0.780553    
#> 156: 0.427420    1.017147    3.428497    0.293970    0.060651    0.015158    0.801711    
#> 157: 0.439829    1.004137    3.437225    0.340812    0.064924    0.020059    0.783622    
#> 158: 0.436243    1.042961    3.425286    0.353003    0.067466    0.015491    0.787203    
#> 159: 0.400464    1.032111    3.429978    0.314455    0.064829    0.015660    0.786997    
#> 160: 0.443740    1.006669    3.448596    0.295545    0.054111    0.019305    0.786903    
#> 161: 0.442581    1.010255    3.442592    0.303719    0.045793    0.020705    0.781732    
#> 162: 0.406187    1.013694    3.414368    0.337095    0.037279    0.018208    0.807851    
#> 163: 0.440286    1.008932    3.413114    0.383241    0.045329    0.023298    0.773063    
#> 164: 0.441817    1.035167    3.416973    0.369922    0.050998    0.023101    0.770447    
#> 165: 0.390938    1.032960    3.410572    0.325450    0.054713    0.018019    0.779113    
#> 166: 0.420711    1.057819    3.407323    0.353407    0.060240    0.021031    0.783839    
#> 167: 0.428310    1.055471    3.419727    0.314207    0.056597    0.023499    0.795209    
#> 168: 0.443887    1.052426    3.420941    0.368230    0.054919    0.021148    0.786598    
#> 169: 0.407929    1.070536    3.404574    0.359618    0.055366    0.021450    0.809322    
#> 170: 0.428939    1.040294    3.413270    0.375070    0.054451    0.021474    0.792464    
#> 171: 0.420920    1.040782    3.411467    0.356994    0.061722    0.017962    0.767169    
#> 172: 0.387147    1.036846    3.417155    0.323851    0.059143    0.019567    0.777371    
#> 173: 0.371329    1.037130    3.404730    0.315227    0.052699    0.020125    0.773302    
#> 174: 0.400795    1.029389    3.415324    0.278293    0.058548    0.017908    0.792962    
#> 175: 0.394904    1.042943    3.409160    0.308237    0.047407    0.018191    0.803472    
#> 176: 0.397246    1.040767    3.419776    0.302455    0.060286    0.019981    0.784578    
#> 177: 0.411855    1.029208    3.419703    0.379234    0.060341    0.015961    0.785311    
#> 178: 0.411981    1.011580    3.417043    0.315201    0.055157    0.017021    0.802941    
#> 179: 0.442967    1.030861    3.415995    0.278257    0.043534    0.019883    0.819192    
#> 180: 0.392512    1.017637    3.425191    0.245998    0.042224    0.019579    0.817660    
#> 181: 0.391499    1.006865    3.407738    0.242351    0.030340    0.019611    0.828964    
#> 182: 0.351649    1.014497    3.400593    0.263098    0.031013    0.020971    0.836330    
#> 183: 0.382521    1.035034    3.395367    0.205049    0.038856    0.020016    0.826146    
#> 184: 0.368990    1.021168    3.408242    0.273312    0.038267    0.022614    0.817696    
#> 185: 0.372396    1.047201    3.406907    0.263840    0.055931    0.017708    0.808175    
#> 186: 0.375382    1.044791    3.415302    0.286888    0.045054    0.020941    0.801534    
#> 187: 0.402137    1.018585    3.421973    0.335937    0.048010    0.026333    0.795033    
#> 188: 0.406633    1.036606    3.414047    0.345548    0.052170    0.024959    0.802742    
#> 189: 0.435465    1.044286    3.418274    0.353441    0.048178    0.028424    0.795031    
#> 190: 0.412533    1.027181    3.435285    0.278523    0.039532    0.024042    0.790113    
#> 191: 0.374206    1.022527    3.402169    0.321902    0.036960    0.025222    0.788186    
#> 192: 0.426420    1.023907    3.421451    0.410629    0.054351    0.025150    0.763922    
#> 193: 0.467634    1.025768    3.435860    0.412210    0.041605    0.022664    0.750934    
#> 194: 0.430410    1.012137    3.432550    0.379732    0.051368    0.026405    0.757628    
#> 195: 0.385172    1.014721    3.417138    0.364509    0.047993    0.030426    0.753228    
#> 196: 0.398895    1.017300    3.419576    0.346027    0.038880    0.027171    0.790538    
#> 197: 0.373627    1.043750    3.433964    0.333111    0.044463    0.026032    0.809922    
#> 198: 0.435398    1.020816    3.421785    0.368491    0.038716    0.029826    0.780181    
#> 199: 0.403685    1.010379    3.414362    0.339017    0.038415    0.031339    0.789933    
#> 200: 0.407803    1.001614    3.419087    0.376980    0.039751    0.033301    0.798217    
#> 201: 0.404772    0.991860    3.428065    0.377968    0.038350    0.034894    0.799778    
#> 202: 0.403944    0.995612    3.424352    0.392237    0.039246    0.033541    0.797330    
#> 203: 0.418609    0.997655    3.424448    0.392066    0.040832    0.031034    0.796770    
#> 204: 0.426420    0.995130    3.427411    0.391150    0.044365    0.029833    0.793763    
#> 205: 0.431685    1.001737    3.427379    0.395210    0.045530    0.029382    0.797217    
#> 206: 0.430262    1.004975    3.428398    0.393558    0.044717    0.030431    0.799511    
#> 207: 0.429877    1.006377    3.426735    0.383010    0.045057    0.030470    0.799944    
#> 208: 0.428583    1.007226    3.426553    0.375359    0.043935    0.030186    0.799332    
#> 209: 0.431189    1.005857    3.425794    0.381344    0.043417    0.029984    0.799737    
#> 210: 0.432916    1.005909    3.426887    0.381464    0.043377    0.029902    0.797540    
#> 211: 0.435032    1.006599    3.427313    0.377488    0.042764    0.030356    0.797178    
#> 212: 0.434618    1.006896    3.427380    0.370413    0.043431    0.030054    0.796904    
#> 213: 0.436505    1.004273    3.428078    0.367635    0.044445    0.030074    0.796616    
#> 214: 0.437723    1.002223    3.428708    0.365671    0.044893    0.029965    0.796380    
#> 215: 0.438238    1.001333    3.429483    0.364599    0.044925    0.030107    0.797325    
#> 216: 0.441248    0.998967    3.430560    0.368245    0.044517    0.030234    0.798346    
#> 217: 0.442695    0.998108    3.431554    0.368788    0.044128    0.030259    0.797417    
#> 218: 0.442377    0.998214    3.431545    0.371857    0.043832    0.029694    0.796614    
#> 219: 0.441083    0.997955    3.430525    0.372469    0.043801    0.029388    0.796038    
#> 220: 0.440407    0.998684    3.429965    0.374935    0.043799    0.029253    0.794819    
#> 221: 0.438698    0.999571    3.428915    0.376531    0.043848    0.029265    0.793634    
#> 222: 0.437195    1.000605    3.427322    0.380086    0.043647    0.029387    0.793070    
#> 223: 0.436345    1.001265    3.426559    0.380456    0.043256    0.029462    0.792303    
#> 224: 0.436775    1.002500    3.426073    0.381986    0.042748    0.029363    0.791299    
#> 225: 0.436343    1.002227    3.425889    0.383213    0.042385    0.029342    0.790984    
#> 226: 0.436036    1.001569    3.425381    0.383700    0.042024    0.029155    0.791127    
#> 227: 0.436184    1.002208    3.425165    0.385530    0.041680    0.028989    0.790743    
#> 228: 0.435093    1.003970    3.424203    0.386134    0.041470    0.028929    0.790771    
#> 229: 0.433245    1.004113    3.423595    0.387819    0.041137    0.028837    0.790305    
#> 230: 0.432302    1.004263    3.423095    0.387612    0.040860    0.028601    0.790330    
#> 231: 0.431456    1.004427    3.422748    0.388373    0.040810    0.028432    0.790885    
#> 232: 0.430436    1.004600    3.422477    0.390680    0.040705    0.028463    0.790783    
#> 233: 0.429558    1.004006    3.422186    0.392954    0.040832    0.028622    0.790322    
#> 234: 0.428482    1.004221    3.422052    0.393464    0.040964    0.028657    0.789878    
#> 235: 0.427196    1.004181    3.421784    0.393536    0.041467    0.028536    0.790096    
#> 236: 0.426632    1.004724    3.421460    0.393646    0.041625    0.028407    0.790429    
#> 237: 0.427394    1.005112    3.421593    0.393304    0.041826    0.028371    0.791704    
#> 238: 0.428006    1.005240    3.421730    0.394832    0.042046    0.028397    0.792253    
#> 239: 0.428111    1.006182    3.421438    0.395734    0.042355    0.028265    0.792013    
#> 240: 0.427812    1.006473    3.421474    0.394421    0.042587    0.028146    0.791660    
#> 241: 0.428413    1.006262    3.421567    0.393483    0.042556    0.028146    0.791602    
#> 242: 0.427647    1.006386    3.421301    0.391008    0.042685    0.028023    0.792002    
#> 243: 0.426360    1.006921    3.421185    0.389399    0.042755    0.027879    0.792544    
#> 244: 0.425650    1.006770    3.421367    0.389301    0.042719    0.027809    0.792462    
#> 245: 0.425426    1.006695    3.421365    0.388634    0.042821    0.027724    0.792774    
#> 246: 0.425313    1.007052    3.421233    0.388856    0.042871    0.027687    0.793295    
#> 247: 0.423942    1.007343    3.420927    0.389486    0.042829    0.027639    0.793391    
#> 248: 0.423488    1.007929    3.420584    0.390063    0.042980    0.027532    0.793113    
#> 249: 0.422442    1.008255    3.420369    0.390256    0.043261    0.027424    0.792974    
#> 250: 0.422674    1.008656    3.420385    0.390594    0.043270    0.027258    0.793012    
#> 251: 0.423681    1.009173    3.420616    0.391697    0.043188    0.027127    0.793403    
#> 252: 0.424192    1.009452    3.420986    0.393428    0.043234    0.027035    0.793679    
#> 253: 0.424492    1.009675    3.421112    0.394448    0.043282    0.026887    0.794267    
#> 254: 0.425488    1.010207    3.421263    0.395223    0.043258    0.026831    0.794319    
#> 255: 0.425553    1.010419    3.421463    0.395044    0.043456    0.026721    0.794387    
#> 256: 0.425297    1.010107    3.421589    0.393786    0.043678    0.026617    0.794601    
#> 257: 0.425324    1.009997    3.421537    0.393881    0.043812    0.026626    0.794386    
#> 258: 0.424970    1.009570    3.421419    0.392839    0.043878    0.026580    0.794492    
#> 259: 0.424506    1.009702    3.421321    0.392055    0.043849    0.026586    0.794767    
#> 260: 0.424131    1.010018    3.421399    0.391702    0.043827    0.026612    0.794521    
#> 261: 0.424128    1.010087    3.421384    0.392326    0.043747    0.026618    0.794508    
#> 262: 0.424179    1.009978    3.421363    0.391967    0.043693    0.026617    0.794688    
#> 263: 0.424095    1.010066    3.421366    0.390737    0.043704    0.026571    0.794660    
#> 264: 0.424124    1.010331    3.421379    0.390413    0.043957    0.026515    0.794401    
#> 265: 0.424777    1.010231    3.421533    0.390497    0.044076    0.026499    0.794353    
#> 266: 0.425220    1.010333    3.421608    0.390504    0.044129    0.026487    0.794073    
#> 267: 0.425513    1.010347    3.421814    0.391340    0.044012    0.026542    0.794115    
#> 268: 0.425528    1.010073    3.421871    0.391502    0.043919    0.026535    0.794068    
#> 269: 0.425900    1.009789    3.421950    0.391989    0.043824    0.026590    0.794109    
#> 270: 0.425701    1.009931    3.421775    0.392974    0.043708    0.026620    0.793979    
#> 271: 0.425714    1.009971    3.421699    0.392500    0.043672    0.026600    0.794084    
#> 272: 0.425542    1.009811    3.421668    0.391945    0.043623    0.026546    0.794493    
#> 273: 0.425129    1.010125    3.421836    0.391559    0.043617    0.026542    0.794832    
#> 274: 0.424954    1.010475    3.422087    0.390442    0.043668    0.026534    0.794755    
#> 275: 0.424796    1.010602    3.422077    0.389282    0.043576    0.026541    0.794764    
#> 276: 0.425028    1.010441    3.422392    0.388791    0.043430    0.026633    0.794780    
#> 277: 0.425033    1.010672    3.422614    0.388700    0.043394    0.026739    0.794712    
#> 278: 0.425284    1.010699    3.422815    0.388647    0.043366    0.026811    0.794564    
#> 279: 0.424938    1.010866    3.422620    0.388659    0.043438    0.026852    0.794682    
#> 280: 0.424751    1.011045    3.422548    0.387665    0.043536    0.026841    0.795003    
#> 281: 0.424276    1.011443    3.422446    0.386396    0.043647    0.026753    0.795204    
#> 282: 0.424383    1.011875    3.422545    0.386027    0.043821    0.026733    0.795390    
#> 283: 0.424795    1.011795    3.422719    0.385823    0.044001    0.026731    0.795767    
#> 284: 0.425062    1.011339    3.422862    0.385179    0.044011    0.026705    0.795892    
#> 285: 0.425548    1.011271    3.422893    0.385370    0.044039    0.026692    0.795930    
#> 286: 0.425894    1.011205    3.422967    0.385435    0.043869    0.026701    0.796328    
#> 287: 0.426044    1.011174    3.422934    0.385287    0.043794    0.026734    0.796454    
#> 288: 0.426398    1.011012    3.423060    0.384328    0.043692    0.026779    0.796587    
#> 289: 0.426605    1.010768    3.423211    0.383597    0.043655    0.026787    0.796482    
#> 290: 0.427024    1.010825    3.423304    0.383534    0.043735    0.026773    0.796441    
#> 291: 0.427704    1.010919    3.423632    0.383430    0.043748    0.026767    0.796327    
#> 292: 0.428007    1.010958    3.423826    0.382877    0.043671    0.026765    0.796262    
#> 293: 0.428201    1.011016    3.423803    0.383097    0.043609    0.026772    0.796139    
#> 294: 0.428398    1.011190    3.423676    0.382775    0.043602    0.026777    0.796163    
#> 295: 0.428472    1.010913    3.423679    0.382664    0.043644    0.026762    0.796000    
#> 296: 0.428462    1.010579    3.423751    0.382000    0.043697    0.026749    0.795997    
#> 297: 0.428386    1.010473    3.423843    0.381536    0.043710    0.026697    0.795991    
#> 298: 0.428657    1.010392    3.423928    0.381099    0.043751    0.026698    0.795885    
#> 299: 0.429243    1.010228    3.424040    0.380657    0.043636    0.026714    0.795764    
#> 300: 0.429721    1.010003    3.424366    0.380093    0.043606    0.026732    0.795554    
#> 301: 0.430170    1.009646    3.424420    0.379742    0.043534    0.026720    0.795561    
#> 302: 0.430307    1.009454    3.424467    0.379324    0.043539    0.026661    0.795378    
#> 303: 0.430211    1.009736    3.424414    0.378827    0.043632    0.026584    0.795348    
#> 304: 0.430118    1.010095    3.424209    0.378424    0.043795    0.026538    0.795302    
#> 305: 0.429886    1.010031    3.424181    0.378136    0.043735    0.026523    0.795177    
#> 306: 0.429236    1.010018    3.423993    0.377435    0.043757    0.026520    0.794992    
#> 307: 0.429092    1.010101    3.423940    0.376593    0.043726    0.026576    0.795098    
#> 308: 0.428702    1.010079    3.423873    0.376773    0.043663    0.026608    0.795302    
#> 309: 0.428307    1.009931    3.423826    0.376579    0.043670    0.026648    0.795365    
#> 310: 0.428457    1.009953    3.423731    0.377483    0.043556    0.026651    0.795562    
#> 311: 0.428210    1.010030    3.423685    0.377498    0.043466    0.026671    0.795436    
#> 312: 0.427999    1.009962    3.423625    0.377689    0.043354    0.026677    0.795542    
#> 313: 0.428123    1.009822    3.423522    0.378025    0.043324    0.026719    0.795603    
#> 314: 0.427872    1.009870    3.423435    0.378118    0.043244    0.026786    0.795506    
#> 315: 0.427544    1.009892    3.423383    0.377949    0.043280    0.026789    0.795332    
#> 316: 0.427367    1.010014    3.423331    0.377394    0.043301    0.026787    0.795233    
#> 317: 0.427095    1.009949    3.423329    0.377243    0.043316    0.026735    0.795337    
#> 318: 0.426735    1.010119    3.423149    0.376806    0.043434    0.026716    0.795095    
#> 319: 0.426519    1.010156    3.423088    0.376431    0.043447    0.026704    0.795189    
#> 320: 0.425908    1.010322    3.422971    0.375840    0.043510    0.026674    0.795257    
#> 321: 0.425698    1.010446    3.422821    0.374963    0.043537    0.026603    0.795490    
#> 322: 0.425509    1.010493    3.422692    0.375079    0.043577    0.026576    0.795478    
#> 323: 0.425053    1.010647    3.422478    0.374793    0.043576    0.026565    0.795488    
#> 324: 0.425220    1.010716    3.422525    0.374652    0.043561    0.026554    0.795373    
#> 325: 0.425045    1.010792    3.422489    0.374555    0.043506    0.026508    0.795368    
#> 326: 0.425282    1.010643    3.422480    0.374282    0.043483    0.026482    0.795391    
#> 327: 0.425601    1.010653    3.422620    0.374451    0.043433    0.026437    0.795383    
#> 328: 0.425602    1.010703    3.422626    0.374184    0.043467    0.026387    0.795258    
#> 329: 0.425748    1.010832    3.422684    0.374187    0.043500    0.026327    0.795162    
#> 330: 0.425321    1.010828    3.422702    0.374014    0.043537    0.026310    0.795145    
#> 331: 0.425311    1.011125    3.422700    0.373554    0.043614    0.026294    0.795069    
#> 332: 0.425406    1.011187    3.422820    0.373224    0.043677    0.026300    0.795155    
#> 333: 0.425158    1.011315    3.422838    0.372985    0.043683    0.026316    0.795288    
#> 334: 0.424961    1.011394    3.422699    0.373335    0.043738    0.026311    0.795215    
#> 335: 0.424568    1.011441    3.422563    0.373105    0.043678    0.026274    0.795178    
#> 336: 0.424114    1.011497    3.422423    0.372891    0.043619    0.026259    0.795164    
#> 337: 0.423859    1.011773    3.422281    0.372902    0.043571    0.026267    0.795219    
#> 338: 0.423896    1.011970    3.422257    0.373343    0.043545    0.026263    0.795347    
#> 339: 0.423856    1.012120    3.422131    0.373884    0.043596    0.026293    0.795222    
#> 340: 0.423782    1.012098    3.422123    0.373915    0.043601    0.026319    0.795146    
#> 341: 0.424066    1.012092    3.422230    0.374047    0.043612    0.026326    0.795134    
#> 342: 0.424005    1.012008    3.422272    0.373658    0.043627    0.026307    0.795165    
#> 343: 0.423642    1.012032    3.422252    0.373236    0.043620    0.026311    0.795155    
#> 344: 0.423656    1.012043    3.422228    0.372637    0.043679    0.026298    0.795127    
#> 345: 0.423648    1.012080    3.422225    0.372496    0.043716    0.026265    0.795055    
#> 346: 0.423704    1.012263    3.422135    0.372346    0.043734    0.026236    0.795018    
#> 347: 0.423915    1.012035    3.422166    0.372420    0.043727    0.026207    0.795108    
#> 348: 0.423942    1.011979    3.422211    0.372306    0.043677    0.026174    0.795237    
#> 349: 0.424153    1.011945    3.422232    0.372212    0.043642    0.026155    0.795179    
#> 350: 0.424120    1.011886    3.422189    0.372489    0.043640    0.026151    0.795134    
#> 351: 0.424172    1.012072    3.422058    0.372870    0.043688    0.026152    0.795116    
#> 352: 0.423890    1.012207    3.421987    0.373308    0.043672    0.026195    0.795125    
#> 353: 0.423976    1.012344    3.421942    0.373643    0.043684    0.026202    0.795192    
#> 354: 0.423830    1.012423    3.421853    0.373848    0.043704    0.026203    0.795169    
#> 355: 0.424213    1.012298    3.421871    0.373883    0.043740    0.026206    0.795042    
#> 356: 0.424374    1.012136    3.422053    0.373526    0.043795    0.026171    0.795368    
#> 357: 0.424682    1.012201    3.422173    0.373450    0.043765    0.026156    0.795453    
#> 358: 0.424757    1.012328    3.422159    0.373690    0.043757    0.026120    0.795364    
#> 359: 0.424477    1.012491    3.422127    0.373529    0.043777    0.026117    0.795309    
#> 360: 0.424423    1.012590    3.422043    0.373331    0.043735    0.026098    0.795289    
#> 361: 0.424089    1.012671    3.421941    0.372856    0.043765    0.026060    0.795306    
#> 362: 0.423916    1.012767    3.421822    0.372621    0.043753    0.026041    0.795194    
#> 363: 0.423884    1.012712    3.421851    0.372137    0.043713    0.026025    0.795105    
#> 364: 0.423992    1.012716    3.421845    0.372326    0.043711    0.025984    0.795115    
#> 365: 0.423887    1.012782    3.421798    0.372375    0.043769    0.025955    0.794984    
#> 366: 0.423823    1.012875    3.421658    0.372209    0.043784    0.025958    0.794872    
#> 367: 0.423894    1.012946    3.421583    0.372226    0.043792    0.025936    0.794823    
#> 368: 0.424034    1.013025    3.421583    0.371734    0.043777    0.025906    0.794814    
#> 369: 0.423942    1.013039    3.421552    0.371358    0.043733    0.025910    0.794845    
#> 370: 0.423924    1.013134    3.421545    0.371132    0.043786    0.025872    0.794849    
#> 371: 0.423969    1.013156    3.421446    0.371456    0.043806    0.025859    0.794851    
#> 372: 0.423810    1.013223    3.421324    0.371404    0.043866    0.025817    0.794941    
#> 373: 0.423531    1.013479    3.421222    0.371264    0.044009    0.025799    0.794978    
#> 374: 0.423552    1.013615    3.421158    0.370891    0.044049    0.025791    0.794894    
#> 375: 0.423578    1.013716    3.421128    0.370549    0.044057    0.025771    0.794865    
#> 376: 0.423777    1.013800    3.421226    0.370344    0.044059    0.025752    0.794731    
#> 377: 0.423799    1.013825    3.421317    0.369929    0.044083    0.025712    0.794725    
#> 378: 0.423796    1.013842    3.421323    0.369695    0.044089    0.025702    0.794797    
#> 379: 0.423980    1.013685    3.421425    0.369502    0.044038    0.025710    0.794806    
#> 380: 0.424088    1.013590    3.421552    0.369105    0.044018    0.025700    0.794747    
#> 381: 0.424044    1.013499    3.421554    0.368914    0.044007    0.025699    0.794760    
#> 382: 0.423960    1.013579    3.421532    0.368834    0.043936    0.025687    0.794795    
#> 383: 0.423973    1.013574    3.421487    0.368632    0.043938    0.025674    0.794661    
#> 384: 0.423820    1.013566    3.421433    0.368669    0.043978    0.025647    0.794650    
#> 385: 0.423801    1.013659    3.421418    0.368691    0.044003    0.025612    0.794646    
#> 386: 0.423784    1.013840    3.421438    0.368412    0.044075    0.025591    0.794715    
#> 387: 0.423824    1.013920    3.421496    0.367922    0.044046    0.025569    0.794731    
#> 388: 0.423996    1.013935    3.421539    0.367583    0.044006    0.025565    0.794666    
#> 389: 0.423994    1.013685    3.421552    0.367376    0.044055    0.025529    0.794747    
#> 390: 0.423965    1.013628    3.421550    0.367014    0.044091    0.025484    0.794785    
#> 391: 0.424382    1.013465    3.421673    0.366742    0.044132    0.025469    0.794717    
#> 392: 0.424737    1.013349    3.421844    0.366745    0.044193    0.025470    0.794698    
#> 393: 0.424737    1.013299    3.421817    0.366637    0.044223    0.025468    0.794690    
#> 394: 0.424885    1.013212    3.421846    0.366490    0.044214    0.025439    0.794698    
#> 395: 0.425090    1.013285    3.421866    0.366418    0.044254    0.025406    0.794661    
#> 396: 0.425153    1.013304    3.421889    0.366383    0.044324    0.025399    0.794527    
#> 397: 0.425174    1.013302    3.421918    0.366247    0.044415    0.025401    0.794573    
#> 398: 0.425459    1.013182    3.422029    0.366186    0.044399    0.025420    0.794522    
#> 399: 0.425570    1.013233    3.422081    0.365889    0.044380    0.025437    0.794548    
#> 400: 0.425735    1.013302    3.422140    0.365573    0.044402    0.025438    0.794520    
#> 401: 0.425769    1.013418    3.422099    0.365426    0.044390    0.025423    0.794614    
#> 402: 0.425632    1.013546    3.422032    0.365195    0.044406    0.025403    0.794610    
#> 403: 0.425656    1.013496    3.422006    0.365100    0.044391    0.025396    0.794589    
#> 404: 0.425620    1.013487    3.422012    0.365078    0.044425    0.025364    0.794492    
#> 405: 0.425624    1.013441    3.422073    0.365332    0.044430    0.025345    0.794457    
#> 406: 0.425702    1.013404    3.422089    0.365467    0.044476    0.025319    0.794500    
#> 407: 0.425679    1.013458    3.422112    0.365612    0.044469    0.025292    0.794485    
#> 408: 0.425826    1.013575    3.422142    0.365358    0.044497    0.025268    0.794557    
#> 409: 0.425810    1.013571    3.422147    0.365044    0.044486    0.025258    0.794585    
#> 410: 0.425679    1.013567    3.422085    0.364752    0.044450    0.025267    0.794618    
#> 411: 0.425817    1.013390    3.422091    0.364823    0.044424    0.025274    0.794638    
#> 412: 0.425868    1.013419    3.422078    0.364614    0.044421    0.025279    0.794592    
#> 413: 0.425872    1.013369    3.422098    0.364280    0.044446    0.025252    0.794611    
#> 414: 0.425562    1.013404    3.422125    0.364250    0.044466    0.025233    0.794552    
#> 415: 0.425669    1.013377    3.422108    0.364387    0.044492    0.025212    0.794493    
#> 416: 0.425646    1.013438    3.422088    0.364238    0.044504    0.025199    0.794452    
#> 417: 0.425622    1.013449    3.422083    0.364064    0.044454    0.025189    0.794471    
#> 418: 0.425502    1.013546    3.422081    0.363999    0.044426    0.025184    0.794398    
#> 419: 0.425629    1.013719    3.422036    0.363920    0.044411    0.025175    0.794396    
#> 420: 0.425621    1.013823    3.422011    0.363818    0.044385    0.025176    0.794249    
#> 421: 0.425467    1.013901    3.422016    0.363695    0.044352    0.025191    0.794139    
#> 422: 0.425640    1.013853    3.422052    0.363605    0.044301    0.025192    0.794078    
#> 423: 0.425823    1.013761    3.422064    0.363734    0.044291    0.025190    0.794037    
#> 424: 0.425862    1.013688    3.422057    0.363812    0.044257    0.025185    0.794024    
#> 425: 0.426045    1.013664    3.422076    0.363957    0.044240    0.025191    0.794072    
#> 426: 0.426092    1.013704    3.422057    0.364192    0.044235    0.025183    0.794031    
#> 427: 0.425942    1.013678    3.422064    0.364240    0.044208    0.025174    0.793971    
#> 428: 0.425781    1.013705    3.422035    0.364503    0.044162    0.025153    0.793952    
#> 429: 0.425699    1.013699    3.421996    0.364702    0.044122    0.025156    0.794009    
#> 430: 0.425643    1.013735    3.421938    0.364807    0.044087    0.025133    0.794049    
#> 431: 0.425684    1.013688    3.421971    0.364517    0.044080    0.025100    0.794058    
#> 432: 0.425636    1.013783    3.421987    0.364303    0.044094    0.025077    0.794134    
#> 433: 0.425620    1.013905    3.421974    0.364137    0.044122    0.025058    0.794130    
#> 434: 0.425254    1.013857    3.421927    0.363878    0.044119    0.025038    0.794154    
#> 435: 0.425334    1.013845    3.421893    0.363736    0.044135    0.025045    0.794096    
#> 436: 0.425378    1.013823    3.421957    0.363598    0.044153    0.025043    0.794020    
#> 437: 0.425376    1.013833    3.421972    0.363503    0.044155    0.025029    0.793999    
#> 438: 0.425366    1.013932    3.421992    0.363678    0.044148    0.025021    0.793961    
#> 439: 0.425427    1.013983    3.422006    0.363923    0.044091    0.025032    0.793859    
#> 440: 0.425416    1.014057    3.422006    0.363936    0.044044    0.025020    0.793863    
#> 441: 0.425384    1.014057    3.422004    0.363955    0.044016    0.025029    0.793783    
#> 442: 0.425331    1.014099    3.422024    0.364070    0.043997    0.025035    0.793707    
#> 443: 0.425372    1.014149    3.422019    0.364286    0.043976    0.025075    0.793600    
#> 444: 0.425395    1.014175    3.421992    0.364572    0.043921    0.025137    0.793482    
#> 445: 0.425420    1.014198    3.421996    0.364746    0.043861    0.025173    0.793416    
#> 446: 0.425229    1.014226    3.421938    0.364812    0.043788    0.025193    0.793344    
#> 447: 0.425365    1.014221    3.421946    0.364915    0.043775    0.025208    0.793338    
#> 448: 0.425432    1.014209    3.422015    0.364905    0.043760    0.025239    0.793279    
#> 449: 0.425516    1.014219    3.422126    0.364840    0.043761    0.025249    0.793334    
#> 450: 0.425580    1.014205    3.422192    0.364716    0.043776    0.025248    0.793384    
#> 451: 0.425641    1.014247    3.422211    0.364598    0.043813    0.025261    0.793387    
#> 452: 0.425674    1.014304    3.422205    0.364434    0.043810    0.025271    0.793373    
#> 453: 0.425576    1.014287    3.422167    0.364502    0.043813    0.025275    0.793287    
#> 454: 0.425530    1.014354    3.422122    0.364573    0.043781    0.025287    0.793231    
#> 455: 0.425538    1.014401    3.422072    0.364651    0.043791    0.025297    0.793164    
#> 456: 0.425356    1.014440    3.422027    0.364707    0.043822    0.025298    0.793129    
#> 457: 0.425314    1.014445    3.422040    0.364715    0.043852    0.025302    0.793046    
#> 458: 0.425337    1.014564    3.422090    0.364757    0.043881    0.025314    0.792966    
#> 459: 0.425218    1.014662    3.422076    0.364550    0.043941    0.025315    0.792861    
#> 460: 0.425089    1.014714    3.422030    0.364528    0.043942    0.025312    0.792780    
#> 461: 0.425105    1.014767    3.422078    0.364536    0.043955    0.025333    0.792734    
#> 462: 0.425049    1.014790    3.422107    0.364566    0.043932    0.025342    0.792713    
#> 463: 0.424970    1.014865    3.422116    0.364535    0.043899    0.025357    0.792712    
#> 464: 0.424935    1.014928    3.422052    0.364767    0.043880    0.025383    0.792659    
#> 465: 0.424929    1.014840    3.422033    0.365018    0.043894    0.025393    0.792593    
#> 466: 0.424948    1.014779    3.422004    0.364930    0.043874    0.025396    0.792580    
#> 467: 0.424811    1.014715    3.422053    0.364741    0.043852    0.025415    0.792513    
#> 468: 0.424994    1.014640    3.422161    0.364453    0.043830    0.025423    0.792574    
#> 469: 0.425037    1.014621    3.422254    0.364157    0.043820    0.025435    0.792685    
#> 470: 0.425067    1.014626    3.422280    0.363990    0.043779    0.025477    0.792757    
#> 471: 0.424979    1.014641    3.422293    0.363563    0.043761    0.025479    0.792798    
#> 472: 0.424920    1.014666    3.422312    0.363315    0.043775    0.025477    0.792774    
#> 473: 0.424924    1.014756    3.422298    0.363326    0.043777    0.025480    0.792717    
#> 474: 0.424921    1.014811    3.422274    0.363514    0.043802    0.025482    0.792690    
#> 475: 0.425006    1.014963    3.422276    0.363528    0.043817    0.025485    0.792667    
#> 476: 0.424999    1.014967    3.422272    0.363472    0.043809    0.025486    0.792658    
#> 477: 0.425052    1.014982    3.422327    0.363442    0.043815    0.025484    0.792536    
#> 478: 0.425031    1.014975    3.422353    0.363437    0.043810    0.025490    0.792501    
#> 479: 0.425062    1.015017    3.422356    0.363555    0.043787    0.025490    0.792477    
#> 480: 0.425076    1.015064    3.422346    0.363459    0.043762    0.025496    0.792557    
#> 481: 0.425105    1.015085    3.422355    0.363564    0.043736    0.025487    0.792524    
#> 482: 0.425156    1.015165    3.422334    0.363771    0.043717    0.025501    0.792526    
#> 483: 0.425077    1.015189    3.422313    0.363865    0.043722    0.025501    0.792481    
#> 484: 0.425133    1.015153    3.422300    0.364132    0.043749    0.025509    0.792462    
#> 485: 0.425086    1.015207    3.422316    0.364249    0.043787    0.025513    0.792484    
#> 486: 0.425157    1.015270    3.422377    0.364373    0.043782    0.025516    0.792491    
#> 487: 0.425422    1.015345    3.422485    0.364661    0.043775    0.025511    0.792472    
#> 488: 0.425613    1.015324    3.422569    0.364589    0.043764    0.025513    0.792419    
#> 489: 0.425753    1.015267    3.422588    0.364675    0.043789    0.025505    0.792407    
#> 490: 0.425877    1.015273    3.422621    0.364662    0.043802    0.025492    0.792396    
#> 491: 0.425930    1.015263    3.422679    0.364626    0.043786    0.025488    0.792382    
#> 492: 0.425937    1.015316    3.422682    0.364716    0.043795    0.025495    0.792429    
#> 493: 0.425908    1.015388    3.422684    0.364555    0.043838    0.025511    0.792446    
#> 494: 0.426009    1.015532    3.422621    0.364454    0.043824    0.025526    0.792440    
#> 495: 0.425986    1.015631    3.422593    0.364362    0.043833    0.025531    0.792357    
#> 496: 0.425966    1.015730    3.422526    0.364363    0.043825    0.025525    0.792303    
#> 497: 0.425883    1.015710    3.422482    0.364403    0.043809    0.025525    0.792307    
#> 498: 0.425851    1.015734    3.422440    0.364304    0.043792    0.025524    0.792239    
#> 499: 0.425862    1.015798    3.422430    0.364181    0.043774    0.025523    0.792219    
#> 500: 0.425922    1.015794    3.422412    0.364033    0.043780    0.025511    0.792180    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.322223    0.974745    3.443615    0.392401    0.078474    0.016800    1.585845    
#> 002: 0.403986    1.012033    3.453287    0.372781    0.074550    0.015960    1.001149    
#> 003: 0.477312    0.974837    3.452484    0.354142    0.070823    0.015162    0.818147    
#> 004: 0.445878    0.970325    3.454436    0.336435    0.067282    0.014404    0.691720    
#> 005: 0.462078    0.987992    3.432741    0.319613    0.063918    0.013684    0.647670    
#> 006: 0.433491    0.994683    3.431783    0.317093    0.060722    0.013000    0.609118    
#> 007: 0.405330    1.005814    3.427035    0.304237    0.067097    0.012722    0.624290    
#> 008: 0.430529    0.992839    3.426492    0.334528    0.063742    0.015998    0.595878    
#> 009: 0.400223    0.970226    3.425048    0.340866    0.060555    0.015198    0.602047    
#> 010: 0.400081    0.982691    3.425433    0.411534    0.060973    0.016048    0.597515    
#> 011: 0.472905    0.996993    3.439453    0.398137    0.057925    0.018947    0.596914    
#> 012: 0.465157    0.996317    3.436562    0.378230    0.055028    0.018000    0.594913    
#> 013: 0.402882    0.996212    3.421638    0.359319    0.052277    0.017100    0.610712    
#> 014: 0.419911    1.004405    3.425354    0.341353    0.057266    0.016245    0.608625    
#> 015: 0.461185    1.011128    3.427545    0.356664    0.054403    0.016127    0.591001    
#> 016: 0.466543    1.015926    3.440277    0.358070    0.051683    0.015695    0.612932    
#> 017: 0.428675    1.009946    3.435981    0.340166    0.051052    0.014910    0.610293    
#> 018: 0.433387    1.017407    3.420993    0.384874    0.049029    0.016407    0.604996    
#> 019: 0.401406    1.002998    3.426531    0.365630    0.050118    0.015587    0.596911    
#> 020: 0.446750    1.011047    3.437137    0.350037    0.047612    0.018928    0.607812    
#> 021: 0.459410    0.999914    3.439966    0.332536    0.045232    0.017982    0.601743    
#> 022: 0.444738    0.997025    3.455056    0.340885    0.042970    0.019085    0.594334    
#> 023: 0.498125    0.978253    3.460521    0.342705    0.040821    0.018632    0.631415    
#> 024: 0.515282    0.987304    3.467535    0.337468    0.038780    0.020612    0.604939    
#> 025: 0.487572    0.979609    3.447855    0.330222    0.046231    0.019581    0.611708    
#> 026: 0.459894    1.017599    3.434790    0.330168    0.044234    0.019018    0.603704    
#> 027: 0.424056    1.030229    3.425132    0.315713    0.042022    0.021032    0.631381    
#> 028: 0.460555    1.010475    3.427747    0.363222    0.041327    0.022773    0.600699    
#> 029: 0.442083    1.006799    3.423370    0.400787    0.039261    0.021635    0.605763    
#> 030: 0.468949    1.019276    3.420512    0.387494    0.046098    0.020553    0.602345    
#> 031: 0.406726    1.004763    3.425281    0.368120    0.047033    0.019828    0.597245    
#> 032: 0.412396    0.985358    3.427107    0.349714    0.044758    0.019367    0.593448    
#> 033: 0.431787    0.989819    3.436432    0.332228    0.042520    0.021541    0.596170    
#> 034: 0.463963    1.009232    3.441205    0.355316    0.045606    0.021181    0.583456    
#> 035: 0.453235    1.000136    3.435885    0.337550    0.052699    0.020122    0.589095    
#> 036: 0.437534    1.006051    3.439892    0.320673    0.050064    0.019115    0.606281    
#> 037: 0.429060    0.995776    3.432957    0.373743    0.047560    0.018933    0.625572    
#> 038: 0.464945    0.993436    3.435102    0.358146    0.045182    0.020249    0.602130    
#> 039: 0.473216    0.989212    3.444361    0.379391    0.042923    0.021360    0.592695    
#> 040: 0.444001    0.991331    3.447992    0.412973    0.040777    0.023743    0.592506    
#> 041: 0.430917    0.989822    3.440625    0.392324    0.038738    0.022784    0.596972    
#> 042: 0.437572    0.982081    3.435328    0.372708    0.036801    0.021645    0.609347    
#> 043: 0.435284    1.000104    3.425374    0.354073    0.039439    0.020563    0.602782    
#> 044: 0.408173    0.990345    3.430967    0.336369    0.037467    0.022925    0.592362    
#> 045: 0.420769    1.010066    3.427594    0.367338    0.035594    0.021779    0.592722    
#> 046: 0.469124    0.998967    3.438568    0.422166    0.034170    0.023361    0.585750    
#> 047: 0.435281    1.000859    3.426269    0.401058    0.032510    0.022193    0.598000    
#> 048: 0.429862    0.993579    3.427620    0.394228    0.033529    0.021698    0.601001    
#> 049: 0.432559    0.991542    3.436147    0.395891    0.041889    0.021908    0.606189    
#> 050: 0.493043    0.968313    3.453890    0.383311    0.043070    0.022797    0.617870    
#> 051: 0.537323    0.956398    3.453016    0.452853    0.040917    0.023725    0.622122    
#> 052: 0.497867    0.980900    3.447063    0.450169    0.042553    0.022539    0.614170    
#> 053: 0.485944    0.980789    3.438168    0.430652    0.048143    0.021412    0.600591    
#> 054: 0.446079    0.993553    3.438400    0.414113    0.049981    0.020341    0.611097    
#> 055: 0.451924    0.996815    3.434135    0.444281    0.052171    0.022132    0.604236    
#> 056: 0.462644    0.998833    3.431037    0.422067    0.057955    0.021025    0.610333    
#> 057: 0.440740    1.007341    3.439534    0.400964    0.055057    0.025762    0.605126    
#> 058: 0.445376    1.004021    3.422472    0.458261    0.052304    0.024474    0.609826    
#> 059: 0.456732    0.960431    3.439840    0.444029    0.049689    0.025880    0.629602    
#> 060: 0.495310    0.964455    3.446052    0.421827    0.047204    0.024586    0.645806    
#> 061: 0.522928    0.983785    3.446197    0.483891    0.046537    0.023356    0.636235    
#> 062: 0.483783    0.995441    3.444390    0.459696    0.049157    0.023986    0.662125    
#> 063: 0.479807    0.965778    3.444394    0.436711    0.046699    0.022787    0.635361    
#> 064: 0.453436    0.998591    3.435418    0.414876    0.044364    0.021647    0.628192    
#> 065: 0.475166    0.984632    3.442055    0.394132    0.045630    0.020565    0.610886    
#> 066: 0.460021    1.004742    3.446262    0.374425    0.043348    0.019537    0.602381    
#> 067: 0.446110    0.986487    3.436526    0.355704    0.041181    0.019249    0.595616    
#> 068: 0.428584    0.999672    3.444244    0.351660    0.045611    0.019654    0.602906    
#> 069: 0.445824    1.006342    3.433533    0.412713    0.043331    0.024957    0.598694    
#> 070: 0.437982    0.993043    3.439478    0.392077    0.041164    0.024493    0.585614    
#> 071: 0.462678    1.016232    3.427962    0.401617    0.048017    0.023269    0.591520    
#> 072: 0.429340    0.991947    3.431117    0.381537    0.045616    0.022105    0.594098    
#> 073: 0.432221    1.009216    3.437929    0.362460    0.043335    0.021250    0.592222    
#> 074: 0.419158    0.995065    3.428869    0.351537    0.044597    0.020188    0.589721    
#> 075: 0.462278    0.986349    3.444394    0.408966    0.042367    0.020903    0.594877    
#> 076: 0.477236    0.987580    3.436091    0.437888    0.040248    0.019857    0.598287    
#> 077: 0.483172    0.996930    3.442643    0.416261    0.039118    0.022939    0.587359    
#> 078: 0.490198    0.992827    3.439689    0.395448    0.042675    0.024267    0.596748    
#> 079: 0.461903    1.006399    3.435291    0.414984    0.040541    0.023054    0.608884    
#> 080: 0.463244    1.017095    3.434743    0.472438    0.041216    0.021901    0.608679    
#> 081: 0.451387    1.018262    3.424487    0.448816    0.039156    0.023020    0.605507    
#> 082: 0.455473    0.998964    3.429224    0.460609    0.037198    0.021869    0.611984    
#> 083: 0.428993    1.013762    3.428758    0.437579    0.035478    0.020775    0.598570    
#> 084: 0.423885    1.006770    3.420957    0.415700    0.039981    0.023229    0.604240    
#> 085: 0.437209    1.008993    3.441999    0.395639    0.043382    0.022068    0.597542    
#> 086: 0.432265    1.002744    3.425305    0.375857    0.041213    0.022243    0.602946    
#> 087: 0.440572    1.000590    3.418671    0.357064    0.041434    0.022719    0.589163    
#> 088: 0.366061    1.002590    3.414651    0.363484    0.043332    0.022398    0.596053    
#> 089: 0.400003    1.022124    3.410299    0.411244    0.051238    0.021887    0.582457    
#> 090: 0.407728    1.005915    3.406566    0.430293    0.048676    0.020954    0.601607    
#> 091: 0.411738    1.005127    3.409404    0.417146    0.046243    0.022967    0.604490    
#> 092: 0.380439    1.023214    3.391070    0.444675    0.050062    0.023632    0.606198    
#> 093: 0.350139    1.016529    3.405153    0.422441    0.047731    0.023816    0.624030    
#> 094: 0.388642    1.018996    3.414335    0.401319    0.045344    0.022626    0.609916    
#> 095: 0.415729    1.025784    3.424078    0.449817    0.043077    0.025032    0.600214    
#> 096: 0.392594    1.016017    3.410889    0.427326    0.045329    0.024114    0.596227    
#> 097: 0.414784    1.028984    3.408589    0.423940    0.045997    0.022909    0.578466    
#> 098: 0.427631    1.021702    3.426628    0.407620    0.045482    0.028283    0.595291    
#> 099: 0.412413    1.002828    3.408459    0.438702    0.044978    0.026869    0.600770    
#> 100: 0.410766    1.011274    3.419372    0.416767    0.044092    0.025525    0.591811    
#> 101: 0.384981    1.005129    3.403917    0.395928    0.042234    0.024249    0.586875    
#> 102: 0.392442    1.000937    3.405310    0.387302    0.051450    0.023037    0.594260    
#> 103: 0.424310    1.016082    3.414140    0.490187    0.048878    0.022526    0.594974    
#> 104: 0.409761    1.015811    3.424865    0.465677    0.046434    0.024272    0.607568    
#> 105: 0.432751    1.019751    3.426364    0.442394    0.061826    0.023548    0.601880    
#> 106: 0.464276    1.007962    3.430232    0.426065    0.058735    0.022371    0.598031    
#> 107: 0.436141    1.025990    3.420466    0.404761    0.055798    0.021252    0.611544    
#> 108: 0.435552    1.009163    3.427682    0.399988    0.057835    0.020189    0.599257    
#> 109: 0.444734    1.010687    3.435570    0.409507    0.054944    0.019180    0.604633    
#> 110: 0.453900    1.001712    3.420340    0.426503    0.052196    0.018221    0.603880    
#> 111: 0.436830    1.009469    3.421181    0.405178    0.049587    0.017310    0.593661    
#> 112: 0.404561    0.997488    3.400727    0.404000    0.051557    0.016444    0.603710    
#> 113: 0.399365    1.026605    3.416129    0.383800    0.048979    0.019487    0.596278    
#> 114: 0.436371    1.027677    3.413893    0.380427    0.046530    0.018901    0.597961    
#> 115: 0.423801    0.998177    3.417175    0.361405    0.044204    0.020335    0.602571    
#> 116: 0.440651    1.014939    3.418188    0.402944    0.045316    0.019318    0.595757    
#> 117: 0.406107    1.026889    3.426015    0.382797    0.045446    0.018352    0.605611    
#> 118: 0.410038    1.007248    3.425620    0.363657    0.043955    0.017783    0.613897    
#> 119: 0.422022    1.012160    3.421144    0.357846    0.041757    0.021169    0.605677    
#> 120: 0.403873    1.015053    3.415536    0.355049    0.039669    0.020408    0.592815    
#> 121: 0.434003    1.025948    3.422946    0.346233    0.042561    0.020620    0.571593    
#> 122: 0.445526    0.997592    3.428399    0.390627    0.040433    0.022248    0.587715    
#> 123: 0.449492    1.036988    3.412199    0.405319    0.042181    0.021135    0.596829    
#> 124: 0.454317    1.054341    3.412347    0.453532    0.040755    0.020343    0.600958    
#> 125: 0.454957    1.037846    3.410029    0.454662    0.038717    0.019326    0.594015    
#> 126: 0.425498    1.037374    3.401765    0.508238    0.044108    0.019585    0.590837    
#> 127: 0.406340    1.029655    3.405200    0.482826    0.041903    0.018606    0.622916    
#> 128: 0.412073    1.025209    3.422504    0.458685    0.039808    0.017676    0.626242    
#> 129: 0.467852    1.020102    3.433892    0.440623    0.049797    0.017273    0.624745    
#> 130: 0.495816    1.024083    3.432163    0.456108    0.047307    0.016409    0.607182    
#> 131: 0.466181    1.003348    3.427129    0.433302    0.044942    0.021684    0.597010    
#> 132: 0.414183    1.007361    3.411534    0.411637    0.045069    0.024182    0.603901    
#> 133: 0.384809    1.003498    3.416224    0.391055    0.043016    0.022973    0.610125    
#> 134: 0.403720    1.003255    3.427939    0.371503    0.040865    0.021825    0.614988    
#> 135: 0.439038    0.996630    3.435027    0.356395    0.038822    0.020733    0.605414    
#> 136: 0.450767    0.981012    3.441466    0.341914    0.036881    0.020621    0.596233    
#> 137: 0.501041    0.986320    3.445872    0.354717    0.035037    0.019590    0.621390    
#> 138: 0.447605    0.984318    3.439155    0.341720    0.037905    0.018611    0.616859    
#> 139: 0.429025    1.005225    3.446913    0.381709    0.036009    0.021066    0.618468    
#> 140: 0.477690    1.008830    3.453936    0.362624    0.034209    0.021777    0.633301    
#> 141: 0.444760    0.987880    3.445259    0.344492    0.038094    0.021192    0.621881    
#> 142: 0.452027    0.965544    3.452396    0.327268    0.036190    0.020132    0.636966    
#> 143: 0.445893    0.993105    3.448552    0.344991    0.037907    0.019156    0.630788    
#> 144: 0.508474    0.975700    3.464699    0.328190    0.036195    0.018198    0.610816    
#> 145: 0.468017    0.990686    3.446941    0.311781    0.034385    0.017288    0.604881    
#> 146: 0.448327    0.989559    3.450047    0.313022    0.037227    0.018155    0.619643    
#> 147: 0.431135    0.983909    3.436722    0.313617    0.035365    0.023925    0.584068    
#> 148: 0.429672    0.988469    3.441723    0.320108    0.033657    0.022729    0.583662    
#> 149: 0.436992    0.997885    3.438657    0.383264    0.040573    0.022155    0.588362    
#> 150: 0.486963    0.993850    3.427469    0.457377    0.043521    0.023364    0.597095    
#> 151: 0.425509    1.003624    3.431078    0.434508    0.042582    0.022196    0.585404    
#> 152: 0.447972    1.002220    3.435132    0.454449    0.040858    0.020974    0.583291    
#> 153: 0.442926    0.989239    3.441300    0.464004    0.046142    0.021740    0.594226    
#> 154: 0.471914    1.000063    3.438872    0.458677    0.038617    0.021742    0.595605    
#> 155: 0.443015    0.990463    3.428716    0.417567    0.045729    0.019348    0.603154    
#> 156: 0.473741    0.986652    3.440022    0.429617    0.040201    0.019640    0.613907    
#> 157: 0.463032    0.984726    3.437468    0.409685    0.049585    0.022491    0.621915    
#> 158: 0.435312    1.022005    3.424384    0.360116    0.052324    0.015961    0.597244    
#> 159: 0.410948    1.024923    3.420006    0.360737    0.046604    0.016056    0.612652    
#> 160: 0.440161    0.993872    3.423681    0.466525    0.055789    0.016618    0.605225    
#> 161: 0.422386    1.005407    3.422572    0.364665    0.051301    0.016217    0.609537    
#> 162: 0.482825    1.004114    3.429341    0.458330    0.041193    0.014545    0.613301    
#> 163: 0.494692    1.001341    3.424564    0.470220    0.050307    0.015584    0.614061    
#> 164: 0.471600    1.016956    3.428688    0.387311    0.045913    0.013239    0.605898    
#> 165: 0.489387    1.006173    3.442428    0.418880    0.049804    0.017189    0.604342    
#> 166: 0.498540    1.034250    3.436570    0.446816    0.056753    0.016851    0.619703    
#> 167: 0.484225    1.026882    3.433177    0.434138    0.046418    0.018347    0.605849    
#> 168: 0.453649    1.020922    3.431369    0.464015    0.043458    0.020318    0.579996    
#> 169: 0.476364    1.038057    3.423338    0.393043    0.045080    0.019583    0.611163    
#> 170: 0.474557    1.012722    3.429936    0.400408    0.035702    0.023299    0.604813    
#> 171: 0.469887    1.001957    3.437565    0.449901    0.040209    0.020380    0.582159    
#> 172: 0.442049    1.005311    3.431674    0.469683    0.037802    0.020945    0.582894    
#> 173: 0.433852    1.011278    3.420855    0.420065    0.035118    0.017744    0.580393    
#> 174: 0.456097    1.003511    3.430268    0.435622    0.038123    0.015413    0.594400    
#> 175: 0.439711    1.017041    3.419209    0.429241    0.043463    0.013576    0.598500    
#> 176: 0.430150    1.029344    3.422601    0.411803    0.053078    0.012938    0.589896    
#> 177: 0.422573    1.004793    3.429675    0.315275    0.052819    0.011723    0.597537    
#> 178: 0.444185    1.009680    3.427485    0.334679    0.042205    0.012031    0.610885    
#> 179: 0.489596    1.031844    3.430545    0.332212    0.041797    0.015941    0.622359    
#> 180: 0.427646    1.009616    3.434669    0.346151    0.042884    0.017072    0.608011    
#> 181: 0.461093    0.995220    3.425081    0.346952    0.039132    0.016078    0.599908    
#> 182: 0.437205    0.995301    3.423695    0.333762    0.039516    0.018335    0.618188    
#> 183: 0.436554    1.024251    3.421447    0.389068    0.038631    0.019951    0.612625    
#> 184: 0.448172    1.010833    3.421578    0.424685    0.040534    0.019550    0.599869    
#> 185: 0.414059    1.019666    3.417499    0.378072    0.039084    0.021968    0.601140    
#> 186: 0.428576    1.025725    3.422591    0.365732    0.041366    0.021977    0.618570    
#> 187: 0.416711    1.009736    3.429089    0.358612    0.044168    0.023032    0.611404    
#> 188: 0.432628    1.013534    3.422792    0.429837    0.041347    0.023363    0.623892    
#> 189: 0.439042    1.024708    3.434138    0.404623    0.054529    0.026648    0.613428    
#> 190: 0.476118    1.011332    3.445775    0.401829    0.043225    0.026199    0.587438    
#> 191: 0.458800    1.014187    3.427667    0.399667    0.036491    0.022309    0.586323    
#> 192: 0.440440    1.013508    3.431184    0.336980    0.040042    0.020153    0.592352    
#> 193: 0.465533    1.017628    3.447070    0.345352    0.043323    0.020025    0.595058    
#> 194: 0.464745    1.012212    3.435010    0.402006    0.052854    0.022213    0.606691    
#> 195: 0.402996    0.996669    3.433444    0.319227    0.041408    0.022254    0.606933    
#> 196: 0.436302    1.001317    3.438682    0.381551    0.031617    0.019214    0.598125    
#> 197: 0.447162    1.001147    3.449785    0.448790    0.043154    0.019890    0.604812    
#> 198: 0.490322    0.971950    3.444061    0.397634    0.041040    0.018851    0.591212    
#> 199: 0.455882    0.988945    3.439914    0.427604    0.045414    0.016951    0.586523    
#> 200: 0.429265    0.980672    3.435660    0.361915    0.048125    0.017304    0.608333    
#> 201: 0.446755    0.979149    3.445071    0.357485    0.044980    0.016354    0.606443    
#> 202: 0.447200    0.981789    3.447805    0.360116    0.044264    0.016658    0.607499    
#> 203: 0.464161    0.982648    3.445547    0.362922    0.043891    0.015620    0.611269    
#> 204: 0.466668    0.981986    3.446141    0.370163    0.045186    0.015274    0.612913    
#> 205: 0.465669    0.986818    3.445578    0.367028    0.045488    0.014688    0.614473    
#> 206: 0.467135    0.990524    3.445641    0.377458    0.045688    0.014964    0.613836    
#> 207: 0.464358    0.992395    3.443636    0.376538    0.045322    0.014959    0.612708    
#> 208: 0.463367    0.993487    3.442046    0.377914    0.044668    0.014937    0.609673    
#> 209: 0.461698    0.992994    3.440285    0.382817    0.044077    0.015190    0.610098    
#> 210: 0.459376    0.993476    3.439360    0.376763    0.043960    0.015528    0.609093    
#> 211: 0.458765    0.995220    3.439264    0.375364    0.043135    0.015957    0.608713    
#> 212: 0.456933    0.995123    3.438648    0.376006    0.043097    0.016176    0.608824    
#> 213: 0.457569    0.994121    3.438270    0.374332    0.043039    0.016575    0.609201    
#> 214: 0.459363    0.993471    3.438557    0.377596    0.043144    0.017075    0.608094    
#> 215: 0.461159    0.992402    3.439375    0.379679    0.042582    0.017624    0.607860    
#> 216: 0.464326    0.990451    3.440371    0.379003    0.042440    0.017949    0.610055    
#> 217: 0.465804    0.990916    3.440296    0.381484    0.042294    0.018096    0.609195    
#> 218: 0.466108    0.991733    3.439967    0.384255    0.042107    0.018038    0.609025    
#> 219: 0.463990    0.991717    3.438926    0.381909    0.042227    0.018003    0.609744    
#> 220: 0.462629    0.992961    3.438588    0.380951    0.042526    0.018022    0.609167    
#> 221: 0.460299    0.994039    3.437844    0.380919    0.042498    0.018015    0.608779    
#> 222: 0.459936    0.994635    3.437086    0.382046    0.042200    0.018249    0.608252    
#> 223: 0.459718    0.994981    3.436591    0.382377    0.041944    0.018426    0.607743    
#> 224: 0.459998    0.996036    3.436573    0.382431    0.041774    0.018326    0.607419    
#> 225: 0.458826    0.995836    3.436509    0.379256    0.041651    0.018369    0.607270    
#> 226: 0.457798    0.995550    3.436070    0.378374    0.041651    0.018273    0.607487    
#> 227: 0.457560    0.995881    3.436316    0.376186    0.041835    0.018267    0.607665    
#> 228: 0.456609    0.996647    3.435867    0.374824    0.041974    0.018199    0.607390    
#> 229: 0.454859    0.996589    3.435414    0.375908    0.042144    0.018109    0.606864    
#> 230: 0.454567    0.996923    3.434878    0.378439    0.042115    0.018009    0.606288    
#> 231: 0.454625    0.997124    3.434623    0.381310    0.042096    0.018008    0.605666    
#> 232: 0.453981    0.997241    3.434522    0.382541    0.041956    0.018053    0.604987    
#> 233: 0.453030    0.996758    3.434307    0.384397    0.041803    0.018039    0.605049    
#> 234: 0.452551    0.996693    3.434038    0.385078    0.042017    0.017983    0.604829    
#> 235: 0.452129    0.996290    3.433817    0.384633    0.042262    0.017872    0.604642    
#> 236: 0.451464    0.996614    3.433525    0.383961    0.042359    0.017842    0.604420    
#> 237: 0.451405    0.996715    3.433300    0.384031    0.042533    0.017832    0.604305    
#> 238: 0.451528    0.996986    3.433215    0.384095    0.042858    0.017796    0.604616    
#> 239: 0.451080    0.997343    3.432931    0.384201    0.042899    0.017773    0.604593    
#> 240: 0.450758    0.997346    3.433071    0.382375    0.043008    0.017849    0.604215    
#> 241: 0.450577    0.996980    3.433088    0.382085    0.042742    0.017939    0.603947    
#> 242: 0.450930    0.996748    3.432978    0.383714    0.042815    0.018061    0.604023    
#> 243: 0.450426    0.997177    3.432818    0.383807    0.042835    0.018197    0.604188    
#> 244: 0.449620    0.997126    3.432786    0.383456    0.042744    0.018331    0.603883    
#> 245: 0.450249    0.996898    3.432874    0.383593    0.042750    0.018455    0.604260    
#> 246: 0.450695    0.996643    3.433124    0.383437    0.042743    0.018598    0.604065    
#> 247: 0.450969    0.996414    3.433430    0.382883    0.042742    0.018697    0.604057    
#> 248: 0.450894    0.996868    3.433455    0.381729    0.042730    0.018711    0.603706    
#> 249: 0.450417    0.996946    3.433670    0.380076    0.042747    0.018741    0.603768    
#> 250: 0.451049    0.997127    3.433905    0.380895    0.042676    0.018842    0.603817    
#> 251: 0.451486    0.997243    3.434211    0.380548    0.042499    0.018913    0.604001    
#> 252: 0.452608    0.997188    3.434720    0.380514    0.042402    0.018971    0.604303    
#> 253: 0.453093    0.997309    3.434883    0.381241    0.042434    0.018957    0.604376    
#> 254: 0.453914    0.997757    3.435021    0.382782    0.042417    0.019027    0.604241    
#> 255: 0.454237    0.998206    3.435079    0.384209    0.042481    0.019096    0.603931    
#> 256: 0.454266    0.998001    3.435043    0.384332    0.042549    0.019150    0.603882    
#> 257: 0.453670    0.997944    3.434943    0.383740    0.042591    0.019192    0.603907    
#> 258: 0.453587    0.997600    3.435035    0.383489    0.042519    0.019215    0.604208    
#> 259: 0.453680    0.997557    3.435146    0.382699    0.042552    0.019214    0.604325    
#> 260: 0.453489    0.997752    3.435208    0.382607    0.042617    0.019195    0.604076    
#> 261: 0.453837    0.997644    3.435376    0.383305    0.042593    0.019166    0.603976    
#> 262: 0.453355    0.998036    3.435287    0.383027    0.042641    0.019144    0.603630    
#> 263: 0.452928    0.998447    3.435234    0.382770    0.042755    0.019183    0.603738    
#> 264: 0.452719    0.998492    3.435202    0.382618    0.043024    0.019116    0.603841    
#> 265: 0.452628    0.998591    3.435172    0.383161    0.043355    0.019062    0.603876    
#> 266: 0.452538    0.998837    3.435091    0.383095    0.043580    0.019004    0.603850    
#> 267: 0.452508    0.998908    3.435189    0.382987    0.043695    0.018939    0.603814    
#> 268: 0.452979    0.998886    3.435107    0.383037    0.043711    0.018870    0.603699    
#> 269: 0.453765    0.998791    3.435304    0.383232    0.043733    0.018858    0.603738    
#> 270: 0.454150    0.998915    3.435345    0.383732    0.043669    0.018826    0.603489    
#> 271: 0.454040    0.999106    3.435245    0.383959    0.043688    0.018803    0.603371    
#> 272: 0.454459    0.999017    3.435204    0.384328    0.043746    0.018769    0.603455    
#> 273: 0.454394    0.999303    3.435192    0.384181    0.043746    0.018768    0.603484    
#> 274: 0.454340    0.999381    3.435293    0.383392    0.043725    0.018734    0.603557    
#> 275: 0.454391    0.999582    3.435193    0.383344    0.043785    0.018691    0.603501    
#> 276: 0.454040    0.999763    3.435187    0.382692    0.043754    0.018706    0.603453    
#> 277: 0.453595    0.999884    3.435221    0.381979    0.043713    0.018734    0.603533    
#> 278: 0.453010    1.000073    3.435189    0.381338    0.043715    0.018718    0.603579    
#> 279: 0.452795    1.000037    3.435108    0.381991    0.043828    0.018773    0.603686    
#> 280: 0.452457    1.000245    3.435028    0.382213    0.043857    0.018779    0.603425    
#> 281: 0.452085    1.000515    3.434971    0.382131    0.043909    0.018752    0.603329    
#> 282: 0.452031    1.000765    3.434964    0.382684    0.044022    0.018759    0.603283    
#> 283: 0.451667    1.000835    3.434950    0.382914    0.044077    0.018770    0.603485    
#> 284: 0.451620    1.000594    3.434991    0.382250    0.043978    0.018795    0.603564    
#> 285: 0.451517    1.000587    3.434877    0.381664    0.043973    0.018834    0.603516    
#> 286: 0.451547    1.000717    3.434741    0.381669    0.043880    0.018892    0.603504    
#> 287: 0.451194    1.000952    3.434589    0.381556    0.043868    0.018944    0.603349    
#> 288: 0.451488    1.000976    3.434521    0.382241    0.043769    0.019015    0.603359    
#> 289: 0.452131    1.000820    3.434530    0.382681    0.043742    0.019050    0.603382    
#> 290: 0.452189    1.000804    3.434592    0.382404    0.043786    0.019070    0.603267    
#> 291: 0.452258    1.001002    3.434614    0.382031    0.043806    0.019061    0.602961    
#> 292: 0.452052    1.001129    3.434515    0.382426    0.043714    0.019050    0.602839    
#> 293: 0.451595    1.001207    3.434313    0.382200    0.043684    0.019060    0.602789    
#> 294: 0.451357    1.001404    3.434107    0.382163    0.043636    0.019067    0.602669    
#> 295: 0.451096    1.001356    3.434002    0.382064    0.043604    0.019088    0.602587    
#> 296: 0.451102    1.001302    3.433943    0.381751    0.043541    0.019108    0.602561    
#> 297: 0.450965    1.001326    3.433897    0.382255    0.043466    0.019101    0.602642    
#> 298: 0.450770    1.001241    3.433862    0.382432    0.043443    0.019078    0.602522    
#> 299: 0.450671    1.001466    3.433753    0.382993    0.043422    0.019107    0.602295    
#> 300: 0.450595    1.001514    3.433678    0.383045    0.043463    0.019160    0.602063    
#> 301: 0.450483    1.001547    3.433590    0.383295    0.043480    0.019183    0.602040    
#> 302: 0.450496    1.001684    3.433437    0.383588    0.043466    0.019202    0.601954    
#> 303: 0.450190    1.001933    3.433224    0.383717    0.043505    0.019225    0.601746    
#> 304: 0.449802    1.002294    3.432995    0.384091    0.043562    0.019243    0.601731    
#> 305: 0.449378    1.002274    3.432875    0.384280    0.043507    0.019292    0.601718    
#> 306: 0.448862    1.002237    3.432632    0.384392    0.043472    0.019349    0.601658    
#> 307: 0.448628    1.002280    3.432475    0.384134    0.043488    0.019393    0.601631    
#> 308: 0.448413    1.002309    3.432343    0.384768    0.043483    0.019421    0.601727    
#> 309: 0.448198    1.002276    3.432281    0.385074    0.043460    0.019437    0.601755    
#> 310: 0.448176    1.002272    3.432223    0.385488    0.043361    0.019470    0.601829    
#> 311: 0.448048    1.002260    3.432164    0.386188    0.043274    0.019513    0.601918    
#> 312: 0.447867    1.002208    3.432040    0.387365    0.043226    0.019536    0.601931    
#> 313: 0.447691    1.002102    3.431925    0.387804    0.043178    0.019555    0.601979    
#> 314: 0.447334    1.002215    3.431783    0.388145    0.043158    0.019592    0.601823    
#> 315: 0.447199    1.002220    3.431716    0.388875    0.043118    0.019637    0.601590    
#> 316: 0.447400    1.002454    3.431566    0.390400    0.043130    0.019687    0.601394    
#> 317: 0.447280    1.002599    3.431503    0.390826    0.043128    0.019705    0.601458    
#> 318: 0.447127    1.002699    3.431365    0.390911    0.043179    0.019749    0.601310    
#> 319: 0.447103    1.002756    3.431347    0.391209    0.043174    0.019775    0.601284    
#> 320: 0.446642    1.002723    3.431290    0.391174    0.043147    0.019783    0.601358    
#> 321: 0.446190    1.002819    3.431185    0.390788    0.043110    0.019782    0.601453    
#> 322: 0.446373    1.002845    3.431127    0.391337    0.043080    0.019808    0.601504    
#> 323: 0.446202    1.002935    3.431054    0.391681    0.043087    0.019834    0.601432    
#> 324: 0.446187    1.003063    3.431023    0.392222    0.043115    0.019855    0.601229    
#> 325: 0.446120    1.003274    3.430883    0.392711    0.043160    0.019849    0.601112    
#> 326: 0.446026    1.003258    3.430758    0.392941    0.043182    0.019849    0.601142    
#> 327: 0.445792    1.003415    3.430712    0.393214    0.043169    0.019870    0.601151    
#> 328: 0.445827    1.003549    3.430654    0.393370    0.043180    0.019870    0.601141    
#> 329: 0.445863    1.003664    3.430648    0.393345    0.043144    0.019857    0.601078    
#> 330: 0.445947    1.003803    3.430624    0.393597    0.043152    0.019861    0.601004    
#> 331: 0.446076    1.004029    3.430606    0.393609    0.043206    0.019847    0.600921    
#> 332: 0.446115    1.004074    3.430595    0.393879    0.043267    0.019821    0.600890    
#> 333: 0.445855    1.004044    3.430503    0.393861    0.043287    0.019818    0.600834    
#> 334: 0.445541    1.003980    3.430372    0.393734    0.043315    0.019828    0.600855    
#> 335: 0.445289    1.004088    3.430216    0.393609    0.043338    0.019827    0.600951    
#> 336: 0.444823    1.004166    3.430085    0.393548    0.043367    0.019850    0.600954    
#> 337: 0.444517    1.004357    3.429971    0.393500    0.043428    0.019859    0.600975    
#> 338: 0.444199    1.004476    3.429904    0.393452    0.043440    0.019837    0.600885    
#> 339: 0.443925    1.004574    3.429837    0.393215    0.043481    0.019836    0.600822    
#> 340: 0.443822    1.004448    3.429854    0.393323    0.043552    0.019849    0.600748    
#> 341: 0.443705    1.004406    3.429837    0.393084    0.043567    0.019857    0.600704    
#> 342: 0.443272    1.004376    3.429734    0.392841    0.043630    0.019833    0.600629    
#> 343: 0.443057    1.004440    3.429664    0.393054    0.043645    0.019835    0.600553    
#> 344: 0.443109    1.004459    3.429582    0.393876    0.043647    0.019827    0.600491    
#> 345: 0.442919    1.004491    3.429490    0.393778    0.043689    0.019816    0.600499    
#> 346: 0.442917    1.004538    3.429434    0.393687    0.043711    0.019805    0.600483    
#> 347: 0.443068    1.004497    3.429406    0.393457    0.043656    0.019797    0.600530    
#> 348: 0.442780    1.004550    3.429330    0.393176    0.043662    0.019783    0.600614    
#> 349: 0.442761    1.004464    3.429322    0.393332    0.043654    0.019789    0.600644    
#> 350: 0.442686    1.004336    3.429288    0.393221    0.043645    0.019766    0.600669    
#> 351: 0.442599    1.004458    3.429274    0.393062    0.043658    0.019734    0.600680    
#> 352: 0.442258    1.004599    3.429272    0.392768    0.043696    0.019717    0.600888    
#> 353: 0.442374    1.004769    3.429263    0.392653    0.043701    0.019700    0.600882    
#> 354: 0.442290    1.004788    3.429238    0.392012    0.043685    0.019693    0.600914    
#> 355: 0.442586    1.004727    3.429287    0.391917    0.043703    0.019671    0.601012    
#> 356: 0.442596    1.004663    3.429337    0.391949    0.043753    0.019649    0.601147    
#> 357: 0.442790    1.004677    3.429429    0.391919    0.043761    0.019643    0.601137    
#> 358: 0.442951    1.004619    3.429493    0.391822    0.043692    0.019666    0.601052    
#> 359: 0.443059    1.004722    3.429522    0.391755    0.043711    0.019687    0.600864    
#> 360: 0.443045    1.004824    3.429504    0.391606    0.043700    0.019707    0.600711    
#> 361: 0.443078    1.004835    3.429456    0.391655    0.043656    0.019736    0.600638    
#> 362: 0.443114    1.004842    3.429464    0.391700    0.043624    0.019742    0.600513    
#> 363: 0.443118    1.004789    3.429486    0.392029    0.043599    0.019777    0.600362    
#> 364: 0.443125    1.004826    3.429463    0.392207    0.043571    0.019818    0.600365    
#> 365: 0.443230    1.004677    3.429484    0.392461    0.043563    0.019881    0.600259    
#> 366: 0.443237    1.004703    3.429431    0.392494    0.043578    0.019939    0.600166    
#> 367: 0.443216    1.004698    3.429424    0.392325    0.043591    0.019968    0.600129    
#> 368: 0.443344    1.004762    3.429410    0.392378    0.043540    0.019966    0.600096    
#> 369: 0.443300    1.004754    3.429339    0.392316    0.043467    0.019973    0.600181    
#> 370: 0.443174    1.004751    3.429316    0.392107    0.043455    0.019987    0.600198    
#> 371: 0.443131    1.004749    3.429278    0.392277    0.043505    0.019994    0.600217    
#> 372: 0.442967    1.004790    3.429233    0.392351    0.043565    0.019989    0.600157    
#> 373: 0.442730    1.004923    3.429163    0.392168    0.043563    0.020000    0.600176    
#> 374: 0.442652    1.005029    3.429099    0.392130    0.043564    0.020009    0.600109    
#> 375: 0.442672    1.005082    3.429108    0.392257    0.043517    0.020039    0.600030    
#> 376: 0.442645    1.005163    3.429150    0.392013    0.043549    0.020041    0.599952    
#> 377: 0.442497    1.005202    3.429136    0.391813    0.043621    0.020019    0.599949    
#> 378: 0.442432    1.005210    3.429077    0.391342    0.043620    0.020004    0.599903    
#> 379: 0.442278    1.005123    3.429059    0.391271    0.043597    0.019987    0.599860    
#> 380: 0.442129    1.005109    3.429036    0.391340    0.043577    0.019984    0.599829    
#> 381: 0.442025    1.005027    3.429032    0.391319    0.043601    0.019994    0.599856    
#> 382: 0.441852    1.004974    3.429019    0.391280    0.043571    0.019995    0.599762    
#> 383: 0.441888    1.004945    3.429042    0.391533    0.043544    0.020005    0.599654    
#> 384: 0.441773    1.004862    3.429072    0.391557    0.043571    0.019992    0.599573    
#> 385: 0.441934    1.004832    3.429117    0.391898    0.043558    0.020003    0.599484    
#> 386: 0.442082    1.004933    3.429132    0.392153    0.043553    0.019993    0.599458    
#> 387: 0.442229    1.004957    3.429161    0.392208    0.043516    0.019997    0.599408    
#> 388: 0.442273    1.004965    3.429200    0.392057    0.043492    0.020010    0.599320    
#> 389: 0.442169    1.004875    3.429163    0.391872    0.043469    0.020011    0.599395    
#> 390: 0.441959    1.004914    3.429096    0.391407    0.043454    0.020007    0.599417    
#> 391: 0.442004    1.004948    3.429062    0.391318    0.043445    0.020017    0.599333    
#> 392: 0.442119    1.004902    3.429108    0.391567    0.043461    0.020007    0.599273    
#> 393: 0.442225    1.004839    3.429151    0.391625    0.043504    0.020003    0.599280    
#> 394: 0.442425    1.004803    3.429190    0.391928    0.043510    0.020021    0.599297    
#> 395: 0.442658    1.004825    3.429196    0.392107    0.043530    0.020026    0.599363    
#> 396: 0.443005    1.004738    3.429236    0.392870    0.043521    0.020046    0.599411    
#> 397: 0.442965    1.004676    3.429230    0.392998    0.043512    0.020050    0.599491    
#> 398: 0.443005    1.004567    3.429250    0.392974    0.043500    0.020051    0.599560    
#> 399: 0.442994    1.004586    3.429276    0.393327    0.043484    0.020056    0.599642    
#> 400: 0.443060    1.004660    3.429280    0.393460    0.043492    0.020055    0.599674    
#> 401: 0.443071    1.004770    3.429268    0.393294    0.043458    0.020079    0.599727    
#> 402: 0.442997    1.004911    3.429260    0.393147    0.043453    0.020106    0.599764    
#> 403: 0.443167    1.004949    3.429289    0.393161    0.043461    0.020120    0.599624    
#> 404: 0.443191    1.005066    3.429217    0.393264    0.043446    0.020140    0.599537    
#> 405: 0.442932    1.005184    3.429166    0.392895    0.043411    0.020148    0.599541    
#> 406: 0.442677    1.005344    3.429092    0.392571    0.043428    0.020137    0.599569    
#> 407: 0.442626    1.005446    3.429055    0.392524    0.043438    0.020110    0.599598    
#> 408: 0.442631    1.005563    3.429023    0.392237    0.043458    0.020090    0.599599    
#> 409: 0.442513    1.005569    3.428970    0.391988    0.043438    0.020061    0.599590    
#> 410: 0.442478    1.005598    3.428946    0.391972    0.043435    0.020033    0.599546    
#> 411: 0.442580    1.005545    3.428920    0.392102    0.043434    0.019998    0.599582    
#> 412: 0.442457    1.005598    3.428868    0.391922    0.043431    0.019983    0.599555    
#> 413: 0.442400    1.005657    3.428835    0.391889    0.043445    0.019966    0.599635    
#> 414: 0.442178    1.005652    3.428802    0.392203    0.043468    0.019944    0.599667    
#> 415: 0.442261    1.005650    3.428764    0.392602    0.043486    0.019938    0.599607    
#> 416: 0.442237    1.005684    3.428775    0.392602    0.043515    0.019929    0.599503    
#> 417: 0.442366    1.005721    3.428766    0.392865    0.043525    0.019914    0.599509    
#> 418: 0.442266    1.005704    3.428768    0.392631    0.043548    0.019894    0.599462    
#> 419: 0.442186    1.005754    3.428735    0.392711    0.043532    0.019869    0.599499    
#> 420: 0.442343    1.005700    3.428798    0.392678    0.043506    0.019865    0.599444    
#> 421: 0.442315    1.005674    3.428855    0.392389    0.043495    0.019861    0.599391    
#> 422: 0.442566    1.005524    3.428931    0.392529    0.043445    0.019878    0.599401    
#> 423: 0.442668    1.005440    3.428977    0.392372    0.043462    0.019880    0.599397    
#> 424: 0.442485    1.005356    3.428943    0.391979    0.043428    0.019885    0.599427    
#> 425: 0.442395    1.005410    3.428882    0.391912    0.043390    0.019899    0.599439    
#> 426: 0.442375    1.005497    3.428824    0.392204    0.043363    0.019920    0.599375    
#> 427: 0.442366    1.005519    3.428818    0.392629    0.043358    0.019953    0.599295    
#> 428: 0.442280    1.005571    3.428776    0.392747    0.043347    0.019974    0.599272    
#> 429: 0.442306    1.005613    3.428765    0.392771    0.043328    0.019995    0.599212    
#> 430: 0.442307    1.005658    3.428722    0.392803    0.043294    0.020007    0.599219    
#> 431: 0.442220    1.005680    3.428649    0.392902    0.043278    0.020011    0.599148    
#> 432: 0.442042    1.005786    3.428609    0.392870    0.043276    0.020013    0.599096    
#> 433: 0.442103    1.005862    3.428629    0.392845    0.043269    0.020026    0.599065    
#> 434: 0.442020    1.005811    3.428630    0.392812    0.043291    0.020033    0.599015    
#> 435: 0.442082    1.005774    3.428628    0.392861    0.043294    0.020045    0.598946    
#> 436: 0.442154    1.005740    3.428683    0.393011    0.043274    0.020051    0.598914    
#> 437: 0.442206    1.005681    3.428688    0.392916    0.043255    0.020046    0.598914    
#> 438: 0.442196    1.005703    3.428736    0.392821    0.043275    0.020033    0.598856    
#> 439: 0.442300    1.005704    3.428787    0.392790    0.043273    0.020025    0.598773    
#> 440: 0.442414    1.005678    3.428824    0.392701    0.043275    0.020013    0.598785    
#> 441: 0.442611    1.005636    3.428868    0.393164    0.043270    0.020007    0.598777    
#> 442: 0.442412    1.005676    3.428855    0.393068    0.043270    0.019996    0.598786    
#> 443: 0.442353    1.005811    3.428784    0.393032    0.043231    0.019999    0.598749    
#> 444: 0.442273    1.005911    3.428712    0.393091    0.043170    0.020010    0.598745    
#> 445: 0.442058    1.006060    3.428632    0.393214    0.043149    0.020010    0.598747    
#> 446: 0.441816    1.006220    3.428503    0.393324    0.043089    0.020016    0.598751    
#> 447: 0.441728    1.006336    3.428439    0.393508    0.043071    0.020034    0.598762    
#> 448: 0.441542    1.006344    3.428443    0.393472    0.043037    0.020062    0.598799    
#> 449: 0.441498    1.006408    3.428480    0.393287    0.043018    0.020075    0.598855    
#> 450: 0.441450    1.006419    3.428466    0.393136    0.042991    0.020094    0.598890    
#> 451: 0.441339    1.006446    3.428426    0.392983    0.042973    0.020101    0.598946    
#> 452: 0.441318    1.006515    3.428400    0.392902    0.042966    0.020112    0.598895    
#> 453: 0.441238    1.006544    3.428369    0.392824    0.042957    0.020110    0.598831    
#> 454: 0.441173    1.006631    3.428343    0.392665    0.042953    0.020108    0.598761    
#> 455: 0.441233    1.006634    3.428313    0.392601    0.042959    0.020102    0.598730    
#> 456: 0.441180    1.006668    3.428323    0.392562    0.042944    0.020110    0.598747    
#> 457: 0.441264    1.006598    3.428382    0.392583    0.042947    0.020113    0.598727    
#> 458: 0.441283    1.006628    3.428403    0.392640    0.042941    0.020114    0.598676    
#> 459: 0.441126    1.006732    3.428383    0.392672    0.042954    0.020113    0.598674    
#> 460: 0.441047    1.006772    3.428304    0.392930    0.042940    0.020128    0.598652    
#> 461: 0.440976    1.006841    3.428292    0.393014    0.042924    0.020155    0.598661    
#> 462: 0.440932    1.006890    3.428290    0.393163    0.042867    0.020179    0.598716    
#> 463: 0.441001    1.006948    3.428309    0.393197    0.042852    0.020178    0.598743    
#> 464: 0.441037    1.006989    3.428301    0.392997    0.042833    0.020191    0.598684    
#> 465: 0.441028    1.006926    3.428311    0.392800    0.042805    0.020213    0.598639    
#> 466: 0.440911    1.006925    3.428287    0.392531    0.042767    0.020224    0.598635    
#> 467: 0.440847    1.006925    3.428282    0.392623    0.042728    0.020246    0.598613    
#> 468: 0.440918    1.006931    3.428303    0.392591    0.042672    0.020276    0.598596    
#> 469: 0.440913    1.007029    3.428314    0.392539    0.042618    0.020298    0.598650    
#> 470: 0.440711    1.007113    3.428237    0.392362    0.042567    0.020318    0.598684    
#> 471: 0.440499    1.007165    3.428178    0.392308    0.042543    0.020320    0.598709    
#> 472: 0.440374    1.007141    3.428128    0.392381    0.042534    0.020328    0.598690    
#> 473: 0.440261    1.007144    3.428104    0.392269    0.042517    0.020329    0.598611    
#> 474: 0.440182    1.007169    3.428103    0.392004    0.042533    0.020330    0.598615    
#> 475: 0.440160    1.007201    3.428106    0.391794    0.042519    0.020337    0.598588    
#> 476: 0.440189    1.007202    3.428108    0.391721    0.042498    0.020337    0.598579    
#> 477: 0.440209    1.007240    3.428131    0.391646    0.042494    0.020344    0.598508    
#> 478: 0.440263    1.007262    3.428161    0.391855    0.042468    0.020351    0.598542    
#> 479: 0.440528    1.007289    3.428180    0.392481    0.042417    0.020359    0.598558    
#> 480: 0.440739    1.007279    3.428204    0.392826    0.042399    0.020373    0.598593    
#> 481: 0.440711    1.007312    3.428185    0.392942    0.042374    0.020376    0.598633    
#> 482: 0.440658    1.007354    3.428154    0.392936    0.042366    0.020382    0.598644    
#> 483: 0.440620    1.007347    3.428148    0.393148    0.042351    0.020389    0.598607    
#> 484: 0.440645    1.007244    3.428142    0.393620    0.042320    0.020396    0.598598    
#> 485: 0.440645    1.007238    3.428129    0.394006    0.042318    0.020404    0.598595    
#> 486: 0.440634    1.007260    3.428123    0.394211    0.042282    0.020404    0.598606    
#> 487: 0.440673    1.007330    3.428135    0.394334    0.042272    0.020412    0.598567    
#> 488: 0.440723    1.007270    3.428166    0.394422    0.042237    0.020428    0.598493    
#> 489: 0.440772    1.007221    3.428159    0.394564    0.042230    0.020432    0.598456    
#> 490: 0.440704    1.007178    3.428163    0.394588    0.042225    0.020433    0.598464    
#> 491: 0.440694    1.007178    3.428225    0.394368    0.042183    0.020450    0.598491    
#> 492: 0.440731    1.007192    3.428252    0.394228    0.042141    0.020460    0.598553    
#> 493: 0.440710    1.007243    3.428299    0.394023    0.042100    0.020494    0.598585    
#> 494: 0.440825    1.007294    3.428324    0.394006    0.042068    0.020521    0.598591    
#> 495: 0.440968    1.007352    3.428337    0.394219    0.042059    0.020540    0.598508    
#> 496: 0.441102    1.007441    3.428332    0.394167    0.042041    0.020557    0.598521    
#> 497: 0.441153    1.007461    3.428322    0.394251    0.042042    0.020558    0.598542    
#> 498: 0.441127    1.007463    3.428289    0.394240    0.042020    0.020565    0.598490    
#> 499: 0.441119    1.007528    3.428264    0.394264    0.042032    0.020568    0.598440    
#> 500: 0.441185    1.007488    3.428270    0.394445    0.042024    0.020570    0.598403    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.263654    0.970654    3.432238    0.392401    0.070002    0.016800    1.675622    
#> 002: 0.282195    0.949757    3.451059    0.372781    0.066502    0.019356    1.203061    
#> 003: 0.330801    0.879597    3.451283    0.354142    0.076110    0.018388    0.942800    
#> 004: 0.245244    0.865089    3.432398    0.336435    0.074836    0.017469    0.830220    
#> 005: 0.254601    0.880152    3.416092    0.319613    0.071094    0.016596    0.779543    
#> 006: 0.230723    0.885967    3.398054    0.303633    0.067540    0.015766    0.744432    
#> 007: 0.178640    0.909341    3.395493    0.288451    0.069134    0.014978    0.753265    
#> 008: 0.170863    0.912564    3.383086    0.274029    0.085815    0.014229    0.755141    
#> 009: 0.134246    0.887980    3.376907    0.260327    0.081524    0.013517    0.750766    
#> 010: 0.168731    0.894619    3.380886    0.247311    0.077448    0.013402    0.744129    
#> 011: 0.238192    0.895130    3.389215    0.234945    0.073576    0.013607    0.753308    
#> 012: 0.179271    0.909904    3.377258    0.223198    0.085652    0.012927    0.719436    
#> 013: 0.136336    0.925640    3.368666    0.212038    0.081369    0.013155    0.739570    
#> 014: 0.175090    0.905633    3.378474    0.201436    0.077301    0.014781    0.768192    
#> 015: 0.228727    0.912487    3.400534    0.198668    0.073436    0.014042    0.729961    
#> 016: 0.211501    0.923382    3.393579    0.189228    0.071240    0.014211    0.748540    
#> 017: 0.209105    0.922641    3.390110    0.179767    0.067678    0.014538    0.737040    
#> 018: 0.194783    0.925030    3.377502    0.236014    0.067102    0.017734    0.760050    
#> 019: 0.152346    0.924857    3.372212    0.224214    0.070067    0.016847    0.749641    
#> 020: 0.168359    0.917928    3.380739    0.213003    0.084564    0.016005    0.755339    
#> 021: 0.175973    0.899371    3.394721    0.202353    0.085485    0.015204    0.741574    
#> 022: 0.213310    0.892130    3.409507    0.192235    0.089526    0.014444    0.727934    
#> 023: 0.285990    0.893293    3.424662    0.219068    0.085049    0.014879    0.753394    
#> 024: 0.275465    0.900139    3.418038    0.208115    0.082316    0.014135    0.752355    
#> 025: 0.240053    0.858577    3.410835    0.197709    0.094084    0.013429    0.756672    
#> 026: 0.227550    0.887433    3.403246    0.187824    0.089379    0.012757    0.747579    
#> 027: 0.186932    0.904520    3.389293    0.178432    0.084910    0.012119    0.754250    
#> 028: 0.224991    0.898624    3.396962    0.169511    0.080665    0.011513    0.748722    
#> 029: 0.219672    0.905504    3.384222    0.231705    0.088274    0.010938    0.766618    
#> 030: 0.206031    0.906609    3.379461    0.220120    0.083861    0.010391    0.770025    
#> 031: 0.192727    0.878257    3.401369    0.209114    0.090023    0.011092    0.742916    
#> 032: 0.181567    0.880810    3.395667    0.198658    0.095197    0.011886    0.740921    
#> 033: 0.176077    0.903593    3.386825    0.188725    0.090437    0.011291    0.756005    
#> 034: 0.180445    0.916947    3.379421    0.179289    0.089992    0.010727    0.749645    
#> 035: 0.165081    0.898546    3.374457    0.170324    0.085492    0.010190    0.757412    
#> 036: 0.155038    0.925290    3.367933    0.185866    0.081218    0.009681    0.767693    
#> 037: 0.150328    0.933130    3.368878    0.176572    0.080557    0.009293    0.771177    
#> 038: 0.151461    0.920085    3.358903    0.167744    0.076530    0.010776    0.787974    
#> 039: 0.171458    0.909352    3.380750    0.167135    0.072703    0.010801    0.770501    
#> 040: 0.189783    0.931790    3.394154    0.191111    0.080675    0.013563    0.758808    
#> 041: 0.154194    0.911707    3.386012    0.181555    0.076641    0.012885    0.743250    
#> 042: 0.180813    0.907718    3.390671    0.172478    0.092361    0.012240    0.745792    
#> 043: 0.157434    0.921627    3.366240    0.163854    0.087742    0.011628    0.739773    
#> 044: 0.145494    0.929959    3.368875    0.159695    0.083355    0.011047    0.755678    
#> 045: 0.145490    0.946943    3.364328    0.197149    0.079188    0.010495    0.745131    
#> 046: 0.172044    0.925179    3.372897    0.187292    0.084713    0.009970    0.746423    
#> 047: 0.153646    0.933076    3.362737    0.177927    0.080477    0.009471    0.762037    
#> 048: 0.153338    0.919601    3.367871    0.169031    0.076790    0.008998    0.760801    
#> 049: 0.143643    0.912661    3.373286    0.168483    0.073461    0.009201    0.764428    
#> 050: 0.234986    0.871112    3.393882    0.163815    0.087528    0.011241    0.787450    
#> 051: 0.222530    0.913908    3.387659    0.169119    0.083152    0.011312    0.788364    
#> 052: 0.221620    0.922877    3.395447    0.167045    0.078994    0.012606    0.760130    
#> 053: 0.216269    0.878836    3.397235    0.158692    0.075044    0.015739    0.775478    
#> 054: 0.163994    0.892405    3.396882    0.150758    0.077447    0.017369    0.765639    
#> 055: 0.191741    0.903924    3.397258    0.143220    0.085318    0.016500    0.771541    
#> 056: 0.211442    0.882300    3.403309    0.136884    0.081052    0.015675    0.766396    
#> 057: 0.238670    0.879834    3.418321    0.133307    0.077440    0.014892    0.768740    
#> 058: 0.235389    0.880132    3.402483    0.136125    0.083438    0.014147    0.755536    
#> 059: 0.246474    0.865260    3.408482    0.141939    0.089652    0.013440    0.757890    
#> 060: 0.232671    0.861215    3.417942    0.178007    0.085169    0.018154    0.762467    
#> 061: 0.283977    0.851721    3.434410    0.169106    0.080911    0.025467    0.766465    
#> 062: 0.254482    0.871912    3.432490    0.210030    0.078480    0.024194    0.771099    
#> 063: 0.265218    0.857264    3.416201    0.199528    0.086064    0.022984    0.757898    
#> 064: 0.252772    0.890781    3.420800    0.189552    0.094877    0.021835    0.753383    
#> 065: 0.251286    0.870128    3.414795    0.180074    0.090133    0.020743    0.737025    
#> 066: 0.228350    0.896259    3.411097    0.183147    0.085626    0.019706    0.743920    
#> 067: 0.241514    0.881145    3.407553    0.183028    0.081345    0.022517    0.724427    
#> 068: 0.214814    0.894905    3.416572    0.185158    0.077278    0.021391    0.761143    
#> 069: 0.201764    0.890157    3.403645    0.184823    0.073414    0.020321    0.748022    
#> 070: 0.210913    0.892882    3.400115    0.203094    0.069743    0.019305    0.740838    
#> 071: 0.172416    0.912175    3.366480    0.192939    0.071067    0.018340    0.752297    
#> 072: 0.127597    0.899976    3.380439    0.183292    0.083568    0.017423    0.742395    
#> 073: 0.179504    0.910183    3.394658    0.174128    0.079390    0.016552    0.753008    
#> 074: 0.171011    0.878693    3.387102    0.165421    0.075420    0.015724    0.739914    
#> 075: 0.191983    0.887883    3.405794    0.172267    0.084084    0.014938    0.723985    
#> 076: 0.244914    0.895709    3.423880    0.191939    0.079879    0.014191    0.741661    
#> 077: 0.251071    0.872473    3.409186    0.182342    0.078788    0.013481    0.770156    
#> 078: 0.235892    0.883440    3.414674    0.173225    0.080480    0.012870    0.736031    
#> 079: 0.223286    0.895304    3.415202    0.164564    0.076456    0.015098    0.773670    
#> 080: 0.232003    0.885563    3.414557    0.156336    0.076279    0.014344    0.784893    
#> 081: 0.233302    0.901180    3.402325    0.148519    0.076724    0.013626    0.764665    
#> 082: 0.184622    0.886156    3.396062    0.176958    0.074810    0.014248    0.758794    
#> 083: 0.164963    0.920315    3.395188    0.168110    0.079835    0.013536    0.770012    
#> 084: 0.163727    0.917156    3.379962    0.207768    0.083864    0.012859    0.751024    
#> 085: 0.150763    0.920964    3.380066    0.197380    0.079671    0.013970    0.766069    
#> 086: 0.158712    0.933078    3.379855    0.187511    0.077629    0.014104    0.745312    
#> 087: 0.176078    0.914395    3.374377    0.188333    0.076924    0.013398    0.746578    
#> 088: 0.155604    0.913811    3.387677    0.193870    0.083857    0.017674    0.756720    
#> 089: 0.186159    0.924371    3.372056    0.188808    0.079664    0.017665    0.730507    
#> 090: 0.134466    0.915525    3.369918    0.179367    0.080172    0.017640    0.732784    
#> 091: 0.113771    0.915678    3.356138    0.170399    0.090451    0.020570    0.740578    
#> 092: 0.108600    0.944651    3.356887    0.198230    0.096205    0.020676    0.748542    
#> 093: 0.110336    0.914459    3.353013    0.188318    0.093051    0.019642    0.762186    
#> 094: 0.126721    0.923376    3.358028    0.185068    0.099295    0.018660    0.753080    
#> 095: 0.179216    0.918175    3.384752    0.175815    0.094330    0.017823    0.765024    
#> 096: 0.152490    0.924552    3.374480    0.173176    0.089613    0.016931    0.748458    
#> 097: 0.163416    0.930327    3.371182    0.187189    0.085133    0.016085    0.738211    
#> 098: 0.149198    0.948068    3.372802    0.186052    0.080876    0.015281    0.769975    
#> 099: 0.147544    0.911410    3.364570    0.176750    0.076832    0.014517    0.767156    
#> 100: 0.142608    0.907237    3.368033    0.176065    0.072991    0.013860    0.759965    
#> 101: 0.109519    0.913376    3.348096    0.178949    0.069341    0.013920    0.752983    
#> 102: 0.108337    0.929900    3.346573    0.185793    0.084412    0.015397    0.731268    
#> 103: 0.145606    0.940878    3.357807    0.207519    0.080191    0.014627    0.728046    
#> 104: 0.138025    0.948722    3.366615    0.205984    0.078915    0.013896    0.761596    
#> 105: 0.157346    0.910444    3.368791    0.195685    0.085670    0.013201    0.755936    
#> 106: 0.182360    0.912693    3.373919    0.185901    0.081386    0.012541    0.750722    
#> 107: 0.190735    0.918127    3.382248    0.176606    0.079311    0.011914    0.768452    
#> 108: 0.188936    0.896025    3.373590    0.172193    0.077655    0.015049    0.755185    
#> 109: 0.173492    0.906229    3.384129    0.164890    0.076755    0.015618    0.746690    
#> 110: 0.179759    0.901833    3.372934    0.168659    0.082014    0.015096    0.737784    
#> 111: 0.165212    0.924517    3.378997    0.174877    0.080435    0.014341    0.741316    
#> 112: 0.166564    0.898108    3.372909    0.166133    0.101881    0.013624    0.752362    
#> 113: 0.151715    0.940704    3.367357    0.170525    0.096787    0.012943    0.747236    
#> 114: 0.154784    0.932236    3.367126    0.183771    0.092627    0.013524    0.717122    
#> 115: 0.161023    0.922919    3.374183    0.183168    0.087996    0.012848    0.744456    
#> 116: 0.164406    0.912960    3.380240    0.174009    0.083596    0.012206    0.742020    
#> 117: 0.154456    0.919247    3.380628    0.172714    0.079416    0.011595    0.748300    
#> 118: 0.176793    0.913397    3.382073    0.164078    0.077877    0.011016    0.739810    
#> 119: 0.189435    0.929788    3.384763    0.155874    0.073983    0.016001    0.735780    
#> 120: 0.147365    0.911961    3.377951    0.153686    0.070306    0.015245    0.751962    
#> 121: 0.147758    0.931335    3.379494    0.146001    0.066791    0.014483    0.764187    
#> 122: 0.178341    0.899017    3.388222    0.167913    0.069953    0.013758    0.757084    
#> 123: 0.195364    0.926831    3.380582    0.207503    0.079148    0.013071    0.764183    
#> 124: 0.187899    0.954410    3.380352    0.212526    0.075190    0.012417    0.764435    
#> 125: 0.191597    0.946598    3.373349    0.201900    0.082580    0.011796    0.728360    
#> 126: 0.174506    0.945626    3.362636    0.191805    0.086916    0.011206    0.736548    
#> 127: 0.147703    0.923851    3.363523    0.182215    0.084904    0.010646    0.763126    
#> 128: 0.125181    0.924793    3.372528    0.173104    0.088804    0.010153    0.752873    
#> 129: 0.166719    0.941897    3.369498    0.164449    0.096675    0.009645    0.749251    
#> 130: 0.166270    0.954098    3.370925    0.187261    0.091841    0.009756    0.733289    
#> 131: 0.146462    0.928680    3.360923    0.197374    0.087249    0.010172    0.746416    
#> 132: 0.116252    0.937586    3.345987    0.188944    0.082886    0.009664    0.753961    
#> 133: 0.115991    0.936200    3.353207    0.204401    0.081466    0.009180    0.767798    
#> 134: 0.166825    0.910718    3.367096    0.194181    0.084050    0.010401    0.760598    
#> 135: 0.151702    0.905742    3.380743    0.197571    0.088164    0.011761    0.746757    
#> 136: 0.158737    0.890131    3.380295    0.199415    0.083756    0.011173    0.738165    
#> 137: 0.168495    0.885758    3.386720    0.189444    0.079568    0.010614    0.742291    
#> 138: 0.168929    0.909842    3.381392    0.179972    0.090192    0.010899    0.736424    
#> 139: 0.186616    0.914378    3.385898    0.170974    0.086023    0.015685    0.763712    
#> 140: 0.153120    0.921228    3.374720    0.162425    0.081722    0.016663    0.758571    
#> 141: 0.151851    0.894027    3.377747    0.154304    0.087424    0.015830    0.739936    
#> 142: 0.195358    0.900188    3.392408    0.153946    0.083053    0.015038    0.777824    
#> 143: 0.194513    0.939938    3.389967    0.160359    0.078900    0.015320    0.765002    
#> 144: 0.195948    0.929069    3.390575    0.152341    0.074955    0.014554    0.756095    
#> 145: 0.170087    0.930263    3.381077    0.154551    0.071208    0.014087    0.741257    
#> 146: 0.160016    0.941027    3.387116    0.180767    0.067647    0.013383    0.741077    
#> 147: 0.163598    0.901950    3.378821    0.172027    0.064265    0.012713    0.744937    
#> 148: 0.171490    0.923007    3.383325    0.177118    0.070653    0.012078    0.733185    
#> 149: 0.164727    0.905779    3.387504    0.181379    0.075621    0.011474    0.759704    
#> 150: 0.171691    0.894016    3.384993    0.172310    0.094526    0.010900    0.763742    
#> 151: 0.153666    0.911503    3.389432    0.163695    0.089800    0.010478    0.745534    
#> 152: 0.180007    0.907821    3.392964    0.201440    0.079658    0.014001    0.725646    
#> 153: 0.190583    0.925446    3.391344    0.211588    0.071073    0.011290    0.736810    
#> 154: 0.222586    0.937666    3.388326    0.215807    0.076080    0.013744    0.747571    
#> 155: 0.190386    0.918094    3.387998    0.213623    0.066306    0.013624    0.740512    
#> 156: 0.177166    0.904464    3.396747    0.207096    0.074011    0.014509    0.755921    
#> 157: 0.194419    0.894429    3.397851    0.217452    0.060600    0.017435    0.748574    
#> 158: 0.216016    0.915416    3.397991    0.204729    0.064474    0.019362    0.728466    
#> 159: 0.152848    0.920339    3.398067    0.182768    0.054048    0.019354    0.752320    
#> 160: 0.207114    0.877418    3.404949    0.202147    0.066272    0.018065    0.747298    
#> 161: 0.173624    0.900498    3.392051    0.194641    0.069158    0.020171    0.729579    
#> 162: 0.191159    0.933583    3.381924    0.194581    0.063368    0.018379    0.739146    
#> 163: 0.210638    0.926693    3.376901    0.175112    0.050432    0.017786    0.755621    
#> 164: 0.191508    0.909461    3.381075    0.189261    0.055253    0.021289    0.753887    
#> 165: 0.189817    0.902188    3.381539    0.178419    0.060416    0.016232    0.747245    
#> 166: 0.196208    0.926684    3.393034    0.193294    0.048843    0.014856    0.755937    
#> 167: 0.206247    0.917731    3.401483    0.190917    0.064368    0.014018    0.761066    
#> 168: 0.239794    0.905603    3.402671    0.213751    0.063529    0.017786    0.759904    
#> 169: 0.200383    0.951353    3.379939    0.168431    0.071265    0.014932    0.760722    
#> 170: 0.205183    0.915403    3.381564    0.180335    0.063477    0.012949    0.724845    
#> 171: 0.167635    0.913651    3.377566    0.191956    0.062237    0.011857    0.720286    
#> 172: 0.150536    0.945310    3.371461    0.171831    0.061867    0.010791    0.733645    
#> 173: 0.181538    0.948808    3.369244    0.200067    0.063684    0.015345    0.720175    
#> 174: 0.184428    0.937856    3.386697    0.190434    0.065265    0.013669    0.730664    
#> 175: 0.189194    0.932400    3.377803    0.201004    0.071266    0.015884    0.742844    
#> 176: 0.185900    0.936300    3.391116    0.205439    0.066670    0.014114    0.736631    
#> 177: 0.185026    0.924686    3.392860    0.187651    0.071136    0.017060    0.717853    
#> 178: 0.216301    0.901346    3.393843    0.153931    0.075182    0.015106    0.722118    
#> 179: 0.198179    0.933340    3.385667    0.127821    0.083642    0.013003    0.749274    
#> 180: 0.184994    0.898285    3.392240    0.146844    0.081718    0.012417    0.743986    
#> 181: 0.177587    0.911216    3.369346    0.157291    0.077091    0.012333    0.756219    
#> 182: 0.133407    0.937345    3.357667    0.171832    0.087103    0.010793    0.766151    
#> 183: 0.139137    0.959174    3.355764    0.194031    0.072832    0.008749    0.751694    
#> 184: 0.143243    0.929368    3.360152    0.193231    0.081004    0.009429    0.746862    
#> 185: 0.103408    0.944363    3.365087    0.161058    0.060351    0.010053    0.763409    
#> 186: 0.138425    0.955547    3.374354    0.145537    0.074354    0.010343    0.754137    
#> 187: 0.149606    0.927582    3.374344    0.163680    0.066041    0.011238    0.750809    
#> 188: 0.149334    0.946960    3.371456    0.166178    0.075039    0.012440    0.757392    
#> 189: 0.174248    0.932384    3.382569    0.177386    0.085847    0.011560    0.733913    
#> 190: 0.177410    0.930497    3.385924    0.160699    0.081857    0.008157    0.738985    
#> 191: 0.153188    0.916981    3.378869    0.152823    0.070634    0.008558    0.753387    
#> 192: 0.160308    0.932343    3.382222    0.158534    0.083588    0.008376    0.755752    
#> 193: 0.194408    0.933835    3.385076    0.140659    0.082979    0.011063    0.734548    
#> 194: 0.177703    0.927164    3.372141    0.168897    0.078794    0.011161    0.740424    
#> 195: 0.147978    0.933261    3.369908    0.132674    0.068763    0.011496    0.749862    
#> 196: 0.135586    0.913473    3.372177    0.167221    0.081082    0.011440    0.758239    
#> 197: 0.162860    0.919638    3.393735    0.208290    0.069024    0.014575    0.759546    
#> 198: 0.209777    0.893443    3.391878    0.192000    0.073879    0.018011    0.755592    
#> 199: 0.195979    0.890254    3.393185    0.224079    0.073499    0.014079    0.755134    
#> 200: 0.179850    0.902909    3.385008    0.197365    0.068973    0.013122    0.764601    
#> 201: 0.163884    0.898096    3.383255    0.192619    0.072299    0.013631    0.755240    
#> 202: 0.163785    0.903431    3.380837    0.196130    0.070098    0.013895    0.751803    
#> 203: 0.182391    0.904900    3.381628    0.197501    0.070579    0.014199    0.746604    
#> 204: 0.186426    0.900500    3.385518    0.196299    0.070370    0.014292    0.749212    
#> 205: 0.182775    0.905346    3.385663    0.197232    0.070965    0.014828    0.748980    
#> 206: 0.181691    0.910452    3.385212    0.201214    0.069472    0.014296    0.750548    
#> 207: 0.179584    0.910770    3.382396    0.198178    0.066185    0.014209    0.751487    
#> 208: 0.178834    0.912534    3.382194    0.197151    0.065369    0.014305    0.749129    
#> 209: 0.182231    0.909896    3.381653    0.196835    0.065676    0.014359    0.749132    
#> 210: 0.185176    0.907095    3.382620    0.194983    0.065772    0.014545    0.748430    
#> 211: 0.188926    0.907395    3.384063    0.195582    0.066463    0.014346    0.746420    
#> 212: 0.191314    0.907014    3.385134    0.193830    0.066050    0.014443    0.745933    
#> 213: 0.195781    0.906133    3.386141    0.193901    0.065274    0.014294    0.748632    
#> 214: 0.198860    0.905882    3.386638    0.196646    0.065386    0.014198    0.749323    
#> 215: 0.199152    0.906824    3.387122    0.194793    0.066180    0.014050    0.749396    
#> 216: 0.199653    0.906153    3.386964    0.194073    0.066234    0.013834    0.752341    
#> 217: 0.200229    0.907594    3.387179    0.192211    0.066608    0.013810    0.752497    
#> 218: 0.199385    0.908686    3.386888    0.191911    0.066067    0.013809    0.752262    
#> 219: 0.198354    0.908499    3.385887    0.191893    0.065867    0.013928    0.752521    
#> 220: 0.196051    0.909397    3.385330    0.192941    0.066022    0.013991    0.752520    
#> 221: 0.194254    0.908996    3.385027    0.191907    0.066507    0.014002    0.753384    
#> 222: 0.194204    0.908490    3.384892    0.191665    0.067146    0.013981    0.753829    
#> 223: 0.195692    0.908484    3.384828    0.191708    0.067517    0.013975    0.752975    
#> 224: 0.196493    0.909331    3.384995    0.191409    0.067715    0.014015    0.751858    
#> 225: 0.196716    0.907582    3.385971    0.190713    0.067917    0.014002    0.751925    
#> 226: 0.196480    0.906417    3.385882    0.190506    0.067830    0.014018    0.751702    
#> 227: 0.195397    0.906631    3.386127    0.189015    0.067779    0.014067    0.751792    
#> 228: 0.193848    0.907419    3.385502    0.188111    0.067677    0.014159    0.752142    
#> 229: 0.192260    0.907538    3.385024    0.187642    0.067528    0.014188    0.751454    
#> 230: 0.192417    0.907143    3.384692    0.187659    0.067600    0.014137    0.751012    
#> 231: 0.192500    0.907923    3.384908    0.187995    0.067663    0.014142    0.750577    
#> 232: 0.191991    0.908701    3.384958    0.187636    0.067570    0.014140    0.750349    
#> 233: 0.191756    0.908590    3.384757    0.187630    0.067401    0.014136    0.750103    
#> 234: 0.190924    0.908603    3.384574    0.187382    0.067358    0.014217    0.749640    
#> 235: 0.191200    0.908328    3.384529    0.186232    0.067438    0.014175    0.750039    
#> 236: 0.190765    0.908950    3.384235    0.185749    0.067786    0.014120    0.750686    
#> 237: 0.191334    0.909498    3.384311    0.185344    0.067898    0.014118    0.751393    
#> 238: 0.191307    0.909647    3.384462    0.185342    0.068232    0.014135    0.751953    
#> 239: 0.190769    0.909966    3.384445    0.184712    0.068207    0.014104    0.752025    
#> 240: 0.190706    0.909742    3.384557    0.184704    0.068239    0.014044    0.751623    
#> 241: 0.190711    0.909026    3.384806    0.184930    0.068521    0.014009    0.751226    
#> 242: 0.190334    0.908757    3.384691    0.184939    0.068883    0.013971    0.751522    
#> 243: 0.189445    0.909631    3.384412    0.183651    0.069010    0.013959    0.752221    
#> 244: 0.189040    0.909837    3.384587    0.183825    0.069398    0.013879    0.752569    
#> 245: 0.189574    0.909435    3.384882    0.183795    0.069458    0.013852    0.752751    
#> 246: 0.189863    0.909246    3.385100    0.183413    0.069530    0.013838    0.752827    
#> 247: 0.189720    0.909150    3.385362    0.183259    0.069737    0.013884    0.752557    
#> 248: 0.189309    0.909415    3.385290    0.183337    0.070031    0.013950    0.752064    
#> 249: 0.188282    0.909668    3.385160    0.182895    0.070172    0.013958    0.751873    
#> 250: 0.188448    0.910075    3.385100    0.182411    0.070222    0.014005    0.751803    
#> 251: 0.188764    0.910260    3.385253    0.182329    0.070582    0.013958    0.751610    
#> 252: 0.189233    0.910155    3.385738    0.181455    0.070737    0.013982    0.751587    
#> 253: 0.188897    0.910313    3.385841    0.181229    0.070770    0.013988    0.751382    
#> 254: 0.188660    0.910786    3.385728    0.181138    0.070860    0.014006    0.751145    
#> 255: 0.188718    0.911276    3.385740    0.181179    0.071054    0.014051    0.750881    
#> 256: 0.188825    0.911494    3.385812    0.180437    0.071155    0.014140    0.750809    
#> 257: 0.188235    0.911171    3.385843    0.180143    0.071022    0.014146    0.751320    
#> 258: 0.188409    0.910815    3.385918    0.179735    0.070850    0.014204    0.751222    
#> 259: 0.188390    0.910638    3.386013    0.178911    0.070891    0.014180    0.751237    
#> 260: 0.188360    0.910720    3.386223    0.178819    0.070932    0.014118    0.751075    
#> 261: 0.189042    0.910363    3.386543    0.179012    0.071129    0.014076    0.750530    
#> 262: 0.189142    0.910729    3.386679    0.178768    0.071452    0.014018    0.750621    
#> 263: 0.189088    0.911162    3.386576    0.178758    0.071775    0.014030    0.750429    
#> 264: 0.188630    0.911535    3.386377    0.179109    0.071983    0.013986    0.750691    
#> 265: 0.188150    0.911932    3.385988    0.179954    0.072418    0.013964    0.750459    
#> 266: 0.188006    0.912602    3.385690    0.180434    0.072503    0.013973    0.750174    
#> 267: 0.187959    0.912835    3.385534    0.180274    0.072614    0.013940    0.750188    
#> 268: 0.187525    0.912880    3.385230    0.180556    0.072546    0.013941    0.750052    
#> 269: 0.187625    0.912889    3.385088    0.180979    0.072475    0.013983    0.749790    
#> 270: 0.187643    0.913078    3.384884    0.181324    0.072637    0.013951    0.749424    
#> 271: 0.187336    0.913259    3.384720    0.181521    0.072933    0.013926    0.749598    
#> 272: 0.187477    0.912944    3.384722    0.181972    0.073158    0.013884    0.749819    
#> 273: 0.187229    0.913032    3.384713    0.182211    0.073367    0.013827    0.749809    
#> 274: 0.186734    0.913007    3.384707    0.182027    0.073543    0.013792    0.749853    
#> 275: 0.186563    0.913040    3.384527    0.182008    0.073718    0.013752    0.749865    
#> 276: 0.186527    0.913252    3.384600    0.181703    0.073870    0.013695    0.749852    
#> 277: 0.186252    0.913410    3.384722    0.181347    0.073968    0.013644    0.749852    
#> 278: 0.186320    0.913233    3.384847    0.180997    0.074067    0.013597    0.749855    
#> 279: 0.186114    0.912936    3.384955    0.180806    0.074031    0.013593    0.749864    
#> 280: 0.186172    0.912935    3.385092    0.180457    0.074012    0.013609    0.749741    
#> 281: 0.186136    0.912856    3.385260    0.180139    0.074013    0.013627    0.749681    
#> 282: 0.186429    0.912942    3.385400    0.179780    0.073961    0.013611    0.749867    
#> 283: 0.186694    0.913132    3.385508    0.179323    0.073805    0.013583    0.750288    
#> 284: 0.186586    0.913106    3.385555    0.178821    0.073820    0.013528    0.750308    
#> 285: 0.186239    0.913303    3.385319    0.178541    0.073859    0.013498    0.750382    
#> 286: 0.185832    0.913467    3.385074    0.178515    0.074015    0.013501    0.750369    
#> 287: 0.185515    0.913686    3.384916    0.178521    0.074161    0.013499    0.750449    
#> 288: 0.185419    0.913466    3.384895    0.178708    0.074191    0.013509    0.750476    
#> 289: 0.185385    0.913464    3.384821    0.179008    0.074162    0.013489    0.750456    
#> 290: 0.185286    0.913456    3.384787    0.178941    0.074189    0.013507    0.750413    
#> 291: 0.185583    0.913422    3.384945    0.178697    0.074266    0.013520    0.750282    
#> 292: 0.185508    0.913313    3.385048    0.178341    0.074361    0.013525    0.750246    
#> 293: 0.185257    0.913286    3.384980    0.178430    0.074329    0.013500    0.750016    
#> 294: 0.185040    0.913424    3.384838    0.178456    0.074217    0.013512    0.749868    
#> 295: 0.184701    0.913342    3.384722    0.178506    0.074165    0.013529    0.749673    
#> 296: 0.184558    0.913353    3.384719    0.178430    0.074135    0.013536    0.749753    
#> 297: 0.184914    0.913447    3.384767    0.178227    0.074085    0.013555    0.749760    
#> 298: 0.184926    0.913543    3.384750    0.178492    0.074058    0.013546    0.749779    
#> 299: 0.184733    0.913688    3.384628    0.178812    0.074166    0.013524    0.749566    
#> 300: 0.184617    0.913664    3.384663    0.178689    0.074250    0.013534    0.749376    
#> 301: 0.184731    0.913566    3.384624    0.178998    0.074362    0.013555    0.749184    
#> 302: 0.184797    0.913637    3.384555    0.179182    0.074417    0.013550    0.749086    
#> 303: 0.184576    0.913795    3.384468    0.179170    0.074392    0.013546    0.748906    
#> 304: 0.184661    0.913946    3.384394    0.179077    0.074294    0.013524    0.749047    
#> 305: 0.184459    0.913685    3.384374    0.178965    0.074230    0.013500    0.748954    
#> 306: 0.184115    0.913584    3.384290    0.178893    0.074193    0.013467    0.748830    
#> 307: 0.184140    0.913626    3.384321    0.178699    0.074316    0.013466    0.748917    
#> 308: 0.183919    0.913665    3.384211    0.178800    0.074456    0.013466    0.749015    
#> 309: 0.183773    0.913480    3.384099    0.178831    0.074539    0.013489    0.749122    
#> 310: 0.183699    0.913493    3.383972    0.178924    0.074632    0.013474    0.749151    
#> 311: 0.183676    0.913617    3.383939    0.178899    0.074717    0.013454    0.748972    
#> 312: 0.183477    0.913598    3.383855    0.178900    0.074716    0.013456    0.748908    
#> 313: 0.183376    0.913299    3.383844    0.178923    0.074704    0.013458    0.748944    
#> 314: 0.183138    0.913296    3.383862    0.179082    0.074767    0.013484    0.748817    
#> 315: 0.183070    0.913381    3.383886    0.179252    0.074684    0.013499    0.748826    
#> 316: 0.183023    0.913612    3.383773    0.179677    0.074545    0.013499    0.748927    
#> 317: 0.183025    0.913774    3.383820    0.180029    0.074447    0.013527    0.749157    
#> 318: 0.182868    0.913846    3.383710    0.179958    0.074396    0.013529    0.749190    
#> 319: 0.182751    0.913781    3.383713    0.180020    0.074402    0.013539    0.749306    
#> 320: 0.182442    0.913829    3.383536    0.179874    0.074368    0.013510    0.749525    
#> 321: 0.181894    0.913930    3.383293    0.179392    0.074245    0.013491    0.749776    
#> 322: 0.181717    0.914142    3.383063    0.179464    0.074170    0.013473    0.749945    
#> 323: 0.181206    0.914209    3.382959    0.179473    0.074092    0.013439    0.750046    
#> 324: 0.181130    0.914469    3.382841    0.179489    0.074191    0.013432    0.749901    
#> 325: 0.181030    0.914781    3.382695    0.179499    0.074204    0.013424    0.749824    
#> 326: 0.180932    0.914746    3.382581    0.179376    0.074197    0.013409    0.749848    
#> 327: 0.181022    0.914741    3.382575    0.179371    0.074268    0.013409    0.749770    
#> 328: 0.181235    0.914796    3.382594    0.179449    0.074331    0.013401    0.749664    
#> 329: 0.181266    0.914785    3.382621    0.179468    0.074400    0.013402    0.749697    
#> 330: 0.180985    0.914866    3.382549    0.179505    0.074477    0.013398    0.749617    
#> 331: 0.180796    0.915077    3.382435    0.179534    0.074554    0.013397    0.749458    
#> 332: 0.180757    0.915184    3.382428    0.179798    0.074507    0.013373    0.749583    
#> 333: 0.180410    0.915450    3.382288    0.179626    0.074527    0.013351    0.749604    
#> 334: 0.180313    0.915445    3.382155    0.179679    0.074557    0.013350    0.749499    
#> 335: 0.180152    0.915496    3.381971    0.179731    0.074693    0.013333    0.749451    
#> 336: 0.179815    0.915772    3.381785    0.179995    0.074842    0.013325    0.749418    
#> 337: 0.179566    0.916179    3.381596    0.179887    0.075059    0.013324    0.749448    
#> 338: 0.179407    0.916287    3.381556    0.179733    0.075183    0.013323    0.749385    
#> 339: 0.179212    0.916454    3.381506    0.179591    0.075178    0.013323    0.749371    
#> 340: 0.179131    0.916245    3.381570    0.179246    0.075252    0.013324    0.749397    
#> 341: 0.179357    0.916146    3.381649    0.178867    0.075232    0.013333    0.749512    
#> 342: 0.179254    0.916018    3.381690    0.178530    0.075049    0.013335    0.749559    
#> 343: 0.179177    0.915922    3.381723    0.178610    0.074924    0.013339    0.749451    
#> 344: 0.179485    0.915678    3.381795    0.178715    0.074834    0.013351    0.749474    
#> 345: 0.179643    0.915647    3.381849    0.178574    0.074713    0.013366    0.749543    
#> 346: 0.179645    0.915758    3.381746    0.178375    0.074644    0.013355    0.749463    
#> 347: 0.179632    0.915668    3.381684    0.178153    0.074612    0.013351    0.749581    
#> 348: 0.179451    0.915835    3.381612    0.178039    0.074638    0.013352    0.749679    
#> 349: 0.179530    0.915670    3.381650    0.178039    0.074588    0.013338    0.749701    
#> 350: 0.179391    0.915510    3.381600    0.178219    0.074503    0.013339    0.749674    
#> 351: 0.179455    0.915644    3.381580    0.178256    0.074447    0.013343    0.749758    
#> 352: 0.179229    0.915757    3.381591    0.178324    0.074429    0.013361    0.749908    
#> 353: 0.179228    0.915946    3.381523    0.178307    0.074358    0.013369    0.749985    
#> 354: 0.179289    0.915810    3.381523    0.177946    0.074290    0.013356    0.750067    
#> 355: 0.179560    0.915576    3.381547    0.177648    0.074323    0.013369    0.750139    
#> 356: 0.179458    0.915383    3.381603    0.177560    0.074331    0.013379    0.750260    
#> 357: 0.179445    0.915311    3.381618    0.177434    0.074360    0.013366    0.750283    
#> 358: 0.179516    0.915142    3.381697    0.177535    0.074395    0.013365    0.750277    
#> 359: 0.179411    0.915112    3.381692    0.177664    0.074364    0.013360    0.750267    
#> 360: 0.179109    0.915165    3.381561    0.177798    0.074324    0.013373    0.750172    
#> 361: 0.178863    0.915165    3.381492    0.177937    0.074255    0.013375    0.750134    
#> 362: 0.178773    0.915168    3.381410    0.177961    0.074172    0.013378    0.750064    
#> 363: 0.178590    0.915132    3.381353    0.178150    0.074122    0.013391    0.750002    
#> 364: 0.178651    0.915134    3.381326    0.178460    0.074065    0.013415    0.750000    
#> 365: 0.178601    0.915081    3.381343    0.178664    0.073970    0.013440    0.750070    
#> 366: 0.178537    0.915172    3.381286    0.178780    0.073920    0.013437    0.750083    
#> 367: 0.178690    0.915218    3.381317    0.178673    0.073946    0.013428    0.750051    
#> 368: 0.178850    0.915191    3.381337    0.178475    0.073924    0.013429    0.750038    
#> 369: 0.178830    0.915115    3.381321    0.178315    0.073958    0.013436    0.750083    
#> 370: 0.178823    0.915124    3.381333    0.178071    0.073931    0.013462    0.750117    
#> 371: 0.178718    0.915238    3.381261    0.177921    0.073958    0.013476    0.750090    
#> 372: 0.178571    0.915383    3.381162    0.177870    0.073927    0.013465    0.750087    
#> 373: 0.178345    0.915544    3.381047    0.177632    0.073903    0.013459    0.750242    
#> 374: 0.178244    0.915602    3.380965    0.177415    0.073911    0.013454    0.750265    
#> 375: 0.177986    0.915591    3.380903    0.177337    0.073871    0.013446    0.750370    
#> 376: 0.177912    0.915637    3.380916    0.177189    0.073872    0.013434    0.750353    
#> 377: 0.177784    0.915704    3.380891    0.176882    0.073873    0.013433    0.750392    
#> 378: 0.177673    0.915698    3.380886    0.176694    0.073849    0.013425    0.750581    
#> 379: 0.177510    0.915534    3.380885    0.176430    0.073857    0.013414    0.750662    
#> 380: 0.177421    0.915553    3.380862    0.176254    0.073882    0.013415    0.750639    
#> 381: 0.177194    0.915588    3.380847    0.176012    0.073923    0.013425    0.750707    
#> 382: 0.177153    0.915554    3.380890    0.175945    0.073880    0.013413    0.750691    
#> 383: 0.177402    0.915516    3.380964    0.175971    0.073878    0.013409    0.750636    
#> 384: 0.177277    0.915430    3.381006    0.176077    0.073808    0.013403    0.750703    
#> 385: 0.177256    0.915353    3.381037    0.176032    0.073743    0.013396    0.750816    
#> 386: 0.177463    0.915348    3.381141    0.175913    0.073695    0.013410    0.750863    
#> 387: 0.177657    0.915301    3.381275    0.175925    0.073634    0.013425    0.750879    
#> 388: 0.177769    0.915253    3.381340    0.175921    0.073627    0.013433    0.750829    
#> 389: 0.177744    0.915137    3.381374    0.175702    0.073653    0.013433    0.750948    
#> 390: 0.177658    0.915132    3.381388    0.175491    0.073640    0.013435    0.750905    
#> 391: 0.177737    0.915063    3.381423    0.175537    0.073608    0.013431    0.750841    
#> 392: 0.177791    0.915051    3.381486    0.175710    0.073549    0.013423    0.750858    
#> 393: 0.177760    0.914998    3.381476    0.175782    0.073541    0.013409    0.750907    
#> 394: 0.177733    0.915020    3.381440    0.175935    0.073452    0.013400    0.750910    
#> 395: 0.177955    0.915144    3.381411    0.176232    0.073409    0.013395    0.750882    
#> 396: 0.178109    0.915189    3.381401    0.176417    0.073402    0.013400    0.750759    
#> 397: 0.178257    0.915073    3.381453    0.176523    0.073305    0.013419    0.750715    
#> 398: 0.178381    0.914992    3.381506    0.176664    0.073307    0.013416    0.750784    
#> 399: 0.178601    0.914934    3.381585    0.176760    0.073307    0.013415    0.750748    
#> 400: 0.178665    0.914987    3.381660    0.176725    0.073325    0.013415    0.750722    
#> 401: 0.178823    0.915017    3.381693    0.176696    0.073332    0.013407    0.750748    
#> 402: 0.178865    0.915083    3.381717    0.176703    0.073286    0.013401    0.750887    
#> 403: 0.179123    0.915116    3.381754    0.176735    0.073310    0.013375    0.750878    
#> 404: 0.179197    0.915129    3.381732    0.176731    0.073293    0.013367    0.750778    
#> 405: 0.179218    0.915079    3.381772    0.176763    0.073324    0.013368    0.750707    
#> 406: 0.179405    0.915059    3.381835    0.176611    0.073289    0.013374    0.750742    
#> 407: 0.179456    0.915048    3.381885    0.176481    0.073304    0.013381    0.750671    
#> 408: 0.179499    0.915110    3.381897    0.176354    0.073367    0.013383    0.750767    
#> 409: 0.179419    0.915037    3.381894    0.176252    0.073452    0.013390    0.750723    
#> 410: 0.179301    0.915112    3.381774    0.176253    0.073484    0.013400    0.750691    
#> 411: 0.179365    0.915032    3.381752    0.176410    0.073577    0.013420    0.750687    
#> 412: 0.179439    0.915163    3.381716    0.176494    0.073622    0.013429    0.750716    
#> 413: 0.179453    0.915183    3.381675    0.176793    0.073614    0.013436    0.750649    
#> 414: 0.179230    0.915194    3.381652    0.177087    0.073596    0.013449    0.750525    
#> 415: 0.179244    0.915181    3.381640    0.177235    0.073504    0.013470    0.750409    
#> 416: 0.179284    0.915250    3.381666    0.177264    0.073471    0.013464    0.750316    
#> 417: 0.179345    0.915206    3.381721    0.177275    0.073503    0.013474    0.750218    
#> 418: 0.179301    0.915203    3.381778    0.177234    0.073558    0.013477    0.750114    
#> 419: 0.179385    0.915284    3.381823    0.177402    0.073545    0.013482    0.750056    
#> 420: 0.179427    0.915293    3.381859    0.177509    0.073579    0.013480    0.749948    
#> 421: 0.179296    0.915266    3.381913    0.177490    0.073601    0.013490    0.749909    
#> 422: 0.179504    0.915158    3.381969    0.177630    0.073564    0.013504    0.749850    
#> 423: 0.179628    0.915106    3.381983    0.177524    0.073519    0.013515    0.749871    
#> 424: 0.179536    0.915120    3.381953    0.177533    0.073449    0.013518    0.749855    
#> 425: 0.179612    0.915175    3.381925    0.177393    0.073429    0.013531    0.749896    
#> 426: 0.179674    0.915270    3.381937    0.177432    0.073392    0.013533    0.749913    
#> 427: 0.179584    0.915281    3.381950    0.177411    0.073400    0.013538    0.749846    
#> 428: 0.179585    0.915307    3.381964    0.177456    0.073387    0.013559    0.749778    
#> 429: 0.179624    0.915332    3.382013    0.177338    0.073353    0.013570    0.749747    
#> 430: 0.179606    0.915394    3.382032    0.177334    0.073345    0.013582    0.749734    
#> 431: 0.179532    0.915378    3.381991    0.177363    0.073296    0.013577    0.749678    
#> 432: 0.179469    0.915427    3.382007    0.177487    0.073274    0.013576    0.749601    
#> 433: 0.179449    0.915561    3.381998    0.177504    0.073258    0.013576    0.749587    
#> 434: 0.179347    0.915535    3.381978    0.177552    0.073244    0.013575    0.749568    
#> 435: 0.179238    0.915600    3.381917    0.177661    0.073258    0.013575    0.749518    
#> 436: 0.179149    0.915596    3.381881    0.177789    0.073334    0.013564    0.749570    
#> 437: 0.179053    0.915577    3.381830    0.177937    0.073375    0.013575    0.749541    
#> 438: 0.178910    0.915745    3.381790    0.178048    0.073502    0.013562    0.749504    
#> 439: 0.178845    0.915852    3.381750    0.178129    0.073562    0.013565    0.749345    
#> 440: 0.178738    0.915959    3.381735    0.178158    0.073597    0.013569    0.749330    
#> 441: 0.178813    0.915973    3.381770    0.178258    0.073572    0.013571    0.749265    
#> 442: 0.178719    0.916030    3.381771    0.178250    0.073548    0.013564    0.749197    
#> 443: 0.178663    0.916085    3.381728    0.178333    0.073610    0.013547    0.749186    
#> 444: 0.178541    0.916139    3.381620    0.178416    0.073673    0.013533    0.749153    
#> 445: 0.178417    0.916195    3.381538    0.178391    0.073712    0.013542    0.749097    
#> 446: 0.178235    0.916233    3.381474    0.178484    0.073694    0.013535    0.749067    
#> 447: 0.178245    0.916258    3.381435    0.178559    0.073713    0.013519    0.749057    
#> 448: 0.178180    0.916216    3.381458    0.178538    0.073717    0.013505    0.749017    
#> 449: 0.178232    0.916251    3.381557    0.178619    0.073693    0.013501    0.749012    
#> 450: 0.178276    0.916174    3.381576    0.178628    0.073677    0.013491    0.749082    
#> 451: 0.178404    0.916181    3.381581    0.178690    0.073585    0.013498    0.749185    
#> 452: 0.178188    0.916269    3.381478    0.178871    0.073582    0.013499    0.749183    
#> 453: 0.178031    0.916343    3.381386    0.179063    0.073632    0.013486    0.749104    
#> 454: 0.178004    0.916417    3.381349    0.179055    0.073637    0.013475    0.749062    
#> 455: 0.177924    0.916434    3.381333    0.179015    0.073622    0.013461    0.749131    
#> 456: 0.177772    0.916422    3.381302    0.179034    0.073595    0.013453    0.749210    
#> 457: 0.177750    0.916445    3.381298    0.179059    0.073518    0.013451    0.749232    
#> 458: 0.177632    0.916486    3.381333    0.178991    0.073484    0.013456    0.749188    
#> 459: 0.177520    0.916617    3.381318    0.178886    0.073507    0.013455    0.749144    
#> 460: 0.177452    0.916652    3.381261    0.178882    0.073508    0.013451    0.749077    
#> 461: 0.177359    0.916679    3.381266    0.178894    0.073549    0.013439    0.749135    
#> 462: 0.177259    0.916774    3.381263    0.178988    0.073594    0.013423    0.749163    
#> 463: 0.177351    0.916803    3.381282    0.179124    0.073593    0.013409    0.749210    
#> 464: 0.177477    0.916801    3.381262    0.179192    0.073569    0.013393    0.749182    
#> 465: 0.177518    0.916606    3.381288    0.179290    0.073588    0.013386    0.749246    
#> 466: 0.177553    0.916655    3.381256    0.179294    0.073584    0.013375    0.749256    
#> 467: 0.177527    0.916664    3.381236    0.179409    0.073547    0.013372    0.749156    
#> 468: 0.177623    0.916670    3.381267    0.179334    0.073543    0.013358    0.749152    
#> 469: 0.177664    0.916768    3.381301    0.179299    0.073558    0.013344    0.749175    
#> 470: 0.177717    0.916800    3.381304    0.179209    0.073578    0.013339    0.749185    
#> 471: 0.177626    0.916763    3.381298    0.179069    0.073552    0.013331    0.749251    
#> 472: 0.177568    0.916775    3.381306    0.178977    0.073544    0.013329    0.749253    
#> 473: 0.177478    0.916798    3.381307    0.179010    0.073500    0.013329    0.749185    
#> 474: 0.177417    0.916802    3.381283    0.178918    0.073451    0.013334    0.749238    
#> 475: 0.177538    0.916913    3.381282    0.178901    0.073430    0.013322    0.749260    
#> 476: 0.177519    0.916956    3.381252    0.178863    0.073470    0.013300    0.749335    
#> 477: 0.177450    0.916940    3.381247    0.178772    0.073487    0.013286    0.749267    
#> 478: 0.177374    0.916896    3.381247    0.178811    0.073532    0.013271    0.749305    
#> 479: 0.177423    0.916962    3.381259    0.178975    0.073581    0.013259    0.749282    
#> 480: 0.177436    0.916952    3.381296    0.179011    0.073631    0.013251    0.749343    
#> 481: 0.177517    0.916888    3.381290    0.179186    0.073657    0.013263    0.749382    
#> 482: 0.177580    0.916884    3.381271    0.179287    0.073654    0.013277    0.749402    
#> 483: 0.177567    0.916814    3.381260    0.179282    0.073669    0.013282    0.749384    
#> 484: 0.177507    0.916687    3.381251    0.179431    0.073664    0.013293    0.749438    
#> 485: 0.177498    0.916782    3.381235    0.179436    0.073678    0.013306    0.749454    
#> 486: 0.177540    0.916844    3.381261    0.179423    0.073713    0.013307    0.749508    
#> 487: 0.177665    0.916925    3.381325    0.179460    0.073722    0.013310    0.749431    
#> 488: 0.177685    0.916914    3.381331    0.179541    0.073723    0.013306    0.749406    
#> 489: 0.177804    0.916938    3.381314    0.179642    0.073697    0.013310    0.749394    
#> 490: 0.177852    0.916927    3.381348    0.179524    0.073674    0.013308    0.749400    
#> 491: 0.177895    0.916978    3.381396    0.179424    0.073739    0.013302    0.749408    
#> 492: 0.177864    0.917019    3.381408    0.179386    0.073740    0.013297    0.749506    
#> 493: 0.177848    0.916969    3.381443    0.179270    0.073684    0.013302    0.749596    
#> 494: 0.177896    0.916951    3.381435    0.179257    0.073625    0.013304    0.749630    
#> 495: 0.177960    0.916940    3.381442    0.179397    0.073562    0.013310    0.749619    
#> 496: 0.178052    0.916989    3.381407    0.179307    0.073554    0.013311    0.749674    
#> 497: 0.177970    0.917006    3.381408    0.179251    0.073534    0.013315    0.749740    
#> 498: 0.177938    0.917034    3.381374    0.179266    0.073557    0.013320    0.749717    
#> 499: 0.177980    0.917102    3.381345    0.179157    0.073574    0.013326    0.749691    
#> 500: 0.178020    0.917083    3.381331    0.179073    0.073594    0.013323    0.749673    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.290828    0.964750    3.444210    0.392401    0.074910    0.016800    1.649533    
#> 002: 0.399425    1.049531    3.453006    0.372781    0.071164    0.015960    1.275690    
#> 003: 0.620985    1.002206    3.479766    0.354142    0.067606    0.015162    0.972698    
#> 004: 0.575039    1.030033    3.476067    0.336435    0.064226    0.014404    0.912122    
#> 005: 0.649507    1.041281    3.471865    0.319613    0.061014    0.013684    0.885735    
#> 006: 0.612487    1.064465    3.457603    0.303633    0.057964    0.013000    0.848336    
#> 007: 0.560547    1.062311    3.451663    0.297845    0.059178    0.012350    0.846121    
#> 008: 0.571881    1.040821    3.453553    0.282953    0.056219    0.011732    0.846858    
#> 009: 0.566334    1.027973    3.458149    0.268805    0.053408    0.011526    0.842114    
#> 010: 0.618892    1.010982    3.464586    0.255365    0.050737    0.010949    0.848551    
#> 011: 0.657917    1.026623    3.481318    0.242597    0.048201    0.010402    0.867261    
#> 012: 0.624684    1.032640    3.462728    0.265630    0.045791    0.009882    0.837167    
#> 013: 0.576735    1.017709    3.455856    0.266054    0.043501    0.011560    0.853080    
#> 014: 0.639575    1.029711    3.463015    0.293083    0.041326    0.013224    0.865864    
#> 015: 0.625980    1.027545    3.486096    0.313601    0.039260    0.012563    0.848434    
#> 016: 0.607697    1.038317    3.480305    0.297921    0.037297    0.014413    0.880371    
#> 017: 0.624294    1.046603    3.481467    0.285899    0.035432    0.015132    0.827935    
#> 018: 0.662354    1.046373    3.475396    0.303070    0.033660    0.014783    0.834875    
#> 019: 0.608957    1.047707    3.471170    0.330922    0.031977    0.018153    0.829687    
#> 020: 0.621149    1.052774    3.462788    0.314376    0.037368    0.017245    0.848987    
#> 021: 0.606733    1.040429    3.473102    0.298657    0.035500    0.016383    0.834781    
#> 022: 0.613182    1.055555    3.477464    0.283724    0.033725    0.015564    0.817310    
#> 023: 0.675126    1.057947    3.480559    0.310766    0.032039    0.014785    0.833814    
#> 024: 0.703840    1.068317    3.484344    0.357767    0.030437    0.014046    0.823567    
#> 025: 0.667735    1.041890    3.480871    0.351389    0.028915    0.013578    0.837527    
#> 026: 0.648127    1.047359    3.454988    0.333820    0.027469    0.012899    0.834220    
#> 027: 0.596917    1.067271    3.459575    0.343880    0.028992    0.012401    0.816825    
#> 028: 0.666901    1.063935    3.479093    0.326686    0.027542    0.015783    0.822558    
#> 029: 0.668767    1.035080    3.479380    0.310352    0.032737    0.014994    0.850358    
#> 030: 0.626908    1.059434    3.473424    0.294834    0.031101    0.014244    0.827639    
#> 031: 0.603739    1.032604    3.475959    0.301732    0.032059    0.013532    0.835501    
#> 032: 0.641845    1.039359    3.486439    0.286646    0.030456    0.012856    0.828693    
#> 033: 0.597295    1.049461    3.468106    0.272314    0.030545    0.012213    0.839292    
#> 034: 0.638037    1.072791    3.464765    0.286868    0.034223    0.011602    0.820473    
#> 035: 0.603899    1.032236    3.462787    0.276977    0.032512    0.011078    0.825568    
#> 036: 0.624495    1.051404    3.465300    0.264791    0.030886    0.012485    0.826264    
#> 037: 0.635208    1.060673    3.474731    0.301620    0.030189    0.011861    0.840275    
#> 038: 0.693616    1.056552    3.470094    0.387741    0.034058    0.011268    0.849281    
#> 039: 0.730328    1.041865    3.482382    0.374899    0.032355    0.011491    0.824903    
#> 040: 0.649794    1.054272    3.477478    0.436811    0.030737    0.012602    0.817312    
#> 041: 0.617400    1.051315    3.465991    0.414970    0.029200    0.013297    0.820235    
#> 042: 0.647262    1.049810    3.467648    0.406648    0.027740    0.013606    0.803641    
#> 043: 0.604330    1.061214    3.449523    0.386316    0.026353    0.012926    0.829803    
#> 044: 0.552294    1.064652    3.454804    0.367000    0.026947    0.012280    0.830169    
#> 045: 0.613210    1.083792    3.451407    0.349302    0.028893    0.011666    0.843049    
#> 046: 0.636584    1.071004    3.449485    0.459885    0.033625    0.011082    0.833412    
#> 047: 0.628215    1.070847    3.446594    0.463850    0.031943    0.012229    0.822090    
#> 048: 0.653209    1.052791    3.461292    0.510035    0.030346    0.014275    0.819858    
#> 049: 0.571486    1.047209    3.456703    0.484533    0.033020    0.013561    0.855463    
#> 050: 0.679118    1.044373    3.455352    0.460306    0.031369    0.014495    0.840783    
#> 051: 0.649518    1.054578    3.454849    0.437291    0.029801    0.013770    0.875902    
#> 052: 0.625870    1.065748    3.463018    0.415426    0.031696    0.013081    0.831596    
#> 053: 0.705486    1.039569    3.481728    0.394655    0.030111    0.014083    0.807299    
#> 054: 0.587868    1.050445    3.473931    0.376604    0.028605    0.014284    0.817055    
#> 055: 0.624071    1.067768    3.476993    0.357774    0.027175    0.013570    0.832745    
#> 056: 0.639923    1.048260    3.470988    0.339885    0.025816    0.012892    0.848672    
#> 057: 0.607984    1.050354    3.466583    0.322891    0.024525    0.014406    0.853608    
#> 058: 0.646967    1.042687    3.467273    0.306746    0.028901    0.013686    0.850174    
#> 059: 0.673949    1.023720    3.492685    0.353413    0.039056    0.013001    0.854971    
#> 060: 0.670227    1.019249    3.495516    0.365281    0.039664    0.012351    0.842986    
#> 061: 0.710113    1.016278    3.495347    0.420065    0.037681    0.011734    0.849211    
#> 062: 0.683776    1.023893    3.498144    0.399062    0.035797    0.011588    0.852360    
#> 063: 0.710259    1.022149    3.490288    0.462714    0.038417    0.011008    0.861156    
#> 064: 0.643087    1.029843    3.491910    0.439578    0.036496    0.010458    0.862963    
#> 065: 0.702357    1.000906    3.481645    0.417599    0.034671    0.010672    0.837234    
#> 066: 0.698870    1.024982    3.483713    0.396719    0.032937    0.012856    0.832987    
#> 067: 0.657845    1.048703    3.467985    0.376883    0.031291    0.013625    0.834885    
#> 068: 0.608250    1.070626    3.472944    0.358039    0.029726    0.012944    0.861301    
#> 069: 0.585011    1.081211    3.458899    0.340137    0.028294    0.012296    0.868773    
#> 070: 0.595928    1.084594    3.465832    0.323130    0.026880    0.011682    0.875131    
#> 071: 0.552156    1.110760    3.437467    0.306974    0.025536    0.011097    0.856826    
#> 072: 0.529809    1.083268    3.436106    0.328695    0.024259    0.012215    0.841726    
#> 073: 0.611790    1.066743    3.465066    0.312260    0.023046    0.011604    0.855342    
#> 074: 0.608908    1.059211    3.472390    0.296647    0.023181    0.011024    0.852891    
#> 075: 0.638492    1.042344    3.495849    0.297316    0.023569    0.010473    0.838869    
#> 076: 0.626373    1.049082    3.491368    0.282451    0.024972    0.009949    0.851226    
#> 077: 0.671675    1.044127    3.471278    0.268328    0.028697    0.011490    0.855188    
#> 078: 0.664131    1.031669    3.485502    0.254912    0.027263    0.011685    0.843610    
#> 079: 0.662834    1.044056    3.487210    0.373819    0.025899    0.011100    0.859499    
#> 080: 0.681947    1.028416    3.484850    0.355128    0.028303    0.010545    0.886363    
#> 081: 0.677665    1.000039    3.496084    0.337371    0.027704    0.010018    0.866960    
#> 082: 0.691831    0.991683    3.514403    0.320503    0.026319    0.009744    0.895067    
#> 083: 0.704101    1.008466    3.514088    0.304478    0.026338    0.009451    0.865736    
#> 084: 0.649915    1.030475    3.491774    0.289254    0.040002    0.012008    0.854223    
#> 085: 0.652806    1.059189    3.496513    0.287343    0.038290    0.011407    0.846133    
#> 086: 0.615441    1.054278    3.484215    0.329383    0.036375    0.012139    0.813545    
#> 087: 0.614823    1.045559    3.471227    0.312913    0.034557    0.011532    0.821343    
#> 088: 0.565390    1.045042    3.475285    0.297268    0.032829    0.010955    0.838304    
#> 089: 0.619578    1.060262    3.457603    0.282404    0.031187    0.012724    0.837439    
#> 090: 0.549179    1.070474    3.451061    0.287747    0.032963    0.012088    0.821903    
#> 091: 0.563349    1.057255    3.441563    0.273360    0.031314    0.011484    0.828573    
#> 092: 0.570624    1.082153    3.442264    0.259692    0.029749    0.010909    0.849102    
#> 093: 0.536982    1.075208    3.442826    0.246707    0.028261    0.011980    0.851550    
#> 094: 0.539578    1.083005    3.436158    0.234372    0.026848    0.011936    0.843349    
#> 095: 0.568178    1.082714    3.460859    0.294239    0.025506    0.015737    0.838073    
#> 096: 0.560039    1.078021    3.450369    0.298356    0.024758    0.014950    0.837770    
#> 097: 0.624409    1.077810    3.455894    0.328252    0.023520    0.016760    0.824948    
#> 098: 0.648763    1.085258    3.468130    0.311839    0.022344    0.015922    0.848764    
#> 099: 0.614528    1.057282    3.456485    0.361081    0.021227    0.015126    0.824755    
#> 100: 0.594898    1.060187    3.449864    0.373400    0.020166    0.014369    0.804108    
#> 101: 0.548801    1.057060    3.429130    0.354730    0.019157    0.013651    0.812571    
#> 102: 0.550818    1.049796    3.430174    0.336993    0.020078    0.013241    0.815325    
#> 103: 0.647243    1.045188    3.461139    0.320144    0.021405    0.012579    0.808155    
#> 104: 0.641884    1.045388    3.472000    0.376672    0.020335    0.011950    0.827685    
#> 105: 0.621261    1.058897    3.468260    0.357838    0.020593    0.011984    0.804135    
#> 106: 0.644661    1.061875    3.461658    0.394832    0.019563    0.015123    0.826591    
#> 107: 0.651444    1.077684    3.463735    0.438701    0.018585    0.014367    0.831466    
#> 108: 0.673344    1.078329    3.462565    0.416766    0.019015    0.013649    0.826803    
#> 109: 0.640859    1.054072    3.482386    0.395928    0.018064    0.012966    0.824325    
#> 110: 0.629926    1.054208    3.464147    0.376131    0.017161    0.012879    0.827079    
#> 111: 0.633933    1.058552    3.467018    0.357325    0.016303    0.014387    0.826920    
#> 112: 0.577348    1.039467    3.455870    0.339458    0.018982    0.013668    0.833876    
#> 113: 0.616675    1.046168    3.468579    0.322486    0.018033    0.014402    0.829987    
#> 114: 0.614662    1.048472    3.470152    0.306361    0.017855    0.013682    0.835344    
#> 115: 0.637142    1.020342    3.467373    0.325479    0.016962    0.013886    0.843720    
#> 116: 0.646709    1.048908    3.470796    0.309205    0.016114    0.015562    0.857469    
#> 117: 0.584793    1.070236    3.474367    0.323562    0.015308    0.014784    0.860883    
#> 118: 0.615740    1.082252    3.461162    0.307384    0.016195    0.014044    0.839191    
#> 119: 0.596555    1.070931    3.467732    0.292015    0.017158    0.014604    0.842266    
#> 120: 0.605505    1.066704    3.462778    0.292744    0.017827    0.015367    0.820338    
#> 121: 0.598904    1.082302    3.454168    0.327612    0.021196    0.014599    0.811949    
#> 122: 0.606934    1.048925    3.465159    0.311232    0.020137    0.013869    0.845509    
#> 123: 0.632608    1.065962    3.464309    0.295670    0.022704    0.014263    0.850609    
#> 124: 0.639409    1.089108    3.461937    0.307643    0.021569    0.013550    0.850910    
#> 125: 0.667179    1.082176    3.461941    0.368615    0.024427    0.012872    0.830134    
#> 126: 0.652640    1.072474    3.466597    0.403873    0.026242    0.017023    0.829361    
#> 127: 0.671014    1.049820    3.467766    0.422610    0.024930    0.016172    0.825986    
#> 128: 0.628807    1.051491    3.468002    0.401479    0.026756    0.015363    0.817311    
#> 129: 0.660088    1.070404    3.472050    0.381405    0.031855    0.014595    0.830223    
#> 130: 0.701661    1.091653    3.469148    0.369215    0.030262    0.013866    0.816119    
#> 131: 0.636817    1.079779    3.456166    0.350754    0.031122    0.013172    0.819348    
#> 132: 0.566156    1.071617    3.434346    0.334829    0.033184    0.012514    0.799247    
#> 133: 0.628029    1.052155    3.446216    0.378373    0.031525    0.011888    0.833066    
#> 134: 0.636650    1.040369    3.465366    0.359454    0.029948    0.013322    0.823847    
#> 135: 0.604325    1.042921    3.469525    0.341481    0.028451    0.012656    0.842745    
#> 136: 0.615278    1.033733    3.468498    0.355232    0.027028    0.014866    0.826939    
#> 137: 0.668594    1.024046    3.478697    0.343172    0.025677    0.015671    0.818360    
#> 138: 0.646683    1.032729    3.477252    0.326014    0.028969    0.014887    0.818934    
#> 139: 0.626407    1.034608    3.482312    0.311917    0.029367    0.017160    0.818024    
#> 140: 0.682912    1.042475    3.489654    0.296321    0.027899    0.016302    0.849750    
#> 141: 0.664440    1.014337    3.503386    0.281505    0.026504    0.016653    0.829331    
#> 142: 0.688330    1.010314    3.502471    0.318691    0.025179    0.015821    0.846176    
#> 143: 0.635766    1.027809    3.487704    0.372486    0.023920    0.016129    0.841147    
#> 144: 0.672442    1.038641    3.488573    0.414178    0.022724    0.016569    0.837127    
#> 145: 0.642636    1.052300    3.471812    0.453107    0.021588    0.015751    0.832378    
#> 146: 0.591780    1.067801    3.468150    0.430452    0.023002    0.016449    0.834951    
#> 147: 0.569609    1.061723    3.453765    0.408929    0.022939    0.016544    0.811260    
#> 148: 0.600430    1.073953    3.469588    0.388483    0.027720    0.015717    0.823443    
#> 149: 0.608554    1.051204    3.463137    0.374681    0.030870    0.014931    0.847567    
#> 150: 0.661544    1.048615    3.467598    0.355947    0.038116    0.014184    0.832445    
#> 151: 0.615444    1.071699    3.462000    0.338149    0.036211    0.013475    0.823968    
#> 152: 0.596096    1.066961    3.470331    0.267397    0.026200    0.012956    0.808727    
#> 153: 0.601499    1.077988    3.467660    0.296427    0.020865    0.012192    0.823051    
#> 154: 0.639677    1.081644    3.467117    0.293831    0.017772    0.011366    0.835333    
#> 155: 0.598505    1.065803    3.466015    0.264918    0.022317    0.013040    0.818318    
#> 156: 0.630080    1.070856    3.480553    0.301840    0.015761    0.017541    0.830230    
#> 157: 0.615110    1.073553    3.470788    0.340532    0.015150    0.015972    0.819741    
#> 158: 0.644278    1.083046    3.467305    0.327153    0.015182    0.014105    0.822591    
#> 159: 0.594138    1.084868    3.467025    0.352161    0.014565    0.013770    0.812214    
#> 160: 0.676628    1.061200    3.484311    0.389385    0.017234    0.013604    0.807664    
#> 161: 0.674786    1.055262    3.479389    0.313599    0.019269    0.015900    0.817295    
#> 162: 0.652877    1.077458    3.474166    0.295442    0.019571    0.015777    0.824622    
#> 163: 0.672562    1.055380    3.465138    0.327545    0.020406    0.015200    0.816694    
#> 164: 0.650977    1.080090    3.457604    0.389729    0.017720    0.017150    0.825482    
#> 165: 0.633883    1.086359    3.456672    0.386349    0.015675    0.015183    0.818685    
#> 166: 0.657782    1.096771    3.458868    0.405841    0.015412    0.014668    0.831034    
#> 167: 0.682796    1.104686    3.471439    0.422110    0.016614    0.014978    0.832053    
#> 168: 0.669281    1.102644    3.476172    0.382669    0.015155    0.012080    0.825062    
#> 169: 0.646519    1.098106    3.468479    0.302850    0.019273    0.013366    0.845799    
#> 170: 0.629987    1.058094    3.467657    0.342961    0.018208    0.014406    0.818481    
#> 171: 0.610020    1.069908    3.467829    0.331164    0.019286    0.011529    0.826671    
#> 172: 0.585112    1.073455    3.460178    0.273402    0.016086    0.008219    0.837986    
#> 173: 0.608223    1.078450    3.456961    0.297967    0.015535    0.008741    0.846728    
#> 174: 0.589170    1.082449    3.452942    0.337910    0.016483    0.010370    0.807735    
#> 175: 0.568148    1.084863    3.446131    0.321721    0.016767    0.013429    0.837818    
#> 176: 0.576229    1.103933    3.451266    0.368691    0.013788    0.012809    0.822514    
#> 177: 0.599323    1.094983    3.465219    0.328913    0.015694    0.012690    0.823558    
#> 178: 0.606876    1.072577    3.462880    0.289846    0.019745    0.012527    0.823289    
#> 179: 0.666481    1.068493    3.455481    0.389056    0.019886    0.011970    0.838152    
#> 180: 0.621270    1.062572    3.467636    0.320295    0.018920    0.010952    0.830302    
#> 181: 0.625601    1.041215    3.445663    0.360440    0.018120    0.015108    0.802062    
#> 182: 0.577622    1.051750    3.435847    0.318638    0.014893    0.014637    0.834924    
#> 183: 0.572023    1.049387    3.444384    0.374386    0.015790    0.015476    0.816930    
#> 184: 0.610888    1.023636    3.453240    0.312416    0.015461    0.015791    0.839885    
#> 185: 0.584963    1.054799    3.456055    0.317702    0.013705    0.010492    0.837627    
#> 186: 0.623494    1.057940    3.462463    0.434948    0.015666    0.011461    0.816820    
#> 187: 0.639721    1.057732    3.466405    0.394974    0.018204    0.013722    0.817919    
#> 188: 0.603675    1.085320    3.456604    0.332962    0.025527    0.012199    0.843102    
#> 189: 0.609981    1.074191    3.467605    0.291437    0.032995    0.011464    0.848792    
#> 190: 0.649281    1.049988    3.484026    0.312128    0.033028    0.013038    0.819678    
#> 191: 0.615176    1.066323    3.466782    0.306771    0.022877    0.009937    0.825905    
#> 192: 0.588980    1.074406    3.458557    0.304659    0.021141    0.010567    0.811131    
#> 193: 0.622313    1.074885    3.459918    0.275363    0.019438    0.012402    0.810484    
#> 194: 0.595368    1.073223    3.449226    0.359436    0.018787    0.013679    0.812120    
#> 195: 0.574437    1.076956    3.445395    0.371757    0.017613    0.014185    0.821190    
#> 196: 0.609742    1.070115    3.458841    0.371475    0.021498    0.017202    0.812041    
#> 197: 0.559154    1.092618    3.464334    0.369323    0.019602    0.016615    0.843226    
#> 198: 0.636714    1.072576    3.458508    0.464842    0.011333    0.017660    0.827165    
#> 199: 0.621535    1.065265    3.459190    0.389541    0.012965    0.015496    0.820674    
#> 200: 0.616650    1.074103    3.462630    0.356272    0.014076    0.014929    0.837640    
#> 201: 0.615207    1.066696    3.471130    0.346374    0.013137    0.015689    0.839540    
#> 202: 0.628535    1.066478    3.472455    0.342122    0.013565    0.015670    0.836324    
#> 203: 0.643154    1.064993    3.474083    0.343403    0.014025    0.015381    0.832905    
#> 204: 0.650831    1.057573    3.477612    0.351999    0.014658    0.015703    0.832735    
#> 205: 0.647617    1.058514    3.477825    0.346172    0.015230    0.016329    0.833130    
#> 206: 0.643747    1.059832    3.478159    0.344165    0.015237    0.016537    0.836929    
#> 207: 0.640704    1.058667    3.477590    0.342743    0.014803    0.016474    0.837438    
#> 208: 0.636263    1.059441    3.476090    0.340906    0.014601    0.016009    0.836486    
#> 209: 0.635200    1.058836    3.475474    0.336231    0.014624    0.015674    0.836034    
#> 210: 0.636403    1.058622    3.474830    0.338480    0.014384    0.015579    0.834390    
#> 211: 0.635860    1.058743    3.475218    0.334799    0.014297    0.015693    0.833424    
#> 212: 0.638105    1.059659    3.475063    0.335393    0.014172    0.015763    0.834030    
#> 213: 0.639193    1.057532    3.475210    0.331927    0.014199    0.016163    0.835000    
#> 214: 0.640918    1.056338    3.475895    0.328384    0.014249    0.016563    0.834906    
#> 215: 0.639212    1.055848    3.475864    0.329619    0.014163    0.016846    0.833652    
#> 216: 0.638316    1.054874    3.475151    0.332905    0.014309    0.016936    0.833487    
#> 217: 0.638230    1.055342    3.474349    0.337822    0.014274    0.016897    0.831790    
#> 218: 0.637298    1.056195    3.472979    0.338214    0.014182    0.016911    0.830883    
#> 219: 0.635488    1.056681    3.471443    0.339638    0.014211    0.016765    0.830191    
#> 220: 0.633352    1.057404    3.470938    0.337996    0.014293    0.016675    0.829879    
#> 221: 0.632619    1.057088    3.470722    0.337704    0.014184    0.016586    0.829389    
#> 222: 0.633186    1.056977    3.470736    0.334631    0.014037    0.016608    0.829074    
#> 223: 0.635245    1.056893    3.471378    0.335126    0.014204    0.016736    0.828776    
#> 224: 0.638420    1.057053    3.471999    0.336304    0.014234    0.016722    0.829578    
#> 225: 0.639750    1.056055    3.472534    0.340131    0.014460    0.016650    0.829168    
#> 226: 0.641255    1.055058    3.472896    0.343550    0.014689    0.016601    0.829258    
#> 227: 0.639710    1.054844    3.472712    0.342737    0.014814    0.016424    0.829741    
#> 228: 0.638237    1.055529    3.471771    0.345527    0.014836    0.016396    0.829630    
#> 229: 0.636889    1.056164    3.470987    0.345721    0.014890    0.016347    0.828503    
#> 230: 0.635791    1.056361    3.470737    0.345271    0.014885    0.016272    0.827777    
#> 231: 0.636217    1.056978    3.470782    0.344331    0.014937    0.016215    0.827352    
#> 232: 0.635488    1.056785    3.470999    0.342470    0.014924    0.016228    0.827700    
#> 233: 0.635349    1.056111    3.471359    0.342428    0.014966    0.016277    0.826968    
#> 234: 0.634163    1.056252    3.471234    0.340785    0.014939    0.016193    0.826818    
#> 235: 0.633949    1.056171    3.471084    0.339794    0.015050    0.016093    0.826329    
#> 236: 0.633146    1.056474    3.470849    0.339010    0.015100    0.016025    0.826183    
#> 237: 0.634568    1.056494    3.470870    0.338369    0.015238    0.015966    0.826550    
#> 238: 0.635772    1.056738    3.470896    0.338210    0.015334    0.015913    0.826872    
#> 239: 0.635188    1.057379    3.470767    0.338152    0.015512    0.015939    0.826890    
#> 240: 0.635452    1.057041    3.470835    0.338521    0.015664    0.015886    0.826434    
#> 241: 0.635595    1.056574    3.471101    0.337971    0.015813    0.015809    0.826798    
#> 242: 0.634902    1.056088    3.471149    0.336150    0.016010    0.015751    0.827560    
#> 243: 0.634146    1.056087    3.471320    0.335380    0.016196    0.015721    0.827993    
#> 244: 0.633559    1.055377    3.471555    0.333580    0.016292    0.015638    0.828459    
#> 245: 0.633719    1.054720    3.471709    0.333753    0.016448    0.015582    0.828573    
#> 246: 0.633836    1.054229    3.471762    0.332947    0.016496    0.015598    0.828783    
#> 247: 0.633342    1.053994    3.471839    0.331786    0.016590    0.015636    0.828571    
#> 248: 0.633187    1.053875    3.471867    0.331528    0.016603    0.015606    0.827984    
#> 249: 0.632408    1.053793    3.471976    0.330534    0.016716    0.015569    0.828164    
#> 250: 0.632618    1.053813    3.472077    0.329736    0.016801    0.015494    0.828316    
#> 251: 0.632898    1.053699    3.472314    0.329889    0.016862    0.015464    0.828477    
#> 252: 0.633463    1.053686    3.472467    0.330001    0.016953    0.015433    0.828584    
#> 253: 0.633595    1.053820    3.472422    0.330111    0.017020    0.015399    0.828987    
#> 254: 0.633294    1.054208    3.472519    0.329694    0.017056    0.015381    0.828801    
#> 255: 0.633132    1.054414    3.472806    0.328745    0.017129    0.015348    0.829021    
#> 256: 0.633459    1.054234    3.472818    0.328478    0.017157    0.015291    0.829395    
#> 257: 0.633560    1.053802    3.472708    0.328137    0.017156    0.015240    0.829496    
#> 258: 0.633388    1.053239    3.472803    0.327536    0.017105    0.015239    0.829271    
#> 259: 0.632758    1.053014    3.472817    0.326445    0.017086    0.015248    0.829309    
#> 260: 0.632310    1.053059    3.472771    0.326862    0.017144    0.015205    0.829062    
#> 261: 0.632649    1.053010    3.472899    0.328122    0.017141    0.015190    0.828898    
#> 262: 0.633258    1.052962    3.472914    0.329310    0.017213    0.015200    0.828659    
#> 263: 0.632945    1.053206    3.472880    0.329395    0.017290    0.015235    0.828835    
#> 264: 0.632692    1.053389    3.472744    0.329552    0.017438    0.015228    0.828663    
#> 265: 0.632929    1.053570    3.472674    0.329967    0.017597    0.015232    0.828467    
#> 266: 0.633076    1.053921    3.472486    0.330058    0.017687    0.015221    0.828302    
#> 267: 0.632686    1.054066    3.472416    0.329794    0.017658    0.015185    0.828360    
#> 268: 0.633086    1.053838    3.472361    0.329845    0.017676    0.015200    0.828426    
#> 269: 0.633734    1.053474    3.472407    0.330483    0.017665    0.015233    0.828277    
#> 270: 0.634333    1.053260    3.472332    0.329566    0.017652    0.015213    0.828291    
#> 271: 0.634371    1.053034    3.472241    0.329241    0.017687    0.015181    0.828496    
#> 272: 0.634208    1.052893    3.472096    0.328827    0.017742    0.015172    0.828419    
#> 273: 0.634215    1.053083    3.472110    0.329145    0.017745    0.015194    0.828451    
#> 274: 0.633649    1.053225    3.472022    0.328997    0.017764    0.015138    0.828183    
#> 275: 0.633525    1.053209    3.471896    0.328310    0.017785    0.015100    0.828106    
#> 276: 0.633013    1.053377    3.472014    0.328668    0.017791    0.015049    0.828182    
#> 277: 0.633060    1.053476    3.472139    0.327902    0.017823    0.015046    0.828340    
#> 278: 0.632583    1.053718    3.472224    0.327200    0.017913    0.015047    0.828377    
#> 279: 0.632136    1.053728    3.472220    0.326695    0.018032    0.015003    0.828385    
#> 280: 0.632388    1.054042    3.472285    0.326990    0.018165    0.014975    0.828243    
#> 281: 0.632226    1.054174    3.472333    0.327150    0.018305    0.014950    0.828170    
#> 282: 0.632128    1.054449    3.472378    0.326955    0.018395    0.014960    0.828007    
#> 283: 0.632297    1.054596    3.472365    0.327141    0.018463    0.014982    0.828255    
#> 284: 0.632439    1.054583    3.472347    0.326722    0.018463    0.014954    0.828267    
#> 285: 0.632174    1.054768    3.472187    0.325951    0.018497    0.014929    0.828322    
#> 286: 0.632089    1.054969    3.472040    0.325287    0.018569    0.014926    0.828443    
#> 287: 0.631642    1.055141    3.471845    0.325134    0.018645    0.014933    0.828355    
#> 288: 0.631791    1.055259    3.471880    0.325203    0.018648    0.014907    0.828343    
#> 289: 0.631873    1.055133    3.471887    0.325256    0.018653    0.014894    0.828268    
#> 290: 0.631507    1.054924    3.471931    0.325111    0.018664    0.014883    0.828442    
#> 291: 0.631600    1.055091    3.471966    0.325351    0.018623    0.014902    0.828421    
#> 292: 0.631771    1.055244    3.471994    0.325410    0.018570    0.014902    0.828462    
#> 293: 0.631880    1.055249    3.471925    0.325138    0.018504    0.014902    0.828328    
#> 294: 0.631574    1.055286    3.471777    0.324849    0.018499    0.014902    0.828115    
#> 295: 0.631409    1.054982    3.471725    0.324534    0.018481    0.014897    0.828031    
#> 296: 0.630901    1.054909    3.471628    0.324703    0.018469    0.014922    0.827984    
#> 297: 0.631005    1.054978    3.471532    0.324536    0.018436    0.014919    0.828199    
#> 298: 0.630792    1.055078    3.471395    0.324859    0.018447    0.014873    0.828211    
#> 299: 0.630813    1.055090    3.471286    0.324482    0.018452    0.014841    0.828224    
#> 300: 0.630961    1.054917    3.471408    0.324747    0.018478    0.014842    0.827955    
#> 301: 0.631164    1.054874    3.471312    0.325052    0.018529    0.014811    0.828044    
#> 302: 0.631104    1.054925    3.471211    0.324468    0.018566    0.014789    0.827997    
#> 303: 0.630904    1.054989    3.471113    0.324127    0.018606    0.014761    0.827701    
#> 304: 0.630872    1.055167    3.470947    0.323927    0.018601    0.014725    0.827606    
#> 305: 0.630577    1.055177    3.470803    0.323729    0.018658    0.014719    0.827776    
#> 306: 0.630100    1.055309    3.470586    0.323854    0.018732    0.014722    0.827738    
#> 307: 0.629830    1.055169    3.470490    0.324176    0.018800    0.014720    0.827723    
#> 308: 0.629100    1.055022    3.470444    0.323798    0.018840    0.014735    0.827810    
#> 309: 0.629154    1.054884    3.470444    0.323534    0.018883    0.014741    0.828124    
#> 310: 0.629531    1.054842    3.470338    0.323374    0.018913    0.014730    0.828200    
#> 311: 0.629751    1.054775    3.470327    0.323350    0.018908    0.014723    0.828003    
#> 312: 0.629385    1.054768    3.470056    0.323063    0.018924    0.014723    0.828166    
#> 313: 0.628808    1.054847    3.469863    0.322688    0.018931    0.014710    0.828474    
#> 314: 0.628121    1.055030    3.469651    0.322022    0.018965    0.014713    0.828638    
#> 315: 0.627553    1.055105    3.469583    0.321698    0.018964    0.014696    0.828732    
#> 316: 0.627600    1.055062    3.469649    0.321155    0.018934    0.014696    0.828839    
#> 317: 0.627626    1.054984    3.469727    0.321138    0.018912    0.014707    0.828977    
#> 318: 0.627761    1.055023    3.469605    0.321149    0.018898    0.014696    0.829008    
#> 319: 0.627862    1.054936    3.469620    0.320915    0.018883    0.014671    0.829037    
#> 320: 0.627564    1.054925    3.469510    0.321242    0.018831    0.014646    0.829180    
#> 321: 0.627279    1.054914    3.469354    0.321658    0.018811    0.014610    0.829383    
#> 322: 0.627275    1.054927    3.469293    0.321504    0.018798    0.014610    0.829530    
#> 323: 0.626599    1.054878    3.469237    0.321356    0.018784    0.014589    0.829669    
#> 324: 0.626349    1.054918    3.469285    0.321422    0.018767    0.014585    0.829602    
#> 325: 0.626379    1.054993    3.469324    0.320826    0.018773    0.014593    0.829496    
#> 326: 0.626311    1.054859    3.469326    0.320370    0.018759    0.014572    0.829550    
#> 327: 0.626368    1.054849    3.469312    0.319984    0.018754    0.014559    0.829669    
#> 328: 0.626316    1.054880    3.469321    0.319399    0.018758    0.014552    0.829791    
#> 329: 0.626432    1.054826    3.469426    0.319199    0.018737    0.014542    0.830015    
#> 330: 0.626064    1.054999    3.469408    0.318676    0.018744    0.014548    0.830067    
#> 331: 0.626044    1.055220    3.469342    0.318301    0.018790    0.014538    0.830182    
#> 332: 0.625996    1.055261    3.469319    0.318036    0.018781    0.014529    0.830240    
#> 333: 0.625705    1.055253    3.469155    0.318162    0.018769    0.014533    0.830122    
#> 334: 0.625327    1.055206    3.468974    0.318538    0.018747    0.014551    0.830105    
#> 335: 0.624952    1.055190    3.468841    0.318455    0.018759    0.014518    0.830084    
#> 336: 0.624556    1.055242    3.468725    0.318394    0.018770    0.014498    0.830253    
#> 337: 0.624420    1.055296    3.468614    0.318483    0.018766    0.014471    0.830370    
#> 338: 0.624436    1.055364    3.468622    0.318431    0.018803    0.014453    0.830527    
#> 339: 0.624455    1.055489    3.468587    0.318600    0.018792    0.014459    0.830412    
#> 340: 0.624535    1.055549    3.468658    0.319031    0.018800    0.014458    0.830314    
#> 341: 0.624708    1.055594    3.468702    0.319470    0.018823    0.014469    0.830193    
#> 342: 0.624461    1.055572    3.468684    0.319466    0.018852    0.014463    0.830089    
#> 343: 0.624061    1.055584    3.468750    0.318928    0.018863    0.014474    0.830018    
#> 344: 0.623985    1.055541    3.468808    0.318722    0.018830    0.014461    0.830168    
#> 345: 0.623956    1.055538    3.468822    0.318679    0.018822    0.014457    0.830135    
#> 346: 0.623641    1.055685    3.468698    0.318404    0.018814    0.014471    0.830242    
#> 347: 0.623347    1.055783    3.468508    0.318446    0.018824    0.014482    0.830407    
#> 348: 0.622965    1.055956    3.468386    0.318392    0.018881    0.014483    0.830390    
#> 349: 0.622796    1.056166    3.468278    0.318231    0.018940    0.014487    0.830359    
#> 350: 0.622569    1.056249    3.468238    0.318067    0.018965    0.014484    0.830310    
#> 351: 0.622578    1.056417    3.468184    0.317841    0.018993    0.014463    0.830351    
#> 352: 0.622354    1.056505    3.468133    0.317794    0.019011    0.014457    0.830594    
#> 353: 0.622441    1.056650    3.468068    0.317443    0.019035    0.014458    0.830741    
#> 354: 0.622374    1.056695    3.467935    0.317509    0.019047    0.014456    0.830636    
#> 355: 0.622665    1.056639    3.467880    0.317786    0.019052    0.014450    0.830542    
#> 356: 0.622831    1.056557    3.467943    0.317534    0.019096    0.014429    0.830688    
#> 357: 0.622977    1.056598    3.467997    0.317295    0.019136    0.014411    0.830648    
#> 358: 0.622947    1.056726    3.468047    0.317185    0.019171    0.014395    0.830636    
#> 359: 0.622856    1.056859    3.467991    0.316895    0.019140    0.014397    0.830605    
#> 360: 0.622666    1.056931    3.467845    0.316569    0.019118    0.014387    0.830549    
#> 361: 0.622568    1.057000    3.467815    0.316301    0.019109    0.014377    0.830509    
#> 362: 0.622687    1.057049    3.467765    0.316107    0.019120    0.014355    0.830536    
#> 363: 0.622789    1.056926    3.467805    0.315745    0.019097    0.014340    0.830525    
#> 364: 0.622962    1.056807    3.467848    0.315469    0.019099    0.014345    0.830654    
#> 365: 0.622880    1.056750    3.467835    0.315426    0.019094    0.014348    0.830803    
#> 366: 0.623122    1.056709    3.467783    0.315719    0.019089    0.014352    0.830942    
#> 367: 0.623339    1.056709    3.467833    0.316139    0.019125    0.014335    0.830924    
#> 368: 0.623446    1.056765    3.467809    0.316292    0.019162    0.014319    0.830956    
#> 369: 0.623495    1.056814    3.467783    0.316546    0.019186    0.014308    0.830984    
#> 370: 0.623321    1.056942    3.467734    0.316497    0.019206    0.014285    0.831039    
#> 371: 0.623105    1.057119    3.467547    0.316357    0.019219    0.014261    0.831093    
#> 372: 0.622946    1.057259    3.467478    0.316516    0.019216    0.014259    0.831213    
#> 373: 0.622634    1.057465    3.467305    0.316785    0.019219    0.014252    0.831223    
#> 374: 0.622309    1.057568    3.467124    0.316814    0.019225    0.014260    0.831258    
#> 375: 0.622067    1.057579    3.467093    0.316744    0.019252    0.014250    0.831284    
#> 376: 0.621944    1.057603    3.467093    0.316810    0.019275    0.014256    0.831136    
#> 377: 0.621862    1.057600    3.467094    0.316824    0.019264    0.014243    0.831128    
#> 378: 0.621587    1.057582    3.467023    0.316918    0.019297    0.014227    0.831264    
#> 379: 0.621599    1.057500    3.467051    0.317537    0.019325    0.014234    0.831238    
#> 380: 0.621449    1.057466    3.467014    0.317638    0.019365    0.014233    0.831175    
#> 381: 0.621142    1.057392    3.466964    0.317554    0.019380    0.014234    0.831188    
#> 382: 0.621087    1.057343    3.466930    0.317800    0.019390    0.014232    0.831185    
#> 383: 0.621184    1.057302    3.466957    0.317937    0.019383    0.014232    0.831040    
#> 384: 0.621112    1.057231    3.466979    0.317858    0.019378    0.014217    0.831062    
#> 385: 0.621272    1.057239    3.467039    0.317903    0.019393    0.014225    0.830994    
#> 386: 0.621397    1.057347    3.467095    0.317972    0.019410    0.014242    0.830848    
#> 387: 0.621646    1.057312    3.467210    0.317958    0.019435    0.014256    0.830750    
#> 388: 0.621853    1.057323    3.467270    0.318108    0.019468    0.014270    0.830641    
#> 389: 0.621780    1.057133    3.467266    0.318179    0.019475    0.014262    0.830801    
#> 390: 0.621773    1.057024    3.467236    0.318427    0.019465    0.014243    0.830919    
#> 391: 0.621851    1.056909    3.467242    0.318318    0.019456    0.014234    0.830954    
#> 392: 0.622045    1.056815    3.467318    0.318265    0.019442    0.014224    0.830999    
#> 393: 0.622027    1.056737    3.467305    0.318633    0.019440    0.014224    0.831052    
#> 394: 0.621786    1.056782    3.467247    0.318448    0.019409    0.014242    0.830953    
#> 395: 0.621780    1.056865    3.467200    0.318281    0.019401    0.014234    0.830903    
#> 396: 0.621915    1.056923    3.467229    0.318239    0.019381    0.014223    0.830832    
#> 397: 0.621988    1.056826    3.467284    0.318158    0.019374    0.014209    0.830970    
#> 398: 0.622123    1.056783    3.467356    0.317998    0.019378    0.014198    0.831013    
#> 399: 0.622206    1.056769    3.467455    0.318106    0.019420    0.014206    0.830924    
#> 400: 0.622227    1.056863    3.467493    0.318060    0.019442    0.014200    0.830934    
#> 401: 0.622302    1.056903    3.467490    0.318056    0.019417    0.014203    0.831048    
#> 402: 0.622405    1.056852    3.467579    0.317825    0.019406    0.014216    0.831124    
#> 403: 0.622617    1.056843    3.467606    0.317530    0.019405    0.014217    0.831125    
#> 404: 0.622779    1.056884    3.467582    0.317337    0.019417    0.014211    0.831133    
#> 405: 0.622690    1.056932    3.467594    0.317149    0.019419    0.014218    0.831153    
#> 406: 0.622736    1.056878    3.467610    0.316998    0.019405    0.014204    0.831246    
#> 407: 0.622770    1.056868    3.467637    0.316906    0.019406    0.014182    0.831191    
#> 408: 0.622886    1.056892    3.467647    0.317026    0.019410    0.014174    0.831317    
#> 409: 0.622660    1.056886    3.467565    0.317079    0.019412    0.014162    0.831340    
#> 410: 0.622545    1.056920    3.467446    0.316930    0.019428    0.014151    0.831381    
#> 411: 0.622434    1.056813    3.467359    0.317157    0.019427    0.014142    0.831372    
#> 412: 0.622414    1.056736    3.467322    0.317537    0.019433    0.014138    0.831377    
#> 413: 0.622220    1.056706    3.467226    0.317510    0.019440    0.014123    0.831369    
#> 414: 0.622012    1.056677    3.467232    0.317391    0.019451    0.014105    0.831299    
#> 415: 0.622226    1.056633    3.467238    0.317255    0.019445    0.014100    0.831229    
#> 416: 0.622428    1.056643    3.467249    0.317498    0.019463    0.014086    0.831124    
#> 417: 0.622596    1.056541    3.467270    0.317688    0.019483    0.014088    0.831093    
#> 418: 0.622572    1.056501    3.467306    0.317659    0.019497    0.014079    0.831043    
#> 419: 0.622725    1.056528    3.467317    0.317782    0.019497    0.014090    0.830958    
#> 420: 0.622814    1.056522    3.467311    0.317918    0.019479    0.014095    0.830919    
#> 421: 0.622652    1.056444    3.467335    0.317951    0.019477    0.014091    0.830806    
#> 422: 0.622804    1.056328    3.467336    0.317877    0.019472    0.014101    0.830763    
#> 423: 0.622948    1.056307    3.467368    0.317673    0.019465    0.014096    0.830791    
#> 424: 0.622750    1.056279    3.467321    0.317482    0.019458    0.014091    0.830778    
#> 425: 0.622912    1.056231    3.467382    0.317944    0.019477    0.014114    0.830788    
#> 426: 0.622893    1.056197    3.467387    0.317818    0.019473    0.014100    0.830847    
#> 427: 0.622742    1.056097    3.467420    0.317462    0.019472    0.014096    0.830868    
#> 428: 0.622506    1.056098    3.467413    0.317227    0.019459    0.014087    0.830993    
#> 429: 0.622579    1.056082    3.467443    0.317134    0.019453    0.014071    0.831034    
#> 430: 0.622646    1.056119    3.467436    0.317307    0.019440    0.014061    0.831091    
#> 431: 0.622542    1.056100    3.467393    0.317305    0.019445    0.014044    0.831087    
#> 432: 0.622465    1.056170    3.467412    0.317159    0.019458    0.014049    0.831074    
#> 433: 0.622441    1.056353    3.467392    0.317186    0.019479    0.014034    0.831141    
#> 434: 0.622528    1.056398    3.467429    0.317224    0.019476    0.014042    0.831127    
#> 435: 0.622708    1.056426    3.467437    0.317297    0.019480    0.014045    0.831072    
#> 436: 0.622712    1.056408    3.467462    0.317254    0.019491    0.014060    0.830998    
#> 437: 0.622850    1.056433    3.467419    0.317464    0.019499    0.014057    0.830985    
#> 438: 0.622822    1.056566    3.467413    0.317531    0.019511    0.014059    0.830901    
#> 439: 0.622805    1.056636    3.467420    0.317665    0.019500    0.014062    0.830885    
#> 440: 0.622841    1.056726    3.467453    0.317621    0.019493    0.014051    0.830797    
#> 441: 0.622706    1.056702    3.467453    0.317520    0.019459    0.014060    0.830801    
#> 442: 0.622603    1.056762    3.467449    0.317495    0.019446    0.014056    0.830754    
#> 443: 0.622710    1.056842    3.467419    0.317444    0.019466    0.014052    0.830795    
#> 444: 0.622837    1.056929    3.467338    0.317689    0.019470    0.014051    0.830765    
#> 445: 0.622764    1.057049    3.467258    0.317900    0.019506    0.014044    0.830754    
#> 446: 0.622474    1.057174    3.467171    0.317826    0.019532    0.014022    0.830806    
#> 447: 0.622492    1.057223    3.467165    0.317627    0.019571    0.014007    0.830855    
#> 448: 0.622202    1.057305    3.467128    0.317653    0.019586    0.013997    0.830837    
#> 449: 0.622324    1.057333    3.467220    0.317725    0.019586    0.013990    0.830798    
#> 450: 0.622309    1.057296    3.467228    0.317821    0.019607    0.013994    0.830776    
#> 451: 0.622254    1.057310    3.467207    0.317896    0.019615    0.014006    0.830797    
#> 452: 0.622131    1.057350    3.467142    0.317917    0.019612    0.014011    0.830763    
#> 453: 0.622001    1.057373    3.467107    0.317858    0.019612    0.014016    0.830731    
#> 454: 0.621901    1.057413    3.467075    0.317547    0.019600    0.014010    0.830670    
#> 455: 0.621984    1.057395    3.467084    0.317277    0.019583    0.014002    0.830690    
#> 456: 0.621979    1.057302    3.467114    0.316978    0.019565    0.014004    0.830702    
#> 457: 0.621837    1.057287    3.467186    0.316643    0.019553    0.014016    0.830724    
#> 458: 0.621779    1.057369    3.467266    0.316359    0.019566    0.014025    0.830804    
#> 459: 0.621448    1.057479    3.467226    0.316252    0.019559    0.014035    0.830764    
#> 460: 0.621255    1.057564    3.467159    0.316340    0.019551    0.014039    0.830813    
#> 461: 0.621027    1.057623    3.467153    0.316267    0.019531    0.014035    0.830846    
#> 462: 0.621012    1.057690    3.467194    0.316349    0.019509    0.014035    0.830868    
#> 463: 0.621030    1.057754    3.467175    0.316375    0.019524    0.014037    0.830803    
#> 464: 0.621091    1.057839    3.467114    0.316363    0.019514    0.014031    0.830807    
#> 465: 0.621088    1.057757    3.467123    0.316190    0.019501    0.014032    0.830855    
#> 466: 0.621135    1.057754    3.467075    0.316426    0.019470    0.014026    0.830888    
#> 467: 0.620965    1.057723    3.467038    0.316316    0.019468    0.014025    0.830876    
#> 468: 0.621049    1.057718    3.467066    0.316386    0.019456    0.014029    0.830939    
#> 469: 0.621022    1.057802    3.467068    0.316594    0.019465    0.014018    0.830951    
#> 470: 0.620968    1.057821    3.467046    0.316459    0.019457    0.014013    0.830993    
#> 471: 0.620922    1.057783    3.467058    0.316317    0.019421    0.014011    0.831015    
#> 472: 0.621078    1.057719    3.467121    0.316434    0.019406    0.014006    0.831003    
#> 473: 0.620935    1.057703    3.467111    0.316339    0.019382    0.014009    0.830993    
#> 474: 0.620903    1.057681    3.467088    0.316422    0.019369    0.014014    0.831010    
#> 475: 0.620907    1.057748    3.467101    0.316492    0.019353    0.014020    0.831023    
#> 476: 0.621001    1.057706    3.467088    0.316580    0.019353    0.014012    0.831091    
#> 477: 0.621003    1.057768    3.467086    0.316481    0.019365    0.014010    0.831107    
#> 478: 0.620951    1.057792    3.467107    0.316311    0.019366    0.013998    0.831146    
#> 479: 0.620961    1.057844    3.467130    0.316257    0.019362    0.013993    0.831193    
#> 480: 0.621009    1.057835    3.467151    0.316052    0.019381    0.013987    0.831260    
#> 481: 0.621109    1.057810    3.467170    0.315917    0.019397    0.013979    0.831280    
#> 482: 0.621230    1.057854    3.467132    0.315897    0.019407    0.013984    0.831265    
#> 483: 0.621276    1.057870    3.467105    0.315859    0.019412    0.013983    0.831233    
#> 484: 0.621260    1.057850    3.467103    0.315994    0.019413    0.013977    0.831195    
#> 485: 0.621273    1.057874    3.467118    0.315968    0.019432    0.013980    0.831144    
#> 486: 0.621301    1.057937    3.467105    0.316009    0.019444    0.013981    0.831128    
#> 487: 0.621504    1.057957    3.467172    0.315791    0.019452    0.013985    0.831128    
#> 488: 0.621563    1.057900    3.467220    0.315854    0.019427    0.014004    0.831093    
#> 489: 0.621768    1.057839    3.467265    0.315942    0.019408    0.014001    0.831107    
#> 490: 0.621981    1.057845    3.467306    0.316289    0.019402    0.014004    0.831050    
#> 491: 0.622077    1.057909    3.467349    0.316648    0.019389    0.014008    0.831033    
#> 492: 0.622186    1.058002    3.467359    0.317021    0.019387    0.014016    0.831083    
#> 493: 0.622295    1.058101    3.467349    0.317493    0.019392    0.014043    0.831119    
#> 494: 0.622325    1.058184    3.467315    0.317461    0.019404    0.014053    0.831107    
#> 495: 0.622419    1.058268    3.467334    0.317288    0.019399    0.014049    0.831141    
#> 496: 0.622539    1.058347    3.467341    0.317218    0.019383    0.014045    0.831201    
#> 497: 0.622535    1.058335    3.467376    0.317121    0.019381    0.014041    0.831252    
#> 498: 0.622559    1.058298    3.467354    0.317106    0.019375    0.014036    0.831223    
#> 499: 0.622570    1.058309    3.467322    0.317087    0.019367    0.014041    0.831126    
#> 500: 0.622575    1.058297    3.467287    0.317122    0.019352    0.014048    0.831067    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.290706    0.976474    3.440613    0.392401    0.074253    0.016800    1.690014    
#> 002: 0.271590    1.005446    3.491625    0.372781    0.070541    0.016373    1.156971    
#> 003: 0.379777    0.965687    3.486911    0.354142    0.067014    0.015554    0.886101    
#> 004: 0.360216    0.985812    3.493245    0.336435    0.063663    0.014777    0.765522    
#> 005: 0.391022    0.995555    3.467550    0.359934    0.076321    0.014038    0.686234    
#> 006: 0.396989    1.006243    3.472599    0.378582    0.075246    0.013336    0.623375    
#> 007: 0.353174    1.018003    3.466744    0.359653    0.071483    0.015396    0.625861    
#> 008: 0.360081    1.005532    3.460560    0.390670    0.086425    0.015544    0.629473    
#> 009: 0.334232    0.991354    3.446860    0.415478    0.082104    0.014767    0.619794    
#> 010: 0.344315    0.995246    3.451359    0.407776    0.077999    0.018366    0.629778    
#> 011: 0.382472    1.020008    3.454947    0.460354    0.074099    0.020060    0.629333    
#> 012: 0.390481    1.015497    3.460567    0.480221    0.079102    0.019975    0.612948    
#> 013: 0.366523    1.009066    3.454494    0.478171    0.075147    0.023729    0.624155    
#> 014: 0.356902    1.000746    3.457019    0.454262    0.071390    0.023713    0.640395    
#> 015: 0.402341    1.036156    3.460088    0.488325    0.067820    0.023166    0.629712    
#> 016: 0.416563    1.033571    3.471897    0.463909    0.064429    0.024159    0.624032    
#> 017: 0.395690    1.028320    3.474220    0.440713    0.066628    0.023970    0.610004    
#> 018: 0.384295    1.005288    3.462690    0.460694    0.063296    0.024032    0.617906    
#> 019: 0.362858    1.006203    3.460380    0.437659    0.067140    0.022831    0.621936    
#> 020: 0.394053    0.990687    3.475824    0.415776    0.065172    0.023864    0.619362    
#> 021: 0.383164    0.996418    3.479489    0.400484    0.069181    0.023192    0.606632    
#> 022: 0.402112    1.013762    3.485654    0.380460    0.068302    0.023359    0.604495    
#> 023: 0.479417    1.020332    3.497202    0.423192    0.075778    0.024235    0.635812    
#> 024: 0.467245    1.021057    3.491497    0.402816    0.071989    0.023023    0.633816    
#> 025: 0.458112    1.005934    3.485635    0.411947    0.080536    0.021872    0.624184    
#> 026: 0.431212    1.012344    3.467852    0.397226    0.076509    0.020779    0.614336    
#> 027: 0.389582    1.012374    3.468832    0.377365    0.072684    0.021242    0.630456    
#> 028: 0.438322    1.007141    3.477418    0.378418    0.069050    0.020180    0.616271    
#> 029: 0.416850    1.009135    3.469254    0.383356    0.065597    0.021540    0.646252    
#> 030: 0.434683    1.020251    3.479094    0.365190    0.062317    0.026658    0.624150    
#> 031: 0.398807    1.009038    3.488595    0.373509    0.059201    0.025900    0.615648    
#> 032: 0.393182    1.010106    3.484658    0.384225    0.069130    0.024605    0.617850    
#> 033: 0.392212    1.020639    3.472664    0.373665    0.069167    0.023375    0.639090    
#> 034: 0.423501    1.002854    3.476335    0.387690    0.065708    0.022214    0.634388    
#> 035: 0.382292    0.986173    3.475358    0.368305    0.064574    0.021104    0.613675    
#> 036: 0.370238    1.021119    3.467409    0.399271    0.063095    0.020049    0.633387    
#> 037: 0.371746    1.029518    3.457231    0.427265    0.068749    0.019046    0.618270    
#> 038: 0.396480    1.023651    3.460212    0.405902    0.075733    0.020864    0.616355    
#> 039: 0.392769    1.018124    3.466098    0.385607    0.071947    0.020973    0.609191    
#> 040: 0.393030    1.039122    3.477505    0.366326    0.080873    0.021417    0.627081    
#> 041: 0.363361    1.020844    3.467789    0.348010    0.076829    0.020346    0.629539    
#> 042: 0.405501    1.019966    3.468307    0.330610    0.072988    0.019329    0.606955    
#> 043: 0.373784    1.026197    3.457638    0.331111    0.078904    0.018363    0.613917    
#> 044: 0.354016    1.034518    3.455469    0.384818    0.074959    0.018058    0.622054    
#> 045: 0.386413    1.046483    3.456903    0.405007    0.084230    0.017155    0.598580    
#> 046: 0.363506    1.025217    3.449806    0.393156    0.080018    0.016298    0.614622    
#> 047: 0.379235    1.035355    3.446546    0.388180    0.080870    0.015483    0.608268    
#> 048: 0.378035    1.019552    3.456938    0.397411    0.076826    0.016657    0.609923    
#> 049: 0.375812    1.028987    3.459243    0.419289    0.072985    0.015824    0.624965    
#> 050: 0.401744    1.012027    3.467721    0.398325    0.073073    0.018184    0.619783    
#> 051: 0.403183    1.020220    3.462802    0.440267    0.074272    0.018711    0.622015    
#> 052: 0.369772    1.017750    3.470230    0.418254    0.072011    0.017795    0.612294    
#> 053: 0.411246    1.011270    3.471512    0.397341    0.070751    0.018221    0.623188    
#> 054: 0.369338    1.005680    3.465888    0.393644    0.068408    0.024817    0.653018    
#> 055: 0.362223    1.027907    3.461007    0.419357    0.073769    0.023576    0.647811    
#> 056: 0.366614    1.015795    3.460591    0.398390    0.071940    0.022397    0.655256    
#> 057: 0.409670    1.015187    3.481743    0.378470    0.080667    0.021277    0.641671    
#> 058: 0.397287    1.021111    3.465534    0.385933    0.078933    0.020213    0.625680    
#> 059: 0.381185    0.971734    3.472464    0.394750    0.085048    0.024441    0.631506    
#> 060: 0.388039    0.989207    3.476702    0.375013    0.080796    0.023219    0.625408    
#> 061: 0.420132    1.016444    3.477629    0.402163    0.080347    0.026153    0.634533    
#> 062: 0.378410    1.026129    3.481004    0.382054    0.076330    0.028927    0.658755    
#> 063: 0.386266    0.995938    3.468583    0.370745    0.072514    0.027481    0.644747    
#> 064: 0.375523    1.010529    3.463632    0.376102    0.069651    0.026107    0.633408    
#> 065: 0.417638    1.013114    3.463978    0.412193    0.074427    0.024802    0.621436    
#> 066: 0.376973    1.034903    3.465538    0.405199    0.070705    0.024622    0.618816    
#> 067: 0.362441    1.019657    3.452936    0.401687    0.067170    0.023391    0.616878    
#> 068: 0.344589    1.035856    3.455217    0.400221    0.063812    0.022222    0.637693    
#> 069: 0.363172    1.037525    3.447051    0.467800    0.060870    0.021110    0.635083    
#> 070: 0.358715    1.039244    3.458229    0.444410    0.083517    0.020055    0.623341    
#> 071: 0.353563    1.049670    3.442565    0.422189    0.079341    0.019052    0.647872    
#> 072: 0.300462    1.029346    3.445561    0.401080    0.075374    0.019512    0.635623    
#> 073: 0.355071    1.055189    3.461127    0.381026    0.071605    0.018537    0.630174    
#> 074: 0.357834    1.028526    3.464554    0.423886    0.068295    0.024550    0.609175    
#> 075: 0.381127    1.009113    3.480835    0.434127    0.072889    0.024299    0.620924    
#> 076: 0.419074    1.019877    3.486521    0.450590    0.069245    0.023084    0.609021    
#> 077: 0.430393    1.000819    3.484758    0.452307    0.065783    0.024891    0.609454    
#> 078: 0.407635    0.997001    3.488845    0.429692    0.065764    0.024037    0.602487    
#> 079: 0.433104    1.019402    3.480209    0.408208    0.062476    0.026675    0.617250    
#> 080: 0.442409    1.007932    3.485567    0.387797    0.059352    0.027506    0.627292    
#> 081: 0.428714    1.017700    3.480892    0.368407    0.057080    0.026131    0.621581    
#> 082: 0.411170    1.001163    3.482841    0.398951    0.054226    0.024824    0.633898    
#> 083: 0.444829    1.014032    3.479696    0.465556    0.054323    0.023583    0.612200    
#> 084: 0.426672    1.014830    3.473199    0.442278    0.061513    0.024888    0.621342    
#> 085: 0.449564    1.011137    3.492797    0.474889    0.059901    0.026282    0.628475    
#> 086: 0.430372    1.013945    3.480607    0.470791    0.056906    0.024968    0.622366    
#> 087: 0.410789    1.015012    3.470733    0.463677    0.054061    0.023719    0.630158    
#> 088: 0.349112    1.009490    3.466171    0.444449    0.051358    0.023049    0.624667    
#> 089: 0.367199    1.021946    3.452599    0.422226    0.049017    0.021897    0.624892    
#> 090: 0.367612    1.034008    3.453512    0.401115    0.058989    0.020857    0.636284    
#> 091: 0.349721    1.018355    3.452151    0.414712    0.056039    0.019814    0.633586    
#> 092: 0.377117    1.038665    3.453092    0.413260    0.066111    0.018824    0.629753    
#> 093: 0.351459    1.029934    3.446255    0.392597    0.070420    0.017883    0.639646    
#> 094: 0.374355    1.022313    3.450857    0.426045    0.074536    0.017218    0.648037    
#> 095: 0.376789    1.024466    3.465108    0.404743    0.073338    0.019833    0.639478    
#> 096: 0.346342    1.031643    3.459979    0.384505    0.069988    0.022287    0.629676    
#> 097: 0.344153    1.043526    3.442270    0.374971    0.067884    0.022401    0.622636    
#> 098: 0.371208    1.051232    3.451668    0.406320    0.069011    0.021281    0.613684    
#> 099: 0.343935    1.030847    3.446937    0.386004    0.065560    0.020217    0.628805    
#> 100: 0.346743    1.039759    3.450993    0.366704    0.071924    0.021259    0.612423    
#> 101: 0.319791    1.032623    3.431930    0.348368    0.068624    0.020196    0.614885    
#> 102: 0.336235    1.033687    3.438192    0.330950    0.065192    0.019186    0.631185    
#> 103: 0.354629    1.032405    3.449816    0.361148    0.070505    0.018227    0.617526    
#> 104: 0.367745    1.041108    3.457884    0.428197    0.074174    0.017315    0.632510    
#> 105: 0.394486    1.027326    3.457761    0.417822    0.077897    0.016450    0.637952    
#> 106: 0.403655    1.017541    3.460597    0.396931    0.079195    0.015627    0.623483    
#> 107: 0.401141    1.034836    3.458037    0.447211    0.091255    0.014846    0.628177    
#> 108: 0.379584    1.012248    3.460904    0.435523    0.086836    0.014104    0.645410    
#> 109: 0.386301    1.019288    3.465892    0.413747    0.091132    0.016310    0.631892    
#> 110: 0.380856    1.015761    3.449614    0.444582    0.092669    0.015494    0.636774    
#> 111: 0.380784    1.021334    3.453224    0.422353    0.088035    0.014719    0.618483    
#> 112: 0.356486    1.006067    3.434450    0.445790    0.092454    0.013983    0.622669    
#> 113: 0.345959    1.041955    3.439217    0.471282    0.087831    0.013284    0.617334    
#> 114: 0.372474    1.047957    3.441626    0.469480    0.093802    0.012802    0.616875    
#> 115: 0.390160    1.027753    3.444549    0.485523    0.100932    0.013257    0.623856    
#> 116: 0.412833    1.042455    3.458457    0.490288    0.095886    0.012594    0.635344    
#> 117: 0.370367    1.052683    3.455345    0.482678    0.091092    0.015164    0.625865    
#> 118: 0.376264    1.026307    3.458562    0.479031    0.086537    0.015340    0.613314    
#> 119: 0.393013    1.042957    3.453683    0.455079    0.082210    0.016660    0.630177    
#> 120: 0.373152    1.021984    3.454131    0.440500    0.080184    0.016057    0.617910    
#> 121: 0.389572    1.047144    3.470507    0.418475    0.076175    0.020100    0.618707    
#> 122: 0.386741    1.017373    3.468755    0.403078    0.072366    0.021245    0.620590    
#> 123: 0.434094    1.033246    3.465342    0.493153    0.070675    0.021108    0.620765    
#> 124: 0.429699    1.047793    3.461137    0.474393    0.072872    0.020893    0.623194    
#> 125: 0.384419    1.043641    3.451084    0.450674    0.074548    0.019849    0.631614    
#> 126: 0.357760    1.063156    3.438515    0.428140    0.077658    0.020706    0.636787    
#> 127: 0.401470    1.041271    3.448390    0.441506    0.075977    0.020330    0.611158    
#> 128: 0.384053    1.023466    3.465611    0.428107    0.072178    0.020909    0.622245    
#> 129: 0.408046    1.046958    3.465679    0.439943    0.074177    0.022376    0.625492    
#> 130: 0.430906    1.045372    3.467757    0.427383    0.070468    0.026543    0.626743    
#> 131: 0.385478    1.009136    3.465252    0.406013    0.066945    0.026512    0.638203    
#> 132: 0.328837    1.008666    3.447997    0.385713    0.063598    0.025186    0.640715    
#> 133: 0.334900    0.997849    3.460534    0.366427    0.075184    0.023927    0.637541    
#> 134: 0.366870    1.000763    3.471484    0.359928    0.071424    0.022731    0.630086    
#> 135: 0.388614    0.998420    3.474585    0.366189    0.068649    0.021594    0.620228    
#> 136: 0.377202    0.984894    3.483273    0.347879    0.066124    0.020514    0.609618    
#> 137: 0.428507    0.989146    3.490404    0.330485    0.062817    0.021345    0.618624    
#> 138: 0.422278    0.989195    3.484765    0.313961    0.061568    0.020277    0.624587    
#> 139: 0.402187    1.007322    3.480285    0.346050    0.064098    0.020436    0.621811    
#> 140: 0.395733    1.035924    3.481008    0.328748    0.063897    0.019840    0.640822    
#> 141: 0.378331    1.004786    3.471888    0.322054    0.073720    0.018848    0.621565    
#> 142: 0.413362    0.986673    3.484964    0.366323    0.070034    0.017906    0.625526    
#> 143: 0.373436    1.017842    3.476893    0.348007    0.074500    0.017011    0.634739    
#> 144: 0.431021    1.012328    3.482726    0.445341    0.076518    0.016160    0.614030    
#> 145: 0.376515    1.040355    3.450709    0.440541    0.085045    0.015352    0.622499    
#> 146: 0.373946    1.030377    3.464644    0.418514    0.080793    0.015421    0.626069    
#> 147: 0.343808    1.020640    3.445221    0.397588    0.076753    0.014650    0.616620    
#> 148: 0.345730    1.012881    3.461456    0.379019    0.077289    0.013917    0.613367    
#> 149: 0.363056    1.024862    3.472688    0.376990    0.073425    0.016065    0.640886    
#> 150: 0.418628    1.017064    3.457664    0.439195    0.069753    0.015580    0.634213    
#> 151: 0.362522    1.040494    3.455478    0.431801    0.066266    0.016685    0.622315    
#> 152: 0.338330    1.025923    3.455163    0.385652    0.074362    0.018115    0.626092    
#> 153: 0.333602    1.036914    3.457660    0.412504    0.082351    0.019567    0.628942    
#> 154: 0.375714    1.034369    3.457543    0.393029    0.088627    0.020780    0.635489    
#> 155: 0.354597    1.021751    3.458114    0.387486    0.074777    0.017195    0.621960    
#> 156: 0.378519    1.029303    3.467637    0.391457    0.081589    0.014206    0.634911    
#> 157: 0.398629    1.021706    3.467311    0.364908    0.090414    0.012060    0.647481    
#> 158: 0.407989    1.048670    3.463337    0.376860    0.082619    0.013698    0.629183    
#> 159: 0.364580    1.041233    3.461278    0.372609    0.068867    0.011460    0.637245    
#> 160: 0.379081    1.003363    3.471081    0.344464    0.074445    0.011116    0.642629    
#> 161: 0.398065    1.020215    3.466207    0.346341    0.083616    0.010626    0.637956    
#> 162: 0.407213    1.013047    3.466490    0.357324    0.077373    0.012074    0.645014    
#> 163: 0.408981    1.020270    3.462082    0.385809    0.062445    0.013205    0.641589    
#> 164: 0.398631    1.018003    3.468573    0.341721    0.074789    0.012618    0.630343    
#> 165: 0.445950    0.989182    3.477033    0.418049    0.074942    0.015065    0.644180    
#> 166: 0.417311    1.030920    3.471590    0.344087    0.080038    0.010223    0.656476    
#> 167: 0.426494    1.032894    3.476922    0.299777    0.086995    0.006905    0.662083    
#> 168: 0.433734    1.024790    3.474730    0.323208    0.091705    0.008262    0.633478    
#> 169: 0.403853    1.056613    3.465761    0.327685    0.091607    0.008601    0.649475    
#> 170: 0.405454    1.046833    3.464456    0.333827    0.082031    0.009785    0.627002    
#> 171: 0.378440    1.030268    3.467042    0.375119    0.091895    0.009632    0.627347    
#> 172: 0.370592    1.036472    3.461782    0.409685    0.089699    0.010075    0.626872    
#> 173: 0.357228    1.046675    3.445144    0.400955    0.083898    0.009988    0.635510    
#> 174: 0.354454    1.035822    3.449492    0.410966    0.088472    0.012276    0.634293    
#> 175: 0.383422    1.042172    3.440651    0.422052    0.091662    0.013591    0.653628    
#> 176: 0.402134    1.046984    3.461401    0.505600    0.072034    0.014651    0.641717    
#> 177: 0.385079    1.042249    3.466887    0.413048    0.086461    0.016786    0.623094    
#> 178: 0.394263    1.002245    3.474670    0.416416    0.086537    0.017135    0.630220    
#> 179: 0.444967    1.018264    3.471758    0.376244    0.073682    0.012839    0.634896    
#> 180: 0.379439    1.008757    3.469510    0.349356    0.072418    0.014065    0.645372    
#> 181: 0.376712    1.012258    3.449774    0.336969    0.070760    0.012516    0.640226    
#> 182: 0.346554    1.043451    3.436541    0.359487    0.092940    0.011638    0.640620    
#> 183: 0.358770    1.066685    3.439754    0.341609    0.087641    0.011138    0.643733    
#> 184: 0.356936    1.038738    3.445792    0.367388    0.087697    0.011938    0.636839    
#> 185: 0.351598    1.065404    3.444967    0.328830    0.077066    0.010703    0.642691    
#> 186: 0.363578    1.060179    3.459266    0.311319    0.065226    0.013865    0.655672    
#> 187: 0.353118    1.026103    3.464171    0.292008    0.061500    0.014084    0.629632    
#> 188: 0.340943    1.039985    3.459755    0.344725    0.072957    0.013224    0.637288    
#> 189: 0.384288    1.049641    3.469726    0.381043    0.073167    0.016916    0.634504    
#> 190: 0.357081    1.038027    3.461719    0.374822    0.061703    0.014557    0.618676    
#> 191: 0.360701    1.036522    3.454797    0.389969    0.059106    0.016989    0.615374    
#> 192: 0.363530    1.040798    3.455861    0.399566    0.070952    0.016834    0.629509    
#> 193: 0.358766    1.034578    3.456197    0.388409    0.058628    0.016961    0.610529    
#> 194: 0.345709    1.015655    3.452190    0.357152    0.075360    0.018615    0.632076    
#> 195: 0.339305    1.017420    3.447008    0.377780    0.080828    0.019548    0.626731    
#> 196: 0.367363    1.020927    3.464944    0.399269    0.093861    0.019391    0.649190    
#> 197: 0.335624    1.050062    3.468267    0.376805    0.075748    0.019374    0.665045    
#> 198: 0.365333    1.025443    3.445384    0.386901    0.076319    0.018358    0.627411    
#> 199: 0.374237    1.017911    3.460580    0.411670    0.066756    0.020260    0.620834    
#> 200: 0.375642    1.012724    3.468736    0.417114    0.069343    0.015459    0.632849    
#> 201: 0.380329    1.009853    3.471833    0.386387    0.070396    0.015106    0.628971    
#> 202: 0.374126    1.011209    3.469062    0.380705    0.073566    0.016993    0.633415    
#> 203: 0.383562    1.010297    3.464934    0.390981    0.073973    0.018340    0.632152    
#> 204: 0.383280    1.006996    3.466097    0.401686    0.076112    0.018417    0.633190    
#> 205: 0.386025    1.007774    3.466447    0.410227    0.077538    0.018731    0.633777    
#> 206: 0.383219    1.012326    3.466769    0.414343    0.077319    0.018442    0.634210    
#> 207: 0.383280    1.013929    3.466423    0.412392    0.077906    0.018054    0.632347    
#> 208: 0.384181    1.017228    3.465792    0.412857    0.076939    0.017751    0.631035    
#> 209: 0.385247    1.015509    3.465030    0.408117    0.076013    0.017562    0.630807    
#> 210: 0.385536    1.014781    3.465456    0.405702    0.075557    0.017328    0.630612    
#> 211: 0.389720    1.014905    3.465881    0.405507    0.075153    0.017318    0.629519    
#> 212: 0.392897    1.014994    3.466160    0.407175    0.075000    0.017538    0.627745    
#> 213: 0.396810    1.012824    3.466564    0.410945    0.075065    0.017649    0.627200    
#> 214: 0.398947    1.011250    3.467561    0.410883    0.075381    0.017870    0.626752    
#> 215: 0.398858    1.011801    3.468078    0.411566    0.075843    0.018011    0.626872    
#> 216: 0.399548    1.011226    3.468095    0.408006    0.076718    0.017912    0.628025    
#> 217: 0.396863    1.012385    3.467490    0.404546    0.077046    0.017929    0.627452    
#> 218: 0.393749    1.014247    3.466364    0.402085    0.077398    0.018057    0.627270    
#> 219: 0.391347    1.014121    3.465239    0.398215    0.077228    0.018018    0.628099    
#> 220: 0.387939    1.014628    3.464666    0.396431    0.077483    0.017743    0.628864    
#> 221: 0.384827    1.015595    3.463796    0.393411    0.077183    0.017595    0.628910    
#> 222: 0.382536    1.016397    3.463003    0.392324    0.077285    0.017431    0.629302    
#> 223: 0.382756    1.016833    3.462606    0.391767    0.077168    0.017339    0.629047    
#> 224: 0.383026    1.017223    3.462746    0.390026    0.077226    0.017324    0.628516    
#> 225: 0.382820    1.016205    3.463153    0.388976    0.076829    0.017383    0.627778    
#> 226: 0.383177    1.015443    3.463204    0.386940    0.076526    0.017285    0.627643    
#> 227: 0.382382    1.015207    3.463159    0.386135    0.076247    0.017221    0.627720    
#> 228: 0.380131    1.016167    3.462572    0.382903    0.076168    0.017158    0.628072    
#> 229: 0.379071    1.016039    3.462191    0.382235    0.076167    0.017105    0.628127    
#> 230: 0.380127    1.015649    3.462231    0.382756    0.076033    0.017048    0.628085    
#> 231: 0.380652    1.015905    3.462664    0.383112    0.076174    0.016893    0.627997    
#> 232: 0.381020    1.015854    3.463123    0.381945    0.076245    0.016821    0.627823    
#> 233: 0.380653    1.015512    3.463130    0.382815    0.076640    0.016735    0.627862    
#> 234: 0.380226    1.015688    3.462922    0.383312    0.076610    0.016661    0.627836    
#> 235: 0.379762    1.016169    3.462708    0.382683    0.076716    0.016548    0.627800    
#> 236: 0.379792    1.016792    3.462485    0.384132    0.076782    0.016509    0.627766    
#> 237: 0.380565    1.017145    3.462504    0.385765    0.076883    0.016552    0.628194    
#> 238: 0.381082    1.017425    3.462557    0.385467    0.076981    0.016593    0.628778    
#> 239: 0.381164    1.017841    3.462554    0.385438    0.077098    0.016597    0.628783    
#> 240: 0.381150    1.017372    3.462735    0.384944    0.077196    0.016601    0.628846    
#> 241: 0.381772    1.016387    3.462897    0.385761    0.076961    0.016584    0.628832    
#> 242: 0.381711    1.015728    3.462950    0.388152    0.077430    0.016573    0.628753    
#> 243: 0.381947    1.016049    3.463024    0.388381    0.077637    0.016555    0.628773    
#> 244: 0.381813    1.016333    3.463180    0.389085    0.077718    0.016546    0.628783    
#> 245: 0.382015    1.015942    3.463387    0.389705    0.077577    0.016530    0.629118    
#> 246: 0.382401    1.015658    3.463747    0.388907    0.077470    0.016637    0.629143    
#> 247: 0.383028    1.015089    3.464225    0.388567    0.077266    0.016711    0.628909    
#> 248: 0.383297    1.015614    3.464551    0.387424    0.077175    0.016793    0.628722    
#> 249: 0.383283    1.016201    3.464740    0.386162    0.077067    0.016868    0.628741    
#> 250: 0.383721    1.016617    3.464913    0.386239    0.077089    0.016901    0.628569    
#> 251: 0.384122    1.016915    3.465132    0.386422    0.077032    0.016900    0.628544    
#> 252: 0.385328    1.017184    3.465493    0.386669    0.076850    0.016931    0.628509    
#> 253: 0.385658    1.017170    3.465694    0.387109    0.076614    0.016943    0.628477    
#> 254: 0.386061    1.017244    3.465990    0.386891    0.076558    0.016954    0.628400    
#> 255: 0.386130    1.017731    3.466099    0.386710    0.076720    0.016952    0.628208    
#> 256: 0.386485    1.017892    3.466118    0.386937    0.076767    0.016962    0.627817    
#> 257: 0.386205    1.017911    3.466044    0.386177    0.076636    0.016974    0.627566    
#> 258: 0.385642    1.017669    3.465952    0.385653    0.076522    0.016964    0.627524    
#> 259: 0.385383    1.017709    3.465892    0.386487    0.076352    0.016960    0.627633    
#> 260: 0.385570    1.017817    3.465842    0.386780    0.076152    0.016955    0.627529    
#> 261: 0.385651    1.017688    3.465898    0.386478    0.075939    0.016948    0.627420    
#> 262: 0.385719    1.017936    3.465914    0.385805    0.075953    0.016945    0.627183    
#> 263: 0.385385    1.018259    3.465946    0.384702    0.075895    0.016974    0.627044    
#> 264: 0.384615    1.018405    3.465795    0.383544    0.075670    0.016951    0.627407    
#> 265: 0.384547    1.018538    3.465644    0.384215    0.075842    0.016939    0.627305    
#> 266: 0.384430    1.018713    3.465533    0.384537    0.075668    0.016967    0.627202    
#> 267: 0.384130    1.018876    3.465530    0.384926    0.075580    0.016988    0.627088    
#> 268: 0.383274    1.018981    3.465214    0.384288    0.075406    0.016955    0.627171    
#> 269: 0.383649    1.018933    3.465171    0.384208    0.075247    0.016950    0.627358    
#> 270: 0.383739    1.019438    3.464926    0.384991    0.075264    0.016895    0.627327    
#> 271: 0.383336    1.019861    3.464537    0.385430    0.075230    0.016879    0.627423    
#> 272: 0.383333    1.020077    3.464312    0.385901    0.075060    0.016841    0.627924    
#> 273: 0.383107    1.020349    3.464216    0.386023    0.074960    0.016821    0.628143    
#> 274: 0.382914    1.020546    3.464224    0.386229    0.075067    0.016778    0.628092    
#> 275: 0.382934    1.020875    3.464012    0.387691    0.075152    0.016745    0.628017    
#> 276: 0.382569    1.020985    3.463991    0.389165    0.075170    0.016747    0.628048    
#> 277: 0.382923    1.021098    3.464132    0.389826    0.075160    0.016786    0.627925    
#> 278: 0.382867    1.021382    3.464215    0.389732    0.075175    0.016802    0.627929    
#> 279: 0.383094    1.021433    3.464318    0.389213    0.075219    0.016836    0.628214    
#> 280: 0.383241    1.021553    3.464398    0.388605    0.075296    0.016861    0.628131    
#> 281: 0.383318    1.021615    3.464448    0.388869    0.075102    0.016886    0.627958    
#> 282: 0.383685    1.021653    3.464530    0.389760    0.074896    0.016921    0.627762    
#> 283: 0.384236    1.021762    3.464706    0.390846    0.074705    0.016969    0.627726    
#> 284: 0.384510    1.021641    3.464813    0.390730    0.074633    0.017044    0.627406    
#> 285: 0.384703    1.021799    3.464702    0.392403    0.074474    0.017101    0.627376    
#> 286: 0.384637    1.021803    3.464659    0.394024    0.074265    0.017172    0.627438    
#> 287: 0.384568    1.022013    3.464497    0.395425    0.074311    0.017219    0.627407    
#> 288: 0.385073    1.021786    3.464514    0.396520    0.074269    0.017304    0.627542    
#> 289: 0.385260    1.021681    3.464500    0.397377    0.074183    0.017339    0.627598    
#> 290: 0.385477    1.021696    3.464470    0.397573    0.074168    0.017340    0.627970    
#> 291: 0.385892    1.021779    3.464670    0.397503    0.074190    0.017354    0.627881    
#> 292: 0.386068    1.021634    3.464728    0.397051    0.074241    0.017354    0.627837    
#> 293: 0.385982    1.021481    3.464760    0.396720    0.074288    0.017367    0.627825    
#> 294: 0.385971    1.021370    3.464719    0.396986    0.074243    0.017377    0.627907    
#> 295: 0.385879    1.021170    3.464615    0.396082    0.074215    0.017364    0.627965    
#> 296: 0.386088    1.021103    3.464635    0.395393    0.074287    0.017389    0.628101    
#> 297: 0.386467    1.021112    3.464720    0.395661    0.074217    0.017395    0.628185    
#> 298: 0.386405    1.021009    3.464742    0.395302    0.074117    0.017410    0.628110    
#> 299: 0.386526    1.021110    3.464655    0.395463    0.074042    0.017450    0.627931    
#> 300: 0.386750    1.020884    3.464716    0.395685    0.073962    0.017487    0.627767    
#> 301: 0.386726    1.020856    3.464666    0.395109    0.073845    0.017539    0.627739    
#> 302: 0.386515    1.020963    3.464574    0.394808    0.073708    0.017574    0.627714    
#> 303: 0.386359    1.020959    3.464543    0.394659    0.073591    0.017601    0.627424    
#> 304: 0.386377    1.021152    3.464485    0.394581    0.073465    0.017639    0.627512    
#> 305: 0.386450    1.020956    3.464546    0.394510    0.073311    0.017674    0.627540    
#> 306: 0.386325    1.020758    3.464480    0.394752    0.073263    0.017683    0.627506    
#> 307: 0.386332    1.020728    3.464394    0.395140    0.073171    0.017723    0.627564    
#> 308: 0.385959    1.020662    3.464357    0.395832    0.073186    0.017789    0.627615    
#> 309: 0.386156    1.020477    3.464259    0.397294    0.073235    0.017831    0.627693    
#> 310: 0.386581    1.020425    3.464233    0.397992    0.073252    0.017858    0.627768    
#> 311: 0.386825    1.020457    3.464172    0.399112    0.073198    0.017884    0.627755    
#> 312: 0.386504    1.020314    3.464102    0.399856    0.073238    0.017921    0.627789    
#> 313: 0.386529    1.020150    3.464046    0.400300    0.073291    0.017975    0.627700    
#> 314: 0.386097    1.020299    3.463896    0.399689    0.073282    0.018000    0.627639    
#> 315: 0.385467    1.020505    3.463808    0.398963    0.073172    0.018023    0.627687    
#> 316: 0.385522    1.020634    3.463730    0.398793    0.073099    0.018042    0.627804    
#> 317: 0.385502    1.020680    3.463773    0.398315    0.073017    0.018086    0.627956    
#> 318: 0.385431    1.020800    3.463716    0.397965    0.072937    0.018106    0.627831    
#> 319: 0.385536    1.020720    3.463809    0.397760    0.072846    0.018136    0.627735    
#> 320: 0.385359    1.020661    3.463825    0.397960    0.072826    0.018158    0.627840    
#> 321: 0.385438    1.020738    3.463713    0.398194    0.072700    0.018174    0.627946    
#> 322: 0.385536    1.020667    3.463701    0.397478    0.072631    0.018175    0.628029    
#> 323: 0.385256    1.020713    3.463636    0.396772    0.072583    0.018178    0.627976    
#> 324: 0.385143    1.020849    3.463655    0.396038    0.072587    0.018204    0.627799    
#> 325: 0.384828    1.021001    3.463629    0.395278    0.072508    0.018180    0.627856    
#> 326: 0.384608    1.020876    3.463557    0.394497    0.072432    0.018187    0.627844    
#> 327: 0.384547    1.020859    3.463609    0.393810    0.072433    0.018194    0.627848    
#> 328: 0.384711    1.020782    3.463745    0.393354    0.072474    0.018200    0.627841    
#> 329: 0.384919    1.020776    3.463901    0.393227    0.072531    0.018227    0.627785    
#> 330: 0.384892    1.020790    3.463936    0.393236    0.072502    0.018223    0.627671    
#> 331: 0.385095    1.020954    3.463979    0.393325    0.072493    0.018205    0.627628    
#> 332: 0.385161    1.020845    3.464077    0.393518    0.072535    0.018182    0.627675    
#> 333: 0.385256    1.020804    3.464065    0.393568    0.072612    0.018155    0.627678    
#> 334: 0.385268    1.020683    3.463994    0.393766    0.072644    0.018143    0.627619    
#> 335: 0.385228    1.020737    3.463938    0.393212    0.072702    0.018145    0.627651    
#> 336: 0.385008    1.020983    3.463865    0.392831    0.072695    0.018153    0.627621    
#> 337: 0.384968    1.021231    3.463752    0.393122    0.072684    0.018169    0.627562    
#> 338: 0.384957    1.021298    3.463763    0.393283    0.072682    0.018209    0.627426    
#> 339: 0.384965    1.021336    3.463805    0.392944    0.072626    0.018245    0.627403    
#> 340: 0.385049    1.020966    3.463935    0.392699    0.072618    0.018294    0.627524    
#> 341: 0.385264    1.020882    3.464104    0.392455    0.072618    0.018312    0.627552    
#> 342: 0.385216    1.020736    3.464175    0.392385    0.072617    0.018308    0.627556    
#> 343: 0.385149    1.020698    3.464145    0.392533    0.072650    0.018287    0.627537    
#> 344: 0.385109    1.020573    3.464141    0.393090    0.072730    0.018266    0.627527    
#> 345: 0.385122    1.020612    3.464146    0.393301    0.072650    0.018260    0.627550    
#> 346: 0.384990    1.020653    3.464079    0.393612    0.072617    0.018262    0.627446    
#> 347: 0.384958    1.020535    3.463986    0.393622    0.072583    0.018275    0.627515    
#> 348: 0.384618    1.020651    3.463912    0.393308    0.072539    0.018286    0.627536    
#> 349: 0.384501    1.020607    3.463867    0.393556    0.072587    0.018277    0.627527    
#> 350: 0.384205    1.020594    3.463810    0.393240    0.072573    0.018252    0.627554    
#> 351: 0.384137    1.020717    3.463748    0.392924    0.072555    0.018239    0.627652    
#> 352: 0.383771    1.020920    3.463738    0.392761    0.072590    0.018262    0.627776    
#> 353: 0.383837    1.021177    3.463700    0.392456    0.072603    0.018262    0.627923    
#> 354: 0.384004    1.021318    3.463655    0.392324    0.072522    0.018294    0.628012    
#> 355: 0.384569    1.021256    3.463682    0.392670    0.072504    0.018304    0.627942    
#> 356: 0.384672    1.021167    3.463754    0.393063    0.072519    0.018303    0.627952    
#> 357: 0.384772    1.021222    3.463783    0.392770    0.072532    0.018281    0.627928    
#> 358: 0.384731    1.021197    3.463863    0.392770    0.072542    0.018280    0.627842    
#> 359: 0.384831    1.021150    3.463892    0.392963    0.072566    0.018288    0.627781    
#> 360: 0.384874    1.021141    3.463866    0.393237    0.072526    0.018304    0.627614    
#> 361: 0.384889    1.021109    3.463815    0.393397    0.072411    0.018299    0.627613    
#> 362: 0.384909    1.021043    3.463805    0.393455    0.072348    0.018289    0.627437    
#> 363: 0.384922    1.021018    3.463862    0.393651    0.072366    0.018300    0.627361    
#> 364: 0.385109    1.021013    3.463855    0.393994    0.072358    0.018303    0.627393    
#> 365: 0.385094    1.020948    3.463852    0.394437    0.072395    0.018308    0.627441    
#> 366: 0.385199    1.021045    3.463769    0.394832    0.072370    0.018299    0.627558    
#> 367: 0.385126    1.021094    3.463703    0.394518    0.072380    0.018284    0.627576    
#> 368: 0.385214    1.021206    3.463658    0.394498    0.072326    0.018291    0.627494    
#> 369: 0.384954    1.021277    3.463549    0.394368    0.072301    0.018303    0.627439    
#> 370: 0.384744    1.021422    3.463470    0.393931    0.072274    0.018326    0.627419    
#> 371: 0.384634    1.021552    3.463404    0.393814    0.072211    0.018345    0.627366    
#> 372: 0.384390    1.021609    3.463347    0.393823    0.072175    0.018361    0.627442    
#> 373: 0.384067    1.021715    3.463279    0.393831    0.072200    0.018388    0.627468    
#> 374: 0.383966    1.021855    3.463194    0.393993    0.072212    0.018393    0.627327    
#> 375: 0.383904    1.021856    3.463153    0.393985    0.072216    0.018396    0.627252    
#> 376: 0.383955    1.021911    3.463189    0.393634    0.072195    0.018397    0.627264    
#> 377: 0.383738    1.022047    3.463149    0.393451    0.072171    0.018405    0.627256    
#> 378: 0.383589    1.022087    3.463103    0.393277    0.072092    0.018410    0.627204    
#> 379: 0.383318    1.021960    3.463083    0.393063    0.072014    0.018435    0.627247    
#> 380: 0.383082    1.022006    3.463049    0.392914    0.072009    0.018457    0.627181    
#> 381: 0.382934    1.022136    3.462946    0.393152    0.072016    0.018466    0.627183    
#> 382: 0.382722    1.022228    3.462854    0.393361    0.071980    0.018477    0.627043    
#> 383: 0.382729    1.022313    3.462776    0.393518    0.071975    0.018462    0.626920    
#> 384: 0.382512    1.022355    3.462760    0.393280    0.071970    0.018472    0.626918    
#> 385: 0.382558    1.022409    3.462780    0.392932    0.071933    0.018465    0.626927    
#> 386: 0.382526    1.022538    3.462786    0.392801    0.071881    0.018447    0.627032    
#> 387: 0.382673    1.022701    3.462839    0.392573    0.071791    0.018437    0.627041    
#> 388: 0.382778    1.022739    3.462881    0.392730    0.071786    0.018435    0.627008    
#> 389: 0.382876    1.022634    3.462884    0.392807    0.071815    0.018433    0.626956    
#> 390: 0.382943    1.022641    3.462894    0.393095    0.071782    0.018427    0.626913    
#> 391: 0.382941    1.022620    3.462879    0.393054    0.071736    0.018426    0.626820    
#> 392: 0.382914    1.022640    3.462949    0.392767    0.071711    0.018427    0.626809    
#> 393: 0.382956    1.022576    3.462936    0.392744    0.071680    0.018439    0.626790    
#> 394: 0.382928    1.022577    3.462914    0.392853    0.071650    0.018426    0.626838    
#> 395: 0.383005    1.022584    3.462938    0.392928    0.071580    0.018425    0.626870    
#> 396: 0.383232    1.022608    3.462980    0.393127    0.071599    0.018423    0.626791    
#> 397: 0.383388    1.022667    3.463026    0.393178    0.071586    0.018416    0.626732    
#> 398: 0.383683    1.022546    3.463104    0.393334    0.071612    0.018394    0.626747    
#> 399: 0.383910    1.022510    3.463180    0.393356    0.071535    0.018375    0.626720    
#> 400: 0.384123    1.022506    3.463230    0.393300    0.071536    0.018374    0.626753    
#> 401: 0.384284    1.022633    3.463239    0.393094    0.071574    0.018366    0.626745    
#> 402: 0.384378    1.022687    3.463292    0.392961    0.071498    0.018356    0.626800    
#> 403: 0.384477    1.022616    3.463342    0.392675    0.071456    0.018334    0.626809    
#> 404: 0.384411    1.022623    3.463306    0.392648    0.071434    0.018336    0.626783    
#> 405: 0.384412    1.022624    3.463308    0.392624    0.071461    0.018337    0.626793    
#> 406: 0.384444    1.022647    3.463286    0.392592    0.071446    0.018348    0.626885    
#> 407: 0.384533    1.022704    3.463352    0.392625    0.071449    0.018358    0.626925    
#> 408: 0.384790    1.022761    3.463394    0.392630    0.071472    0.018366    0.626930    
#> 409: 0.384835    1.022716    3.463425    0.392429    0.071419    0.018386    0.626862    
#> 410: 0.384807    1.022735    3.463395    0.392219    0.071403    0.018390    0.626821    
#> 411: 0.384790    1.022643    3.463393    0.392136    0.071437    0.018399    0.626826    
#> 412: 0.384775    1.022787    3.463336    0.392082    0.071487    0.018380    0.626844    
#> 413: 0.384665    1.022820    3.463287    0.391966    0.071515    0.018357    0.626904    
#> 414: 0.384376    1.022821    3.463286    0.391852    0.071532    0.018350    0.626904    
#> 415: 0.384352    1.022818    3.463318    0.391617    0.071504    0.018357    0.626854    
#> 416: 0.384358    1.022771    3.463336    0.391420    0.071500    0.018360    0.626921    
#> 417: 0.384516    1.022667    3.463366    0.391475    0.071503    0.018348    0.626882    
#> 418: 0.384516    1.022654    3.463395    0.391477    0.071572    0.018336    0.626825    
#> 419: 0.384635    1.022671    3.463422    0.391652    0.071603    0.018324    0.626802    
#> 420: 0.384648    1.022688    3.463449    0.391535    0.071672    0.018317    0.626840    
#> 421: 0.384688    1.022696    3.463524    0.391481    0.071708    0.018311    0.626754    
#> 422: 0.384881    1.022532    3.463583    0.391375    0.071700    0.018311    0.626744    
#> 423: 0.385060    1.022375    3.463639    0.391232    0.071669    0.018328    0.626809    
#> 424: 0.385058    1.022210    3.463629    0.391426    0.071617    0.018339    0.626801    
#> 425: 0.385339    1.022133    3.463677    0.391807    0.071572    0.018363    0.626799    
#> 426: 0.385488    1.022093    3.463738    0.391982    0.071568    0.018376    0.626780    
#> 427: 0.385523    1.022050    3.463782    0.392045    0.071572    0.018391    0.626761    
#> 428: 0.385405    1.022116    3.463751    0.391814    0.071551    0.018377    0.626711    
#> 429: 0.385468    1.022232    3.463711    0.391748    0.071549    0.018351    0.626731    
#> 430: 0.385441    1.022352    3.463682    0.391864    0.071621    0.018348    0.626746    
#> 431: 0.385346    1.022405    3.463612    0.391860    0.071613    0.018347    0.626716    
#> 432: 0.385196    1.022540    3.463567    0.392067    0.071598    0.018354    0.626674    
#> 433: 0.385071    1.022592    3.463537    0.391906    0.071572    0.018352    0.626683    
#> 434: 0.384916    1.022540    3.463550    0.391630    0.071572    0.018358    0.626625    
#> 435: 0.384893    1.022489    3.463537    0.391579    0.071590    0.018354    0.626528    
#> 436: 0.384952    1.022431    3.463595    0.391777    0.071587    0.018341    0.626510    
#> 437: 0.384985    1.022316    3.463649    0.391537    0.071590    0.018336    0.626502    
#> 438: 0.385019    1.022330    3.463647    0.391670    0.071595    0.018338    0.626447    
#> 439: 0.385006    1.022372    3.463667    0.391497    0.071554    0.018342    0.626430    
#> 440: 0.385048    1.022381    3.463706    0.391386    0.071536    0.018323    0.626422    
#> 441: 0.385124    1.022386    3.463707    0.391313    0.071520    0.018307    0.626390    
#> 442: 0.384994    1.022414    3.463720    0.391181    0.071481    0.018296    0.626352    
#> 443: 0.385081    1.022499    3.463680    0.391218    0.071494    0.018273    0.626378    
#> 444: 0.384960    1.022618    3.463576    0.391337    0.071522    0.018261    0.626315    
#> 445: 0.384764    1.022696    3.463504    0.391088    0.071523    0.018268    0.626259    
#> 446: 0.384543    1.022808    3.463439    0.391085    0.071548    0.018257    0.626229    
#> 447: 0.384553    1.022907    3.463397    0.391022    0.071610    0.018251    0.626195    
#> 448: 0.384357    1.022998    3.463348    0.390958    0.071642    0.018242    0.626137    
#> 449: 0.384295    1.023056    3.463394    0.390860    0.071677    0.018233    0.626141    
#> 450: 0.384213    1.023076    3.463378    0.390585    0.071684    0.018217    0.626228    
#> 451: 0.384158    1.023065    3.463353    0.390447    0.071737    0.018203    0.626279    
#> 452: 0.384144    1.023098    3.463353    0.390386    0.071749    0.018192    0.626247    
#> 453: 0.384174    1.023056    3.463389    0.390252    0.071770    0.018177    0.626220    
#> 454: 0.384230    1.023104    3.463411    0.390181    0.071776    0.018154    0.626187    
#> 455: 0.384284    1.023059    3.463431    0.390126    0.071787    0.018141    0.626191    
#> 456: 0.384230    1.023018    3.463423    0.390078    0.071766    0.018138    0.626203    
#> 457: 0.384197    1.022967    3.463434    0.390116    0.071747    0.018130    0.626192    
#> 458: 0.384260    1.023082    3.463465    0.390159    0.071762    0.018121    0.626141    
#> 459: 0.384117    1.023149    3.463462    0.390137    0.071844    0.018120    0.626148    
#> 460: 0.383997    1.023159    3.463448    0.390099    0.071859    0.018114    0.626052    
#> 461: 0.383967    1.023178    3.463486    0.389809    0.071903    0.018110    0.626006    
#> 462: 0.383870    1.023235    3.463539    0.389647    0.071950    0.018102    0.626019    
#> 463: 0.383930    1.023247    3.463552    0.389667    0.071939    0.018083    0.626068    
#> 464: 0.384036    1.023240    3.463543    0.389708    0.071966    0.018073    0.626087    
#> 465: 0.384185    1.023089    3.463595    0.389788    0.071996    0.018062    0.626116    
#> 466: 0.384207    1.023102    3.463604    0.389715    0.072012    0.018046    0.626123    
#> 467: 0.384186    1.023080    3.463603    0.389812    0.072075    0.018028    0.626105    
#> 468: 0.384320    1.023125    3.463634    0.390114    0.072133    0.018011    0.626141    
#> 469: 0.384400    1.023190    3.463681    0.390185    0.072161    0.018007    0.626216    
#> 470: 0.384346    1.023220    3.463651    0.390128    0.072186    0.018001    0.626188    
#> 471: 0.384330    1.023164    3.463644    0.390128    0.072182    0.017999    0.626166    
#> 472: 0.384314    1.023083    3.463650    0.390103    0.072211    0.017995    0.626117    
#> 473: 0.384276    1.023028    3.463663    0.389844    0.072207    0.017982    0.626051    
#> 474: 0.384251    1.023002    3.463668    0.389670    0.072187    0.017979    0.626083    
#> 475: 0.384357    1.022982    3.463707    0.389579    0.072180    0.017970    0.626068    
#> 476: 0.384511    1.022959    3.463720    0.389614    0.072169    0.017963    0.626061    
#> 477: 0.384449    1.022980    3.463759    0.389322    0.072198    0.017953    0.625989    
#> 478: 0.384337    1.022932    3.463786    0.389064    0.072196    0.017949    0.625979    
#> 479: 0.384470    1.022919    3.463832    0.389040    0.072247    0.017950    0.625958    
#> 480: 0.384606    1.022909    3.463859    0.389138    0.072292    0.017949    0.625963    
#> 481: 0.384673    1.022931    3.463880    0.388998    0.072254    0.017946    0.626015    
#> 482: 0.384695    1.022949    3.463845    0.388722    0.072228    0.017937    0.626072    
#> 483: 0.384667    1.022999    3.463823    0.388713    0.072215    0.017927    0.626065    
#> 484: 0.384582    1.022931    3.463794    0.388652    0.072171    0.017927    0.626108    
#> 485: 0.384512    1.023004    3.463787    0.388500    0.072138    0.017935    0.626174    
#> 486: 0.384499    1.023090    3.463831    0.388469    0.072116    0.017932    0.626165    
#> 487: 0.384653    1.023093    3.463922    0.388374    0.072094    0.017936    0.626190    
#> 488: 0.384660    1.023044    3.463968    0.388200    0.072150    0.017937    0.626212    
#> 489: 0.384788    1.023024    3.463985    0.388250    0.072203    0.017944    0.626235    
#> 490: 0.384923    1.023003    3.464020    0.388272    0.072235    0.017954    0.626181    
#> 491: 0.384852    1.023081    3.464025    0.388130    0.072270    0.017956    0.626140    
#> 492: 0.384735    1.023198    3.463977    0.387975    0.072321    0.017956    0.626179    
#> 493: 0.384660    1.023240    3.463931    0.387776    0.072357    0.017950    0.626201    
#> 494: 0.384814    1.023278    3.463906    0.387701    0.072389    0.017946    0.626204    
#> 495: 0.384871    1.023298    3.463895    0.387673    0.072401    0.017943    0.626193    
#> 496: 0.384867    1.023369    3.463804    0.387788    0.072392    0.017930    0.626202    
#> 497: 0.384775    1.023448    3.463755    0.387861    0.072374    0.017921    0.626216    
#> 498: 0.384687    1.023481    3.463689    0.388044    0.072364    0.017912    0.626151    
#> 499: 0.384591    1.023549    3.463624    0.387963    0.072385    0.017903    0.626057    
#> 500: 0.384508    1.023589    3.463565    0.387818    0.072460    0.017891    0.626020    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.292060    0.990179    3.445648    0.392401    0.082551    0.016800    1.738304    
#> 002: 0.290581    1.029917    3.472683    0.372781    0.078423    0.015960    1.201157    
#> 003: 0.458526    0.969876    3.504149    0.354142    0.115691    0.015162    0.852348    
#> 004: 0.443757    0.956499    3.502422    0.336435    0.118228    0.014404    0.758306    
#> 005: 0.476779    0.950324    3.500494    0.319613    0.112317    0.013684    0.729181    
#> 006: 0.436573    0.960410    3.484031    0.303633    0.129737    0.013000    0.687184    
#> 007: 0.393240    0.973971    3.483485    0.288451    0.123250    0.012350    0.686358    
#> 008: 0.393986    0.980917    3.476632    0.274029    0.125417    0.011732    0.698052    
#> 009: 0.364143    0.981327    3.470905    0.260327    0.119146    0.011146    0.693975    
#> 010: 0.375290    0.970437    3.472904    0.247311    0.128026    0.010588    0.699246    
#> 011: 0.425373    0.971291    3.472913    0.234945    0.142324    0.011417    0.717106    
#> 012: 0.419047    0.976354    3.470654    0.223198    0.135208    0.010846    0.698752    
#> 013: 0.372010    0.989123    3.470115    0.242040    0.140191    0.011746    0.691727    
#> 014: 0.411922    0.969428    3.484806    0.229938    0.133181    0.012710    0.700512    
#> 015: 0.430407    0.961340    3.490387    0.245641    0.126522    0.013225    0.667133    
#> 016: 0.433720    0.995949    3.488399    0.233359    0.120196    0.012703    0.684802    
#> 017: 0.378576    1.006809    3.482494    0.230377    0.118665    0.015162    0.689023    
#> 018: 0.407010    1.010786    3.465271    0.222186    0.123117    0.016491    0.674391    
#> 019: 0.372035    0.999397    3.469496    0.211076    0.116961    0.015666    0.663269    
#> 020: 0.397631    1.005370    3.480256    0.200551    0.125688    0.014883    0.685084    
#> 021: 0.431303    0.982173    3.487610    0.196379    0.132281    0.014139    0.660676    
#> 022: 0.407695    0.981148    3.486393    0.187723    0.128950    0.015300    0.674600    
#> 023: 0.469941    0.965182    3.498502    0.208510    0.122502    0.014535    0.711831    
#> 024: 0.456936    0.980933    3.496603    0.209730    0.133969    0.013808    0.705248    
#> 025: 0.414720    0.964341    3.484060    0.199244    0.127271    0.013118    0.675122    
#> 026: 0.376988    1.000977    3.472083    0.194601    0.120907    0.012462    0.671362    
#> 027: 0.366794    1.010028    3.468158    0.236284    0.114862    0.014374    0.698282    
#> 028: 0.425923    0.992278    3.477942    0.243457    0.109119    0.013689    0.682017    
#> 029: 0.441741    0.984922    3.475915    0.231284    0.141323    0.013279    0.688413    
#> 030: 0.436140    0.989887    3.476350    0.250168    0.134257    0.012615    0.677322    
#> 031: 0.412074    0.967394    3.490733    0.237659    0.140505    0.014178    0.696599    
#> 032: 0.417587    0.963302    3.490718    0.225776    0.133480    0.013469    0.695765    
#> 033: 0.387478    0.989305    3.479883    0.214487    0.126806    0.012796    0.704446    
#> 034: 0.407561    1.005206    3.480856    0.203763    0.122309    0.012156    0.702233    
#> 035: 0.399163    0.983611    3.471292    0.193575    0.116641    0.013164    0.677410    
#> 036: 0.392232    1.013195    3.471936    0.183896    0.132401    0.015667    0.685720    
#> 037: 0.367827    1.020419    3.472649    0.196205    0.125781    0.018752    0.678542    
#> 038: 0.414621    1.019365    3.468555    0.204623    0.123397    0.017814    0.684755    
#> 039: 0.417421    1.000177    3.480606    0.194391    0.117227    0.016923    0.684347    
#> 040: 0.398668    1.016234    3.489142    0.195229    0.111366    0.016077    0.713671    
#> 041: 0.399277    0.984273    3.486200    0.190378    0.105798    0.016708    0.685394    
#> 042: 0.439348    0.987939    3.488739    0.230605    0.100508    0.015872    0.677625    
#> 043: 0.392865    1.008830    3.466308    0.232776    0.100591    0.015169    0.674859    
#> 044: 0.343758    1.027777    3.461752    0.227176    0.099170    0.015752    0.675750    
#> 045: 0.360679    1.038056    3.455447    0.222621    0.094211    0.016810    0.678999    
#> 046: 0.367046    1.009696    3.465442    0.221947    0.121619    0.016545    0.668954    
#> 047: 0.379061    1.027079    3.461251    0.225324    0.115538    0.017083    0.665636    
#> 048: 0.403282    1.011595    3.474350    0.214058    0.120096    0.018261    0.672772    
#> 049: 0.388972    0.998212    3.473693    0.224094    0.135274    0.017348    0.673508    
#> 050: 0.446727    0.976153    3.480909    0.229157    0.132246    0.016481    0.688136    
#> 051: 0.420890    0.982796    3.481378    0.217699    0.125634    0.015657    0.684502    
#> 052: 0.439696    0.998126    3.493524    0.207945    0.119352    0.014874    0.659778    
#> 053: 0.433605    0.973066    3.488295    0.197548    0.113385    0.014651    0.668350    
#> 054: 0.388108    0.972328    3.490095    0.187670    0.133981    0.016584    0.681582    
#> 055: 0.409818    0.994936    3.477795    0.195279    0.127282    0.015755    0.683035    
#> 056: 0.386626    0.987375    3.480325    0.212074    0.120918    0.014967    0.694994    
#> 057: 0.391525    0.979701    3.485283    0.223482    0.119186    0.014219    0.713939    
#> 058: 0.415758    0.994234    3.458594    0.217534    0.125484    0.013508    0.693157    
#> 059: 0.411596    0.968252    3.468223    0.223144    0.120771    0.012832    0.681473    
#> 060: 0.385164    0.970039    3.479011    0.213753    0.114733    0.017790    0.698098    
#> 061: 0.451669    0.997718    3.490603    0.230010    0.120598    0.019431    0.714633    
#> 062: 0.395108    1.011202    3.488603    0.218510    0.131424    0.018459    0.717643    
#> 063: 0.423675    0.976015    3.486212    0.207584    0.124853    0.017536    0.690531    
#> 064: 0.443426    0.980303    3.491617    0.197205    0.118610    0.016659    0.693950    
#> 065: 0.471464    0.979852    3.495058    0.187345    0.118482    0.015866    0.692482    
#> 066: 0.433237    0.984075    3.496878    0.178949    0.132485    0.016982    0.669259    
#> 067: 0.431595    0.980942    3.493969    0.179704    0.125860    0.016133    0.674588    
#> 068: 0.408683    0.966751    3.495561    0.170718    0.119567    0.015327    0.702851    
#> 069: 0.381398    1.000489    3.471267    0.202111    0.113589    0.014919    0.694498    
#> 070: 0.409480    0.999328    3.483462    0.193942    0.107910    0.015236    0.694540    
#> 071: 0.383340    1.001482    3.452526    0.235201    0.109843    0.014475    0.695688    
#> 072: 0.353054    0.988274    3.463044    0.272363    0.130066    0.013751    0.680012    
#> 073: 0.434150    1.012992    3.477659    0.323797    0.137753    0.013063    0.698069    
#> 074: 0.375158    0.983190    3.474338    0.307607    0.132406    0.012410    0.696473    
#> 075: 0.391964    0.989446    3.497043    0.292226    0.149571    0.012282    0.679707    
#> 076: 0.480151    0.991129    3.510207    0.277615    0.142093    0.015068    0.678081    
#> 077: 0.497356    0.960227    3.504299    0.272998    0.134988    0.014315    0.672133    
#> 078: 0.437015    0.978915    3.495756    0.259348    0.146861    0.013599    0.679585    
#> 079: 0.459701    0.980739    3.490675    0.293497    0.139518    0.012919    0.700970    
#> 080: 0.452505    0.973642    3.491791    0.295467    0.136575    0.014148    0.707066    
#> 081: 0.431382    0.991216    3.487574    0.296107    0.129747    0.017565    0.694254    
#> 082: 0.452800    0.964905    3.499932    0.281301    0.125117    0.016687    0.698657    
#> 083: 0.418718    1.009168    3.493361    0.267236    0.136718    0.015853    0.676426    
#> 084: 0.417026    0.998489    3.485415    0.253875    0.129882    0.016237    0.679343    
#> 085: 0.420663    0.998292    3.492779    0.241181    0.123388    0.017134    0.686855    
#> 086: 0.407589    1.005776    3.486603    0.229122    0.117219    0.020299    0.666857    
#> 087: 0.414077    0.981806    3.473047    0.236486    0.117418    0.019284    0.674353    
#> 088: 0.374840    0.975316    3.490123    0.224662    0.119010    0.018320    0.683528    
#> 089: 0.430593    0.990594    3.491136    0.213429    0.113060    0.019892    0.688126    
#> 090: 0.423157    0.974841    3.492416    0.202757    0.107581    0.021329    0.665664    
#> 091: 0.410459    0.960415    3.483835    0.238096    0.111019    0.022359    0.671437    
#> 092: 0.425526    0.976164    3.492604    0.233629    0.111999    0.021578    0.686085    
#> 093: 0.414937    0.958650    3.495045    0.221948    0.111951    0.020499    0.686987    
#> 094: 0.429709    0.993654    3.479866    0.210850    0.130695    0.019474    0.697326    
#> 095: 0.413175    0.999424    3.486109    0.200308    0.124160    0.018501    0.690113    
#> 096: 0.385930    0.982771    3.483622    0.190293    0.117952    0.017575    0.692105    
#> 097: 0.397556    1.020071    3.468746    0.187444    0.112055    0.016697    0.685313    
#> 098: 0.364546    1.022797    3.469835    0.180140    0.117134    0.015862    0.707967    
#> 099: 0.330060    0.989910    3.454730    0.171133    0.111278    0.015069    0.669395    
#> 100: 0.336751    1.019665    3.449570    0.170449    0.117394    0.014315    0.670498    
#> 101: 0.320497    0.992539    3.441847    0.190813    0.117678    0.013600    0.677954    
#> 102: 0.328159    1.032362    3.443207    0.187070    0.116035    0.015020    0.689789    
#> 103: 0.360860    1.026015    3.450286    0.199240    0.110234    0.014269    0.681035    
#> 104: 0.377618    1.003435    3.470380    0.212471    0.104722    0.013556    0.680450    
#> 105: 0.380176    0.987781    3.470900    0.201848    0.129566    0.012878    0.683668    
#> 106: 0.403093    0.987165    3.472416    0.208681    0.130214    0.012234    0.675308    
#> 107: 0.421214    1.014563    3.473015    0.218823    0.123703    0.011622    0.693773    
#> 108: 0.412292    0.992783    3.476830    0.207881    0.117518    0.012300    0.686758    
#> 109: 0.388443    1.017270    3.476481    0.200001    0.123946    0.013762    0.678247    
#> 110: 0.393262    0.996917    3.464508    0.203135    0.125949    0.016206    0.658501    
#> 111: 0.363169    0.999442    3.472554    0.201391    0.137772    0.015396    0.658428    
#> 112: 0.380302    0.985400    3.460277    0.201270    0.130883    0.014626    0.670138    
#> 113: 0.397541    1.026602    3.468755    0.199169    0.125905    0.013894    0.665568    
#> 114: 0.374160    1.008498    3.470594    0.218867    0.135846    0.014332    0.666247    
#> 115: 0.404988    0.984489    3.477919    0.212568    0.129054    0.015416    0.698926    
#> 116: 0.417594    1.008524    3.472596    0.204968    0.122601    0.015250    0.666399    
#> 117: 0.389611    1.008884    3.480779    0.200896    0.128212    0.014487    0.679735    
#> 118: 0.431618    0.984765    3.486232    0.228860    0.121802    0.015803    0.669908    
#> 119: 0.421610    1.005229    3.483798    0.248371    0.125669    0.020101    0.672120    
#> 120: 0.412191    0.985153    3.477339    0.268390    0.119386    0.019096    0.664121    
#> 121: 0.391491    1.017303    3.476783    0.254970    0.113417    0.018141    0.683847    
#> 122: 0.400889    0.995870    3.480831    0.242222    0.107746    0.017234    0.668122    
#> 123: 0.424049    1.007956    3.475446    0.230110    0.104230    0.016373    0.684427    
#> 124: 0.403266    1.029152    3.463371    0.218605    0.099019    0.015554    0.701558    
#> 125: 0.397612    1.023390    3.469273    0.210220    0.126503    0.014776    0.682070    
#> 126: 0.344857    1.032300    3.446041    0.199709    0.120178    0.014037    0.685098    
#> 127: 0.361326    1.013275    3.440667    0.189724    0.114388    0.013336    0.700056    
#> 128: 0.318675    1.007416    3.457007    0.180238    0.118728    0.012669    0.703325    
#> 129: 0.354766    1.025481    3.460419    0.193130    0.132644    0.012035    0.684061    
#> 130: 0.415979    1.023507    3.465345    0.183474    0.143659    0.011434    0.672273    
#> 131: 0.390728    1.010056    3.456801    0.199293    0.146163    0.010862    0.676151    
#> 132: 0.354737    1.034496    3.446632    0.189328    0.138855    0.011337    0.683529    
#> 133: 0.346552    1.023303    3.442894    0.184204    0.131912    0.010771    0.689869    
#> 134: 0.354481    0.990602    3.457990    0.218524    0.131735    0.015286    0.683405    
#> 135: 0.362017    0.999628    3.468396    0.207598    0.125148    0.014521    0.680889    
#> 136: 0.393629    0.989285    3.473828    0.197218    0.118891    0.013795    0.673263    
#> 137: 0.417976    0.984539    3.485349    0.204200    0.112946    0.013105    0.673497    
#> 138: 0.386991    0.990466    3.474989    0.200667    0.115003    0.013839    0.658859    
#> 139: 0.413713    0.993636    3.490560    0.213026    0.128247    0.014104    0.668710    
#> 140: 0.424250    0.991513    3.491702    0.202374    0.130108    0.013399    0.700398    
#> 141: 0.405724    0.977765    3.492340    0.192256    0.127317    0.012729    0.676607    
#> 142: 0.437304    0.972614    3.504009    0.210542    0.122289    0.012093    0.704729    
#> 143: 0.393777    1.017513    3.486062    0.210707    0.133831    0.011488    0.688402    
#> 144: 0.448993    0.997194    3.494729    0.203478    0.127140    0.010914    0.686518    
#> 145: 0.441062    0.983779    3.492130    0.193304    0.120967    0.010700    0.690432    
#> 146: 0.412782    0.990026    3.494209    0.219282    0.115248    0.013593    0.687085    
#> 147: 0.391127    0.978758    3.479976    0.208318    0.114317    0.012913    0.669155    
#> 148: 0.393839    1.006298    3.486263    0.197902    0.108601    0.012345    0.694897    
#> 149: 0.408659    0.981321    3.484056    0.206684    0.139196    0.013612    0.690112    
#> 150: 0.427308    0.991717    3.475070    0.258310    0.132236    0.012931    0.685024    
#> 151: 0.379127    1.023901    3.473335    0.254524    0.126244    0.012298    0.680900    
#> 152: 0.383056    1.001895    3.475556    0.211809    0.143058    0.012140    0.684744    
#> 153: 0.412000    0.995321    3.488093    0.217372    0.128790    0.018380    0.679564    
#> 154: 0.433391    1.004315    3.495837    0.184766    0.110304    0.021390    0.677333    
#> 155: 0.400099    0.986652    3.487523    0.173932    0.109845    0.023236    0.675073    
#> 156: 0.415774    0.982914    3.497986    0.188069    0.094522    0.025758    0.674743    
#> 157: 0.423129    0.974208    3.498616    0.170161    0.087067    0.029320    0.685804    
#> 158: 0.421697    1.010395    3.487188    0.172710    0.083380    0.027411    0.671637    
#> 159: 0.384015    0.998469    3.490026    0.161566    0.088257    0.028682    0.664267    
#> 160: 0.396468    0.974586    3.487462    0.146522    0.105022    0.028588    0.652700    
#> 161: 0.396777    0.981395    3.478446    0.149493    0.091144    0.032640    0.674709    
#> 162: 0.409952    0.990077    3.484497    0.183693    0.083842    0.035386    0.677775    
#> 163: 0.452539    0.967468    3.493446    0.192690    0.078551    0.032800    0.675637    
#> 164: 0.444127    0.965027    3.494115    0.178683    0.080063    0.029188    0.679166    
#> 165: 0.449918    0.968639    3.491052    0.202034    0.093731    0.023775    0.676034    
#> 166: 0.454780    0.997324    3.485285    0.222215    0.086015    0.022865    0.704645    
#> 167: 0.422081    1.022579    3.487189    0.200968    0.099962    0.025807    0.678329    
#> 168: 0.430612    0.989815    3.492600    0.222492    0.097812    0.026163    0.688134    
#> 169: 0.438649    1.031203    3.482974    0.213934    0.106834    0.024792    0.681306    
#> 170: 0.451070    0.999630    3.488368    0.199768    0.105471    0.021977    0.664341    
#> 171: 0.423050    0.973444    3.488242    0.219193    0.098549    0.020282    0.644713    
#> 172: 0.418433    1.012323    3.479811    0.217801    0.091182    0.019048    0.642832    
#> 173: 0.430261    1.010636    3.479598    0.224860    0.088641    0.021179    0.650102    
#> 174: 0.426099    0.995707    3.493575    0.234206    0.086488    0.024208    0.667560    
#> 175: 0.427973    0.988318    3.484317    0.194318    0.099857    0.022673    0.683678    
#> 176: 0.413220    1.006447    3.489160    0.186987    0.111102    0.020767    0.674018    
#> 177: 0.391603    1.009547    3.485898    0.196559    0.098267    0.023126    0.673599    
#> 178: 0.414498    1.001099    3.485722    0.186849    0.108725    0.018058    0.662748    
#> 179: 0.450210    1.007346    3.491896    0.184827    0.125580    0.016672    0.682002    
#> 180: 0.409880    0.992856    3.479853    0.205281    0.115578    0.012499    0.693442    
#> 181: 0.372934    0.992988    3.457673    0.204264    0.119216    0.016057    0.683881    
#> 182: 0.347953    1.016367    3.448181    0.210719    0.123761    0.013914    0.682259    
#> 183: 0.348208    1.030081    3.452930    0.194969    0.122959    0.012472    0.681058    
#> 184: 0.362509    1.023551    3.456671    0.222880    0.111355    0.013888    0.685478    
#> 185: 0.330338    1.029687    3.454427    0.218001    0.103898    0.012707    0.679884    
#> 186: 0.323257    1.054587    3.448448    0.201168    0.138651    0.013062    0.685559    
#> 187: 0.381576    1.025129    3.457941    0.185075    0.120285    0.015027    0.697789    
#> 188: 0.362032    1.020876    3.458733    0.224069    0.118292    0.013679    0.694611    
#> 189: 0.402980    1.009466    3.477041    0.210522    0.124675    0.014196    0.698904    
#> 190: 0.437851    1.009381    3.489827    0.214227    0.125745    0.016420    0.670902    
#> 191: 0.366948    1.013806    3.471680    0.191729    0.119625    0.015215    0.667610    
#> 192: 0.350437    1.011777    3.463837    0.187251    0.101970    0.013988    0.658554    
#> 193: 0.385280    1.019910    3.469234    0.183114    0.116546    0.015818    0.661920    
#> 194: 0.345998    0.998061    3.463296    0.156656    0.106437    0.013589    0.684112    
#> 195: 0.355542    1.006184    3.459782    0.160720    0.089717    0.014953    0.690577    
#> 196: 0.354645    1.003219    3.472820    0.189899    0.115040    0.016975    0.687414    
#> 197: 0.337190    0.997833    3.486536    0.178703    0.092022    0.018180    0.725657    
#> 198: 0.401530    0.981307    3.484311    0.157862    0.093846    0.017598    0.683255    
#> 199: 0.393982    0.995612    3.474679    0.184272    0.104855    0.014359    0.689280    
#> 200: 0.379516    1.019248    3.459613    0.188565    0.109857    0.017050    0.685295    
#> 201: 0.373999    1.015374    3.464087    0.200575    0.109962    0.016698    0.681437    
#> 202: 0.383647    1.018665    3.464663    0.199334    0.105500    0.017010    0.686972    
#> 203: 0.394854    1.014763    3.466205    0.210009    0.105495    0.017625    0.682501    
#> 204: 0.394894    1.004401    3.469620    0.205797    0.103202    0.017377    0.689289    
#> 205: 0.392529    1.006498    3.471246    0.211319    0.103085    0.018069    0.690746    
#> 206: 0.393547    1.008382    3.472210    0.213094    0.102839    0.018111    0.693669    
#> 207: 0.389673    1.007226    3.471865    0.213871    0.101604    0.018153    0.692718    
#> 208: 0.389990    1.007977    3.472074    0.212240    0.101071    0.018456    0.690379    
#> 209: 0.395319    1.004381    3.473067    0.211952    0.099873    0.018774    0.688641    
#> 210: 0.398532    1.000804    3.474884    0.213089    0.101121    0.018783    0.686564    
#> 211: 0.400995    1.001133    3.475491    0.214485    0.103888    0.018568    0.684171    
#> 212: 0.403372    0.999402    3.476351    0.214076    0.104196    0.018501    0.684804    
#> 213: 0.406470    0.996417    3.477426    0.211569    0.103735    0.018407    0.687750    
#> 214: 0.408606    0.995397    3.478183    0.211692    0.104883    0.018360    0.688167    
#> 215: 0.409624    0.994760    3.479186    0.211547    0.105510    0.018548    0.688527    
#> 216: 0.411199    0.993686    3.479858    0.210044    0.106045    0.018705    0.690051    
#> 217: 0.411597    0.993744    3.480537    0.207246    0.105484    0.018751    0.689558    
#> 218: 0.412385    0.994122    3.480975    0.204936    0.104882    0.018872    0.689326    
#> 219: 0.411979    0.992560    3.480906    0.203967    0.104391    0.019072    0.688954    
#> 220: 0.411917    0.992339    3.481624    0.205195    0.103886    0.019354    0.688082    
#> 221: 0.411205    0.991894    3.481680    0.205753    0.103050    0.019539    0.687476    
#> 222: 0.412056    0.991485    3.481808    0.207028    0.102851    0.019777    0.687070    
#> 223: 0.414664    0.990616    3.482572    0.207552    0.102822    0.020075    0.686677    
#> 224: 0.417206    0.991376    3.483038    0.208553    0.103099    0.020280    0.686838    
#> 225: 0.417973    0.989833    3.483887    0.209810    0.103022    0.020517    0.686346    
#> 226: 0.418188    0.988395    3.484189    0.208406    0.103096    0.020623    0.685946    
#> 227: 0.417714    0.988657    3.484439    0.209223    0.103170    0.020621    0.685189    
#> 228: 0.416496    0.989742    3.483878    0.208600    0.102869    0.020835    0.684520    
#> 229: 0.415438    0.989938    3.483631    0.208530    0.102407    0.021039    0.683710    
#> 230: 0.415822    0.989985    3.483357    0.208944    0.102143    0.021112    0.683693    
#> 231: 0.416172    0.989973    3.483769    0.209411    0.101697    0.021266    0.683091    
#> 232: 0.415992    0.989542    3.484278    0.208525    0.101369    0.021307    0.682745    
#> 233: 0.416052    0.988520    3.484591    0.207673    0.101133    0.021296    0.682711    
#> 234: 0.416707    0.988392    3.484843    0.207834    0.101247    0.021319    0.682190    
#> 235: 0.417071    0.987946    3.484771    0.208795    0.100956    0.021270    0.681872    
#> 236: 0.417707    0.988165    3.484790    0.209020    0.100994    0.021274    0.681983    
#> 237: 0.418468    0.988024    3.484839    0.208896    0.100916    0.021340    0.682466    
#> 238: 0.419494    0.987874    3.485439    0.208927    0.101224    0.021315    0.683041    
#> 239: 0.419877    0.987854    3.485769    0.208975    0.101362    0.021236    0.682850    
#> 240: 0.420170    0.987874    3.486078    0.208499    0.101714    0.021137    0.682382    
#> 241: 0.420666    0.986934    3.486423    0.207661    0.102077    0.021031    0.682503    
#> 242: 0.420855    0.986251    3.486304    0.207629    0.102262    0.020950    0.682721    
#> 243: 0.420401    0.986790    3.486211    0.206990    0.102412    0.020851    0.683066    
#> 244: 0.419995    0.986949    3.486557    0.206549    0.102444    0.020841    0.683265    
#> 245: 0.420300    0.986330    3.486718    0.205708    0.102855    0.020809    0.683870    
#> 246: 0.420651    0.985772    3.486955    0.204529    0.102661    0.020866    0.683983    
#> 247: 0.420701    0.985431    3.487285    0.204355    0.102665    0.020931    0.684119    
#> 248: 0.420689    0.985789    3.487372    0.204191    0.102513    0.020877    0.684190    
#> 249: 0.421312    0.985636    3.487549    0.204191    0.102478    0.020741    0.684148    
#> 250: 0.422320    0.985581    3.487918    0.204258    0.102783    0.020669    0.684001    
#> 251: 0.422594    0.985745    3.488261    0.203456    0.103251    0.020554    0.684240    
#> 252: 0.423298    0.985744    3.488674    0.203363    0.103559    0.020500    0.684221    
#> 253: 0.423546    0.985694    3.488896    0.203101    0.103857    0.020440    0.684108    
#> 254: 0.423686    0.986133    3.489010    0.202725    0.104288    0.020397    0.684071    
#> 255: 0.423648    0.986559    3.488928    0.202567    0.104462    0.020329    0.684037    
#> 256: 0.423671    0.986693    3.488772    0.202322    0.104338    0.020305    0.683939    
#> 257: 0.423191    0.986530    3.488500    0.201582    0.104204    0.020261    0.684236    
#> 258: 0.422074    0.986444    3.488206    0.201407    0.104158    0.020259    0.684333    
#> 259: 0.421622    0.986384    3.488099    0.201624    0.104487    0.020258    0.684103    
#> 260: 0.421363    0.986359    3.488133    0.201336    0.104589    0.020285    0.684017    
#> 261: 0.421924    0.985898    3.488275    0.201172    0.104775    0.020355    0.683737    
#> 262: 0.422092    0.985614    3.488512    0.201188    0.105020    0.020344    0.683673    
#> 263: 0.422183    0.985595    3.488750    0.200735    0.105040    0.020379    0.683510    
#> 264: 0.422182    0.985363    3.488945    0.200474    0.104815    0.020387    0.683825    
#> 265: 0.422242    0.985330    3.489064    0.199948    0.105065    0.020372    0.683765    
#> 266: 0.422843    0.985463    3.489160    0.199897    0.104795    0.020306    0.683690    
#> 267: 0.422998    0.985475    3.489280    0.199856    0.104787    0.020245    0.683574    
#> 268: 0.423343    0.985290    3.489223    0.199500    0.104804    0.020193    0.683628    
#> 269: 0.424057    0.985198    3.489168    0.199460    0.105088    0.020129    0.683621    
#> 270: 0.424077    0.985391    3.488981    0.199804    0.105144    0.020051    0.683516    
#> 271: 0.424345    0.985450    3.488789    0.200050    0.105245    0.019984    0.683460    
#> 272: 0.424365    0.985468    3.488761    0.200308    0.105345    0.019929    0.683604    
#> 273: 0.424151    0.985746    3.488742    0.200622    0.105837    0.019870    0.683778    
#> 274: 0.423593    0.986111    3.488691    0.201029    0.105872    0.019845    0.683799    
#> 275: 0.423600    0.986189    3.488577    0.200760    0.106117    0.019787    0.683802    
#> 276: 0.423163    0.986244    3.488697    0.200636    0.106220    0.019746    0.683805    
#> 277: 0.422739    0.986383    3.488776    0.200271    0.106269    0.019732    0.683887    
#> 278: 0.422801    0.986290    3.488991    0.200495    0.106402    0.019706    0.683845    
#> 279: 0.422665    0.985912    3.489052    0.200564    0.106363    0.019724    0.683933    
#> 280: 0.422832    0.985866    3.489156    0.200462    0.106445    0.019755    0.683709    
#> 281: 0.422363    0.985999    3.489212    0.200336    0.106409    0.019781    0.683655    
#> 282: 0.422300    0.986240    3.489286    0.200531    0.106546    0.019766    0.683438    
#> 283: 0.422528    0.986410    3.489355    0.200332    0.106465    0.019727    0.683819    
#> 284: 0.422732    0.986294    3.489431    0.199839    0.106467    0.019675    0.683821    
#> 285: 0.422868    0.986285    3.489326    0.200177    0.106698    0.019619    0.683889    
#> 286: 0.422925    0.986296    3.489210    0.200333    0.107048    0.019585    0.683833    
#> 287: 0.422849    0.986492    3.489107    0.200424    0.106955    0.019553    0.683898    
#> 288: 0.422891    0.986340    3.489060    0.200681    0.107193    0.019474    0.684096    
#> 289: 0.423163    0.986372    3.488985    0.201276    0.107354    0.019432    0.683985    
#> 290: 0.423322    0.986326    3.488996    0.201448    0.107334    0.019383    0.683918    
#> 291: 0.423437    0.986349    3.488985    0.201210    0.107234    0.019370    0.683599    
#> 292: 0.423287    0.986450    3.488945    0.201000    0.107135    0.019374    0.683573    
#> 293: 0.422923    0.986546    3.488751    0.200811    0.107049    0.019353    0.683555    
#> 294: 0.422498    0.986652    3.488625    0.200660    0.107095    0.019309    0.683480    
#> 295: 0.422370    0.986446    3.488555    0.200558    0.107099    0.019290    0.683182    
#> 296: 0.422351    0.986410    3.488517    0.201026    0.107006    0.019299    0.683114    
#> 297: 0.422483    0.986719    3.488536    0.201278    0.106760    0.019356    0.682912    
#> 298: 0.422406    0.986832    3.488458    0.201043    0.106769    0.019326    0.682831    
#> 299: 0.422190    0.987077    3.488322    0.201206    0.106838    0.019257    0.682689    
#> 300: 0.422157    0.986940    3.488264    0.201236    0.106727    0.019222    0.682568    
#> 301: 0.422039    0.986878    3.488075    0.201157    0.106813    0.019182    0.682599    
#> 302: 0.421873    0.987170    3.487884    0.201070    0.107012    0.019163    0.682492    
#> 303: 0.421555    0.987393    3.487789    0.201095    0.107040    0.019166    0.682195    
#> 304: 0.421263    0.987823    3.487518    0.201076    0.106977    0.019137    0.682157    
#> 305: 0.420574    0.987664    3.487215    0.201175    0.107190    0.019134    0.682086    
#> 306: 0.419771    0.987831    3.486824    0.201236    0.107287    0.019084    0.682029    
#> 307: 0.419209    0.987931    3.486605    0.201652    0.107615    0.019015    0.682082    
#> 308: 0.418336    0.988036    3.486294    0.201892    0.107732    0.018987    0.682148    
#> 309: 0.418038    0.987955    3.486077    0.201930    0.107706    0.018978    0.682315    
#> 310: 0.417709    0.988070    3.485813    0.202046    0.107892    0.018959    0.682415    
#> 311: 0.417279    0.988122    3.485654    0.202091    0.107977    0.018938    0.682317    
#> 312: 0.417211    0.988267    3.485481    0.202156    0.107993    0.018919    0.682301    
#> 313: 0.417085    0.988129    3.485396    0.202669    0.107853    0.018900    0.682333    
#> 314: 0.416529    0.988276    3.485239    0.202725    0.107874    0.018891    0.682317    
#> 315: 0.415924    0.988390    3.485110    0.202639    0.107831    0.018859    0.682386    
#> 316: 0.415955    0.988529    3.485038    0.202809    0.107855    0.018836    0.682320    
#> 317: 0.415876    0.988620    3.485047    0.202571    0.107915    0.018807    0.682412    
#> 318: 0.415836    0.988671    3.484940    0.202431    0.107918    0.018777    0.682452    
#> 319: 0.415564    0.988667    3.484795    0.202422    0.107883    0.018748    0.682546    
#> 320: 0.415035    0.988713    3.484647    0.202633    0.107857    0.018691    0.682798    
#> 321: 0.414733    0.989000    3.484458    0.202934    0.107899    0.018665    0.682943    
#> 322: 0.414603    0.989078    3.484348    0.202812    0.107893    0.018637    0.683004    
#> 323: 0.413983    0.989101    3.484199    0.202845    0.107914    0.018643    0.682990    
#> 324: 0.414037    0.989177    3.484183    0.202703    0.108041    0.018629    0.682814    
#> 325: 0.413866    0.989238    3.484157    0.202573    0.108081    0.018615    0.682769    
#> 326: 0.413856    0.989000    3.484132    0.202538    0.108235    0.018572    0.682770    
#> 327: 0.413919    0.988917    3.484132    0.202575    0.108404    0.018560    0.682787    
#> 328: 0.413856    0.989054    3.484126    0.202567    0.108419    0.018519    0.682857    
#> 329: 0.413872    0.989246    3.484095    0.202398    0.108464    0.018480    0.682782    
#> 330: 0.413622    0.989340    3.484063    0.202167    0.108476    0.018407    0.682944    
#> 331: 0.413647    0.989365    3.484048    0.202243    0.108499    0.018359    0.682919    
#> 332: 0.413545    0.989521    3.484025    0.202303    0.108472    0.018330    0.683120    
#> 333: 0.413350    0.989591    3.483910    0.202423    0.108523    0.018299    0.683165    
#> 334: 0.413217    0.989499    3.483805    0.202414    0.108504    0.018282    0.683197    
#> 335: 0.413010    0.989618    3.483681    0.202323    0.108573    0.018260    0.683238    
#> 336: 0.412752    0.989959    3.483480    0.202377    0.108769    0.018256    0.683161    
#> 337: 0.412534    0.990474    3.483304    0.202376    0.108972    0.018242    0.683180    
#> 338: 0.412629    0.990690    3.483280    0.202325    0.109095    0.018244    0.683155    
#> 339: 0.412423    0.990905    3.483186    0.202211    0.109102    0.018250    0.683133    
#> 340: 0.412207    0.990807    3.483155    0.202133    0.109170    0.018257    0.683053    
#> 341: 0.412212    0.990857    3.483155    0.201991    0.109200    0.018255    0.683025    
#> 342: 0.411965    0.990661    3.483161    0.201958    0.109122    0.018257    0.682936    
#> 343: 0.411844    0.990557    3.483198    0.201949    0.109147    0.018244    0.682865    
#> 344: 0.412037    0.990441    3.483298    0.202077    0.109048    0.018251    0.682997    
#> 345: 0.412247    0.990347    3.483430    0.202027    0.108905    0.018281    0.683014    
#> 346: 0.412270    0.990319    3.483434    0.201844    0.108884    0.018274    0.682975    
#> 347: 0.412384    0.990365    3.483387    0.201569    0.108995    0.018275    0.683000    
#> 348: 0.412266    0.990513    3.483348    0.201309    0.109033    0.018250    0.683092    
#> 349: 0.412234    0.990504    3.483309    0.201397    0.109019    0.018232    0.683170    
#> 350: 0.412079    0.990431    3.483251    0.201412    0.109076    0.018209    0.683176    
#> 351: 0.412105    0.990536    3.483181    0.201672    0.109015    0.018194    0.683231    
#> 352: 0.411743    0.990698    3.483107    0.201825    0.109138    0.018192    0.683423    
#> 353: 0.411590    0.990839    3.482982    0.201685    0.109186    0.018177    0.683455    
#> 354: 0.411603    0.990938    3.482904    0.201599    0.109100    0.018160    0.683487    
#> 355: 0.411913    0.990865    3.482881    0.201579    0.109082    0.018152    0.683536    
#> 356: 0.411866    0.990705    3.482976    0.201739    0.109068    0.018174    0.683664    
#> 357: 0.411992    0.990834    3.483012    0.201694    0.109062    0.018156    0.683642    
#> 358: 0.412112    0.990889    3.483074    0.201675    0.109173    0.018157    0.683551    
#> 359: 0.412228    0.990948    3.483150    0.201507    0.109275    0.018150    0.683599    
#> 360: 0.412126    0.990947    3.483058    0.201392    0.109374    0.018131    0.683567    
#> 361: 0.412074    0.990938    3.483005    0.201283    0.109448    0.018100    0.683579    
#> 362: 0.412196    0.990886    3.482949    0.201185    0.109413    0.018063    0.683446    
#> 363: 0.412190    0.990883    3.482946    0.201065    0.109400    0.018045    0.683357    
#> 364: 0.412236    0.990921    3.482947    0.201017    0.109408    0.018048    0.683371    
#> 365: 0.412128    0.990773    3.482985    0.201087    0.109373    0.018052    0.683455    
#> 366: 0.411981    0.990784    3.482909    0.201009    0.109468    0.018046    0.683507    
#> 367: 0.412075    0.990756    3.482886    0.201060    0.109588    0.018029    0.683468    
#> 368: 0.412367    0.990733    3.482900    0.201354    0.109539    0.018017    0.683413    
#> 369: 0.412382    0.990757    3.482863    0.201376    0.109516    0.018008    0.683395    
#> 370: 0.412211    0.990958    3.482792    0.201388    0.109442    0.018015    0.683377    
#> 371: 0.412025    0.991229    3.482654    0.201299    0.109480    0.017989    0.683341    
#> 372: 0.411750    0.991354    3.482515    0.201330    0.109576    0.017975    0.683372    
#> 373: 0.411466    0.991519    3.482417    0.201236    0.109582    0.017955    0.683513    
#> 374: 0.411466    0.991601    3.482355    0.201500    0.109572    0.017954    0.683554    
#> 375: 0.411488    0.991617    3.482347    0.201516    0.109570    0.017968    0.683618    
#> 376: 0.411290    0.991715    3.482311    0.201278    0.109646    0.017964    0.683617    
#> 377: 0.411146    0.991854    3.482306    0.201141    0.109752    0.017941    0.683620    
#> 378: 0.410990    0.991887    3.482291    0.201033    0.109747    0.017924    0.683713    
#> 379: 0.410853    0.991752    3.482267    0.200868    0.109790    0.017903    0.683766    
#> 380: 0.410600    0.991703    3.482177    0.200893    0.109746    0.017864    0.683852    
#> 381: 0.410207    0.991732    3.482047    0.201164    0.109707    0.017849    0.683827    
#> 382: 0.409938    0.991829    3.481990    0.201142    0.109689    0.017835    0.683791    
#> 383: 0.409868    0.991812    3.481964    0.201015    0.109629    0.017819    0.683775    
#> 384: 0.409676    0.991740    3.481969    0.200873    0.109642    0.017804    0.683735    
#> 385: 0.409797    0.991635    3.482016    0.200736    0.109672    0.017783    0.683839    
#> 386: 0.409844    0.991694    3.482019    0.200703    0.109678    0.017780    0.683938    
#> 387: 0.409990    0.991744    3.482142    0.200560    0.109660    0.017778    0.683973    
#> 388: 0.409916    0.991880    3.482177    0.200585    0.109641    0.017779    0.683935    
#> 389: 0.409977    0.991858    3.482181    0.200592    0.109638    0.017779    0.683967    
#> 390: 0.409947    0.991910    3.482200    0.200499    0.109627    0.017796    0.683888    
#> 391: 0.410180    0.991784    3.482228    0.200567    0.109565    0.017802    0.683850    
#> 392: 0.410392    0.991634    3.482318    0.200705    0.109433    0.017806    0.683851    
#> 393: 0.410540    0.991517    3.482332    0.200890    0.109341    0.017812    0.683849    
#> 394: 0.410654    0.991492    3.482325    0.201204    0.109188    0.017841    0.683833    
#> 395: 0.410912    0.991619    3.482330    0.201390    0.109072    0.017858    0.683942    
#> 396: 0.411219    0.991699    3.482377    0.201464    0.108996    0.017872    0.683850    
#> 397: 0.411393    0.991683    3.482429    0.201656    0.108922    0.017892    0.683793    
#> 398: 0.411493    0.991693    3.482443    0.201918    0.108899    0.017882    0.683756    
#> 399: 0.411656    0.991734    3.482489    0.202009    0.108931    0.017878    0.683654    
#> 400: 0.411775    0.991743    3.482549    0.202164    0.108910    0.017870    0.683550    
#> 401: 0.411820    0.991656    3.482538    0.202309    0.108886    0.017848    0.683579    
#> 402: 0.411783    0.991766    3.482485    0.202480    0.108849    0.017829    0.683574    
#> 403: 0.411839    0.991839    3.482444    0.202618    0.108995    0.017817    0.683502    
#> 404: 0.411853    0.991848    3.482367    0.202679    0.109030    0.017798    0.683446    
#> 405: 0.411767    0.991858    3.482351    0.202729    0.109138    0.017770    0.683447    
#> 406: 0.411834    0.991804    3.482372    0.202831    0.109138    0.017761    0.683471    
#> 407: 0.412001    0.991730    3.482478    0.202810    0.109220    0.017754    0.683386    
#> 408: 0.412096    0.991702    3.482544    0.202875    0.109241    0.017751    0.683365    
#> 409: 0.411990    0.991707    3.482495    0.202831    0.109207    0.017745    0.683266    
#> 410: 0.411961    0.991766    3.482443    0.202870    0.109162    0.017766    0.683271    
#> 411: 0.411944    0.991615    3.482426    0.203008    0.109164    0.017765    0.683350    
#> 412: 0.412031    0.991608    3.482447    0.203096    0.109129    0.017763    0.683388    
#> 413: 0.412093    0.991649    3.482461    0.203236    0.109102    0.017756    0.683520    
#> 414: 0.412027    0.991582    3.482491    0.203144    0.109046    0.017754    0.683488    
#> 415: 0.412149    0.991512    3.482554    0.202925    0.108954    0.017763    0.683443    
#> 416: 0.412435    0.991553    3.482617    0.202780    0.108958    0.017754    0.683402    
#> 417: 0.412431    0.991585    3.482627    0.202703    0.109030    0.017758    0.683318    
#> 418: 0.412281    0.991651    3.482644    0.202722    0.109079    0.017748    0.683256    
#> 419: 0.412242    0.991775    3.482640    0.202557    0.109202    0.017752    0.683248    
#> 420: 0.412308    0.991835    3.482648    0.202484    0.109308    0.017752    0.683192    
#> 421: 0.412216    0.991955    3.482658    0.202411    0.109337    0.017752    0.683115    
#> 422: 0.412360    0.991896    3.482700    0.202501    0.109370    0.017746    0.683080    
#> 423: 0.412508    0.991772    3.482761    0.202567    0.109373    0.017760    0.683025    
#> 424: 0.412503    0.991745    3.482753    0.202590    0.109493    0.017748    0.682977    
#> 425: 0.412734    0.991744    3.482737    0.202753    0.109507    0.017744    0.683076    
#> 426: 0.412912    0.991763    3.482746    0.202902    0.109511    0.017745    0.683036    
#> 427: 0.413004    0.991635    3.482827    0.203006    0.109506    0.017751    0.682923    
#> 428: 0.412992    0.991700    3.482824    0.203038    0.109527    0.017758    0.682903    
#> 429: 0.413036    0.991735    3.482856    0.203047    0.109526    0.017765    0.682862    
#> 430: 0.413115    0.991760    3.482888    0.202989    0.109554    0.017770    0.682820    
#> 431: 0.413140    0.991684    3.482872    0.202860    0.109531    0.017765    0.682785    
#> 432: 0.413136    0.991669    3.482928    0.202748    0.109517    0.017770    0.682757    
#> 433: 0.413094    0.991665    3.482981    0.202760    0.109486    0.017773    0.682733    
#> 434: 0.412968    0.991628    3.482986    0.202739    0.109455    0.017795    0.682611    
#> 435: 0.412932    0.991629    3.482963    0.202677    0.109430    0.017798    0.682567    
#> 436: 0.412897    0.991447    3.483001    0.202645    0.109466    0.017800    0.682648    
#> 437: 0.412953    0.991323    3.483023    0.202506    0.109514    0.017789    0.682670    
#> 438: 0.412955    0.991417    3.483052    0.202545    0.109583    0.017773    0.682697    
#> 439: 0.413018    0.991456    3.483077    0.202425    0.109519    0.017781    0.682658    
#> 440: 0.413064    0.991460    3.483168    0.202308    0.109446    0.017789    0.682616    
#> 441: 0.413094    0.991419    3.483199    0.202157    0.109471    0.017790    0.682584    
#> 442: 0.413099    0.991501    3.483251    0.201908    0.109493    0.017793    0.682524    
#> 443: 0.413001    0.991610    3.483194    0.201741    0.109521    0.017772    0.682471    
#> 444: 0.412786    0.991753    3.483068    0.201632    0.109552    0.017751    0.682437    
#> 445: 0.412544    0.991877    3.482952    0.201617    0.109637    0.017737    0.682476    
#> 446: 0.412226    0.991999    3.482817    0.201653    0.109678    0.017725    0.682457    
#> 447: 0.412141    0.992026    3.482751    0.201695    0.109623    0.017718    0.682487    
#> 448: 0.411922    0.992039    3.482711    0.201801    0.109594    0.017702    0.682434    
#> 449: 0.411942    0.992151    3.482763    0.201808    0.109521    0.017711    0.682419    
#> 450: 0.411982    0.992144    3.482751    0.201945    0.109487    0.017724    0.682419    
#> 451: 0.411879    0.992189    3.482713    0.202010    0.109465    0.017748    0.682431    
#> 452: 0.411652    0.992363    3.482621    0.202062    0.109455    0.017750    0.682366    
#> 453: 0.411500    0.992408    3.482561    0.201906    0.109414    0.017749    0.682309    
#> 454: 0.411517    0.992533    3.482547    0.201895    0.109405    0.017740    0.682253    
#> 455: 0.411497    0.992582    3.482531    0.201991    0.109369    0.017729    0.682209    
#> 456: 0.411347    0.992618    3.482508    0.201951    0.109333    0.017727    0.682194    
#> 457: 0.411364    0.992566    3.482536    0.201903    0.109316    0.017727    0.682141    
#> 458: 0.411404    0.992599    3.482561    0.201818    0.109275    0.017732    0.682131    
#> 459: 0.411395    0.992676    3.482589    0.201980    0.109194    0.017752    0.682186    
#> 460: 0.411416    0.992628    3.482593    0.201922    0.109135    0.017778    0.682266    
#> 461: 0.411357    0.992618    3.482618    0.201903    0.109083    0.017793    0.682313    
#> 462: 0.411320    0.992669    3.482632    0.201925    0.109063    0.017805    0.682279    
#> 463: 0.411404    0.992698    3.482668    0.201904    0.109023    0.017812    0.682250    
#> 464: 0.411510    0.992725    3.482678    0.201843    0.109014    0.017808    0.682201    
#> 465: 0.411590    0.992573    3.482711    0.201856    0.109029    0.017804    0.682202    
#> 466: 0.411719    0.992602    3.482677    0.202029    0.109034    0.017806    0.682168    
#> 467: 0.411645    0.992611    3.482691    0.202160    0.109029    0.017797    0.682124    
#> 468: 0.411753    0.992637    3.482755    0.202162    0.109022    0.017793    0.682165    
#> 469: 0.411733    0.992797    3.482772    0.202140    0.109030    0.017783    0.682223    
#> 470: 0.411623    0.992850    3.482740    0.202286    0.109079    0.017768    0.682202    
#> 471: 0.411435    0.992931    3.482672    0.202423    0.109101    0.017760    0.682186    
#> 472: 0.411365    0.992934    3.482651    0.202333    0.109103    0.017746    0.682178    
#> 473: 0.411291    0.992886    3.482633    0.202321    0.109047    0.017748    0.682146    
#> 474: 0.411258    0.992841    3.482639    0.202373    0.109030    0.017745    0.682193    
#> 475: 0.411343    0.992879    3.482650    0.202426    0.108957    0.017732    0.682204    
#> 476: 0.411436    0.992861    3.482653    0.202398    0.108977    0.017714    0.682308    
#> 477: 0.411465    0.992840    3.482720    0.202406    0.108943    0.017692    0.682323    
#> 478: 0.411344    0.992781    3.482717    0.202383    0.108943    0.017673    0.682305    
#> 479: 0.411509    0.992787    3.482722    0.202385    0.108962    0.017663    0.682208    
#> 480: 0.411585    0.992792    3.482738    0.202412    0.108950    0.017654    0.682212    
#> 481: 0.411699    0.992745    3.482783    0.202378    0.108991    0.017659    0.682284    
#> 482: 0.411810    0.992716    3.482814    0.202348    0.109019    0.017671    0.682345    
#> 483: 0.411784    0.992656    3.482829    0.202196    0.109035    0.017675    0.682344    
#> 484: 0.411792    0.992493    3.482859    0.202143    0.109019    0.017677    0.682357    
#> 485: 0.411797    0.992522    3.482867    0.202186    0.109060    0.017686    0.682328    
#> 486: 0.411862    0.992570    3.482920    0.202148    0.109099    0.017690    0.682220    
#> 487: 0.411970    0.992624    3.482986    0.202177    0.109118    0.017699    0.682132    
#> 488: 0.412012    0.992631    3.483005    0.202146    0.109093    0.017711    0.682070    
#> 489: 0.412151    0.992648    3.483023    0.202065    0.109018    0.017727    0.682056    
#> 490: 0.412209    0.992613    3.483067    0.202104    0.109006    0.017727    0.682065    
#> 491: 0.412183    0.992624    3.483108    0.202068    0.109075    0.017716    0.682049    
#> 492: 0.412043    0.992707    3.483085    0.202078    0.109077    0.017702    0.682114    
#> 493: 0.411997    0.992642    3.483098    0.202010    0.109011    0.017700    0.682195    
#> 494: 0.412121    0.992688    3.483086    0.202086    0.108958    0.017694    0.682178    
#> 495: 0.412279    0.992715    3.483093    0.202094    0.108929    0.017687    0.682128    
#> 496: 0.412413    0.992798    3.483059    0.202321    0.108964    0.017695    0.682107    
#> 497: 0.412301    0.992816    3.483024    0.202507    0.108970    0.017690    0.682102    
#> 498: 0.412265    0.992827    3.482994    0.202587    0.108950    0.017679    0.682120    
#> 499: 0.412261    0.992854    3.482958    0.202484    0.108977    0.017665    0.682024    
#> 500: 0.412298    0.992733    3.482945    0.202454    0.108932    0.017657    0.682008    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.319200    0.980553    3.445558    0.392401    0.090792    0.016800    1.671406    
#> 002: 0.348413    0.942467    3.465739    0.372781    0.086252    0.015960    1.167994    
#> 003: 0.404863    0.910670    3.476162    0.354142    0.081940    0.017208    0.946675    
#> 004: 0.371659    0.919269    3.464072    0.352464    0.084030    0.016348    0.836911    
#> 005: 0.450011    0.915028    3.462712    0.344230    0.096598    0.015829    0.786982    
#> 006: 0.425419    0.916969    3.448849    0.382505    0.091768    0.016869    0.726891    
#> 007: 0.378453    0.939445    3.438138    0.418289    0.094808    0.019239    0.720284    
#> 008: 0.360325    0.949473    3.428253    0.397374    0.110004    0.019116    0.719780    
#> 009: 0.358617    0.924989    3.426477    0.413670    0.109855    0.019937    0.721270    
#> 010: 0.339582    0.949053    3.419717    0.440824    0.104535    0.025070    0.719439    
#> 011: 0.440149    0.931665    3.436511    0.512389    0.099308    0.028016    0.711278    
#> 012: 0.413359    0.948213    3.433121    0.486769    0.094343    0.026616    0.707487    
#> 013: 0.365998    0.946635    3.414600    0.551439    0.089626    0.025285    0.717714    
#> 014: 0.429771    0.962608    3.427267    0.746713    0.099391    0.026543    0.709744    
#> 015: 0.428268    0.952635    3.437230    0.709378    0.094422    0.025215    0.694157    
#> 016: 0.404047    0.963293    3.439295    0.673909    0.089701    0.023955    0.698205    
#> 017: 0.435685    0.962060    3.434547    0.711073    0.085428    0.022757    0.675278    
#> 018: 0.407471    0.952129    3.425451    0.675519    0.081661    0.021619    0.684506    
#> 019: 0.410218    0.957862    3.423789    0.641743    0.081429    0.020538    0.678565    
#> 020: 0.415524    0.962250    3.427910    0.697142    0.091782    0.020033    0.703991    
#> 021: 0.435980    0.947662    3.436475    0.676876    0.087193    0.019031    0.689771    
#> 022: 0.451766    0.951903    3.444326    0.704006    0.086344    0.018079    0.671339    
#> 023: 0.505575    0.975991    3.443812    0.668805    0.092250    0.017396    0.682882    
#> 024: 0.442089    0.974288    3.441223    0.635365    0.096362    0.016651    0.679536    
#> 025: 0.404666    0.965096    3.426884    0.603597    0.091544    0.015818    0.694267    
#> 026: 0.428314    0.979333    3.427584    0.625143    0.095924    0.015027    0.705383    
#> 027: 0.411550    0.976796    3.426778    0.630392    0.109639    0.014276    0.702298    
#> 028: 0.416087    0.979586    3.430735    0.598872    0.104157    0.018169    0.700966    
#> 029: 0.434399    0.968476    3.420750    0.582817    0.098949    0.017261    0.715543    
#> 030: 0.391521    0.981718    3.411819    0.556638    0.115705    0.016398    0.708022    
#> 031: 0.361338    0.963901    3.415193    0.528806    0.122811    0.015578    0.715159    
#> 032: 0.371855    0.967979    3.415591    0.634183    0.116670    0.016992    0.690559    
#> 033: 0.396665    0.988925    3.411167    0.688444    0.110837    0.018525    0.701359    
#> 034: 0.422082    0.989946    3.420937    0.715082    0.105295    0.018144    0.713526    
#> 035: 0.392544    0.960843    3.417798    0.679328    0.104034    0.017237    0.694984    
#> 036: 0.386729    0.989377    3.419624    0.645361    0.105834    0.018322    0.690708    
#> 037: 0.358060    0.991157    3.408495    0.613093    0.101569    0.019206    0.701762    
#> 038: 0.401161    0.987119    3.408517    0.691763    0.096491    0.018260    0.698854    
#> 039: 0.385982    0.970628    3.411846    0.706010    0.101370    0.017347    0.688847    
#> 040: 0.386366    0.976708    3.413408    0.684748    0.096301    0.019811    0.701192    
#> 041: 0.335146    0.980216    3.403144    0.650511    0.091486    0.018820    0.699040    
#> 042: 0.385598    0.981560    3.402377    0.711915    0.086912    0.017879    0.677859    
#> 043: 0.398556    0.984094    3.401600    0.696798    0.082566    0.021066    0.678501    
#> 044: 0.394130    0.988524    3.404348    0.661958    0.090612    0.020013    0.684171    
#> 045: 0.366356    1.005146    3.412346    0.628860    0.086081    0.025732    0.676302    
#> 046: 0.378283    0.968902    3.420555    0.597417    0.081777    0.024445    0.691737    
#> 047: 0.419526    0.982301    3.424348    0.631471    0.077688    0.023223    0.685600    
#> 048: 0.402223    0.953275    3.430338    0.619667    0.076463    0.025456    0.685227    
#> 049: 0.429297    0.954783    3.434255    0.607311    0.083496    0.030652    0.686460    
#> 050: 0.461550    0.946508    3.441841    0.661741    0.079635    0.032884    0.703781    
#> 051: 0.471648    0.943578    3.431499    0.667443    0.076227    0.031240    0.703773    
#> 052: 0.467258    0.943191    3.438356    0.688988    0.076125    0.029678    0.683532    
#> 053: 0.445730    0.947263    3.433897    0.720627    0.078371    0.031603    0.688042    
#> 054: 0.401930    0.948839    3.425307    0.684596    0.074452    0.030023    0.715938    
#> 055: 0.408703    0.954008    3.426178    0.650366    0.070730    0.028522    0.709889    
#> 056: 0.461301    0.959395    3.416505    0.700358    0.078329    0.027096    0.701799    
#> 057: 0.465782    0.948650    3.436772    0.709034    0.076508    0.025741    0.716351    
#> 058: 0.474427    0.952910    3.424352    0.673582    0.089786    0.024454    0.733414    
#> 059: 0.458401    0.918842    3.434598    0.656508    0.085297    0.024512    0.719174    
#> 060: 0.464001    0.911952    3.452673    0.749783    0.081032    0.023996    0.706484    
#> 061: 0.498186    0.924593    3.461647    0.712293    0.076980    0.022796    0.719075    
#> 062: 0.501899    0.924745    3.458766    0.676679    0.073131    0.022635    0.741633    
#> 063: 0.520792    0.895597    3.456019    0.655024    0.069475    0.023584    0.738644    
#> 064: 0.508917    0.907161    3.458035    0.714537    0.066001    0.024101    0.742374    
#> 065: 0.473557    0.904733    3.441720    0.678810    0.063550    0.025106    0.722639    
#> 066: 0.455739    0.942761    3.440278    0.644869    0.064671    0.024863    0.689624    
#> 067: 0.439727    0.930812    3.434302    0.683967    0.075764    0.028574    0.695220    
#> 068: 0.417772    0.955263    3.445061    0.649768    0.092610    0.027145    0.700229    
#> 069: 0.478766    0.953347    3.430156    0.693774    0.087979    0.027573    0.703179    
#> 070: 0.465287    0.946587    3.447131    0.683151    0.083581    0.033135    0.710614    
#> 071: 0.429647    0.974859    3.428691    0.648994    0.079401    0.032658    0.708144    
#> 072: 0.442866    0.927913    3.434625    0.616544    0.075431    0.038763    0.699719    
#> 073: 0.451091    0.953671    3.454778    0.585717    0.071660    0.036824    0.708114    
#> 074: 0.447802    0.939751    3.435138    0.564046    0.074158    0.034983    0.697822    
#> 075: 0.447366    0.931696    3.454836    0.535844    0.076846    0.033234    0.714679    
#> 076: 0.456679    0.961348    3.456837    0.509052    0.073004    0.032576    0.722207    
#> 077: 0.484361    0.945572    3.444722    0.496253    0.088174    0.030947    0.736590    
#> 078: 0.445423    0.944416    3.444116    0.568937    0.083765    0.029400    0.706664    
#> 079: 0.431006    0.946223    3.439557    0.619588    0.079577    0.027930    0.735676    
#> 080: 0.479936    0.944423    3.445002    0.719782    0.075598    0.027736    0.717779    
#> 081: 0.461778    0.947432    3.437905    0.683793    0.071818    0.026475    0.700235    
#> 082: 0.444431    0.933843    3.453472    0.649603    0.068227    0.028658    0.717696    
#> 083: 0.429991    0.950071    3.446801    0.617123    0.064816    0.030820    0.734696    
#> 084: 0.393648    0.968953    3.433359    0.586267    0.084170    0.029279    0.704712    
#> 085: 0.450033    0.972524    3.447435    0.670635    0.088993    0.027815    0.717843    
#> 086: 0.426222    0.954168    3.440671    0.637103    0.100199    0.026425    0.717238    
#> 087: 0.384111    0.952789    3.422452    0.605248    0.108043    0.025103    0.698117    
#> 088: 0.345808    0.953649    3.424116    0.574985    0.102641    0.023848    0.725154    
#> 089: 0.394695    0.980068    3.419618    0.607046    0.099108    0.022656    0.701893    
#> 090: 0.391698    0.981326    3.415258    0.604102    0.112989    0.021523    0.714063    
#> 091: 0.392517    0.971415    3.395614    0.665014    0.107340    0.020447    0.703105    
#> 092: 0.399868    0.979111    3.392015    0.731681    0.101973    0.019425    0.704552    
#> 093: 0.308161    0.977333    3.398512    0.695097    0.096874    0.018453    0.710860    
#> 094: 0.342210    0.978097    3.390675    0.660342    0.092031    0.017617    0.723016    
#> 095: 0.393168    0.994291    3.405812    0.685963    0.100199    0.021657    0.701113    
#> 096: 0.333583    0.981461    3.406246    0.651665    0.104685    0.020574    0.697028    
#> 097: 0.386174    0.999638    3.413105    0.621827    0.107099    0.023595    0.698127    
#> 098: 0.400317    0.988432    3.427300    0.590735    0.123717    0.024583    0.690642    
#> 099: 0.393900    0.948816    3.414285    0.626335    0.117531    0.025466    0.683452    
#> 100: 0.383020    0.963495    3.406731    0.675717    0.111654    0.024193    0.680632    
#> 101: 0.375358    0.972483    3.386458    0.668726    0.106071    0.022983    0.692989    
#> 102: 0.316240    0.969895    3.388266    0.635289    0.104827    0.021834    0.715066    
#> 103: 0.367468    0.972692    3.406933    0.603525    0.104012    0.020742    0.690816    
#> 104: 0.376080    0.969133    3.429952    0.574266    0.098811    0.022180    0.717120    
#> 105: 0.407463    0.968366    3.426763    0.587606    0.093871    0.021071    0.719923    
#> 106: 0.400883    0.963612    3.423368    0.588818    0.089177    0.020018    0.689444    
#> 107: 0.427979    0.969829    3.426958    0.615157    0.099012    0.019398    0.687365    
#> 108: 0.418917    0.969036    3.428903    0.614590    0.107020    0.018428    0.704036    
#> 109: 0.436095    0.950756    3.441235    0.634530    0.101669    0.017506    0.713962    
#> 110: 0.452039    0.929984    3.429612    0.745419    0.096586    0.018393    0.712979    
#> 111: 0.432099    0.950374    3.437611    0.708148    0.091756    0.017473    0.702582    
#> 112: 0.433385    0.936192    3.422056    0.672740    0.087169    0.017615    0.715862    
#> 113: 0.407234    0.970371    3.424498    0.670317    0.082810    0.019041    0.685702    
#> 114: 0.448372    0.964333    3.422792    0.694194    0.078670    0.023131    0.684360    
#> 115: 0.451198    0.936595    3.419191    0.730638    0.074736    0.021974    0.696329    
#> 116: 0.448367    0.978311    3.411366    0.728137    0.091916    0.022713    0.694974    
#> 117: 0.383454    0.975966    3.416166    0.691730    0.087320    0.021577    0.709996    
#> 118: 0.420207    0.965901    3.422087    0.657143    0.099426    0.020498    0.708312    
#> 119: 0.424099    0.972625    3.427771    0.660430    0.094455    0.028587    0.710820    
#> 120: 0.379583    0.958269    3.422737    0.627409    0.089732    0.028792    0.685288    
#> 121: 0.398594    0.997510    3.417004    0.596038    0.090174    0.027662    0.700513    
#> 122: 0.386031    0.960034    3.428767    0.566236    0.085665    0.026279    0.714768    
#> 123: 0.402510    0.984348    3.411138    0.537924    0.081382    0.024965    0.715401    
#> 124: 0.366257    1.015698    3.405365    0.570579    0.090617    0.023717    0.703434    
#> 125: 0.380478    1.008294    3.403214    0.601005    0.088190    0.022531    0.703638    
#> 126: 0.352927    1.008578    3.388168    0.580689    0.108495    0.021404    0.707250    
#> 127: 0.367364    1.000707    3.388506    0.562863    0.103070    0.020334    0.715799    
#> 128: 0.357946    0.976753    3.400125    0.621714    0.097916    0.019317    0.718850    
#> 129: 0.385312    0.984088    3.399585    0.695995    0.095246    0.018352    0.709861    
#> 130: 0.393390    1.001787    3.400070    0.661195    0.099766    0.017434    0.711289    
#> 131: 0.353087    0.980200    3.395381    0.628135    0.106222    0.016562    0.703939    
#> 132: 0.322284    0.990225    3.392876    0.596729    0.100911    0.016581    0.705874    
#> 133: 0.387340    0.980912    3.409545    0.681992    0.095866    0.016202    0.704011    
#> 134: 0.427089    0.961407    3.416611    0.854449    0.091072    0.023330    0.712428    
#> 135: 0.442626    0.962307    3.431670    0.811727    0.086519    0.023660    0.718635    
#> 136: 0.416995    0.958749    3.418345    0.771141    0.082193    0.022477    0.689230    
#> 137: 0.442540    0.962483    3.425842    0.734466    0.086252    0.021353    0.699484    
#> 138: 0.462537    0.970037    3.432150    0.740978    0.084538    0.020551    0.687179    
#> 139: 0.406228    0.960025    3.429433    0.703929    0.080312    0.021094    0.685158    
#> 140: 0.435447    0.970577    3.427332    0.705683    0.076296    0.030050    0.679772    
#> 141: 0.450286    0.959381    3.431435    0.759938    0.072481    0.028548    0.686656    
#> 142: 0.454050    0.949157    3.442719    0.721941    0.068857    0.027621    0.685964    
#> 143: 0.418475    0.950081    3.436280    0.745385    0.078163    0.026240    0.697405    
#> 144: 0.494308    0.942862    3.453831    0.708116    0.074255    0.025328    0.687745    
#> 145: 0.451052    0.960978    3.429997    0.697735    0.072311    0.025473    0.685539    
#> 146: 0.389252    0.958410    3.443156    0.662848    0.077177    0.027963    0.693958    
#> 147: 0.387448    0.934080    3.424834    0.629706    0.084774    0.026565    0.699256    
#> 148: 0.405315    0.963081    3.430253    0.608926    0.080894    0.025237    0.694811    
#> 149: 0.390085    0.939375    3.439356    0.578480    0.076850    0.028429    0.701577    
#> 150: 0.398341    0.954895    3.423686    0.549556    0.073007    0.027008    0.717454    
#> 151: 0.339666    0.988529    3.414857    0.522078    0.069357    0.025658    0.699746    
#> 152: 0.357763    0.980539    3.419457    0.494112    0.071466    0.022254    0.702965    
#> 153: 0.360310    0.970540    3.433218    0.481860    0.071094    0.022637    0.712808    
#> 154: 0.371120    0.979409    3.432840    0.462717    0.066362    0.024429    0.724509    
#> 155: 0.370554    0.947848    3.424212    0.499789    0.061257    0.030037    0.704045    
#> 156: 0.414486    0.963590    3.438093    0.528398    0.050100    0.036721    0.723351    
#> 157: 0.462149    0.955382    3.436596    0.681635    0.047730    0.045745    0.711353    
#> 158: 0.501491    0.958883    3.449176    0.662176    0.057093    0.042753    0.707918    
#> 159: 0.432583    0.956478    3.454881    0.565551    0.073710    0.036530    0.703072    
#> 160: 0.462409    0.913473    3.468702    0.566552    0.074815    0.034411    0.719096    
#> 161: 0.486712    0.924023    3.466600    0.509414    0.057709    0.035390    0.726950    
#> 162: 0.419518    0.951153    3.449796    0.515078    0.052282    0.029485    0.728977    
#> 163: 0.446847    0.945271    3.442151    0.551255    0.069256    0.033286    0.714139    
#> 164: 0.445894    0.960115    3.440034    0.583172    0.074680    0.026615    0.701719    
#> 165: 0.442856    0.940052    3.437657    0.628418    0.078699    0.019671    0.693368    
#> 166: 0.472352    0.958539    3.434815    0.634680    0.073377    0.024068    0.690569    
#> 167: 0.484721    0.972578    3.443170    0.702316    0.091400    0.031687    0.678939    
#> 168: 0.482618    0.974579    3.450574    0.684321    0.074889    0.030333    0.686535    
#> 169: 0.483000    0.982656    3.442127    0.664549    0.077692    0.026693    0.705399    
#> 170: 0.480923    0.967991    3.451406    0.688646    0.077702    0.024745    0.700413    
#> 171: 0.440577    0.964823    3.435898    0.644222    0.075430    0.025249    0.681275    
#> 172: 0.366732    0.971545    3.426211    0.563171    0.076194    0.026971    0.674035    
#> 173: 0.370719    0.976264    3.407664    0.547267    0.073581    0.023167    0.667028    
#> 174: 0.403730    0.974109    3.426593    0.466134    0.094102    0.019818    0.685979    
#> 175: 0.421877    0.969669    3.420049    0.567930    0.081337    0.018738    0.685375    
#> 176: 0.386143    0.974004    3.431403    0.438537    0.086922    0.020952    0.686231    
#> 177: 0.423356    0.967675    3.429305    0.563629    0.093042    0.018447    0.683181    
#> 178: 0.401626    0.955822    3.424146    0.579132    0.093947    0.014705    0.697711    
#> 179: 0.431871    0.977750    3.417969    0.500310    0.088590    0.015730    0.713333    
#> 180: 0.385959    0.978047    3.422940    0.454787    0.090896    0.015678    0.722289    
#> 181: 0.377556    0.965249    3.403986    0.466990    0.086126    0.011846    0.715482    
#> 182: 0.338230    0.977711    3.395618    0.441413    0.077483    0.014720    0.750453    
#> 183: 0.349491    1.013039    3.396295    0.418130    0.098011    0.014222    0.724707    
#> 184: 0.362606    0.978899    3.407483    0.532397    0.099516    0.013292    0.713770    
#> 185: 0.357553    0.981153    3.401415    0.557502    0.088294    0.013418    0.718029    
#> 186: 0.349717    0.991057    3.402152    0.610884    0.091583    0.014973    0.725710    
#> 187: 0.384762    0.981820    3.407117    0.732689    0.089805    0.016251    0.689456    
#> 188: 0.404507    0.981453    3.412506    0.671412    0.085035    0.015469    0.699626    
#> 189: 0.400188    0.986464    3.431599    0.593069    0.093097    0.017098    0.717331    
#> 190: 0.382525    0.980477    3.434366    0.557440    0.079275    0.017197    0.700464    
#> 191: 0.368931    0.995142    3.421726    0.490274    0.078460    0.015689    0.686789    
#> 192: 0.402876    0.985368    3.426131    0.536742    0.091266    0.020263    0.677304    
#> 193: 0.429848    0.983957    3.432957    0.602471    0.078762    0.019487    0.683645    
#> 194: 0.414566    0.970364    3.430109    0.559686    0.075924    0.019696    0.714893    
#> 195: 0.369651    0.973454    3.415039    0.528669    0.075959    0.020625    0.685749    
#> 196: 0.401017    0.975760    3.422387    0.595891    0.079349    0.019648    0.693965    
#> 197: 0.348592    0.965555    3.433412    0.500517    0.076887    0.021156    0.708469    
#> 198: 0.457956    0.946100    3.420614    0.572308    0.066240    0.023043    0.693756    
#> 199: 0.380598    0.948678    3.418694    0.492042    0.071980    0.024502    0.692009    
#> 200: 0.375872    0.943440    3.428029    0.525506    0.064237    0.029083    0.731909    
#> 201: 0.372443    0.945142    3.429459    0.511306    0.062289    0.031593    0.724744    
#> 202: 0.365721    0.956539    3.427200    0.505362    0.068810    0.030785    0.717913    
#> 203: 0.381722    0.958955    3.425643    0.508963    0.072890    0.030207    0.719775    
#> 204: 0.388331    0.952343    3.428413    0.519412    0.075968    0.030057    0.718109    
#> 205: 0.388644    0.956162    3.429378    0.506656    0.075993    0.030527    0.717749    
#> 206: 0.391385    0.958895    3.432648    0.503963    0.075498    0.031334    0.718046    
#> 207: 0.393170    0.959033    3.433537    0.498640    0.075638    0.031191    0.717846    
#> 208: 0.399136    0.958874    3.435101    0.490608    0.075944    0.031301    0.717628    
#> 209: 0.407223    0.955511    3.435986    0.496596    0.076871    0.030811    0.716911    
#> 210: 0.409877    0.952759    3.437787    0.495291    0.076573    0.030338    0.715893    
#> 211: 0.415135    0.952178    3.439441    0.497448    0.076115    0.030179    0.714129    
#> 212: 0.419202    0.950449    3.440461    0.502163    0.076388    0.029869    0.712344    
#> 213: 0.420446    0.947794    3.441637    0.498592    0.078023    0.029900    0.712243    
#> 214: 0.422093    0.946619    3.442374    0.497453    0.078583    0.029841    0.712165    
#> 215: 0.420583    0.946315    3.442887    0.495030    0.078826    0.029866    0.711916    
#> 216: 0.424134    0.944417    3.443224    0.498585    0.078457    0.029891    0.712489    
#> 217: 0.423641    0.945124    3.443041    0.498482    0.078390    0.029717    0.711930    
#> 218: 0.424623    0.946150    3.442619    0.502414    0.078746    0.029774    0.710115    
#> 219: 0.424333    0.945353    3.442201    0.504562    0.077722    0.030137    0.708695    
#> 220: 0.423768    0.945559    3.442121    0.506840    0.077182    0.030736    0.708254    
#> 221: 0.422313    0.945783    3.441743    0.509323    0.076561    0.031140    0.707702    
#> 222: 0.422464    0.945354    3.441559    0.516090    0.075559    0.031353    0.707516    
#> 223: 0.424383    0.945793    3.441484    0.517816    0.075338    0.031418    0.707642    
#> 224: 0.426476    0.946778    3.441225    0.521409    0.075086    0.031291    0.707212    
#> 225: 0.426258    0.946036    3.441350    0.523664    0.075265    0.031266    0.707004    
#> 226: 0.426219    0.944959    3.441098    0.526398    0.075110    0.031151    0.706401    
#> 227: 0.425498    0.944826    3.440717    0.528886    0.074856    0.030919    0.705725    
#> 228: 0.424351    0.945562    3.439990    0.531743    0.074452    0.030701    0.704830    
#> 229: 0.423721    0.945636    3.439510    0.534959    0.074088    0.030581    0.704140    
#> 230: 0.422878    0.945449    3.439220    0.534625    0.073466    0.030524    0.704311    
#> 231: 0.422899    0.945325    3.439246    0.534355    0.073066    0.030472    0.704105    
#> 232: 0.422833    0.944804    3.439562    0.533956    0.072756    0.030442    0.703855    
#> 233: 0.422698    0.943796    3.439630    0.536543    0.072413    0.030531    0.703665    
#> 234: 0.422429    0.943639    3.439508    0.538337    0.072180    0.030461    0.704001    
#> 235: 0.422298    0.943415    3.439362    0.539981    0.072185    0.030456    0.703387    
#> 236: 0.421551    0.944132    3.438926    0.541060    0.072009    0.030469    0.703399    
#> 237: 0.421814    0.944334    3.438908    0.538808    0.071764    0.030511    0.704141    
#> 238: 0.421829    0.944417    3.438960    0.537568    0.071527    0.030786    0.704667    
#> 239: 0.421910    0.944863    3.438858    0.538142    0.071936    0.030864    0.705047    
#> 240: 0.421817    0.944757    3.438950    0.539206    0.072222    0.030841    0.705303    
#> 241: 0.422878    0.944017    3.439247    0.542642    0.072567    0.030765    0.705389    
#> 242: 0.422448    0.943434    3.439327    0.541671    0.073017    0.030648    0.705712    
#> 243: 0.422318    0.943860    3.439214    0.542024    0.073547    0.030637    0.705986    
#> 244: 0.421645    0.944041    3.439202    0.542518    0.073585    0.030583    0.706156    
#> 245: 0.421402    0.943908    3.439189    0.542682    0.074074    0.030610    0.706368    
#> 246: 0.421525    0.944013    3.439026    0.543204    0.074283    0.030706    0.706369    
#> 247: 0.420949    0.943677    3.438788    0.544138    0.074452    0.030740    0.706635    
#> 248: 0.420658    0.943883    3.438744    0.543307    0.074587    0.030613    0.706342    
#> 249: 0.420016    0.944218    3.438723    0.543697    0.074513    0.030578    0.706068    
#> 250: 0.420175    0.944664    3.438564    0.545153    0.074580    0.030462    0.705949    
#> 251: 0.420227    0.945408    3.438445    0.546255    0.074355    0.030363    0.706344    
#> 252: 0.421256    0.945566    3.438857    0.546728    0.074271    0.030313    0.706499    
#> 253: 0.421515    0.945784    3.438945    0.546606    0.074310    0.030254    0.706829    
#> 254: 0.421601    0.945890    3.439180    0.546786    0.074188    0.030342    0.707262    
#> 255: 0.421499    0.945927    3.439168    0.547407    0.073945    0.030334    0.707772    
#> 256: 0.421249    0.945779    3.438900    0.549043    0.073870    0.030339    0.707850    
#> 257: 0.421734    0.945548    3.438828    0.551626    0.074006    0.030415    0.707634    
#> 258: 0.420784    0.945130    3.438901    0.551757    0.074032    0.030397    0.707780    
#> 259: 0.420427    0.945054    3.438742    0.551503    0.073964    0.030365    0.707735    
#> 260: 0.419808    0.945382    3.438612    0.550925    0.073853    0.030404    0.707617    
#> 261: 0.419699    0.945307    3.438819    0.549512    0.073767    0.030399    0.707868    
#> 262: 0.420204    0.945403    3.438972    0.549398    0.073643    0.030366    0.707671    
#> 263: 0.420271    0.945457    3.439126    0.549301    0.073532    0.030245    0.707676    
#> 264: 0.420573    0.945720    3.439135    0.550322    0.073962    0.030186    0.707549    
#> 265: 0.421070    0.945862    3.439091    0.550852    0.074157    0.030148    0.707470    
#> 266: 0.421437    0.945988    3.439175    0.552059    0.074246    0.030171    0.707177    
#> 267: 0.421772    0.945826    3.439311    0.553746    0.074055    0.030157    0.707107    
#> 268: 0.422324    0.945683    3.439285    0.555324    0.074059    0.030125    0.707120    
#> 269: 0.423576    0.945448    3.439426    0.557151    0.073890    0.030133    0.707059    
#> 270: 0.424098    0.945592    3.439475    0.558466    0.073626    0.030151    0.706946    
#> 271: 0.424524    0.945535    3.439494    0.559214    0.073459    0.030060    0.706967    
#> 272: 0.424793    0.945249    3.439562    0.559095    0.073441    0.030041    0.707218    
#> 273: 0.424772    0.945525    3.439835    0.557917    0.073518    0.030076    0.707622    
#> 274: 0.425230    0.945768    3.440104    0.556209    0.073614    0.030048    0.707624    
#> 275: 0.425358    0.945693    3.440163    0.555120    0.073771    0.029963    0.707585    
#> 276: 0.425352    0.945934    3.440252    0.555096    0.073751    0.029964    0.707545    
#> 277: 0.425418    0.946121    3.440388    0.555248    0.073762    0.029947    0.707490    
#> 278: 0.425716    0.946122    3.440533    0.556110    0.073787    0.029912    0.707454    
#> 279: 0.425860    0.945882    3.440551    0.556967    0.073764    0.029840    0.707562    
#> 280: 0.426084    0.945775    3.440709    0.556635    0.073892    0.029737    0.707644    
#> 281: 0.425986    0.945673    3.440724    0.556658    0.074119    0.029613    0.707505    
#> 282: 0.426294    0.945859    3.440723    0.558080    0.074218    0.029555    0.707471    
#> 283: 0.426486    0.946123    3.440716    0.558961    0.074536    0.029446    0.707613    
#> 284: 0.426604    0.946144    3.440640    0.559923    0.074686    0.029318    0.707474    
#> 285: 0.426268    0.946277    3.440406    0.560107    0.074775    0.029245    0.707402    
#> 286: 0.426452    0.946641    3.440158    0.560326    0.074955    0.029158    0.707390    
#> 287: 0.426297    0.947017    3.440071    0.561749    0.075031    0.029106    0.707340    
#> 288: 0.426048    0.947214    3.439887    0.561447    0.075129    0.029065    0.707598    
#> 289: 0.426136    0.947269    3.439999    0.560041    0.075263    0.028973    0.707667    
#> 290: 0.426008    0.947323    3.440024    0.558708    0.075378    0.028885    0.707883    
#> 291: 0.426316    0.947478    3.440087    0.558065    0.075345    0.028822    0.707881    
#> 292: 0.425810    0.947679    3.440004    0.557329    0.075319    0.028764    0.707873    
#> 293: 0.425638    0.947972    3.439807    0.557279    0.075326    0.028690    0.707876    
#> 294: 0.425318    0.948234    3.439606    0.557255    0.075441    0.028649    0.707722    
#> 295: 0.425314    0.947941    3.439579    0.557941    0.075387    0.028636    0.707658    
#> 296: 0.425563    0.947818    3.439530    0.558013    0.075344    0.028608    0.707746    
#> 297: 0.425935    0.947950    3.439544    0.558543    0.075296    0.028613    0.707776    
#> 298: 0.426347    0.948034    3.439547    0.559429    0.075406    0.028583    0.707644    
#> 299: 0.426390    0.948178    3.439447    0.559947    0.075399    0.028545    0.707476    
#> 300: 0.426356    0.948316    3.439380    0.560309    0.075425    0.028553    0.707395    
#> 301: 0.426412    0.948331    3.439342    0.559828    0.075332    0.028501    0.707502    
#> 302: 0.426272    0.948414    3.439129    0.560411    0.075407    0.028507    0.707412    
#> 303: 0.425843    0.948773    3.438858    0.560874    0.075545    0.028469    0.707362    
#> 304: 0.425638    0.949021    3.438576    0.562303    0.075669    0.028425    0.707314    
#> 305: 0.425322    0.948822    3.438397    0.563433    0.075734    0.028320    0.707309    
#> 306: 0.424990    0.948779    3.438228    0.563663    0.075839    0.028287    0.707272    
#> 307: 0.424214    0.948805    3.438058    0.562639    0.075866    0.028318    0.707490    
#> 308: 0.423394    0.948830    3.437857    0.562453    0.075816    0.028313    0.707744    
#> 309: 0.423015    0.948735    3.437779    0.562579    0.075968    0.028293    0.708062    
#> 310: 0.423116    0.948673    3.437658    0.563071    0.075968    0.028241    0.708342    
#> 311: 0.423216    0.948633    3.437686    0.563356    0.075966    0.028197    0.708200    
#> 312: 0.422849    0.948611    3.437586    0.562706    0.075983    0.028136    0.708290    
#> 313: 0.422133    0.948482    3.437411    0.561820    0.076054    0.028070    0.708458    
#> 314: 0.421673    0.948588    3.437210    0.561551    0.076078    0.028033    0.708375    
#> 315: 0.421376    0.948767    3.437099    0.561890    0.076107    0.027939    0.708222    
#> 316: 0.421272    0.948930    3.437035    0.562297    0.076134    0.027864    0.708152    
#> 317: 0.421229    0.949075    3.437024    0.561746    0.076155    0.027818    0.708334    
#> 318: 0.420805    0.949377    3.436826    0.561151    0.076270    0.027813    0.708324    
#> 319: 0.420422    0.949509    3.436760    0.560492    0.076269    0.027829    0.708352    
#> 320: 0.419933    0.949597    3.436628    0.560918    0.076240    0.027777    0.708529    
#> 321: 0.419499    0.949773    3.436427    0.560735    0.076232    0.027711    0.708607    
#> 322: 0.418816    0.949855    3.436130    0.561087    0.076217    0.027675    0.708649    
#> 323: 0.418471    0.950095    3.435883    0.561388    0.076234    0.027650    0.708596    
#> 324: 0.418189    0.950391    3.435765    0.561322    0.076232    0.027617    0.708497    
#> 325: 0.417937    0.950708    3.435565    0.561396    0.076188    0.027571    0.708536    
#> 326: 0.417842    0.950748    3.435403    0.561911    0.076114    0.027538    0.708442    
#> 327: 0.417874    0.950879    3.435289    0.563253    0.075989    0.027506    0.708388    
#> 328: 0.418250    0.951018    3.435253    0.564247    0.075911    0.027482    0.708157    
#> 329: 0.418578    0.950959    3.435241    0.565119    0.075764    0.027462    0.708066    
#> 330: 0.418160    0.951001    3.435196    0.565084    0.075749    0.027477    0.708110    
#> 331: 0.418150    0.951185    3.435192    0.564679    0.075752    0.027447    0.708104    
#> 332: 0.418176    0.951168    3.435269    0.564037    0.075797    0.027420    0.708087    
#> 333: 0.418057    0.951132    3.435155    0.564137    0.075816    0.027386    0.708031    
#> 334: 0.417631    0.951045    3.434959    0.564087    0.075833    0.027380    0.707962    
#> 335: 0.417249    0.951089    3.434756    0.564256    0.075786    0.027358    0.707922    
#> 336: 0.416541    0.951303    3.434611    0.563737    0.075800    0.027332    0.707912    
#> 337: 0.416179    0.951597    3.434407    0.564386    0.075895    0.027316    0.707849    
#> 338: 0.415946    0.951853    3.434274    0.564493    0.075939    0.027285    0.707688    
#> 339: 0.415594    0.952075    3.434130    0.564118    0.076014    0.027236    0.707665    
#> 340: 0.415185    0.952071    3.434037    0.563806    0.076016    0.027201    0.707627    
#> 341: 0.415125    0.952180    3.434026    0.564080    0.076037    0.027160    0.707553    
#> 342: 0.414987    0.952148    3.433990    0.563733    0.076091    0.027115    0.707483    
#> 343: 0.414780    0.952240    3.433994    0.563672    0.076096    0.027117    0.707463    
#> 344: 0.414842    0.952212    3.434031    0.564061    0.076012    0.027112    0.707516    
#> 345: 0.415047    0.952304    3.434085    0.564668    0.076048    0.027093    0.707559    
#> 346: 0.414729    0.952408    3.433939    0.564415    0.076062    0.027071    0.707482    
#> 347: 0.414458    0.952408    3.433819    0.563817    0.076054    0.027010    0.707565    
#> 348: 0.414276    0.952540    3.433678    0.564185    0.076070    0.026950    0.707647    
#> 349: 0.414280    0.952492    3.433651    0.564529    0.076074    0.026921    0.707649    
#> 350: 0.414142    0.952429    3.433581    0.564691    0.076116    0.026889    0.707661    
#> 351: 0.414164    0.952668    3.433496    0.565250    0.076207    0.026882    0.707675    
#> 352: 0.413756    0.952724    3.433379    0.565274    0.076149    0.026879    0.707902    
#> 353: 0.413663    0.952912    3.433281    0.565401    0.076270    0.026866    0.707850    
#> 354: 0.413738    0.952977    3.433191    0.565604    0.076441    0.026827    0.707784    
#> 355: 0.413969    0.952811    3.433207    0.565489    0.076436    0.026811    0.707794    
#> 356: 0.414014    0.952668    3.433250    0.565102    0.076453    0.026759    0.707992    
#> 357: 0.414493    0.952746    3.433273    0.566237    0.076468    0.026721    0.707949    
#> 358: 0.414691    0.952760    3.433335    0.566219    0.076383    0.026698    0.707867    
#> 359: 0.414724    0.952883    3.433336    0.565492    0.076276    0.026713    0.707859    
#> 360: 0.414594    0.952926    3.433238    0.565133    0.076157    0.026728    0.707751    
#> 361: 0.414548    0.953046    3.433167    0.565216    0.076208    0.026723    0.707489    
#> 362: 0.414849    0.953138    3.433126    0.565638    0.076226    0.026714    0.707260    
#> 363: 0.415014    0.953112    3.433181    0.565920    0.076193    0.026711    0.707051    
#> 364: 0.415144    0.953153    3.433189    0.565431    0.076175    0.026684    0.706914    
#> 365: 0.415086    0.953097    3.433199    0.564878    0.076316    0.026644    0.706914    
#> 366: 0.415061    0.953168    3.433127    0.564383    0.076402    0.026603    0.706882    
#> 367: 0.415150    0.953191    3.433075    0.564074    0.076408    0.026562    0.706813    
#> 368: 0.415235    0.953271    3.433091    0.564177    0.076490    0.026511    0.706695    
#> 369: 0.415314    0.953253    3.433099    0.564663    0.076476    0.026501    0.706790    
#> 370: 0.415339    0.953262    3.433062    0.564777    0.076544    0.026459    0.706859    
#> 371: 0.415106    0.953350    3.432942    0.564790    0.076541    0.026445    0.706879    
#> 372: 0.414786    0.953504    3.432791    0.564528    0.076540    0.026443    0.706856    
#> 373: 0.414317    0.953715    3.432634    0.564156    0.076575    0.026418    0.706933    
#> 374: 0.414042    0.953859    3.432501    0.563945    0.076539    0.026395    0.706888    
#> 375: 0.413813    0.953960    3.432441    0.563789    0.076536    0.026378    0.706851    
#> 376: 0.413714    0.954072    3.432418    0.563217    0.076527    0.026372    0.706776    
#> 377: 0.413687    0.954090    3.432404    0.562900    0.076504    0.026330    0.706751    
#> 378: 0.413521    0.954011    3.432406    0.562681    0.076435    0.026317    0.706692    
#> 379: 0.413291    0.953798    3.432423    0.562656    0.076394    0.026295    0.706662    
#> 380: 0.413027    0.953749    3.432419    0.562187    0.076378    0.026265    0.706683    
#> 381: 0.412863    0.953790    3.432363    0.562088    0.076418    0.026248    0.706687    
#> 382: 0.412600    0.953815    3.432343    0.561392    0.076404    0.026237    0.706665    
#> 383: 0.412449    0.953924    3.432297    0.561039    0.076371    0.026231    0.706542    
#> 384: 0.412201    0.953999    3.432289    0.560435    0.076371    0.026212    0.706536    
#> 385: 0.412270    0.953978    3.432312    0.560638    0.076370    0.026180    0.706422    
#> 386: 0.412412    0.954029    3.432414    0.560337    0.076531    0.026150    0.706425    
#> 387: 0.412581    0.954130    3.432485    0.560393    0.076577    0.026117    0.706377    
#> 388: 0.412848    0.954169    3.432504    0.560541    0.076647    0.026070    0.706313    
#> 389: 0.412710    0.954025    3.432470    0.560462    0.076692    0.026021    0.706448    
#> 390: 0.412746    0.954177    3.432451    0.560393    0.076797    0.025982    0.706415    
#> 391: 0.412801    0.954280    3.432392    0.560335    0.076845    0.025950    0.706352    
#> 392: 0.412888    0.954294    3.432449    0.560286    0.076842    0.025941    0.706400    
#> 393: 0.412974    0.954227    3.432416    0.560589    0.076819    0.025924    0.706457    
#> 394: 0.413183    0.954246    3.432410    0.561131    0.076844    0.025925    0.706380    
#> 395: 0.413377    0.954302    3.432458    0.561132    0.076876    0.025927    0.706375    
#> 396: 0.413470    0.954263    3.432505    0.561384    0.076919    0.025924    0.706276    
#> 397: 0.413521    0.954229    3.432551    0.561600    0.076975    0.025904    0.706266    
#> 398: 0.413720    0.954249    3.432598    0.561630    0.076944    0.025881    0.706249    
#> 399: 0.413885    0.954252    3.432702    0.561545    0.076987    0.025880    0.706166    
#> 400: 0.414120    0.954277    3.432771    0.561208    0.077019    0.025846    0.706200    
#> 401: 0.414297    0.954278    3.432775    0.561025    0.077086    0.025807    0.706364    
#> 402: 0.414365    0.954320    3.432719    0.560926    0.077348    0.025757    0.706420    
#> 403: 0.414801    0.954296    3.432729    0.561392    0.077447    0.025701    0.706437    
#> 404: 0.414890    0.954299    3.432702    0.561715    0.077506    0.025646    0.706384    
#> 405: 0.415081    0.954231    3.432704    0.562188    0.077575    0.025604    0.706465    
#> 406: 0.415159    0.954205    3.432668    0.562676    0.077627    0.025581    0.706604    
#> 407: 0.415300    0.954182    3.432697    0.563342    0.077665    0.025572    0.706681    
#> 408: 0.415570    0.954221    3.432753    0.563623    0.077678    0.025544    0.706753    
#> 409: 0.415623    0.954100    3.432748    0.563644    0.077620    0.025530    0.706714    
#> 410: 0.415513    0.954036    3.432676    0.563368    0.077640    0.025512    0.706706    
#> 411: 0.415415    0.953895    3.432651    0.563317    0.077615    0.025502    0.706723    
#> 412: 0.415237    0.953995    3.432604    0.562847    0.077571    0.025515    0.706779    
#> 413: 0.415068    0.954068    3.432532    0.562379    0.077496    0.025522    0.706833    
#> 414: 0.414810    0.954146    3.432488    0.562561    0.077483    0.025550    0.706789    
#> 415: 0.414974    0.954158    3.432499    0.562646    0.077510    0.025568    0.706699    
#> 416: 0.415086    0.954282    3.432572    0.562302    0.077533    0.025559    0.706688    
#> 417: 0.415214    0.954253    3.432629    0.561844    0.077497    0.025549    0.706676    
#> 418: 0.415262    0.954162    3.432738    0.561616    0.077456    0.025567    0.706620    
#> 419: 0.415519    0.954120    3.432826    0.561571    0.077409    0.025583    0.706577    
#> 420: 0.415718    0.954080    3.432907    0.561631    0.077378    0.025585    0.706511    
#> 421: 0.415683    0.954017    3.432992    0.561275    0.077327    0.025623    0.706534    
#> 422: 0.415786    0.953936    3.433048    0.561353    0.077233    0.025640    0.706524    
#> 423: 0.415868    0.953878    3.433076    0.561251    0.077160    0.025645    0.706504    
#> 424: 0.415883    0.953842    3.433026    0.561504    0.077133    0.025647    0.706528    
#> 425: 0.415995    0.953955    3.433003    0.561631    0.077201    0.025653    0.706564    
#> 426: 0.415966    0.954148    3.432966    0.562008    0.077284    0.025635    0.706565    
#> 427: 0.415840    0.954258    3.432977    0.562118    0.077352    0.025598    0.706595    
#> 428: 0.415700    0.954381    3.432954    0.562025    0.077371    0.025560    0.706604    
#> 429: 0.415802    0.954449    3.432980    0.562430    0.077386    0.025536    0.706591    
#> 430: 0.415785    0.954515    3.433007    0.562383    0.077405    0.025504    0.706564    
#> 431: 0.415788    0.954532    3.432986    0.562127    0.077452    0.025474    0.706559    
#> 432: 0.415847    0.954605    3.433048    0.561948    0.077498    0.025468    0.706492    
#> 433: 0.415942    0.954683    3.433094    0.561842    0.077559    0.025459    0.706450    
#> 434: 0.415875    0.954659    3.433113    0.561632    0.077532    0.025449    0.706399    
#> 435: 0.415982    0.954659    3.433139    0.561305    0.077537    0.025450    0.706379    
#> 436: 0.415970    0.954663    3.433228    0.560877    0.077573    0.025468    0.706386    
#> 437: 0.416092    0.954621    3.433252    0.560875    0.077583    0.025474    0.706356    
#> 438: 0.416272    0.954762    3.433308    0.561013    0.077568    0.025466    0.706371    
#> 439: 0.416507    0.954877    3.433344    0.561415    0.077551    0.025473    0.706257    
#> 440: 0.416722    0.954883    3.433400    0.561435    0.077602    0.025478    0.706146    
#> 441: 0.416967    0.954794    3.433480    0.561497    0.077583    0.025504    0.706033    
#> 442: 0.416953    0.954810    3.433478    0.561542    0.077548    0.025514    0.705896    
#> 443: 0.416996    0.954920    3.433415    0.562078    0.077505    0.025545    0.705842    
#> 444: 0.416840    0.955049    3.433287    0.562188    0.077453    0.025568    0.705764    
#> 445: 0.416718    0.955208    3.433207    0.562728    0.077433    0.025574    0.705714    
#> 446: 0.416601    0.955336    3.433142    0.562959    0.077405    0.025566    0.705713    
#> 447: 0.416716    0.955440    3.433131    0.563196    0.077385    0.025562    0.705738    
#> 448: 0.416738    0.955465    3.433128    0.563186    0.077393    0.025565    0.705688    
#> 449: 0.416695    0.955533    3.433185    0.562781    0.077420    0.025556    0.705663    
#> 450: 0.416665    0.955523    3.433156    0.562585    0.077480    0.025535    0.705624    
#> 451: 0.416733    0.955555    3.433146    0.562852    0.077541    0.025523    0.705564    
#> 452: 0.416729    0.955597    3.433125    0.562841    0.077620    0.025507    0.705528    
#> 453: 0.416576    0.955618    3.433071    0.562353    0.077659    0.025495    0.705476    
#> 454: 0.416324    0.955703    3.432991    0.562155    0.077700    0.025482    0.705448    
#> 455: 0.416078    0.955756    3.432884    0.562205    0.077742    0.025457    0.705389    
#> 456: 0.415879    0.955777    3.432805    0.562363    0.077831    0.025424    0.705351    
#> 457: 0.415752    0.955768    3.432767    0.562639    0.077921    0.025397    0.705286    
#> 458: 0.415747    0.955903    3.432758    0.563011    0.078006    0.025385    0.705256    
#> 459: 0.415627    0.956107    3.432728    0.563027    0.078092    0.025373    0.705326    
#> 460: 0.415481    0.956259    3.432618    0.562908    0.078221    0.025356    0.705438    
#> 461: 0.415288    0.956433    3.432574    0.562882    0.078306    0.025351    0.705511    
#> 462: 0.415228    0.956539    3.432561    0.563002    0.078286    0.025340    0.705532    
#> 463: 0.415265    0.956599    3.432616    0.562898    0.078283    0.025344    0.705523    
#> 464: 0.415503    0.956658    3.432637    0.562954    0.078250    0.025348    0.705436    
#> 465: 0.415534    0.956552    3.432669    0.562780    0.078206    0.025342    0.705382    
#> 466: 0.415568    0.956601    3.432633    0.562676    0.078197    0.025333    0.705350    
#> 467: 0.415492    0.956617    3.432643    0.562467    0.078156    0.025329    0.705275    
#> 468: 0.415474    0.956638    3.432650    0.562668    0.078122    0.025318    0.705243    
#> 469: 0.415552    0.956726    3.432689    0.562772    0.078129    0.025297    0.705273    
#> 470: 0.415588    0.956714    3.432695    0.562739    0.078087    0.025295    0.705316    
#> 471: 0.415580    0.956644    3.432710    0.562660    0.078069    0.025285    0.705370    
#> 472: 0.415553    0.956611    3.432706    0.562604    0.078092    0.025270    0.705361    
#> 473: 0.415506    0.956584    3.432719    0.562284    0.078081    0.025264    0.705314    
#> 474: 0.415455    0.956585    3.432704    0.562224    0.078087    0.025273    0.705322    
#> 475: 0.415415    0.956790    3.432662    0.562028    0.078175    0.025277    0.705278    
#> 476: 0.415351    0.956851    3.432653    0.561985    0.078190    0.025273    0.705338    
#> 477: 0.415379    0.956874    3.432684    0.562097    0.078182    0.025271    0.705288    
#> 478: 0.415294    0.956848    3.432694    0.562040    0.078209    0.025264    0.705374    
#> 479: 0.415285    0.956907    3.432681    0.561959    0.078209    0.025261    0.705457    
#> 480: 0.415182    0.956978    3.432626    0.561758    0.078214    0.025260    0.705447    
#> 481: 0.415068    0.957055    3.432591    0.561600    0.078214    0.025269    0.705372    
#> 482: 0.415083    0.957086    3.432532    0.561838    0.078217    0.025286    0.705311    
#> 483: 0.414861    0.957093    3.432505    0.561835    0.078160    0.025318    0.705245    
#> 484: 0.414846    0.956998    3.432505    0.561800    0.078104    0.025346    0.705224    
#> 485: 0.414809    0.957006    3.432490    0.561983    0.078087    0.025359    0.705238    
#> 486: 0.414776    0.957088    3.432484    0.561816    0.078053    0.025362    0.705224    
#> 487: 0.414923    0.957186    3.432516    0.561823    0.078065    0.025369    0.705238    
#> 488: 0.414987    0.957175    3.432571    0.561843    0.078074    0.025397    0.705194    
#> 489: 0.415144    0.957114    3.432571    0.561956    0.078068    0.025402    0.705139    
#> 490: 0.415274    0.957086    3.432584    0.562251    0.078084    0.025390    0.705109    
#> 491: 0.415439    0.957105    3.432635    0.562427    0.078049    0.025397    0.705022    
#> 492: 0.415504    0.957212    3.432641    0.562718    0.078067    0.025399    0.704997    
#> 493: 0.415370    0.957246    3.432638    0.562536    0.078104    0.025391    0.704968    
#> 494: 0.415304    0.957259    3.432601    0.562463    0.078145    0.025375    0.704890    
#> 495: 0.415284    0.957322    3.432556    0.562408    0.078165    0.025366    0.704785    
#> 496: 0.415431    0.957441    3.432514    0.562588    0.078168    0.025360    0.704767    
#> 497: 0.415492    0.957473    3.432493    0.562860    0.078181    0.025351    0.704793    
#> 498: 0.415481    0.957524    3.432419    0.563151    0.078162    0.025356    0.704735    
#> 499: 0.415575    0.957609    3.432369    0.563558    0.078120    0.025349    0.704686    
#> 500: 0.415595    0.957617    3.432307    0.563557    0.078092    0.025328    0.704630    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.305310    0.960503    3.440190    0.392401    0.082526    0.016800    1.903440    
#> 002: 0.366249    0.945954    3.447300    0.372781    0.078400    0.015960    1.303402    
#> 003: 0.485901    0.889218    3.434919    0.354142    0.074480    0.015293    0.986381    
#> 004: 0.477401    0.908866    3.442132    0.348247    0.077229    0.014528    0.831429    
#> 005: 0.516425    0.911232    3.429299    0.401150    0.083528    0.013802    0.782772    
#> 006: 0.544911    0.921084    3.411642    0.484968    0.098517    0.013112    0.728097    
#> 007: 0.519194    0.930564    3.416258    0.460719    0.104630    0.012456    0.763345    
#> 008: 0.536662    0.913077    3.413273    0.500097    0.133174    0.012507    0.744611    
#> 009: 0.522068    0.914775    3.406823    0.577050    0.126516    0.012524    0.752798    
#> 010: 0.488690    0.915318    3.400363    0.593061    0.120190    0.011897    0.759759    
#> 011: 0.555913    0.924015    3.402626    0.626082    0.114180    0.011302    0.751090    
#> 012: 0.533530    0.924182    3.402539    0.614583    0.108471    0.010737    0.755481    
#> 013: 0.469840    0.926288    3.395565    0.583854    0.103048    0.010200    0.775373    
#> 014: 0.537717    0.944436    3.398895    0.596555    0.097895    0.009690    0.773739    
#> 015: 0.535734    0.936533    3.411347    0.644837    0.093001    0.010180    0.753132    
#> 016: 0.554610    0.937300    3.416998    0.629421    0.088350    0.010342    0.757383    
#> 017: 0.527149    0.953613    3.422971    0.597950    0.083933    0.011450    0.749916    
#> 018: 0.559606    0.945096    3.412204    0.595280    0.091113    0.010877    0.751663    
#> 019: 0.526633    0.926149    3.417097    0.565516    0.091240    0.010333    0.732635    
#> 020: 0.563089    0.921413    3.425734    0.599421    0.111026    0.010626    0.746202    
#> 021: 0.542132    0.905859    3.427271    0.569450    0.105474    0.011025    0.757616    
#> 022: 0.574955    0.918595    3.434172    0.606640    0.100201    0.010648    0.735376    
#> 023: 0.625231    0.917224    3.441506    0.655441    0.110365    0.012064    0.768152    
#> 024: 0.571715    0.914634    3.432528    0.622669    0.104847    0.011460    0.737956    
#> 025: 0.522724    0.892582    3.415422    0.591535    0.099614    0.010887    0.765883    
#> 026: 0.524294    0.949889    3.407469    0.561958    0.105786    0.010614    0.775762    
#> 027: 0.540070    0.968553    3.405202    0.533861    0.108478    0.010926    0.779508    
#> 028: 0.592726    0.940771    3.417129    0.542584    0.103054    0.011814    0.741456    
#> 029: 0.597216    0.945039    3.411976    0.625424    0.097901    0.011467    0.766600    
#> 030: 0.536664    0.945560    3.415786    0.594153    0.093006    0.012442    0.740710    
#> 031: 0.519844    0.911406    3.425798    0.564445    0.088356    0.011820    0.745680    
#> 032: 0.539111    0.894126    3.428984    0.571146    0.095559    0.012532    0.728601    
#> 033: 0.553901    0.919518    3.424313    0.613313    0.108136    0.011905    0.730611    
#> 034: 0.589601    0.932498    3.424805    0.628571    0.102729    0.014185    0.730236    
#> 035: 0.578088    0.902823    3.426717    0.597142    0.123075    0.013476    0.730150    
#> 036: 0.581603    0.928535    3.421196    0.567285    0.116922    0.013282    0.748012    
#> 037: 0.547944    0.918365    3.426244    0.553729    0.120183    0.013277    0.749338    
#> 038: 0.612068    0.914535    3.426669    0.650017    0.114174    0.012613    0.748750    
#> 039: 0.616110    0.898839    3.440358    0.617516    0.110989    0.014960    0.748985    
#> 040: 0.592036    0.906802    3.445421    0.586640    0.105439    0.015522    0.779720    
#> 041: 0.564526    0.879283    3.440707    0.557308    0.100167    0.014746    0.755084    
#> 042: 0.601324    0.882573    3.441220    0.529443    0.095159    0.014009    0.741838    
#> 043: 0.577318    0.922280    3.428731    0.504022    0.096862    0.013309    0.743901    
#> 044: 0.555354    0.920388    3.421156    0.582531    0.093040    0.012643    0.749264    
#> 045: 0.509960    0.947985    3.407199    0.553404    0.102962    0.012011    0.728821    
#> 046: 0.538888    0.926342    3.412331    0.551801    0.097814    0.011635    0.734365    
#> 047: 0.596766    0.940855    3.403872    0.786027    0.095896    0.011053    0.729542    
#> 048: 0.578974    0.935088    3.405492    0.854436    0.099131    0.010500    0.737562    
#> 049: 0.580050    0.924801    3.414586    0.811715    0.103624    0.010738    0.744445    
#> 050: 0.554790    0.895369    3.417273    0.771129    0.098443    0.010201    0.766957    
#> 051: 0.596744    0.919065    3.412442    0.776498    0.107161    0.009885    0.774423    
#> 052: 0.581578    0.912427    3.422330    0.737673    0.101803    0.009390    0.769620    
#> 053: 0.559465    0.928222    3.419857    0.700789    0.096712    0.009973    0.750109    
#> 054: 0.577383    0.920549    3.417476    0.706120    0.091877    0.009867    0.767959    
#> 055: 0.588714    0.911122    3.412871    0.704070    0.089539    0.011642    0.758951    
#> 056: 0.556084    0.902880    3.411483    0.668866    0.085062    0.013330    0.760399    
#> 057: 0.568255    0.916765    3.417831    0.697242    0.100759    0.012664    0.759718    
#> 058: 0.566101    0.896878    3.408238    0.662380    0.095721    0.012030    0.773473    
#> 059: 0.540917    0.895267    3.409973    0.659761    0.110062    0.011429    0.775800    
#> 060: 0.517244    0.930066    3.400032    0.665071    0.104559    0.010857    0.770481    
#> 061: 0.550518    0.947491    3.402589    0.642373    0.099331    0.010315    0.781007    
#> 062: 0.498546    0.968653    3.406232    0.610254    0.098007    0.009799    0.814520    
#> 063: 0.564544    0.924232    3.404876    0.612709    0.103825    0.009309    0.791760    
#> 064: 0.547312    0.926964    3.412129    0.582074    0.107865    0.008843    0.776592    
#> 065: 0.555432    0.914948    3.401451    0.611556    0.102624    0.010802    0.768829    
#> 066: 0.555666    0.930697    3.399103    0.580979    0.097493    0.010262    0.751982    
#> 067: 0.543118    0.917617    3.398620    0.565929    0.097583    0.015145    0.739249    
#> 068: 0.480132    0.928648    3.399345    0.537632    0.120906    0.014388    0.757642    
#> 069: 0.502158    0.938075    3.390153    0.631231    0.124894    0.013668    0.757485    
#> 070: 0.515482    0.945521    3.406797    0.599669    0.118649    0.014371    0.732809    
#> 071: 0.470714    0.938804    3.392841    0.575856    0.112717    0.013652    0.752322    
#> 072: 0.502623    0.923285    3.407742    0.547063    0.109581    0.014240    0.753232    
#> 073: 0.515447    0.921295    3.426524    0.557286    0.123523    0.013528    0.749495    
#> 074: 0.552819    0.896685    3.420470    0.579586    0.117924    0.012851    0.738743    
#> 075: 0.580945    0.897499    3.441702    0.550606    0.112028    0.012209    0.743326    
#> 076: 0.611503    0.899288    3.447395    0.593272    0.106426    0.011598    0.763076    
#> 077: 0.619627    0.873880    3.443908    0.633636    0.105440    0.011647    0.758865    
#> 078: 0.594713    0.892584    3.440366    0.601954    0.100168    0.011064    0.749831    
#> 079: 0.587499    0.914656    3.440287    0.601363    0.103347    0.010511    0.778441    
#> 080: 0.588025    0.910846    3.440371    0.636469    0.120172    0.009985    0.785634    
#> 081: 0.573057    0.925669    3.431140    0.608238    0.114164    0.009486    0.769140    
#> 082: 0.566897    0.914188    3.427111    0.647329    0.108455    0.009012    0.785228    
#> 083: 0.555646    0.965067    3.416209    0.758957    0.103033    0.008561    0.763106    
#> 084: 0.625001    0.960465    3.420287    0.721009    0.104795    0.008133    0.777459    
#> 085: 0.624821    0.950281    3.426562    0.719699    0.108844    0.007727    0.767586    
#> 086: 0.578516    0.938829    3.425645    0.683714    0.105870    0.007340    0.757376    
#> 087: 0.549402    0.935098    3.405068    0.649528    0.100577    0.007110    0.742131    
#> 088: 0.531073    0.936895    3.407977    0.617052    0.097155    0.007082    0.757598    
#> 089: 0.542385    0.957259    3.402258    0.586199    0.112439    0.008540    0.752397    
#> 090: 0.471946    0.951395    3.401912    0.556889    0.119440    0.009308    0.768572    
#> 091: 0.511983    0.941717    3.394652    0.544662    0.113468    0.010509    0.753318    
#> 092: 0.503725    0.939077    3.395903    0.595331    0.107795    0.013603    0.740015    
#> 093: 0.463221    0.947315    3.386999    0.570405    0.102405    0.012979    0.747844    
#> 094: 0.504879    0.959107    3.387442    0.593787    0.097285    0.012330    0.745520    
#> 095: 0.510614    0.955376    3.401607    0.649405    0.092421    0.017971    0.736569    
#> 096: 0.486700    0.957311    3.387820    0.668499    0.090234    0.017073    0.737786    
#> 097: 0.541057    0.976252    3.393425    0.657303    0.095840    0.016219    0.733959    
#> 098: 0.535784    0.972987    3.406412    0.624437    0.108086    0.015408    0.736471    
#> 099: 0.541442    0.928409    3.404507    0.593216    0.102682    0.014638    0.722443    
#> 100: 0.484487    0.940555    3.401544    0.563555    0.097548    0.013906    0.744552    
#> 101: 0.465082    0.932400    3.385349    0.569723    0.092725    0.013210    0.755826    
#> 102: 0.464202    0.943926    3.381857    0.541237    0.094860    0.012550    0.756372    
#> 103: 0.513437    0.934147    3.397871    0.594792    0.100796    0.011922    0.740100    
#> 104: 0.510013    0.949058    3.408129    0.651764    0.100177    0.011326    0.734880    
#> 105: 0.543944    0.932761    3.404558    0.621384    0.104493    0.010760    0.751025    
#> 106: 0.528059    0.912635    3.409289    0.590315    0.099269    0.010222    0.752432    
#> 107: 0.552542    0.926333    3.409045    0.608157    0.105870    0.009952    0.739659    
#> 108: 0.534748    0.930699    3.414278    0.577749    0.100577    0.009455    0.747419    
#> 109: 0.541515    0.925080    3.421369    0.548862    0.101248    0.010171    0.754605    
#> 110: 0.565308    0.920760    3.411356    0.562978    0.096185    0.011861    0.761598    
#> 111: 0.556199    0.922955    3.423847    0.534829    0.091376    0.011276    0.741694    
#> 112: 0.531881    0.919914    3.413308    0.540154    0.093524    0.010712    0.757636    
#> 113: 0.593746    0.954528    3.416718    0.660844    0.088847    0.012486    0.744793    
#> 114: 0.551053    0.958653    3.411556    0.627802    0.084405    0.012489    0.754829    
#> 115: 0.556923    0.929076    3.409880    0.612775    0.082272    0.012695    0.742980    
#> 116: 0.581653    0.932805    3.420248    0.603094    0.097210    0.012708    0.733272    
#> 117: 0.542908    0.942486    3.410356    0.599616    0.092350    0.012072    0.773901    
#> 118: 0.581571    0.917974    3.405999    0.704188    0.092868    0.011469    0.763248    
#> 119: 0.534948    0.926999    3.402083    0.735346    0.104506    0.012251    0.784640    
#> 120: 0.510544    0.928481    3.395828    0.698579    0.099280    0.012949    0.773220    
#> 121: 0.501922    0.969589    3.390146    0.663650    0.097565    0.012301    0.761795    
#> 122: 0.502189    0.936770    3.399329    0.637901    0.092687    0.011686    0.770453    
#> 123: 0.580983    0.957438    3.402886    0.698914    0.097331    0.011102    0.764390    
#> 124: 0.546360    0.968822    3.396951    0.663969    0.100424    0.010547    0.794268    
#> 125: 0.527879    0.973894    3.392685    0.630770    0.104418    0.010020    0.765360    
#> 126: 0.512839    0.961785    3.387568    0.599232    0.119847    0.009519    0.764463    
#> 127: 0.514116    0.937430    3.389549    0.580095    0.113855    0.009043    0.764487    
#> 128: 0.470545    0.938769    3.395457    0.594922    0.108162    0.010717    0.749924    
#> 129: 0.518735    0.943741    3.406058    0.580920    0.102754    0.010970    0.735276    
#> 130: 0.527880    0.956514    3.405151    0.579804    0.097616    0.010651    0.732836    
#> 131: 0.523922    0.941472    3.398143    0.616170    0.102469    0.012267    0.731954    
#> 132: 0.474120    0.946226    3.384273    0.585361    0.109151    0.012621    0.743109    
#> 133: 0.470258    0.929358    3.394042    0.556093    0.110252    0.011990    0.759832    
#> 134: 0.511498    0.914951    3.409574    0.528289    0.104739    0.012400    0.753395    
#> 135: 0.519552    0.914065    3.419483    0.501874    0.099503    0.012353    0.771537    
#> 136: 0.505341    0.904706    3.422783    0.476781    0.094527    0.013275    0.760784    
#> 137: 0.546039    0.922922    3.427105    0.459346    0.096513    0.018261    0.747551    
#> 138: 0.532601    0.926048    3.422610    0.453077    0.095868    0.017348    0.743959    
#> 139: 0.526311    0.945519    3.416710    0.528830    0.102954    0.016481    0.730715    
#> 140: 0.531779    0.938057    3.415263    0.538539    0.104514    0.018545    0.743917    
#> 141: 0.531144    0.912175    3.413955    0.580475    0.099288    0.022581    0.738270    
#> 142: 0.547523    0.917020    3.423271    0.587145    0.094324    0.021570    0.748508    
#> 143: 0.563469    0.944696    3.428226    0.557788    0.089607    0.027089    0.763012    
#> 144: 0.573992    0.946877    3.423992    0.584593    0.085127    0.025735    0.726945    
#> 145: 0.554339    0.945863    3.424155    0.562751    0.081110    0.024448    0.723204    
#> 146: 0.575201    0.928144    3.438340    0.542381    0.078955    0.023225    0.734935    
#> 147: 0.544491    0.906708    3.426684    0.527006    0.094991    0.022064    0.717590    
#> 148: 0.536476    0.943138    3.422109    0.617724    0.094636    0.020961    0.730862    
#> 149: 0.539305    0.910770    3.419205    0.594058    0.089904    0.019913    0.734268    
#> 150: 0.555902    0.909688    3.406183    0.677134    0.085409    0.018917    0.748344    
#> 151: 0.514593    0.936766    3.408280    0.647935    0.084899    0.017971    0.726879    
#> 152: 0.514520    0.944178    3.409377    0.604847    0.073637    0.013772    0.747084    
#> 153: 0.528674    0.938040    3.414960    0.575743    0.092040    0.014790    0.748043    
#> 154: 0.577760    0.927711    3.427693    0.605593    0.108437    0.014423    0.744327    
#> 155: 0.561825    0.903768    3.427644    0.609693    0.093485    0.010924    0.751013    
#> 156: 0.581481    0.911947    3.441030    0.592408    0.094626    0.015348    0.760092    
#> 157: 0.594251    0.893655    3.445906    0.582865    0.105574    0.013988    0.754525    
#> 158: 0.637476    0.918303    3.437241    0.649531    0.095997    0.012807    0.728275    
#> 159: 0.582031    0.907266    3.440229    0.510590    0.093414    0.013714    0.743961    
#> 160: 0.579723    0.889654    3.441746    0.504975    0.096370    0.013547    0.753840    
#> 161: 0.580819    0.909995    3.438005    0.484047    0.079126    0.017517    0.754254    
#> 162: 0.552471    0.913266    3.429334    0.497979    0.092851    0.017252    0.750529    
#> 163: 0.575229    0.912052    3.422466    0.553058    0.099023    0.015018    0.742111    
#> 164: 0.590770    0.912857    3.434689    0.485134    0.090225    0.012482    0.755244    
#> 165: 0.602696    0.882061    3.438260    0.522606    0.091714    0.015817    0.757857    
#> 166: 0.608460    0.924550    3.434741    0.498961    0.101802    0.018147    0.750654    
#> 167: 0.587228    0.924202    3.441470    0.422126    0.087063    0.019667    0.761466    
#> 168: 0.602354    0.940604    3.440906    0.417427    0.089242    0.016483    0.778909    
#> 169: 0.574844    0.956620    3.433680    0.385780    0.076556    0.018035    0.801859    
#> 170: 0.580556    0.902247    3.439837    0.405290    0.075210    0.017379    0.760523    
#> 171: 0.546487    0.899659    3.432295    0.427607    0.073129    0.013428    0.746468    
#> 172: 0.527256    0.935222    3.422162    0.501772    0.082841    0.013476    0.727193    
#> 173: 0.519098    0.935271    3.409035    0.455465    0.079557    0.012435    0.746122    
#> 174: 0.555177    0.936652    3.418160    0.470188    0.093065    0.009314    0.745647    
#> 175: 0.554166    0.926160    3.421386    0.516358    0.094375    0.014163    0.749768    
#> 176: 0.535224    0.916482    3.430805    0.535014    0.081806    0.012228    0.750780    
#> 177: 0.605966    0.904334    3.448021    0.599820    0.089716    0.010117    0.768467    
#> 178: 0.605139    0.889901    3.439822    0.586115    0.105823    0.010256    0.749267    
#> 179: 0.605542    0.914354    3.437084    0.585547    0.088924    0.011082    0.751033    
#> 180: 0.547217    0.900443    3.427438    0.510605    0.091286    0.012204    0.765660    
#> 181: 0.543524    0.919816    3.411187    0.466434    0.082507    0.011606    0.758339    
#> 182: 0.500839    0.939874    3.400087    0.474101    0.095028    0.012655    0.767176    
#> 183: 0.490241    0.947251    3.397357    0.453828    0.098552    0.013696    0.756692    
#> 184: 0.531038    0.937953    3.401589    0.591268    0.088237    0.013127    0.745073    
#> 185: 0.525228    0.932640    3.407727    0.544509    0.074089    0.012398    0.753539    
#> 186: 0.515922    0.952480    3.410347    0.490803    0.074496    0.013939    0.763631    
#> 187: 0.534934    0.920547    3.418988    0.479807    0.066449    0.011679    0.766860    
#> 188: 0.524531    0.950649    3.408413    0.607331    0.075398    0.012050    0.753285    
#> 189: 0.538931    0.948335    3.419711    0.590888    0.094850    0.009607    0.768502    
#> 190: 0.536639    0.935571    3.421281    0.482708    0.091208    0.009135    0.735038    
#> 191: 0.525232    0.951777    3.405320    0.555025    0.091757    0.008739    0.736046    
#> 192: 0.520556    0.936307    3.411874    0.586669    0.091599    0.009679    0.734856    
#> 193: 0.575091    0.935897    3.418641    0.587174    0.081548    0.009954    0.729272    
#> 194: 0.545242    0.937069    3.403833    0.517652    0.097531    0.009099    0.753498    
#> 195: 0.519687    0.933214    3.408076    0.509660    0.102820    0.007042    0.750499    
#> 196: 0.571549    0.938076    3.418622    0.558302    0.100025    0.007358    0.769917    
#> 197: 0.500134    0.935813    3.427045    0.518862    0.116639    0.007123    0.779565    
#> 198: 0.624306    0.923380    3.426510    0.640566    0.088891    0.006718    0.752887    
#> 199: 0.526794    0.909049    3.417630    0.531553    0.103180    0.006760    0.766060    
#> 200: 0.495628    0.916178    3.405966    0.497822    0.093725    0.005612    0.795524    
#> 201: 0.489434    0.920755    3.410515    0.487361    0.090470    0.005984    0.787005    
#> 202: 0.494315    0.924501    3.412064    0.507415    0.097927    0.005817    0.784288    
#> 203: 0.512335    0.923020    3.411697    0.535829    0.100686    0.005622    0.784088    
#> 204: 0.519950    0.918096    3.412881    0.552524    0.107989    0.005744    0.784556    
#> 205: 0.531822    0.922736    3.413356    0.574831    0.109649    0.005912    0.785283    
#> 206: 0.536030    0.928269    3.413690    0.593104    0.111252    0.006207    0.786276    
#> 207: 0.531910    0.928227    3.413641    0.581088    0.111203    0.006370    0.785619    
#> 208: 0.529896    0.930737    3.413820    0.572650    0.110775    0.006469    0.782250    
#> 209: 0.537087    0.928648    3.414180    0.578116    0.112408    0.006398    0.781136    
#> 210: 0.538794    0.926601    3.414006    0.575901    0.112563    0.006438    0.780255    
#> 211: 0.543360    0.927364    3.414522    0.578443    0.112160    0.006320    0.779305    
#> 212: 0.545579    0.927233    3.414581    0.580553    0.113039    0.006214    0.777184    
#> 213: 0.547032    0.925139    3.414747    0.583571    0.114486    0.006189    0.777391    
#> 214: 0.550010    0.924539    3.415109    0.581142    0.115210    0.006201    0.777289    
#> 215: 0.550567    0.924841    3.415800    0.581412    0.115309    0.006422    0.776990    
#> 216: 0.555841    0.923945    3.416142    0.588530    0.115722    0.006532    0.777043    
#> 217: 0.553593    0.925845    3.415860    0.585419    0.116530    0.006615    0.776390    
#> 218: 0.551057    0.926369    3.415211    0.580142    0.117059    0.006599    0.776835    
#> 219: 0.549908    0.926362    3.414143    0.577168    0.117246    0.006636    0.776408    
#> 220: 0.545029    0.927140    3.413764    0.570457    0.116861    0.006721    0.776800    
#> 221: 0.541858    0.928372    3.413310    0.564609    0.116880    0.006822    0.776286    
#> 222: 0.543024    0.928205    3.412971    0.565860    0.116315    0.006999    0.776309    
#> 223: 0.543247    0.928138    3.412859    0.568224    0.116888    0.007064    0.776082    
#> 224: 0.545560    0.928687    3.413051    0.573646    0.117776    0.007078    0.775459    
#> 225: 0.544710    0.927259    3.413286    0.576314    0.118082    0.007149    0.775454    
#> 226: 0.544501    0.926138    3.413312    0.576391    0.118612    0.007292    0.775142    
#> 227: 0.544089    0.925827    3.413390    0.579479    0.118088    0.007434    0.774439    
#> 228: 0.543230    0.926464    3.413205    0.577229    0.117778    0.007583    0.774151    
#> 229: 0.543510    0.926098    3.413266    0.579349    0.117474    0.007704    0.773877    
#> 230: 0.542869    0.926019    3.413106    0.577489    0.117128    0.007847    0.773946    
#> 231: 0.542475    0.926949    3.413176    0.575058    0.116513    0.007977    0.773869    
#> 232: 0.541473    0.927493    3.413540    0.573490    0.115720    0.008116    0.773338    
#> 233: 0.540882    0.926835    3.413814    0.574000    0.114981    0.008252    0.772964    
#> 234: 0.540967    0.926875    3.413982    0.572990    0.114526    0.008348    0.772248    
#> 235: 0.541916    0.927243    3.413883    0.574325    0.114641    0.008387    0.771592    
#> 236: 0.541913    0.927189    3.413827    0.573264    0.114861    0.008423    0.771145    
#> 237: 0.542228    0.927308    3.413848    0.574816    0.114505    0.008472    0.770976    
#> 238: 0.543028    0.926697    3.413941    0.574783    0.114215    0.008574    0.770738    
#> 239: 0.542453    0.926711    3.413906    0.575691    0.114001    0.008601    0.770318    
#> 240: 0.542231    0.926282    3.413908    0.573420    0.113513    0.008618    0.769685    
#> 241: 0.542961    0.925426    3.414177    0.574987    0.113157    0.008616    0.769236    
#> 242: 0.543159    0.924729    3.414163    0.576030    0.112924    0.008641    0.769247    
#> 243: 0.543297    0.925401    3.414223    0.575224    0.112920    0.008686    0.769213    
#> 244: 0.543472    0.925276    3.414277    0.576288    0.112704    0.008734    0.769065    
#> 245: 0.543480    0.924840    3.414429    0.575147    0.112484    0.008758    0.769778    
#> 246: 0.544503    0.924964    3.414635    0.574509    0.112467    0.008820    0.769891    
#> 247: 0.544916    0.924832    3.414920    0.576238    0.112082    0.008912    0.769689    
#> 248: 0.545452    0.924819    3.415140    0.576846    0.111569    0.008976    0.769186    
#> 249: 0.544865    0.925041    3.415130    0.576320    0.111430    0.009046    0.768717    
#> 250: 0.545737    0.925376    3.415023    0.578801    0.111293    0.009091    0.768256    
#> 251: 0.546332    0.925689    3.415131    0.580905    0.110748    0.009122    0.767914    
#> 252: 0.547772    0.926123    3.415263    0.586035    0.110294    0.009155    0.767485    
#> 253: 0.548062    0.926595    3.415261    0.586519    0.110121    0.009189    0.767624    
#> 254: 0.547915    0.927037    3.415251    0.586868    0.109843    0.009232    0.767337    
#> 255: 0.547047    0.927703    3.415188    0.585990    0.109384    0.009322    0.767399    
#> 256: 0.547162    0.927815    3.415004    0.587441    0.108938    0.009429    0.767157    
#> 257: 0.547006    0.927805    3.414869    0.588157    0.108475    0.009470    0.766982    
#> 258: 0.546880    0.927515    3.414894    0.589308    0.108255    0.009477    0.766915    
#> 259: 0.547369    0.927649    3.414850    0.590821    0.107941    0.009517    0.766511    
#> 260: 0.548064    0.927675    3.415085    0.590354    0.107774    0.009527    0.766156    
#> 261: 0.548545    0.927257    3.415381    0.588927    0.107425    0.009553    0.766066    
#> 262: 0.548528    0.927008    3.415586    0.588627    0.107183    0.009575    0.765689    
#> 263: 0.548499    0.927305    3.415528    0.588227    0.106982    0.009578    0.765637    
#> 264: 0.548114    0.927718    3.415428    0.587605    0.107127    0.009565    0.765769    
#> 265: 0.548265    0.928179    3.415306    0.587860    0.107194    0.009546    0.766028    
#> 266: 0.548283    0.928255    3.415205    0.588674    0.107367    0.009493    0.765963    
#> 267: 0.548030    0.928377    3.415086    0.589044    0.107327    0.009450    0.766050    
#> 268: 0.547504    0.928049    3.414891    0.588861    0.107368    0.009432    0.765922    
#> 269: 0.547814    0.927895    3.414907    0.589529    0.107248    0.009433    0.765727    
#> 270: 0.548191    0.928063    3.414751    0.592217    0.107199    0.009423    0.765475    
#> 271: 0.548169    0.928526    3.414491    0.593282    0.107212    0.009422    0.765548    
#> 272: 0.548521    0.928347    3.414383    0.593225    0.107129    0.009435    0.765671    
#> 273: 0.548488    0.928363    3.414358    0.592701    0.107102    0.009463    0.765700    
#> 274: 0.548303    0.928643    3.414412    0.592436    0.106890    0.009470    0.765622    
#> 275: 0.548656    0.928886    3.414273    0.594500    0.106626    0.009472    0.765563    
#> 276: 0.548447    0.928860    3.414351    0.596739    0.106320    0.009470    0.765535    
#> 277: 0.548350    0.929128    3.414403    0.597763    0.106162    0.009509    0.765347    
#> 278: 0.548145    0.929362    3.414402    0.598489    0.105967    0.009524    0.765227    
#> 279: 0.547679    0.929465    3.414360    0.598186    0.105813    0.009541    0.765353    
#> 280: 0.547214    0.929668    3.414280    0.597188    0.105840    0.009528    0.765157    
#> 281: 0.546907    0.929917    3.414278    0.597941    0.105759    0.009503    0.764965    
#> 282: 0.547265    0.929973    3.414233    0.600042    0.105714    0.009506    0.764781    
#> 283: 0.547456    0.930155    3.414152    0.602762    0.105788    0.009544    0.764750    
#> 284: 0.546827    0.929988    3.413987    0.603065    0.105521    0.009556    0.764663    
#> 285: 0.547043    0.930053    3.413762    0.604656    0.105258    0.009612    0.764709    
#> 286: 0.546704    0.930453    3.413577    0.605241    0.105358    0.009669    0.764704    
#> 287: 0.546632    0.930835    3.413379    0.606514    0.105595    0.009725    0.764664    
#> 288: 0.546867    0.930831    3.413324    0.607251    0.105650    0.009770    0.764676    
#> 289: 0.547442    0.931009    3.413322    0.608175    0.105844    0.009809    0.764675    
#> 290: 0.547837    0.931059    3.413261    0.609487    0.105786    0.009823    0.764703    
#> 291: 0.547898    0.931106    3.413314    0.610299    0.105665    0.009831    0.764570    
#> 292: 0.547292    0.930988    3.413278    0.609516    0.105679    0.009809    0.764471    
#> 293: 0.547052    0.931126    3.413135    0.609132    0.105543    0.009786    0.764427    
#> 294: 0.546685    0.931281    3.412988    0.609147    0.105418    0.009783    0.764319    
#> 295: 0.546467    0.931057    3.412870    0.608257    0.105247    0.009784    0.764085    
#> 296: 0.546007    0.931195    3.412771    0.607172    0.105112    0.009795    0.764123    
#> 297: 0.545897    0.931414    3.412655    0.607311    0.105154    0.009810    0.764152    
#> 298: 0.545747    0.931489    3.412631    0.606168    0.105112    0.009833    0.764124    
#> 299: 0.545726    0.931488    3.412660    0.605884    0.105024    0.009841    0.763876    
#> 300: 0.546008    0.931191    3.412841    0.605621    0.104974    0.009864    0.763634    
#> 301: 0.546006    0.931037    3.412884    0.604517    0.104971    0.009858    0.763569    
#> 302: 0.546037    0.931369    3.412873    0.603984    0.104849    0.009860    0.763467    
#> 303: 0.546067    0.931422    3.412845    0.604477    0.104713    0.009873    0.763286    
#> 304: 0.546237    0.931783    3.412695    0.605427    0.104643    0.009896    0.763103    
#> 305: 0.546126    0.931683    3.412656    0.606352    0.104578    0.009941    0.762779    
#> 306: 0.545883    0.931551    3.412600    0.607262    0.104644    0.009970    0.762710    
#> 307: 0.545631    0.931411    3.412451    0.608089    0.104734    0.009973    0.762585    
#> 308: 0.545526    0.931461    3.412301    0.610043    0.104732    0.009976    0.762617    
#> 309: 0.545504    0.931488    3.412146    0.611761    0.104634    0.009985    0.762808    
#> 310: 0.545492    0.931651    3.411858    0.612996    0.104508    0.009998    0.762975    
#> 311: 0.545405    0.931699    3.411697    0.614813    0.104375    0.010004    0.762965    
#> 312: 0.545730    0.931806    3.411551    0.617481    0.104438    0.010002    0.762915    
#> 313: 0.545567    0.931592    3.411441    0.619438    0.104504    0.009996    0.762886    
#> 314: 0.545119    0.931753    3.411278    0.619831    0.104503    0.009993    0.762713    
#> 315: 0.544592    0.931990    3.411194    0.619425    0.104448    0.009997    0.762605    
#> 316: 0.544375    0.932185    3.411155    0.619407    0.104381    0.009998    0.762629    
#> 317: 0.543915    0.932121    3.411153    0.618336    0.104429    0.010004    0.762609    
#> 318: 0.543708    0.932129    3.411091    0.618083    0.104408    0.010026    0.762512    
#> 319: 0.543614    0.932269    3.411042    0.617592    0.104362    0.010040    0.762411    
#> 320: 0.543379    0.932243    3.410940    0.617867    0.104226    0.010064    0.762443    
#> 321: 0.542979    0.932370    3.410749    0.618893    0.104233    0.010097    0.762423    
#> 322: 0.542666    0.932556    3.410540    0.618419    0.104019    0.010112    0.762428    
#> 323: 0.542067    0.932841    3.410335    0.618110    0.103905    0.010107    0.762359    
#> 324: 0.541446    0.933102    3.410262    0.617308    0.103761    0.010103    0.762194    
#> 325: 0.540961    0.933436    3.410130    0.616637    0.103749    0.010110    0.762040    
#> 326: 0.540679    0.933428    3.409964    0.616461    0.103739    0.010099    0.762030    
#> 327: 0.540582    0.933528    3.409841    0.616951    0.103607    0.010117    0.761871    
#> 328: 0.540511    0.933653    3.409725    0.617201    0.103428    0.010129    0.761655    
#> 329: 0.540374    0.933685    3.409694    0.617271    0.103239    0.010150    0.761449    
#> 330: 0.540228    0.933693    3.409748    0.617234    0.103113    0.010174    0.761418    
#> 331: 0.540136    0.933886    3.409774    0.616490    0.102988    0.010174    0.761391    
#> 332: 0.540227    0.933848    3.409887    0.615991    0.102861    0.010197    0.761288    
#> 333: 0.540257    0.933861    3.409884    0.615953    0.102782    0.010229    0.761131    
#> 334: 0.540085    0.933788    3.409753    0.615823    0.102668    0.010250    0.760937    
#> 335: 0.539933    0.933784    3.409631    0.615633    0.102518    0.010244    0.760890    
#> 336: 0.539083    0.933962    3.409470    0.614855    0.102330    0.010234    0.761014    
#> 337: 0.538893    0.934316    3.409321    0.614586    0.102218    0.010224    0.761073    
#> 338: 0.538465    0.934369    3.409285    0.613648    0.102091    0.010213    0.761243    
#> 339: 0.538220    0.934577    3.409245    0.612622    0.101969    0.010207    0.761201    
#> 340: 0.538122    0.934340    3.409349    0.611975    0.101802    0.010205    0.761250    
#> 341: 0.538204    0.934155    3.409485    0.611450    0.101708    0.010210    0.761184    
#> 342: 0.537910    0.933931    3.409522    0.611071    0.101661    0.010213    0.761093    
#> 343: 0.537834    0.933937    3.409513    0.611461    0.101630    0.010215    0.760910    
#> 344: 0.538242    0.933848    3.409547    0.612212    0.101498    0.010208    0.760947    
#> 345: 0.538552    0.933579    3.409630    0.612681    0.101418    0.010213    0.760851    
#> 346: 0.538796    0.933461    3.409582    0.613222    0.101304    0.010210    0.760593    
#> 347: 0.538531    0.933457    3.409515    0.612702    0.101290    0.010215    0.760583    
#> 348: 0.538531    0.933551    3.409473    0.612617    0.101344    0.010233    0.760487    
#> 349: 0.538439    0.933477    3.409463    0.612894    0.101364    0.010255    0.760408    
#> 350: 0.538231    0.933348    3.409429    0.612634    0.101344    0.010275    0.760400    
#> 351: 0.538256    0.933379    3.409408    0.612287    0.101405    0.010297    0.760280    
#> 352: 0.537922    0.933408    3.409365    0.611880    0.101406    0.010312    0.760329    
#> 353: 0.538049    0.933611    3.409399    0.611761    0.101422    0.010325    0.760253    
#> 354: 0.538177    0.933670    3.409347    0.611777    0.101406    0.010333    0.760213    
#> 355: 0.538466    0.933561    3.409356    0.611874    0.101340    0.010344    0.760159    
#> 356: 0.538324    0.933443    3.409425    0.611513    0.101224    0.010338    0.760297    
#> 357: 0.538403    0.933409    3.409509    0.611045    0.101112    0.010331    0.760319    
#> 358: 0.538491    0.933395    3.409627    0.610373    0.101026    0.010340    0.760249    
#> 359: 0.538535    0.933447    3.409648    0.610105    0.100892    0.010353    0.760139    
#> 360: 0.538738    0.933398    3.409583    0.610455    0.100799    0.010370    0.759970    
#> 361: 0.538841    0.933389    3.409534    0.610771    0.100695    0.010394    0.759771    
#> 362: 0.539217    0.933376    3.409562    0.611219    0.100656    0.010399    0.759596    
#> 363: 0.539626    0.933279    3.409620    0.612485    0.100576    0.010406    0.759349    
#> 364: 0.539986    0.933319    3.409620    0.613590    0.100546    0.010411    0.759245    
#> 365: 0.540148    0.933278    3.409577    0.613702    0.100524    0.010435    0.759171    
#> 366: 0.540024    0.933290    3.409451    0.613521    0.100461    0.010465    0.759112    
#> 367: 0.539988    0.933353    3.409386    0.613057    0.100396    0.010473    0.759048    
#> 368: 0.539980    0.933458    3.409325    0.613434    0.100343    0.010474    0.758968    
#> 369: 0.539787    0.933531    3.409295    0.613532    0.100283    0.010480    0.758982    
#> 370: 0.539592    0.933619    3.409255    0.613290    0.100266    0.010473    0.758988    
#> 371: 0.539236    0.933739    3.409141    0.612799    0.100234    0.010469    0.758988    
#> 372: 0.538747    0.933868    3.409032    0.612621    0.100249    0.010456    0.759000    
#> 373: 0.538246    0.934235    3.408897    0.612324    0.100230    0.010443    0.759102    
#> 374: 0.538266    0.934422    3.408834    0.611979    0.100214    0.010427    0.759111    
#> 375: 0.538125    0.934493    3.408800    0.611384    0.100186    0.010415    0.759116    
#> 376: 0.537950    0.934636    3.408795    0.610714    0.100163    0.010413    0.759092    
#> 377: 0.537753    0.934796    3.408772    0.610388    0.100047    0.010414    0.759012    
#> 378: 0.537654    0.934862    3.408738    0.609900    0.099935    0.010429    0.758970    
#> 379: 0.537483    0.934695    3.408759    0.609448    0.099802    0.010449    0.758906    
#> 380: 0.537454    0.934653    3.408784    0.609084    0.099720    0.010448    0.758953    
#> 381: 0.537570    0.934627    3.408807    0.609308    0.099703    0.010452    0.758913    
#> 382: 0.537529    0.934567    3.408823    0.609324    0.099630    0.010452    0.758758    
#> 383: 0.537425    0.934506    3.408829    0.609195    0.099635    0.010450    0.758711    
#> 384: 0.537180    0.934524    3.408881    0.608572    0.099625    0.010444    0.758679    
#> 385: 0.536971    0.934511    3.408879    0.608113    0.099658    0.010459    0.758543    
#> 386: 0.537016    0.934616    3.408889    0.607893    0.099737    0.010466    0.758490    
#> 387: 0.537152    0.934743    3.408959    0.607769    0.099734    0.010466    0.758428    
#> 388: 0.537117    0.934931    3.408956    0.607453    0.099762    0.010457    0.758372    
#> 389: 0.537089    0.934840    3.408930    0.607531    0.099728    0.010453    0.758385    
#> 390: 0.536993    0.934845    3.408905    0.607594    0.099716    0.010453    0.758478    
#> 391: 0.537020    0.934797    3.408919    0.607366    0.099719    0.010444    0.758549    
#> 392: 0.537029    0.934709    3.408983    0.607514    0.099704    0.010453    0.758697    
#> 393: 0.537196    0.934746    3.409014    0.607574    0.099708    0.010455    0.758714    
#> 394: 0.537400    0.934673    3.409046    0.607596    0.099771    0.010449    0.758732    
#> 395: 0.537566    0.934734    3.409075    0.607273    0.099805    0.010448    0.758728    
#> 396: 0.537777    0.934707    3.409099    0.607399    0.099792    0.010446    0.758694    
#> 397: 0.537904    0.934593    3.409132    0.607520    0.099825    0.010432    0.758662    
#> 398: 0.538160    0.934529    3.409157    0.607987    0.099863    0.010440    0.758618    
#> 399: 0.538237    0.934600    3.409207    0.607618    0.099896    0.010454    0.758567    
#> 400: 0.538325    0.934698    3.409253    0.607447    0.099879    0.010473    0.758631    
#> 401: 0.538419    0.934682    3.409225    0.607522    0.099956    0.010506    0.758625    
#> 402: 0.538512    0.934723    3.409232    0.607561    0.099947    0.010545    0.758603    
#> 403: 0.538707    0.934757    3.409242    0.607682    0.099813    0.010576    0.758540    
#> 404: 0.538683    0.934839    3.409155    0.607918    0.099709    0.010592    0.758431    
#> 405: 0.538611    0.934912    3.409120    0.608566    0.099678    0.010600    0.758455    
#> 406: 0.538675    0.934988    3.409102    0.608512    0.099714    0.010611    0.758449    
#> 407: 0.538540    0.935025    3.409116    0.608470    0.099766    0.010615    0.758460    
#> 408: 0.538574    0.935052    3.409113    0.608255    0.099786    0.010630    0.758383    
#> 409: 0.538409    0.935011    3.409093    0.607608    0.099808    0.010637    0.758406    
#> 410: 0.538317    0.935027    3.409065    0.607585    0.099888    0.010630    0.758326    
#> 411: 0.538448    0.934813    3.409074    0.607651    0.099929    0.010642    0.758309    
#> 412: 0.538386    0.934887    3.409013    0.607302    0.099896    0.010661    0.758238    
#> 413: 0.538224    0.934897    3.408975    0.606618    0.099829    0.010673    0.758200    
#> 414: 0.538161    0.934873    3.408962    0.607005    0.099794    0.010670    0.758133    
#> 415: 0.538216    0.934927    3.408913    0.607113    0.099814    0.010664    0.758038    
#> 416: 0.538032    0.935024    3.408848    0.606741    0.099807    0.010655    0.757992    
#> 417: 0.538053    0.935102    3.408810    0.607266    0.099764    0.010652    0.757864    
#> 418: 0.537916    0.935125    3.408794    0.607537    0.099735    0.010651    0.757833    
#> 419: 0.538003    0.935264    3.408785    0.607548    0.099744    0.010657    0.757812    
#> 420: 0.538021    0.935331    3.408780    0.607432    0.099680    0.010654    0.757748    
#> 421: 0.537991    0.935360    3.408825    0.607456    0.099570    0.010654    0.757731    
#> 422: 0.538200    0.935233    3.408858    0.607412    0.099532    0.010662    0.757685    
#> 423: 0.538466    0.935145    3.408872    0.608060    0.099528    0.010661    0.757704    
#> 424: 0.538513    0.935109    3.408823    0.608666    0.099500    0.010650    0.757720    
#> 425: 0.538546    0.935121    3.408838    0.609158    0.099538    0.010648    0.757674    
#> 426: 0.538803    0.935255    3.408853    0.609237    0.099571    0.010653    0.757684    
#> 427: 0.538773    0.935275    3.408858    0.609389    0.099628    0.010657    0.757592    
#> 428: 0.538601    0.935369    3.408847    0.608960    0.099593    0.010658    0.757629    
#> 429: 0.538489    0.935440    3.408839    0.608796    0.099558    0.010662    0.757586    
#> 430: 0.538332    0.935578    3.408836    0.608331    0.099521    0.010665    0.757720    
#> 431: 0.538198    0.935653    3.408831    0.608005    0.099537    0.010663    0.757699    
#> 432: 0.538224    0.935787    3.408824    0.608439    0.099533    0.010665    0.757659    
#> 433: 0.538187    0.935874    3.408777    0.608891    0.099536    0.010659    0.757704    
#> 434: 0.537844    0.935830    3.408754    0.608726    0.099536    0.010657    0.757710    
#> 435: 0.537731    0.935891    3.408715    0.608650    0.099609    0.010654    0.757620    
#> 436: 0.537698    0.935872    3.408732    0.608635    0.099722    0.010661    0.757594    
#> 437: 0.537708    0.935897    3.408703    0.608454    0.099789    0.010665    0.757560    
#> 438: 0.537679    0.935923    3.408694    0.608378    0.099818    0.010657    0.757517    
#> 439: 0.537552    0.936024    3.408683    0.607857    0.099843    0.010653    0.757485    
#> 440: 0.537422    0.936100    3.408689    0.607366    0.099859    0.010655    0.757487    
#> 441: 0.537402    0.936080    3.408708    0.606981    0.099857    0.010653    0.757474    
#> 442: 0.537376    0.936172    3.408728    0.606661    0.099873    0.010640    0.757398    
#> 443: 0.537433    0.936271    3.408704    0.606626    0.099863    0.010644    0.757452    
#> 444: 0.537305    0.936326    3.408638    0.606454    0.099805    0.010656    0.757511    
#> 445: 0.537179    0.936305    3.408570    0.606686    0.099723    0.010654    0.757527    
#> 446: 0.537132    0.936390    3.408489    0.607115    0.099690    0.010651    0.757480    
#> 447: 0.537077    0.936462    3.408434    0.607241    0.099702    0.010650    0.757459    
#> 448: 0.536903    0.936505    3.408415    0.607038    0.099711    0.010652    0.757440    
#> 449: 0.536739    0.936612    3.408464    0.606409    0.099752    0.010658    0.757420    
#> 450: 0.536584    0.936590    3.408453    0.605998    0.099755    0.010671    0.757439    
#> 451: 0.536653    0.936635    3.408419    0.605785    0.099766    0.010682    0.757481    
#> 452: 0.536536    0.936701    3.408382    0.605503    0.099751    0.010683    0.757499    
#> 453: 0.536382    0.936735    3.408347    0.605407    0.099708    0.010678    0.757481    
#> 454: 0.536384    0.936786    3.408330    0.605414    0.099701    0.010676    0.757432    
#> 455: 0.536439    0.936772    3.408304    0.605521    0.099606    0.010681    0.757314    
#> 456: 0.536268    0.936709    3.408261    0.605513    0.099605    0.010683    0.757266    
#> 457: 0.536208    0.936680    3.408284    0.605489    0.099631    0.010685    0.757138    
#> 458: 0.536359    0.936744    3.408357    0.605653    0.099638    0.010675    0.757132    
#> 459: 0.536304    0.936822    3.408394    0.605566    0.099607    0.010668    0.757232    
#> 460: 0.536173    0.936775    3.408393    0.605219    0.099631    0.010657    0.757263    
#> 461: 0.536187    0.936803    3.408438    0.604816    0.099589    0.010651    0.757264    
#> 462: 0.536239    0.936866    3.408493    0.604655    0.099603    0.010654    0.757216    
#> 463: 0.536302    0.936938    3.408544    0.604320    0.099683    0.010662    0.757146    
#> 464: 0.536439    0.936969    3.408562    0.604285    0.099693    0.010666    0.757086    
#> 465: 0.536498    0.936805    3.408581    0.604281    0.099712    0.010671    0.757055    
#> 466: 0.536579    0.936827    3.408563    0.604033    0.099698    0.010673    0.757042    
#> 467: 0.536569    0.936744    3.408602    0.603737    0.099663    0.010689    0.756983    
#> 468: 0.536782    0.936760    3.408667    0.603981    0.099650    0.010698    0.757005    
#> 469: 0.536793    0.936851    3.408695    0.603558    0.099680    0.010701    0.757122    
#> 470: 0.536710    0.936887    3.408682    0.603670    0.099727    0.010706    0.757141    
#> 471: 0.536665    0.936828    3.408679    0.603671    0.099718    0.010699    0.757174    
#> 472: 0.536633    0.936810    3.408722    0.603549    0.099819    0.010692    0.757178    
#> 473: 0.536545    0.936757    3.408751    0.603127    0.099789    0.010692    0.757098    
#> 474: 0.536728    0.936700    3.408798    0.603202    0.099767    0.010699    0.757077    
#> 475: 0.536925    0.936760    3.408856    0.603300    0.099778    0.010711    0.757016    
#> 476: 0.537035    0.936697    3.408866    0.603837    0.099804    0.010711    0.756954    
#> 477: 0.537080    0.936620    3.408940    0.603934    0.099790    0.010718    0.756870    
#> 478: 0.536971    0.936497    3.408990    0.603745    0.099813    0.010728    0.756918    
#> 479: 0.536940    0.936476    3.409040    0.603615    0.099832    0.010729    0.756990    
#> 480: 0.536944    0.936447    3.409064    0.603473    0.099876    0.010748    0.756932    
#> 481: 0.536875    0.936460    3.409063    0.603248    0.099902    0.010762    0.756880    
#> 482: 0.536974    0.936497    3.409029    0.603326    0.099915    0.010775    0.756878    
#> 483: 0.536915    0.936459    3.409039    0.603578    0.099916    0.010782    0.756878    
#> 484: 0.536957    0.936322    3.409087    0.603711    0.099927    0.010789    0.756895    
#> 485: 0.537030    0.936325    3.409128    0.603993    0.099925    0.010805    0.756870    
#> 486: 0.537156    0.936373    3.409181    0.604016    0.099931    0.010807    0.756809    
#> 487: 0.537335    0.936348    3.409271    0.604047    0.099946    0.010812    0.756713    
#> 488: 0.537334    0.936299    3.409316    0.603965    0.099942    0.010823    0.756624    
#> 489: 0.537374    0.936230    3.409315    0.603875    0.099892    0.010847    0.756592    
#> 490: 0.537538    0.936254    3.409319    0.604245    0.099884    0.010854    0.756512    
#> 491: 0.537487    0.936335    3.409366    0.603959    0.099866    0.010865    0.756414    
#> 492: 0.537521    0.936405    3.409405    0.603738    0.099944    0.010867    0.756433    
#> 493: 0.537478    0.936383    3.409427    0.603537    0.099981    0.010877    0.756351    
#> 494: 0.537481    0.936418    3.409397    0.603204    0.100035    0.010884    0.756272    
#> 495: 0.537547    0.936408    3.409416    0.603306    0.100028    0.010892    0.756223    
#> 496: 0.537643    0.936507    3.409358    0.603357    0.100008    0.010902    0.756231    
#> 497: 0.537563    0.936570    3.409318    0.603339    0.099998    0.010907    0.756210    
#> 498: 0.537574    0.936599    3.409260    0.603351    0.100000    0.010909    0.756105    
#> 499: 0.537657    0.936647    3.409203    0.603539    0.099951    0.010906    0.756019    
#> 500: 0.537715    0.936661    3.409161    0.603688    0.099941    0.010903    0.755935    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.378828    0.954779    3.442426    0.392401    0.082168    0.016800    1.803006    
#> 002: 0.687300    0.953008    3.438510    0.372781    0.078060    0.017197    1.231078    
#> 003: 0.874573    0.912580    3.462495    0.354142    0.074157    0.016338    0.965055    
#> 004: 0.893413    0.914740    3.471773    0.336435    0.070449    0.015521    0.856614    
#> 005: 0.905978    0.936937    3.458742    0.319613    0.066926    0.014745    0.806811    
#> 006: 0.908005    0.935728    3.443509    0.379679    0.063580    0.014007    0.767875    
#> 007: 0.899546    0.951591    3.438284    0.367861    0.060401    0.013307    0.789620    
#> 008: 0.871416    0.957507    3.434197    0.364743    0.057381    0.012642    0.775660    
#> 009: 0.822318    0.944951    3.421754    0.367784    0.054512    0.012010    0.763217    
#> 010: 0.844778    0.945778    3.422283    0.377423    0.051786    0.011409    0.770511    
#> 011: 0.943957    0.949964    3.433533    0.464095    0.049197    0.010839    0.766432    
#> 012: 0.959879    0.951107    3.427639    0.440891    0.046737    0.010297    0.744117    
#> 013: 0.885128    0.968725    3.422012    0.418846    0.044400    0.009782    0.781327    
#> 014: 0.934859    0.967625    3.434530    0.473044    0.050098    0.009293    0.785396    
#> 015: 0.948660    0.963184    3.451717    0.449392    0.047593    0.008828    0.761730    
#> 016: 0.967609    0.969806    3.451701    0.426922    0.045214    0.008387    0.771370    
#> 017: 0.953002    0.964810    3.450882    0.490739    0.042953    0.008336    0.762974    
#> 018: 0.936684    0.983809    3.430004    0.480744    0.040805    0.008463    0.790694    
#> 019: 0.875151    0.978102    3.434232    0.456707    0.040715    0.008040    0.753279    
#> 020: 0.898687    0.982432    3.436417    0.433871    0.055727    0.007638    0.772320    
#> 021: 0.946060    0.969920    3.445098    0.435160    0.052941    0.008062    0.745532    
#> 022: 0.939181    0.972621    3.444831    0.516094    0.050294    0.007659    0.725306    
#> 023: 1.019532    0.959978    3.449722    0.526017    0.047779    0.007917    0.765345    
#> 024: 0.999123    0.998871    3.453659    0.559651    0.045390    0.009460    0.743058    
#> 025: 1.006862    0.975624    3.449567    0.531669    0.043121    0.008987    0.749798    
#> 026: 0.958216    1.000377    3.440025    0.505085    0.040965    0.008892    0.770911    
#> 027: 0.930433    1.002842    3.440451    0.479831    0.038916    0.009423    0.790195    
#> 028: 0.977732    0.997786    3.445920    0.512855    0.036971    0.011860    0.756441    
#> 029: 0.989145    0.982485    3.435055    0.566978    0.040253    0.011267    0.754960    
#> 030: 0.982638    0.991747    3.441159    0.538629    0.040647    0.010703    0.753518    
#> 031: 0.955395    0.961086    3.451511    0.562793    0.038615    0.010168    0.759083    
#> 032: 0.942333    0.966984    3.459037    0.534654    0.036684    0.010491    0.756418    
#> 033: 0.987359    0.970280    3.451379    0.521687    0.034850    0.011656    0.761581    
#> 034: 1.020603    0.968585    3.450285    0.578233    0.034115    0.011074    0.755664    
#> 035: 0.978717    0.952350    3.442345    0.549322    0.034849    0.010520    0.737269    
#> 036: 0.943619    0.964811    3.443299    0.521856    0.033107    0.009994    0.752364    
#> 037: 0.919484    0.967491    3.444927    0.495763    0.032581    0.009494    0.778202    
#> 038: 0.941543    0.977172    3.436619    0.470975    0.033463    0.009949    0.770950    
#> 039: 0.953160    0.971222    3.446450    0.520231    0.033224    0.012639    0.742935    
#> 040: 0.973417    0.985977    3.436579    0.575504    0.037576    0.012007    0.749282    
#> 041: 0.928577    0.973912    3.431858    0.598262    0.035697    0.011407    0.758219    
#> 042: 0.966100    0.971754    3.432200    0.568349    0.038486    0.010837    0.734170    
#> 043: 0.951403    0.986139    3.422993    0.643637    0.036593    0.010701    0.740999    
#> 044: 0.889726    1.005106    3.422408    0.611456    0.035674    0.010166    0.758045    
#> 045: 0.891611    1.004349    3.419057    0.580883    0.042935    0.009658    0.749974    
#> 046: 0.941745    0.974584    3.433853    0.551839    0.040788    0.009175    0.755363    
#> 047: 0.938155    0.969626    3.426900    0.524247    0.038749    0.008716    0.743321    
#> 048: 0.927381    0.964722    3.430235    0.498034    0.037424    0.008281    0.753568    
#> 049: 0.907417    0.964299    3.436367    0.473133    0.046839    0.007867    0.779509    
#> 050: 0.962039    0.961521    3.430241    0.457914    0.048058    0.007473    0.788168    
#> 051: 0.904576    0.981382    3.426925    0.435018    0.045655    0.007100    0.788769    
#> 052: 0.958927    0.986853    3.440282    0.428107    0.043373    0.007361    0.761465    
#> 053: 0.902829    0.971748    3.442958    0.450615    0.041204    0.007917    0.758952    
#> 054: 0.857388    0.969182    3.437808    0.428084    0.039910    0.009330    0.776259    
#> 055: 0.884801    0.975988    3.435544    0.488676    0.037915    0.009985    0.777283    
#> 056: 0.896315    0.979165    3.428965    0.466212    0.038864    0.010161    0.770783    
#> 057: 0.928466    0.970299    3.446582    0.442901    0.043231    0.009950    0.789280    
#> 058: 0.997031    0.954904    3.435399    0.486346    0.041069    0.009452    0.789125    
#> 059: 0.994208    0.926271    3.443669    0.604808    0.039016    0.008980    0.780056    
#> 060: 0.994402    0.915765    3.458086    0.606794    0.037065    0.008967    0.782350    
#> 061: 1.022984    0.932558    3.457647    0.576454    0.035212    0.010379    0.802687    
#> 062: 1.021909    0.960247    3.456811    0.566814    0.033451    0.009860    0.799197    
#> 063: 1.041431    0.942438    3.455542    0.624040    0.037554    0.009367    0.793095    
#> 064: 1.035017    0.952051    3.461166    0.657226    0.040087    0.008898    0.800120    
#> 065: 1.003097    0.941678    3.445948    0.624364    0.041109    0.008453    0.784220    
#> 066: 1.022114    0.953947    3.455031    0.681092    0.039053    0.008031    0.765425    
#> 067: 0.987097    0.957698    3.457281    0.647037    0.042637    0.008726    0.755291    
#> 068: 0.953248    0.957557    3.465294    0.614685    0.040505    0.008765    0.781934    
#> 069: 0.999390    0.965274    3.447909    0.674981    0.038479    0.008837    0.775989    
#> 070: 1.018044    0.945519    3.454354    0.763579    0.036555    0.011740    0.781536    
#> 071: 0.915396    0.994155    3.419275    0.725400    0.034728    0.011153    0.773910    
#> 072: 0.920582    0.967413    3.426606    0.689130    0.032991    0.010595    0.760240    
#> 073: 0.949147    0.987477    3.448613    0.654674    0.032738    0.010065    0.767633    
#> 074: 0.942484    0.979121    3.445164    0.621940    0.033095    0.009562    0.784293    
#> 075: 0.977137    0.981629    3.467059    0.590843    0.031440    0.009084    0.766989    
#> 076: 0.961015    0.984490    3.459119    0.561301    0.030635    0.008630    0.780957    
#> 077: 0.980066    0.955658    3.449548    0.533236    0.041438    0.008198    0.766955    
#> 078: 0.964403    0.952166    3.455681    0.506574    0.039367    0.007788    0.764729    
#> 079: 0.992935    0.967337    3.462222    0.481245    0.037398    0.008325    0.805513    
#> 080: 1.005323    0.952907    3.460148    0.570194    0.035528    0.008390    0.810894    
#> 081: 1.049170    0.954899    3.454814    0.581275    0.039283    0.007971    0.787451    
#> 082: 1.015398    0.941354    3.457941    0.577117    0.037319    0.007572    0.779226    
#> 083: 0.945588    0.957918    3.456429    0.548261    0.040561    0.007194    0.779023    
#> 084: 1.001222    0.963524    3.450864    0.526677    0.045548    0.006834    0.754948    
#> 085: 0.961408    0.952485    3.460558    0.500343    0.043271    0.008312    0.771911    
#> 086: 0.952823    0.939170    3.451404    0.475326    0.041107    0.007896    0.776795    
#> 087: 0.926594    0.952940    3.444999    0.451560    0.041034    0.007952    0.765545    
#> 088: 0.897833    0.940643    3.453793    0.430305    0.043562    0.009056    0.762657    
#> 089: 0.959300    0.949994    3.439176    0.490368    0.047438    0.008603    0.768669    
#> 090: 0.931543    0.948141    3.437157    0.550309    0.045066    0.009064    0.755336    
#> 091: 0.921857    0.953680    3.425843    0.522794    0.046225    0.010058    0.744559    
#> 092: 0.904762    0.956075    3.425895    0.557233    0.043914    0.011453    0.746944    
#> 093: 0.865193    0.973401    3.423155    0.529371    0.041718    0.010881    0.757150    
#> 094: 0.881502    0.989394    3.421670    0.502902    0.039632    0.010337    0.752338    
#> 095: 0.874599    0.978220    3.435401    0.477757    0.037651    0.012258    0.763758    
#> 096: 0.889534    0.967408    3.433163    0.454113    0.035768    0.012530    0.761506    
#> 097: 0.972510    0.983765    3.432635    0.565086    0.038532    0.012200    0.735363    
#> 098: 0.930341    0.999146    3.441770    0.536832    0.036605    0.013501    0.755599    
#> 099: 0.968515    0.968713    3.431877    0.536115    0.034775    0.012937    0.764396    
#> 100: 0.980267    0.971291    3.443151    0.575067    0.033036    0.013414    0.739148    
#> 101: 0.929629    0.964412    3.430893    0.546313    0.031385    0.012744    0.735442    
#> 102: 0.894741    0.955761    3.425166    0.518998    0.029815    0.013717    0.750553    
#> 103: 0.937557    0.964249    3.436097    0.515031    0.037521    0.013031    0.738739    
#> 104: 0.983617    0.955538    3.446894    0.640935    0.035645    0.012379    0.771744    
#> 105: 0.981220    0.972229    3.440370    0.623931    0.033862    0.011760    0.777128    
#> 106: 0.998716    0.977931    3.444295    0.649925    0.032841    0.011172    0.765386    
#> 107: 1.020821    0.977266    3.445003    0.719974    0.031199    0.010682    0.760255    
#> 108: 0.941659    0.977903    3.430917    0.683975    0.037339    0.011275    0.765363    
#> 109: 1.009473    0.975718    3.448072    0.649776    0.036439    0.011283    0.762092    
#> 110: 0.980241    0.963432    3.426752    0.635925    0.034618    0.011952    0.752664    
#> 111: 0.954588    0.978469    3.430478    0.604129    0.034409    0.011993    0.736853    
#> 112: 0.925469    0.944579    3.432739    0.573922    0.036425    0.012280    0.747605    
#> 113: 0.920446    0.962790    3.434380    0.545226    0.036788    0.011704    0.748060    
#> 114: 0.949103    0.975922    3.439144    0.558439    0.040550    0.012092    0.748446    
#> 115: 1.006314    0.933502    3.441572    0.593214    0.038523    0.011488    0.750743    
#> 116: 0.966553    0.958306    3.439089    0.610682    0.036597    0.010913    0.761811    
#> 117: 0.976723    0.971458    3.442667    0.617890    0.035162    0.010368    0.747645    
#> 118: 0.956016    0.968991    3.438234    0.586996    0.043899    0.009849    0.754773    
#> 119: 0.965407    0.975221    3.436521    0.587184    0.043780    0.011242    0.760994    
#> 120: 0.943904    0.960414    3.431618    0.559380    0.041591    0.010941    0.755511    
#> 121: 0.921159    0.992923    3.426351    0.548367    0.039512    0.010394    0.753170    
#> 122: 0.905372    0.952413    3.442113    0.520948    0.037536    0.009874    0.761195    
#> 123: 0.995367    0.977766    3.449697    0.494901    0.035659    0.009380    0.752090    
#> 124: 0.971754    0.995781    3.444658    0.470156    0.037768    0.009282    0.761826    
#> 125: 1.018789    0.973618    3.445422    0.509960    0.038568    0.008818    0.764482    
#> 126: 0.969136    0.990380    3.432537    0.530273    0.047975    0.008377    0.759876    
#> 127: 0.996642    0.975765    3.428092    0.702874    0.047529    0.007959    0.766073    
#> 128: 0.974670    0.971358    3.434597    0.667730    0.046633    0.007561    0.753916    
#> 129: 0.983721    0.984336    3.438619    0.645247    0.050806    0.007183    0.747565    
#> 130: 0.978488    0.998522    3.440958    0.612984    0.048265    0.006823    0.759745    
#> 131: 0.958408    0.981465    3.424229    0.582335    0.045852    0.007484    0.765764    
#> 132: 0.893388    0.987769    3.419785    0.553218    0.043560    0.007448    0.772654    
#> 133: 0.980492    0.970085    3.424373    0.700097    0.041382    0.007075    0.780130    
#> 134: 0.988459    0.959198    3.431841    0.715350    0.039313    0.010990    0.769607    
#> 135: 0.950122    0.977174    3.429060    0.679583    0.037347    0.010728    0.765971    
#> 136: 0.996264    0.964173    3.437772    0.726091    0.035480    0.010192    0.755219    
#> 137: 0.977130    0.962911    3.440289    0.689786    0.033706    0.009682    0.754930    
#> 138: 0.979959    0.948921    3.449030    0.655297    0.037450    0.009198    0.748882    
#> 139: 0.946305    0.973910    3.440368    0.622532    0.038850    0.012002    0.758567    
#> 140: 0.965767    0.985951    3.438383    0.653523    0.036908    0.012879    0.770634    
#> 141: 0.955825    0.966946    3.450983    0.620846    0.037315    0.012235    0.774467    
#> 142: 0.951707    0.953830    3.448872    0.589804    0.039712    0.011623    0.783044    
#> 143: 0.895796    0.966941    3.447725    0.560314    0.043528    0.011042    0.758695    
#> 144: 0.986550    0.969284    3.458206    0.543304    0.041352    0.010490    0.749531    
#> 145: 0.986460    0.981584    3.442655    0.536318    0.039284    0.010214    0.739715    
#> 146: 0.917674    0.966393    3.449778    0.509503    0.037320    0.012538    0.770827    
#> 147: 0.899338    0.960334    3.438261    0.484027    0.035454    0.012457    0.745498    
#> 148: 0.927385    0.973815    3.451416    0.544886    0.042939    0.011834    0.754280    
#> 149: 0.966279    0.959869    3.456012    0.517642    0.040792    0.011242    0.753202    
#> 150: 0.941531    0.957271    3.437147    0.491760    0.043166    0.010680    0.787888    
#> 151: 0.876724    0.982986    3.434261    0.467172    0.044517    0.010146    0.773004    
#> 152: 0.933933    0.987874    3.432990    0.545410    0.044093    0.009282    0.772963    
#> 153: 0.988505    0.986162    3.447132    0.546347    0.044515    0.010626    0.771065    
#> 154: 1.023914    0.996331    3.459621    0.541359    0.036646    0.009752    0.787667    
#> 155: 0.951364    0.967246    3.450429    0.431311    0.036037    0.009545    0.763783    
#> 156: 0.928958    0.966906    3.446226    0.403333    0.034881    0.008938    0.781067    
#> 157: 0.968157    0.956490    3.462143    0.471670    0.028496    0.008633    0.764882    
#> 158: 0.972083    0.979669    3.451651    0.477065    0.029232    0.008218    0.779471    
#> 159: 0.901175    0.979232    3.453547    0.438736    0.027566    0.008098    0.770213    
#> 160: 0.983241    0.944915    3.455915    0.540350    0.022222    0.009761    0.778092    
#> 161: 0.965769    0.937349    3.448602    0.528700    0.022239    0.010306    0.773922    
#> 162: 0.961040    0.960546    3.437287    0.552450    0.023737    0.010997    0.765897    
#> 163: 0.998365    0.952456    3.444495    0.636109    0.026079    0.012547    0.785869    
#> 164: 1.006903    0.959510    3.438888    0.731850    0.021438    0.012068    0.777595    
#> 165: 0.988261    0.963622    3.440509    0.610936    0.025521    0.010692    0.761625    
#> 166: 1.021435    0.985689    3.435753    0.742240    0.021681    0.009574    0.761790    
#> 167: 1.016373    0.992983    3.442826    0.772220    0.023846    0.010000    0.762592    
#> 168: 1.018702    1.003954    3.451973    0.642763    0.024609    0.012247    0.749262    
#> 169: 1.002100    1.004570    3.433185    0.661379    0.025503    0.012811    0.771460    
#> 170: 1.053696    0.979420    3.437519    0.844886    0.024487    0.012605    0.765612    
#> 171: 0.994395    0.982860    3.433549    0.726530    0.024614    0.012175    0.748678    
#> 172: 0.948236    0.981273    3.443099    0.564590    0.029919    0.011624    0.754847    
#> 173: 0.953848    0.975358    3.432148    0.540218    0.020860    0.012950    0.756623    
#> 174: 1.001327    0.967187    3.445729    0.706094    0.024449    0.010885    0.772314    
#> 175: 0.982974    0.977641    3.438092    0.618816    0.024043    0.009952    0.780906    
#> 176: 0.994300    0.992067    3.441534    0.625056    0.026378    0.009046    0.763478    
#> 177: 1.027439    0.981865    3.455322    0.609250    0.022868    0.008926    0.776991    
#> 178: 1.006367    0.969893    3.459048    0.541788    0.029099    0.007710    0.783391    
#> 179: 1.068675    0.969726    3.458990    0.626075    0.028873    0.008491    0.782752    
#> 180: 1.034557    0.976096    3.452043    0.676541    0.030964    0.010434    0.743164    
#> 181: 0.992020    0.928537    3.436767    0.562768    0.029108    0.011202    0.753718    
#> 182: 0.957550    0.946461    3.433229    0.564774    0.035100    0.010735    0.773758    
#> 183: 0.951098    0.977846    3.434712    0.524814    0.031619    0.012307    0.743447    
#> 184: 0.923449    0.968316    3.431014    0.578387    0.032449    0.011374    0.735833    
#> 185: 0.930045    0.985124    3.430593    0.558558    0.043786    0.011571    0.738889    
#> 186: 0.927922    1.014645    3.432061    0.550882    0.053456    0.009301    0.752646    
#> 187: 0.961220    0.980401    3.434283    0.661414    0.043753    0.007924    0.740811    
#> 188: 0.928489    1.005382    3.432414    0.514633    0.047941    0.008982    0.750799    
#> 189: 0.967783    1.004083    3.443798    0.586669    0.057313    0.008453    0.772000    
#> 190: 1.006394    0.984721    3.448236    0.734987    0.046852    0.009198    0.748920    
#> 191: 0.946122    0.998685    3.431850    0.453293    0.038274    0.007840    0.749330    
#> 192: 0.938162    0.986002    3.432052    0.487781    0.042056    0.008663    0.748183    
#> 193: 0.986619    1.000317    3.436615    0.518445    0.044388    0.006989    0.741323    
#> 194: 0.964153    0.986748    3.427027    0.579696    0.039799    0.007612    0.763226    
#> 195: 0.893907    0.986706    3.425322    0.532927    0.037788    0.006827    0.789605    
#> 196: 0.890519    0.993437    3.429257    0.531787    0.034833    0.008135    0.811397    
#> 197: 0.853688    1.007357    3.441543    0.379997    0.031178    0.007293    0.808225    
#> 198: 0.870265    0.985667    3.432703    0.375202    0.031187    0.008092    0.780309    
#> 199: 0.895013    0.966246    3.438897    0.438344    0.029781    0.006434    0.768845    
#> 200: 0.935315    0.979081    3.437314    0.472108    0.028872    0.006231    0.794510    
#> 201: 0.926989    0.971033    3.442302    0.448573    0.029149    0.006650    0.786886    
#> 202: 0.921552    0.969844    3.442001    0.436470    0.029839    0.006498    0.789458    
#> 203: 0.920844    0.969536    3.440967    0.420852    0.031933    0.006394    0.788671    
#> 204: 0.929980    0.964043    3.442431    0.435302    0.033502    0.006527    0.787882    
#> 205: 0.928216    0.963634    3.442665    0.429187    0.034316    0.006393    0.787337    
#> 206: 0.925203    0.965118    3.443290    0.427381    0.033530    0.006270    0.790715    
#> 207: 0.922711    0.965373    3.443322    0.430072    0.033283    0.006391    0.791370    
#> 208: 0.922819    0.965749    3.444088    0.426602    0.032349    0.006542    0.791245    
#> 209: 0.925039    0.963639    3.444391    0.425051    0.032339    0.006506    0.789519    
#> 210: 0.928716    0.962858    3.445501    0.424630    0.032511    0.006526    0.787872    
#> 211: 0.930727    0.964256    3.445972    0.418709    0.033118    0.006496    0.786633    
#> 212: 0.936470    0.964066    3.446099    0.421305    0.033571    0.006483    0.785268    
#> 213: 0.939869    0.961828    3.446281    0.427647    0.033895    0.006623    0.785284    
#> 214: 0.946358    0.960994    3.446616    0.435331    0.033978    0.006887    0.784943    
#> 215: 0.949173    0.960635    3.446778    0.444205    0.034128    0.007214    0.783068    
#> 216: 0.950715    0.959513    3.446342    0.447946    0.034133    0.007290    0.784913    
#> 217: 0.948285    0.960319    3.445644    0.448167    0.034274    0.007313    0.784306    
#> 218: 0.949996    0.962073    3.444546    0.453603    0.034424    0.007384    0.784203    
#> 219: 0.949396    0.962607    3.443023    0.461994    0.034731    0.007463    0.783658    
#> 220: 0.947225    0.963364    3.442612    0.468187    0.035157    0.007536    0.782943    
#> 221: 0.947635    0.964242    3.441934    0.476132    0.035067    0.007497    0.781593    
#> 222: 0.950240    0.964119    3.441640    0.483038    0.034574    0.007526    0.780888    
#> 223: 0.949939    0.963996    3.441727    0.483239    0.034465    0.007596    0.779463    
#> 224: 0.951702    0.963718    3.442124    0.482592    0.034332    0.007595    0.779079    
#> 225: 0.951171    0.962444    3.442317    0.482918    0.034596    0.007589    0.778572    
#> 226: 0.951668    0.961839    3.442098    0.485052    0.034443    0.007579    0.777865    
#> 227: 0.951301    0.961776    3.442313    0.482999    0.034418    0.007566    0.777670    
#> 228: 0.951104    0.963001    3.441917    0.485839    0.034288    0.007611    0.777592    
#> 229: 0.950202    0.962997    3.441632    0.485451    0.034098    0.007639    0.777268    
#> 230: 0.951883    0.962728    3.441347    0.487112    0.034029    0.007617    0.777818    
#> 231: 0.952296    0.963493    3.441468    0.489216    0.034391    0.007582    0.777643    
#> 232: 0.950612    0.963091    3.441689    0.485853    0.034718    0.007611    0.777689    
#> 233: 0.950664    0.962014    3.442150    0.485359    0.035200    0.007607    0.777607    
#> 234: 0.950304    0.961962    3.442373    0.486577    0.035440    0.007572    0.777230    
#> 235: 0.949328    0.961527    3.442212    0.485996    0.035768    0.007508    0.777447    
#> 236: 0.948398    0.961399    3.442232    0.483680    0.035934    0.007462    0.777570    
#> 237: 0.948857    0.961323    3.442159    0.481971    0.035913    0.007424    0.778530    
#> 238: 0.948189    0.961743    3.442126    0.479230    0.035931    0.007410    0.779361    
#> 239: 0.947447    0.962648    3.441947    0.477548    0.035808    0.007377    0.779541    
#> 240: 0.947428    0.963109    3.442024    0.478258    0.035814    0.007346    0.779274    
#> 241: 0.946632    0.963339    3.442140    0.476145    0.035958    0.007335    0.779207    
#> 242: 0.945746    0.963438    3.441940    0.475148    0.036095    0.007334    0.779710    
#> 243: 0.944933    0.963870    3.441998    0.473812    0.036178    0.007326    0.779884    
#> 244: 0.944362    0.963878    3.441968    0.473391    0.036123    0.007324    0.780517    
#> 245: 0.944483    0.963657    3.441870    0.474848    0.036166    0.007300    0.781160    
#> 246: 0.945236    0.963592    3.441956    0.475192    0.036182    0.007291    0.781091    
#> 247: 0.945465    0.963331    3.442242    0.473401    0.036139    0.007306    0.780777    
#> 248: 0.945872    0.963665    3.442297    0.473226    0.036207    0.007304    0.779980    
#> 249: 0.945809    0.963875    3.442218    0.475043    0.036293    0.007295    0.779833    
#> 250: 0.945812    0.964315    3.442051    0.474879    0.036263    0.007290    0.779947    
#> 251: 0.945867    0.964964    3.442044    0.475156    0.036310    0.007263    0.779795    
#> 252: 0.945908    0.965352    3.442125    0.474278    0.036300    0.007247    0.779633    
#> 253: 0.945305    0.965609    3.441922    0.474707    0.036251    0.007263    0.779252    
#> 254: 0.945934    0.966235    3.441900    0.474794    0.036129    0.007293    0.779274    
#> 255: 0.945303    0.966648    3.442017    0.474217    0.036100    0.007348    0.779396    
#> 256: 0.944967    0.966647    3.442018    0.473080    0.036127    0.007354    0.779460    
#> 257: 0.944349    0.966280    3.442064    0.472274    0.036059    0.007360    0.779541    
#> 258: 0.942792    0.965874    3.442032    0.469944    0.036004    0.007341    0.779388    
#> 259: 0.942088    0.965829    3.441924    0.470072    0.036160    0.007341    0.778947    
#> 260: 0.942353    0.965991    3.441947    0.472032    0.036363    0.007318    0.778710    
#> 261: 0.942790    0.966013    3.442040    0.472318    0.036400    0.007311    0.778716    
#> 262: 0.942719    0.966329    3.442073    0.471263    0.036526    0.007322    0.778624    
#> 263: 0.942062    0.966739    3.442009    0.471462    0.036675    0.007338    0.778449    
#> 264: 0.942127    0.966792    3.441924    0.472943    0.036955    0.007338    0.778130    
#> 265: 0.941900    0.967277    3.441851    0.472146    0.037289    0.007351    0.778143    
#> 266: 0.941840    0.967825    3.441764    0.471554    0.037523    0.007359    0.778473    
#> 267: 0.941513    0.968059    3.441764    0.470931    0.037570    0.007354    0.778733    
#> 268: 0.941749    0.967861    3.441757    0.470696    0.037723    0.007365    0.778548    
#> 269: 0.942367    0.967427    3.441776    0.470483    0.037739    0.007381    0.778766    
#> 270: 0.942824    0.967194    3.441691    0.470086    0.037689    0.007385    0.778812    
#> 271: 0.943599    0.966990    3.441749    0.470881    0.037644    0.007387    0.778635    
#> 272: 0.943939    0.966772    3.441703    0.472363    0.037611    0.007377    0.778629    
#> 273: 0.943163    0.967014    3.441639    0.471714    0.037655    0.007387    0.778515    
#> 274: 0.942395    0.967296    3.441603    0.471500    0.037796    0.007381    0.778373    
#> 275: 0.941246    0.967561    3.441470    0.470943    0.037933    0.007383    0.778182    
#> 276: 0.940702    0.967800    3.441536    0.470644    0.037906    0.007380    0.778167    
#> 277: 0.940276    0.968108    3.441622    0.470720    0.037914    0.007375    0.777964    
#> 278: 0.940148    0.968244    3.441656    0.471085    0.038044    0.007370    0.777639    
#> 279: 0.940180    0.968231    3.441617    0.471464    0.038180    0.007365    0.777639    
#> 280: 0.940008    0.968561    3.441568    0.471074    0.038326    0.007346    0.777520    
#> 281: 0.939656    0.968796    3.441618    0.470279    0.038526    0.007325    0.777765    
#> 282: 0.939092    0.969049    3.441585    0.469344    0.038550    0.007328    0.777898    
#> 283: 0.939252    0.969093    3.441644    0.470421    0.038546    0.007323    0.778177    
#> 284: 0.939382    0.969005    3.441641    0.471307    0.038505    0.007316    0.777979    
#> 285: 0.939262    0.969230    3.441493    0.471110    0.038543    0.007326    0.778035    
#> 286: 0.939509    0.969377    3.441508    0.471075    0.038579    0.007324    0.777880    
#> 287: 0.939009    0.969607    3.441396    0.471536    0.038587    0.007340    0.777877    
#> 288: 0.939642    0.969620    3.441334    0.472525    0.038543    0.007354    0.777847    
#> 289: 0.940239    0.969589    3.441316    0.472677    0.038494    0.007358    0.777869    
#> 290: 0.940591    0.969563    3.441347    0.473203    0.038461    0.007363    0.777992    
#> 291: 0.940768    0.969722    3.441368    0.473618    0.038358    0.007383    0.777910    
#> 292: 0.940914    0.969770    3.441431    0.474302    0.038244    0.007395    0.777903    
#> 293: 0.940852    0.969995    3.441353    0.474595    0.038152    0.007412    0.777797    
#> 294: 0.940854    0.970174    3.441255    0.475164    0.038135    0.007412    0.777635    
#> 295: 0.940530    0.969974    3.441210    0.475357    0.038130    0.007425    0.777298    
#> 296: 0.940826    0.969886    3.441262    0.476224    0.038139    0.007458    0.777280    
#> 297: 0.941072    0.970029    3.441250    0.477048    0.038135    0.007464    0.777352    
#> 298: 0.941621    0.969984    3.441226    0.478894    0.038127    0.007461    0.777263    
#> 299: 0.942067    0.970148    3.441205    0.479367    0.038126    0.007450    0.777182    
#> 300: 0.942292    0.970014    3.441253    0.479805    0.038126    0.007455    0.776967    
#> 301: 0.942827    0.969818    3.441211    0.480115    0.038159    0.007464    0.776946    
#> 302: 0.943181    0.969800    3.441222    0.480361    0.038165    0.007463    0.776940    
#> 303: 0.943030    0.969881    3.441157    0.480210    0.038114    0.007463    0.776689    
#> 304: 0.943090    0.969993    3.441044    0.480447    0.038118    0.007460    0.776529    
#> 305: 0.942738    0.969890    3.441002    0.480529    0.038085    0.007463    0.776366    
#> 306: 0.942378    0.969813    3.440847    0.480598    0.038093    0.007467    0.776219    
#> 307: 0.941782    0.969738    3.440754    0.480027    0.038153    0.007466    0.776219    
#> 308: 0.941538    0.969733    3.440677    0.479881    0.038207    0.007464    0.776181    
#> 309: 0.941570    0.969507    3.440689    0.479433    0.038263    0.007483    0.776077    
#> 310: 0.942201    0.969427    3.440570    0.480262    0.038275    0.007478    0.776156    
#> 311: 0.942356    0.969539    3.440558    0.480378    0.038277    0.007486    0.776007    
#> 312: 0.941836    0.969578    3.440454    0.479967    0.038264    0.007482    0.776212    
#> 313: 0.941550    0.969484    3.440341    0.480002    0.038280    0.007478    0.776449    
#> 314: 0.940942    0.969552    3.440216    0.479285    0.038256    0.007484    0.776479    
#> 315: 0.940987    0.969447    3.440223    0.479683    0.038232    0.007488    0.776548    
#> 316: 0.941303    0.969329    3.440276    0.480229    0.038155    0.007487    0.776602    
#> 317: 0.941566    0.969231    3.440350    0.480340    0.038076    0.007488    0.776677    
#> 318: 0.941940    0.969126    3.440304    0.480767    0.038031    0.007496    0.776504    
#> 319: 0.941884    0.969081    3.440310    0.480540    0.037982    0.007489    0.776552    
#> 320: 0.941306    0.969147    3.440213    0.480239    0.037863    0.007484    0.776829    
#> 321: 0.940916    0.969286    3.440085    0.479426    0.037799    0.007481    0.777143    
#> 322: 0.940858    0.969338    3.439992    0.479384    0.037749    0.007473    0.777186    
#> 323: 0.940367    0.969316    3.439886    0.479006    0.037690    0.007457    0.777268    
#> 324: 0.940153    0.969432    3.439872    0.478720    0.037734    0.007443    0.777259    
#> 325: 0.940095    0.969563    3.439768    0.478292    0.037782    0.007433    0.777174    
#> 326: 0.939934    0.969360    3.439723    0.478065    0.037859    0.007425    0.776954    
#> 327: 0.939900    0.969387    3.439750    0.477793    0.037939    0.007418    0.776875    
#> 328: 0.940243    0.969356    3.439755    0.477893    0.037941    0.007404    0.776744    
#> 329: 0.940723    0.969322    3.439769    0.478159    0.037916    0.007388    0.776653    
#> 330: 0.940517    0.969322    3.439825    0.477579    0.037963    0.007387    0.776734    
#> 331: 0.940653    0.969458    3.439886    0.477194    0.038045    0.007388    0.776717    
#> 332: 0.940603    0.969402    3.439938    0.476641    0.038058    0.007382    0.776684    
#> 333: 0.940474    0.969397    3.439907    0.476521    0.038112    0.007392    0.776572    
#> 334: 0.940215    0.969356    3.439781    0.476353    0.038168    0.007397    0.776400    
#> 335: 0.939781    0.969513    3.439616    0.475566    0.038285    0.007384    0.776352    
#> 336: 0.939694    0.969661    3.439546    0.475442    0.038397    0.007371    0.776370    
#> 337: 0.939356    0.969898    3.439426    0.475477    0.038513    0.007359    0.776256    
#> 338: 0.939440    0.970045    3.439449    0.475610    0.038571    0.007341    0.776303    
#> 339: 0.939176    0.970127    3.439395    0.476122    0.038622    0.007337    0.776274    
#> 340: 0.938720    0.969960    3.439374    0.476384    0.038616    0.007335    0.776274    
#> 341: 0.938900    0.969877    3.439429    0.476563    0.038557    0.007328    0.776414    
#> 342: 0.938561    0.969726    3.439424    0.475857    0.038533    0.007319    0.776420    
#> 343: 0.938430    0.969801    3.439439    0.475716    0.038532    0.007332    0.776268    
#> 344: 0.938447    0.969784    3.439438    0.475832    0.038521    0.007334    0.776238    
#> 345: 0.938483    0.969808    3.439460    0.475773    0.038498    0.007325    0.776311    
#> 346: 0.938555    0.969866    3.439455    0.475690    0.038507    0.007327    0.776328    
#> 347: 0.938760    0.969650    3.439429    0.475624    0.038451    0.007329    0.776483    
#> 348: 0.938889    0.969672    3.439401    0.475995    0.038409    0.007331    0.776436    
#> 349: 0.939043    0.969650    3.439355    0.476476    0.038386    0.007332    0.776454    
#> 350: 0.938964    0.969640    3.439303    0.476687    0.038348    0.007344    0.776588    
#> 351: 0.938928    0.969822    3.439232    0.476549    0.038309    0.007342    0.776674    
#> 352: 0.938440    0.969906    3.439211    0.476216    0.038259    0.007339    0.776836    
#> 353: 0.938453    0.970189    3.439204    0.475741    0.038280    0.007341    0.776817    
#> 354: 0.938189    0.970258    3.439112    0.475070    0.038262    0.007329    0.776768    
#> 355: 0.938686    0.970151    3.439115    0.475303    0.038244    0.007322    0.776677    
#> 356: 0.938475    0.970099    3.439147    0.474998    0.038218    0.007320    0.776867    
#> 357: 0.938494    0.970190    3.439098    0.475673    0.038182    0.007313    0.776788    
#> 358: 0.938558    0.970266    3.439113    0.475763    0.038146    0.007307    0.776628    
#> 359: 0.938260    0.970500    3.439050    0.475651    0.038163    0.007311    0.776503    
#> 360: 0.937958    0.970613    3.438908    0.474987    0.038101    0.007313    0.776487    
#> 361: 0.937924    0.970725    3.438765    0.475260    0.038129    0.007321    0.776253    
#> 362: 0.937906    0.970813    3.438725    0.475762    0.038140    0.007329    0.776010    
#> 363: 0.937720    0.970791    3.438706    0.475533    0.038136    0.007331    0.775854    
#> 364: 0.937780    0.970842    3.438736    0.475240    0.038102    0.007343    0.775764    
#> 365: 0.937823    0.970868    3.438783    0.475180    0.038094    0.007362    0.775705    
#> 366: 0.937817    0.970883    3.438803    0.475194    0.038040    0.007383    0.775711    
#> 367: 0.938088    0.970865    3.438849    0.475385    0.038035    0.007394    0.775695    
#> 368: 0.938662    0.970853    3.438907    0.476069    0.038011    0.007405    0.775615    
#> 369: 0.938796    0.970842    3.438965    0.476352    0.037978    0.007401    0.775657    
#> 370: 0.938679    0.970943    3.438972    0.476491    0.038046    0.007394    0.775561    
#> 371: 0.938432    0.971006    3.438874    0.476326    0.038075    0.007393    0.775482    
#> 372: 0.938262    0.971075    3.438809    0.476226    0.038088    0.007382    0.775451    
#> 373: 0.938151    0.971179    3.438721    0.476896    0.038117    0.007379    0.775377    
#> 374: 0.938246    0.971227    3.438673    0.478156    0.038175    0.007376    0.775308    
#> 375: 0.938190    0.971205    3.438661    0.478933    0.038253    0.007377    0.775171    
#> 376: 0.937958    0.971250    3.438655    0.478521    0.038290    0.007375    0.775123    
#> 377: 0.937778    0.971310    3.438662    0.478339    0.038269    0.007367    0.775206    
#> 378: 0.937652    0.971326    3.438610    0.477996    0.038248    0.007362    0.775239    
#> 379: 0.937258    0.971207    3.438616    0.477312    0.038264    0.007357    0.775231    
#> 380: 0.936901    0.971215    3.438569    0.476557    0.038234    0.007358    0.775202    
#> 381: 0.936414    0.971249    3.438490    0.476066    0.038227    0.007349    0.775170    
#> 382: 0.936160    0.971166    3.438453    0.475705    0.038218    0.007333    0.775126    
#> 383: 0.936202    0.971146    3.438494    0.475314    0.038218    0.007333    0.775136    
#> 384: 0.935969    0.971092    3.438511    0.474756    0.038216    0.007327    0.775174    
#> 385: 0.935955    0.971085    3.438532    0.474695    0.038207    0.007328    0.775138    
#> 386: 0.936023    0.971264    3.438543    0.474860    0.038236    0.007328    0.775132    
#> 387: 0.936422    0.971298    3.438612    0.475192    0.038186    0.007334    0.775091    
#> 388: 0.936481    0.971371    3.438674    0.475334    0.038218    0.007342    0.775010    
#> 389: 0.936454    0.971308    3.438669    0.475365    0.038285    0.007336    0.774979    
#> 390: 0.936235    0.971362    3.438621    0.475303    0.038296    0.007328    0.775008    
#> 391: 0.936315    0.971372    3.438593    0.475182    0.038327    0.007322    0.774872    
#> 392: 0.936301    0.971420    3.438617    0.475017    0.038360    0.007327    0.774858    
#> 393: 0.936120    0.971398    3.438601    0.474675    0.038397    0.007324    0.774894    
#> 394: 0.936268    0.971413    3.438558    0.474983    0.038413    0.007331    0.774834    
#> 395: 0.936682    0.971536    3.438560    0.475640    0.038429    0.007332    0.774750    
#> 396: 0.937019    0.971592    3.438535    0.476272    0.038436    0.007340    0.774659    
#> 397: 0.936936    0.971632    3.438529    0.475981    0.038472    0.007352    0.774626    
#> 398: 0.937099    0.971589    3.438560    0.475913    0.038453    0.007361    0.774591    
#> 399: 0.937454    0.971637    3.438628    0.476176    0.038428    0.007378    0.774535    
#> 400: 0.937621    0.971740    3.438668    0.476327    0.038418    0.007395    0.774488    
#> 401: 0.937815    0.971789    3.438659    0.476464    0.038344    0.007402    0.774536    
#> 402: 0.937517    0.971878    3.438660    0.475890    0.038292    0.007414    0.774650    
#> 403: 0.937683    0.971928    3.438657    0.476028    0.038294    0.007434    0.774608    
#> 404: 0.937868    0.971989    3.438601    0.476560    0.038319    0.007439    0.774513    
#> 405: 0.937920    0.971949    3.438651    0.477055    0.038379    0.007442    0.774533    
#> 406: 0.938073    0.972011    3.438631    0.477553    0.038445    0.007444    0.774679    
#> 407: 0.938119    0.972061    3.438630    0.477958    0.038448    0.007438    0.774727    
#> 408: 0.938339    0.972107    3.438685    0.478074    0.038452    0.007434    0.774719    
#> 409: 0.938370    0.972106    3.438653    0.478368    0.038447    0.007426    0.774600    
#> 410: 0.938222    0.972186    3.438559    0.478368    0.038434    0.007421    0.774587    
#> 411: 0.937992    0.972041    3.438527    0.478149    0.038451    0.007423    0.774627    
#> 412: 0.937935    0.972002    3.438493    0.478182    0.038423    0.007426    0.774561    
#> 413: 0.937976    0.971992    3.438483    0.478658    0.038421    0.007432    0.774566    
#> 414: 0.937909    0.971957    3.438492    0.478865    0.038433    0.007438    0.774522    
#> 415: 0.938263    0.971830    3.438526    0.479321    0.038424    0.007443    0.774414    
#> 416: 0.938627    0.971831    3.438551    0.480074    0.038402    0.007442    0.774344    
#> 417: 0.938527    0.971735    3.438543    0.480130    0.038378    0.007441    0.774340    
#> 418: 0.938366    0.971699    3.438548    0.479988    0.038343    0.007440    0.774391    
#> 419: 0.938533    0.971789    3.438546    0.480359    0.038338    0.007444    0.774344    
#> 420: 0.938712    0.971852    3.438547    0.480480    0.038327    0.007445    0.774294    
#> 421: 0.938743    0.971892    3.438610    0.480143    0.038321    0.007454    0.774220    
#> 422: 0.938925    0.971804    3.438642    0.479923    0.038293    0.007468    0.774220    
#> 423: 0.939187    0.971674    3.438699    0.479882    0.038258    0.007467    0.774341    
#> 424: 0.939166    0.971647    3.438705    0.479772    0.038249    0.007467    0.774354    
#> 425: 0.939211    0.971749    3.438672    0.480015    0.038295    0.007462    0.774300    
#> 426: 0.939300    0.971843    3.438668    0.480224    0.038316    0.007459    0.774209    
#> 427: 0.939205    0.971881    3.438652    0.479982    0.038319    0.007461    0.774053    
#> 428: 0.939022    0.971962    3.438628    0.479484    0.038288    0.007468    0.774048    
#> 429: 0.939036    0.971976    3.438635    0.478857    0.038234    0.007475    0.774107    
#> 430: 0.938960    0.972024    3.438622    0.478772    0.038221    0.007482    0.774059    
#> 431: 0.938908    0.972015    3.438578    0.478554    0.038201    0.007478    0.774025    
#> 432: 0.938768    0.972123    3.438548    0.478681    0.038212    0.007475    0.773990    
#> 433: 0.938630    0.972203    3.438551    0.478441    0.038237    0.007471    0.773951    
#> 434: 0.938373    0.972077    3.438582    0.478215    0.038228    0.007479    0.773938    
#> 435: 0.938386    0.972032    3.438562    0.478114    0.038209    0.007483    0.773832    
#> 436: 0.938211    0.971994    3.438552    0.477864    0.038196    0.007483    0.773760    
#> 437: 0.938263    0.971957    3.438537    0.477716    0.038174    0.007478    0.773715    
#> 438: 0.938259    0.972125    3.438533    0.477883    0.038183    0.007473    0.773597    
#> 439: 0.938263    0.972183    3.438523    0.477966    0.038175    0.007472    0.773506    
#> 440: 0.938114    0.972277    3.438528    0.477774    0.038147    0.007472    0.773582    
#> 441: 0.938100    0.972248    3.438557    0.477755    0.038128    0.007488    0.773511    
#> 442: 0.937842    0.972268    3.438581    0.477577    0.038095    0.007495    0.773441    
#> 443: 0.937776    0.972325    3.438552    0.477570    0.038100    0.007500    0.773389    
#> 444: 0.937656    0.972394    3.438512    0.477238    0.038092    0.007503    0.773379    
#> 445: 0.937352    0.972454    3.438445    0.476976    0.038092    0.007504    0.773447    
#> 446: 0.937057    0.972517    3.438377    0.476774    0.038103    0.007506    0.773482    
#> 447: 0.936999    0.972527    3.438338    0.476890    0.038127    0.007503    0.773482    
#> 448: 0.936912    0.972530    3.438307    0.477056    0.038161    0.007508    0.773463    
#> 449: 0.936856    0.972573    3.438357    0.477024    0.038202    0.007509    0.773457    
#> 450: 0.936837    0.972541    3.438361    0.477287    0.038188    0.007515    0.773501    
#> 451: 0.937125    0.972581    3.438359    0.477596    0.038153    0.007524    0.773564    
#> 452: 0.937193    0.972624    3.438314    0.477715    0.038109    0.007534    0.773526    
#> 453: 0.937165    0.972671    3.438292    0.477497    0.038104    0.007541    0.773417    
#> 454: 0.937164    0.972718    3.438269    0.477647    0.038087    0.007541    0.773314    
#> 455: 0.937224    0.972714    3.438246    0.477798    0.038077    0.007538    0.773274    
#> 456: 0.937256    0.972709    3.438237    0.477876    0.038079    0.007540    0.773274    
#> 457: 0.937237    0.972660    3.438272    0.477888    0.038024    0.007543    0.773222    
#> 458: 0.937332    0.972696    3.438309    0.478242    0.037987    0.007556    0.773123    
#> 459: 0.937242    0.972805    3.438326    0.478516    0.037970    0.007566    0.773145    
#> 460: 0.937046    0.972870    3.438274    0.478564    0.037973    0.007576    0.773168    
#> 461: 0.936750    0.972957    3.438257    0.478271    0.037967    0.007584    0.773180    
#> 462: 0.936514    0.973089    3.438250    0.478237    0.037933    0.007587    0.773191    
#> 463: 0.936407    0.973191    3.438193    0.478330    0.037916    0.007590    0.773123    
#> 464: 0.936426    0.973298    3.438154    0.478433    0.037922    0.007591    0.773023    
#> 465: 0.936399    0.973226    3.438126    0.478549    0.037925    0.007591    0.772952    
#> 466: 0.936492    0.973231    3.438079    0.478929    0.037887    0.007589    0.772909    
#> 467: 0.936483    0.973244    3.438071    0.479194    0.037827    0.007604    0.772849    
#> 468: 0.936700    0.973221    3.438092    0.479955    0.037796    0.007611    0.772819    
#> 469: 0.936809    0.973309    3.438131    0.480013    0.037834    0.007619    0.772797    
#> 470: 0.936629    0.973333    3.438107    0.479628    0.037847    0.007633    0.772739    
#> 471: 0.936527    0.973325    3.438092    0.479367    0.037845    0.007642    0.772680    
#> 472: 0.936430    0.973364    3.438099    0.479402    0.037848    0.007649    0.772628    
#> 473: 0.936224    0.973393    3.438080    0.479374    0.037807    0.007654    0.772612    
#> 474: 0.936155    0.973382    3.438068    0.479212    0.037824    0.007659    0.772616    
#> 475: 0.936111    0.973518    3.438059    0.478976    0.037846    0.007656    0.772601    
#> 476: 0.935955    0.973489    3.437999    0.478674    0.037865    0.007652    0.772656    
#> 477: 0.935933    0.973505    3.437977    0.478705    0.037901    0.007650    0.772538    
#> 478: 0.935768    0.973464    3.437971    0.478490    0.037915    0.007645    0.772561    
#> 479: 0.935592    0.973541    3.437956    0.478195    0.037960    0.007640    0.772567    
#> 480: 0.935542    0.973577    3.437934    0.478265    0.038003    0.007633    0.772700    
#> 481: 0.935413    0.973568    3.437895    0.477989    0.038027    0.007628    0.772730    
#> 482: 0.935481    0.973631    3.437875    0.477982    0.038017    0.007637    0.772739    
#> 483: 0.935358    0.973651    3.437867    0.477793    0.037985    0.007642    0.772750    
#> 484: 0.935301    0.973559    3.437875    0.477813    0.037970    0.007639    0.772739    
#> 485: 0.935260    0.973654    3.437864    0.477727    0.038013    0.007641    0.772700    
#> 486: 0.935232    0.973767    3.437850    0.477671    0.038035    0.007641    0.772615    
#> 487: 0.935398    0.973800    3.437890    0.477621    0.038038    0.007640    0.772586    
#> 488: 0.935449    0.973727    3.437924    0.477457    0.038032    0.007640    0.772566    
#> 489: 0.935447    0.973637    3.437943    0.477229    0.038009    0.007642    0.772637    
#> 490: 0.935675    0.973637    3.437993    0.477295    0.038016    0.007642    0.772648    
#> 491: 0.935795    0.973660    3.438037    0.477443    0.037997    0.007642    0.772647    
#> 492: 0.935643    0.973621    3.438064    0.477107    0.037992    0.007647    0.772762    
#> 493: 0.935544    0.973578    3.438067    0.477005    0.037997    0.007659    0.772778    
#> 494: 0.935561    0.973638    3.438017    0.476988    0.038000    0.007665    0.772720    
#> 495: 0.935609    0.973655    3.438026    0.476905    0.037982    0.007669    0.772652    
#> 496: 0.935664    0.973717    3.438000    0.476825    0.037982    0.007670    0.772613    
#> 497: 0.935664    0.973692    3.437983    0.476913    0.037963    0.007666    0.772590    
#> 498: 0.935730    0.973688    3.437940    0.477182    0.037975    0.007666    0.772550    
#> 499: 0.935782    0.973768    3.437908    0.477411    0.037955    0.007670    0.772551    
#> 500: 0.935819    0.973785    3.437870    0.477431    0.037971    0.007669    0.772531    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.313780    0.958197    3.438409    0.392401    0.080858    0.016800    1.694605    
#> 002: 0.486901    0.979037    3.446326    0.372781    0.076815    0.015960    1.202897    
#> 003: 0.593889    0.968674    3.445750    0.354142    0.093491    0.015162    0.959151    
#> 004: 0.578225    0.966497    3.435853    0.357476    0.088816    0.014404    0.892630    
#> 005: 0.656539    0.967675    3.435002    0.434635    0.087930    0.013684    0.877124    
#> 006: 0.620705    0.997670    3.430005    0.412903    0.083534    0.013000    0.856755    
#> 007: 0.587209    0.989444    3.430709    0.470478    0.082190    0.012350    0.872391    
#> 008: 0.595742    0.978557    3.424049    0.490700    0.082847    0.011732    0.888387    
#> 009: 0.571789    0.948699    3.415540    0.497181    0.082680    0.011146    0.879043    
#> 010: 0.593395    0.974526    3.408008    0.503342    0.108728    0.010588    0.883248    
#> 011: 0.623478    0.953843    3.421288    0.478175    0.105002    0.010059    0.907169    
#> 012: 0.626385    0.973972    3.414687    0.490419    0.101925    0.009556    0.884849    
#> 013: 0.571731    0.957672    3.410850    0.526724    0.096829    0.009078    0.907564    
#> 014: 0.587081    0.973598    3.417062    0.500388    0.110341    0.008624    0.918472    
#> 015: 0.578345    0.953363    3.436688    0.475368    0.104824    0.008193    0.909067    
#> 016: 0.632424    0.990028    3.431807    0.518631    0.099583    0.007783    0.920270    
#> 017: 0.630717    0.965059    3.439829    0.514445    0.094604    0.009627    0.873424    
#> 018: 0.637291    0.977896    3.426118    0.488723    0.089873    0.010464    0.903028    
#> 019: 0.562455    0.981963    3.419901    0.467784    0.085380    0.009940    0.883158    
#> 020: 0.614747    0.971952    3.424302    0.506910    0.094499    0.009443    0.863066    
#> 021: 0.641233    0.989531    3.430971    0.521069    0.089774    0.008971    0.877718    
#> 022: 0.618831    0.973153    3.440821    0.495015    0.085286    0.008893    0.873010    
#> 023: 0.682398    0.956360    3.447426    0.470264    0.081021    0.008514    0.904769    
#> 024: 0.661239    0.985344    3.442699    0.495700    0.076970    0.009051    0.878602    
#> 025: 0.659207    0.975427    3.437631    0.496995    0.090185    0.008598    0.872619    
#> 026: 0.628913    1.004588    3.419338    0.501221    0.101018    0.008168    0.871952    
#> 027: 0.602839    1.022436    3.419092    0.476160    0.096686    0.007760    0.885248    
#> 028: 0.653564    0.977205    3.430424    0.474510    0.091852    0.007372    0.876322    
#> 029: 0.649378    0.974221    3.419955    0.450785    0.087259    0.007003    0.917088    
#> 030: 0.648616    1.008040    3.424988    0.524179    0.116378    0.006653    0.903622    
#> 031: 0.590068    0.986961    3.426383    0.518108    0.111003    0.006321    0.877237    
#> 032: 0.582405    0.974944    3.430888    0.492203    0.105453    0.006004    0.887064    
#> 033: 0.573727    0.985972    3.420724    0.467593    0.100180    0.005704    0.897324    
#> 034: 0.600547    0.988681    3.421045    0.444213    0.095171    0.005419    0.872255    
#> 035: 0.555755    0.959205    3.421700    0.422002    0.090520    0.005148    0.887673    
#> 036: 0.578333    0.985798    3.414823    0.400902    0.085994    0.004891    0.909248    
#> 037: 0.581824    0.985462    3.419119    0.399006    0.081695    0.004646    0.913059    
#> 038: 0.585062    0.992057    3.410201    0.379056    0.077610    0.004414    0.916716    
#> 039: 0.630664    0.962015    3.424263    0.385113    0.073729    0.004657    0.911547    
#> 040: 0.607184    0.969439    3.430576    0.381591    0.091796    0.005849    0.874889    
#> 041: 0.555544    0.978042    3.424754    0.379917    0.087206    0.005557    0.905565    
#> 042: 0.595186    0.960908    3.421968    0.471978    0.095662    0.005279    0.883625    
#> 043: 0.554420    0.968124    3.413753    0.448379    0.090879    0.005015    0.882829    
#> 044: 0.563469    0.996326    3.414777    0.439079    0.086335    0.004764    0.890163    
#> 045: 0.623405    1.012802    3.411904    0.475241    0.082018    0.004559    0.873916    
#> 046: 0.623698    0.992881    3.423012    0.561246    0.110429    0.004331    0.882611    
#> 047: 0.625998    1.006297    3.417725    0.580603    0.104908    0.004114    0.898370    
#> 048: 0.596739    0.963788    3.409885    0.551573    0.102840    0.003908    0.902840    
#> 049: 0.565965    0.978006    3.421283    0.523994    0.107142    0.003713    0.904370    
#> 050: 0.668746    0.944174    3.424725    0.497794    0.106708    0.003870    0.908152    
#> 051: 0.603289    0.974791    3.422030    0.475252    0.101373    0.004145    0.936085    
#> 052: 0.620526    0.978517    3.424717    0.451489    0.096304    0.003938    0.910893    
#> 053: 0.620368    0.978503    3.428699    0.484198    0.091489    0.004220    0.895876    
#> 054: 0.547514    0.978371    3.426127    0.459988    0.106969    0.004502    0.898090    
#> 055: 0.598970    0.968861    3.429162    0.436989    0.101621    0.004503    0.894934    
#> 056: 0.624218    0.958155    3.432874    0.424193    0.096540    0.004342    0.924263    
#> 057: 0.604155    0.959938    3.435842    0.402984    0.092264    0.004678    0.946773    
#> 058: 0.614152    0.949101    3.427005    0.382834    0.087651    0.004444    0.927529    
#> 059: 0.620746    0.934254    3.426840    0.459391    0.083268    0.004372    0.933642    
#> 060: 0.588941    0.942135    3.437659    0.446440    0.079105    0.004153    0.956418    
#> 061: 0.655464    0.921278    3.449160    0.424118    0.084438    0.006197    0.944297    
#> 062: 0.615566    0.968844    3.454843    0.402912    0.080216    0.005893    0.979159    
#> 063: 0.668804    0.939916    3.448219    0.414536    0.092953    0.006288    0.933091    
#> 064: 0.656774    0.951822    3.453586    0.436552    0.096473    0.005974    0.925659    
#> 065: 0.687112    0.916993    3.449548    0.495072    0.100731    0.006116    0.877582    
#> 066: 0.667279    0.953165    3.449391    0.505954    0.095694    0.006674    0.871840    
#> 067: 0.628687    0.948183    3.442616    0.480656    0.090909    0.008101    0.884864    
#> 068: 0.599718    0.962265    3.446420    0.456623    0.086364    0.008155    0.907320    
#> 069: 0.594043    0.984219    3.432116    0.433792    0.087026    0.008580    0.910543    
#> 070: 0.585683    0.955259    3.443178    0.412103    0.082675    0.008861    0.902216    
#> 071: 0.571034    1.008281    3.418728    0.391497    0.087126    0.008418    0.899605    
#> 072: 0.549867    0.963568    3.424189    0.371923    0.082769    0.009096    0.931668    
#> 073: 0.617443    0.974957    3.433422    0.384364    0.078631    0.008641    0.928882    
#> 074: 0.588348    0.964286    3.436387    0.367703    0.074699    0.008209    0.936800    
#> 075: 0.629633    0.980142    3.448452    0.507524    0.073483    0.007798    0.926703    
#> 076: 0.681571    0.979969    3.458886    0.482147    0.079119    0.007408    0.937889    
#> 077: 0.704532    0.952835    3.447600    0.458040    0.090089    0.007038    0.893987    
#> 078: 0.684789    0.953015    3.456314    0.438620    0.085584    0.006686    0.896730    
#> 079: 0.716814    0.969185    3.471178    0.465063    0.081305    0.008180    0.927336    
#> 080: 0.697497    0.934941    3.461660    0.441810    0.085871    0.007771    0.945444    
#> 081: 0.672475    0.947399    3.462644    0.419719    0.090113    0.007456    0.907490    
#> 082: 0.652778    0.943844    3.467434    0.398733    0.085945    0.009599    0.914867    
#> 083: 0.631463    0.979141    3.455525    0.451217    0.097750    0.009119    0.882969    
#> 084: 0.646669    0.974615    3.444315    0.428657    0.092862    0.008663    0.893919    
#> 085: 0.621123    0.970990    3.448937    0.407224    0.088219    0.008230    0.903552    
#> 086: 0.626898    0.966817    3.446467    0.386863    0.083808    0.007818    0.894351    
#> 087: 0.605264    0.967584    3.435189    0.367519    0.094720    0.007656    0.903880    
#> 088: 0.503027    0.986688    3.427184    0.349143    0.093438    0.009616    0.912073    
#> 089: 0.566669    0.986537    3.411627    0.331686    0.088766    0.009135    0.921524    
#> 090: 0.535830    0.982738    3.412048    0.315102    0.084328    0.008678    0.928901    
#> 091: 0.546918    0.976830    3.401694    0.299347    0.080111    0.008346    0.908004    
#> 092: 0.536555    1.000312    3.411479    0.293808    0.085213    0.008374    0.918624    
#> 093: 0.562707    0.990345    3.415815    0.372572    0.085237    0.008063    0.889693    
#> 094: 0.583463    1.005812    3.408151    0.395448    0.080975    0.007660    0.909195    
#> 095: 0.614779    1.019003    3.426306    0.416137    0.090146    0.007277    0.896705    
#> 096: 0.570673    0.996175    3.425175    0.442009    0.085639    0.006913    0.901167    
#> 097: 0.644580    0.995147    3.427451    0.477523    0.082791    0.006810    0.873258    
#> 098: 0.625327    0.986132    3.436708    0.453647    0.078651    0.006865    0.888818    
#> 099: 0.584449    0.966875    3.426898    0.430965    0.074719    0.006521    0.890769    
#> 100: 0.604916    0.966495    3.425009    0.475902    0.070983    0.006750    0.857276    
#> 101: 0.526394    0.972256    3.411197    0.452107    0.068346    0.007368    0.880922    
#> 102: 0.568822    0.965703    3.405336    0.429502    0.077795    0.007681    0.879119    
#> 103: 0.627590    0.967760    3.422117    0.408027    0.080298    0.007297    0.875502    
#> 104: 0.584757    0.990137    3.427005    0.419726    0.076283    0.006933    0.889150    
#> 105: 0.600419    0.973920    3.420765    0.398740    0.085586    0.006586    0.914337    
#> 106: 0.635836    0.966179    3.419570    0.430105    0.081306    0.006257    0.900795    
#> 107: 0.645629    1.006375    3.428220    0.458367    0.077241    0.005944    0.933901    
#> 108: 0.612495    0.978174    3.422290    0.435448    0.089921    0.005647    0.926706    
#> 109: 0.582165    0.955783    3.437226    0.413676    0.085425    0.005364    0.933599    
#> 110: 0.579436    0.955204    3.424345    0.392992    0.085164    0.005096    0.910474    
#> 111: 0.606888    0.975084    3.430559    0.388625    0.085407    0.004841    0.899056    
#> 112: 0.567039    0.960742    3.424767    0.369194    0.093885    0.004599    0.893526    
#> 113: 0.563933    0.985510    3.419107    0.410635    0.089191    0.004369    0.895205    
#> 114: 0.588901    0.998659    3.419022    0.425014    0.105079    0.004151    0.887090    
#> 115: 0.603125    0.981407    3.415331    0.534058    0.101444    0.003943    0.901902    
#> 116: 0.636759    0.991432    3.418024    0.569677    0.096372    0.003746    0.917264    
#> 117: 0.641179    1.024642    3.416811    0.582726    0.117484    0.003559    0.893150    
#> 118: 0.666741    0.990642    3.421501    0.573778    0.123564    0.003381    0.895036    
#> 119: 0.647288    0.992289    3.426749    0.545089    0.117386    0.003989    0.917611    
#> 120: 0.562268    0.974512    3.428910    0.517835    0.111517    0.004471    0.879153    
#> 121: 0.637252    1.004564    3.425564    0.491943    0.107079    0.004248    0.869379    
#> 122: 0.585447    0.984064    3.429022    0.467346    0.101725    0.004051    0.885864    
#> 123: 0.626263    0.996209    3.433204    0.443978    0.096639    0.004245    0.906369    
#> 124: 0.631914    1.026923    3.429510    0.421779    0.091807    0.005566    0.883596    
#> 125: 0.633562    1.013412    3.421434    0.449461    0.095686    0.005288    0.862218    
#> 126: 0.585964    1.017987    3.405420    0.501484    0.090901    0.005024    0.870766    
#> 127: 0.612635    0.986870    3.405817    0.568647    0.098707    0.004773    0.883550    
#> 128: 0.549870    0.990452    3.412780    0.542116    0.093772    0.004664    0.900234    
#> 129: 0.634939    0.995596    3.422736    0.515010    0.104854    0.004431    0.919471    
#> 130: 0.651609    1.009093    3.428393    0.489259    0.099612    0.004209    0.906444    
#> 131: 0.631328    0.973910    3.423560    0.464796    0.094631    0.005092    0.900414    
#> 132: 0.589073    0.970957    3.410792    0.494507    0.103094    0.004858    0.891373    
#> 133: 0.598337    0.966798    3.414278    0.472149    0.097939    0.004615    0.897417    
#> 134: 0.618456    0.947242    3.421238    0.453647    0.093042    0.004385    0.913199    
#> 135: 0.575453    0.974429    3.426002    0.430964    0.088390    0.004165    0.920131    
#> 136: 0.621148    0.972612    3.430116    0.409416    0.083971    0.004085    0.915255    
#> 137: 0.584690    0.963835    3.425613    0.391950    0.079772    0.004455    0.931704    
#> 138: 0.599903    0.969289    3.427788    0.410666    0.076779    0.004232    0.906240    
#> 139: 0.605949    0.988590    3.435521    0.400426    0.072940    0.005100    0.906260    
#> 140: 0.639423    0.990966    3.442160    0.428071    0.074432    0.005043    0.927966    
#> 141: 0.639928    0.951678    3.433583    0.502517    0.076714    0.004823    0.909033    
#> 142: 0.687869    0.935412    3.445070    0.519412    0.086714    0.004582    0.897968    
#> 143: 0.629171    0.973127    3.439329    0.516116    0.095067    0.004353    0.888683    
#> 144: 0.672090    0.966286    3.444559    0.490310    0.090818    0.004135    0.885574    
#> 145: 0.634830    0.961585    3.437424    0.496145    0.086277    0.003928    0.885234    
#> 146: 0.646420    0.970927    3.444600    0.543424    0.104528    0.003732    0.881371    
#> 147: 0.575476    0.963954    3.438824    0.516253    0.109435    0.003545    0.873305    
#> 148: 0.595202    0.962168    3.439402    0.490440    0.103964    0.003368    0.896001    
#> 149: 0.610785    0.950682    3.436018    0.465918    0.100493    0.003200    0.927646    
#> 150: 0.632364    0.983422    3.435680    0.442622    0.123430    0.003040    0.909556    
#> 151: 0.580636    1.000780    3.426987    0.420491    0.117258    0.002888    0.921184    
#> 152: 0.586101    0.989666    3.425326    0.348379    0.103941    0.003420    0.895978    
#> 153: 0.582152    0.979925    3.427444    0.304636    0.094267    0.003350    0.903059    
#> 154: 0.622571    1.015531    3.425894    0.334804    0.097257    0.003609    0.925239    
#> 155: 0.608697    0.970586    3.422796    0.368824    0.095045    0.003457    0.885138    
#> 156: 0.598207    0.983042    3.441153    0.318557    0.068405    0.003947    0.885664    
#> 157: 0.580707    0.969772    3.442130    0.379852    0.072069    0.003674    0.909671    
#> 158: 0.626341    0.987367    3.440442    0.365907    0.084233    0.003248    0.906404    
#> 159: 0.568420    0.975869    3.440082    0.378563    0.082284    0.002832    0.912012    
#> 160: 0.626079    0.938961    3.444627    0.363093    0.089576    0.002722    0.913220    
#> 161: 0.651319    0.970571    3.443513    0.448119    0.093190    0.003290    0.893722    
#> 162: 0.664854    0.986639    3.429846    0.394105    0.086955    0.003848    0.887176    
#> 163: 0.647298    0.974227    3.442921    0.276222    0.075134    0.004477    0.907717    
#> 164: 0.620879    0.968903    3.442430    0.297666    0.066787    0.004637    0.914473    
#> 165: 0.632791    0.966408    3.451830    0.380720    0.074863    0.004397    0.909462    
#> 166: 0.674430    1.005776    3.450539    0.399118    0.079731    0.004075    0.910224    
#> 167: 0.673695    1.004804    3.451189    0.425092    0.074625    0.004923    0.911344    
#> 168: 0.671369    0.988610    3.453342    0.482068    0.059810    0.007100    0.900831    
#> 169: 0.654773    1.001215    3.435730    0.508169    0.070172    0.006278    0.911849    
#> 170: 0.646670    0.975245    3.441156    0.415736    0.072642    0.006045    0.888382    
#> 171: 0.578872    0.982152    3.433777    0.381987    0.096134    0.005689    0.866211    
#> 172: 0.594331    0.986244    3.430525    0.379698    0.088766    0.005150    0.876525    
#> 173: 0.582133    1.005276    3.415883    0.372129    0.078580    0.006396    0.873804    
#> 174: 0.597374    0.993763    3.423596    0.417304    0.085500    0.006987    0.886660    
#> 175: 0.582855    0.996141    3.413989    0.382420    0.080833    0.007266    0.905805    
#> 176: 0.588671    1.014425    3.418385    0.397571    0.090293    0.005960    0.885761    
#> 177: 0.569267    0.981899    3.428631    0.401500    0.100683    0.005637    0.875587    
#> 178: 0.600497    0.978429    3.425378    0.468041    0.098378    0.004782    0.885705    
#> 179: 0.673968    1.009555    3.422991    0.717263    0.103079    0.004345    0.900879    
#> 180: 0.556249    0.998314    3.419221    0.470523    0.103024    0.003294    0.906738    
#> 181: 0.568701    0.985225    3.396698    0.430083    0.104849    0.002971    0.895387    
#> 182: 0.526369    0.997662    3.389076    0.504382    0.096693    0.002927    0.902948    
#> 183: 0.547115    1.022059    3.388440    0.444527    0.090990    0.002876    0.901778    
#> 184: 0.563418    0.994624    3.392490    0.402154    0.083903    0.002863    0.893793    
#> 185: 0.548333    1.028832    3.391090    0.420451    0.083243    0.002380    0.887558    
#> 186: 0.529900    1.044855    3.393602    0.485319    0.104640    0.002649    0.905977    
#> 187: 0.565399    1.013007    3.405388    0.414183    0.115387    0.003962    0.868027    
#> 188: 0.534551    1.017405    3.405511    0.347256    0.112649    0.005225    0.883984    
#> 189: 0.563784    1.021821    3.414538    0.350524    0.114784    0.005270    0.897481    
#> 190: 0.534354    0.999759    3.417643    0.349135    0.108296    0.005303    0.880604    
#> 191: 0.549624    1.015377    3.404534    0.449026    0.105306    0.003618    0.873009    
#> 192: 0.516021    1.006802    3.403253    0.425027    0.104436    0.003014    0.892614    
#> 193: 0.518827    1.017634    3.403234    0.367015    0.113933    0.002698    0.886754    
#> 194: 0.532258    0.988382    3.397253    0.340733    0.108054    0.002725    0.930978    
#> 195: 0.482973    1.003826    3.390627    0.363661    0.085786    0.002623    0.931816    
#> 196: 0.547544    1.016984    3.398473    0.339287    0.109423    0.002221    0.934641    
#> 197: 0.500700    1.018477    3.409005    0.341657    0.099001    0.002104    0.899520    
#> 198: 0.608799    0.993906    3.404728    0.361739    0.080606    0.002685    0.889478    
#> 199: 0.530386    0.993305    3.407962    0.345090    0.083646    0.002509    0.891266    
#> 200: 0.511405    0.997270    3.409311    0.381554    0.078803    0.002402    0.920400    
#> 201: 0.526096    0.989480    3.410222    0.377226    0.085849    0.002290    0.911232    
#> 202: 0.545951    0.986973    3.410373    0.399140    0.082470    0.002041    0.907604    
#> 203: 0.564122    0.981867    3.410707    0.415106    0.085049    0.001970    0.899223    
#> 204: 0.571765    0.976985    3.411802    0.432574    0.091964    0.001829    0.899899    
#> 205: 0.568985    0.978730    3.412266    0.443587    0.096774    0.001801    0.898592    
#> 206: 0.571706    0.983865    3.413313    0.445658    0.096217    0.001801    0.900890    
#> 207: 0.574758    0.985930    3.413071    0.455183    0.092204    0.001793    0.903775    
#> 208: 0.574935    0.987262    3.413926    0.446568    0.089674    0.001789    0.903660    
#> 209: 0.577242    0.984978    3.414252    0.432911    0.088760    0.001801    0.904147    
#> 210: 0.577881    0.982008    3.414939    0.429676    0.090021    0.001842    0.901824    
#> 211: 0.581346    0.983446    3.415757    0.425641    0.090679    0.001852    0.900202    
#> 212: 0.586365    0.983526    3.416311    0.423716    0.090454    0.001826    0.900109    
#> 213: 0.589011    0.979779    3.416782    0.419718    0.090511    0.001851    0.902312    
#> 214: 0.589321    0.978729    3.417166    0.414194    0.091666    0.001873    0.904029    
#> 215: 0.589525    0.980157    3.417225    0.411306    0.091115    0.001886    0.904617    
#> 216: 0.591271    0.980307    3.417217    0.412649    0.090454    0.001885    0.906273    
#> 217: 0.591562    0.981772    3.417063    0.415536    0.089957    0.001882    0.905113    
#> 218: 0.591964    0.983747    3.416516    0.415432    0.089720    0.001885    0.904562    
#> 219: 0.590156    0.984439    3.415629    0.416868    0.089349    0.001907    0.904350    
#> 220: 0.586499    0.985150    3.415121    0.416828    0.090037    0.001899    0.905127    
#> 221: 0.585466    0.985535    3.414900    0.418410    0.089917    0.001875    0.905141    
#> 222: 0.584830    0.985550    3.414999    0.415147    0.089893    0.001866    0.905300    
#> 223: 0.585734    0.985417    3.415139    0.415711    0.089787    0.001859    0.904741    
#> 224: 0.587118    0.986301    3.415537    0.412088    0.089875    0.001850    0.905567    
#> 225: 0.586473    0.984749    3.415957    0.412021    0.090531    0.001873    0.906022    
#> 226: 0.586612    0.983507    3.416076    0.411250    0.090782    0.001891    0.906484    
#> 227: 0.586597    0.983668    3.416110    0.411086    0.091476    0.001880    0.906565    
#> 228: 0.585800    0.984892    3.415804    0.410743    0.091795    0.001881    0.906807    
#> 229: 0.584948    0.984668    3.415623    0.410412    0.091541    0.001882    0.905547    
#> 230: 0.584686    0.984281    3.415463    0.409065    0.091523    0.001864    0.905019    
#> 231: 0.584077    0.984380    3.415415    0.409500    0.091178    0.001860    0.905162    
#> 232: 0.581205    0.984640    3.415263    0.408808    0.091142    0.001866    0.905778    
#> 233: 0.580644    0.983772    3.415150    0.408956    0.091008    0.001868    0.906385    
#> 234: 0.580445    0.984129    3.415105    0.410271    0.091510    0.001861    0.905769    
#> 235: 0.579483    0.984163    3.414877    0.408965    0.091714    0.001846    0.906193    
#> 236: 0.578753    0.984363    3.414605    0.409574    0.091706    0.001819    0.906159    
#> 237: 0.579554    0.984447    3.414398    0.411647    0.092075    0.001794    0.906479    
#> 238: 0.581097    0.984299    3.414433    0.413691    0.092133    0.001792    0.907017    
#> 239: 0.581189    0.985146    3.414378    0.415350    0.091960    0.001796    0.907422    
#> 240: 0.581754    0.985230    3.414378    0.418307    0.092400    0.001793    0.906863    
#> 241: 0.583088    0.984264    3.414490    0.419919    0.092194    0.001797    0.906944    
#> 242: 0.582463    0.984249    3.414400    0.418166    0.092494    0.001818    0.907470    
#> 243: 0.581599    0.985482    3.414447    0.416584    0.092943    0.001833    0.907947    
#> 244: 0.580547    0.985680    3.414362    0.415594    0.093234    0.001842    0.908401    
#> 245: 0.580174    0.985456    3.414269    0.416027    0.093236    0.001841    0.909352    
#> 246: 0.580024    0.984959    3.414345    0.415013    0.092987    0.001840    0.909661    
#> 247: 0.580241    0.984337    3.414555    0.415747    0.092830    0.001837    0.909419    
#> 248: 0.579120    0.984083    3.414652    0.415810    0.093088    0.001830    0.908955    
#> 249: 0.578619    0.984047    3.414796    0.417962    0.092849    0.001831    0.908710    
#> 250: 0.579571    0.984377    3.414870    0.418108    0.092658    0.001836    0.908621    
#> 251: 0.579547    0.984877    3.415036    0.417960    0.092612    0.001833    0.908681    
#> 252: 0.578924    0.985219    3.415122    0.417118    0.092458    0.001836    0.908890    
#> 253: 0.578294    0.985424    3.415148    0.416344    0.092656    0.001840    0.908618    
#> 254: 0.578262    0.986051    3.415307    0.415409    0.092667    0.001854    0.908821    
#> 255: 0.578365    0.986740    3.415593    0.414569    0.093029    0.001874    0.908754    
#> 256: 0.579185    0.986718    3.415774    0.413888    0.093336    0.001892    0.908884    
#> 257: 0.579529    0.986614    3.415719    0.415085    0.093399    0.001894    0.908619    
#> 258: 0.579461    0.986420    3.415588    0.414552    0.093339    0.001887    0.908525    
#> 259: 0.579088    0.986216    3.415504    0.415196    0.093490    0.001883    0.908632    
#> 260: 0.578957    0.986281    3.415583    0.414529    0.093682    0.001873    0.908531    
#> 261: 0.579193    0.986166    3.415651    0.413332    0.093741    0.001866    0.908852    
#> 262: 0.579650    0.986661    3.415642    0.415799    0.094113    0.001866    0.908790    
#> 263: 0.580106    0.987204    3.415678    0.415658    0.094467    0.001872    0.908700    
#> 264: 0.579683    0.987681    3.415558    0.416142    0.095035    0.001873    0.908607    
#> 265: 0.579740    0.987930    3.415538    0.416963    0.095474    0.001881    0.908382    
#> 266: 0.580262    0.988409    3.415545    0.418088    0.095662    0.001894    0.908016    
#> 267: 0.580661    0.988364    3.415612    0.418670    0.095839    0.001903    0.908047    
#> 268: 0.580885    0.987960    3.415525    0.419266    0.095735    0.001907    0.907772    
#> 269: 0.581635    0.987732    3.415483    0.419343    0.095731    0.001913    0.907804    
#> 270: 0.581871    0.987951    3.415270    0.419100    0.095626    0.001912    0.907879    
#> 271: 0.581721    0.988168    3.415030    0.418612    0.095678    0.001910    0.907715    
#> 272: 0.581564    0.988026    3.414846    0.418494    0.095814    0.001914    0.907913    
#> 273: 0.581372    0.988168    3.414736    0.419223    0.096128    0.001915    0.907647    
#> 274: 0.581228    0.988434    3.414751    0.418972    0.096452    0.001910    0.907799    
#> 275: 0.581145    0.988827    3.414705    0.419696    0.096831    0.001909    0.907644    
#> 276: 0.581060    0.989101    3.414841    0.420529    0.096939    0.001913    0.907626    
#> 277: 0.580979    0.989384    3.414963    0.420636    0.096825    0.001913    0.907513    
#> 278: 0.580840    0.989186    3.415050    0.420406    0.096681    0.001911    0.907506    
#> 279: 0.580920    0.989164    3.415071    0.419880    0.096623    0.001913    0.907624    
#> 280: 0.581130    0.989114    3.415192    0.421142    0.096782    0.001918    0.907556    
#> 281: 0.581260    0.989266    3.415223    0.420931    0.097067    0.001921    0.907407    
#> 282: 0.581111    0.989405    3.415241    0.420764    0.097374    0.001922    0.907364    
#> 283: 0.581449    0.989658    3.415273    0.421135    0.097445    0.001926    0.907549    
#> 284: 0.581220    0.989375    3.415216    0.421027    0.097549    0.001920    0.907447    
#> 285: 0.580890    0.989178    3.415135    0.421247    0.097632    0.001919    0.907489    
#> 286: 0.580725    0.989337    3.415026    0.421258    0.097638    0.001913    0.907477    
#> 287: 0.580712    0.989716    3.414953    0.421549    0.097690    0.001908    0.907398    
#> 288: 0.581270    0.989809    3.414892    0.421769    0.097499    0.001910    0.907514    
#> 289: 0.582064    0.989876    3.414840    0.422827    0.097491    0.001911    0.907365    
#> 290: 0.582366    0.989916    3.414829    0.423169    0.097571    0.001902    0.907711    
#> 291: 0.582996    0.990119    3.414871    0.423579    0.097477    0.001896    0.907548    
#> 292: 0.582939    0.990168    3.414874    0.423458    0.097473    0.001891    0.907399    
#> 293: 0.582909    0.990116    3.414792    0.423538    0.097549    0.001889    0.907119    
#> 294: 0.582632    0.990426    3.414702    0.423368    0.097555    0.001888    0.907176    
#> 295: 0.582416    0.990151    3.414619    0.423625    0.097583    0.001889    0.907004    
#> 296: 0.581920    0.990112    3.414594    0.423258    0.097637    0.001895    0.906809    
#> 297: 0.582252    0.990164    3.414544    0.423438    0.097624    0.001901    0.906695    
#> 298: 0.582420    0.990126    3.414511    0.424321    0.097802    0.001902    0.906588    
#> 299: 0.582585    0.990189    3.414504    0.424228    0.097767    0.001896    0.906441    
#> 300: 0.582721    0.990085    3.414569    0.424523    0.097768    0.001891    0.906263    
#> 301: 0.582851    0.990007    3.414582    0.424315    0.097986    0.001890    0.906026    
#> 302: 0.582909    0.990264    3.414506    0.423893    0.097986    0.001891    0.906037    
#> 303: 0.582534    0.990621    3.414501    0.423411    0.098006    0.001889    0.905959    
#> 304: 0.582714    0.990777    3.414468    0.423070    0.098091    0.001891    0.905914    
#> 305: 0.582774    0.990465    3.414481    0.423375    0.098080    0.001892    0.905968    
#> 306: 0.582386    0.990423    3.414453    0.423564    0.098262    0.001890    0.906152    
#> 307: 0.582378    0.990323    3.414398    0.424830    0.098380    0.001887    0.906314    
#> 308: 0.581701    0.990237    3.414375    0.424136    0.098356    0.001885    0.906560    
#> 309: 0.581763    0.990354    3.414300    0.423594    0.098587    0.001891    0.906657    
#> 310: 0.581617    0.990530    3.414159    0.422742    0.098716    0.001889    0.906821    
#> 311: 0.581439    0.990642    3.414108    0.422400    0.098664    0.001890    0.906647    
#> 312: 0.581384    0.990601    3.413999    0.422265    0.098534    0.001887    0.906655    
#> 313: 0.581005    0.990321    3.413901    0.421599    0.098291    0.001882    0.907075    
#> 314: 0.580971    0.990389    3.413833    0.421633    0.098301    0.001878    0.907175    
#> 315: 0.580474    0.990510    3.413784    0.420793    0.098210    0.001875    0.907419    
#> 316: 0.580553    0.990538    3.413720    0.420062    0.098327    0.001876    0.907586    
#> 317: 0.580323    0.990633    3.413673    0.419809    0.098342    0.001874    0.907642    
#> 318: 0.580251    0.990668    3.413585    0.420084    0.098428    0.001873    0.907453    
#> 319: 0.580149    0.990685    3.413530    0.420431    0.098417    0.001872    0.907316    
#> 320: 0.579635    0.990736    3.413433    0.420203    0.098372    0.001872    0.907377    
#> 321: 0.579063    0.990871    3.413289    0.420461    0.098304    0.001873    0.907507    
#> 322: 0.578907    0.991118    3.413098    0.419537    0.098317    0.001879    0.907599    
#> 323: 0.578223    0.991347    3.412974    0.418526    0.098281    0.001884    0.907759    
#> 324: 0.577826    0.991485    3.412927    0.417726    0.098160    0.001889    0.907644    
#> 325: 0.577655    0.991651    3.412884    0.417221    0.098046    0.001893    0.907506    
#> 326: 0.577660    0.991390    3.412847    0.417743    0.097931    0.001893    0.907462    
#> 327: 0.577763    0.991338    3.412869    0.417648    0.097913    0.001894    0.907399    
#> 328: 0.577828    0.991449    3.412822    0.417410    0.097940    0.001895    0.907302    
#> 329: 0.577866    0.991548    3.412811    0.417627    0.097967    0.001894    0.907278    
#> 330: 0.577542    0.991713    3.412821    0.417701    0.098054    0.001897    0.907209    
#> 331: 0.577556    0.991921    3.412812    0.418447    0.098154    0.001897    0.907024    
#> 332: 0.577705    0.991984    3.412823    0.419179    0.098165    0.001895    0.907028    
#> 333: 0.577450    0.992024    3.412802    0.419298    0.098162    0.001894    0.907032    
#> 334: 0.577241    0.991784    3.412751    0.419054    0.098182    0.001891    0.907036    
#> 335: 0.576950    0.991933    3.412680    0.418776    0.098265    0.001885    0.906943    
#> 336: 0.576680    0.992060    3.412616    0.418557    0.098394    0.001884    0.906985    
#> 337: 0.576643    0.992580    3.412538    0.418545    0.098691    0.001883    0.906975    
#> 338: 0.576759    0.992787    3.412517    0.418673    0.098887    0.001881    0.906963    
#> 339: 0.576381    0.992980    3.412471    0.418915    0.098992    0.001878    0.906928    
#> 340: 0.576105    0.992870    3.412469    0.418526    0.099202    0.001878    0.906921    
#> 341: 0.576296    0.992905    3.412494    0.418347    0.099208    0.001878    0.906992    
#> 342: 0.576251    0.992784    3.412499    0.418675    0.099210    0.001881    0.906862    
#> 343: 0.575800    0.992823    3.412542    0.418275    0.099073    0.001882    0.906792    
#> 344: 0.575841    0.992779    3.412606    0.418163    0.099006    0.001887    0.906770    
#> 345: 0.575769    0.992679    3.412680    0.418000    0.099062    0.001891    0.906670    
#> 346: 0.575824    0.992735    3.412710    0.417825    0.099004    0.001891    0.906552    
#> 347: 0.576103    0.992686    3.412655    0.417867    0.099013    0.001895    0.906513    
#> 348: 0.575897    0.992814    3.412588    0.417935    0.098989    0.001899    0.906547    
#> 349: 0.575643    0.992645    3.412550    0.418444    0.099027    0.001904    0.906514    
#> 350: 0.575464    0.992453    3.412519    0.418750    0.099064    0.001906    0.906526    
#> 351: 0.575477    0.992576    3.412463    0.419308    0.099139    0.001905    0.906533    
#> 352: 0.575119    0.992663    3.412409    0.419222    0.099144    0.001904    0.906646    
#> 353: 0.575187    0.992766    3.412347    0.418577    0.099328    0.001903    0.906579    
#> 354: 0.575270    0.992825    3.412241    0.419097    0.099374    0.001905    0.906454    
#> 355: 0.575364    0.992712    3.412138    0.418753    0.099409    0.001903    0.906591    
#> 356: 0.575179    0.992694    3.412092    0.418765    0.099446    0.001900    0.906629    
#> 357: 0.575477    0.992812    3.412074    0.418886    0.099491    0.001897    0.906679    
#> 358: 0.575394    0.992851    3.412100    0.418781    0.099358    0.001892    0.906607    
#> 359: 0.575336    0.993051    3.412070    0.418474    0.099244    0.001890    0.906580    
#> 360: 0.575005    0.993172    3.411981    0.418181    0.099112    0.001891    0.906634    
#> 361: 0.574533    0.993147    3.411891    0.418089    0.099176    0.001894    0.906679    
#> 362: 0.574542    0.993154    3.411823    0.417777    0.099127    0.001896    0.906493    
#> 363: 0.574663    0.993131    3.411778    0.417967    0.099065    0.001901    0.906299    
#> 364: 0.574881    0.993233    3.411725    0.417606    0.098877    0.001902    0.906389    
#> 365: 0.574964    0.993252    3.411732    0.417610    0.098753    0.001904    0.906388    
#> 366: 0.574944    0.993227    3.411698    0.417820    0.098737    0.001907    0.906283    
#> 367: 0.575057    0.993309    3.411681    0.417784    0.098832    0.001907    0.906276    
#> 368: 0.575107    0.993470    3.411641    0.417487    0.098874    0.001909    0.906167    
#> 369: 0.575134    0.993424    3.411623    0.417440    0.098789    0.001910    0.906087    
#> 370: 0.575134    0.993483    3.411598    0.417055    0.098762    0.001913    0.906170    
#> 371: 0.574967    0.993414    3.411516    0.417484    0.098803    0.001914    0.906177    
#> 372: 0.574972    0.993473    3.411476    0.417975    0.098913    0.001917    0.906095    
#> 373: 0.574604    0.993525    3.411403    0.417760    0.099051    0.001919    0.906131    
#> 374: 0.574412    0.993552    3.411339    0.417429    0.099124    0.001919    0.906141    
#> 375: 0.574126    0.993501    3.411266    0.416909    0.099053    0.001918    0.906321    
#> 376: 0.573947    0.993566    3.411216    0.416674    0.099124    0.001918    0.906241    
#> 377: 0.573757    0.993662    3.411159    0.416781    0.099200    0.001919    0.906180    
#> 378: 0.573548    0.993681    3.411103    0.416759    0.099154    0.001918    0.906246    
#> 379: 0.573306    0.993536    3.411083    0.416868    0.099215    0.001913    0.906186    
#> 380: 0.573111    0.993530    3.411048    0.416732    0.099234    0.001912    0.906102    
#> 381: 0.572752    0.993539    3.411015    0.416496    0.099281    0.001911    0.906105    
#> 382: 0.572778    0.993559    3.410995    0.416748    0.099261    0.001907    0.906055    
#> 383: 0.573082    0.993610    3.410988    0.416953    0.099198    0.001908    0.906061    
#> 384: 0.573034    0.993508    3.411012    0.417324    0.099184    0.001907    0.906012    
#> 385: 0.572895    0.993396    3.411032    0.416969    0.099106    0.001908    0.906099    
#> 386: 0.573163    0.993647    3.411067    0.416960    0.099118    0.001908    0.906126    
#> 387: 0.573250    0.993736    3.411116    0.416678    0.099058    0.001913    0.906128    
#> 388: 0.573622    0.993807    3.411197    0.416729    0.099071    0.001914    0.905963    
#> 389: 0.573809    0.993681    3.411233    0.416503    0.099157    0.001912    0.905872    
#> 390: 0.573710    0.993647    3.411241    0.416436    0.099288    0.001911    0.905807    
#> 391: 0.573707    0.993617    3.411262    0.415927    0.099332    0.001907    0.905829    
#> 392: 0.573641    0.993609    3.411301    0.415651    0.099333    0.001905    0.905843    
#> 393: 0.573659    0.993553    3.411322    0.415635    0.099391    0.001904    0.905792    
#> 394: 0.573610    0.993489    3.411322    0.415204    0.099382    0.001903    0.905773    
#> 395: 0.573832    0.993599    3.411325    0.415162    0.099425    0.001901    0.905812    
#> 396: 0.573740    0.993675    3.411332    0.414986    0.099388    0.001899    0.905842    
#> 397: 0.573857    0.993655    3.411344    0.415532    0.099357    0.001900    0.905750    
#> 398: 0.574101    0.993574    3.411355    0.416389    0.099378    0.001901    0.905708    
#> 399: 0.574584    0.993488    3.411386    0.416952    0.099313    0.001901    0.905594    
#> 400: 0.574795    0.993600    3.411402    0.417463    0.099289    0.001904    0.905536    
#> 401: 0.575128    0.993642    3.411408    0.418192    0.099172    0.001906    0.905526    
#> 402: 0.575404    0.993753    3.411420    0.418462    0.099176    0.001909    0.905586    
#> 403: 0.575897    0.993779    3.411448    0.418864    0.099226    0.001912    0.905628    
#> 404: 0.575968    0.993800    3.411425    0.418605    0.099326    0.001913    0.905576    
#> 405: 0.575954    0.993815    3.411451    0.418778    0.099346    0.001913    0.905555    
#> 406: 0.575956    0.993841    3.411465    0.418941    0.099331    0.001915    0.905634    
#> 407: 0.576053    0.993822    3.411491    0.418948    0.099357    0.001913    0.905696    
#> 408: 0.576430    0.993906    3.411505    0.419158    0.099306    0.001911    0.905811    
#> 409: 0.576460    0.993915    3.411471    0.418945    0.099236    0.001909    0.905811    
#> 410: 0.576442    0.994026    3.411440    0.418609    0.099260    0.001910    0.905747    
#> 411: 0.576452    0.993854    3.411400    0.418237    0.099350    0.001911    0.905746    
#> 412: 0.576436    0.993894    3.411376    0.418402    0.099318    0.001911    0.905716    
#> 413: 0.576342    0.993937    3.411341    0.418572    0.099284    0.001912    0.905722    
#> 414: 0.576205    0.993876    3.411318    0.418529    0.099316    0.001912    0.905573    
#> 415: 0.576217    0.993797    3.411296    0.418294    0.099273    0.001915    0.905497    
#> 416: 0.576253    0.993857    3.411288    0.418177    0.099270    0.001917    0.905421    
#> 417: 0.576179    0.993896    3.411251    0.417760    0.099266    0.001918    0.905458    
#> 418: 0.575907    0.994020    3.411206    0.417681    0.099299    0.001918    0.905505    
#> 419: 0.575737    0.994183    3.411143    0.417848    0.099286    0.001921    0.905533    
#> 420: 0.575752    0.994185    3.411145    0.417855    0.099292    0.001920    0.905623    
#> 421: 0.575636    0.994178    3.411179    0.417622    0.099349    0.001923    0.905584    
#> 422: 0.575632    0.994084    3.411188    0.417176    0.099353    0.001924    0.905543    
#> 423: 0.575716    0.994086    3.411194    0.416787    0.099439    0.001923    0.905569    
#> 424: 0.575620    0.994062    3.411187    0.416580    0.099454    0.001922    0.905449    
#> 425: 0.575667    0.994182    3.411161    0.416262    0.099476    0.001921    0.905475    
#> 426: 0.575699    0.994289    3.411173    0.415906    0.099462    0.001919    0.905554    
#> 427: 0.575516    0.994056    3.411181    0.415341    0.099557    0.001918    0.905630    
#> 428: 0.575207    0.994061    3.411174    0.414973    0.099560    0.001919    0.905664    
#> 429: 0.575141    0.994061    3.411178    0.414703    0.099522    0.001918    0.905667    
#> 430: 0.575082    0.994090    3.411162    0.414596    0.099479    0.001919    0.905616    
#> 431: 0.575089    0.994043    3.411147    0.414391    0.099429    0.001918    0.905582    
#> 432: 0.574933    0.994123    3.411126    0.414291    0.099378    0.001919    0.905540    
#> 433: 0.574970    0.994283    3.411122    0.414565    0.099379    0.001920    0.905458    
#> 434: 0.574808    0.994244    3.411130    0.414783    0.099369    0.001922    0.905389    
#> 435: 0.574947    0.994249    3.411154    0.415023    0.099326    0.001921    0.905340    
#> 436: 0.574986    0.994243    3.411167    0.414843    0.099316    0.001921    0.905345    
#> 437: 0.575127    0.994293    3.411146    0.414707    0.099339    0.001920    0.905392    
#> 438: 0.575251    0.994467    3.411150    0.414774    0.099421    0.001915    0.905407    
#> 439: 0.575474    0.994547    3.411139    0.414726    0.099451    0.001914    0.905405    
#> 440: 0.575397    0.994696    3.411140    0.414842    0.099413    0.001911    0.905463    
#> 441: 0.575329    0.994751    3.411139    0.414773    0.099407    0.001910    0.905435    
#> 442: 0.575254    0.994748    3.411131    0.414815    0.099348    0.001909    0.905488    
#> 443: 0.575380    0.994779    3.411143    0.415045    0.099412    0.001907    0.905572    
#> 444: 0.575354    0.994853    3.411142    0.415274    0.099378    0.001904    0.905565    
#> 445: 0.575357    0.994902    3.411117    0.415371    0.099425    0.001903    0.905643    
#> 446: 0.575245    0.994995    3.411075    0.415510    0.099331    0.001902    0.905697    
#> 447: 0.575175    0.995008    3.411048    0.415276    0.099317    0.001901    0.905714    
#> 448: 0.575021    0.995085    3.411024    0.415414    0.099328    0.001901    0.905702    
#> 449: 0.574971    0.995142    3.411079    0.415364    0.099302    0.001902    0.905748    
#> 450: 0.575014    0.995122    3.411097    0.415502    0.099244    0.001902    0.905739    
#> 451: 0.575138    0.995072    3.411084    0.415834    0.099159    0.001904    0.905658    
#> 452: 0.575242    0.995093    3.411036    0.416586    0.099141    0.001905    0.905510    
#> 453: 0.575295    0.995088    3.411019    0.416750    0.099208    0.001906    0.905375    
#> 454: 0.575223    0.995177    3.411010    0.416524    0.099206    0.001906    0.905304    
#> 455: 0.575246    0.995151    3.410983    0.416437    0.099240    0.001904    0.905346    
#> 456: 0.575068    0.995009    3.410985    0.416128    0.099216    0.001905    0.905439    
#> 457: 0.574875    0.994951    3.410989    0.415904    0.099194    0.001904    0.905442    
#> 458: 0.574693    0.995059    3.411003    0.415738    0.099164    0.001904    0.905419    
#> 459: 0.574579    0.995278    3.411022    0.415742    0.099159    0.001904    0.905413    
#> 460: 0.574365    0.995373    3.411011    0.415711    0.099110    0.001903    0.905466    
#> 461: 0.574287    0.995402    3.411040    0.415444    0.099074    0.001903    0.905517    
#> 462: 0.574220    0.995400    3.411076    0.415553    0.098976    0.001903    0.905497    
#> 463: 0.574293    0.995417    3.411085    0.415826    0.098935    0.001902    0.905512    
#> 464: 0.574209    0.995391    3.411078    0.415809    0.098866    0.001901    0.905478    
#> 465: 0.574222    0.995219    3.411079    0.415808    0.098824    0.001899    0.905501    
#> 466: 0.574211    0.995224    3.411072    0.415871    0.098821    0.001897    0.905448    
#> 467: 0.574137    0.995214    3.411041    0.415779    0.098707    0.001896    0.905395    
#> 468: 0.574264    0.995237    3.411029    0.415996    0.098689    0.001895    0.905360    
#> 469: 0.574342    0.995343    3.411037    0.415936    0.098699    0.001895    0.905427    
#> 470: 0.574344    0.995330    3.411035    0.415870    0.098602    0.001895    0.905488    
#> 471: 0.574019    0.995328    3.411029    0.415547    0.098568    0.001894    0.905586    
#> 472: 0.573898    0.995349    3.411037    0.415321    0.098518    0.001894    0.905664    
#> 473: 0.573660    0.995369    3.411028    0.414999    0.098480    0.001895    0.905686    
#> 474: 0.573594    0.995341    3.411026    0.414946    0.098546    0.001898    0.905707    
#> 475: 0.573607    0.995414    3.411000    0.414709    0.098606    0.001899    0.905720    
#> 476: 0.573640    0.995415    3.410969    0.414557    0.098569    0.001901    0.905747    
#> 477: 0.573547    0.995429    3.410947    0.414214    0.098520    0.001904    0.905688    
#> 478: 0.573482    0.995442    3.410948    0.414088    0.098491    0.001905    0.905669    
#> 479: 0.573551    0.995481    3.410962    0.413989    0.098454    0.001905    0.905732    
#> 480: 0.573535    0.995429    3.410975    0.414038    0.098438    0.001903    0.905777    
#> 481: 0.573570    0.995449    3.410981    0.413923    0.098448    0.001902    0.905822    
#> 482: 0.573714    0.995549    3.410963    0.413776    0.098401    0.001903    0.905865    
#> 483: 0.573650    0.995600    3.410947    0.413759    0.098303    0.001902    0.905911    
#> 484: 0.573692    0.995498    3.410927    0.413752    0.098288    0.001900    0.905941    
#> 485: 0.573874    0.995499    3.410916    0.413795    0.098362    0.001899    0.905888    
#> 486: 0.574090    0.995500    3.410927    0.413702    0.098365    0.001897    0.905821    
#> 487: 0.574255    0.995486    3.410960    0.413424    0.098367    0.001896    0.905818    
#> 488: 0.574207    0.995463    3.410988    0.413253    0.098370    0.001894    0.905798    
#> 489: 0.574331    0.995432    3.410994    0.413040    0.098369    0.001894    0.905790    
#> 490: 0.574523    0.995436    3.411018    0.412942    0.098341    0.001895    0.905813    
#> 491: 0.574517    0.995503    3.411030    0.412995    0.098373    0.001894    0.905815    
#> 492: 0.574470    0.995590    3.411028    0.412989    0.098343    0.001894    0.905889    
#> 493: 0.574429    0.995617    3.411021    0.413181    0.098279    0.001897    0.905870    
#> 494: 0.574560    0.995673    3.411021    0.413324    0.098257    0.001898    0.905822    
#> 495: 0.574750    0.995642    3.411044    0.413592    0.098243    0.001899    0.905727    
#> 496: 0.574812    0.995634    3.411041    0.413665    0.098237    0.001901    0.905702    
#> 497: 0.574687    0.995613    3.411058    0.413504    0.098238    0.001903    0.905696    
#> 498: 0.574732    0.995585    3.411067    0.413468    0.098174    0.001901    0.905708    
#> 499: 0.574707    0.995622    3.411070    0.413417    0.098154    0.001900    0.905682    
#> 500: 0.574722    0.995509    3.411068    0.413505    0.098120    0.001897    0.905720    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.277914    0.966011    3.443091    0.392401    0.083033    0.016800    1.842861    
#> 002: 0.279575    0.959779    3.455077    0.372781    0.078881    0.015960    1.145831    
#> 003: 0.285354    0.924607    3.435788    0.354142    0.080466    0.015162    0.820189    
#> 004: 0.294238    0.932765    3.439244    0.336435    0.082844    0.014404    0.755275    
#> 005: 0.305761    0.952188    3.423060    0.414073    0.103616    0.014839    0.680450    
#> 006: 0.276735    0.968180    3.412248    0.424032    0.134664    0.014831    0.613968    
#> 007: 0.257569    0.976989    3.407543    0.469188    0.143176    0.016677    0.604601    
#> 008: 0.279351    0.956089    3.417146    0.489345    0.136017    0.023717    0.608270    
#> 009: 0.257204    0.968113    3.412317    0.464877    0.129216    0.023960    0.602927    
#> 010: 0.236232    0.956759    3.396632    0.477683    0.122755    0.022884    0.616685    
#> 011: 0.312009    0.953705    3.414177    0.491005    0.116618    0.025196    0.622964    
#> 012: 0.303865    0.957618    3.414501    0.499246    0.110787    0.023936    0.606004    
#> 013: 0.251049    0.977143    3.408211    0.474284    0.121875    0.026628    0.602231    
#> 014: 0.308323    0.962863    3.407446    0.569141    0.115782    0.026359    0.617561    
#> 015: 0.314386    0.960043    3.421598    0.540684    0.110894    0.027184    0.594406    
#> 016: 0.317011    0.948181    3.435598    0.513650    0.111859    0.025825    0.596806    
#> 017: 0.330356    0.952452    3.434362    0.583508    0.112248    0.024534    0.585063    
#> 018: 0.340419    0.958449    3.430436    0.554332    0.112469    0.023307    0.594017    
#> 019: 0.316965    0.951726    3.427320    0.526616    0.106846    0.024160    0.586833    
#> 020: 0.337536    0.958353    3.434264    0.500285    0.105899    0.026116    0.573314    
#> 021: 0.335048    0.947692    3.442534    0.475271    0.106494    0.026937    0.563278    
#> 022: 0.354230    0.942979    3.443738    0.561410    0.101169    0.027397    0.577418    
#> 023: 0.379818    0.951991    3.451741    0.533340    0.108336    0.028543    0.592505    
#> 024: 0.359246    0.949783    3.451953    0.506673    0.104720    0.027116    0.579089    
#> 025: 0.327066    0.945528    3.435252    0.512613    0.099484    0.032003    0.584050    
#> 026: 0.340810    0.963784    3.438626    0.486983    0.100454    0.033775    0.587301    
#> 027: 0.336636    0.966651    3.429775    0.488778    0.095431    0.033441    0.595100    
#> 028: 0.298781    0.971924    3.425425    0.522598    0.105208    0.031769    0.590377    
#> 029: 0.305463    0.959901    3.420809    0.501179    0.104921    0.031999    0.593925    
#> 030: 0.315415    0.954463    3.419535    0.480353    0.099675    0.036795    0.593171    
#> 031: 0.289872    0.952081    3.434678    0.457081    0.096789    0.041738    0.600984    
#> 032: 0.290841    0.944561    3.423283    0.502420    0.094055    0.039651    0.597186    
#> 033: 0.297741    0.957611    3.432063    0.558163    0.096252    0.037668    0.594856    
#> 034: 0.359722    0.936905    3.440851    0.570863    0.091439    0.037190    0.592433    
#> 035: 0.315094    0.937821    3.433691    0.574166    0.094462    0.035331    0.578026    
#> 036: 0.333532    0.952035    3.432783    0.545458    0.104326    0.033564    0.583561    
#> 037: 0.333793    0.959860    3.429637    0.518185    0.099284    0.033081    0.589911    
#> 038: 0.376785    0.966593    3.434732    0.665998    0.101159    0.034450    0.577824    
#> 039: 0.374611    0.957220    3.443151    0.632698    0.096101    0.034724    0.581076    
#> 040: 0.347300    0.958188    3.447511    0.601063    0.091296    0.037502    0.592056    
#> 041: 0.358272    0.947435    3.447151    0.571010    0.089736    0.035626    0.589177    
#> 042: 0.378107    0.938821    3.451155    0.542459    0.085249    0.033845    0.573914    
#> 043: 0.355881    0.947493    3.436449    0.515336    0.090019    0.033561    0.588015    
#> 044: 0.325401    0.957699    3.428945    0.535479    0.087021    0.033956    0.574664    
#> 045: 0.319126    0.959935    3.418445    0.570019    0.086547    0.032259    0.578089    
#> 046: 0.303697    0.952235    3.422360    0.541518    0.086481    0.030933    0.578331    
#> 047: 0.308355    0.958543    3.426083    0.521609    0.100273    0.032847    0.565354    
#> 048: 0.323231    0.962355    3.425847    0.568260    0.103991    0.039276    0.577102    
#> 049: 0.313047    0.964884    3.428723    0.539847    0.098792    0.037312    0.590981    
#> 050: 0.349725    0.914805    3.444919    0.544748    0.093852    0.035446    0.602134    
#> 051: 0.343161    0.933793    3.438519    0.573879    0.101019    0.033674    0.600518    
#> 052: 0.372268    0.938883    3.450277    0.616153    0.111726    0.031990    0.589731    
#> 053: 0.379297    0.940500    3.441757    0.631218    0.114982    0.030391    0.582207    
#> 054: 0.335957    0.949706    3.438141    0.599657    0.135171    0.028871    0.599332    
#> 055: 0.311504    0.942125    3.437394    0.569674    0.128412    0.027428    0.593814    
#> 056: 0.328489    0.932676    3.436338    0.541191    0.121992    0.026056    0.604688    
#> 057: 0.344661    0.959374    3.431959    0.524244    0.115892    0.032341    0.588976    
#> 058: 0.340275    0.956923    3.423293    0.537740    0.110097    0.034526    0.585936    
#> 059: 0.328771    0.937738    3.430668    0.573714    0.104593    0.038079    0.587049    
#> 060: 0.353670    0.939835    3.436010    0.594460    0.099363    0.037002    0.581436    
#> 061: 0.376582    0.954227    3.443339    0.637146    0.096409    0.039059    0.576954    
#> 062: 0.348933    0.951403    3.449361    0.605288    0.119975    0.038764    0.599462    
#> 063: 0.369197    0.918522    3.435326    0.575024    0.113976    0.036825    0.592634    
#> 064: 0.341149    0.923604    3.437374    0.582097    0.108277    0.038468    0.588035    
#> 065: 0.346434    0.946940    3.436451    0.552992    0.117994    0.036545    0.583952    
#> 066: 0.329477    0.953190    3.436764    0.525342    0.112094    0.035728    0.583764    
#> 067: 0.313934    0.926648    3.439698    0.499075    0.106490    0.033942    0.584404    
#> 068: 0.280562    0.950059    3.433092    0.474121    0.101165    0.035250    0.596366    
#> 069: 0.295854    0.959267    3.414973    0.450415    0.098477    0.033487    0.604210    
#> 070: 0.304205    0.979195    3.426210    0.509350    0.108386    0.031813    0.589604    
#> 071: 0.286433    0.972454    3.413750    0.511953    0.119893    0.030222    0.581838    
#> 072: 0.305736    0.954515    3.423193    0.486356    0.113899    0.028711    0.582747    
#> 073: 0.314787    0.963151    3.433980    0.462038    0.113174    0.027276    0.574500    
#> 074: 0.293987    0.942914    3.430745    0.438936    0.111595    0.028189    0.573657    
#> 075: 0.328593    0.935232    3.451080    0.489548    0.106016    0.030582    0.578405    
#> 076: 0.355426    0.942615    3.450044    0.465070    0.101418    0.038585    0.574062    
#> 077: 0.383691    0.930553    3.466535    0.500131    0.096347    0.042560    0.573410    
#> 078: 0.372472    0.926584    3.460656    0.514259    0.091530    0.043350    0.573068    
#> 079: 0.384871    0.937400    3.449025    0.534445    0.097468    0.041183    0.589198    
#> 080: 0.354317    0.943738    3.439478    0.578924    0.104343    0.039123    0.589304    
#> 081: 0.347414    0.952248    3.447579    0.607048    0.110062    0.037167    0.587856    
#> 082: 0.336272    0.952723    3.436574    0.576695    0.114709    0.035309    0.589273    
#> 083: 0.343891    0.970125    3.433671    0.547860    0.108973    0.036176    0.601827    
#> 084: 0.288807    0.966702    3.431700    0.520467    0.103525    0.034368    0.599007    
#> 085: 0.330823    0.973178    3.436819    0.527296    0.100551    0.032649    0.600943    
#> 086: 0.297000    0.969583    3.426862    0.500931    0.095524    0.036351    0.591195    
#> 087: 0.287399    0.967036    3.424296    0.475884    0.099054    0.034534    0.589295    
#> 088: 0.298254    0.949327    3.431592    0.497115    0.095369    0.032807    0.597520    
#> 089: 0.267764    0.973709    3.409753    0.477782    0.104648    0.031298    0.592208    
#> 090: 0.280434    0.965346    3.407830    0.536058    0.099416    0.029733    0.589944    
#> 091: 0.285381    0.962186    3.403836    0.555711    0.100884    0.028246    0.593296    
#> 092: 0.244858    0.985445    3.391733    0.527925    0.095840    0.027498    0.599445    
#> 093: 0.246135    0.975837    3.400383    0.501529    0.091048    0.032350    0.605227    
#> 094: 0.253198    0.984630    3.408298    0.506680    0.098188    0.035525    0.598169    
#> 095: 0.301028    0.979668    3.414810    0.587068    0.107843    0.035850    0.581935    
#> 096: 0.302246    0.965877    3.413709    0.588778    0.102451    0.034563    0.588799    
#> 097: 0.287668    0.968512    3.404390    0.559339    0.102817    0.032835    0.587345    
#> 098: 0.311020    0.973715    3.423731    0.531372    0.097676    0.032886    0.588801    
#> 099: 0.304875    0.966709    3.412002    0.599175    0.117104    0.031241    0.577795    
#> 100: 0.301780    0.986972    3.398602    0.659460    0.111249    0.033691    0.579528    
#> 101: 0.289293    0.981029    3.402607    0.626487    0.105686    0.032007    0.569889    
#> 102: 0.279294    0.970648    3.408654    0.614010    0.100402    0.030406    0.596650    
#> 103: 0.288102    0.974201    3.411050    0.615475    0.095794    0.029138    0.590042    
#> 104: 0.306374    0.973670    3.425277    0.636638    0.118419    0.030311    0.598510    
#> 105: 0.333831    0.953895    3.431199    0.625246    0.112498    0.036471    0.613620    
#> 106: 0.346987    0.933241    3.432527    0.593984    0.106873    0.040096    0.592771    
#> 107: 0.342130    0.943857    3.432688    0.582216    0.101530    0.038453    0.591638    
#> 108: 0.339452    0.934651    3.447530    0.583078    0.096453    0.036530    0.586973    
#> 109: 0.370117    0.936117    3.457440    0.553924    0.091630    0.035320    0.587839    
#> 110: 0.369931    0.924831    3.440671    0.526228    0.098816    0.033554    0.594062    
#> 111: 0.363993    0.924410    3.443777    0.558526    0.100540    0.032585    0.591048    
#> 112: 0.354844    0.915425    3.431832    0.565845    0.112605    0.034152    0.594770    
#> 113: 0.331520    0.951088    3.441448    0.565637    0.106974    0.033688    0.578625    
#> 114: 0.316910    0.953849    3.427710    0.537355    0.101626    0.032004    0.585602    
#> 115: 0.332886    0.941738    3.426100    0.524105    0.096544    0.033252    0.593405    
#> 116: 0.347564    0.939589    3.422492    0.609481    0.091717    0.037977    0.574606    
#> 117: 0.335936    0.949687    3.442941    0.579007    0.089686    0.038875    0.582446    
#> 118: 0.363970    0.933173    3.441954    0.601174    0.085202    0.037635    0.586888    
#> 119: 0.361428    0.950210    3.422791    0.738216    0.090391    0.035753    0.605885    
#> 120: 0.338413    0.942631    3.421591    0.705066    0.095750    0.034340    0.580847    
#> 121: 0.334919    0.976094    3.421541    0.669813    0.104684    0.032623    0.572463    
#> 122: 0.324702    0.961285    3.432956    0.636322    0.100436    0.034578    0.576196    
#> 123: 0.311016    0.988611    3.416543    0.604506    0.100356    0.032849    0.588909    
#> 124: 0.314294    0.993086    3.421392    0.583211    0.104120    0.031207    0.598869    
#> 125: 0.329567    0.990592    3.419625    0.557551    0.100870    0.032812    0.589421    
#> 126: 0.316836    0.977214    3.408868    0.580484    0.095827    0.036836    0.600902    
#> 127: 0.320423    0.967742    3.408685    0.551460    0.093970    0.036192    0.584713    
#> 128: 0.304993    0.962802    3.406984    0.579010    0.089988    0.035353    0.602740    
#> 129: 0.334094    0.971811    3.422660    0.592615    0.098055    0.033586    0.612917    
#> 130: 0.330982    0.971416    3.413297    0.580209    0.111747    0.031907    0.585365    
#> 131: 0.270179    0.970085    3.396945    0.578543    0.115494    0.030311    0.588900    
#> 132: 0.237693    0.981524    3.395846    0.549616    0.109720    0.028796    0.582923    
#> 133: 0.251733    0.972561    3.405971    0.522135    0.109329    0.028786    0.582636    
#> 134: 0.250757    0.956637    3.416128    0.496029    0.103863    0.027347    0.594271    
#> 135: 0.271544    0.960346    3.425845    0.471227    0.116843    0.025980    0.593535    
#> 136: 0.315470    0.951873    3.428927    0.469002    0.129003    0.024681    0.576671    
#> 137: 0.347385    0.945970    3.435087    0.533763    0.122553    0.024707    0.590720    
#> 138: 0.338722    0.951450    3.426790    0.592747    0.116425    0.026141    0.593640    
#> 139: 0.288369    0.945420    3.431263    0.563110    0.121431    0.029443    0.588621    
#> 140: 0.315892    0.961064    3.428062    0.578669    0.121217    0.028964    0.575321    
#> 141: 0.301262    0.943633    3.423933    0.580814    0.126502    0.031910    0.597861    
#> 142: 0.327606    0.946831    3.438794    0.597453    0.120177    0.034876    0.613036    
#> 143: 0.284089    0.978245    3.424263    0.585512    0.114168    0.035361    0.617919    
#> 144: 0.338545    0.977151    3.439171    0.556237    0.108460    0.034910    0.589921    
#> 145: 0.334001    0.963694    3.434756    0.528425    0.103037    0.033165    0.598043    
#> 146: 0.347369    0.966412    3.442454    0.540744    0.097885    0.031507    0.587434    
#> 147: 0.302586    0.943883    3.437633    0.513706    0.092991    0.033587    0.576225    
#> 148: 0.311106    0.953767    3.435510    0.526501    0.089462    0.032752    0.597357    
#> 149: 0.294435    0.954116    3.424276    0.500176    0.089870    0.031114    0.590764    
#> 150: 0.334183    0.951366    3.418685    0.475167    0.101575    0.031667    0.593799    
#> 151: 0.275107    0.979378    3.421328    0.459353    0.099687    0.030424    0.587062    
#> 152: 0.253748    0.968968    3.412796    0.464577    0.096680    0.026551    0.582773    
#> 153: 0.276867    0.964811    3.418737    0.508947    0.107970    0.025549    0.596566    
#> 154: 0.311149    0.967493    3.417191    0.479489    0.125097    0.024555    0.594032    
#> 155: 0.315970    0.964606    3.420581    0.557611    0.115496    0.022840    0.599442    
#> 156: 0.327092    0.960671    3.429076    0.537650    0.110847    0.025999    0.600291    
#> 157: 0.302912    0.963252    3.424947    0.531125    0.130510    0.021792    0.595000    
#> 158: 0.346976    0.963602    3.434531    0.584741    0.117003    0.024498    0.596286    
#> 159: 0.327019    0.949154    3.437326    0.521187    0.093759    0.025896    0.607316    
#> 160: 0.328033    0.909824    3.448653    0.588746    0.091402    0.030154    0.602164    
#> 161: 0.339111    0.942205    3.438392    0.551800    0.107208    0.025820    0.605966    
#> 162: 0.325701    0.954136    3.426588    0.455192    0.115103    0.027715    0.607115    
#> 163: 0.336854    0.971037    3.428634    0.533722    0.120858    0.027252    0.596350    
#> 164: 0.328365    0.966341    3.428711    0.509028    0.112939    0.030107    0.581666    
#> 165: 0.365108    0.945770    3.438264    0.508385    0.116005    0.037256    0.589058    
#> 166: 0.360198    0.972426    3.429852    0.520993    0.123827    0.030492    0.587863    
#> 167: 0.364134    0.967956    3.433067    0.530526    0.111077    0.029283    0.589131    
#> 168: 0.331415    0.972570    3.432447    0.528099    0.123216    0.025836    0.595428    
#> 169: 0.309754    0.996803    3.416136    0.517583    0.116042    0.022297    0.599325    
#> 170: 0.300826    0.966853    3.435505    0.447674    0.121703    0.023837    0.599639    
#> 171: 0.327773    0.948298    3.436109    0.432543    0.111770    0.024705    0.593558    
#> 172: 0.287379    0.962593    3.438781    0.432629    0.121629    0.021016    0.600628    
#> 173: 0.283775    0.976201    3.419750    0.411495    0.123629    0.020055    0.601863    
#> 174: 0.285992    0.968614    3.420193    0.374478    0.107921    0.028654    0.597476    
#> 175: 0.289045    0.977753    3.400370    0.446639    0.109843    0.026300    0.612965    
#> 176: 0.277703    0.979702    3.422125    0.444566    0.104719    0.033123    0.602326    
#> 177: 0.339191    0.947145    3.430717    0.549424    0.105992    0.035229    0.597764    
#> 178: 0.368609    0.948192    3.430658    0.452501    0.100742    0.032995    0.603570    
#> 179: 0.349404    0.963932    3.422369    0.550507    0.114108    0.035832    0.587002    
#> 180: 0.294282    0.967902    3.422954    0.450114    0.094787    0.034046    0.605936    
#> 181: 0.317050    0.963620    3.417237    0.498860    0.107744    0.036963    0.595897    
#> 182: 0.279757    0.957428    3.411112    0.498238    0.101199    0.035609    0.608032    
#> 183: 0.288331    0.962560    3.422421    0.484972    0.084082    0.046213    0.603048    
#> 184: 0.307614    0.959435    3.425042    0.538627    0.083676    0.037721    0.589184    
#> 185: 0.269634    0.972692    3.415293    0.530842    0.087060    0.033308    0.580350    
#> 186: 0.285145    0.992237    3.405107    0.560171    0.095526    0.036283    0.585947    
#> 187: 0.322675    0.976790    3.411082    0.624448    0.101924    0.032746    0.573465    
#> 188: 0.303979    0.968640    3.412770    0.637696    0.098678    0.029105    0.576882    
#> 189: 0.312534    0.965675    3.423203    0.543985    0.101048    0.028213    0.571249    
#> 190: 0.292157    0.980975    3.429776    0.457840    0.097328    0.030940    0.569985    
#> 191: 0.303591    0.977040    3.420668    0.478337    0.089359    0.029467    0.570516    
#> 192: 0.292003    0.995751    3.415975    0.487797    0.082243    0.026991    0.578331    
#> 193: 0.308322    0.982410    3.417470    0.527207    0.090556    0.023051    0.589783    
#> 194: 0.310124    0.964760    3.412044    0.539352    0.095461    0.027951    0.581275    
#> 195: 0.260355    0.958754    3.414489    0.506777    0.101883    0.031171    0.578009    
#> 196: 0.317288    0.955215    3.423313    0.542567    0.098294    0.028024    0.579480    
#> 197: 0.297564    0.967940    3.427223    0.510982    0.100153    0.025706    0.587215    
#> 198: 0.337096    0.948280    3.423253    0.539251    0.114237    0.029010    0.576237    
#> 199: 0.306590    0.943944    3.427222    0.488105    0.106313    0.030822    0.589901    
#> 200: 0.312135    0.951506    3.423695    0.501042    0.111546    0.028927    0.592114    
#> 201: 0.315991    0.950060    3.429333    0.503135    0.106806    0.031099    0.589008    
#> 202: 0.321263    0.943001    3.432798    0.502656    0.104295    0.032318    0.586394    
#> 203: 0.333719    0.940680    3.434680    0.506930    0.101994    0.033591    0.586997    
#> 204: 0.335262    0.936569    3.437553    0.510753    0.102683    0.034175    0.587876    
#> 205: 0.336372    0.938741    3.437842    0.510689    0.102264    0.033487    0.591494    
#> 206: 0.339166    0.942817    3.437889    0.526314    0.103424    0.033109    0.592807    
#> 207: 0.339745    0.943721    3.438340    0.516444    0.104495    0.032203    0.593823    
#> 208: 0.339938    0.944483    3.437700    0.501865    0.105890    0.031370    0.592508    
#> 209: 0.342327    0.942071    3.437376    0.501942    0.105369    0.031015    0.591266    
#> 210: 0.343483    0.941621    3.438007    0.504583    0.105578    0.031052    0.589294    
#> 211: 0.346020    0.941667    3.438796    0.507655    0.105605    0.030911    0.587738    
#> 212: 0.347767    0.941704    3.439615    0.514857    0.104187    0.031088    0.586255    
#> 213: 0.349400    0.940853    3.440322    0.517086    0.102348    0.031264    0.586152    
#> 214: 0.351212    0.939492    3.441169    0.520610    0.101081    0.031355    0.585905    
#> 215: 0.353487    0.938979    3.442706    0.522366    0.100151    0.031478    0.585953    
#> 216: 0.359982    0.936946    3.444156    0.532148    0.101516    0.031351    0.587070    
#> 217: 0.364076    0.936032    3.445269    0.537478    0.102785    0.031291    0.586663    
#> 218: 0.364616    0.936098    3.445127    0.544598    0.103161    0.031097    0.586576    
#> 219: 0.363440    0.936290    3.444330    0.551233    0.103418    0.030838    0.586532    
#> 220: 0.360370    0.936955    3.443117    0.552184    0.103219    0.030408    0.586299    
#> 221: 0.358045    0.938306    3.441901    0.551052    0.103262    0.030039    0.586724    
#> 222: 0.356929    0.939022    3.441049    0.556211    0.103826    0.029954    0.586493    
#> 223: 0.356428    0.939648    3.440200    0.558141    0.103559    0.030029    0.586067    
#> 224: 0.356485    0.940592    3.439661    0.561287    0.102866    0.030235    0.586088    
#> 225: 0.356848    0.939782    3.439879    0.562656    0.102315    0.030336    0.586276    
#> 226: 0.356882    0.938732    3.439679    0.565659    0.101671    0.030375    0.586912    
#> 227: 0.355435    0.938865    3.439204    0.566843    0.101589    0.030504    0.586830    
#> 228: 0.354505    0.940154    3.438305    0.568063    0.101665    0.030471    0.586771    
#> 229: 0.352023    0.940915    3.437759    0.568475    0.101865    0.030568    0.586327    
#> 230: 0.350605    0.941491    3.437027    0.568188    0.101873    0.030655    0.586032    
#> 231: 0.349145    0.942300    3.436620    0.567492    0.101668    0.030780    0.585856    
#> 232: 0.348211    0.942919    3.436318    0.568341    0.101214    0.030754    0.585922    
#> 233: 0.347017    0.943361    3.435899    0.568866    0.101422    0.030685    0.586129    
#> 234: 0.345394    0.943698    3.435032    0.568862    0.101621    0.030789    0.586426    
#> 235: 0.344434    0.943803    3.434610    0.569844    0.101260    0.030889    0.586813    
#> 236: 0.342600    0.944731    3.433845    0.569978    0.100999    0.030919    0.587075    
#> 237: 0.341889    0.945427    3.433573    0.570028    0.101256    0.031001    0.587715    
#> 238: 0.342209    0.945955    3.433357    0.570506    0.101598    0.030917    0.587875    
#> 239: 0.342368    0.946471    3.433081    0.570792    0.101836    0.030868    0.587936    
#> 240: 0.342378    0.946349    3.433171    0.570474    0.101853    0.030864    0.587532    
#> 241: 0.343035    0.945498    3.433483    0.569757    0.101643    0.030777    0.587597    
#> 242: 0.342730    0.944727    3.433542    0.567349    0.101493    0.030815    0.587929    
#> 243: 0.342452    0.944993    3.433654    0.565164    0.101515    0.030732    0.588145    
#> 244: 0.341305    0.944911    3.433912    0.562215    0.101569    0.030649    0.588227    
#> 245: 0.340446    0.944624    3.433929    0.559627    0.101579    0.030510    0.588674    
#> 246: 0.340416    0.944439    3.434074    0.557939    0.101356    0.030459    0.588682    
#> 247: 0.339961    0.944420    3.434127    0.556530    0.101559    0.030450    0.588616    
#> 248: 0.339714    0.944775    3.434054    0.555141    0.101665    0.030401    0.588386    
#> 249: 0.338661    0.945219    3.433845    0.554284    0.101853    0.030336    0.588318    
#> 250: 0.338696    0.945834    3.433878    0.554457    0.102180    0.030379    0.588242    
#> 251: 0.339562    0.946231    3.434009    0.556613    0.102459    0.030402    0.588131    
#> 252: 0.340375    0.946543    3.434331    0.559805    0.102639    0.030455    0.588103    
#> 253: 0.340523    0.946370    3.434734    0.559995    0.102751    0.030617    0.588189    
#> 254: 0.340784    0.946573    3.434845    0.559951    0.102986    0.030564    0.588161    
#> 255: 0.340464    0.946505    3.434987    0.558562    0.102861    0.030574    0.588174    
#> 256: 0.340205    0.946382    3.435058    0.557894    0.102832    0.030630    0.587990    
#> 257: 0.340027    0.946072    3.435098    0.558614    0.102981    0.030609    0.587949    
#> 258: 0.339934    0.945974    3.434994    0.559414    0.102986    0.030573    0.587919    
#> 259: 0.339892    0.945835    3.434914    0.559091    0.102917    0.030555    0.588021    
#> 260: 0.339407    0.945872    3.434860    0.558187    0.103054    0.030484    0.588006    
#> 261: 0.339169    0.945657    3.434929    0.557215    0.103024    0.030417    0.588087    
#> 262: 0.339388    0.945635    3.435046    0.557064    0.103008    0.030411    0.588070    
#> 263: 0.339298    0.945668    3.435137    0.556478    0.103194    0.030360    0.587974    
#> 264: 0.338884    0.945807    3.435028    0.556219    0.103118    0.030355    0.588112    
#> 265: 0.338683    0.945959    3.434945    0.556467    0.103054    0.030402    0.588359    
#> 266: 0.339345    0.945954    3.434962    0.558084    0.102802    0.030442    0.588476    
#> 267: 0.339612    0.946012    3.435136    0.559176    0.102793    0.030432    0.588461    
#> 268: 0.339743    0.945751    3.435109    0.559590    0.102761    0.030428    0.588403    
#> 269: 0.339828    0.945798    3.435086    0.559855    0.102738    0.030467    0.588353    
#> 270: 0.340108    0.946166    3.435021    0.561056    0.102688    0.030486    0.588216    
#> 271: 0.339798    0.946395    3.434981    0.561285    0.102727    0.030560    0.588162    
#> 272: 0.339970    0.946281    3.434920    0.561086    0.102571    0.030631    0.588362    
#> 273: 0.339604    0.946500    3.434785    0.560841    0.102409    0.030679    0.588387    
#> 274: 0.339437    0.946751    3.434721    0.560076    0.102511    0.030676    0.588375    
#> 275: 0.339293    0.946833    3.434648    0.559101    0.102493    0.030659    0.588369    
#> 276: 0.339238    0.947137    3.434704    0.559007    0.102380    0.030682    0.588394    
#> 277: 0.338842    0.947306    3.434848    0.558360    0.102268    0.030714    0.588466    
#> 278: 0.338710    0.947405    3.434950    0.558988    0.102365    0.030755    0.588628    
#> 279: 0.338216    0.947508    3.434847    0.559987    0.102574    0.030817    0.588813    
#> 280: 0.338221    0.947605    3.434794    0.561054    0.102425    0.030943    0.588858    
#> 281: 0.337856    0.948085    3.434586    0.562308    0.102339    0.031010    0.588685    
#> 282: 0.337851    0.948461    3.434581    0.563423    0.102352    0.031101    0.588803    
#> 283: 0.338241    0.948576    3.434682    0.564268    0.102213    0.031197    0.589188    
#> 284: 0.338157    0.948555    3.434677    0.564636    0.102036    0.031232    0.589200    
#> 285: 0.338143    0.948759    3.434530    0.564934    0.101862    0.031257    0.589370    
#> 286: 0.337677    0.948762    3.434305    0.564648    0.101767    0.031205    0.589306    
#> 287: 0.337154    0.948946    3.434077    0.564540    0.101594    0.031160    0.589333    
#> 288: 0.336703    0.949016    3.433924    0.563593    0.101577    0.031163    0.589560    
#> 289: 0.336712    0.949053    3.433888    0.563038    0.101445    0.031187    0.589535    
#> 290: 0.336555    0.949057    3.433842    0.562793    0.101267    0.031289    0.589621    
#> 291: 0.336772    0.949232    3.433895    0.563141    0.101244    0.031419    0.589476    
#> 292: 0.336878    0.949148    3.433831    0.563226    0.101121    0.031508    0.589463    
#> 293: 0.336573    0.949263    3.433710    0.563137    0.101018    0.031602    0.589471    
#> 294: 0.336475    0.949476    3.433511    0.563249    0.101058    0.031683    0.589404    
#> 295: 0.336166    0.949460    3.433317    0.562995    0.101009    0.031677    0.589428    
#> 296: 0.336086    0.949523    3.433321    0.562877    0.100969    0.031683    0.589525    
#> 297: 0.336067    0.949663    3.433310    0.563103    0.100877    0.031648    0.589819    
#> 298: 0.335890    0.949497    3.433249    0.562948    0.100814    0.031608    0.589850    
#> 299: 0.335736    0.949508    3.433240    0.562853    0.100822    0.031537    0.589692    
#> 300: 0.335770    0.949431    3.433249    0.562859    0.100877    0.031505    0.589726    
#> 301: 0.335603    0.949370    3.433178    0.561607    0.100964    0.031455    0.589788    
#> 302: 0.335495    0.949463    3.433084    0.561517    0.101134    0.031414    0.589610    
#> 303: 0.335368    0.949464    3.432985    0.561399    0.101048    0.031393    0.589602    
#> 304: 0.335153    0.949789    3.432837    0.561386    0.100944    0.031355    0.589589    
#> 305: 0.334829    0.949761    3.432645    0.561157    0.100910    0.031354    0.589646    
#> 306: 0.334148    0.949890    3.432476    0.560450    0.100824    0.031370    0.589560    
#> 307: 0.333480    0.950000    3.432238    0.559719    0.100698    0.031420    0.589666    
#> 308: 0.332720    0.949974    3.432068    0.559113    0.100657    0.031436    0.589728    
#> 309: 0.332328    0.949979    3.432005    0.559039    0.100513    0.031505    0.589961    
#> 310: 0.332396    0.949999    3.431911    0.559208    0.100598    0.031562    0.590048    
#> 311: 0.332268    0.949953    3.431918    0.559480    0.100536    0.031647    0.590099    
#> 312: 0.332251    0.949916    3.431833    0.560260    0.100446    0.031723    0.590145    
#> 313: 0.332281    0.949699    3.431774    0.561168    0.100398    0.031753    0.590281    
#> 314: 0.331871    0.949965    3.431545    0.561495    0.100425    0.031747    0.590293    
#> 315: 0.331182    0.950269    3.431316    0.561202    0.100461    0.031715    0.590406    
#> 316: 0.330869    0.950573    3.431214    0.560499    0.100524    0.031695    0.590442    
#> 317: 0.330573    0.950825    3.431160    0.559523    0.100593    0.031692    0.590598    
#> 318: 0.330474    0.951000    3.431159    0.559096    0.100631    0.031720    0.590683    
#> 319: 0.330370    0.951010    3.431202    0.558746    0.100655    0.031794    0.590838    
#> 320: 0.330110    0.950950    3.431210    0.558230    0.100629    0.031836    0.590916    
#> 321: 0.330105    0.951105    3.431157    0.558255    0.100607    0.031862    0.590993    
#> 322: 0.329901    0.951106    3.431098    0.558533    0.100683    0.031884    0.590962    
#> 323: 0.329713    0.951092    3.431073    0.558347    0.100611    0.031917    0.590855    
#> 324: 0.329607    0.951119    3.431080    0.558325    0.100653    0.031920    0.590809    
#> 325: 0.329616    0.951250    3.431070    0.558035    0.100680    0.031934    0.590699    
#> 326: 0.329617    0.951140    3.431032    0.557364    0.100770    0.031955    0.590611    
#> 327: 0.329702    0.951197    3.431027    0.557633    0.100968    0.031951    0.590508    
#> 328: 0.329721    0.951308    3.430931    0.557550    0.100950    0.031934    0.590491    
#> 329: 0.329826    0.951435    3.430948    0.557372    0.101092    0.031916    0.590483    
#> 330: 0.329718    0.951541    3.430940    0.556572    0.101098    0.031900    0.590433    
#> 331: 0.329896    0.951690    3.431025    0.556083    0.101083    0.031895    0.590314    
#> 332: 0.330085    0.951722    3.431146    0.555421    0.101060    0.031944    0.590323    
#> 333: 0.330125    0.951533    3.431126    0.555144    0.101063    0.031913    0.590323    
#> 334: 0.329970    0.951449    3.431011    0.554734    0.101002    0.031910    0.590368    
#> 335: 0.329888    0.951494    3.430922    0.554709    0.101059    0.031896    0.590377    
#> 336: 0.329644    0.951667    3.430825    0.554762    0.101106    0.031892    0.590462    
#> 337: 0.329407    0.951945    3.430663    0.555120    0.101086    0.031897    0.590536    
#> 338: 0.329198    0.951996    3.430549    0.555394    0.100997    0.031919    0.590561    
#> 339: 0.328877    0.952156    3.430327    0.555264    0.100949    0.031915    0.590634    
#> 340: 0.328401    0.952190    3.430118    0.555409    0.101005    0.031899    0.590693    
#> 341: 0.328328    0.952312    3.430052    0.555708    0.101021    0.031901    0.590750    
#> 342: 0.327975    0.952285    3.430005    0.555819    0.101054    0.031906    0.590789    
#> 343: 0.327756    0.952318    3.429919    0.555182    0.101057    0.031860    0.590843    
#> 344: 0.327696    0.952365    3.429907    0.554937    0.101070    0.031852    0.590893    
#> 345: 0.327554    0.952465    3.429894    0.554567    0.101171    0.031866    0.590835    
#> 346: 0.327346    0.952491    3.429771    0.554230    0.101134    0.031849    0.590904    
#> 347: 0.326975    0.952560    3.429605    0.554483    0.101147    0.031855    0.590959    
#> 348: 0.326593    0.952669    3.429511    0.554529    0.101237    0.031853    0.591035    
#> 349: 0.326273    0.952590    3.429392    0.555031    0.101359    0.031822    0.591126    
#> 350: 0.326091    0.952493    3.429281    0.555260    0.101425    0.031780    0.591203    
#> 351: 0.326032    0.952713    3.429145    0.555406    0.101459    0.031754    0.591290    
#> 352: 0.325877    0.952983    3.429042    0.555519    0.101597    0.031751    0.591391    
#> 353: 0.325747    0.953095    3.428970    0.555735    0.101615    0.031764    0.591357    
#> 354: 0.325485    0.953278    3.428777    0.556138    0.101565    0.031789    0.591440    
#> 355: 0.325315    0.953293    3.428614    0.556307    0.101527    0.031774    0.591457    
#> 356: 0.325209    0.953251    3.428679    0.556004    0.101605    0.031759    0.591548    
#> 357: 0.325337    0.953344    3.428718    0.556413    0.101673    0.031782    0.591529    
#> 358: 0.325400    0.953375    3.428716    0.556777    0.101655    0.031813    0.591462    
#> 359: 0.325265    0.953464    3.428638    0.556772    0.101652    0.031809    0.591451    
#> 360: 0.325132    0.953556    3.428506    0.556818    0.101700    0.031800    0.591327    
#> 361: 0.324933    0.953632    3.428407    0.556758    0.101709    0.031777    0.591223    
#> 362: 0.324805    0.953665    3.428316    0.556875    0.101654    0.031755    0.591072    
#> 363: 0.324756    0.953680    3.428278    0.557042    0.101623    0.031734    0.590903    
#> 364: 0.324778    0.953680    3.428243    0.557407    0.101678    0.031742    0.590867    
#> 365: 0.324854    0.953630    3.428289    0.557286    0.101581    0.031780    0.590809    
#> 366: 0.324859    0.953485    3.428332    0.556803    0.101525    0.031815    0.590829    
#> 367: 0.324921    0.953414    3.428379    0.556637    0.101491    0.031833    0.590807    
#> 368: 0.325022    0.953490    3.428409    0.557040    0.101468    0.031870    0.590793    
#> 369: 0.325017    0.953569    3.428416    0.557732    0.101462    0.031906    0.590755    
#> 370: 0.324906    0.953717    3.428348    0.557932    0.101473    0.031929    0.590715    
#> 371: 0.324651    0.953773    3.428169    0.558341    0.101484    0.031924    0.590695    
#> 372: 0.324247    0.953854    3.428054    0.558428    0.101526    0.031964    0.590751    
#> 373: 0.323795    0.954061    3.427899    0.558783    0.101588    0.032018    0.590814    
#> 374: 0.323528    0.954137    3.427798    0.558831    0.101563    0.032087    0.590730    
#> 375: 0.323247    0.954254    3.427661    0.558510    0.101598    0.032126    0.590803    
#> 376: 0.322894    0.954355    3.427554    0.558386    0.101642    0.032159    0.590775    
#> 377: 0.322505    0.954480    3.427421    0.558260    0.101639    0.032203    0.590715    
#> 378: 0.322262    0.954620    3.427273    0.558202    0.101675    0.032215    0.590723    
#> 379: 0.321976    0.954663    3.427199    0.558161    0.101687    0.032223    0.590671    
#> 380: 0.321742    0.954614    3.427199    0.557878    0.101673    0.032239    0.590708    
#> 381: 0.321642    0.954616    3.427167    0.557591    0.101714    0.032243    0.590740    
#> 382: 0.321364    0.954726    3.427089    0.557180    0.101746    0.032259    0.590665    
#> 383: 0.321307    0.954816    3.427096    0.556963    0.101801    0.032236    0.590605    
#> 384: 0.321113    0.954945    3.427056    0.556475    0.101791    0.032206    0.590618    
#> 385: 0.321000    0.955025    3.427045    0.556417    0.101802    0.032186    0.590718    
#> 386: 0.321037    0.955158    3.427080    0.556084    0.101738    0.032171    0.590810    
#> 387: 0.321259    0.955295    3.427115    0.556335    0.101766    0.032167    0.590791    
#> 388: 0.321430    0.955262    3.427155    0.556543    0.101714    0.032198    0.590796    
#> 389: 0.321452    0.955097    3.427169    0.556864    0.101587    0.032239    0.590850    
#> 390: 0.321414    0.955181    3.427176    0.556920    0.101516    0.032242    0.590827    
#> 391: 0.321411    0.955158    3.427172    0.556807    0.101424    0.032255    0.590723    
#> 392: 0.321481    0.955078    3.427222    0.556669    0.101310    0.032295    0.590666    
#> 393: 0.321582    0.954997    3.427271    0.556719    0.101188    0.032356    0.590617    
#> 394: 0.321656    0.954956    3.427330    0.556564    0.101101    0.032374    0.590642    
#> 395: 0.321774    0.955082    3.427351    0.556321    0.101074    0.032373    0.590613    
#> 396: 0.321828    0.955128    3.427401    0.556470    0.101035    0.032367    0.590526    
#> 397: 0.321780    0.955052    3.427446    0.556600    0.100927    0.032378    0.590533    
#> 398: 0.321983    0.954844    3.427570    0.556763    0.100897    0.032410    0.590558    
#> 399: 0.322086    0.954762    3.427666    0.556382    0.100892    0.032425    0.590573    
#> 400: 0.322347    0.954742    3.427790    0.556323    0.100884    0.032457    0.590626    
#> 401: 0.322495    0.954705    3.427851    0.556318    0.100848    0.032480    0.590694    
#> 402: 0.322616    0.954723    3.427886    0.556205    0.100723    0.032498    0.590702    
#> 403: 0.322908    0.954691    3.427940    0.556567    0.100676    0.032497    0.590648    
#> 404: 0.322980    0.954645    3.427958    0.556614    0.100641    0.032482    0.590623    
#> 405: 0.323145    0.954698    3.427995    0.557453    0.100606    0.032472    0.590533    
#> 406: 0.323127    0.954763    3.427941    0.557852    0.100611    0.032477    0.590497    
#> 407: 0.323069    0.954812    3.427921    0.558132    0.100633    0.032482    0.590557    
#> 408: 0.323148    0.954897    3.427881    0.558274    0.100616    0.032493    0.590620    
#> 409: 0.323010    0.954863    3.427823    0.558090    0.100674    0.032466    0.590632    
#> 410: 0.322863    0.954921    3.427755    0.557956    0.100676    0.032439    0.590630    
#> 411: 0.322742    0.954906    3.427688    0.558021    0.100683    0.032424    0.590670    
#> 412: 0.322666    0.955020    3.427665    0.557612    0.100723    0.032424    0.590751    
#> 413: 0.322545    0.955119    3.427653    0.556782    0.100798    0.032409    0.590861    
#> 414: 0.322316    0.955134    3.427660    0.556627    0.100796    0.032389    0.590932    
#> 415: 0.322168    0.955157    3.427603    0.556704    0.100782    0.032359    0.590948    
#> 416: 0.322171    0.955243    3.427609    0.556534    0.100824    0.032346    0.590958    
#> 417: 0.322029    0.955284    3.427565    0.556163    0.100857    0.032311    0.590931    
#> 418: 0.321867    0.955339    3.427534    0.555954    0.100954    0.032273    0.590901    
#> 419: 0.321898    0.955385    3.427489    0.555878    0.101050    0.032252    0.590864    
#> 420: 0.321815    0.955447    3.427447    0.555688    0.101092    0.032223    0.590783    
#> 421: 0.321691    0.955442    3.427467    0.555503    0.101134    0.032200    0.590729    
#> 422: 0.321637    0.955428    3.427444    0.555641    0.101131    0.032188    0.590651    
#> 423: 0.321772    0.955345    3.427469    0.555851    0.101095    0.032198    0.590589    
#> 424: 0.321791    0.955317    3.427455    0.556165    0.101080    0.032231    0.590532    
#> 425: 0.321792    0.955418    3.427399    0.556578    0.101070    0.032273    0.590546    
#> 426: 0.321821    0.955446    3.427339    0.557384    0.101037    0.032291    0.590557    
#> 427: 0.321667    0.955468    3.427297    0.557635    0.100995    0.032304    0.590542    
#> 428: 0.321487    0.955544    3.427256    0.557774    0.101017    0.032303    0.590500    
#> 429: 0.321425    0.955550    3.427212    0.558060    0.101040    0.032284    0.590437    
#> 430: 0.321269    0.955600    3.427146    0.557911    0.101050    0.032271    0.590468    
#> 431: 0.321036    0.955641    3.427060    0.557677    0.101025    0.032262    0.590465    
#> 432: 0.320803    0.955695    3.427028    0.557673    0.101033    0.032281    0.590457    
#> 433: 0.320721    0.955817    3.426955    0.557860    0.101011    0.032283    0.590414    
#> 434: 0.320595    0.955842    3.426909    0.557849    0.100979    0.032283    0.590474    
#> 435: 0.320568    0.955857    3.426896    0.557548    0.100927    0.032275    0.590523    
#> 436: 0.320576    0.955832    3.426958    0.557348    0.100962    0.032263    0.590593    
#> 437: 0.320741    0.955716    3.427035    0.557281    0.100967    0.032236    0.590673    
#> 438: 0.320689    0.955734    3.427040    0.557172    0.100978    0.032228    0.590604    
#> 439: 0.320761    0.955871    3.427067    0.557185    0.100962    0.032213    0.590514    
#> 440: 0.320824    0.955924    3.427099    0.556963    0.100953    0.032199    0.590470    
#> 441: 0.320941    0.955880    3.427149    0.556825    0.100966    0.032201    0.590409    
#> 442: 0.320913    0.955960    3.427161    0.556816    0.101001    0.032179    0.590377    
#> 443: 0.320750    0.956032    3.427072    0.556732    0.100964    0.032165    0.590317    
#> 444: 0.320540    0.956163    3.426996    0.556623    0.100987    0.032159    0.590291    
#> 445: 0.320431    0.956216    3.426956    0.556644    0.100973    0.032156    0.590317    
#> 446: 0.320315    0.956294    3.426917    0.556696    0.100984    0.032139    0.590340    
#> 447: 0.320368    0.956359    3.426881    0.556733    0.100932    0.032140    0.590312    
#> 448: 0.320241    0.956468    3.426847    0.556410    0.100933    0.032130    0.590225    
#> 449: 0.320167    0.956538    3.426880    0.555998    0.100958    0.032119    0.590217    
#> 450: 0.320003    0.956521    3.426875    0.555659    0.100916    0.032125    0.590261    
#> 451: 0.320000    0.956494    3.426885    0.555577    0.100927    0.032110    0.590223    
#> 452: 0.319973    0.956533    3.426889    0.555351    0.100928    0.032113    0.590214    
#> 453: 0.319884    0.956564    3.426877    0.554960    0.100928    0.032110    0.590170    
#> 454: 0.319773    0.956725    3.426847    0.554674    0.100962    0.032078    0.590172    
#> 455: 0.319746    0.956818    3.426831    0.554405    0.101012    0.032045    0.590096    
#> 456: 0.319677    0.956822    3.426817    0.554326    0.100957    0.032039    0.590053    
#> 457: 0.319721    0.956789    3.426842    0.554279    0.100873    0.032027    0.589985    
#> 458: 0.319777    0.956852    3.426861    0.554169    0.100860    0.032017    0.589931    
#> 459: 0.319726    0.956950    3.426863    0.554023    0.100831    0.032024    0.589938    
#> 460: 0.319646    0.956992    3.426861    0.553769    0.100799    0.032016    0.589898    
#> 461: 0.319613    0.957029    3.426870    0.553701    0.100835    0.032006    0.589859    
#> 462: 0.319497    0.957055    3.426860    0.553564    0.100832    0.032001    0.589815    
#> 463: 0.319503    0.957089    3.426877    0.553397    0.100800    0.032005    0.589805    
#> 464: 0.319600    0.957140    3.426853    0.553370    0.100798    0.031989    0.589803    
#> 465: 0.319578    0.957085    3.426867    0.553170    0.100780    0.031975    0.589763    
#> 466: 0.319567    0.957192    3.426847    0.552793    0.100829    0.031951    0.589769    
#> 467: 0.319394    0.957149    3.426873    0.552268    0.100880    0.031922    0.589731    
#> 468: 0.319578    0.957105    3.426926    0.552072    0.100880    0.031914    0.589671    
#> 469: 0.319737    0.957098    3.426958    0.552134    0.100871    0.031915    0.589655    
#> 470: 0.319676    0.957138    3.426938    0.552325    0.100882    0.031926    0.589656    
#> 471: 0.319668    0.957076    3.426961    0.552253    0.100842    0.031932    0.589771    
#> 472: 0.319662    0.957014    3.426957    0.552192    0.100860    0.031930    0.589779    
#> 473: 0.319613    0.956972    3.426968    0.552002    0.100867    0.031915    0.589733    
#> 474: 0.319667    0.956932    3.427008    0.552051    0.100888    0.031898    0.589719    
#> 475: 0.319803    0.956991    3.427045    0.551940    0.100861    0.031883    0.589683    
#> 476: 0.319903    0.956986    3.427075    0.551867    0.100883    0.031873    0.589612    
#> 477: 0.320075    0.956938    3.427171    0.551963    0.100855    0.031864    0.589584    
#> 478: 0.320147    0.956893    3.427255    0.551913    0.100808    0.031863    0.589594    
#> 479: 0.320184    0.956879    3.427286    0.551728    0.100770    0.031858    0.589627    
#> 480: 0.320192    0.956862    3.427280    0.551509    0.100756    0.031862    0.589643    
#> 481: 0.320224    0.956867    3.427290    0.551172    0.100795    0.031842    0.589609    
#> 482: 0.320246    0.956869    3.427293    0.550898    0.100884    0.031819    0.589646    
#> 483: 0.320128    0.956868    3.427250    0.550875    0.100955    0.031787    0.589647    
#> 484: 0.320020    0.956855    3.427225    0.550891    0.100979    0.031758    0.589645    
#> 485: 0.320050    0.956840    3.427202    0.551038    0.101022    0.031738    0.589631    
#> 486: 0.320032    0.956862    3.427236    0.550788    0.101031    0.031723    0.589598    
#> 487: 0.320056    0.956818    3.427288    0.550495    0.101047    0.031712    0.589593    
#> 488: 0.319990    0.956823    3.427319    0.550272    0.101064    0.031696    0.589598    
#> 489: 0.320090    0.956824    3.427323    0.550075    0.101130    0.031670    0.589557    
#> 490: 0.320242    0.956847    3.427349    0.550039    0.101157    0.031654    0.589485    
#> 491: 0.320295    0.956909    3.427370    0.549850    0.101177    0.031643    0.589394    
#> 492: 0.320337    0.956976    3.427360    0.549720    0.101194    0.031633    0.589383    
#> 493: 0.320377    0.957037    3.427371    0.549577    0.101194    0.031617    0.589355    
#> 494: 0.320440    0.957112    3.427373    0.549470    0.101200    0.031594    0.589336    
#> 495: 0.320484    0.957125    3.427349    0.549445    0.101176    0.031581    0.589313    
#> 496: 0.320583    0.957245    3.427334    0.549632    0.101187    0.031562    0.589318    
#> 497: 0.320729    0.957283    3.427347    0.550223    0.101226    0.031566    0.589276    
#> 498: 0.320741    0.957304    3.427325    0.550512    0.101225    0.031564    0.589223    
#> 499: 0.320797    0.957354    3.427281    0.550838    0.101279    0.031552    0.589167    
#> 500: 0.320767    0.957372    3.427278    0.550724    0.101273    0.031544    0.589123    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.309476    0.976834    3.445568    0.392401    0.074914    0.016800    1.683967    
#> 002: 0.381234    0.999672    3.471595    0.372781    0.071168    0.015960    1.162745    
#> 003: 0.443827    0.977629    3.467396    0.354142    0.075906    0.019251    0.950734    
#> 004: 0.385585    0.999195    3.468599    0.336435    0.079653    0.023486    0.853288    
#> 005: 0.438659    1.026707    3.470096    0.319613    0.078161    0.022311    0.791215    
#> 006: 0.441874    1.035604    3.462928    0.303633    0.074253    0.021896    0.765658    
#> 007: 0.395029    1.042166    3.448516    0.288451    0.075017    0.021378    0.769551    
#> 008: 0.378786    1.042533    3.437767    0.274029    0.079115    0.023075    0.782220    
#> 009: 0.304383    1.040889    3.422870    0.260327    0.081069    0.024398    0.765405    
#> 010: 0.381650    1.044824    3.433570    0.247311    0.089275    0.025105    0.736699    
#> 011: 0.394668    1.058754    3.439538    0.236145    0.084811    0.030045    0.751264    
#> 012: 0.389805    1.052974    3.444043    0.224338    0.080570    0.028543    0.733120    
#> 013: 0.320209    1.042518    3.427952    0.213121    0.076542    0.027116    0.747998    
#> 014: 0.361020    1.060206    3.432972    0.202465    0.095621    0.025760    0.736185    
#> 015: 0.381515    1.062574    3.440055    0.194355    0.090840    0.024472    0.726647    
#> 016: 0.378016    1.063749    3.436557    0.204410    0.086298    0.031743    0.743832    
#> 017: 0.392712    1.074520    3.444079    0.194190    0.081983    0.030156    0.743977    
#> 018: 0.383122    1.070973    3.434954    0.184480    0.077884    0.028648    0.752368    
#> 019: 0.356465    1.074097    3.426732    0.175256    0.077582    0.027216    0.748208    
#> 020: 0.385333    1.067678    3.442623    0.166493    0.073703    0.029811    0.759527    
#> 021: 0.387736    1.039933    3.453049    0.158169    0.070018    0.028320    0.762247    
#> 022: 0.398859    1.039111    3.465100    0.191449    0.068959    0.032810    0.748863    
#> 023: 0.474843    1.060949    3.466372    0.192965    0.075992    0.034236    0.767343    
#> 024: 0.464466    1.068902    3.462524    0.183316    0.072193    0.032524    0.764980    
#> 025: 0.469612    1.053148    3.463078    0.185568    0.068583    0.030898    0.754324    
#> 026: 0.394929    1.091497    3.436400    0.179025    0.065154    0.033109    0.736258    
#> 027: 0.372812    1.079938    3.441241    0.188424    0.064800    0.031454    0.775925    
#> 028: 0.413336    1.061531    3.463949    0.205529    0.063049    0.030939    0.750302    
#> 029: 0.440610    1.054857    3.444913    0.195252    0.059896    0.029392    0.793641    
#> 030: 0.427805    1.076790    3.443541    0.217403    0.062970    0.031510    0.766701    
#> 031: 0.404918    1.057135    3.449607    0.206533    0.062304    0.035881    0.752627    
#> 032: 0.368546    1.052596    3.458944    0.196206    0.059189    0.034087    0.743385    
#> 033: 0.407622    1.058379    3.458862    0.192351    0.065494    0.032383    0.750267    
#> 034: 0.446864    1.054679    3.458567    0.219303    0.070683    0.030764    0.747213    
#> 035: 0.429483    1.047367    3.447545    0.230119    0.067148    0.029226    0.720977    
#> 036: 0.413794    1.062222    3.451064    0.218613    0.066924    0.027764    0.758549    
#> 037: 0.401538    1.078070    3.446786    0.207683    0.063577    0.026376    0.771338    
#> 038: 0.430424    1.070213    3.440867    0.214301    0.060398    0.029935    0.780183    
#> 039: 0.426925    1.065307    3.454560    0.203586    0.066544    0.028438    0.752380    
#> 040: 0.385808    1.063578    3.457227    0.193407    0.078681    0.027016    0.750781    
#> 041: 0.391658    1.056709    3.446981    0.183736    0.081040    0.027658    0.763273    
#> 042: 0.424387    1.061318    3.444892    0.213830    0.076988    0.026276    0.743510    
#> 043: 0.342459    1.078432    3.419053    0.203138    0.073138    0.028791    0.752449    
#> 044: 0.313843    1.088058    3.416566    0.192981    0.072297    0.030052    0.754459    
#> 045: 0.325423    1.110813    3.408396    0.212869    0.073822    0.028549    0.758565    
#> 046: 0.375900    1.076554    3.430510    0.227077    0.070131    0.027121    0.757029    
#> 047: 0.412834    1.073797    3.431921    0.215723    0.066624    0.025765    0.749402    
#> 048: 0.411124    1.061894    3.438778    0.228817    0.066948    0.027114    0.752824    
#> 049: 0.354628    1.062345    3.444300    0.217376    0.067973    0.030613    0.755210    
#> 050: 0.435266    1.046505    3.454930    0.213617    0.065368    0.031877    0.762054    
#> 051: 0.400021    1.061477    3.436179    0.212655    0.071421    0.030411    0.763088    
#> 052: 0.391259    1.064140    3.443792    0.229631    0.070509    0.029113    0.749071    
#> 053: 0.380578    1.074662    3.432835    0.241530    0.085540    0.027658    0.747518    
#> 054: 0.345479    1.061692    3.443961    0.229454    0.081263    0.032332    0.796473    
#> 055: 0.359087    1.050467    3.433176    0.217981    0.077199    0.030716    0.782808    
#> 056: 0.375037    1.060819    3.438350    0.207082    0.078326    0.029180    0.748160    
#> 057: 0.406893    1.060786    3.445241    0.216848    0.074409    0.027721    0.766756    
#> 058: 0.412917    1.051937    3.441704    0.210831    0.070689    0.033220    0.745197    
#> 059: 0.412417    1.013009    3.460061    0.230990    0.067155    0.037372    0.768180    
#> 060: 0.427342    1.008242    3.462290    0.235634    0.069476    0.038373    0.764437    
#> 061: 0.484460    1.037350    3.465767    0.291811    0.069454    0.036455    0.775887    
#> 062: 0.422522    1.047158    3.460775    0.277221    0.065982    0.038728    0.803352    
#> 063: 0.447483    1.012714    3.465592    0.263360    0.062682    0.043163    0.767496    
#> 064: 0.436678    1.031668    3.468295    0.250192    0.059548    0.041005    0.761626    
#> 065: 0.456447    1.038782    3.444704    0.237682    0.061397    0.038955    0.745584    
#> 066: 0.445063    1.045643    3.456462    0.225798    0.058327    0.037007    0.743869    
#> 067: 0.451098    1.041518    3.464106    0.214508    0.061534    0.036639    0.734754    
#> 068: 0.422323    1.043336    3.468345    0.203783    0.066082    0.038767    0.752899    
#> 069: 0.430883    1.049419    3.445328    0.213915    0.066649    0.037138    0.763901    
#> 070: 0.414314    1.072944    3.456567    0.215810    0.063316    0.040279    0.765611    
#> 071: 0.396329    1.080872    3.437190    0.217203    0.077903    0.042390    0.768050    
#> 072: 0.357959    1.047779    3.431733    0.239738    0.074008    0.040270    0.762821    
#> 073: 0.398948    1.059279    3.454795    0.241304    0.070308    0.038257    0.758266    
#> 074: 0.353710    1.049146    3.452458    0.241401    0.066792    0.036344    0.758284    
#> 075: 0.401822    1.044225    3.473980    0.229331    0.063453    0.037918    0.768537    
#> 076: 0.454807    1.018037    3.494459    0.217865    0.060280    0.038355    0.767782    
#> 077: 0.490998    1.017456    3.484946    0.206971    0.057266    0.036437    0.775703    
#> 078: 0.451810    1.022868    3.472749    0.205292    0.054403    0.034615    0.747715    
#> 079: 0.461113    1.035272    3.467518    0.249472    0.056398    0.035715    0.754013    
#> 080: 0.474193    1.042786    3.462635    0.268456    0.053578    0.038669    0.771769    
#> 081: 0.443447    1.041123    3.457150    0.255033    0.055423    0.040907    0.774388    
#> 082: 0.445274    1.040430    3.471817    0.242282    0.059722    0.038862    0.775201    
#> 083: 0.437829    1.034365    3.470525    0.230168    0.056735    0.036999    0.765989    
#> 084: 0.427258    1.046848    3.447133    0.260483    0.059407    0.035149    0.734282    
#> 085: 0.391627    1.060671    3.445801    0.247459    0.074329    0.033391    0.740703    
#> 086: 0.402729    1.072706    3.436875    0.235086    0.070612    0.031722    0.742375    
#> 087: 0.384137    1.077035    3.437292    0.223331    0.071552    0.030136    0.735298    
#> 088: 0.362840    1.045272    3.438032    0.228399    0.071873    0.028629    0.752520    
#> 089: 0.352159    1.074241    3.423449    0.216979    0.073309    0.028441    0.745159    
#> 090: 0.358856    1.058358    3.434613    0.212055    0.069644    0.027019    0.756248    
#> 091: 0.387405    1.041275    3.430183    0.258583    0.069224    0.028727    0.752631    
#> 092: 0.376125    1.065864    3.428763    0.245654    0.065763    0.029752    0.739936    
#> 093: 0.343110    1.061487    3.433451    0.233371    0.062475    0.031091    0.771894    
#> 094: 0.341933    1.067275    3.426213    0.221702    0.061063    0.030175    0.766182    
#> 095: 0.367580    1.079546    3.431768    0.210617    0.067832    0.033688    0.759546    
#> 096: 0.343484    1.081935    3.417339    0.241931    0.083490    0.032329    0.728705    
#> 097: 0.351577    1.123729    3.412565    0.230166    0.083779    0.030713    0.737999    
#> 098: 0.354091    1.118414    3.423138    0.227197    0.079590    0.030754    0.744169    
#> 099: 0.322464    1.095468    3.405811    0.223936    0.075611    0.029216    0.746349    
#> 100: 0.357855    1.086513    3.422385    0.224582    0.071830    0.028372    0.742602    
#> 101: 0.324917    1.071163    3.404473    0.219675    0.068239    0.027596    0.747441    
#> 102: 0.314733    1.079320    3.387551    0.208691    0.064827    0.026217    0.765064    
#> 103: 0.338276    1.088411    3.414084    0.229947    0.066948    0.024906    0.759694    
#> 104: 0.369290    1.091054    3.435280    0.265987    0.063601    0.027265    0.761396    
#> 105: 0.392089    1.079428    3.443103    0.252688    0.068766    0.027187    0.761760    
#> 106: 0.378808    1.070599    3.439726    0.240054    0.071763    0.025827    0.742813    
#> 107: 0.423640    1.053306    3.448802    0.230157    0.068175    0.029576    0.733934    
#> 108: 0.407225    1.064302    3.455790    0.218649    0.071391    0.028097    0.762212    
#> 109: 0.395936    1.062798    3.462805    0.207717    0.067822    0.026692    0.767364    
#> 110: 0.416607    1.045792    3.448909    0.197331    0.069716    0.025358    0.747035    
#> 111: 0.417343    1.052172    3.446709    0.187465    0.066230    0.024090    0.754602    
#> 112: 0.387933    1.044605    3.435433    0.185681    0.062919    0.022885    0.785225    
#> 113: 0.379731    1.077138    3.435404    0.176397    0.059773    0.022670    0.771661    
#> 114: 0.390841    1.065826    3.446369    0.172093    0.057123    0.027838    0.759729    
#> 115: 0.390725    1.032568    3.438182    0.194486    0.058905    0.026446    0.774029    
#> 116: 0.385920    1.064227    3.438013    0.194059    0.076872    0.026214    0.781539    
#> 117: 0.367255    1.094819    3.433608    0.184356    0.073028    0.029145    0.772762    
#> 118: 0.384908    1.068417    3.438286    0.175138    0.084010    0.027688    0.755967    
#> 119: 0.406190    1.062171    3.440933    0.189786    0.079810    0.028783    0.750437    
#> 120: 0.370570    1.057637    3.425991    0.205777    0.078778    0.027344    0.745187    
#> 121: 0.368777    1.091835    3.420134    0.220931    0.087440    0.025977    0.733621    
#> 122: 0.365442    1.071946    3.428118    0.213367    0.083068    0.027076    0.740108    
#> 123: 0.381178    1.099118    3.414931    0.211812    0.078915    0.025723    0.752794    
#> 124: 0.379180    1.111165    3.427712    0.204684    0.079870    0.028863    0.748520    
#> 125: 0.403225    1.092093    3.428875    0.198055    0.075877    0.027420    0.752165    
#> 126: 0.360274    1.085681    3.416995    0.188152    0.079111    0.026049    0.753613    
#> 127: 0.397641    1.058929    3.431637    0.178745    0.075736    0.024746    0.765249    
#> 128: 0.365088    1.046247    3.450634    0.169808    0.071949    0.027395    0.763958    
#> 129: 0.390223    1.059290    3.440104    0.167108    0.068352    0.026025    0.760849    
#> 130: 0.422747    1.085634    3.436144    0.158753    0.081075    0.027107    0.736274    
#> 131: 0.368462    1.058087    3.427639    0.151456    0.077021    0.037111    0.748012    
#> 132: 0.369045    1.055526    3.423526    0.157512    0.073170    0.036551    0.759712    
#> 133: 0.352884    1.065606    3.427460    0.174726    0.069512    0.037808    0.753780    
#> 134: 0.373472    1.059858    3.438620    0.180446    0.066036    0.035918    0.765725    
#> 135: 0.360665    1.047942    3.441367    0.171424    0.062734    0.034596    0.754713    
#> 136: 0.378611    1.035943    3.443905    0.162853    0.059598    0.032867    0.755103    
#> 137: 0.417981    1.040694    3.451862    0.165434    0.059305    0.035453    0.756090    
#> 138: 0.404553    1.052882    3.456180    0.173427    0.056340    0.033680    0.760143    
#> 139: 0.417175    1.073308    3.464640    0.181632    0.061994    0.038131    0.753271    
#> 140: 0.406455    1.061108    3.467282    0.205729    0.063215    0.041299    0.751731    
#> 141: 0.378588    1.047719    3.447560    0.195442    0.061944    0.039234    0.750714    
#> 142: 0.407379    1.034984    3.462027    0.189273    0.062524    0.037273    0.752174    
#> 143: 0.378147    1.061314    3.452650    0.209426    0.068136    0.036141    0.760299    
#> 144: 0.437272    1.057774    3.470746    0.207516    0.064729    0.038549    0.737301    
#> 145: 0.394514    1.073985    3.443584    0.197140    0.061493    0.036622    0.759634    
#> 146: 0.391954    1.074246    3.449633    0.203162    0.058418    0.034933    0.766293    
#> 147: 0.380636    1.065038    3.445218    0.193003    0.060404    0.038052    0.760522    
#> 148: 0.376722    1.052734    3.452961    0.183353    0.059600    0.040357    0.754745    
#> 149: 0.360501    1.062734    3.449761    0.174186    0.057059    0.038339    0.776205    
#> 150: 0.403510    1.062074    3.439955    0.172290    0.061254    0.036422    0.755680    
#> 151: 0.366257    1.066987    3.450634    0.188068    0.058191    0.034601    0.781001    
#> 152: 0.354526    1.070532    3.441451    0.178636    0.064960    0.032678    0.760971    
#> 153: 0.353648    1.079132    3.435254    0.203296    0.067381    0.025481    0.746388    
#> 154: 0.389992    1.068543    3.438630    0.179958    0.066569    0.029600    0.772153    
#> 155: 0.397141    1.062899    3.442183    0.187595    0.080421    0.025076    0.759040    
#> 156: 0.412890    1.070818    3.443700    0.149995    0.067243    0.020138    0.775795    
#> 157: 0.400835    1.060743    3.457273    0.147801    0.077339    0.024305    0.777232    
#> 158: 0.439941    1.047791    3.459782    0.145334    0.085237    0.023287    0.781617    
#> 159: 0.402264    1.053392    3.460944    0.164223    0.072235    0.022659    0.786838    
#> 160: 0.448423    1.007975    3.480010    0.155563    0.060370    0.023965    0.788731    
#> 161: 0.433159    1.013726    3.474278    0.151651    0.069844    0.030352    0.777526    
#> 162: 0.403191    1.042374    3.449746    0.134113    0.061462    0.028497    0.792357    
#> 163: 0.415095    1.036603    3.438852    0.161727    0.073083    0.029619    0.773317    
#> 164: 0.381888    1.057477    3.429128    0.167441    0.078613    0.023565    0.786413    
#> 165: 0.437557    1.039929    3.448346    0.164989    0.066417    0.023342    0.783359    
#> 166: 0.426189    1.085139    3.450686    0.160419    0.081571    0.021213    0.765922    
#> 167: 0.426669    1.074661    3.457131    0.168402    0.072735    0.019744    0.789541    
#> 168: 0.420783    1.086607    3.446719    0.192657    0.073775    0.019966    0.782562    
#> 169: 0.374323    1.115274    3.433323    0.189159    0.078169    0.018370    0.787076    
#> 170: 0.396633    1.071029    3.436915    0.188569    0.081896    0.019860    0.766373    
#> 171: 0.343541    1.071848    3.423896    0.171045    0.085843    0.020594    0.747526    
#> 172: 0.323165    1.082292    3.418560    0.171915    0.092505    0.018157    0.765452    
#> 173: 0.353745    1.113720    3.415805    0.178769    0.082178    0.020753    0.750213    
#> 174: 0.324272    1.093569    3.416428    0.190603    0.079291    0.017664    0.770193    
#> 175: 0.315227    1.082582    3.403222    0.196183    0.067249    0.015032    0.789663    
#> 176: 0.339378    1.093325    3.417525    0.196267    0.086023    0.016310    0.775042    
#> 177: 0.366295    1.079212    3.428552    0.174504    0.077292    0.013627    0.783043    
#> 178: 0.405168    1.070782    3.429916    0.153507    0.074262    0.014562    0.785532    
#> 179: 0.403638    1.075410    3.439249    0.168718    0.076798    0.018071    0.787900    
#> 180: 0.371664    1.071600    3.440863    0.192800    0.076855    0.019240    0.783438    
#> 181: 0.366364    1.070511    3.417169    0.201636    0.069614    0.017188    0.785693    
#> 182: 0.328811    1.092003    3.411547    0.149216    0.067305    0.018969    0.786835    
#> 183: 0.350899    1.112369    3.411481    0.151346    0.063527    0.018077    0.783163    
#> 184: 0.317127    1.074657    3.419916    0.153416    0.075783    0.017645    0.769605    
#> 185: 0.330354    1.088671    3.427688    0.167909    0.099115    0.018119    0.788993    
#> 186: 0.340058    1.095531    3.428329    0.171047    0.084376    0.019702    0.793138    
#> 187: 0.364010    1.076104    3.433336    0.213038    0.079876    0.021036    0.783900    
#> 188: 0.350190    1.110973    3.429455    0.235111    0.091804    0.020631    0.787820    
#> 189: 0.378184    1.092163    3.437336    0.205146    0.082205    0.023711    0.789030    
#> 190: 0.373357    1.068416    3.442210    0.225943    0.075276    0.016592    0.777978    
#> 191: 0.354007    1.077957    3.416028    0.199811    0.076135    0.017229    0.767279    
#> 192: 0.346019    1.090986    3.427771    0.181488    0.070945    0.023630    0.747475    
#> 193: 0.390994    1.086316    3.438566    0.188843    0.070006    0.029402    0.766884    
#> 194: 0.350223    1.082556    3.436147    0.169380    0.071374    0.036165    0.759943    
#> 195: 0.357576    1.088269    3.435610    0.164880    0.066697    0.031222    0.759602    
#> 196: 0.351912    1.073347    3.430892    0.136499    0.059526    0.026320    0.786755    
#> 197: 0.325852    1.100315    3.437539    0.117950    0.078296    0.028077    0.800935    
#> 198: 0.369701    1.073833    3.430281    0.145543    0.076261    0.030041    0.779703    
#> 199: 0.348904    1.089259    3.416434    0.169651    0.063727    0.030204    0.761699    
#> 200: 0.340333    1.081090    3.425203    0.200817    0.062512    0.030977    0.782694    
#> 201: 0.341292    1.074332    3.434420    0.190681    0.068592    0.033991    0.777685    
#> 202: 0.346304    1.072915    3.431474    0.192651    0.070594    0.034043    0.778363    
#> 203: 0.364381    1.072688    3.430959    0.188659    0.073284    0.032737    0.777029    
#> 204: 0.372521    1.062689    3.435109    0.185931    0.074396    0.032587    0.774372    
#> 205: 0.372495    1.065991    3.435133    0.181155    0.074521    0.032251    0.778407    
#> 206: 0.377053    1.066629    3.437836    0.181992    0.071851    0.032824    0.779093    
#> 207: 0.378028    1.066434    3.437300    0.179964    0.070735    0.032646    0.777406    
#> 208: 0.377139    1.067527    3.437910    0.177547    0.068945    0.032909    0.776574    
#> 209: 0.380189    1.065354    3.437903    0.177770    0.068417    0.032993    0.776171    
#> 210: 0.382817    1.064116    3.438209    0.180649    0.068418    0.032926    0.771910    
#> 211: 0.386430    1.065439    3.439066    0.183886    0.067089    0.032583    0.769218    
#> 212: 0.389498    1.066559    3.440245    0.187715    0.068150    0.032262    0.766737    
#> 213: 0.390958    1.064581    3.441391    0.188843    0.069225    0.032400    0.766266    
#> 214: 0.395541    1.064163    3.442026    0.190408    0.070005    0.032609    0.765516    
#> 215: 0.397232    1.064832    3.443234    0.191716    0.069864    0.032910    0.765852    
#> 216: 0.399929    1.062413    3.444181    0.191428    0.069592    0.032601    0.767389    
#> 217: 0.400619    1.062404    3.445033    0.192431    0.069391    0.032584    0.765808    
#> 218: 0.401731    1.062693    3.444867    0.193932    0.069837    0.032119    0.765385    
#> 219: 0.401291    1.062126    3.444658    0.194989    0.070054    0.032206    0.764884    
#> 220: 0.401320    1.062752    3.444862    0.195549    0.070417    0.032217    0.764051    
#> 221: 0.399465    1.063534    3.444287    0.194812    0.070529    0.032136    0.763747    
#> 222: 0.400081    1.062851    3.443903    0.195384    0.070064    0.032198    0.763557    
#> 223: 0.402029    1.061821    3.444024    0.196292    0.069595    0.032292    0.763347    
#> 224: 0.404301    1.062510    3.444288    0.197013    0.069349    0.032098    0.762758    
#> 225: 0.403807    1.061233    3.444771    0.198001    0.069227    0.032065    0.762464    
#> 226: 0.402778    1.060915    3.444129    0.199394    0.069306    0.031748    0.762962    
#> 227: 0.400826    1.061328    3.443941    0.200524    0.069655    0.031442    0.762805    
#> 228: 0.398587    1.061887    3.443104    0.200268    0.070262    0.031148    0.762692    
#> 229: 0.397625    1.061812    3.442585    0.199884    0.070310    0.030773    0.762813    
#> 230: 0.397334    1.061108    3.442292    0.198994    0.070486    0.030311    0.763635    
#> 231: 0.396532    1.061576    3.442444    0.197472    0.070624    0.029973    0.764663    
#> 232: 0.395647    1.061241    3.442813    0.196784    0.070771    0.029774    0.765340    
#> 233: 0.395497    1.060673    3.443063    0.197033    0.071110    0.029671    0.765290    
#> 234: 0.395672    1.060398    3.443485    0.197041    0.071418    0.029705    0.765279    
#> 235: 0.395390    1.059828    3.443391    0.197458    0.071380    0.029510    0.765056    
#> 236: 0.395033    1.059915    3.443209    0.197216    0.071282    0.029481    0.765067    
#> 237: 0.396388    1.059394    3.443697    0.196868    0.071295    0.029558    0.765810    
#> 238: 0.397551    1.059109    3.444165    0.196210    0.071226    0.029716    0.766166    
#> 239: 0.397579    1.059479    3.444065    0.196133    0.071094    0.029758    0.765908    
#> 240: 0.397148    1.059001    3.444411    0.195796    0.071176    0.029749    0.765428    
#> 241: 0.397424    1.058323    3.444595    0.195929    0.070656    0.029847    0.765332    
#> 242: 0.397062    1.057998    3.444371    0.196251    0.070418    0.029914    0.765190    
#> 243: 0.395705    1.058431    3.444207    0.196282    0.070325    0.029920    0.765438    
#> 244: 0.395393    1.058222    3.444525    0.195742    0.070211    0.030006    0.765449    
#> 245: 0.395863    1.057736    3.444902    0.195166    0.070016    0.030058    0.765611    
#> 246: 0.395995    1.057281    3.445184    0.194506    0.069997    0.030067    0.765823    
#> 247: 0.395844    1.056962    3.445263    0.193929    0.070021    0.029911    0.766214    
#> 248: 0.395764    1.057452    3.445066    0.193721    0.070157    0.029823    0.765966    
#> 249: 0.395508    1.057626    3.445098    0.193419    0.070221    0.029742    0.765758    
#> 250: 0.396206    1.058133    3.445178    0.193277    0.070087    0.029631    0.765746    
#> 251: 0.396444    1.058645    3.445503    0.192743    0.069936    0.029612    0.766450    
#> 252: 0.397002    1.058747    3.445779    0.193110    0.069723    0.029540    0.766627    
#> 253: 0.397727    1.058857    3.445902    0.193057    0.069550    0.029569    0.766814    
#> 254: 0.398227    1.059278    3.445898    0.192999    0.069298    0.029667    0.766326    
#> 255: 0.398045    1.059604    3.445771    0.193050    0.069281    0.029795    0.766199    
#> 256: 0.397812    1.059259    3.445773    0.193325    0.069290    0.029863    0.765751    
#> 257: 0.397471    1.058760    3.445920    0.192850    0.069552    0.029999    0.765348    
#> 258: 0.397212    1.058319    3.445945    0.193223    0.069583    0.029976    0.765301    
#> 259: 0.396988    1.058123    3.445833    0.193413    0.069435    0.030006    0.765294    
#> 260: 0.396715    1.058037    3.445944    0.192817    0.069489    0.029964    0.765112    
#> 261: 0.397008    1.057713    3.446161    0.192373    0.069397    0.029881    0.765738    
#> 262: 0.397669    1.057962    3.446443    0.192097    0.069280    0.029929    0.765799    
#> 263: 0.397619    1.058269    3.446599    0.192393    0.069296    0.029961    0.765813    
#> 264: 0.397777    1.058181    3.446794    0.192550    0.069505    0.029970    0.766104    
#> 265: 0.398064    1.058131    3.446987    0.192219    0.069544    0.029965    0.766699    
#> 266: 0.398410    1.058383    3.447162    0.192344    0.069440    0.030038    0.766680    
#> 267: 0.398609    1.058302    3.447417    0.192768    0.069305    0.030165    0.766287    
#> 268: 0.398721    1.058164    3.447345    0.193146    0.069242    0.030224    0.766108    
#> 269: 0.399093    1.057967    3.447382    0.193278    0.069031    0.030312    0.766180    
#> 270: 0.399334    1.058114    3.447390    0.193501    0.068721    0.030332    0.766002    
#> 271: 0.398994    1.058364    3.447076    0.194075    0.068581    0.030375    0.766196    
#> 272: 0.398509    1.058319    3.446979    0.194265    0.068458    0.030370    0.766944    
#> 273: 0.398236    1.058635    3.446899    0.194407    0.068473    0.030396    0.767399    
#> 274: 0.397723    1.058967    3.446898    0.194216    0.068681    0.030379    0.767343    
#> 275: 0.397833    1.059050    3.446840    0.194012    0.068862    0.030374    0.767259    
#> 276: 0.397950    1.059006    3.447050    0.194268    0.068825    0.030463    0.767189    
#> 277: 0.398066    1.059285    3.447214    0.194178    0.068936    0.030543    0.767255    
#> 278: 0.398267    1.059352    3.447356    0.194498    0.068886    0.030614    0.767167    
#> 279: 0.397649    1.059348    3.447368    0.195189    0.068854    0.030681    0.767319    
#> 280: 0.397718    1.059487    3.447278    0.195739    0.068757    0.030648    0.767230    
#> 281: 0.397429    1.059652    3.447260    0.196299    0.068856    0.030531    0.767078    
#> 282: 0.397556    1.059641    3.447365    0.196353    0.069040    0.030494    0.767083    
#> 283: 0.397695    1.059754    3.447342    0.196753    0.069364    0.030514    0.767205    
#> 284: 0.397621    1.059391    3.447334    0.197061    0.069420    0.030484    0.767086    
#> 285: 0.397520    1.059491    3.447166    0.197130    0.069488    0.030461    0.767080    
#> 286: 0.397723    1.059574    3.447069    0.197322    0.069414    0.030492    0.766947    
#> 287: 0.397600    1.059864    3.446933    0.197458    0.069326    0.030563    0.766798    
#> 288: 0.397876    1.059772    3.447054    0.197631    0.069238    0.030645    0.766889    
#> 289: 0.398160    1.059637    3.447105    0.197556    0.069270    0.030654    0.766840    
#> 290: 0.398339    1.059491    3.447135    0.197763    0.069545    0.030613    0.766576    
#> 291: 0.398431    1.059676    3.447189    0.197769    0.069605    0.030563    0.766373    
#> 292: 0.398442    1.059722    3.447130    0.197847    0.069526    0.030616    0.766132    
#> 293: 0.398042    1.059816    3.446912    0.197886    0.069433    0.030647    0.766020    
#> 294: 0.397543    1.059990    3.446682    0.198179    0.069383    0.030639    0.765906    
#> 295: 0.397369    1.059830    3.446522    0.198094    0.069435    0.030589    0.765912    
#> 296: 0.397111    1.059796    3.446385    0.198190    0.069467    0.030526    0.766266    
#> 297: 0.397187    1.060063    3.446300    0.198375    0.069480    0.030427    0.766280    
#> 298: 0.397191    1.060196    3.446286    0.198123    0.069557    0.030413    0.766140    
#> 299: 0.397032    1.060447    3.446211    0.197816    0.069472    0.030485    0.765783    
#> 300: 0.397055    1.060518    3.446197    0.197979    0.069326    0.030545    0.765475    
#> 301: 0.397060    1.060503    3.446064    0.197631    0.069117    0.030569    0.765432    
#> 302: 0.397129    1.060471    3.445895    0.197612    0.068973    0.030520    0.765317    
#> 303: 0.397029    1.060527    3.445757    0.197509    0.068906    0.030479    0.765135    
#> 304: 0.397298    1.060718    3.445646    0.197891    0.068938    0.030447    0.765107    
#> 305: 0.397211    1.060602    3.445669    0.198046    0.068810    0.030476    0.764915    
#> 306: 0.396923    1.060546    3.445618    0.197919    0.068762    0.030572    0.764776    
#> 307: 0.396797    1.060490    3.445502    0.197879    0.068581    0.030645    0.764824    
#> 308: 0.396565    1.060337    3.445405    0.198184    0.068406    0.030657    0.764990    
#> 309: 0.396702    1.059977    3.445398    0.198505    0.068355    0.030681    0.764882    
#> 310: 0.396723    1.059882    3.445251    0.198588    0.068251    0.030643    0.765003    
#> 311: 0.396562    1.059905    3.445191    0.198658    0.068177    0.030630    0.764932    
#> 312: 0.396144    1.059912    3.445006    0.198618    0.068081    0.030634    0.764938    
#> 313: 0.395930    1.059789    3.444941    0.198573    0.067994    0.030683    0.765003    
#> 314: 0.395632    1.059862    3.444807    0.198866    0.067890    0.030702    0.764872    
#> 315: 0.395230    1.060184    3.444695    0.199066    0.067983    0.030743    0.764716    
#> 316: 0.395041    1.060516    3.444486    0.199308    0.068089    0.030713    0.764542    
#> 317: 0.394672    1.060760    3.444376    0.199251    0.068197    0.030686    0.764648    
#> 318: 0.394554    1.061006    3.444198    0.199213    0.068401    0.030662    0.764591    
#> 319: 0.394202    1.061160    3.444118    0.198951    0.068450    0.030650    0.764765    
#> 320: 0.393748    1.061204    3.443978    0.198708    0.068518    0.030631    0.764810    
#> 321: 0.393429    1.061396    3.443812    0.198811    0.068570    0.030570    0.764851    
#> 322: 0.393355    1.061657    3.443609    0.198936    0.068579    0.030509    0.764897    
#> 323: 0.392535    1.061847    3.443359    0.199236    0.068629    0.030463    0.765019    
#> 324: 0.392229    1.062085    3.443208    0.199413    0.068598    0.030454    0.764856    
#> 325: 0.391727    1.062390    3.442976    0.199373    0.068563    0.030421    0.764649    
#> 326: 0.391591    1.062418    3.442756    0.199316    0.068531    0.030428    0.764564    
#> 327: 0.391684    1.062609    3.442694    0.199369    0.068509    0.030424    0.764531    
#> 328: 0.391786    1.062791    3.442612    0.199451    0.068538    0.030417    0.764355    
#> 329: 0.391910    1.062925    3.442571    0.199581    0.068548    0.030378    0.764368    
#> 330: 0.391741    1.063037    3.442585    0.199380    0.068563    0.030364    0.764339    
#> 331: 0.391990    1.063220    3.442643    0.199375    0.068571    0.030366    0.764367    
#> 332: 0.392167    1.063169    3.442754    0.199389    0.068502    0.030355    0.764479    
#> 333: 0.392009    1.063390    3.442665    0.199448    0.068495    0.030302    0.764570    
#> 334: 0.391655    1.063500    3.442435    0.199425    0.068532    0.030264    0.764612    
#> 335: 0.391335    1.063596    3.442307    0.199477    0.068437    0.030250    0.764506    
#> 336: 0.390969    1.063822    3.442194    0.199443    0.068388    0.030235    0.764451    
#> 337: 0.390742    1.064149    3.442069    0.199529    0.068369    0.030226    0.764405    
#> 338: 0.390675    1.064209    3.442054    0.199491    0.068288    0.030218    0.764347    
#> 339: 0.390426    1.064265    3.441972    0.199390    0.068297    0.030213    0.764110    
#> 340: 0.390179    1.064165    3.441886    0.199503    0.068368    0.030206    0.763874    
#> 341: 0.390102    1.064201    3.441832    0.199609    0.068395    0.030184    0.763790    
#> 342: 0.389874    1.064170    3.441825    0.199551    0.068388    0.030113    0.763665    
#> 343: 0.389462    1.064236    3.441734    0.199383    0.068395    0.030060    0.763742    
#> 344: 0.389582    1.064224    3.441761    0.199528    0.068436    0.030022    0.763727    
#> 345: 0.389915    1.064117    3.441877    0.199518    0.068532    0.029987    0.763576    
#> 346: 0.390064    1.064113    3.441818    0.199472    0.068552    0.029974    0.763453    
#> 347: 0.390306    1.063878    3.441832    0.199592    0.068496    0.029971    0.763477    
#> 348: 0.390328    1.063909    3.441752    0.199526    0.068438    0.029961    0.763644    
#> 349: 0.390235    1.063757    3.441666    0.199434    0.068484    0.029932    0.763696    
#> 350: 0.390011    1.063594    3.441584    0.199345    0.068553    0.029911    0.763737    
#> 351: 0.389994    1.063771    3.441521    0.199196    0.068671    0.029927    0.763675    
#> 352: 0.389788    1.064022    3.441424    0.199171    0.068753    0.029956    0.763697    
#> 353: 0.389716    1.064205    3.441358    0.199204    0.068867    0.029963    0.763642    
#> 354: 0.389702    1.064248    3.441219    0.199271    0.068905    0.029973    0.763556    
#> 355: 0.389858    1.064190    3.441130    0.199567    0.069022    0.029940    0.763430    
#> 356: 0.389843    1.064109    3.441146    0.199625    0.069077    0.029881    0.763525    
#> 357: 0.390074    1.064118    3.441217    0.199595    0.069036    0.029854    0.763398    
#> 358: 0.390206    1.064152    3.441204    0.199563    0.068949    0.029850    0.763399    
#> 359: 0.389931    1.064344    3.441101    0.199253    0.069007    0.029831    0.763294    
#> 360: 0.389637    1.064529    3.440891    0.198991    0.068944    0.029824    0.763184    
#> 361: 0.389403    1.064695    3.440774    0.198713    0.068916    0.029814    0.763019    
#> 362: 0.389421    1.064758    3.440674    0.198530    0.068886    0.029819    0.762872    
#> 363: 0.389415    1.064813    3.440686    0.198279    0.068819    0.029830    0.762619    
#> 364: 0.389474    1.064889    3.440661    0.198203    0.068742    0.029816    0.762544    
#> 365: 0.389436    1.064870    3.440685    0.198201    0.068759    0.029828    0.762522    
#> 366: 0.389277    1.065043    3.440604    0.198021    0.068729    0.029821    0.762533    
#> 367: 0.389118    1.065259    3.440523    0.197936    0.068661    0.029800    0.762539    
#> 368: 0.388955    1.065492    3.440327    0.198298    0.068685    0.029805    0.762389    
#> 369: 0.388716    1.065609    3.440162    0.198639    0.068610    0.029791    0.762328    
#> 370: 0.388398    1.065701    3.440039    0.198767    0.068638    0.029774    0.762377    
#> 371: 0.388016    1.065797    3.439880    0.198819    0.068643    0.029755    0.762394    
#> 372: 0.387848    1.065972    3.439816    0.198776    0.068737    0.029726    0.762467    
#> 373: 0.387759    1.066207    3.439748    0.198967    0.068804    0.029731    0.762624    
#> 374: 0.387632    1.066306    3.439613    0.199172    0.068752    0.029744    0.762710    
#> 375: 0.387487    1.066369    3.439583    0.199106    0.068741    0.029731    0.762784    
#> 376: 0.387363    1.066471    3.439503    0.198920    0.068716    0.029693    0.762801    
#> 377: 0.387305    1.066660    3.439441    0.198742    0.068789    0.029654    0.762765    
#> 378: 0.386996    1.066671    3.439372    0.198641    0.068755    0.029653    0.762738    
#> 379: 0.386790    1.066534    3.439383    0.198725    0.068698    0.029648    0.762759    
#> 380: 0.386648    1.066453    3.439404    0.198674    0.068769    0.029662    0.762660    
#> 381: 0.386449    1.066498    3.439346    0.198791    0.068833    0.029649    0.762621    
#> 382: 0.386405    1.066417    3.439336    0.198916    0.068771    0.029665    0.762466    
#> 383: 0.386582    1.066392    3.439395    0.198958    0.068750    0.029665    0.762289    
#> 384: 0.386637    1.066358    3.439470    0.198813    0.068770    0.029682    0.762148    
#> 385: 0.386936    1.066374    3.439496    0.198783    0.068750    0.029677    0.762075    
#> 386: 0.387208    1.066473    3.439564    0.198739    0.068794    0.029669    0.762055    
#> 387: 0.387421    1.066490    3.439698    0.198585    0.068795    0.029635    0.762117    
#> 388: 0.387543    1.066506    3.439782    0.198611    0.068838    0.029582    0.762213    
#> 389: 0.387494    1.066372    3.439735    0.198721    0.068878    0.029544    0.762383    
#> 390: 0.387348    1.066294    3.439709    0.198726    0.068894    0.029489    0.762481    
#> 391: 0.387334    1.066276    3.439721    0.198624    0.068862    0.029468    0.762509    
#> 392: 0.387377    1.066360    3.439752    0.198668    0.069012    0.029455    0.762562    
#> 393: 0.387258    1.066394    3.439684    0.198792    0.069054    0.029443    0.762526    
#> 394: 0.387147    1.066452    3.439569    0.198942    0.069057    0.029434    0.762564    
#> 395: 0.387279    1.066533    3.439534    0.198744    0.069178    0.029417    0.762686    
#> 396: 0.387327    1.066639    3.439518    0.198694    0.069216    0.029403    0.762679    
#> 397: 0.387318    1.066690    3.439509    0.198664    0.069278    0.029379    0.762643    
#> 398: 0.387349    1.066674    3.439484    0.198660    0.069278    0.029362    0.762626    
#> 399: 0.387461    1.066648    3.439522    0.198805    0.069297    0.029352    0.762521    
#> 400: 0.387537    1.066601    3.439577    0.198981    0.069316    0.029344    0.762430    
#> 401: 0.387611    1.066645    3.439604    0.199004    0.069310    0.029340    0.762470    
#> 402: 0.387598    1.066760    3.439625    0.199028    0.069379    0.029332    0.762484    
#> 403: 0.387917    1.066711    3.439721    0.198885    0.069357    0.029318    0.762424    
#> 404: 0.388164    1.066704    3.439762    0.198701    0.069385    0.029318    0.762295    
#> 405: 0.388154    1.066676    3.439795    0.198374    0.069387    0.029305    0.762259    
#> 406: 0.388271    1.066637    3.439820    0.198173    0.069467    0.029285    0.762306    
#> 407: 0.388437    1.066569    3.439904    0.198030    0.069468    0.029302    0.762288    
#> 408: 0.388480    1.066594    3.439912    0.197844    0.069444    0.029295    0.762356    
#> 409: 0.388444    1.066465    3.439898    0.197745    0.069428    0.029291    0.762358    
#> 410: 0.388345    1.066464    3.439859    0.197807    0.069434    0.029288    0.762372    
#> 411: 0.388433    1.066320    3.439873    0.197689    0.069428    0.029280    0.762448    
#> 412: 0.388546    1.066344    3.439902    0.197518    0.069385    0.029282    0.762428    
#> 413: 0.388715    1.066299    3.439922    0.197241    0.069415    0.029268    0.762507    
#> 414: 0.388573    1.066282    3.439933    0.197158    0.069472    0.029267    0.762413    
#> 415: 0.388544    1.066304    3.439879    0.197001    0.069522    0.029264    0.762303    
#> 416: 0.388578    1.066383    3.439885    0.196917    0.069551    0.029278    0.762280    
#> 417: 0.388590    1.066476    3.439858    0.196841    0.069530    0.029252    0.762289    
#> 418: 0.388408    1.066481    3.439812    0.196644    0.069457    0.029241    0.762231    
#> 419: 0.388339    1.066544    3.439737    0.196513    0.069394    0.029216    0.762239    
#> 420: 0.388387    1.066481    3.439790    0.196458    0.069372    0.029205    0.762196    
#> 421: 0.388406    1.066479    3.439875    0.196340    0.069382    0.029213    0.762139    
#> 422: 0.388728    1.066272    3.439976    0.196283    0.069375    0.029232    0.762102    
#> 423: 0.388864    1.066124    3.440038    0.196288    0.069431    0.029243    0.762066    
#> 424: 0.388826    1.066018    3.439995    0.196260    0.069430    0.029236    0.762141    
#> 425: 0.388972    1.065949    3.439978    0.196450    0.069480    0.029240    0.762249    
#> 426: 0.389088    1.065991    3.439969    0.196482    0.069543    0.029237    0.762238    
#> 427: 0.388998    1.065925    3.439984    0.196575    0.069507    0.029246    0.762129    
#> 428: 0.388952    1.065968    3.439979    0.196532    0.069493    0.029223    0.762126    
#> 429: 0.388976    1.065985    3.440000    0.196558    0.069459    0.029207    0.762197    
#> 430: 0.388729    1.066021    3.439980    0.196298    0.069484    0.029191    0.762225    
#> 431: 0.388559    1.066021    3.439909    0.196196    0.069466    0.029174    0.762239    
#> 432: 0.388518    1.066070    3.439880    0.196210    0.069493    0.029167    0.762259    
#> 433: 0.388634    1.066130    3.439885    0.196237    0.069543    0.029180    0.762227    
#> 434: 0.388553    1.066089    3.439856    0.196256    0.069626    0.029166    0.762144    
#> 435: 0.388697    1.066033    3.439894    0.196284    0.069640    0.029171    0.762055    
#> 436: 0.388766    1.065947    3.439939    0.196344    0.069685    0.029138    0.762039    
#> 437: 0.388677    1.065866    3.439928    0.196177    0.069730    0.029125    0.762078    
#> 438: 0.388702    1.065978    3.439923    0.196114    0.069726    0.029114    0.762083    
#> 439: 0.388821    1.065982    3.439959    0.196070    0.069688    0.029114    0.762055    
#> 440: 0.388874    1.065993    3.440013    0.196072    0.069629    0.029093    0.762094    
#> 441: 0.388939    1.065933    3.440070    0.196048    0.069616    0.029106    0.762014    
#> 442: 0.388896    1.065956    3.440112    0.195945    0.069575    0.029105    0.761943    
#> 443: 0.388875    1.065971    3.440087    0.195884    0.069517    0.029132    0.761942    
#> 444: 0.388838    1.066015    3.440015    0.195844    0.069447    0.029168    0.761939    
#> 445: 0.388894    1.066073    3.439980    0.196076    0.069336    0.029207    0.761886    
#> 446: 0.388821    1.066131    3.439968    0.196153    0.069232    0.029225    0.761781    
#> 447: 0.388992    1.066157    3.439990    0.196247    0.069166    0.029252    0.761771    
#> 448: 0.389026    1.066134    3.440046    0.196159    0.069107    0.029281    0.761684    
#> 449: 0.389136    1.066120    3.440159    0.196034    0.069109    0.029276    0.761719    
#> 450: 0.389242    1.066068    3.440193    0.196044    0.069098    0.029248    0.761737    
#> 451: 0.389422    1.066075    3.440194    0.196168    0.069137    0.029221    0.761770    
#> 452: 0.389445    1.066139    3.440166    0.196194    0.069117    0.029211    0.761738    
#> 453: 0.389362    1.066140    3.440141    0.196096    0.069089    0.029217    0.761639    
#> 454: 0.389363    1.066217    3.440126    0.196137    0.069032    0.029235    0.761538    
#> 455: 0.389467    1.066284    3.440123    0.196324    0.069005    0.029264    0.761373    
#> 456: 0.389380    1.066363    3.440114    0.196362    0.069026    0.029274    0.761283    
#> 457: 0.389360    1.066390    3.440128    0.196413    0.069038    0.029264    0.761228    
#> 458: 0.389377    1.066510    3.440132    0.196502    0.069042    0.029244    0.761178    
#> 459: 0.389289    1.066606    3.440122    0.196522    0.069095    0.029213    0.761162    
#> 460: 0.389146    1.066672    3.440032    0.196475    0.069137    0.029205    0.761133    
#> 461: 0.388969    1.066730    3.440008    0.196421    0.069174    0.029203    0.761153    
#> 462: 0.388815    1.066803    3.439996    0.196317    0.069158    0.029183    0.761216    
#> 463: 0.388764    1.066887    3.439966    0.196160    0.069162    0.029167    0.761331    
#> 464: 0.388725    1.066918    3.439957    0.196099    0.069136    0.029168    0.761312    
#> 465: 0.388730    1.066813    3.439962    0.195940    0.069148    0.029151    0.761321    
#> 466: 0.388788    1.066808    3.439929    0.195797    0.069175    0.029123    0.761391    
#> 467: 0.388717    1.066807    3.439967    0.195633    0.069137    0.029128    0.761347    
#> 468: 0.388876    1.066775    3.440049    0.195637    0.069102    0.029134    0.761335    
#> 469: 0.388914    1.066799    3.440094    0.195766    0.069079    0.029155    0.761375    
#> 470: 0.388871    1.066827    3.440046    0.195896    0.069019    0.029175    0.761389    
#> 471: 0.388731    1.066831    3.440016    0.195913    0.068988    0.029166    0.761353    
#> 472: 0.388648    1.066841    3.439990    0.195884    0.068979    0.029163    0.761350    
#> 473: 0.388570    1.066831    3.440004    0.195764    0.068992    0.029147    0.761294    
#> 474: 0.388493    1.066812    3.440007    0.195691    0.069050    0.029137    0.761317    
#> 475: 0.388493    1.066909    3.440002    0.195596    0.069039    0.029139    0.761269    
#> 476: 0.388520    1.066900    3.440007    0.195544    0.069052    0.029148    0.761247    
#> 477: 0.388450    1.066863    3.440035    0.195564    0.069028    0.029162    0.761183    
#> 478: 0.388360    1.066848    3.440004    0.195625    0.068997    0.029156    0.761178    
#> 479: 0.388395    1.066896    3.439987    0.195717    0.069000    0.029135    0.761151    
#> 480: 0.388442    1.066907    3.439969    0.195766    0.068997    0.029147    0.761199    
#> 481: 0.388445    1.066844    3.440003    0.195723    0.068946    0.029160    0.761170    
#> 482: 0.388555    1.066821    3.439989    0.195860    0.068923    0.029169    0.761156    
#> 483: 0.388520    1.066785    3.440018    0.195976    0.068905    0.029171    0.761108    
#> 484: 0.388573    1.066620    3.440085    0.195984    0.068897    0.029179    0.761108    
#> 485: 0.388565    1.066576    3.440110    0.196071    0.068951    0.029174    0.761054    
#> 486: 0.388582    1.066544    3.440184    0.196040    0.068930    0.029170    0.760991    
#> 487: 0.388831    1.066512    3.440257    0.195978    0.068912    0.029161    0.760954    
#> 488: 0.388869    1.066449    3.440311    0.196013    0.068922    0.029163    0.760903    
#> 489: 0.389030    1.066387    3.440327    0.196018    0.068936    0.029144    0.760914    
#> 490: 0.389155    1.066378    3.440398    0.196085    0.068931    0.029124    0.760949    
#> 491: 0.389238    1.066363    3.440473    0.196006    0.068889    0.029115    0.761001    
#> 492: 0.389221    1.066389    3.440457    0.195935    0.068866    0.029115    0.761046    
#> 493: 0.389189    1.066364    3.440484    0.195995    0.068884    0.029117    0.761039    
#> 494: 0.389274    1.066414    3.440457    0.195972    0.068865    0.029114    0.761037    
#> 495: 0.389357    1.066474    3.440468    0.195981    0.068877    0.029126    0.760958    
#> 496: 0.389487    1.066524    3.440459    0.196128    0.068877    0.029138    0.760950    
#> 497: 0.389491    1.066557    3.440430    0.196337    0.068901    0.029140    0.761011    
#> 498: 0.389601    1.066512    3.440451    0.196258    0.068898    0.029127    0.761038    
#> 499: 0.389654    1.066530    3.440432    0.196147    0.068883    0.029117    0.761067    
#> 500: 0.389776    1.066501    3.440451    0.196120    0.068883    0.029109    0.761043    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.319491    0.975570    3.440859    0.392401    0.079456    0.016800    1.796036    
#> 002: 0.539392    0.989105    3.468656    0.372781    0.075484    0.015960    1.247662    
#> 003: 0.747856    0.984349    3.472016    0.354142    0.071709    0.015162    0.962905    
#> 004: 0.840552    0.987721    3.492115    0.500625    0.068124    0.014404    0.747248    
#> 005: 0.893953    0.998313    3.480129    0.557471    0.068537    0.013684    0.668887    
#> 006: 0.927613    1.008389    3.479299    0.647461    0.080682    0.014613    0.585708    
#> 007: 0.974087    1.007595    3.487554    0.697502    0.076947    0.014349    0.587779    
#> 008: 0.914450    1.009383    3.484409    0.701285    0.091280    0.014058    0.571740    
#> 009: 0.933520    0.978537    3.485224    0.808284    0.086716    0.013355    0.558473    
#> 010: 0.953563    0.992947    3.482622    0.883704    0.082380    0.015489    0.566662    
#> 011: 0.972336    1.001990    3.488990    0.839518    0.083566    0.014715    0.566864    
#> 012: 1.024155    0.999379    3.491097    0.919589    0.083610    0.013979    0.551221    
#> 013: 0.981526    1.002343    3.486317    0.925237    0.079429    0.013304    0.558984    
#> 014: 1.060098    1.002786    3.493834    1.172498    0.088301    0.013096    0.567678    
#> 015: 1.062094    1.007028    3.494220    1.113873    0.083886    0.013514    0.553131    
#> 016: 1.076180    1.013630    3.496325    1.135042    0.079691    0.017337    0.559418    
#> 017: 1.068408    1.026061    3.489929    1.084598    0.075707    0.016470    0.551498    
#> 018: 1.100704    1.013272    3.486369    1.199117    0.071921    0.015647    0.548303    
#> 019: 0.987356    1.013383    3.490461    1.139161    0.068325    0.015950    0.528912    
#> 020: 1.055882    1.009765    3.490262    1.082203    0.074817    0.018222    0.544776    
#> 021: 1.040541    1.003641    3.486782    1.028093    0.071076    0.017310    0.547934    
#> 022: 1.001946    1.014935    3.493080    0.976688    0.067522    0.016767    0.543631    
#> 023: 1.092584    1.014903    3.501291    1.037997    0.064146    0.018311    0.546472    
#> 024: 1.065622    1.013204    3.500109    0.986097    0.062697    0.018822    0.525660    
#> 025: 1.057370    1.001432    3.484139    1.076995    0.059562    0.017881    0.541111    
#> 026: 1.078344    1.025559    3.486074    1.148074    0.073074    0.016987    0.549205    
#> 027: 1.017947    1.029471    3.481417    1.090670    0.069457    0.016138    0.532559    
#> 028: 1.107635    1.007042    3.489182    1.237373    0.065984    0.019030    0.532236    
#> 029: 1.071193    1.017291    3.480829    1.278103    0.062685    0.021267    0.550725    
#> 030: 1.020193    1.026361    3.466593    1.288790    0.067600    0.020204    0.539754    
#> 031: 1.046209    1.014739    3.479256    1.306487    0.065925    0.019194    0.555489    
#> 032: 1.031334    1.006406    3.484398    1.241163    0.079870    0.018587    0.553448    
#> 033: 1.019111    1.020782    3.484100    1.179105    0.081459    0.018897    0.556013    
#> 034: 1.058300    1.024122    3.487133    1.120149    0.077386    0.017952    0.553873    
#> 035: 1.005458    1.008614    3.482437    1.064142    0.077442    0.017054    0.543577    
#> 036: 1.070390    1.016648    3.483773    1.039583    0.073570    0.016201    0.540176    
#> 037: 1.070721    1.026130    3.490344    1.208500    0.069892    0.015391    0.558370    
#> 038: 1.136078    1.016565    3.485125    1.330536    0.068855    0.015351    0.546422    
#> 039: 1.120952    1.021943    3.492301    1.271833    0.067768    0.014584    0.551479    
#> 040: 1.088680    1.017450    3.496573    1.208241    0.074266    0.015834    0.554785    
#> 041: 0.999123    1.002078    3.489538    1.147829    0.081928    0.015042    0.548059    
#> 042: 1.109238    1.003645    3.492042    1.151324    0.077832    0.015375    0.538921    
#> 043: 1.060685    1.027417    3.488259    1.093758    0.073940    0.017256    0.541461    
#> 044: 1.107537    1.032216    3.484891    1.151139    0.070243    0.016394    0.542298    
#> 045: 1.025781    1.043126    3.472446    1.114940    0.082148    0.015574    0.525428    
#> 046: 1.087899    1.025478    3.483955    1.311769    0.078041    0.014795    0.539693    
#> 047: 1.160029    1.022242    3.484905    1.438293    0.077300    0.014055    0.531329    
#> 048: 1.060221    1.015843    3.475826    1.366378    0.073435    0.014591    0.537599    
#> 049: 1.064871    1.029892    3.472416    1.301430    0.069764    0.013861    0.550935    
#> 050: 1.111224    1.010317    3.480633    1.311482    0.069897    0.015118    0.553691    
#> 051: 1.158976    1.037860    3.469423    1.458985    0.066402    0.014362    0.560997    
#> 052: 1.156092    1.041301    3.483298    1.386036    0.069783    0.013644    0.546183    
#> 053: 1.081044    1.009195    3.484906    1.316734    0.072272    0.014002    0.543987    
#> 054: 1.068035    1.011165    3.485840    1.250898    0.070544    0.013772    0.558336    
#> 055: 1.048797    1.024174    3.480536    1.321459    0.077728    0.013084    0.562048    
#> 056: 1.059975    1.006119    3.475098    1.258354    0.086787    0.012430    0.566744    
#> 057: 1.013127    1.022875    3.478556    1.195436    0.084588    0.011808    0.564008    
#> 058: 0.969954    1.009042    3.468014    1.135665    0.080359    0.011650    0.569966    
#> 059: 0.978905    0.986767    3.477372    1.078881    0.079605    0.012100    0.569678    
#> 060: 1.042659    0.999303    3.485350    1.153460    0.075625    0.014529    0.569460    
#> 061: 1.047384    0.995245    3.492896    1.095787    0.071843    0.014426    0.570073    
#> 062: 1.033857    1.006027    3.491416    1.049040    0.068251    0.019930    0.574498    
#> 063: 1.126582    0.993662    3.482721    1.372409    0.064839    0.020442    0.565077    
#> 064: 1.100363    1.008913    3.484382    1.368770    0.066626    0.021815    0.571527    
#> 065: 1.094703    0.987643    3.478619    1.318888    0.063295    0.020724    0.563321    
#> 066: 1.089880    1.005829    3.480314    1.359371    0.061747    0.019688    0.548214    
#> 067: 1.047980    1.018409    3.477579    1.291403    0.062545    0.020656    0.536426    
#> 068: 0.951078    1.026605    3.465057    1.226832    0.062913    0.019623    0.558992    
#> 069: 0.985214    1.028857    3.467151    1.165491    0.068517    0.019218    0.541985    
#> 070: 1.008628    1.019023    3.474052    1.143315    0.065091    0.019505    0.534181    
#> 071: 0.977303    1.035866    3.464849    1.086149    0.066979    0.018530    0.543739    
#> 072: 0.903803    1.019107    3.467889    1.031842    0.063630    0.018763    0.539491    
#> 073: 0.940422    1.027800    3.481321    0.980249    0.060448    0.018364    0.537446    
#> 074: 0.977895    1.003696    3.474700    0.931237    0.066098    0.018690    0.540650    
#> 075: 0.999875    1.009186    3.493924    1.051671    0.074174    0.018250    0.544660    
#> 076: 1.040469    1.011790    3.493863    1.045130    0.080159    0.018388    0.547855    
#> 077: 1.050377    1.012374    3.489263    1.045334    0.078024    0.017469    0.546909    
#> 078: 1.058927    1.004650    3.490152    1.105086    0.075622    0.016595    0.547134    
#> 079: 1.041427    1.010415    3.485649    1.073996    0.071841    0.015766    0.562542    
#> 080: 0.998651    1.003062    3.472580    1.020296    0.075438    0.014977    0.568684    
#> 081: 1.020888    1.029184    3.473448    1.031174    0.071666    0.014410    0.554669    
#> 082: 0.985708    1.011505    3.483543    0.998257    0.068083    0.013690    0.572048    
#> 083: 1.034394    1.027416    3.488936    1.026774    0.065033    0.013005    0.567362    
#> 084: 1.001169    1.024897    3.488905    0.975436    0.081502    0.012355    0.546759    
#> 085: 1.060262    1.021200    3.490742    1.190172    0.078087    0.011737    0.542748    
#> 086: 1.015094    1.028148    3.479269    1.130664    0.074182    0.012042    0.531361    
#> 087: 1.005478    1.018428    3.482004    1.074131    0.071117    0.012092    0.534693    
#> 088: 0.955716    1.005146    3.483735    1.020424    0.067561    0.011488    0.568373    
#> 089: 0.966528    1.014927    3.478388    0.969403    0.071390    0.015281    0.556589    
#> 090: 1.001134    1.013957    3.480402    0.920933    0.076441    0.015219    0.550403    
#> 091: 1.018674    1.007442    3.473118    0.989927    0.072619    0.014458    0.548825    
#> 092: 1.007533    1.025147    3.472104    1.089329    0.070410    0.016824    0.548219    
#> 093: 0.981884    1.024781    3.471131    1.034862    0.072538    0.015982    0.552974    
#> 094: 0.984862    1.029199    3.466925    0.989721    0.068911    0.015947    0.556064    
#> 095: 1.003873    1.037964    3.477439    1.017387    0.073914    0.020027    0.545981    
#> 096: 0.980993    1.038071    3.469344    0.980084    0.070219    0.019025    0.553668    
#> 097: 1.011168    1.041225    3.471491    0.931079    0.074715    0.018074    0.546570    
#> 098: 1.026308    1.029420    3.480656    0.910944    0.071541    0.017170    0.539809    
#> 099: 1.053241    1.003613    3.488203    1.002437    0.067964    0.017566    0.535309    
#> 100: 1.052979    1.007603    3.487482    1.074207    0.064566    0.017845    0.527041    
#> 101: 0.976331    1.005135    3.478961    1.020496    0.061338    0.018653    0.528327    
#> 102: 0.939789    1.020154    3.470871    0.969472    0.074292    0.017720    0.537236    
#> 103: 1.025681    1.018138    3.478183    0.920998    0.070577    0.016834    0.540013    
#> 104: 1.013784    1.029524    3.493348    0.940275    0.067048    0.018142    0.545805    
#> 105: 1.060238    1.004229    3.485910    1.118112    0.067088    0.017235    0.552982    
#> 106: 1.045956    1.018536    3.488313    1.163509    0.063733    0.016373    0.534564    
#> 107: 1.101787    1.022024    3.491512    1.258056    0.060612    0.017174    0.537126    
#> 108: 1.069804    1.020738    3.498046    1.198988    0.062478    0.017661    0.541940    
#> 109: 1.047383    1.010690    3.500653    1.139039    0.060013    0.017603    0.535928    
#> 110: 1.128383    0.999048    3.485579    1.259439    0.057012    0.017234    0.541436    
#> 111: 1.111708    1.002915    3.494354    1.196467    0.057621    0.016372    0.530790    
#> 112: 1.045595    0.999149    3.486274    1.136644    0.062354    0.015553    0.537611    
#> 113: 1.083412    1.028338    3.490143    1.246016    0.059236    0.014776    0.536828    
#> 114: 1.072117    1.022434    3.478154    1.216989    0.058556    0.017323    0.544099    
#> 115: 1.155745    1.002778    3.473037    1.492259    0.059264    0.017835    0.559970    
#> 116: 1.218985    1.001413    3.483128    1.663695    0.068013    0.016943    0.543695    
#> 117: 1.243138    1.005060    3.496258    1.860156    0.064612    0.016148    0.542321    
#> 118: 1.230448    0.998724    3.492314    1.825020    0.067715    0.015611    0.542279    
#> 119: 1.138685    1.007119    3.486176    1.733769    0.064766    0.019616    0.541962    
#> 120: 1.130541    1.003953    3.501167    1.647080    0.067382    0.020047    0.531634    
#> 121: 1.088593    1.016686    3.493885    1.564726    0.064013    0.022818    0.538964    
#> 122: 1.099088    0.990608    3.497716    1.486490    0.060812    0.021677    0.556692    
#> 123: 1.135575    1.015898    3.493614    1.412166    0.067202    0.020593    0.538267    
#> 124: 1.064793    1.034699    3.489031    1.341557    0.065942    0.020152    0.541238    
#> 125: 1.092559    1.038255    3.477641    1.406187    0.065696    0.022937    0.542121    
#> 126: 1.070853    1.034592    3.481172    1.350761    0.070419    0.021790    0.534807    
#> 127: 1.114822    1.015886    3.476163    1.462893    0.066898    0.020701    0.535145    
#> 128: 1.111292    1.019299    3.493960    1.389748    0.063553    0.019666    0.548318    
#> 129: 1.150425    1.015594    3.488682    1.407509    0.067866    0.018985    0.536156    
#> 130: 1.057568    1.024022    3.483644    1.337134    0.064473    0.019123    0.529335    
#> 131: 1.013022    1.014852    3.484650    1.270277    0.067053    0.022315    0.534392    
#> 132: 1.020484    1.008974    3.475466    1.206763    0.068022    0.023117    0.542066    
#> 133: 1.062083    0.986409    3.480490    1.333341    0.066310    0.022767    0.547390    
#> 134: 1.084142    0.989313    3.484869    1.401158    0.062995    0.022407    0.549954    
#> 135: 1.077424    0.992166    3.481737    1.359033    0.059845    0.021797    0.549372    
#> 136: 1.044656    0.999748    3.476519    1.291081    0.056853    0.021665    0.540913    
#> 137: 1.087347    1.001059    3.489721    1.226527    0.059365    0.022220    0.526706    
#> 138: 1.043639    1.004546    3.486286    1.165201    0.064835    0.021109    0.530691    
#> 139: 1.056965    1.016078    3.497881    1.115969    0.061594    0.020053    0.528036    
#> 140: 1.094660    1.025236    3.497261    1.288450    0.070072    0.020702    0.535401    
#> 141: 1.162347    1.009431    3.492723    1.456969    0.066569    0.019667    0.540490    
#> 142: 1.156490    0.999588    3.500719    1.410726    0.063240    0.018683    0.551479    
#> 143: 1.067482    1.011361    3.492813    1.340190    0.065726    0.017749    0.559017    
#> 144: 1.127400    1.027019    3.495352    1.273180    0.066541    0.019311    0.549551    
#> 145: 1.041154    1.031025    3.482402    1.209521    0.063264    0.021061    0.531499    
#> 146: 1.030786    1.037565    3.486487    1.149045    0.060506    0.020699    0.531437    
#> 147: 0.993312    1.019629    3.477499    1.091593    0.057481    0.020064    0.531944    
#> 148: 0.995907    1.016643    3.488217    1.037013    0.068017    0.019608    0.521342    
#> 149: 1.018245    0.987829    3.499571    0.985163    0.064616    0.023296    0.528112    
#> 150: 1.047774    1.003131    3.486872    1.024449    0.061385    0.022210    0.540098    
#> 151: 1.077696    1.038550    3.493186    1.139167    0.062147    0.021100    0.531412    
#> 152: 1.011410    1.026432    3.486986    0.992165    0.061581    0.019645    0.530618    
#> 153: 1.021024    1.022440    3.497034    1.060304    0.069126    0.018709    0.546437    
#> 154: 1.046603    1.014568    3.492490    1.095040    0.061518    0.020126    0.541796    
#> 155: 1.039939    1.003981    3.488577    1.082369    0.059346    0.018803    0.555569    
#> 156: 1.057671    0.995607    3.500025    1.061803    0.059506    0.020856    0.553807    
#> 157: 1.101899    1.001658    3.495849    1.313737    0.052979    0.025288    0.556296    
#> 158: 1.130354    1.014996    3.480373    1.399602    0.070766    0.022985    0.544867    
#> 159: 1.062078    1.022954    3.486647    1.248356    0.061581    0.021208    0.545775    
#> 160: 1.086823    1.002675    3.490790    1.290749    0.060179    0.019362    0.545109    
#> 161: 1.091860    1.022770    3.484787    1.388671    0.061060    0.018577    0.559805    
#> 162: 1.054055    1.038293    3.477542    1.251187    0.068284    0.018735    0.568155    
#> 163: 1.110374    1.030286    3.478959    1.312660    0.066305    0.019211    0.560187    
#> 164: 1.081570    1.014957    3.477934    1.223240    0.060707    0.016121    0.545048    
#> 165: 1.112652    1.009755    3.481768    1.463321    0.054099    0.015735    0.559140    
#> 166: 1.119995    1.040461    3.475637    1.425478    0.060662    0.017827    0.550264    
#> 167: 1.095566    1.045830    3.477335    1.340041    0.065900    0.017696    0.555610    
#> 168: 1.051983    1.033717    3.486099    1.259118    0.070464    0.017168    0.548884    
#> 169: 1.044606    1.051310    3.484011    1.105039    0.072031    0.015226    0.559447    
#> 170: 0.991594    1.003605    3.491496    0.975133    0.062136    0.015301    0.553843    
#> 171: 0.926042    1.013999    3.477434    0.838371    0.078483    0.011751    0.559489    
#> 172: 0.918883    1.045529    3.472065    0.791552    0.064582    0.012322    0.555441    
#> 173: 0.936494    1.037822    3.471085    0.796844    0.061071    0.012056    0.552114    
#> 174: 0.977530    1.038587    3.478072    0.831368    0.071068    0.014429    0.549059    
#> 175: 0.983948    1.032780    3.467916    0.966411    0.066184    0.016626    0.547730    
#> 176: 0.962702    1.041472    3.476332    0.908959    0.070943    0.017290    0.538391    
#> 177: 1.031233    1.028740    3.483662    1.080198    0.079282    0.018615    0.555194    
#> 178: 1.015219    1.033827    3.479147    1.004834    0.076675    0.019446    0.548034    
#> 179: 1.063253    1.045619    3.477848    1.216607    0.063135    0.018541    0.565952    
#> 180: 0.957074    1.024080    3.484407    0.841740    0.057751    0.021835    0.552085    
#> 181: 0.956200    1.018246    3.470753    0.858130    0.056860    0.019553    0.544628    
#> 182: 0.923140    1.010831    3.460070    0.840500    0.059803    0.018092    0.555375    
#> 183: 0.947091    1.037772    3.468477    0.816858    0.071242    0.016711    0.548374    
#> 184: 0.973104    1.046224    3.464935    0.970563    0.071268    0.015785    0.542745    
#> 185: 0.963480    1.044336    3.461218    0.993594    0.061173    0.015377    0.546610    
#> 186: 0.940586    1.052514    3.462781    0.972474    0.061627    0.014283    0.568027    
#> 187: 1.008646    1.042137    3.471179    1.149458    0.062442    0.014589    0.555241    
#> 188: 1.011506    1.044840    3.470012    1.123139    0.065856    0.015812    0.565441    
#> 189: 1.054322    1.043893    3.485144    1.134915    0.071757    0.013802    0.555044    
#> 190: 1.006704    1.020581    3.484011    0.998975    0.069011    0.013508    0.540247    
#> 191: 1.025462    1.026124    3.478351    1.115712    0.071812    0.013966    0.538982    
#> 192: 1.030978    1.019507    3.482412    1.080441    0.068272    0.015567    0.526749    
#> 193: 1.096325    1.032336    3.483941    1.309778    0.062842    0.017016    0.536584    
#> 194: 0.953830    1.020280    3.480216    0.815191    0.064425    0.022015    0.537219    
#> 195: 0.944755    1.015883    3.471928    0.933573    0.070822    0.020040    0.525309    
#> 196: 0.977320    1.014524    3.483858    0.977529    0.078201    0.018782    0.536109    
#> 197: 1.022623    1.004067    3.495803    1.097859    0.075719    0.021632    0.556122    
#> 198: 1.125812    0.992036    3.500080    1.344780    0.064691    0.023203    0.548320    
#> 199: 1.088387    0.992758    3.492552    1.151869    0.061654    0.026093    0.538889    
#> 200: 1.098462    0.999767    3.487940    1.327768    0.053814    0.021040    0.556871    
#> 201: 1.069872    0.998118    3.490977    1.263893    0.051376    0.021763    0.552108    
#> 202: 1.065042    0.999435    3.489562    1.248051    0.055746    0.022169    0.547825    
#> 203: 1.095183    1.002968    3.488265    1.320702    0.058682    0.021721    0.544465    
#> 204: 1.106713    1.003773    3.489178    1.370135    0.060940    0.021537    0.543068    
#> 205: 1.125673    1.010127    3.487759    1.440978    0.063066    0.021738    0.544358    
#> 206: 1.147886    1.015760    3.487274    1.540814    0.063671    0.021738    0.544312    
#> 207: 1.157196    1.016323    3.485463    1.590817    0.063244    0.021182    0.543405    
#> 208: 1.153155    1.018384    3.485193    1.560514    0.062732    0.021143    0.541988    
#> 209: 1.153940    1.017359    3.484414    1.575189    0.062530    0.020658    0.542468    
#> 210: 1.153900    1.016236    3.485066    1.558180    0.062439    0.020370    0.542506    
#> 211: 1.155145    1.016270    3.485110    1.553393    0.061582    0.020059    0.542971    
#> 212: 1.152361    1.015879    3.485138    1.538809    0.061542    0.019928    0.543583    
#> 213: 1.152899    1.014315    3.484825    1.521632    0.062143    0.019990    0.544682    
#> 214: 1.155057    1.014230    3.485424    1.509292    0.062434    0.020179    0.544790    
#> 215: 1.152752    1.014313    3.486178    1.487764    0.062259    0.020365    0.544793    
#> 216: 1.153599    1.011979    3.486817    1.482929    0.062173    0.020647    0.545624    
#> 217: 1.150911    1.012011    3.487412    1.467116    0.061522    0.020809    0.545590    
#> 218: 1.149750    1.011474    3.487176    1.452864    0.060836    0.020999    0.545863    
#> 219: 1.147432    1.011344    3.486699    1.446432    0.060713    0.021138    0.545426    
#> 220: 1.139324    1.012034    3.486163    1.429466    0.060464    0.021181    0.545247    
#> 221: 1.132446    1.012943    3.485569    1.411766    0.060661    0.021215    0.544290    
#> 222: 1.126022    1.013340    3.484804    1.398086    0.060553    0.021174    0.543660    
#> 223: 1.121098    1.014078    3.484192    1.383980    0.060850    0.021072    0.543309    
#> 224: 1.118618    1.014974    3.483716    1.376139    0.061116    0.020940    0.543098    
#> 225: 1.116625    1.014331    3.483743    1.369181    0.061856    0.020786    0.542717    
#> 226: 1.114777    1.013782    3.483588    1.362373    0.062207    0.020619    0.542239    
#> 227: 1.112567    1.013825    3.483726    1.353694    0.062224    0.020502    0.541837    
#> 228: 1.109318    1.014459    3.483270    1.345285    0.062260    0.020426    0.541715    
#> 229: 1.106931    1.014601    3.482887    1.341430    0.062395    0.020363    0.541221    
#> 230: 1.104528    1.014364    3.482721    1.336530    0.062424    0.020260    0.541079    
#> 231: 1.101529    1.013980    3.482850    1.329539    0.062587    0.020141    0.541359    
#> 232: 1.098840    1.013825    3.482917    1.318661    0.062603    0.020161    0.541077    
#> 233: 1.098450    1.012933    3.483116    1.316744    0.062544    0.020166    0.540966    
#> 234: 1.097168    1.012268    3.483214    1.311939    0.062397    0.020098    0.540987    
#> 235: 1.095320    1.012168    3.483262    1.304461    0.062538    0.020018    0.540890    
#> 236: 1.094435    1.012437    3.483445    1.297408    0.062568    0.019997    0.540936    
#> 237: 1.093553    1.012163    3.483568    1.292422    0.062441    0.020017    0.541364    
#> 238: 1.092229    1.011583    3.483851    1.285085    0.062539    0.020159    0.541711    
#> 239: 1.091361    1.011582    3.483875    1.281504    0.062527    0.020187    0.541915    
#> 240: 1.092656    1.011385    3.484161    1.283591    0.062508    0.020181    0.541724    
#> 241: 1.092704    1.010711    3.484281    1.283334    0.062411    0.020199    0.541536    
#> 242: 1.091093    1.010175    3.484249    1.278038    0.062414    0.020180    0.541782    
#> 243: 1.089480    1.010533    3.484211    1.272648    0.062284    0.020199    0.542205    
#> 244: 1.087604    1.010372    3.484355    1.265578    0.062419    0.020234    0.542107    
#> 245: 1.086308    1.010083    3.484522    1.260227    0.062593    0.020321    0.542202    
#> 246: 1.086076    1.010338    3.484706    1.257216    0.062808    0.020394    0.542090    
#> 247: 1.086055    1.010158    3.484939    1.255257    0.062705    0.020461    0.541965    
#> 248: 1.084939    1.010260    3.485039    1.249216    0.062813    0.020468    0.541903    
#> 249: 1.082982    1.010238    3.484987    1.244566    0.062981    0.020429    0.541823    
#> 250: 1.083449    1.010268    3.485199    1.241118    0.062873    0.020418    0.541956    
#> 251: 1.083199    1.010342    3.485495    1.237803    0.062786    0.020393    0.541956    
#> 252: 1.083965    1.010319    3.486045    1.236466    0.062745    0.020384    0.542240    
#> 253: 1.084269    1.010132    3.486347    1.234097    0.062918    0.020391    0.542420    
#> 254: 1.084307    1.010205    3.486580    1.231274    0.062833    0.020432    0.542605    
#> 255: 1.084475    1.010280    3.486682    1.230128    0.062730    0.020454    0.542598    
#> 256: 1.084232    1.010146    3.486830    1.227577    0.062657    0.020450    0.542613    
#> 257: 1.083252    1.009694    3.486983    1.222498    0.062586    0.020435    0.542907    
#> 258: 1.082861    1.009110    3.487201    1.218563    0.062511    0.020414    0.542990    
#> 259: 1.082675    1.008762    3.487341    1.217879    0.062609    0.020414    0.543174    
#> 260: 1.082412    1.008432    3.487668    1.215807    0.062688    0.020404    0.543183    
#> 261: 1.081837    1.008182    3.487944    1.211389    0.062690    0.020406    0.543184    
#> 262: 1.081968    1.008232    3.488069    1.211395    0.062603    0.020424    0.543077    
#> 263: 1.081466    1.008369    3.488119    1.210040    0.062483    0.020377    0.543009    
#> 264: 1.081307    1.008623    3.488089    1.209694    0.062619    0.020337    0.543223    
#> 265: 1.081344    1.008631    3.488040    1.210700    0.062536    0.020362    0.543404    
#> 266: 1.082571    1.008792    3.488070    1.214830    0.062437    0.020342    0.543422    
#> 267: 1.084005    1.008706    3.488197    1.220954    0.062233    0.020358    0.543528    
#> 268: 1.084486    1.008598    3.488193    1.222862    0.062271    0.020347    0.543398    
#> 269: 1.085299    1.008366    3.488257    1.225070    0.062216    0.020356    0.543367    
#> 270: 1.086726    1.008526    3.488222    1.227278    0.062161    0.020316    0.543262    
#> 271: 1.086597    1.008636    3.488108    1.227233    0.062089    0.020274    0.543308    
#> 272: 1.086716    1.008571    3.488050    1.226980    0.062014    0.020324    0.543593    
#> 273: 1.086637    1.008829    3.488139    1.226435    0.061935    0.020360    0.543773    
#> 274: 1.085808    1.009024    3.488276    1.224361    0.061811    0.020417    0.543868    
#> 275: 1.086268    1.008913    3.488272    1.225941    0.061700    0.020466    0.543942    
#> 276: 1.086897    1.008896    3.488368    1.228675    0.061535    0.020546    0.543926    
#> 277: 1.086462    1.009073    3.488524    1.229220    0.061392    0.020598    0.543943    
#> 278: 1.086106    1.009346    3.488564    1.228905    0.061320    0.020636    0.543857    
#> 279: 1.084471    1.009250    3.488539    1.225298    0.061295    0.020625    0.543913    
#> 280: 1.083117    1.009400    3.488467    1.221972    0.061306    0.020575    0.543803    
#> 281: 1.082671    1.009468    3.488484    1.220860    0.061256    0.020548    0.543608    
#> 282: 1.083070    1.009519    3.488474    1.222821    0.061201    0.020511    0.543497    
#> 283: 1.083501    1.009730    3.488381    1.224776    0.061229    0.020511    0.543577    
#> 284: 1.083553    1.009605    3.488415    1.225476    0.061164    0.020507    0.543453    
#> 285: 1.084339    1.009503    3.488348    1.229016    0.061071    0.020511    0.543357    
#> 286: 1.085319    1.009645    3.488187    1.231739    0.060992    0.020509    0.543319    
#> 287: 1.086577    1.009706    3.488028    1.236967    0.061020    0.020530    0.543108    
#> 288: 1.087082    1.009800    3.487894    1.241036    0.060926    0.020588    0.543346    
#> 289: 1.086750    1.010057    3.487749    1.242039    0.060891    0.020618    0.543398    
#> 290: 1.087245    1.010057    3.487703    1.244889    0.060896    0.020647    0.543510    
#> 291: 1.087919    1.010226    3.487768    1.245461    0.060904    0.020680    0.543456    
#> 292: 1.087714    1.010232    3.487806    1.244287    0.060943    0.020671    0.543465    
#> 293: 1.088066    1.010289    3.487782    1.244584    0.060952    0.020659    0.543637    
#> 294: 1.088059    1.010470    3.487700    1.244603    0.061018    0.020636    0.543618    
#> 295: 1.087412    1.010370    3.487622    1.242411    0.061014    0.020599    0.543586    
#> 296: 1.086219    1.010350    3.487545    1.239229    0.061043    0.020589    0.543621    
#> 297: 1.085341    1.010407    3.487554    1.237452    0.061057    0.020588    0.543644    
#> 298: 1.085177    1.010322    3.487576    1.236819    0.061094    0.020602    0.543536    
#> 299: 1.084726    1.010308    3.487447    1.236004    0.061055    0.020620    0.543480    
#> 300: 1.084460    1.010147    3.487488    1.235934    0.061082    0.020637    0.543361    
#> 301: 1.084226    1.010038    3.487471    1.234139    0.061058    0.020637    0.543492    
#> 302: 1.083854    1.010291    3.487357    1.232984    0.060998    0.020629    0.543682    
#> 303: 1.083431    1.010627    3.487202    1.231965    0.061143    0.020586    0.543588    
#> 304: 1.083729    1.011045    3.487031    1.233480    0.061303    0.020546    0.543488    
#> 305: 1.083802    1.011086    3.486836    1.235295    0.061352    0.020506    0.543529    
#> 306: 1.083124    1.011137    3.486640    1.235412    0.061478    0.020462    0.543550    
#> 307: 1.082376    1.011182    3.486461    1.236137    0.061572    0.020439    0.543733    
#> 308: 1.082280    1.011280    3.486353    1.237255    0.061584    0.020397    0.543844    
#> 309: 1.083003    1.011236    3.486267    1.240600    0.061660    0.020356    0.544021    
#> 310: 1.083048    1.011166    3.486113    1.241617    0.061667    0.020315    0.544064    
#> 311: 1.083355    1.011126    3.485986    1.244889    0.061666    0.020261    0.544046    
#> 312: 1.083669    1.011062    3.485916    1.247878    0.061608    0.020229    0.543992    
#> 313: 1.084136    1.010878    3.485845    1.250832    0.061564    0.020214    0.544214    
#> 314: 1.083815    1.010920    3.485765    1.250282    0.061535    0.020198    0.544376    
#> 315: 1.082901    1.011049    3.485705    1.247586    0.061577    0.020185    0.544419    
#> 316: 1.083051    1.011052    3.485678    1.247375    0.061703    0.020135    0.544492    
#> 317: 1.082542    1.011014    3.485641    1.245148    0.061806    0.020098    0.544638    
#> 318: 1.081943    1.011046    3.485530    1.243211    0.061904    0.020053    0.544732    
#> 319: 1.081353    1.010997    3.485485    1.241558    0.062036    0.020021    0.544811    
#> 320: 1.080814    1.011034    3.485409    1.241071    0.062146    0.019962    0.544932    
#> 321: 1.080342    1.011154    3.485326    1.240727    0.062217    0.019923    0.544988    
#> 322: 1.079311    1.011256    3.485243    1.238966    0.062223    0.019887    0.544971    
#> 323: 1.078400    1.011322    3.485159    1.237257    0.062202    0.019848    0.545012    
#> 324: 1.077866    1.011377    3.485188    1.235016    0.062248    0.019824    0.544967    
#> 325: 1.077213    1.011476    3.485118    1.232854    0.062249    0.019812    0.544920    
#> 326: 1.077188    1.011290    3.485078    1.232652    0.062128    0.019793    0.544894    
#> 327: 1.077585    1.011350    3.485099    1.233733    0.062033    0.019780    0.544841    
#> 328: 1.077869    1.011417    3.485102    1.234290    0.061991    0.019798    0.544722    
#> 329: 1.078045    1.011446    3.485151    1.234347    0.061890    0.019819    0.544588    
#> 330: 1.077607    1.011407    3.485181    1.232293    0.061898    0.019819    0.544484    
#> 331: 1.077467    1.011500    3.485263    1.231166    0.061890    0.019797    0.544421    
#> 332: 1.077172    1.011521    3.485325    1.229966    0.061905    0.019779    0.544483    
#> 333: 1.076423    1.011568    3.485235    1.227544    0.061966    0.019759    0.544480    
#> 334: 1.075526    1.011461    3.485124    1.224738    0.061955    0.019759    0.544509    
#> 335: 1.074876    1.011526    3.485054    1.223266    0.061957    0.019740    0.544487    
#> 336: 1.073532    1.011677    3.484909    1.219879    0.061928    0.019708    0.544530    
#> 337: 1.072991    1.012014    3.484759    1.218672    0.061952    0.019705    0.544481    
#> 338: 1.072350    1.012169    3.484706    1.217063    0.061954    0.019695    0.544493    
#> 339: 1.071384    1.012401    3.484618    1.214578    0.061950    0.019689    0.544467    
#> 340: 1.070908    1.012366    3.484607    1.213175    0.061888    0.019679    0.544391    
#> 341: 1.070659    1.012381    3.484670    1.211878    0.061833    0.019681    0.544323    
#> 342: 1.069871    1.012351    3.484624    1.209709    0.061842    0.019668    0.544255    
#> 343: 1.069621    1.012415    3.484613    1.209028    0.061855    0.019653    0.544191    
#> 344: 1.069789    1.012433    3.484599    1.209778    0.061802    0.019651    0.544140    
#> 345: 1.069887    1.012421    3.484590    1.210765    0.061855    0.019640    0.544087    
#> 346: 1.069866    1.012465    3.484524    1.210744    0.061863    0.019627    0.544018    
#> 347: 1.069235    1.012555    3.484439    1.209027    0.061870    0.019607    0.544046    
#> 348: 1.068550    1.012597    3.484323    1.207640    0.061863    0.019591    0.544011    
#> 349: 1.067873    1.012521    3.484269    1.206415    0.061879    0.019569    0.543991    
#> 350: 1.067307    1.012411    3.484231    1.204416    0.061910    0.019539    0.544020    
#> 351: 1.066845    1.012464    3.484167    1.202627    0.061948    0.019515    0.544083    
#> 352: 1.066464    1.012460    3.484208    1.200843    0.061937    0.019523    0.544146    
#> 353: 1.066258    1.012535    3.484259    1.199255    0.062023    0.019504    0.544125    
#> 354: 1.065843    1.012614    3.484245    1.197707    0.062123    0.019478    0.544120    
#> 355: 1.065806    1.012573    3.484258    1.196744    0.062176    0.019452    0.544135    
#> 356: 1.065988    1.012469    3.484299    1.195752    0.062196    0.019419    0.544232    
#> 357: 1.066241    1.012468    3.484367    1.195664    0.062214    0.019399    0.544247    
#> 358: 1.066282    1.012514    3.484443    1.194570    0.062204    0.019388    0.544235    
#> 359: 1.066256    1.012582    3.484504    1.193810    0.062128    0.019394    0.544241    
#> 360: 1.066302    1.012446    3.484503    1.193483    0.062140    0.019398    0.544188    
#> 361: 1.066174    1.012444    3.484490    1.192421    0.062081    0.019391    0.544139    
#> 362: 1.066129    1.012415    3.484510    1.191562    0.062114    0.019382    0.544051    
#> 363: 1.066171    1.012323    3.484480    1.191369    0.062121    0.019365    0.543956    
#> 364: 1.066130    1.012358    3.484475    1.190923    0.062133    0.019358    0.543989    
#> 365: 1.066289    1.012239    3.484524    1.191154    0.062156    0.019338    0.544064    
#> 366: 1.066307    1.012207    3.484518    1.191413    0.062267    0.019306    0.544092    
#> 367: 1.066231    1.012185    3.484502    1.191225    0.062279    0.019279    0.544111    
#> 368: 1.066178    1.012217    3.484517    1.190174    0.062278    0.019257    0.544093    
#> 369: 1.065726    1.012179    3.484526    1.188969    0.062286    0.019253    0.544049    
#> 370: 1.065169    1.012228    3.484501    1.187396    0.062312    0.019226    0.544166    
#> 371: 1.065163    1.012294    3.484491    1.187061    0.062306    0.019219    0.544186    
#> 372: 1.064817    1.012382    3.484427    1.186082    0.062345    0.019196    0.544171    
#> 373: 1.064166    1.012569    3.484336    1.185050    0.062397    0.019169    0.544124    
#> 374: 1.063850    1.012677    3.484286    1.184298    0.062436    0.019156    0.544130    
#> 375: 1.063645    1.012734    3.484264    1.183630    0.062445    0.019146    0.544176    
#> 376: 1.063140    1.012847    3.484258    1.182424    0.062449    0.019137    0.544176    
#> 377: 1.062919    1.012931    3.484198    1.181856    0.062419    0.019129    0.544146    
#> 378: 1.062853    1.012974    3.484154    1.181978    0.062419    0.019151    0.544084    
#> 379: 1.062631    1.012864    3.484146    1.181532    0.062399    0.019166    0.544102    
#> 380: 1.061883    1.012785    3.484155    1.179707    0.062379    0.019167    0.544115    
#> 381: 1.061473    1.012740    3.484104    1.178887    0.062361    0.019189    0.544098    
#> 382: 1.061169    1.012761    3.484080    1.177699    0.062380    0.019199    0.544027    
#> 383: 1.061033    1.012781    3.484104    1.176406    0.062376    0.019212    0.543929    
#> 384: 1.060602    1.012710    3.484157    1.174851    0.062316    0.019224    0.543949    
#> 385: 1.060188    1.012680    3.484169    1.173246    0.062313    0.019223    0.543877    
#> 386: 1.060225    1.012832    3.484190    1.173114    0.062355    0.019214    0.543889    
#> 387: 1.060322    1.012944    3.484225    1.173281    0.062352    0.019201    0.543846    
#> 388: 1.060259    1.013005    3.484252    1.172871    0.062370    0.019192    0.543778    
#> 389: 1.059986    1.012947    3.484220    1.172500    0.062341    0.019191    0.543854    
#> 390: 1.059810    1.012912    3.484203    1.172172    0.062305    0.019198    0.543834    
#> 391: 1.059559    1.012888    3.484180    1.171495    0.062270    0.019196    0.543761    
#> 392: 1.059039    1.012882    3.484114    1.170652    0.062235    0.019191    0.543731    
#> 393: 1.058731    1.012947    3.484006    1.170337    0.062203    0.019181    0.543765    
#> 394: 1.058950    1.012962    3.483961    1.170964    0.062195    0.019194    0.543797    
#> 395: 1.058846    1.013069    3.483944    1.170878    0.062160    0.019199    0.543831    
#> 396: 1.058669    1.013150    3.483931    1.170716    0.062160    0.019194    0.543768    
#> 397: 1.058668    1.013167    3.483917    1.170982    0.062200    0.019166    0.543758    
#> 398: 1.058975    1.013171    3.483911    1.171854    0.062279    0.019145    0.543736    
#> 399: 1.059144    1.013137    3.483933    1.172661    0.062350    0.019132    0.543692    
#> 400: 1.059293    1.013166    3.483960    1.172840    0.062397    0.019107    0.543713    
#> 401: 1.059423    1.013228    3.483925    1.173137    0.062432    0.019084    0.543754    
#> 402: 1.059273    1.013340    3.483904    1.172605    0.062476    0.019062    0.543765    
#> 403: 1.059382    1.013315    3.483922    1.172543    0.062505    0.019031    0.543760    
#> 404: 1.059388    1.013328    3.483902    1.171831    0.062578    0.019012    0.543707    
#> 405: 1.059312    1.013346    3.483922    1.171535    0.062568    0.019002    0.543659    
#> 406: 1.059189    1.013403    3.483885    1.171051    0.062594    0.018993    0.543632    
#> 407: 1.058866    1.013484    3.483870    1.170032    0.062626    0.019000    0.543618    
#> 408: 1.058987    1.013557    3.483868    1.169718    0.062629    0.018988    0.543613    
#> 409: 1.058853    1.013468    3.483896    1.168905    0.062633    0.018986    0.543561    
#> 410: 1.058735    1.013428    3.483923    1.168070    0.062674    0.018974    0.543550    
#> 411: 1.058772    1.013270    3.483937    1.167972    0.062675    0.018970    0.543592    
#> 412: 1.058357    1.013367    3.483915    1.166879    0.062715    0.018964    0.543642    
#> 413: 1.058028    1.013489    3.483908    1.165451    0.062730    0.018957    0.543717    
#> 414: 1.058019    1.013499    3.483962    1.165286    0.062700    0.018951    0.543774    
#> 415: 1.057853    1.013567    3.483974    1.164197    0.062694    0.018956    0.543707    
#> 416: 1.057625    1.013583    3.484038    1.163251    0.062691    0.018951    0.543643    
#> 417: 1.057218    1.013614    3.484069    1.162041    0.062641    0.018956    0.543608    
#> 418: 1.057068    1.013582    3.484104    1.161675    0.062589    0.018977    0.543565    
#> 419: 1.056904    1.013623    3.484083    1.161601    0.062563    0.018995    0.543529    
#> 420: 1.056751    1.013601    3.484100    1.161151    0.062521    0.019003    0.543480    
#> 421: 1.056656    1.013576    3.484112    1.161238    0.062458    0.019018    0.543466    
#> 422: 1.056819    1.013490    3.484108    1.161889    0.062389    0.019038    0.543435    
#> 423: 1.056792    1.013373    3.484114    1.161422    0.062343    0.019058    0.543460    
#> 424: 1.056789    1.013371    3.484105    1.161099    0.062294    0.019070    0.543427    
#> 425: 1.056751    1.013422    3.484081    1.160773    0.062296    0.019077    0.543447    
#> 426: 1.056957    1.013448    3.484078    1.161352    0.062309    0.019068    0.543423    
#> 427: 1.056952    1.013399    3.484130    1.161138    0.062343    0.019070    0.543394    
#> 428: 1.056775    1.013416    3.484166    1.160456    0.062354    0.019069    0.543373    
#> 429: 1.056767    1.013453    3.484161    1.160733    0.062336    0.019072    0.543348    
#> 430: 1.056882    1.013526    3.484149    1.161043    0.062300    0.019071    0.543385    
#> 431: 1.056877    1.013595    3.484103    1.160816    0.062314    0.019064    0.543340    
#> 432: 1.056899    1.013688    3.484095    1.160419    0.062306    0.019062    0.543368    
#> 433: 1.056956    1.013702    3.484150    1.160161    0.062299    0.019070    0.543348    
#> 434: 1.056689    1.013642    3.484141    1.159409    0.062269    0.019065    0.543377    
#> 435: 1.056580    1.013726    3.484086    1.159361    0.062302    0.019086    0.543350    
#> 436: 1.056395    1.013707    3.484081    1.158943    0.062296    0.019100    0.543372    
#> 437: 1.056544    1.013671    3.484112    1.158670    0.062294    0.019121    0.543335    
#> 438: 1.056685    1.013767    3.484116    1.158759    0.062329    0.019109    0.543325    
#> 439: 1.056747    1.013852    3.484113    1.158821    0.062306    0.019113    0.543248    
#> 440: 1.056827    1.013904    3.484149    1.158314    0.062323    0.019115    0.543212    
#> 441: 1.056871    1.013883    3.484195    1.157703    0.062304    0.019118    0.543135    
#> 442: 1.056690    1.013867    3.484199    1.157081    0.062283    0.019117    0.543134    
#> 443: 1.056769    1.013924    3.484171    1.156963    0.062273    0.019122    0.543115    
#> 444: 1.056729    1.014016    3.484130    1.156699    0.062261    0.019131    0.543106    
#> 445: 1.056504    1.014035    3.484066    1.156706    0.062312    0.019129    0.543186    
#> 446: 1.056155    1.014106    3.483990    1.156722    0.062326    0.019117    0.543191    
#> 447: 1.055822    1.014181    3.483954    1.155894    0.062366    0.019121    0.543194    
#> 448: 1.055538    1.014223    3.483929    1.155133    0.062326    0.019126    0.543166    
#> 449: 1.055398    1.014321    3.483972    1.155022    0.062292    0.019138    0.543155    
#> 450: 1.055397    1.014345    3.483988    1.154453    0.062309    0.019143    0.543121    
#> 451: 1.055409    1.014414    3.483980    1.154076    0.062364    0.019150    0.543126    
#> 452: 1.055470    1.014494    3.483987    1.153792    0.062399    0.019160    0.543106    
#> 453: 1.055403    1.014504    3.483978    1.153442    0.062356    0.019167    0.543110    
#> 454: 1.055422    1.014596    3.483962    1.153376    0.062323    0.019178    0.543097    
#> 455: 1.055459    1.014604    3.483957    1.153372    0.062327    0.019191    0.543073    
#> 456: 1.055351    1.014597    3.483963    1.153267    0.062346    0.019189    0.543107    
#> 457: 1.055303    1.014582    3.483991    1.153193    0.062350    0.019194    0.543059    
#> 458: 1.055353    1.014648    3.484008    1.153476    0.062367    0.019208    0.543011    
#> 459: 1.055151    1.014750    3.483976    1.153429    0.062420    0.019221    0.542978    
#> 460: 1.054834    1.014777    3.483901    1.152825    0.062406    0.019224    0.542970    
#> 461: 1.054442    1.014830    3.483853    1.152033    0.062364    0.019231    0.542914    
#> 462: 1.054200    1.014911    3.483814    1.151958    0.062342    0.019241    0.542884    
#> 463: 1.054275    1.014999    3.483817    1.152642    0.062340    0.019253    0.542862    
#> 464: 1.054346    1.015025    3.483773    1.152804    0.062307    0.019265    0.542822    
#> 465: 1.054426    1.014900    3.483775    1.152824    0.062275    0.019277    0.542784    
#> 466: 1.054688    1.014878    3.483734    1.153399    0.062205    0.019300    0.542780    
#> 467: 1.054825    1.014799    3.483750    1.154392    0.062174    0.019305    0.542774    
#> 468: 1.055269    1.014804    3.483768    1.156103    0.062140    0.019305    0.542787    
#> 469: 1.055674    1.014903    3.483771    1.157224    0.062165    0.019301    0.542848    
#> 470: 1.055913    1.014942    3.483708    1.158573    0.062168    0.019296    0.542937    
#> 471: 1.055980    1.014928    3.483673    1.159454    0.062160    0.019295    0.543002    
#> 472: 1.056009    1.014920    3.483663    1.159699    0.062160    0.019295    0.543007    
#> 473: 1.055822    1.014970    3.483654    1.158749    0.062163    0.019299    0.542990    
#> 474: 1.055693    1.014953    3.483642    1.158208    0.062125    0.019298    0.543024    
#> 475: 1.055649    1.014969    3.483667    1.157700    0.062146    0.019309    0.542995    
#> 476: 1.055830    1.014961    3.483679    1.158391    0.062155    0.019312    0.542973    
#> 477: 1.055721    1.014966    3.483698    1.158202    0.062154    0.019308    0.542957    
#> 478: 1.055412    1.014911    3.483722    1.157210    0.062198    0.019300    0.543006    
#> 479: 1.055370    1.014898    3.483752    1.156422    0.062214    0.019291    0.543036    
#> 480: 1.055102    1.014861    3.483779    1.155242    0.062254    0.019300    0.543025    
#> 481: 1.054909    1.014879    3.483786    1.154462    0.062293    0.019294    0.543008    
#> 482: 1.054933    1.014838    3.483764    1.154004    0.062336    0.019297    0.543033    
#> 483: 1.054822    1.014776    3.483765    1.153541    0.062327    0.019306    0.543065    
#> 484: 1.054827    1.014627    3.483793    1.153527    0.062319    0.019311    0.543077    
#> 485: 1.054837    1.014629    3.483786    1.153417    0.062308    0.019307    0.543147    
#> 486: 1.054786    1.014634    3.483814    1.152829    0.062309    0.019305    0.543117    
#> 487: 1.054788    1.014588    3.483867    1.152167    0.062290    0.019310    0.543095    
#> 488: 1.054652    1.014564    3.483916    1.151405    0.062259    0.019319    0.543088    
#> 489: 1.054634    1.014522    3.483928    1.150772    0.062251    0.019320    0.543114    
#> 490: 1.054773    1.014515    3.483961    1.150803    0.062241    0.019314    0.543124    
#> 491: 1.054891    1.014575    3.483988    1.151286    0.062212    0.019316    0.543118    
#> 492: 1.054713    1.014648    3.483970    1.150688    0.062235    0.019319    0.543119    
#> 493: 1.054482    1.014710    3.483950    1.150037    0.062235    0.019322    0.543105    
#> 494: 1.054323    1.014809    3.483906    1.149488    0.062229    0.019326    0.543055    
#> 495: 1.054178    1.014842    3.483862    1.149123    0.062249    0.019325    0.542966    
#> 496: 1.054059    1.014919    3.483812    1.148927    0.062260    0.019315    0.542940    
#> 497: 1.053811    1.014915    3.483795    1.148404    0.062281    0.019304    0.542943    
#> 498: 1.053636    1.014955    3.483732    1.148317    0.062293    0.019287    0.542930    
#> 499: 1.053409    1.015002    3.483685    1.148100    0.062295    0.019284    0.542905    
#> 500: 1.053543    1.015021    3.483651    1.148677    0.062281    0.019276    0.542898    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.322436    0.987643    3.454627    0.392401    0.084842    0.016800    1.651271    
#> 002: 0.392042    1.115417    3.481687    0.372781    0.080600    0.016055    1.060919    
#> 003: 0.631273    1.154076    3.524315    0.357393    0.076570    0.015252    0.748095    
#> 004: 0.641904    1.183128    3.542302    0.339523    0.072742    0.014490    0.633044    
#> 005: 0.743730    1.185242    3.543275    0.356787    0.069105    0.013765    0.573432    
#> 006: 0.712535    1.194973    3.540857    0.401845    0.065649    0.013077    0.538656    
#> 007: 0.711087    1.203724    3.542198    0.445020    0.062367    0.012423    0.550084    
#> 008: 0.715699    1.200324    3.537997    0.459514    0.059249    0.011802    0.550819    
#> 009: 0.699664    1.179310    3.537284    0.461996    0.056286    0.012398    0.553535    
#> 010: 0.711887    1.176661    3.540890    0.468944    0.053472    0.017969    0.546603    
#> 011: 0.776512    1.188812    3.547888    0.463934    0.050798    0.017805    0.540809    
#> 012: 0.801620    1.184320    3.558940    0.447327    0.048258    0.019592    0.527480    
#> 013: 0.745225    1.191631    3.555344    0.438593    0.045845    0.020777    0.525664    
#> 014: 0.758104    1.194738    3.568258    0.416663    0.043553    0.019738    0.523207    
#> 015: 0.771740    1.198680    3.565038    0.395830    0.041376    0.018934    0.513263    
#> 016: 0.814306    1.187082    3.585975    0.411569    0.039307    0.017987    0.514438    
#> 017: 0.799028    1.189427    3.583114    0.390991    0.037341    0.017088    0.513407    
#> 018: 0.781515    1.196035    3.570733    0.411075    0.035474    0.016233    0.520865    
#> 019: 0.747997    1.205046    3.566395    0.390522    0.033701    0.016502    0.503975    
#> 020: 0.774370    1.202545    3.567548    0.397950    0.032016    0.015677    0.515946    
#> 021: 0.797809    1.186527    3.571875    0.414878    0.030415    0.015886    0.506247    
#> 022: 0.797019    1.190824    3.577923    0.495029    0.028894    0.015091    0.500129    
#> 023: 0.901668    1.198831    3.591091    0.535977    0.027449    0.014337    0.527027    
#> 024: 0.875215    1.203031    3.581648    0.540467    0.026077    0.014942    0.504424    
#> 025: 0.810982    1.196175    3.576284    0.513443    0.024892    0.017639    0.504978    
#> 026: 0.810774    1.205620    3.566091    0.487771    0.023647    0.017562    0.506460    
#> 027: 0.799019    1.207660    3.570968    0.463383    0.025884    0.017168    0.499317    
#> 028: 0.797277    1.194118    3.564977    0.514033    0.024590    0.018877    0.488417    
#> 029: 0.778528    1.202806    3.551901    0.511520    0.023360    0.017933    0.506005    
#> 030: 0.762436    1.211947    3.550246    0.487608    0.025270    0.017716    0.505645    
#> 031: 0.756880    1.197932    3.565726    0.505623    0.024634    0.016830    0.501048    
#> 032: 0.755948    1.197227    3.567817    0.516696    0.024173    0.017021    0.491142    
#> 033: 0.738826    1.208996    3.566191    0.490861    0.023170    0.019761    0.497376    
#> 034: 0.784609    1.213331    3.560641    0.466318    0.024640    0.018773    0.499028    
#> 035: 0.770656    1.194504    3.557878    0.443002    0.023408    0.017835    0.493224    
#> 036: 0.780158    1.199543    3.561978    0.469300    0.027361    0.018684    0.501260    
#> 037: 0.786690    1.195629    3.570252    0.460765    0.031186    0.021138    0.500068    
#> 038: 0.778719    1.197625    3.564526    0.446193    0.029626    0.020081    0.502765    
#> 039: 0.805708    1.181167    3.577103    0.437704    0.028145    0.019439    0.498344    
#> 040: 0.770919    1.186197    3.575897    0.430708    0.026738    0.022288    0.507677    
#> 041: 0.751165    1.170379    3.570421    0.458379    0.025401    0.021505    0.518429    
#> 042: 0.775600    1.162189    3.567583    0.451276    0.024131    0.020430    0.496959    
#> 043: 0.737113    1.189652    3.553742    0.428712    0.025220    0.019408    0.500428    
#> 044: 0.743830    1.197499    3.548450    0.456625    0.023959    0.018438    0.498475    
#> 045: 0.738411    1.218429    3.545356    0.433794    0.023284    0.020136    0.489235    
#> 046: 0.748313    1.219560    3.548761    0.433323    0.027226    0.019129    0.493335    
#> 047: 0.745942    1.220086    3.546115    0.462788    0.025864    0.018173    0.503317    
#> 048: 0.721972    1.205283    3.546938    0.439649    0.027208    0.018433    0.508219    
#> 049: 0.754099    1.192868    3.554110    0.432870    0.028470    0.018781    0.509104    
#> 050: 0.781464    1.181050    3.568055    0.459944    0.027047    0.017842    0.526997    
#> 051: 0.762330    1.196613    3.567362    0.465552    0.029177    0.018806    0.522517    
#> 052: 0.780952    1.199740    3.570442    0.455273    0.027719    0.017865    0.506684    
#> 053: 0.777398    1.186286    3.568893    0.447075    0.026333    0.017153    0.504451    
#> 054: 0.738914    1.190185    3.561704    0.424721    0.025016    0.017112    0.511102    
#> 055: 0.776384    1.185480    3.572631    0.403485    0.023765    0.023257    0.505475    
#> 056: 0.825841    1.181796    3.570575    0.475900    0.022577    0.023538    0.515211    
#> 057: 0.771946    1.197754    3.564693    0.461335    0.021448    0.022361    0.519638    
#> 058: 0.754882    1.192691    3.552077    0.438268    0.022075    0.021690    0.503994    
#> 059: 0.751660    1.171983    3.555415    0.468648    0.025208    0.022088    0.529662    
#> 060: 0.775061    1.161319    3.574423    0.445216    0.025492    0.020983    0.531366    
#> 061: 0.801531    1.178951    3.581387    0.429914    0.029114    0.019934    0.527852    
#> 062: 0.805787    1.192337    3.574428    0.464685    0.034194    0.018938    0.529189    
#> 063: 0.794203    1.195481    3.568382    0.441451    0.035794    0.017991    0.526242    
#> 064: 0.768719    1.204236    3.562932    0.419378    0.034004    0.020300    0.515746    
#> 065: 0.760497    1.195033    3.551384    0.400026    0.032304    0.019285    0.502034    
#> 066: 0.776107    1.206694    3.563196    0.458458    0.030689    0.018321    0.502948    
#> 067: 0.799338    1.187476    3.574525    0.470048    0.029154    0.017405    0.498764    
#> 068: 0.773391    1.187339    3.581738    0.466407    0.030377    0.018625    0.507056    
#> 069: 0.814358    1.193884    3.574301    0.476188    0.031980    0.019704    0.510995    
#> 070: 0.817555    1.179872    3.575777    0.524444    0.030381    0.019687    0.502490    
#> 071: 0.797394    1.200390    3.561754    0.514266    0.028862    0.020180    0.508172    
#> 072: 0.764050    1.178949    3.565092    0.505224    0.027419    0.019171    0.503801    
#> 073: 0.779678    1.194602    3.569507    0.524308    0.026048    0.019686    0.502503    
#> 074: 0.771707    1.181126    3.563449    0.498092    0.024745    0.018702    0.511056    
#> 075: 0.786944    1.179850    3.586149    0.473188    0.024156    0.018999    0.508911    
#> 076: 0.828053    1.183672    3.592670    0.455680    0.024861    0.021748    0.504276    
#> 077: 0.875892    1.171831    3.585358    0.548095    0.027032    0.020661    0.520615    
#> 078: 0.854833    1.171570    3.587251    0.536473    0.025680    0.022354    0.508850    
#> 079: 0.824210    1.178488    3.587544    0.509649    0.027399    0.021236    0.519192    
#> 080: 0.830665    1.183026    3.582839    0.484167    0.027727    0.023074    0.531241    
#> 081: 0.799073    1.186662    3.579003    0.459958    0.026341    0.022960    0.514660    
#> 082: 0.772471    1.179143    3.572311    0.501864    0.025024    0.023682    0.510701    
#> 083: 0.801415    1.190253    3.565889    0.549624    0.024019    0.023692    0.504295    
#> 084: 0.780516    1.194068    3.564473    0.522142    0.025462    0.022507    0.508130    
#> 085: 0.758336    1.202857    3.575747    0.496035    0.025458    0.021382    0.500229    
#> 086: 0.775167    1.199241    3.565527    0.471234    0.033246    0.020313    0.494112    
#> 087: 0.801106    1.205527    3.568180    0.447672    0.031812    0.019297    0.500890    
#> 088: 0.738172    1.187063    3.573013    0.425288    0.030222    0.018332    0.514968    
#> 089: 0.757173    1.201214    3.557963    0.437048    0.028711    0.017416    0.508812    
#> 090: 0.739376    1.198545    3.547684    0.415196    0.027275    0.016774    0.509485    
#> 091: 0.730532    1.189091    3.547292    0.452704    0.026435    0.018826    0.511266    
#> 092: 0.737977    1.193205    3.556786    0.430069    0.025113    0.021029    0.502194    
#> 093: 0.725204    1.190777    3.552731    0.439381    0.023858    0.023175    0.523024    
#> 094: 0.739512    1.193575    3.552922    0.417412    0.023281    0.022016    0.507310    
#> 095: 0.726286    1.196568    3.551648    0.409744    0.028022    0.020915    0.509242    
#> 096: 0.708124    1.196992    3.551974    0.425136    0.027521    0.019870    0.507107    
#> 097: 0.765556    1.203269    3.562341    0.449770    0.026144    0.018876    0.503922    
#> 098: 0.781348    1.202814    3.566044    0.454546    0.024837    0.017932    0.500791    
#> 099: 0.739935    1.197326    3.561003    0.431819    0.027080    0.018475    0.494394    
#> 100: 0.764003    1.189986    3.565310    0.410228    0.025726    0.018241    0.496192    
#> 101: 0.739473    1.187324    3.550855    0.398795    0.027767    0.017329    0.498026    
#> 102: 0.741430    1.180875    3.541656    0.438683    0.026379    0.016462    0.511237    
#> 103: 0.751222    1.194352    3.552085    0.420748    0.025060    0.016786    0.510657    
#> 104: 0.755171    1.197341    3.559094    0.448358    0.027339    0.018116    0.520605    
#> 105: 0.760513    1.176492    3.562062    0.439301    0.025972    0.017210    0.517939    
#> 106: 0.780007    1.186283    3.566380    0.427744    0.025766    0.016668    0.492732    
#> 107: 0.796512    1.196558    3.577902    0.406357    0.026711    0.017553    0.500707    
#> 108: 0.791942    1.191046    3.587582    0.392493    0.025376    0.017611    0.511272    
#> 109: 0.810991    1.182874    3.581108    0.431825    0.024107    0.017032    0.510465    
#> 110: 0.777420    1.182815    3.562979    0.420890    0.022902    0.019554    0.513746    
#> 111: 0.761060    1.184294    3.572865    0.416496    0.021756    0.020068    0.502516    
#> 112: 0.751669    1.174878    3.557420    0.406024    0.020669    0.022954    0.517777    
#> 113: 0.808820    1.197672    3.573973    0.496296    0.019635    0.026221    0.502706    
#> 114: 0.830964    1.194403    3.571862    0.471482    0.023503    0.024910    0.505434    
#> 115: 0.793603    1.170654    3.564800    0.460482    0.022328    0.023665    0.528016    
#> 116: 0.772302    1.195728    3.551215    0.501610    0.025173    0.022482    0.507438    
#> 117: 0.739092    1.210135    3.557125    0.476530    0.023914    0.021357    0.508337    
#> 118: 0.760270    1.214542    3.552174    0.489279    0.024815    0.020290    0.486729    
#> 119: 0.753382    1.205249    3.558866    0.468263    0.023575    0.019950    0.496868    
#> 120: 0.725683    1.195825    3.558277    0.444850    0.026924    0.020658    0.502669    
#> 121: 0.738614    1.218494    3.555948    0.437788    0.025578    0.020700    0.496412    
#> 122: 0.756164    1.203957    3.565091    0.478574    0.029753    0.019793    0.490588    
#> 123: 0.783195    1.217532    3.555382    0.459744    0.028265    0.018803    0.500784    
#> 124: 0.726641    1.245102    3.542500    0.436757    0.029790    0.017863    0.499856    
#> 125: 0.738427    1.240662    3.540416    0.450073    0.028300    0.018724    0.496954    
#> 126: 0.715973    1.238197    3.535814    0.427570    0.026885    0.021581    0.517626    
#> 127: 0.757001    1.224587    3.551154    0.427517    0.025541    0.022002    0.515569    
#> 128: 0.736293    1.201154    3.550055    0.465175    0.024264    0.020902    0.519625    
#> 129: 0.733861    1.203716    3.555182    0.441916    0.025035    0.021722    0.512443    
#> 130: 0.768464    1.210719    3.554520    0.445422    0.025120    0.020636    0.504125    
#> 131: 0.743948    1.206493    3.553340    0.423151    0.027342    0.019604    0.491541    
#> 132: 0.732815    1.197109    3.542386    0.420803    0.025975    0.018624    0.509018    
#> 133: 0.719038    1.197124    3.550615    0.406764    0.024677    0.017693    0.515518    
#> 134: 0.775086    1.184357    3.568298    0.452004    0.023443    0.021333    0.494975    
#> 135: 0.764167    1.186738    3.564477    0.455038    0.024377    0.024150    0.493761    
#> 136: 0.791852    1.176364    3.578485    0.434457    0.025775    0.022943    0.511933    
#> 137: 0.833813    1.175174    3.581488    0.495878    0.024837    0.021796    0.508025    
#> 138: 0.806018    1.179005    3.570317    0.471084    0.023595    0.021939    0.506910    
#> 139: 0.765609    1.194446    3.574007    0.447530    0.022415    0.021096    0.506608    
#> 140: 0.776754    1.189472    3.576584    0.425154    0.025718    0.023118    0.514348    
#> 141: 0.771566    1.180815    3.575606    0.403896    0.027484    0.022370    0.503604    
#> 142: 0.802736    1.181032    3.589308    0.412212    0.031094    0.021252    0.506877    
#> 143: 0.773509    1.191626    3.580480    0.391601    0.029539    0.020189    0.510150    
#> 144: 0.794033    1.200800    3.578921    0.431621    0.028062    0.019180    0.503282    
#> 145: 0.760847    1.197474    3.562076    0.410040    0.026659    0.018221    0.494379    
#> 146: 0.751183    1.202036    3.559691    0.445444    0.025326    0.017310    0.508626    
#> 147: 0.717996    1.201041    3.548061    0.456070    0.029560    0.016444    0.498885    
#> 148: 0.735459    1.213283    3.553344    0.440771    0.028082    0.018666    0.494996    
#> 149: 0.751347    1.192563    3.557785    0.450290    0.027488    0.017733    0.499776    
#> 150: 0.736863    1.200318    3.538388    0.450768    0.027735    0.017139    0.522452    
#> 151: 0.695691    1.221238    3.538886    0.432593    0.027216    0.016282    0.510986    
#> 152: 0.703428    1.223998    3.547118    0.420654    0.025847    0.014538    0.513969    
#> 153: 0.720744    1.221864    3.559419    0.401675    0.026297    0.017794    0.520306    
#> 154: 0.751230    1.221387    3.553249    0.460998    0.028353    0.017529    0.519071    
#> 155: 0.738641    1.206354    3.552707    0.460810    0.020049    0.019669    0.514010    
#> 156: 0.753007    1.216563    3.559342    0.449756    0.027958    0.022365    0.511174    
#> 157: 0.759610    1.203633    3.551525    0.452362    0.025540    0.017737    0.521091    
#> 158: 0.786338    1.210959    3.559019    0.462698    0.022290    0.015538    0.516791    
#> 159: 0.749354    1.222788    3.565735    0.483129    0.021085    0.017577    0.511648    
#> 160: 0.778220    1.185341    3.571710    0.440612    0.028180    0.018375    0.519971    
#> 161: 0.789790    1.192754    3.568528    0.488612    0.024968    0.016600    0.518209    
#> 162: 0.777525    1.205452    3.573667    0.428519    0.024923    0.015602    0.523914    
#> 163: 0.801108    1.190075    3.566723    0.414684    0.033193    0.015472    0.523489    
#> 164: 0.793221    1.185405    3.572990    0.424908    0.023090    0.019149    0.499948    
#> 165: 0.832440    1.171605    3.574765    0.455413    0.021992    0.019627    0.522394    
#> 166: 0.834575    1.188908    3.581129    0.476808    0.018792    0.024142    0.519872    
#> 167: 0.812604    1.194558    3.586848    0.406048    0.018487    0.025433    0.517152    
#> 168: 0.798723    1.194225    3.576299    0.395142    0.017966    0.022260    0.508043    
#> 169: 0.778515    1.200807    3.566565    0.370274    0.020429    0.020358    0.509714    
#> 170: 0.783156    1.188354    3.575716    0.391099    0.024807    0.019278    0.503893    
#> 171: 0.778476    1.189726    3.569376    0.377900    0.017846    0.022593    0.492396    
#> 172: 0.766687    1.195891    3.571471    0.403743    0.021496    0.019237    0.495593    
#> 173: 0.782441    1.208890    3.563201    0.420485    0.022398    0.022782    0.495478    
#> 174: 0.792880    1.206782    3.572857    0.423421    0.020759    0.019266    0.514273    
#> 175: 0.774124    1.205278    3.562932    0.400831    0.016987    0.022943    0.510244    
#> 176: 0.795911    1.219958    3.569892    0.520426    0.017852    0.022022    0.497177    
#> 177: 0.784308    1.208546    3.569101    0.486541    0.020753    0.023457    0.502502    
#> 178: 0.800735    1.199724    3.567470    0.456612    0.022472    0.023600    0.499061    
#> 179: 0.779151    1.214255    3.555979    0.440064    0.026569    0.023115    0.497837    
#> 180: 0.757324    1.210122    3.560835    0.429753    0.026348    0.021726    0.503627    
#> 181: 0.783062    1.200414    3.557957    0.446969    0.021785    0.022711    0.508738    
#> 182: 0.768041    1.197145    3.559913    0.435603    0.020719    0.022996    0.515609    
#> 183: 0.781053    1.204683    3.565260    0.490349    0.020642    0.022260    0.515117    
#> 184: 0.779409    1.186674    3.566740    0.514807    0.017601    0.023335    0.503161    
#> 185: 0.746294    1.181736    3.568318    0.415798    0.020361    0.021531    0.503561    
#> 186: 0.714912    1.203093    3.560203    0.389907    0.020399    0.022332    0.532374    
#> 187: 0.760520    1.184039    3.563485    0.428871    0.026418    0.019666    0.511371    
#> 188: 0.748860    1.203546    3.561725    0.408076    0.022539    0.016887    0.516730    
#> 189: 0.767567    1.207630    3.562047    0.476617    0.020567    0.018156    0.523775    
#> 190: 0.794332    1.192948    3.575291    0.401674    0.022618    0.016556    0.514949    
#> 191: 0.795618    1.195606    3.569392    0.519434    0.025789    0.016413    0.510218    
#> 192: 0.788139    1.198869    3.564944    0.553265    0.023548    0.018337    0.510207    
#> 193: 0.815990    1.210612    3.571038    0.451672    0.025052    0.017629    0.503760    
#> 194: 0.744631    1.205550    3.545133    0.421923    0.021704    0.015558    0.523484    
#> 195: 0.706960    1.214791    3.539987    0.406152    0.023891    0.014674    0.511930    
#> 196: 0.729909    1.208523    3.552479    0.386928    0.029116    0.014045    0.520422    
#> 197: 0.704819    1.224701    3.565093    0.383297    0.029243    0.015673    0.526041    
#> 198: 0.781333    1.199206    3.566265    0.359974    0.026390    0.017219    0.511925    
#> 199: 0.763488    1.191577    3.564933    0.392117    0.027340    0.014770    0.503862    
#> 200: 0.769028    1.184860    3.568898    0.391698    0.026170    0.019297    0.510608    
#> 201: 0.760407    1.184327    3.570157    0.369057    0.027959    0.018272    0.505466    
#> 202: 0.763363    1.184965    3.571761    0.384721    0.027560    0.017208    0.505645    
#> 203: 0.775249    1.186678    3.569526    0.394618    0.027851    0.016520    0.504918    
#> 204: 0.769056    1.183830    3.570989    0.399610    0.028506    0.016338    0.509669    
#> 205: 0.771556    1.188074    3.571259    0.402658    0.028267    0.016654    0.511887    
#> 206: 0.772343    1.192667    3.570744    0.407021    0.027932    0.016911    0.513662    
#> 207: 0.771019    1.193065    3.569094    0.402484    0.027393    0.017024    0.514258    
#> 208: 0.769898    1.193206    3.567734    0.406559    0.027377    0.017120    0.512934    
#> 209: 0.772110    1.191210    3.567221    0.411814    0.027800    0.017251    0.511412    
#> 210: 0.771863    1.191322    3.567297    0.414534    0.027474    0.017038    0.509741    
#> 211: 0.773664    1.191790    3.567440    0.410879    0.027783    0.016960    0.509462    
#> 212: 0.775276    1.191474    3.567696    0.413080    0.027898    0.016699    0.508888    
#> 213: 0.776807    1.189760    3.568072    0.415520    0.028094    0.016586    0.508617    
#> 214: 0.777995    1.189845    3.568284    0.417823    0.028422    0.016340    0.508506    
#> 215: 0.778403    1.189843    3.568534    0.420774    0.028515    0.016317    0.509179    
#> 216: 0.781698    1.189038    3.568853    0.426142    0.028649    0.016454    0.509690    
#> 217: 0.782825    1.189272    3.568936    0.425773    0.029013    0.016407    0.509943    
#> 218: 0.782958    1.189855    3.568465    0.428794    0.029222    0.016229    0.510359    
#> 219: 0.780854    1.190174    3.567369    0.429344    0.028907    0.016191    0.510432    
#> 220: 0.779593    1.190423    3.567502    0.427676    0.028762    0.016430    0.509424    
#> 221: 0.779267    1.190532    3.567672    0.425901    0.028580    0.016551    0.508637    
#> 222: 0.779207    1.190472    3.567347    0.426375    0.028670    0.016680    0.508732    
#> 223: 0.780755    1.190311    3.567491    0.427921    0.028520    0.016722    0.508709    
#> 224: 0.782853    1.190786    3.567858    0.427432    0.028284    0.016814    0.508370    
#> 225: 0.782614    1.190251    3.568123    0.429311    0.028062    0.016869    0.508596    
#> 226: 0.782572    1.189754    3.567896    0.429941    0.028024    0.017044    0.508786    
#> 227: 0.782685    1.189936    3.567826    0.430907    0.027780    0.017206    0.508519    
#> 228: 0.782661    1.190853    3.567368    0.431259    0.027731    0.017241    0.508616    
#> 229: 0.781586    1.190791    3.567153    0.432504    0.027702    0.017250    0.508421    
#> 230: 0.782157    1.190872    3.567119    0.432815    0.027811    0.017303    0.508258    
#> 231: 0.782439    1.191036    3.567258    0.433058    0.027769    0.017368    0.508146    
#> 232: 0.782891    1.191023    3.567527    0.433940    0.027661    0.017388    0.507862    
#> 233: 0.782061    1.190210    3.567435    0.435161    0.027603    0.017366    0.507940    
#> 234: 0.781595    1.190061    3.567346    0.436344    0.027487    0.017418    0.507911    
#> 235: 0.781184    1.189543    3.567256    0.436258    0.027355    0.017540    0.507875    
#> 236: 0.781207    1.189997    3.566927    0.437173    0.027221    0.017592    0.507837    
#> 237: 0.781659    1.189976    3.566886    0.439590    0.027122    0.017596    0.508286    
#> 238: 0.782053    1.189934    3.566809    0.440962    0.027090    0.017612    0.508458    
#> 239: 0.781782    1.190432    3.566632    0.441760    0.027080    0.017594    0.508557    
#> 240: 0.781449    1.190570    3.566567    0.441910    0.026996    0.017627    0.508256    
#> 241: 0.781294    1.190031    3.566527    0.441149    0.026974    0.017635    0.508431    
#> 242: 0.780126    1.189760    3.566139    0.441021    0.027008    0.017667    0.508755    
#> 243: 0.778950    1.190497    3.565740    0.440442    0.027100    0.017755    0.508869    
#> 244: 0.778306    1.190978    3.565602    0.441470    0.027131    0.017773    0.508859    
#> 245: 0.777753    1.190741    3.565611    0.441524    0.027111    0.017840    0.509055    
#> 246: 0.777783    1.190862    3.565643    0.441943    0.027092    0.017932    0.508912    
#> 247: 0.777891    1.190687    3.565657    0.442352    0.027101    0.017944    0.508856    
#> 248: 0.777716    1.190970    3.565692    0.442619    0.026981    0.017960    0.508741    
#> 249: 0.777404    1.191255    3.565768    0.443254    0.026857    0.017997    0.508714    
#> 250: 0.777761    1.191485    3.565880    0.443550    0.026879    0.018059    0.508669    
#> 251: 0.778256    1.191718    3.566041    0.443880    0.026937    0.018109    0.508533    
#> 252: 0.778946    1.191996    3.566398    0.444481    0.026890    0.018155    0.508501    
#> 253: 0.779130    1.192224    3.566459    0.444851    0.026777    0.018202    0.508476    
#> 254: 0.779213    1.192582    3.566478    0.444805    0.026681    0.018272    0.508485    
#> 255: 0.779401    1.192754    3.566425    0.445771    0.026524    0.018334    0.508349    
#> 256: 0.779897    1.192563    3.566542    0.446275    0.026437    0.018357    0.508290    
#> 257: 0.779919    1.192328    3.566528    0.446369    0.026409    0.018379    0.508185    
#> 258: 0.779809    1.191993    3.566520    0.445268    0.026402    0.018339    0.508205    
#> 259: 0.780335    1.191681    3.566653    0.444983    0.026411    0.018365    0.508342    
#> 260: 0.780504    1.191623    3.566862    0.444262    0.026424    0.018384    0.508457    
#> 261: 0.780644    1.191658    3.567002    0.443906    0.026438    0.018334    0.508691    
#> 262: 0.780977    1.191718    3.567137    0.443817    0.026464    0.018288    0.508736    
#> 263: 0.780442    1.191983    3.567100    0.443751    0.026406    0.018250    0.509008    
#> 264: 0.779701    1.192218    3.566946    0.443335    0.026446    0.018205    0.509090    
#> 265: 0.779395    1.192229    3.566869    0.442801    0.026487    0.018168    0.509175    
#> 266: 0.779515    1.192326    3.566922    0.442222    0.026507    0.018106    0.509334    
#> 267: 0.779515    1.192468    3.567053    0.442544    0.026517    0.018060    0.509587    
#> 268: 0.779316    1.192345    3.566987    0.442643    0.026434    0.018033    0.509518    
#> 269: 0.780089    1.192356    3.567043    0.444079    0.026429    0.018083    0.509290    
#> 270: 0.780436    1.192598    3.566935    0.445313    0.026433    0.018130    0.509065    
#> 271: 0.780490    1.192692    3.566867    0.445819    0.026447    0.018138    0.509025    
#> 272: 0.780217    1.192662    3.566668    0.446915    0.026491    0.018104    0.509321    
#> 273: 0.779957    1.192963    3.566635    0.447629    0.026568    0.018070    0.509414    
#> 274: 0.779458    1.193254    3.566525    0.447834    0.026644    0.018030    0.509412    
#> 275: 0.778950    1.193415    3.566331    0.447595    0.026678    0.017984    0.509323    
#> 276: 0.778690    1.193414    3.566409    0.447534    0.026743    0.017963    0.509159    
#> 277: 0.778492    1.193726    3.566374    0.447806    0.026768    0.017973    0.509369    
#> 278: 0.778169    1.193917    3.566342    0.448244    0.026797    0.017986    0.509365    
#> 279: 0.778174    1.193872    3.566393    0.448804    0.026765    0.018022    0.509555    
#> 280: 0.778262    1.193952    3.566425    0.449090    0.026793    0.018009    0.509565    
#> 281: 0.778318    1.193964    3.566442    0.449019    0.026859    0.017970    0.509647    
#> 282: 0.778270    1.194170    3.566389    0.448892    0.026886    0.017964    0.509714    
#> 283: 0.778487    1.194222    3.566456    0.449337    0.026939    0.017961    0.509893    
#> 284: 0.778574    1.193973    3.566488    0.449641    0.026975    0.017928    0.509838    
#> 285: 0.778465    1.193967    3.566442    0.449807    0.027036    0.017936    0.509850    
#> 286: 0.778060    1.194095    3.566352    0.449719    0.027184    0.017951    0.509867    
#> 287: 0.777812    1.194177    3.566187    0.449135    0.027274    0.017951    0.509943    
#> 288: 0.777737    1.194208    3.566137    0.448643    0.027305    0.017970    0.509910    
#> 289: 0.777948    1.194349    3.566104    0.448674    0.027386    0.017983    0.509914    
#> 290: 0.778113    1.194433    3.566028    0.448765    0.027454    0.017982    0.510108    
#> 291: 0.777919    1.194584    3.566060    0.448513    0.027531    0.017957    0.510032    
#> 292: 0.777679    1.194663    3.565931    0.448057    0.027627    0.017932    0.510018    
#> 293: 0.777762    1.194748    3.565893    0.447892    0.027623    0.017883    0.510022    
#> 294: 0.777614    1.194876    3.565775    0.447846    0.027613    0.017860    0.510090    
#> 295: 0.777712    1.194665    3.565839    0.447642    0.027580    0.017851    0.510036    
#> 296: 0.777794    1.194596    3.565878    0.447303    0.027610    0.017830    0.510017    
#> 297: 0.778007    1.194643    3.565998    0.447448    0.027663    0.017835    0.509975    
#> 298: 0.778258    1.194601    3.566018    0.447616    0.027689    0.017831    0.509839    
#> 299: 0.778189    1.194783    3.565848    0.447803    0.027705    0.017831    0.509651    
#> 300: 0.778128    1.194745    3.565773    0.447754    0.027656    0.017823    0.509532    
#> 301: 0.778078    1.194698    3.565674    0.447388    0.027574    0.017802    0.509611    
#> 302: 0.777790    1.194685    3.565529    0.447237    0.027471    0.017795    0.509554    
#> 303: 0.777349    1.194842    3.565402    0.446871    0.027401    0.017815    0.509387    
#> 304: 0.777115    1.195054    3.565315    0.446308    0.027345    0.017830    0.509514    
#> 305: 0.776959    1.194900    3.565313    0.445487    0.027312    0.017835    0.509500    
#> 306: 0.776898    1.194787    3.565314    0.445153    0.027254    0.017833    0.509578    
#> 307: 0.776897    1.194619    3.565350    0.444984    0.027176    0.017858    0.509699    
#> 308: 0.776628    1.194601    3.565306    0.445349    0.027103    0.017880    0.509877    
#> 309: 0.776556    1.194484    3.565301    0.446032    0.027098    0.017895    0.510034    
#> 310: 0.776619    1.194470    3.565175    0.446444    0.027083    0.017918    0.510166    
#> 311: 0.776623    1.194463    3.565162    0.446237    0.027047    0.017919    0.510112    
#> 312: 0.776234    1.194429    3.565040    0.446224    0.027036    0.017916    0.510089    
#> 313: 0.775992    1.194343    3.564864    0.446686    0.027004    0.017903    0.510179    
#> 314: 0.775599    1.194287    3.564783    0.446515    0.026985    0.017902    0.510244    
#> 315: 0.775286    1.194266    3.564668    0.446068    0.026975    0.017901    0.510215    
#> 316: 0.775004    1.194343    3.564559    0.445958    0.026960    0.017927    0.510118    
#> 317: 0.775006    1.194334    3.564547    0.446257    0.026949    0.017955    0.510094    
#> 318: 0.774907    1.194414    3.564433    0.446454    0.026905    0.018002    0.510037    
#> 319: 0.774951    1.194425    3.564408    0.446899    0.026853    0.018040    0.509995    
#> 320: 0.774722    1.194418    3.564408    0.446589    0.026832    0.018059    0.510056    
#> 321: 0.774500    1.194473    3.564386    0.446501    0.026833    0.018083    0.510104    
#> 322: 0.774393    1.194447    3.564383    0.446436    0.026807    0.018109    0.510121    
#> 323: 0.773915    1.194482    3.564272    0.446317    0.026829    0.018127    0.510077    
#> 324: 0.774084    1.194597    3.564373    0.446792    0.026822    0.018104    0.510024    
#> 325: 0.774370    1.194727    3.564331    0.447412    0.026838    0.018082    0.509929    
#> 326: 0.774458    1.194625    3.564339    0.447780    0.026821    0.018081    0.509874    
#> 327: 0.774600    1.194669    3.564387    0.448231    0.026780    0.018102    0.509902    
#> 328: 0.774969    1.194741    3.564427    0.448774    0.026772    0.018089    0.509882    
#> 329: 0.775415    1.194692    3.564577    0.449087    0.026758    0.018100    0.509863    
#> 330: 0.775648    1.194588    3.564667    0.449777    0.026730    0.018126    0.509881    
#> 331: 0.776218    1.194582    3.564790    0.450980    0.026714    0.018164    0.509830    
#> 332: 0.776503    1.194424    3.564863    0.451240    0.026664    0.018208    0.509880    
#> 333: 0.776607    1.194345    3.564853    0.451273    0.026637    0.018229    0.509842    
#> 334: 0.776862    1.194245    3.564814    0.452086    0.026617    0.018240    0.509761    
#> 335: 0.776894    1.194204    3.564814    0.452293    0.026555    0.018217    0.509815    
#> 336: 0.776500    1.194237    3.564739    0.452132    0.026506    0.018233    0.509854    
#> 337: 0.776134    1.194499    3.564620    0.451847    0.026510    0.018227    0.509830    
#> 338: 0.776251    1.194653    3.564591    0.452438    0.026565    0.018221    0.509830    
#> 339: 0.776167    1.194844    3.564524    0.452865    0.026603    0.018184    0.509788    
#> 340: 0.775931    1.194876    3.564464    0.452684    0.026655    0.018148    0.509718    
#> 341: 0.776031    1.194899    3.564439    0.452804    0.026706    0.018110    0.509665    
#> 342: 0.775813    1.194851    3.564410    0.452869    0.026716    0.018111    0.509628    
#> 343: 0.775685    1.194796    3.564436    0.453001    0.026724    0.018117    0.509614    
#> 344: 0.775735    1.194782    3.564474    0.452923    0.026705    0.018136    0.509583    
#> 345: 0.775792    1.194789    3.564455    0.453410    0.026690    0.018153    0.509532    
#> 346: 0.775849    1.194853    3.564379    0.454083    0.026716    0.018147    0.509440    
#> 347: 0.775857    1.194863    3.564335    0.454144    0.026749    0.018127    0.509421    
#> 348: 0.775891    1.194906    3.564338    0.454053    0.026763    0.018119    0.509446    
#> 349: 0.775749    1.194860    3.564298    0.454138    0.026763    0.018113    0.509431    
#> 350: 0.775592    1.194773    3.564294    0.453797    0.026801    0.018099    0.509421    
#> 351: 0.775689    1.194839    3.564266    0.453813    0.026829    0.018109    0.509448    
#> 352: 0.775697    1.194923    3.564309    0.453487    0.026838    0.018100    0.509541    
#> 353: 0.775905    1.195015    3.564378    0.453459    0.026861    0.018112    0.509492    
#> 354: 0.775936    1.195024    3.564342    0.453303    0.026872    0.018103    0.509462    
#> 355: 0.776296    1.194898    3.564365    0.453516    0.026875    0.018095    0.509420    
#> 356: 0.776525    1.194810    3.564465    0.453723    0.026876    0.018106    0.509518    
#> 357: 0.776630    1.194766    3.564507    0.453641    0.026864    0.018090    0.509483    
#> 358: 0.776743    1.194822    3.564529    0.453983    0.026850    0.018073    0.509388    
#> 359: 0.776651    1.194913    3.564476    0.454056    0.026822    0.018038    0.509422    
#> 360: 0.776507    1.194959    3.564395    0.453909    0.026802    0.018028    0.509339    
#> 361: 0.776471    1.194989    3.564381    0.453928    0.026778    0.018033    0.509263    
#> 362: 0.776519    1.194999    3.564369    0.453782    0.026746    0.018039    0.509173    
#> 363: 0.776406    1.194927    3.564432    0.453541    0.026708    0.018052    0.509072    
#> 364: 0.776487    1.194989    3.564452    0.453486    0.026696    0.018052    0.508996    
#> 365: 0.776327    1.194925    3.564443    0.453498    0.026674    0.018080    0.508988    
#> 366: 0.776145    1.194951    3.564341    0.453789    0.026653    0.018110    0.508984    
#> 367: 0.776153    1.194997    3.564312    0.454167    0.026599    0.018135    0.508936    
#> 368: 0.776085    1.195086    3.564259    0.454141    0.026583    0.018147    0.508814    
#> 369: 0.775876    1.195099    3.564229    0.453909    0.026567    0.018150    0.508870    
#> 370: 0.775951    1.195154    3.564215    0.454017    0.026547    0.018185    0.508865    
#> 371: 0.775770    1.195216    3.564130    0.454265    0.026533    0.018200    0.508851    
#> 372: 0.775424    1.195240    3.564045    0.454850    0.026530    0.018225    0.508853    
#> 373: 0.774971    1.195389    3.563893    0.455270    0.026516    0.018231    0.508986    
#> 374: 0.774688    1.195440    3.563811    0.455449    0.026459    0.018241    0.509084    
#> 375: 0.774452    1.195460    3.563779    0.455228    0.026423    0.018263    0.509099    
#> 376: 0.774651    1.195501    3.563806    0.455663    0.026382    0.018276    0.509017    
#> 377: 0.774654    1.195483    3.563817    0.455882    0.026364    0.018283    0.508992    
#> 378: 0.774550    1.195468    3.563800    0.455617    0.026361    0.018288    0.508997    
#> 379: 0.774511    1.195401    3.563834    0.455455    0.026348    0.018293    0.508970    
#> 380: 0.774546    1.195379    3.563868    0.455162    0.026344    0.018284    0.508994    
#> 381: 0.774446    1.195299    3.563888    0.454603    0.026339    0.018283    0.509017    
#> 382: 0.774327    1.195269    3.563883    0.454613    0.026311    0.018280    0.508988    
#> 383: 0.774279    1.195225    3.563875    0.454726    0.026302    0.018273    0.508950    
#> 384: 0.774155    1.195226    3.563829    0.454975    0.026281    0.018267    0.508974    
#> 385: 0.774188    1.195300    3.563813    0.454942    0.026279    0.018267    0.509007    
#> 386: 0.774136    1.195476    3.563795    0.454492    0.026328    0.018277    0.509038    
#> 387: 0.774132    1.195611    3.563851    0.454286    0.026368    0.018280    0.509093    
#> 388: 0.774173    1.195707    3.563876    0.454170    0.026344    0.018293    0.509074    
#> 389: 0.774158    1.195650    3.563873    0.454301    0.026327    0.018288    0.509088    
#> 390: 0.774086    1.195683    3.563857    0.454317    0.026330    0.018282    0.509065    
#> 391: 0.774127    1.195658    3.563814    0.454355    0.026321    0.018274    0.509039    
#> 392: 0.774248    1.195587    3.563854    0.454542    0.026326    0.018271    0.509056    
#> 393: 0.774189    1.195588    3.563812    0.454433    0.026345    0.018253    0.509073    
#> 394: 0.774216    1.195612    3.563785    0.454409    0.026327    0.018244    0.509073    
#> 395: 0.774519    1.195709    3.563771    0.454926    0.026345    0.018231    0.509097    
#> 396: 0.774682    1.195768    3.563793    0.455010    0.026373    0.018232    0.509077    
#> 397: 0.774702    1.195704    3.563795    0.455018    0.026402    0.018243    0.509051    
#> 398: 0.774848    1.195648    3.563840    0.455308    0.026424    0.018259    0.508953    
#> 399: 0.774959    1.195624    3.563915    0.455333    0.026429    0.018269    0.508855    
#> 400: 0.775098    1.195597    3.563987    0.455216    0.026402    0.018259    0.508867    
#> 401: 0.775268    1.195630    3.564068    0.455120    0.026395    0.018268    0.508872    
#> 402: 0.775479    1.195661    3.564108    0.455134    0.026419    0.018284    0.508833    
#> 403: 0.775630    1.195642    3.564147    0.455176    0.026435    0.018292    0.508848    
#> 404: 0.775548    1.195686    3.564076    0.455138    0.026475    0.018274    0.508830    
#> 405: 0.775614    1.195710    3.564108    0.455093    0.026457    0.018271    0.508811    
#> 406: 0.775582    1.195747    3.564093    0.454844    0.026441    0.018267    0.508860    
#> 407: 0.775618    1.195757    3.564172    0.454555    0.026445    0.018257    0.508865    
#> 408: 0.775725    1.195816    3.564206    0.454217    0.026454    0.018253    0.508870    
#> 409: 0.775676    1.195816    3.564170    0.454000    0.026434    0.018252    0.508814    
#> 410: 0.775543    1.195848    3.564091    0.453875    0.026422    0.018245    0.508806    
#> 411: 0.775508    1.195741    3.564094    0.453718    0.026436    0.018237    0.508822    
#> 412: 0.775587    1.195765    3.564095    0.453927    0.026432    0.018234    0.508802    
#> 413: 0.775596    1.195819    3.564071    0.454301    0.026425    0.018230    0.508875    
#> 414: 0.775396    1.195847    3.564053    0.454256    0.026416    0.018233    0.508937    
#> 415: 0.775413    1.195875    3.564037    0.454192    0.026395    0.018227    0.508938    
#> 416: 0.775477    1.195963    3.564064    0.454165    0.026368    0.018221    0.508938    
#> 417: 0.775475    1.196010    3.564066    0.453998    0.026352    0.018220    0.508972    
#> 418: 0.775414    1.196006    3.564097    0.453867    0.026350    0.018218    0.508923    
#> 419: 0.775416    1.196100    3.564098    0.453808    0.026348    0.018212    0.508883    
#> 420: 0.775489    1.196162    3.564099    0.453975    0.026354    0.018198    0.508778    
#> 421: 0.775482    1.196217    3.564115    0.454131    0.026331    0.018208    0.508711    
#> 422: 0.775535    1.196151    3.564150    0.454042    0.026325    0.018218    0.508656    
#> 423: 0.775577    1.196113    3.564160    0.454025    0.026337    0.018229    0.508588    
#> 424: 0.775408    1.196100    3.564092    0.454278    0.026332    0.018219    0.508506    
#> 425: 0.775435    1.196127    3.564080    0.454526    0.026349    0.018216    0.508485    
#> 426: 0.775495    1.196190    3.564055    0.454893    0.026367    0.018221    0.508438    
#> 427: 0.775334    1.196174    3.564032    0.454776    0.026372    0.018204    0.508408    
#> 428: 0.775287    1.196226    3.564050    0.454753    0.026355    0.018203    0.508440    
#> 429: 0.775318    1.196249    3.564065    0.454746    0.026333    0.018215    0.508507    
#> 430: 0.775381    1.196233    3.564088    0.454765    0.026305    0.018223    0.508540    
#> 431: 0.775395    1.196221    3.564060    0.454690    0.026292    0.018217    0.508549    
#> 432: 0.775337    1.196278    3.564037    0.454728    0.026288    0.018210    0.508549    
#> 433: 0.775369    1.196336    3.564059    0.454756    0.026309    0.018198    0.508520    
#> 434: 0.775215    1.196291    3.564050    0.454547    0.026338    0.018182    0.508487    
#> 435: 0.775209    1.196244    3.564030    0.454629    0.026371    0.018162    0.508433    
#> 436: 0.775060    1.196226    3.564023    0.454290    0.026416    0.018145    0.508407    
#> 437: 0.775012    1.196207    3.564024    0.454176    0.026468    0.018137    0.508417    
#> 438: 0.774953    1.196345    3.563986    0.454098    0.026474    0.018135    0.508415    
#> 439: 0.775074    1.196446    3.563964    0.454328    0.026477    0.018130    0.508376    
#> 440: 0.775173    1.196488    3.564001    0.454345    0.026492    0.018129    0.508359    
#> 441: 0.775181    1.196462    3.564047    0.454223    0.026477    0.018127    0.508325    
#> 442: 0.775085    1.196498    3.564045    0.454198    0.026472    0.018127    0.508299    
#> 443: 0.775077    1.196573    3.564012    0.454107    0.026451    0.018133    0.508309    
#> 444: 0.775017    1.196641    3.563957    0.454213    0.026427    0.018142    0.508272    
#> 445: 0.774888    1.196682    3.563927    0.454046    0.026411    0.018141    0.508297    
#> 446: 0.774850    1.196707    3.563909    0.453772    0.026385    0.018152    0.508315    
#> 447: 0.775019    1.196717    3.563922    0.453786    0.026366    0.018157    0.508336    
#> 448: 0.775018    1.196693    3.563983    0.453771    0.026357    0.018164    0.508271    
#> 449: 0.775051    1.196722    3.564078    0.453776    0.026332    0.018190    0.508286    
#> 450: 0.775054    1.196685    3.564129    0.453712    0.026317    0.018214    0.508300    
#> 451: 0.775106    1.196669    3.564144    0.453588    0.026292    0.018227    0.508313    
#> 452: 0.775226    1.196637    3.564148    0.453373    0.026281    0.018231    0.508303    
#> 453: 0.775391    1.196588    3.564176    0.453424    0.026273    0.018229    0.508288    
#> 454: 0.775607    1.196617    3.564190    0.453991    0.026254    0.018250    0.508260    
#> 455: 0.775733    1.196630    3.564180    0.454559    0.026238    0.018260    0.508254    
#> 456: 0.775753    1.196558    3.564193    0.454715    0.026243    0.018270    0.508242    
#> 457: 0.775835    1.196503    3.564280    0.454677    0.026255    0.018273    0.508235    
#> 458: 0.775761    1.196564    3.564310    0.454289    0.026260    0.018274    0.508237    
#> 459: 0.775481    1.196655    3.564301    0.454108    0.026250    0.018275    0.508306    
#> 460: 0.775325    1.196698    3.564270    0.453929    0.026259    0.018265    0.508268    
#> 461: 0.775306    1.196763    3.564260    0.453874    0.026253    0.018274    0.508251    
#> 462: 0.775274    1.196826    3.564260    0.453875    0.026238    0.018284    0.508260    
#> 463: 0.775471    1.196847    3.564329    0.454059    0.026230    0.018296    0.508258    
#> 464: 0.775757    1.196850    3.564349    0.454405    0.026216    0.018302    0.508252    
#> 465: 0.776074    1.196719    3.564408    0.454860    0.026204    0.018298    0.508220    
#> 466: 0.776325    1.196666    3.564439    0.455255    0.026204    0.018298    0.508172    
#> 467: 0.776546    1.196589    3.564504    0.455532    0.026201    0.018308    0.508113    
#> 468: 0.776693    1.196532    3.564565    0.455587    0.026200    0.018309    0.508129    
#> 469: 0.776760    1.196580    3.564592    0.455424    0.026220    0.018299    0.508191    
#> 470: 0.776645    1.196596    3.564574    0.455400    0.026234    0.018306    0.508186    
#> 471: 0.776538    1.196615    3.564578    0.455084    0.026246    0.018311    0.508209    
#> 472: 0.776491    1.196604    3.564569    0.455149    0.026239    0.018307    0.508207    
#> 473: 0.776469    1.196622    3.564570    0.455001    0.026241    0.018308    0.508169    
#> 474: 0.776470    1.196657    3.564560    0.454861    0.026239    0.018316    0.508160    
#> 475: 0.776512    1.196762    3.564551    0.455010    0.026243    0.018314    0.508113    
#> 476: 0.776452    1.196794    3.564547    0.455003    0.026224    0.018308    0.508119    
#> 477: 0.776443    1.196804    3.564579    0.454963    0.026196    0.018311    0.508086    
#> 478: 0.776376    1.196775    3.564605    0.454915    0.026182    0.018317    0.508080    
#> 479: 0.776383    1.196775    3.564614    0.454983    0.026172    0.018323    0.508112    
#> 480: 0.776402    1.196768    3.564611    0.455195    0.026175    0.018332    0.508102    
#> 481: 0.776436    1.196765    3.564594    0.455331    0.026170    0.018341    0.508060    
#> 482: 0.776436    1.196772    3.564563    0.455586    0.026159    0.018346    0.508068    
#> 483: 0.776321    1.196710    3.564552    0.455690    0.026167    0.018354    0.508015    
#> 484: 0.776289    1.196600    3.564570    0.455546    0.026171    0.018373    0.507987    
#> 485: 0.776209    1.196632    3.564560    0.455469    0.026171    0.018384    0.507983    
#> 486: 0.776137    1.196660    3.564569    0.455380    0.026164    0.018402    0.507943    
#> 487: 0.776216    1.196696    3.564613    0.455527    0.026149    0.018421    0.507919    
#> 488: 0.776187    1.196655    3.564627    0.455396    0.026138    0.018429    0.507899    
#> 489: 0.776295    1.196592    3.564623    0.455464    0.026125    0.018440    0.507913    
#> 490: 0.776329    1.196577    3.564641    0.455496    0.026127    0.018452    0.507925    
#> 491: 0.776282    1.196635    3.564631    0.455619    0.026115    0.018468    0.507921    
#> 492: 0.776216    1.196703    3.564584    0.455697    0.026122    0.018484    0.507945    
#> 493: 0.776110    1.196738    3.564567    0.455869    0.026107    0.018491    0.507920    
#> 494: 0.776155    1.196781    3.564547    0.455928    0.026092    0.018496    0.507901    
#> 495: 0.776231    1.196827    3.564532    0.455974    0.026086    0.018506    0.507891    
#> 496: 0.776261    1.196918    3.564467    0.456098    0.026093    0.018514    0.507916    
#> 497: 0.776163    1.196956    3.564413    0.456126    0.026089    0.018519    0.507959    
#> 498: 0.776027    1.196966    3.564359    0.456082    0.026101    0.018517    0.507924    
#> 499: 0.775904    1.197027    3.564299    0.455912    0.026100    0.018511    0.507898    
#> 500: 0.775881    1.197039    3.564269    0.455660    0.026093    0.018506    0.507954    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.286717    0.966445    3.452233    0.392401    0.084150    0.016800    1.710174    
#> 002: 0.251876    1.057468    3.463566    0.372781    0.079942    0.015960    1.187661    
#> 003: 0.441017    1.040675    3.510213    0.354142    0.075945    0.015162    0.876435    
#> 004: 0.437024    1.091807    3.518143    0.336435    0.072148    0.014404    0.778573    
#> 005: 0.511109    1.105649    3.515356    0.319613    0.068540    0.013684    0.750749    
#> 006: 0.477268    1.103728    3.504226    0.365177    0.065113    0.013000    0.704700    
#> 007: 0.437882    1.120722    3.495757    0.352076    0.061858    0.012350    0.724772    
#> 008: 0.401960    1.119892    3.479412    0.334472    0.058765    0.011732    0.719826    
#> 009: 0.381891    1.106724    3.486171    0.330975    0.055827    0.011146    0.722992    
#> 010: 0.387442    1.113625    3.478321    0.364940    0.053035    0.010588    0.737109    
#> 011: 0.468330    1.135540    3.484608    0.405975    0.050384    0.010059    0.729799    
#> 012: 0.434513    1.127186    3.472917    0.385676    0.047864    0.009556    0.710285    
#> 013: 0.378507    1.132673    3.469025    0.366393    0.045471    0.009796    0.721232    
#> 014: 0.443247    1.134760    3.476424    0.348073    0.043198    0.009306    0.734096    
#> 015: 0.455317    1.134476    3.491993    0.330669    0.041038    0.008841    0.714257    
#> 016: 0.438216    1.135319    3.499693    0.316521    0.038986    0.008975    0.721177    
#> 017: 0.431121    1.119354    3.497288    0.300695    0.037037    0.008526    0.707868    
#> 018: 0.461640    1.135868    3.488344    0.290648    0.035185    0.008100    0.732214    
#> 019: 0.408329    1.139119    3.488313    0.276115    0.033425    0.007695    0.709700    
#> 020: 0.435775    1.130263    3.497152    0.262309    0.031754    0.007928    0.725424    
#> 021: 0.460553    1.123172    3.505650    0.275655    0.030166    0.007532    0.706191    
#> 022: 0.482289    1.108006    3.511036    0.296909    0.028658    0.007155    0.704476    
#> 023: 0.533602    1.118032    3.526181    0.342229    0.027225    0.007030    0.730236    
#> 024: 0.529740    1.112355    3.533184    0.325118    0.025864    0.008192    0.720419    
#> 025: 0.510224    1.105577    3.514333    0.308862    0.024571    0.008079    0.718981    
#> 026: 0.475979    1.101780    3.516598    0.293419    0.023342    0.008893    0.712909    
#> 027: 0.446524    1.126878    3.511378    0.323259    0.022175    0.011350    0.724990    
#> 028: 0.558675    1.110079    3.539369    0.337070    0.021066    0.010783    0.703159    
#> 029: 0.553686    1.085712    3.526467    0.369290    0.020013    0.010244    0.737579    
#> 030: 0.532221    1.106929    3.517060    0.350826    0.019012    0.009731    0.703737    
#> 031: 0.509901    1.084181    3.526356    0.333285    0.018062    0.009245    0.713658    
#> 032: 0.479420    1.099409    3.529383    0.316620    0.017159    0.008783    0.716194    
#> 033: 0.460217    1.107410    3.507696    0.367260    0.016301    0.009554    0.727901    
#> 034: 0.517696    1.110129    3.515760    0.366716    0.015486    0.009176    0.711266    
#> 035: 0.488010    1.108328    3.506094    0.348380    0.014711    0.008717    0.704109    
#> 036: 0.439921    1.114186    3.494553    0.330961    0.013976    0.008384    0.708911    
#> 037: 0.471922    1.131481    3.500400    0.330111    0.015152    0.008537    0.720692    
#> 038: 0.481242    1.113348    3.503656    0.313605    0.015267    0.008110    0.710517    
#> 039: 0.494339    1.104196    3.513536    0.357323    0.014504    0.008991    0.713955    
#> 040: 0.444402    1.105486    3.511490    0.375337    0.013779    0.008541    0.715866    
#> 041: 0.464310    1.094173    3.507013    0.364940    0.013090    0.008114    0.704037    
#> 042: 0.508756    1.090437    3.502625    0.431270    0.012435    0.009307    0.702144    
#> 043: 0.450526    1.109928    3.493509    0.439359    0.011960    0.009754    0.718192    
#> 044: 0.462369    1.116083    3.500374    0.417391    0.011954    0.009843    0.712865    
#> 045: 0.454106    1.124067    3.491844    0.396521    0.011356    0.009369    0.713557    
#> 046: 0.458721    1.121775    3.493943    0.388598    0.010788    0.008900    0.704951    
#> 047: 0.449391    1.121951    3.490233    0.369168    0.011367    0.008455    0.702915    
#> 048: 0.454203    1.118113    3.495467    0.350709    0.015729    0.008032    0.710223    
#> 049: 0.406106    1.116313    3.490955    0.333174    0.017896    0.010668    0.726931    
#> 050: 0.519457    1.101901    3.502222    0.386551    0.018201    0.011037    0.721902    
#> 051: 0.468477    1.102196    3.489198    0.367224    0.017291    0.012550    0.733289    
#> 052: 0.467052    1.110999    3.512033    0.348863    0.016427    0.011923    0.719010    
#> 053: 0.484269    1.107130    3.512926    0.331420    0.015605    0.011327    0.707322    
#> 054: 0.417140    1.112266    3.505460    0.314849    0.017602    0.010760    0.743619    
#> 055: 0.458759    1.100590    3.518902    0.299106    0.016722    0.010784    0.720651    
#> 056: 0.509774    1.095186    3.524155    0.284151    0.015886    0.012271    0.728897    
#> 057: 0.521392    1.074515    3.532135    0.269943    0.015092    0.011738    0.743816    
#> 058: 0.541017    1.081474    3.519963    0.307325    0.014337    0.011151    0.724800    
#> 059: 0.526550    1.068009    3.532286    0.357089    0.014463    0.011750    0.712735    
#> 060: 0.507211    1.065683    3.529933    0.339235    0.015016    0.011162    0.719091    
#> 061: 0.542184    1.062837    3.535914    0.350123    0.015067    0.010604    0.728934    
#> 062: 0.493094    1.078523    3.534874    0.332617    0.021831    0.010074    0.741225    
#> 063: 0.528336    1.071890    3.528758    0.315986    0.022842    0.009570    0.727310    
#> 064: 0.507587    1.083620    3.528801    0.300187    0.021700    0.009092    0.724876    
#> 065: 0.504659    1.076953    3.513812    0.285177    0.020615    0.008637    0.715452    
#> 066: 0.497517    1.104152    3.516314    0.270918    0.019584    0.008328    0.698362    
#> 067: 0.475312    1.119165    3.503210    0.257372    0.018605    0.010930    0.719142    
#> 068: 0.418389    1.132089    3.504723    0.248300    0.017675    0.010383    0.726567    
#> 069: 0.429975    1.139660    3.489124    0.324948    0.016791    0.009864    0.736819    
#> 070: 0.458217    1.141413    3.505208    0.339445    0.015951    0.009371    0.743612    
#> 071: 0.428067    1.162377    3.475048    0.343234    0.016306    0.008903    0.733829    
#> 072: 0.369700    1.147308    3.471078    0.411374    0.015491    0.008457    0.725742    
#> 073: 0.438302    1.132669    3.500022    0.390805    0.014717    0.010233    0.729969    
#> 074: 0.449525    1.133985    3.502727    0.371265    0.016513    0.009721    0.729182    
#> 075: 0.490121    1.127054    3.524093    0.352702    0.015687    0.009235    0.725740    
#> 076: 0.485460    1.124493    3.527419    0.335067    0.014903    0.008773    0.722831    
#> 077: 0.551757    1.108717    3.520205    0.318313    0.014158    0.010309    0.706284    
#> 078: 0.537384    1.091286    3.545018    0.302398    0.014895    0.011973    0.728012    
#> 079: 0.540053    1.098171    3.536365    0.366199    0.014151    0.011374    0.738673    
#> 080: 0.509632    1.081631    3.517343    0.409374    0.015350    0.010806    0.735506    
#> 081: 0.520094    1.083996    3.519581    0.400452    0.014582    0.010265    0.715924    
#> 082: 0.509383    1.078505    3.526429    0.380430    0.013853    0.011499    0.718684    
#> 083: 0.480951    1.084897    3.530359    0.361408    0.013160    0.012177    0.719659    
#> 084: 0.503624    1.098288    3.516656    0.383854    0.012661    0.012959    0.722966    
#> 085: 0.473543    1.095775    3.528635    0.364661    0.013122    0.012311    0.741568    
#> 086: 0.477776    1.086213    3.522163    0.346428    0.012466    0.011696    0.731123    
#> 087: 0.485093    1.079374    3.522385    0.329107    0.011842    0.011491    0.725744    
#> 088: 0.435939    1.083927    3.523783    0.316717    0.011250    0.010916    0.754271    
#> 089: 0.464598    1.079202    3.503405    0.307912    0.010688    0.010371    0.722351    
#> 090: 0.442085    1.079804    3.511557    0.292517    0.010153    0.010189    0.722169    
#> 091: 0.425442    1.078699    3.496270    0.321170    0.009646    0.010020    0.729342    
#> 092: 0.450433    1.089401    3.503121    0.310574    0.009163    0.009519    0.722657    
#> 093: 0.448254    1.092064    3.501545    0.307218    0.008705    0.011223    0.732447    
#> 094: 0.418725    1.094266    3.492078    0.291857    0.008270    0.011106    0.735916    
#> 095: 0.454158    1.091040    3.517846    0.277265    0.008061    0.010856    0.746046    
#> 096: 0.441476    1.104043    3.505676    0.280275    0.008614    0.010313    0.728486    
#> 097: 0.462772    1.108571    3.497554    0.302440    0.008183    0.010042    0.714081    
#> 098: 0.472480    1.107814    3.515263    0.342366    0.008738    0.011530    0.726975    
#> 099: 0.443349    1.101353    3.492442    0.325248    0.012040    0.011348    0.726302    
#> 100: 0.465678    1.101938    3.508095    0.327480    0.014083    0.010781    0.718544    
#> 101: 0.459655    1.091367    3.501188    0.315762    0.013379    0.010242    0.708637    
#> 102: 0.454665    1.088179    3.493975    0.299974    0.012710    0.009730    0.709513    
#> 103: 0.523578    1.097379    3.516140    0.311582    0.012075    0.009243    0.715650    
#> 104: 0.491874    1.088684    3.527943    0.424281    0.011471    0.008781    0.708399    
#> 105: 0.527313    1.089610    3.523612    0.403067    0.011886    0.009771    0.703723    
#> 106: 0.514142    1.096155    3.518708    0.405500    0.011292    0.009283    0.717397    
#> 107: 0.568515    1.106044    3.530304    0.385225    0.011141    0.008819    0.716058    
#> 108: 0.506342    1.109498    3.520192    0.365964    0.014043    0.008378    0.713442    
#> 109: 0.497557    1.106708    3.522520    0.354868    0.013340    0.007959    0.731095    
#> 110: 0.490410    1.110510    3.500916    0.337125    0.012673    0.007561    0.745006    
#> 111: 0.486764    1.120154    3.508588    0.320268    0.012040    0.007183    0.731416    
#> 112: 0.436124    1.101643    3.501148    0.304255    0.011438    0.008554    0.720877    
#> 113: 0.442071    1.101633    3.509271    0.289042    0.010866    0.008126    0.713658    
#> 114: 0.473530    1.105399    3.511159    0.301005    0.010323    0.007720    0.724542    
#> 115: 0.492118    1.094532    3.512013    0.355071    0.009806    0.007334    0.743390    
#> 116: 0.504958    1.113694    3.516504    0.369771    0.009481    0.008091    0.729356    
#> 117: 0.486190    1.126179    3.516356    0.352398    0.012387    0.007686    0.722351    
#> 118: 0.495555    1.123687    3.509795    0.334778    0.013035    0.007302    0.727059    
#> 119: 0.443935    1.114013    3.498103    0.318039    0.012383    0.006937    0.722399    
#> 120: 0.464066    1.106069    3.501775    0.378617    0.012189    0.006590    0.700494    
#> 121: 0.469083    1.123962    3.497953    0.359686    0.019068    0.006536    0.685430    
#> 122: 0.457923    1.100282    3.509498    0.341702    0.022014    0.007844    0.697287    
#> 123: 0.503003    1.125551    3.509176    0.325586    0.025232    0.007452    0.709092    
#> 124: 0.490663    1.145664    3.503777    0.313514    0.023971    0.007079    0.702762    
#> 125: 0.494293    1.130756    3.501320    0.320617    0.022772    0.008046    0.707295    
#> 126: 0.465228    1.138346    3.498134    0.304586    0.021633    0.009395    0.711509    
#> 127: 0.475742    1.127377    3.491134    0.333038    0.020552    0.010062    0.712718    
#> 128: 0.483688    1.107194    3.515521    0.316386    0.019524    0.009559    0.710309    
#> 129: 0.510984    1.114399    3.526782    0.315080    0.020464    0.009917    0.708788    
#> 130: 0.518471    1.106231    3.517008    0.299326    0.019441    0.009857    0.713536    
#> 131: 0.482149    1.113845    3.508602    0.284360    0.022580    0.009799    0.693075    
#> 132: 0.454696    1.106615    3.490467    0.270142    0.021451    0.009309    0.721477    
#> 133: 0.453543    1.131517    3.495310    0.260126    0.020378    0.009269    0.733375    
#> 134: 0.461363    1.110689    3.512954    0.284275    0.019359    0.011995    0.732628    
#> 135: 0.458755    1.091319    3.521263    0.270062    0.018391    0.011612    0.715654    
#> 136: 0.457303    1.091486    3.521819    0.256559    0.020355    0.011031    0.726626    
#> 137: 0.487157    1.093736    3.522100    0.301770    0.019337    0.010480    0.728252    
#> 138: 0.506871    1.080946    3.523591    0.321257    0.018370    0.010551    0.714829    
#> 139: 0.556639    1.089028    3.546481    0.322069    0.017452    0.012144    0.728164    
#> 140: 0.547722    1.096295    3.547784    0.327714    0.016579    0.013297    0.742304    
#> 141: 0.500399    1.068818    3.542594    0.311328    0.015750    0.012632    0.717392    
#> 142: 0.505264    1.072809    3.538494    0.295762    0.015230    0.012000    0.732737    
#> 143: 0.483611    1.068635    3.538608    0.280974    0.014468    0.013019    0.740886    
#> 144: 0.539253    1.087478    3.549934    0.304996    0.013745    0.012368    0.731182    
#> 145: 0.483953    1.097883    3.519041    0.337691    0.013058    0.011749    0.712979    
#> 146: 0.477416    1.098952    3.525647    0.389686    0.012405    0.011854    0.731709    
#> 147: 0.446549    1.107507    3.501642    0.370201    0.011785    0.011262    0.704389    
#> 148: 0.436240    1.116999    3.504049    0.351691    0.011195    0.010699    0.721332    
#> 149: 0.473476    1.110990    3.508699    0.356564    0.010636    0.010164    0.731452    
#> 150: 0.497943    1.088497    3.508489    0.358214    0.010104    0.009656    0.711435    
#> 151: 0.441865    1.094171    3.499153    0.340304    0.009599    0.009173    0.725450    
#> 152: 0.440381    1.107114    3.501347    0.356796    0.008552    0.011337    0.729959    
#> 153: 0.471260    1.118967    3.519247    0.311472    0.011660    0.009775    0.728000    
#> 154: 0.476051    1.124347    3.516830    0.332225    0.008153    0.008255    0.713532    
#> 155: 0.464930    1.112344    3.508389    0.301808    0.008899    0.009215    0.715874    
#> 156: 0.486491    1.114201    3.518296    0.283819    0.008758    0.011641    0.724614    
#> 157: 0.510742    1.125439    3.525165    0.252775    0.007479    0.010301    0.738283    
#> 158: 0.532080    1.138975    3.524332    0.265721    0.007122    0.013297    0.728558    
#> 159: 0.444270    1.136026    3.520055    0.243139    0.008897    0.013446    0.712290    
#> 160: 0.501580    1.106673    3.533743    0.245872    0.011545    0.013019    0.719802    
#> 161: 0.485068    1.089501    3.526227    0.257314    0.011895    0.016279    0.722793    
#> 162: 0.492442    1.115097    3.515717    0.274467    0.010592    0.014623    0.729464    
#> 163: 0.507806    1.095083    3.512286    0.348109    0.010157    0.010222    0.713275    
#> 164: 0.510561    1.102092    3.520095    0.315731    0.010486    0.010671    0.721013    
#> 165: 0.507983    1.108219    3.530133    0.273508    0.008152    0.013536    0.707431    
#> 166: 0.480000    1.132316    3.516964    0.268765    0.007604    0.011817    0.707313    
#> 167: 0.497071    1.142983    3.523150    0.253944    0.005696    0.014338    0.718153    
#> 168: 0.498549    1.160233    3.513163    0.331642    0.005362    0.015270    0.721062    
#> 169: 0.495495    1.162057    3.498014    0.351920    0.006136    0.011496    0.747212    
#> 170: 0.496172    1.137561    3.509648    0.350431    0.006603    0.010830    0.716148    
#> 171: 0.447513    1.142896    3.504415    0.318489    0.007705    0.010635    0.712895    
#> 172: 0.478913    1.150655    3.505290    0.333845    0.007177    0.009698    0.713104    
#> 173: 0.467816    1.156418    3.488419    0.372914    0.008349    0.011858    0.709580    
#> 174: 0.460980    1.151664    3.493836    0.446721    0.006995    0.013608    0.708155    
#> 175: 0.444580    1.135280    3.486498    0.376836    0.009618    0.009358    0.716535    
#> 176: 0.460709    1.156352    3.488271    0.475430    0.006351    0.007348    0.690136    
#> 177: 0.463179    1.147594    3.496162    0.410245    0.007543    0.005788    0.722202    
#> 178: 0.470385    1.137670    3.491270    0.322160    0.009047    0.007750    0.723946    
#> 179: 0.493282    1.152617    3.491296    0.282079    0.009962    0.008043    0.739721    
#> 180: 0.428327    1.143670    3.488198    0.360913    0.008758    0.008747    0.700938    
#> 181: 0.424760    1.121735    3.481251    0.295334    0.010408    0.008811    0.698385    
#> 182: 0.444500    1.120909    3.473716    0.285546    0.009246    0.009134    0.722463    
#> 183: 0.424102    1.131302    3.479540    0.305229    0.008230    0.010920    0.714907    
#> 184: 0.422148    1.122768    3.478519    0.273806    0.007938    0.008645    0.731281    
#> 185: 0.411966    1.127397    3.484746    0.284854    0.008201    0.008799    0.735223    
#> 186: 0.428480    1.129159    3.493367    0.340711    0.010569    0.009448    0.729296    
#> 187: 0.445977    1.115044    3.503418    0.340577    0.010108    0.009109    0.711628    
#> 188: 0.435680    1.132535    3.495640    0.315702    0.012642    0.007763    0.744202    
#> 189: 0.499908    1.157767    3.507052    0.377031    0.015159    0.007755    0.736041    
#> 190: 0.488439    1.129172    3.501592    0.458264    0.010764    0.009986    0.720345    
#> 191: 0.438241    1.129185    3.488850    0.291111    0.011189    0.008539    0.730666    
#> 192: 0.398959    1.132514    3.489323    0.279620    0.010643    0.010360    0.728831    
#> 193: 0.483198    1.139982    3.504464    0.299041    0.009546    0.008196    0.720739    
#> 194: 0.427403    1.127164    3.500049    0.293751    0.011684    0.008737    0.730248    
#> 195: 0.426397    1.122207    3.491826    0.329198    0.013859    0.007679    0.729999    
#> 196: 0.443473    1.122932    3.504861    0.309830    0.018814    0.008377    0.722521    
#> 197: 0.421765    1.134642    3.509484    0.264193    0.017646    0.006985    0.729892    
#> 198: 0.487396    1.134234    3.501214    0.238925    0.011743    0.008141    0.735615    
#> 199: 0.464863    1.125415    3.502067    0.328389    0.012493    0.006809    0.714931    
#> 200: 0.435374    1.127766    3.490465    0.368248    0.013996    0.007374    0.715006    
#> 201: 0.430403    1.124454    3.495214    0.351635    0.013850    0.008418    0.713229    
#> 202: 0.431854    1.125499    3.496236    0.334926    0.013619    0.008854    0.719145    
#> 203: 0.443329    1.122511    3.496601    0.322526    0.013742    0.008890    0.721566    
#> 204: 0.452341    1.119753    3.500747    0.314160    0.012791    0.008924    0.724557    
#> 205: 0.452361    1.121274    3.502238    0.312724    0.012344    0.009094    0.724971    
#> 206: 0.455542    1.123037    3.503834    0.312452    0.011942    0.009134    0.725115    
#> 207: 0.451821    1.122803    3.503179    0.314688    0.011837    0.009304    0.724404    
#> 208: 0.452291    1.121408    3.502880    0.324440    0.011576    0.009264    0.722698    
#> 209: 0.453828    1.119792    3.502667    0.325590    0.011400    0.009412    0.720214    
#> 210: 0.456599    1.118455    3.503112    0.328300    0.011280    0.009345    0.719709    
#> 211: 0.458697    1.118387    3.504461    0.327003    0.011285    0.009361    0.718672    
#> 212: 0.461458    1.118391    3.505536    0.328303    0.011291    0.009296    0.717661    
#> 213: 0.466511    1.116559    3.505953    0.332757    0.011373    0.009402    0.718167    
#> 214: 0.471913    1.115718    3.506687    0.337447    0.011325    0.009569    0.717810    
#> 215: 0.471395    1.115372    3.506893    0.343143    0.011072    0.009787    0.718381    
#> 216: 0.473294    1.113837    3.507685    0.339033    0.010956    0.009867    0.720457    
#> 217: 0.474906    1.113023    3.508345    0.336784    0.010849    0.009864    0.720956    
#> 218: 0.474614    1.114246    3.506942    0.335899    0.010897    0.009866    0.720670    
#> 219: 0.475433    1.114883    3.506053    0.338894    0.010899    0.009899    0.721118    
#> 220: 0.474470    1.115574    3.505334    0.342564    0.010788    0.009897    0.720388    
#> 221: 0.473867    1.115852    3.505103    0.344978    0.010659    0.009820    0.719496    
#> 222: 0.475825    1.115643    3.505332    0.345546    0.010476    0.009877    0.718576    
#> 223: 0.477816    1.115291    3.505749    0.348618    0.010380    0.009927    0.717937    
#> 224: 0.478717    1.115290    3.506151    0.347985    0.010334    0.009987    0.717648    
#> 225: 0.477675    1.114588    3.506288    0.349392    0.010271    0.009990    0.718050    
#> 226: 0.476776    1.113948    3.506014    0.347435    0.010191    0.009942    0.718929    
#> 227: 0.475470    1.113622    3.506292    0.346649    0.010244    0.009889    0.719439    
#> 228: 0.473756    1.114135    3.506192    0.345254    0.010335    0.009832    0.719804    
#> 229: 0.472616    1.113990    3.505946    0.343800    0.010356    0.009786    0.719225    
#> 230: 0.471954    1.113968    3.505566    0.342642    0.010403    0.009765    0.719016    
#> 231: 0.472508    1.114551    3.505677    0.341666    0.010460    0.009754    0.718785    
#> 232: 0.471262    1.114821    3.505802    0.340424    0.010465    0.009744    0.718729    
#> 233: 0.471109    1.114749    3.505979    0.339574    0.010429    0.009742    0.718633    
#> 234: 0.469993    1.115122    3.506135    0.339960    0.010532    0.009721    0.718789    
#> 235: 0.470364    1.115142    3.505983    0.341790    0.010431    0.009713    0.718426    
#> 236: 0.471005    1.115347    3.505892    0.341048    0.010335    0.009743    0.718538    
#> 237: 0.472459    1.115444    3.505982    0.340808    0.010265    0.009771    0.718772    
#> 238: 0.472525    1.115828    3.505912    0.339580    0.010222    0.009745    0.718913    
#> 239: 0.472048    1.116565    3.505707    0.338984    0.010334    0.009729    0.718306    
#> 240: 0.472162    1.116927    3.505631    0.336750    0.010449    0.009709    0.717503    
#> 241: 0.472306    1.117108    3.505722    0.336278    0.010450    0.009671    0.717374    
#> 242: 0.471762    1.117483    3.505335    0.338040    0.010498    0.009674    0.717735    
#> 243: 0.471177    1.117750    3.505283    0.338536    0.010563    0.009650    0.718241    
#> 244: 0.471050    1.117561    3.505642    0.337320    0.010552    0.009678    0.719054    
#> 245: 0.471076    1.117575    3.505609    0.336936    0.010603    0.009674    0.719803    
#> 246: 0.471147    1.117573    3.505485    0.336503    0.010631    0.009727    0.720068    
#> 247: 0.471240    1.117639    3.505717    0.335824    0.010588    0.009747    0.720241    
#> 248: 0.470904    1.117556    3.505828    0.335268    0.010539    0.009756    0.719963    
#> 249: 0.471156    1.117345    3.506068    0.335139    0.010508    0.009748    0.720041    
#> 250: 0.471357    1.117674    3.506097    0.334964    0.010521    0.009770    0.720100    
#> 251: 0.471096    1.118089    3.506178    0.334591    0.010519    0.009793    0.720240    
#> 252: 0.471141    1.118359    3.506347    0.333804    0.010527    0.009787    0.720250    
#> 253: 0.471060    1.118435    3.506318    0.333862    0.010539    0.009807    0.720101    
#> 254: 0.471323    1.118644    3.506378    0.333929    0.010551    0.009803    0.720052    
#> 255: 0.470807    1.118840    3.506571    0.334408    0.010530    0.009833    0.720394    
#> 256: 0.471183    1.118375    3.506727    0.334687    0.010533    0.009810    0.720938    
#> 257: 0.471578    1.117907    3.506859    0.333492    0.010518    0.009809    0.721284    
#> 258: 0.471213    1.117480    3.506802    0.332335    0.010505    0.009781    0.721472    
#> 259: 0.471070    1.117222    3.506901    0.331803    0.010507    0.009764    0.721556    
#> 260: 0.470560    1.117234    3.506860    0.331826    0.010515    0.009742    0.721526    
#> 261: 0.470391    1.117331    3.506845    0.332705    0.010566    0.009740    0.721590    
#> 262: 0.469815    1.117518    3.506718    0.332135    0.010595    0.009747    0.721531    
#> 263: 0.469084    1.117715    3.506521    0.332535    0.010548    0.009733    0.721537    
#> 264: 0.468670    1.117897    3.506233    0.332606    0.010541    0.009726    0.721791    
#> 265: 0.468540    1.117856    3.506251    0.331489    0.010519    0.009747    0.722090    
#> 266: 0.468336    1.117989    3.506327    0.330301    0.010511    0.009773    0.722151    
#> 267: 0.468053    1.117947    3.506446    0.330519    0.010495    0.009786    0.722237    
#> 268: 0.467973    1.117858    3.506345    0.330151    0.010504    0.009813    0.722018    
#> 269: 0.468300    1.117614    3.506385    0.329342    0.010504    0.009867    0.721921    
#> 270: 0.468421    1.117418    3.506408    0.328885    0.010470    0.009902    0.721786    
#> 271: 0.468679    1.117252    3.506406    0.328415    0.010444    0.009969    0.721748    
#> 272: 0.468905    1.117286    3.506365    0.328270    0.010445    0.009996    0.721833    
#> 273: 0.468593    1.117567    3.506396    0.328181    0.010489    0.010041    0.721690    
#> 274: 0.468882    1.117858    3.506483    0.328166    0.010468    0.010068    0.721509    
#> 275: 0.468850    1.117959    3.506361    0.327664    0.010458    0.010087    0.721255    
#> 276: 0.468921    1.118071    3.506491    0.327464    0.010467    0.010102    0.721222    
#> 277: 0.469182    1.118154    3.506686    0.327376    0.010462    0.010106    0.721297    
#> 278: 0.468853    1.118279    3.506734    0.327163    0.010481    0.010093    0.721458    
#> 279: 0.468666    1.118320    3.506750    0.327746    0.010489    0.010076    0.721399    
#> 280: 0.469122    1.118483    3.506867    0.328461    0.010503    0.010048    0.721339    
#> 281: 0.468485    1.118556    3.506810    0.328622    0.010502    0.010027    0.721459    
#> 282: 0.468261    1.118733    3.506841    0.328398    0.010544    0.010009    0.721424    
#> 283: 0.468405    1.118792    3.506950    0.328602    0.010591    0.010003    0.721532    
#> 284: 0.468467    1.118671    3.506936    0.328357    0.010596    0.010018    0.721587    
#> 285: 0.467937    1.118787    3.506699    0.328493    0.010598    0.010048    0.721556    
#> 286: 0.467538    1.118806    3.506530    0.328444    0.010648    0.010045    0.721416    
#> 287: 0.467185    1.118888    3.506424    0.328028    0.010673    0.010028    0.721497    
#> 288: 0.467613    1.118824    3.506427    0.328709    0.010720    0.010007    0.721479    
#> 289: 0.468166    1.118571    3.506530    0.328877    0.010737    0.009989    0.721383    
#> 290: 0.468475    1.118450    3.506589    0.329050    0.010740    0.009950    0.721492    
#> 291: 0.468446    1.118591    3.506664    0.328769    0.010720    0.009960    0.721267    
#> 292: 0.468536    1.118667    3.506639    0.328538    0.010686    0.009980    0.721392    
#> 293: 0.468126    1.118765    3.506470    0.328109    0.010660    0.009987    0.721506    
#> 294: 0.467605    1.118883    3.506271    0.328448    0.010676    0.009995    0.721527    
#> 295: 0.467200    1.118772    3.506208    0.328020    0.010683    0.009999    0.721445    
#> 296: 0.467081    1.118719    3.506167    0.328359    0.010655    0.010013    0.721592    
#> 297: 0.467427    1.118649    3.506298    0.328525    0.010649    0.010038    0.721530    
#> 298: 0.467744    1.118491    3.506434    0.328230    0.010635    0.010047    0.721605    
#> 299: 0.467835    1.118516    3.506418    0.328296    0.010619    0.010039    0.721833    
#> 300: 0.467887    1.118533    3.506466    0.328698    0.010600    0.010011    0.721893    
#> 301: 0.468236    1.118319    3.506557    0.328749    0.010590    0.009995    0.722080    
#> 302: 0.468562    1.118328    3.506586    0.328721    0.010590    0.009961    0.722090    
#> 303: 0.468487    1.118441    3.506564    0.328481    0.010566    0.009952    0.721954    
#> 304: 0.468525    1.118575    3.506497    0.328268    0.010535    0.009968    0.721984    
#> 305: 0.468498    1.118417    3.506525    0.328115    0.010513    0.009972    0.721985    
#> 306: 0.468102    1.118360    3.506439    0.327725    0.010494    0.009972    0.722037    
#> 307: 0.467925    1.118317    3.506392    0.327383    0.010498    0.009948    0.722117    
#> 308: 0.467544    1.118230    3.506360    0.327349    0.010492    0.009932    0.722146    
#> 309: 0.467831    1.118162    3.506313    0.327867    0.010489    0.009914    0.722216    
#> 310: 0.468147    1.118093    3.506221    0.328516    0.010523    0.009905    0.722365    
#> 311: 0.468313    1.118110    3.506259    0.328794    0.010530    0.009877    0.722298    
#> 312: 0.467920    1.118010    3.506138    0.328264    0.010545    0.009851    0.722293    
#> 313: 0.467741    1.117886    3.506033    0.328515    0.010557    0.009819    0.722430    
#> 314: 0.467150    1.118093    3.505819    0.328402    0.010570    0.009799    0.722462    
#> 315: 0.466739    1.118173    3.505699    0.327980    0.010579    0.009773    0.722467    
#> 316: 0.466586    1.118241    3.505652    0.328121    0.010602    0.009751    0.722438    
#> 317: 0.466704    1.118168    3.505703    0.328031    0.010617    0.009730    0.722524    
#> 318: 0.466710    1.118249    3.505586    0.328447    0.010606    0.009722    0.722510    
#> 319: 0.466641    1.118258    3.505477    0.328267    0.010599    0.009714    0.722556    
#> 320: 0.465926    1.118298    3.505292    0.327894    0.010619    0.009717    0.722715    
#> 321: 0.465523    1.118420    3.505017    0.327765    0.010616    0.009719    0.722895    
#> 322: 0.465615    1.118510    3.504830    0.327896    0.010609    0.009722    0.722923    
#> 323: 0.465122    1.118563    3.504723    0.327786    0.010622    0.009731    0.722904    
#> 324: 0.465228    1.118655    3.504765    0.328082    0.010610    0.009733    0.722884    
#> 325: 0.465032    1.118781    3.504698    0.328168    0.010607    0.009736    0.722858    
#> 326: 0.465131    1.118630    3.504705    0.328143    0.010616    0.009726    0.722841    
#> 327: 0.465248    1.118604    3.504781    0.327952    0.010596    0.009739    0.722851    
#> 328: 0.465680    1.118648    3.504828    0.327790    0.010584    0.009734    0.722919    
#> 329: 0.465675    1.118569    3.504870    0.327577    0.010592    0.009721    0.722837    
#> 330: 0.465448    1.118614    3.504895    0.327316    0.010598    0.009729    0.722899    
#> 331: 0.465593    1.118647    3.504925    0.327408    0.010592    0.009728    0.722819    
#> 332: 0.465596    1.118630    3.504958    0.327349    0.010572    0.009735    0.722825    
#> 333: 0.465209    1.118655    3.504881    0.327117    0.010552    0.009756    0.722882    
#> 334: 0.464921    1.118624    3.504773    0.327084    0.010528    0.009771    0.722824    
#> 335: 0.464688    1.118575    3.504693    0.326901    0.010517    0.009772    0.722822    
#> 336: 0.464731    1.118551    3.504668    0.327178    0.010498    0.009778    0.722731    
#> 337: 0.464686    1.118608    3.504630    0.327132    0.010480    0.009794    0.722751    
#> 338: 0.464829    1.118602    3.504688    0.327073    0.010479    0.009800    0.722719    
#> 339: 0.464677    1.118656    3.504690    0.326777    0.010465    0.009810    0.722693    
#> 340: 0.464822    1.118588    3.504781    0.326792    0.010470    0.009806    0.722591    
#> 341: 0.465227    1.118480    3.504941    0.326727    0.010489    0.009812    0.722475    
#> 342: 0.465179    1.118315    3.505039    0.326437    0.010496    0.009810    0.722355    
#> 343: 0.464828    1.118302    3.505034    0.326026    0.010508    0.009811    0.722225    
#> 344: 0.464953    1.118297    3.505037    0.326134    0.010512    0.009803    0.722191    
#> 345: 0.464852    1.118322    3.505055    0.326008    0.010537    0.009802    0.722136    
#> 346: 0.464812    1.118347    3.505008    0.325935    0.010540    0.009797    0.722127    
#> 347: 0.464867    1.118318    3.504940    0.326142    0.010558    0.009817    0.722099    
#> 348: 0.464480    1.118306    3.504833    0.326148    0.010568    0.009820    0.722139    
#> 349: 0.464383    1.118333    3.504797    0.326075    0.010568    0.009835    0.722068    
#> 350: 0.464004    1.118297    3.504718    0.326069    0.010571    0.009841    0.722016    
#> 351: 0.464058    1.118460    3.504623    0.326166    0.010577    0.009833    0.721926    
#> 352: 0.463856    1.118520    3.504670    0.326002    0.010600    0.009825    0.722128    
#> 353: 0.463764    1.118672    3.504669    0.325599    0.010623    0.009823    0.722088    
#> 354: 0.463812    1.118756    3.504598    0.325240    0.010617    0.009835    0.722017    
#> 355: 0.464103    1.118699    3.504555    0.325542    0.010610    0.009841    0.721974    
#> 356: 0.464375    1.118650    3.504667    0.326119    0.010621    0.009847    0.721912    
#> 357: 0.464742    1.118661    3.504733    0.326451    0.010607    0.009858    0.721871    
#> 358: 0.464757    1.118757    3.504807    0.326835    0.010582    0.009874    0.721971    
#> 359: 0.464616    1.118901    3.504736    0.327018    0.010566    0.009888    0.721922    
#> 360: 0.464464    1.119029    3.504608    0.326859    0.010560    0.009891    0.721903    
#> 361: 0.464174    1.119125    3.504505    0.326785    0.010548    0.009902    0.721810    
#> 362: 0.464122    1.119112    3.504514    0.326616    0.010534    0.009907    0.721590    
#> 363: 0.463962    1.119025    3.504504    0.326318    0.010513    0.009901    0.721544    
#> 364: 0.463857    1.119053    3.504442    0.326118    0.010489    0.009906    0.721478    
#> 365: 0.463920    1.119029    3.504472    0.326232    0.010475    0.009923    0.721471    
#> 366: 0.463829    1.119013    3.504399    0.326164    0.010468    0.009944    0.721450    
#> 367: 0.464019    1.119040    3.504401    0.326247    0.010471    0.009938    0.721417    
#> 368: 0.464301    1.119016    3.504365    0.326984    0.010457    0.009929    0.721282    
#> 369: 0.464288    1.118978    3.504356    0.327334    0.010474    0.009915    0.721242    
#> 370: 0.464259    1.119042    3.504387    0.327283    0.010498    0.009925    0.721187    
#> 371: 0.464218    1.119062    3.504322    0.327288    0.010514    0.009914    0.721133    
#> 372: 0.464202    1.119065    3.504310    0.327324    0.010520    0.009931    0.721190    
#> 373: 0.464204    1.119073    3.504297    0.327545    0.010541    0.009930    0.721193    
#> 374: 0.464136    1.119041    3.504246    0.328004    0.010546    0.009920    0.721293    
#> 375: 0.463984    1.118969    3.504170    0.328190    0.010533    0.009921    0.721418    
#> 376: 0.463972    1.118982    3.504129    0.328056    0.010505    0.009927    0.721438    
#> 377: 0.463678    1.119029    3.504097    0.327891    0.010500    0.009920    0.721510    
#> 378: 0.463342    1.119093    3.503971    0.327729    0.010504    0.009912    0.721532    
#> 379: 0.463140    1.119128    3.503972    0.327646    0.010510    0.009902    0.721510    
#> 380: 0.462907    1.119163    3.503904    0.327666    0.010524    0.009893    0.721424    
#> 381: 0.462723    1.119137    3.503887    0.327813    0.010524    0.009873    0.721464    
#> 382: 0.462778    1.119101    3.503852    0.327997    0.010525    0.009862    0.721433    
#> 383: 0.462867    1.119085    3.503831    0.328188    0.010531    0.009863    0.721291    
#> 384: 0.462863    1.119089    3.503839    0.328009    0.010523    0.009863    0.721225    
#> 385: 0.462894    1.119112    3.503834    0.327829    0.010519    0.009886    0.721180    
#> 386: 0.462949    1.119208    3.503859    0.327807    0.010527    0.009906    0.721124    
#> 387: 0.463167    1.119147    3.503987    0.327510    0.010519    0.009920    0.721183    
#> 388: 0.463231    1.119080    3.504046    0.327354    0.010509    0.009935    0.721271    
#> 389: 0.463170    1.118865    3.504129    0.327354    0.010500    0.009936    0.721393    
#> 390: 0.462942    1.118818    3.504088    0.327317    0.010498    0.009931    0.721402    
#> 391: 0.462866    1.118774    3.504014    0.327087    0.010497    0.009945    0.721413    
#> 392: 0.462802    1.118753    3.504028    0.327234    0.010497    0.009943    0.721472    
#> 393: 0.462579    1.118722    3.503969    0.327188    0.010480    0.009954    0.721502    
#> 394: 0.462493    1.118691    3.503907    0.327588    0.010466    0.009977    0.721383    
#> 395: 0.462867    1.118725    3.503926    0.327954    0.010458    0.009991    0.721352    
#> 396: 0.463024    1.118802    3.503871    0.328432    0.010446    0.009995    0.721385    
#> 397: 0.463161    1.118712    3.503891    0.328498    0.010441    0.010002    0.721325    
#> 398: 0.463457    1.118621    3.503945    0.328351    0.010428    0.010010    0.721369    
#> 399: 0.463631    1.118565    3.504099    0.328174    0.010447    0.010029    0.721317    
#> 400: 0.463641    1.118639    3.504166    0.328182    0.010440    0.010030    0.721327    
#> 401: 0.463591    1.118767    3.504090    0.328084    0.010440    0.010039    0.721385    
#> 402: 0.463500    1.118863    3.504088    0.327918    0.010448    0.010055    0.721370    
#> 403: 0.463665    1.118895    3.504130    0.327488    0.010456    0.010071    0.721401    
#> 404: 0.463729    1.118932    3.504108    0.327299    0.010461    0.010069    0.721375    
#> 405: 0.463526    1.118909    3.504086    0.327313    0.010454    0.010073    0.721463    
#> 406: 0.463402    1.118933    3.504045    0.327445    0.010444    0.010079    0.721483    
#> 407: 0.463389    1.118922    3.504048    0.327567    0.010438    0.010080    0.721480    
#> 408: 0.463561    1.119005    3.504038    0.327584    0.010427    0.010074    0.721527    
#> 409: 0.463553    1.118980    3.503991    0.327556    0.010414    0.010070    0.721520    
#> 410: 0.463365    1.119037    3.503861    0.327644    0.010412    0.010067    0.721489    
#> 411: 0.463188    1.118927    3.503776    0.327555    0.010404    0.010069    0.721591    
#> 412: 0.463080    1.118909    3.503739    0.327542    0.010400    0.010066    0.721546    
#> 413: 0.463029    1.118917    3.503678    0.327628    0.010395    0.010070    0.721546    
#> 414: 0.462868    1.118934    3.503675    0.327777    0.010390    0.010074    0.721502    
#> 415: 0.462939    1.118904    3.503691    0.328083    0.010372    0.010086    0.721431    
#> 416: 0.463150    1.118933    3.503760    0.328326    0.010371    0.010086    0.721404    
#> 417: 0.463171    1.118937    3.503751    0.328795    0.010372    0.010092    0.721352    
#> 418: 0.463086    1.118903    3.503788    0.328882    0.010377    0.010090    0.721341    
#> 419: 0.463082    1.118945    3.503764    0.329089    0.010387    0.010087    0.721375    
#> 420: 0.463184    1.118989    3.503792    0.329141    0.010406    0.010075    0.721402    
#> 421: 0.463273    1.118994    3.503849    0.329367    0.010418    0.010065    0.721397    
#> 422: 0.463423    1.118972    3.503859    0.329184    0.010426    0.010060    0.721487    
#> 423: 0.463587    1.118918    3.503908    0.329099    0.010432    0.010047    0.721522    
#> 424: 0.463660    1.118882    3.503909    0.328985    0.010448    0.010040    0.721490    
#> 425: 0.463845    1.118899    3.503923    0.329581    0.010454    0.010046    0.721532    
#> 426: 0.463878    1.118909    3.503923    0.329794    0.010446    0.010043    0.721546    
#> 427: 0.463715    1.118883    3.503901    0.329756    0.010429    0.010042    0.721493    
#> 428: 0.463562    1.118938    3.503913    0.329748    0.010419    0.010034    0.721551    
#> 429: 0.463549    1.118910    3.503921    0.329885    0.010413    0.010026    0.721508    
#> 430: 0.463347    1.118933    3.503907    0.329768    0.010401    0.010023    0.721496    
#> 431: 0.463298    1.118939    3.503864    0.329826    0.010394    0.010011    0.721465    
#> 432: 0.463221    1.118979    3.503856    0.330038    0.010387    0.010020    0.721408    
#> 433: 0.463313    1.118987    3.503910    0.330064    0.010377    0.010030    0.721421    
#> 434: 0.463368    1.118947    3.503952    0.329812    0.010363    0.010041    0.721389    
#> 435: 0.463401    1.118918    3.503950    0.329742    0.010361    0.010045    0.721316    
#> 436: 0.463426    1.118872    3.503950    0.329736    0.010355    0.010050    0.721218    
#> 437: 0.463472    1.118863    3.503921    0.329388    0.010359    0.010037    0.721187    
#> 438: 0.463507    1.118946    3.503919    0.329281    0.010359    0.010026    0.721093    
#> 439: 0.463551    1.118975    3.503922    0.329104    0.010366    0.010017    0.721023    
#> 440: 0.463391    1.119002    3.503905    0.329185    0.010378    0.010010    0.720970    
#> 441: 0.463293    1.119007    3.503910    0.329205    0.010387    0.010004    0.720921    
#> 442: 0.463165    1.119040    3.503917    0.328875    0.010397    0.009991    0.720887    
#> 443: 0.463075    1.119094    3.503894    0.328781    0.010389    0.009986    0.720916    
#> 444: 0.463027    1.119063    3.503852    0.328950    0.010389    0.009980    0.720934    
#> 445: 0.463017    1.119040    3.503817    0.328973    0.010422    0.009965    0.720975    
#> 446: 0.462894    1.119012    3.503777    0.328947    0.010461    0.009953    0.721028    
#> 447: 0.463104    1.119019    3.503778    0.329101    0.010479    0.009959    0.721061    
#> 448: 0.463036    1.119017    3.503790    0.329168    0.010478    0.009969    0.721030    
#> 449: 0.463065    1.119073    3.503865    0.329100    0.010473    0.009971    0.721034    
#> 450: 0.463138    1.119096    3.503884    0.329300    0.010468    0.009984    0.720994    
#> 451: 0.463342    1.119133    3.503877    0.329488    0.010458    0.009986    0.721022    
#> 452: 0.463318    1.119195    3.503810    0.329554    0.010447    0.009991    0.721043    
#> 453: 0.463249    1.119262    3.503759    0.329489    0.010443    0.009982    0.721051    
#> 454: 0.463299    1.119359    3.503729    0.329640    0.010441    0.009980    0.720980    
#> 455: 0.463337    1.119457    3.503710    0.329842    0.010443    0.009975    0.720946    
#> 456: 0.463314    1.119490    3.503680    0.329744    0.010445    0.009976    0.720955    
#> 457: 0.463311    1.119488    3.503739    0.329631    0.010446    0.009968    0.720905    
#> 458: 0.463412    1.119539    3.503841    0.329544    0.010448    0.009971    0.720960    
#> 459: 0.463371    1.119574    3.503863    0.329632    0.010440    0.009969    0.720979    
#> 460: 0.463319    1.119581    3.503811    0.329526    0.010427    0.009978    0.720982    
#> 461: 0.463173    1.119613    3.503791    0.329493    0.010418    0.009987    0.720991    
#> 462: 0.462996    1.119669    3.503769    0.329523    0.010408    0.009994    0.720996    
#> 463: 0.463010    1.119711    3.503796    0.329393    0.010408    0.009999    0.720965    
#> 464: 0.462993    1.119749    3.503772    0.329403    0.010395    0.010003    0.720928    
#> 465: 0.463017    1.119676    3.503744    0.329363    0.010383    0.010006    0.720927    
#> 466: 0.463237    1.119646    3.503748    0.329446    0.010368    0.010001    0.720917    
#> 467: 0.463162    1.119664    3.503745    0.329375    0.010365    0.010010    0.720885    
#> 468: 0.463299    1.119643    3.503797    0.329609    0.010361    0.010023    0.720944    
#> 469: 0.463394    1.119661    3.503867    0.329590    0.010347    0.010032    0.721020    
#> 470: 0.463468    1.119657    3.503887    0.329589    0.010333    0.010046    0.721018    
#> 471: 0.463492    1.119601    3.503906    0.329482    0.010327    0.010049    0.721039    
#> 472: 0.463479    1.119531    3.503938    0.329401    0.010323    0.010044    0.721122    
#> 473: 0.463454    1.119519    3.503960    0.329408    0.010313    0.010050    0.721174    
#> 474: 0.463568    1.119468    3.504007    0.329422    0.010308    0.010057    0.721238    
#> 475: 0.463643    1.119501    3.504039    0.329295    0.010299    0.010065    0.721230    
#> 476: 0.463674    1.119469    3.504009    0.329134    0.010294    0.010066    0.721282    
#> 477: 0.463671    1.119504    3.504016    0.328941    0.010281    0.010069    0.721271    
#> 478: 0.463638    1.119447    3.504013    0.328791    0.010263    0.010065    0.721312    
#> 479: 0.463672    1.119423    3.504049    0.328654    0.010250    0.010071    0.721332    
#> 480: 0.463737    1.119441    3.504064    0.328831    0.010251    0.010076    0.721329    
#> 481: 0.463787    1.119429    3.504061    0.328878    0.010248    0.010077    0.721313    
#> 482: 0.463854    1.119397    3.504033    0.328950    0.010245    0.010075    0.721341    
#> 483: 0.463747    1.119370    3.503999    0.328940    0.010250    0.010072    0.721355    
#> 484: 0.463741    1.119285    3.503990    0.328979    0.010253    0.010070    0.721377    
#> 485: 0.463847    1.119325    3.503996    0.329063    0.010251    0.010062    0.721344    
#> 486: 0.463849    1.119306    3.503986    0.329173    0.010247    0.010054    0.721289    
#> 487: 0.464030    1.119316    3.504030    0.329204    0.010243    0.010049    0.721256    
#> 488: 0.464079    1.119226    3.504077    0.329119    0.010241    0.010051    0.721246    
#> 489: 0.464205    1.119159    3.504084    0.329130    0.010237    0.010051    0.721279    
#> 490: 0.464201    1.119194    3.504073    0.329302    0.010237    0.010049    0.721299    
#> 491: 0.464154    1.119255    3.504073    0.329294    0.010234    0.010050    0.721295    
#> 492: 0.464158    1.119305    3.504065    0.329209    0.010235    0.010054    0.721344    
#> 493: 0.464093    1.119342    3.504050    0.329183    0.010244    0.010061    0.721381    
#> 494: 0.464160    1.119414    3.504041    0.329033    0.010259    0.010064    0.721372    
#> 495: 0.464179    1.119488    3.504029    0.328966    0.010261    0.010062    0.721341    
#> 496: 0.464311    1.119578    3.503998    0.329054    0.010257    0.010065    0.721383    
#> 497: 0.464227    1.119591    3.503988    0.329139    0.010262    0.010067    0.721347    
#> 498: 0.464270    1.119609    3.503975    0.328910    0.010271    0.010059    0.721377    
#> 499: 0.464285    1.119622    3.503979    0.328855    0.010283    0.010051    0.721346    
#> 500: 0.464295    1.119593    3.503987    0.328839    0.010287    0.010041    0.721281    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.347908    0.973071    3.457338    0.392401    0.085541    0.016800    1.771155    
#> 002: 0.541893    1.038304    3.480720    0.372781    0.081264    0.016327    1.191424    
#> 003: 0.683276    1.013727    3.490874    0.546927    0.077201    0.015510    0.869386    
#> 004: 0.734690    1.045179    3.494358    0.732930    0.073341    0.014735    0.766713    
#> 005: 0.826934    1.031712    3.485750    0.793465    0.069674    0.013998    0.692958    
#> 006: 0.845034    1.036700    3.486607    0.872512    0.066190    0.013298    0.654492    
#> 007: 0.826274    1.047006    3.470941    0.968630    0.062881    0.012633    0.624666    
#> 008: 0.806984    1.024001    3.470811    0.951017    0.059737    0.012002    0.627380    
#> 009: 0.751904    1.016055    3.460029    0.926251    0.056750    0.011402    0.637633    
#> 010: 0.809847    1.027974    3.460681    1.029248    0.053912    0.010831    0.616032    
#> 011: 0.894732    1.036915    3.469854    1.116640    0.055190    0.010290    0.606573    
#> 012: 0.837469    1.028199    3.468108    1.060808    0.052431    0.009775    0.606588    
#> 013: 0.841181    1.045557    3.469196    1.061353    0.049809    0.009287    0.615175    
#> 014: 0.924144    1.035649    3.471451    1.257614    0.047319    0.008822    0.628135    
#> 015: 0.932812    1.024110    3.487032    1.194734    0.044953    0.008381    0.619936    
#> 016: 0.889917    1.013193    3.483497    1.134997    0.042705    0.007962    0.609440    
#> 017: 0.875392    1.024190    3.481009    1.132758    0.042829    0.007712    0.586097    
#> 018: 0.928712    1.035890    3.471899    1.331336    0.048254    0.008262    0.577524    
#> 019: 0.820409    1.034802    3.465741    1.264769    0.045842    0.007849    0.573266    
#> 020: 0.892186    1.033928    3.471726    1.214936    0.043549    0.007456    0.583582    
#> 021: 0.885848    1.021949    3.467759    1.231145    0.041844    0.007780    0.586085    
#> 022: 0.911586    1.017814    3.475275    1.376871    0.039752    0.007391    0.581594    
#> 023: 1.073026    1.035587    3.480640    1.771092    0.037764    0.008020    0.594377    
#> 024: 1.083077    1.062048    3.470513    1.854443    0.037755    0.007619    0.579774    
#> 025: 1.073645    1.044532    3.468115    1.864798    0.041606    0.007238    0.585235    
#> 026: 0.967701    1.052395    3.463572    1.771558    0.046597    0.006876    0.596421    
#> 027: 0.898463    1.059183    3.466280    1.682980    0.045367    0.007778    0.584412    
#> 028: 0.962916    1.058542    3.460426    1.614640    0.043098    0.007389    0.590631    
#> 029: 0.981359    1.054759    3.454163    1.553578    0.049256    0.007235    0.580847    
#> 030: 1.000856    1.061743    3.457603    1.658688    0.046794    0.007146    0.586070    
#> 031: 0.980976    1.040203    3.469239    1.683384    0.047291    0.006788    0.583546    
#> 032: 0.981429    1.043984    3.467121    1.742403    0.050824    0.007865    0.579502    
#> 033: 0.983672    1.061559    3.459789    1.655283    0.048283    0.007746    0.574731    
#> 034: 0.990301    1.051315    3.463426    1.572518    0.045868    0.008024    0.591481    
#> 035: 0.901261    1.036539    3.461457    1.493892    0.043575    0.008357    0.589081    
#> 036: 0.926127    1.036891    3.464717    1.419198    0.055570    0.008716    0.607635    
#> 037: 0.903140    1.036036    3.472763    1.348238    0.052792    0.008280    0.611285    
#> 038: 0.940461    1.030884    3.466495    1.345201    0.055056    0.007866    0.605668    
#> 039: 0.972272    1.043804    3.474351    1.396912    0.052304    0.007473    0.597904    
#> 040: 0.991632    1.051654    3.474003    1.484664    0.049688    0.007099    0.604767    
#> 041: 0.982651    1.038959    3.471432    1.500403    0.047204    0.006744    0.582959    
#> 042: 0.958803    1.029321    3.462654    1.600053    0.046775    0.006407    0.577822    
#> 043: 1.000655    1.051105    3.454846    1.670918    0.044436    0.006376    0.585798    
#> 044: 0.884568    1.063202    3.458481    1.587372    0.044936    0.006057    0.592286    
#> 045: 0.895823    1.062061    3.458484    1.508003    0.044746    0.005754    0.578507    
#> 046: 0.947919    1.034056    3.465631    1.432603    0.042745    0.005466    0.575592    
#> 047: 0.957701    1.046697    3.469057    1.360973    0.040607    0.005929    0.594377    
#> 048: 0.833215    1.026869    3.468338    1.292924    0.045561    0.005750    0.595556    
#> 049: 0.872508    1.039311    3.476405    1.228278    0.046148    0.005986    0.597582    
#> 050: 0.970937    1.031167    3.477479    1.474585    0.052465    0.005687    0.608706    
#> 051: 0.922896    1.029109    3.481118    1.400856    0.050700    0.005402    0.625320    
#> 052: 0.906026    1.038029    3.473903    1.330813    0.051155    0.005132    0.601495    
#> 053: 0.894764    1.032655    3.476013    1.264272    0.048598    0.004876    0.599704    
#> 054: 0.866975    1.021040    3.478965    1.201059    0.052243    0.004632    0.624269    
#> 055: 0.899879    1.021099    3.479295    1.199680    0.049631    0.004655    0.608545    
#> 056: 0.925603    1.021029    3.481747    1.244159    0.050039    0.004422    0.620065    
#> 057: 0.874796    1.017240    3.481325    1.181951    0.051960    0.004357    0.618787    
#> 058: 0.922310    1.014023    3.479011    1.257282    0.053870    0.004722    0.612704    
#> 059: 0.961899    0.991530    3.478840    1.433246    0.060751    0.006099    0.613354    
#> 060: 0.901906    1.005580    3.477721    1.361583    0.057714    0.005794    0.628505    
#> 061: 0.989725    1.025002    3.481564    1.452253    0.061556    0.005504    0.619660    
#> 062: 0.994384    1.023709    3.478145    1.546267    0.077426    0.005229    0.628700    
#> 063: 0.998653    1.004159    3.472106    1.547794    0.073555    0.005058    0.633114    
#> 064: 1.019034    1.027280    3.476016    1.569212    0.069877    0.004805    0.612073    
#> 065: 0.932360    1.017238    3.467205    1.490751    0.066383    0.004565    0.618494    
#> 066: 0.978182    1.043137    3.472246    1.715512    0.063064    0.005658    0.598909    
#> 067: 0.920473    1.016038    3.468858    1.629737    0.059911    0.007393    0.603678    
#> 068: 0.894672    1.037860    3.480168    1.548250    0.063088    0.007063    0.611931    
#> 069: 1.020840    1.044170    3.466262    1.727444    0.059933    0.006710    0.609079    
#> 070: 0.990475    1.033549    3.474029    1.728784    0.056936    0.006577    0.615828    
#> 071: 1.023200    1.050039    3.455602    1.651686    0.054547    0.006743    0.617831    
#> 072: 0.875163    1.010590    3.461021    1.569101    0.053332    0.006664    0.593561    
#> 073: 0.922279    1.036246    3.468961    1.490646    0.050666    0.006551    0.591966    
#> 074: 0.912457    1.024084    3.467289    1.431921    0.048132    0.006628    0.589004    
#> 075: 0.897867    1.027402    3.479830    1.373561    0.054816    0.006409    0.593445    
#> 076: 0.954238    1.048691    3.480367    1.408181    0.052075    0.007153    0.611488    
#> 077: 0.920957    1.035328    3.468303    1.337772    0.049471    0.009162    0.595557    
#> 078: 0.921313    1.035438    3.468841    1.297572    0.046998    0.008703    0.587274    
#> 079: 0.934072    1.046474    3.465782    1.380971    0.047380    0.009022    0.605602    
#> 080: 0.921407    1.045289    3.457631    1.475333    0.051018    0.008691    0.615701    
#> 081: 0.948543    1.047175    3.460158    1.473573    0.048467    0.010860    0.613692    
#> 082: 0.962823    1.029649    3.472299    1.501410    0.046044    0.010967    0.606997    
#> 083: 0.875849    1.046356    3.470626    1.426339    0.043742    0.011656    0.605221    
#> 084: 1.011638    1.026513    3.480682    1.579263    0.042899    0.011073    0.596606    
#> 085: 0.900554    1.029103    3.481512    1.500300    0.040754    0.010520    0.594007    
#> 086: 0.929612    1.015091    3.477915    1.425285    0.042252    0.009994    0.603738    
#> 087: 0.913352    1.022787    3.474938    1.354021    0.040139    0.009494    0.590881    
#> 088: 0.903215    1.016375    3.472929    1.286320    0.038132    0.009019    0.586687    
#> 089: 0.968266    1.038429    3.472048    1.465905    0.045353    0.008971    0.591151    
#> 090: 1.013004    1.036019    3.477771    1.597838    0.044513    0.008638    0.599924    
#> 091: 0.919603    1.024141    3.460601    1.517946    0.042287    0.008206    0.607841    
#> 092: 0.995537    1.035163    3.459935    1.605138    0.040173    0.010106    0.601279    
#> 093: 0.901669    1.027931    3.457117    1.524881    0.038164    0.009753    0.613089    
#> 094: 0.879987    1.044728    3.458124    1.448637    0.041417    0.009266    0.604413    
#> 095: 0.830616    1.051596    3.461062    1.376205    0.039681    0.008802    0.589338    
#> 096: 0.826005    1.058971    3.458034    1.307395    0.037697    0.008362    0.592988    
#> 097: 0.904261    1.067819    3.455119    1.393039    0.035812    0.007944    0.586671    
#> 098: 0.945926    1.074961    3.462313    1.419032    0.040476    0.007547    0.596780    
#> 099: 0.931937    1.047870    3.451285    1.348890    0.044273    0.007170    0.595722    
#> 100: 0.856628    1.056930    3.458791    1.281446    0.047417    0.006811    0.578891    
#> 101: 0.838122    1.039200    3.447382    1.217374    0.046784    0.006471    0.584708    
#> 102: 0.786975    1.046731    3.439482    1.156505    0.044445    0.006147    0.603507    
#> 103: 0.851565    1.048102    3.456734    1.139402    0.042222    0.006481    0.583168    
#> 104: 0.873518    1.030135    3.468270    1.278725    0.040111    0.006844    0.593847    
#> 105: 0.979366    1.028161    3.460493    1.644118    0.044812    0.006501    0.606782    
#> 106: 0.988650    1.044502    3.454904    1.670990    0.042571    0.006176    0.591720    
#> 107: 1.048723    1.048134    3.458371    2.039580    0.044341    0.005868    0.597596    
#> 108: 0.909691    1.048037    3.454239    1.937601    0.045490    0.006032    0.606828    
#> 109: 0.892288    1.060058    3.461439    1.840721    0.045838    0.005730    0.592259    
#> 110: 0.981164    1.035457    3.452898    1.748685    0.043546    0.005443    0.602832    
#> 111: 0.890357    1.043747    3.456666    1.661251    0.042441    0.005597    0.584191    
#> 112: 0.875524    1.017888    3.457010    1.578188    0.045406    0.005317    0.607147    
#> 113: 0.934013    1.063174    3.460315    1.499279    0.043136    0.005051    0.596909    
#> 114: 0.950376    1.059018    3.462145    1.454700    0.040979    0.004925    0.596541    
#> 115: 1.031302    1.032527    3.464831    1.768579    0.038930    0.006174    0.607820    
#> 116: 1.076230    1.046340    3.475508    1.725283    0.038793    0.006996    0.608524    
#> 117: 0.968675    1.067105    3.469384    1.639019    0.042565    0.007043    0.610407    
#> 118: 0.945081    1.053863    3.471148    1.557068    0.040436    0.006691    0.599745    
#> 119: 0.909997    1.062338    3.460860    1.479214    0.049219    0.006356    0.589034    
#> 120: 0.877332    1.036279    3.461144    1.405254    0.046758    0.006126    0.590452    
#> 121: 0.890025    1.060669    3.460578    1.334991    0.048396    0.006013    0.582432    
#> 122: 0.847450    1.058704    3.458006    1.268241    0.046630    0.006954    0.579753    
#> 123: 0.904224    1.074207    3.459610    1.369503    0.044299    0.007682    0.581816    
#> 124: 0.895907    1.094170    3.449852    1.463739    0.042084    0.007298    0.605898    
#> 125: 0.903979    1.084077    3.444381    1.443156    0.043816    0.007414    0.595594    
#> 126: 0.853518    1.090301    3.434598    1.370998    0.041625    0.007309    0.614763    
#> 127: 0.905781    1.064571    3.446309    1.377170    0.039543    0.009097    0.616323    
#> 128: 0.914297    1.058903    3.459621    1.409240    0.037566    0.009763    0.595067    
#> 129: 0.958696    1.047415    3.465589    1.469212    0.042836    0.011985    0.585965    
#> 130: 0.985697    1.054696    3.462580    1.528995    0.040694    0.011386    0.589584    
#> 131: 0.886588    1.042157    3.449820    1.452545    0.054668    0.010816    0.581443    
#> 132: 0.870853    1.040758    3.447433    1.379918    0.051934    0.010276    0.580668    
#> 133: 0.937329    1.034039    3.452773    1.587652    0.052395    0.009762    0.585301    
#> 134: 0.945067    1.022629    3.466921    1.649354    0.052011    0.009274    0.586683    
#> 135: 0.941844    1.035858    3.465016    1.587299    0.049411    0.009686    0.602500    
#> 136: 0.940299    1.046618    3.457197    1.507934    0.050830    0.009201    0.602323    
#> 137: 1.039733    1.024336    3.461177    1.734470    0.048289    0.008741    0.592724    
#> 138: 0.926634    1.021748    3.463948    1.647746    0.045874    0.008304    0.599510    
#> 139: 0.921813    1.038817    3.464750    1.565359    0.045518    0.007974    0.589994    
#> 140: 0.976131    1.044520    3.463985    1.669871    0.048768    0.007701    0.602086    
#> 141: 0.954637    1.019958    3.463792    1.586378    0.046329    0.007316    0.609230    
#> 142: 0.967493    1.015413    3.472654    1.591693    0.051820    0.007063    0.597276    
#> 143: 0.911127    1.028362    3.471111    1.512109    0.053516    0.006710    0.589889    
#> 144: 0.960712    1.037288    3.473351    1.540994    0.050840    0.006374    0.595223    
#> 145: 0.927974    1.041484    3.466454    1.463944    0.048298    0.006056    0.588673    
#> 146: 0.933801    1.029588    3.479716    1.390747    0.046301    0.006824    0.589912    
#> 147: 0.877559    1.020555    3.472908    1.321209    0.045669    0.006745    0.579818    
#> 148: 0.867257    1.024854    3.482536    1.255149    0.043385    0.006408    0.581797    
#> 149: 0.835073    1.010469    3.484449    1.192392    0.041216    0.007943    0.587535    
#> 150: 0.880579    1.022349    3.472915    1.132772    0.040398    0.007546    0.594054    
#> 151: 0.826182    1.054197    3.470135    1.076133    0.042293    0.007169    0.593872    
#> 152: 0.859460    1.045169    3.472108    1.159952    0.039715    0.005534    0.586616    
#> 153: 0.839848    1.064632    3.475052    1.077376    0.041895    0.006465    0.575229    
#> 154: 0.882738    1.051298    3.476950    1.120434    0.039579    0.008277    0.577505    
#> 155: 0.853960    1.026268    3.471800    1.117316    0.038201    0.008131    0.583372    
#> 156: 0.910061    1.019386    3.481769    1.209730    0.045616    0.008598    0.598345    
#> 157: 0.968042    1.019749    3.494071    1.328774    0.041541    0.008989    0.602324    
#> 158: 0.975788    1.031813    3.487092    1.293856    0.037587    0.007979    0.593569    
#> 159: 0.856501    1.038892    3.492731    1.061956    0.039345    0.008295    0.586431    
#> 160: 0.977198    1.013772    3.497572    1.268487    0.047914    0.008005    0.582130    
#> 161: 0.942941    1.019515    3.489612    1.154744    0.039873    0.009650    0.597170    
#> 162: 0.882477    1.047514    3.466570    1.251936    0.040180    0.009551    0.590920    
#> 163: 0.934518    1.041864    3.456720    1.458219    0.050782    0.009339    0.585726    
#> 164: 0.943281    1.046442    3.458309    1.428365    0.046002    0.007755    0.580787    
#> 165: 0.925586    1.036771    3.464140    1.548010    0.044563    0.008255    0.582637    
#> 166: 0.906303    1.070604    3.465653    1.259900    0.043939    0.008378    0.591629    
#> 167: 0.995863    1.066469    3.469339    1.543003    0.041977    0.009464    0.596150    
#> 168: 0.988901    1.062837    3.473669    1.537745    0.038478    0.009808    0.582292    
#> 169: 1.001405    1.068018    3.463517    1.527468    0.041573    0.007162    0.593321    
#> 170: 0.997350    1.040884    3.467966    1.599324    0.039763    0.008617    0.594950    
#> 171: 0.979068    1.037317    3.464975    1.513300    0.043665    0.008778    0.570136    
#> 172: 0.903044    1.057777    3.459883    1.371657    0.042912    0.009385    0.573459    
#> 173: 0.936271    1.070173    3.457712    1.345135    0.042550    0.008107    0.589423    
#> 174: 0.904455    1.065623    3.461742    1.166594    0.032742    0.007660    0.592445    
#> 175: 0.871896    1.054851    3.457725    1.153721    0.035802    0.007918    0.592165    
#> 176: 0.906484    1.062264    3.460511    1.245879    0.031521    0.007603    0.599757    
#> 177: 0.876969    1.059823    3.469079    1.119086    0.037125    0.008731    0.600562    
#> 178: 0.931513    1.054103    3.465416    1.250171    0.038831    0.009816    0.586383    
#> 179: 0.878113    1.060845    3.461221    1.082256    0.043654    0.011170    0.590776    
#> 180: 0.881562    1.054899    3.460686    1.098449    0.037339    0.010724    0.578334    
#> 181: 0.838681    1.041238    3.450558    1.097168    0.034645    0.010773    0.580127    
#> 182: 0.822980    1.051988    3.445967    1.074255    0.035097    0.011119    0.603011    
#> 183: 0.879400    1.072714    3.448800    1.187434    0.032077    0.008549    0.586613    
#> 184: 0.842719    1.038551    3.460223    1.105271    0.028343    0.008755    0.579095    
#> 185: 0.812150    1.050914    3.455011    1.125258    0.030861    0.008588    0.608661    
#> 186: 0.792162    1.057948    3.452451    0.932736    0.037951    0.010537    0.602598    
#> 187: 0.845251    1.048059    3.473471    1.144557    0.031571    0.009507    0.583001    
#> 188: 0.865555    1.065394    3.472288    1.144057    0.031341    0.008626    0.592177    
#> 189: 0.897891    1.063846    3.475895    1.187602    0.030082    0.008645    0.604719    
#> 190: 0.892119    1.039489    3.474955    1.349537    0.031234    0.007732    0.596511    
#> 191: 0.857279    1.054144    3.467574    1.118572    0.037263    0.006665    0.588526    
#> 192: 0.879949    1.050645    3.463462    1.167302    0.033703    0.006017    0.589452    
#> 193: 0.979838    1.056283    3.464583    1.401694    0.040364    0.005633    0.584843    
#> 194: 0.911320    1.057371    3.455901    1.317807    0.051407    0.004381    0.598551    
#> 195: 0.873842    1.050198    3.456659    1.249636    0.038725    0.003466    0.610150    
#> 196: 0.873876    1.045178    3.466831    1.117657    0.048666    0.003211    0.604060    
#> 197: 0.829341    1.043162    3.476595    1.042196    0.043928    0.004108    0.611797    
#> 198: 0.851045    1.044623    3.466998    1.055556    0.039004    0.004201    0.609805    
#> 199: 0.841531    1.035631    3.470765    1.129946    0.050188    0.003434    0.604455    
#> 200: 0.916398    1.035576    3.476087    1.231722    0.047004    0.003909    0.614888    
#> 201: 0.903611    1.030223    3.479659    1.228945    0.045804    0.004516    0.607163    
#> 202: 0.900550    1.028277    3.477755    1.236264    0.045482    0.004642    0.608223    
#> 203: 0.915790    1.029575    3.475814    1.281736    0.043928    0.004746    0.609411    
#> 204: 0.937454    1.025760    3.476371    1.348940    0.043302    0.004723    0.613541    
#> 205: 0.949112    1.027222    3.477147    1.387435    0.042918    0.005001    0.612306    
#> 206: 0.951187    1.028890    3.478066    1.382362    0.043249    0.005139    0.612746    
#> 207: 0.960374    1.028703    3.477491    1.403991    0.043214    0.005289    0.610407    
#> 208: 0.969037    1.030460    3.477202    1.437530    0.043389    0.005337    0.607679    
#> 209: 0.974555    1.028843    3.476680    1.468646    0.043623    0.005493    0.606361    
#> 210: 0.971817    1.028570    3.475787    1.467798    0.043282    0.005565    0.606123    
#> 211: 0.967885    1.030153    3.475312    1.450783    0.042934    0.005620    0.605088    
#> 212: 0.964191    1.031066    3.475141    1.434207    0.042722    0.005608    0.604621    
#> 213: 0.967246    1.029845    3.474790    1.438587    0.042735    0.005619    0.605429    
#> 214: 0.972879    1.029551    3.474761    1.448283    0.043090    0.005608    0.605816    
#> 215: 0.973417    1.030045    3.475011    1.446181    0.042625    0.005694    0.605688    
#> 216: 0.974200    1.028684    3.475422    1.442295    0.042543    0.005723    0.605850    
#> 217: 0.970294    1.029405    3.475722    1.430242    0.042328    0.005746    0.605850    
#> 218: 0.969261    1.030099    3.475346    1.428815    0.042123    0.005806    0.605761    
#> 219: 0.966450    1.030180    3.474356    1.426900    0.041848    0.005968    0.605539    
#> 220: 0.968181    1.030467    3.473828    1.445782    0.041462    0.006100    0.605282    
#> 221: 0.968925    1.031096    3.473579    1.450850    0.041225    0.006160    0.604298    
#> 222: 0.969560    1.030900    3.473379    1.453276    0.041281    0.006280    0.603183    
#> 223: 0.971428    1.031143    3.473449    1.460826    0.041213    0.006388    0.602116    
#> 224: 0.972877    1.031161    3.473781    1.467992    0.041206    0.006440    0.601701    
#> 225: 0.970728    1.030136    3.473816    1.462574    0.040874    0.006511    0.601467    
#> 226: 0.967260    1.028898    3.473709    1.449825    0.040955    0.006534    0.601654    
#> 227: 0.963084    1.028840    3.473686    1.436639    0.041021    0.006513    0.601778    
#> 228: 0.961441    1.029302    3.473514    1.431612    0.041231    0.006516    0.601937    
#> 229: 0.960772    1.029075    3.473511    1.426896    0.041159    0.006534    0.601511    
#> 230: 0.959011    1.028812    3.473443    1.420785    0.041070    0.006553    0.601360    
#> 231: 0.960179    1.029558    3.473734    1.420734    0.041121    0.006581    0.600965    
#> 232: 0.957704    1.029745    3.474180    1.410428    0.041005    0.006623    0.601247    
#> 233: 0.955009    1.029403    3.474615    1.401704    0.040599    0.006686    0.601776    
#> 234: 0.954085    1.029193    3.474850    1.396581    0.040397    0.006703    0.601737    
#> 235: 0.952751    1.028685    3.474774    1.388369    0.040078    0.006715    0.601571    
#> 236: 0.952356    1.029120    3.474627    1.383946    0.039935    0.006763    0.601220    
#> 237: 0.951910    1.029646    3.474489    1.382123    0.040008    0.006839    0.601266    
#> 238: 0.950659    1.029899    3.474378    1.377346    0.040093    0.006905    0.601486    
#> 239: 0.948987    1.030574    3.474240    1.371345    0.040151    0.006897    0.601781    
#> 240: 0.947850    1.030765    3.474231    1.367992    0.040291    0.006899    0.601526    
#> 241: 0.946024    1.030590    3.474224    1.362245    0.040287    0.006905    0.601363    
#> 242: 0.945129    1.030432    3.474118    1.359207    0.040166    0.006958    0.601432    
#> 243: 0.943369    1.030902    3.474098    1.352077    0.040163    0.007005    0.601517    
#> 244: 0.942472    1.030845    3.474131    1.349848    0.040219    0.007023    0.601424    
#> 245: 0.942585    1.030494    3.474113    1.347224    0.040295    0.007068    0.601584    
#> 246: 0.942425    1.030630    3.474152    1.346685    0.040339    0.007136    0.601927    
#> 247: 0.941769    1.030449    3.474290    1.343255    0.040366    0.007200    0.602052    
#> 248: 0.941452    1.030569    3.474340    1.339764    0.040334    0.007209    0.601662    
#> 249: 0.941169    1.030839    3.474593    1.340502    0.040267    0.007222    0.601759    
#> 250: 0.941966    1.031149    3.474716    1.341771    0.040302    0.007261    0.601705    
#> 251: 0.941881    1.031590    3.474815    1.340498    0.040301    0.007277    0.601841    
#> 252: 0.941564    1.032023    3.474886    1.338597    0.040500    0.007266    0.601773    
#> 253: 0.942350    1.032066    3.474807    1.344986    0.040546    0.007256    0.601636    
#> 254: 0.942771    1.032420    3.474740    1.350495    0.040646    0.007241    0.601475    
#> 255: 0.943878    1.032723    3.474792    1.356072    0.040635    0.007251    0.601553    
#> 256: 0.944157    1.032544    3.474798    1.356221    0.040495    0.007275    0.601467    
#> 257: 0.943786    1.032340    3.474794    1.351842    0.040483    0.007265    0.601644    
#> 258: 0.942937    1.031873    3.474788    1.348541    0.040385    0.007240    0.601716    
#> 259: 0.941857    1.031736    3.474713    1.346082    0.040427    0.007218    0.601441    
#> 260: 0.941716    1.031753    3.474754    1.346732    0.040477    0.007212    0.600970    
#> 261: 0.941761    1.031594    3.474716    1.347320    0.040509    0.007206    0.600647    
#> 262: 0.939990    1.031682    3.474774    1.341570    0.040571    0.007188    0.600485    
#> 263: 0.939314    1.031933    3.474762    1.338669    0.040575    0.007185    0.600435    
#> 264: 0.939160    1.031995    3.474739    1.339526    0.040433    0.007177    0.600645    
#> 265: 0.938018    1.032215    3.474648    1.337902    0.040315    0.007151    0.601051    
#> 266: 0.937737    1.032419    3.474642    1.338284    0.040233    0.007122    0.601248    
#> 267: 0.938032    1.032510    3.474773    1.339772    0.040178    0.007117    0.601547    
#> 268: 0.938837    1.032249    3.474822    1.340116    0.040195    0.007132    0.601535    
#> 269: 0.939627    1.032000    3.474938    1.339763    0.040274    0.007138    0.601482    
#> 270: 0.940129    1.032038    3.474864    1.339446    0.040251    0.007156    0.601248    
#> 271: 0.941016    1.032149    3.474824    1.340380    0.040222    0.007149    0.601303    
#> 272: 0.940984    1.031990    3.474677    1.339791    0.040193    0.007132    0.601344    
#> 273: 0.940543    1.032315    3.474554    1.340543    0.040278    0.007129    0.601586    
#> 274: 0.939457    1.032828    3.474473    1.337901    0.040203    0.007115    0.601739    
#> 275: 0.938569    1.033069    3.474287    1.335644    0.040167    0.007108    0.601880    
#> 276: 0.937540    1.033081    3.474381    1.332047    0.040069    0.007121    0.601859    
#> 277: 0.936785    1.033231    3.474528    1.329778    0.039998    0.007131    0.602024    
#> 278: 0.936426    1.033218    3.474638    1.328964    0.039941    0.007138    0.602048    
#> 279: 0.935952    1.033153    3.474632    1.328188    0.040023    0.007148    0.602223    
#> 280: 0.935000    1.033408    3.474588    1.325357    0.040131    0.007137    0.602166    
#> 281: 0.933777    1.033398    3.474638    1.320222    0.040154    0.007118    0.602367    
#> 282: 0.933608    1.033393    3.474684    1.319105    0.040275    0.007126    0.602278    
#> 283: 0.933849    1.033446    3.474803    1.318805    0.040354    0.007136    0.602277    
#> 284: 0.934341    1.033298    3.474825    1.319588    0.040370    0.007169    0.602034    
#> 285: 0.934831    1.033283    3.474761    1.321932    0.040446    0.007200    0.601798    
#> 286: 0.935800    1.033668    3.474624    1.326945    0.040573    0.007223    0.601594    
#> 287: 0.936212    1.033870    3.474532    1.329879    0.040659    0.007246    0.601441    
#> 288: 0.936638    1.033938    3.474522    1.332733    0.040696    0.007237    0.601534    
#> 289: 0.936332    1.033859    3.474484    1.331983    0.040804    0.007241    0.601279    
#> 290: 0.935647    1.033689    3.474443    1.329429    0.040863    0.007242    0.601324    
#> 291: 0.934966    1.033886    3.474388    1.326839    0.040856    0.007236    0.601305    
#> 292: 0.935122    1.034020    3.474345    1.327073    0.040892    0.007225    0.601131    
#> 293: 0.935125    1.034179    3.474221    1.325940    0.040850    0.007240    0.601164    
#> 294: 0.935135    1.034425    3.474029    1.327096    0.040833    0.007243    0.601093    
#> 295: 0.934521    1.034411    3.473931    1.325793    0.040832    0.007246    0.600952    
#> 296: 0.934551    1.034322    3.473917    1.326029    0.040793    0.007245    0.601104    
#> 297: 0.935009    1.034382    3.473954    1.326965    0.040772    0.007273    0.600990    
#> 298: 0.935831    1.034297    3.474018    1.330807    0.040762    0.007287    0.600832    
#> 299: 0.935798    1.034441    3.473979    1.331220    0.040777    0.007266    0.600817    
#> 300: 0.935308    1.034373    3.473995    1.330887    0.040862    0.007241    0.600907    
#> 301: 0.935127    1.034361    3.473892    1.330548    0.040902    0.007222    0.600910    
#> 302: 0.935052    1.034427    3.473797    1.330869    0.040869    0.007219    0.600786    
#> 303: 0.934494    1.034688    3.473759    1.328981    0.040841    0.007231    0.600549    
#> 304: 0.934582    1.034908    3.473668    1.329434    0.040778    0.007246    0.600362    
#> 305: 0.934360    1.034787    3.473588    1.329879    0.040837    0.007256    0.600046    
#> 306: 0.933610    1.034758    3.473431    1.328949    0.040830    0.007247    0.599908    
#> 307: 0.932806    1.034770    3.473277    1.326893    0.040935    0.007236    0.599914    
#> 308: 0.932168    1.034900    3.473132    1.326587    0.041036    0.007242    0.600017    
#> 309: 0.931534    1.034791    3.473002    1.326266    0.041077    0.007244    0.600189    
#> 310: 0.932101    1.034640    3.472902    1.328081    0.041132    0.007254    0.600229    
#> 311: 0.932557    1.034591    3.472897    1.329608    0.041203    0.007282    0.600209    
#> 312: 0.931958    1.034598    3.472805    1.328818    0.041250    0.007286    0.600197    
#> 313: 0.931483    1.034530    3.472690    1.327718    0.041265    0.007292    0.600309    
#> 314: 0.930815    1.034462    3.472586    1.326191    0.041313    0.007291    0.600311    
#> 315: 0.930863    1.034464    3.472560    1.326065    0.041381    0.007302    0.600218    
#> 316: 0.931755    1.034494    3.472523    1.329334    0.041479    0.007303    0.600128    
#> 317: 0.932025    1.034517    3.472473    1.331707    0.041543    0.007296    0.600046    
#> 318: 0.932169    1.034538    3.472367    1.332602    0.041520    0.007301    0.599956    
#> 319: 0.932130    1.034494    3.472345    1.333142    0.041550    0.007300    0.599923    
#> 320: 0.931464    1.034492    3.472210    1.334022    0.041567    0.007311    0.600097    
#> 321: 0.930387    1.034467    3.472036    1.332314    0.041606    0.007327    0.600157    
#> 322: 0.930569    1.034515    3.471861    1.334310    0.041607    0.007331    0.600093    
#> 323: 0.930327    1.034595    3.471723    1.335501    0.041644    0.007329    0.600064    
#> 324: 0.930551    1.034894    3.471641    1.337727    0.041590    0.007322    0.599937    
#> 325: 0.930699    1.035126    3.471563    1.338574    0.041577    0.007338    0.599840    
#> 326: 0.930709    1.035038    3.471447    1.339579    0.041579    0.007345    0.599824    
#> 327: 0.931077    1.035098    3.471419    1.341577    0.041539    0.007358    0.599704    
#> 328: 0.931094    1.035385    3.471260    1.343796    0.041552    0.007380    0.599646    
#> 329: 0.931327    1.035603    3.471141    1.346075    0.041579    0.007393    0.599560    
#> 330: 0.931095    1.035722    3.471059    1.347264    0.041589    0.007394    0.599691    
#> 331: 0.931443    1.035931    3.471005    1.349301    0.041566    0.007403    0.599717    
#> 332: 0.931362    1.035948    3.471047    1.350203    0.041506    0.007414    0.599751    
#> 333: 0.931060    1.035947    3.470973    1.348969    0.041448    0.007429    0.599633    
#> 334: 0.930443    1.035920    3.470835    1.347160    0.041377    0.007434    0.599600    
#> 335: 0.929444    1.035895    3.470739    1.344295    0.041334    0.007447    0.599727    
#> 336: 0.929084    1.036105    3.470687    1.343325    0.041302    0.007461    0.599780    
#> 337: 0.929177    1.036425    3.470580    1.344138    0.041318    0.007463    0.599812    
#> 338: 0.929278    1.036663    3.470539    1.344540    0.041389    0.007455    0.599826    
#> 339: 0.929038    1.036747    3.470519    1.344026    0.041404    0.007455    0.599778    
#> 340: 0.928923    1.036618    3.470507    1.343697    0.041486    0.007454    0.599684    
#> 341: 0.928952    1.036610    3.470488    1.343756    0.041597    0.007446    0.599597    
#> 342: 0.928510    1.036393    3.470505    1.342605    0.041654    0.007447    0.599583    
#> 343: 0.928421    1.036251    3.470617    1.341479    0.041784    0.007440    0.599554    
#> 344: 0.928443    1.036191    3.470710    1.340985    0.041791    0.007453    0.599555    
#> 345: 0.928428    1.036184    3.470756    1.340283    0.041850    0.007470    0.599449    
#> 346: 0.928340    1.036164    3.470762    1.339024    0.041849    0.007467    0.599287    
#> 347: 0.928938    1.036067    3.470754    1.341863    0.041881    0.007476    0.599244    
#> 348: 0.928804    1.036059    3.470721    1.342013    0.041896    0.007479    0.599285    
#> 349: 0.928910    1.036082    3.470654    1.343525    0.041845    0.007497    0.599151    
#> 350: 0.928952    1.036120    3.470555    1.345364    0.041860    0.007509    0.599068    
#> 351: 0.928792    1.036229    3.470444    1.346410    0.041862    0.007523    0.598938    
#> 352: 0.928453    1.036390    3.470360    1.346430    0.041897    0.007533    0.598917    
#> 353: 0.928225    1.036660    3.470258    1.346355    0.041925    0.007538    0.598967    
#> 354: 0.927618    1.036826    3.470081    1.345856    0.041923    0.007557    0.598926    
#> 355: 0.927805    1.036733    3.470004    1.347514    0.041935    0.007568    0.598921    
#> 356: 0.927698    1.036737    3.469897    1.347473    0.041989    0.007574    0.599030    
#> 357: 0.928198    1.036828    3.469827    1.349521    0.041968    0.007575    0.598975    
#> 358: 0.928181    1.036889    3.469813    1.350319    0.041902    0.007584    0.598901    
#> 359: 0.927788    1.037028    3.469786    1.349392    0.041884    0.007590    0.598865    
#> 360: 0.927147    1.037036    3.469719    1.347811    0.041900    0.007590    0.598816    
#> 361: 0.927152    1.037119    3.469664    1.347858    0.041894    0.007594    0.598774    
#> 362: 0.927036    1.037147    3.469612    1.348291    0.041890    0.007592    0.598628    
#> 363: 0.927224    1.037149    3.469588    1.349328    0.041868    0.007600    0.598525    
#> 364: 0.927396    1.037152    3.469555    1.349688    0.041838    0.007614    0.598463    
#> 365: 0.927694    1.037084    3.469589    1.350485    0.041852    0.007634    0.598429    
#> 366: 0.927377    1.037134    3.469586    1.349197    0.041895    0.007656    0.598348    
#> 367: 0.927191    1.037135    3.469580    1.348343    0.041893    0.007668    0.598247    
#> 368: 0.927493    1.037193    3.469583    1.348496    0.041884    0.007674    0.598224    
#> 369: 0.927584    1.037224    3.469635    1.348090    0.041923    0.007681    0.598143    
#> 370: 0.927130    1.037321    3.469662    1.345994    0.041918    0.007695    0.598085    
#> 371: 0.926890    1.037288    3.469611    1.345046    0.041899    0.007693    0.597969    
#> 372: 0.926459    1.037317    3.469616    1.343588    0.041874    0.007697    0.597904    
#> 373: 0.926309    1.037325    3.469593    1.343454    0.041857    0.007697    0.597799    
#> 374: 0.926177    1.037343    3.469572    1.342675    0.041841    0.007688    0.597801    
#> 375: 0.926113    1.037377    3.469577    1.342635    0.041803    0.007687    0.597898    
#> 376: 0.926041    1.037351    3.469609    1.342136    0.041758    0.007683    0.597879    
#> 377: 0.925910    1.037323    3.469648    1.341951    0.041769    0.007668    0.597840    
#> 378: 0.925518    1.037303    3.469611    1.341656    0.041778    0.007662    0.597818    
#> 379: 0.925162    1.037173    3.469630    1.340718    0.041778    0.007658    0.597768    
#> 380: 0.925145    1.037107    3.469634    1.340809    0.041821    0.007644    0.597765    
#> 381: 0.924871    1.037027    3.469626    1.340045    0.041790    0.007632    0.597739    
#> 382: 0.924690    1.036996    3.469637    1.339510    0.041836    0.007624    0.597600    
#> 383: 0.924722    1.037010    3.469609    1.339788    0.041846    0.007615    0.597492    
#> 384: 0.924205    1.037004    3.469607    1.338766    0.041891    0.007605    0.597445    
#> 385: 0.924366    1.036994    3.469597    1.340162    0.041939    0.007606    0.597388    
#> 386: 0.924717    1.037173    3.469584    1.341938    0.041983    0.007602    0.597317    
#> 387: 0.924743    1.037221    3.469601    1.342344    0.042017    0.007605    0.597300    
#> 388: 0.924561    1.037239    3.469589    1.341749    0.041987    0.007609    0.597290    
#> 389: 0.924375    1.037132    3.469584    1.340569    0.041959    0.007614    0.597302    
#> 390: 0.924364    1.037240    3.469529    1.340189    0.041910    0.007626    0.597260    
#> 391: 0.924567    1.037310    3.469466    1.340885    0.041860    0.007639    0.597161    
#> 392: 0.924485    1.037337    3.469472    1.341032    0.041815    0.007652    0.597175    
#> 393: 0.924452    1.037310    3.469438    1.341596    0.041773    0.007667    0.597117    
#> 394: 0.925010    1.037318    3.469404    1.343820    0.041758    0.007672    0.597031    
#> 395: 0.925506    1.037342    3.469435    1.345430    0.041730    0.007672    0.596978    
#> 396: 0.925858    1.037344    3.469471    1.346936    0.041698    0.007673    0.596933    
#> 397: 0.925786    1.037305    3.469486    1.346931    0.041665    0.007682    0.596860    
#> 398: 0.926113    1.037258    3.469554    1.346967    0.041652    0.007689    0.596873    
#> 399: 0.926096    1.037271    3.469634    1.346650    0.041658    0.007690    0.596881    
#> 400: 0.926351    1.037243    3.469719    1.346419    0.041636    0.007689    0.596975    
#> 401: 0.926467    1.037321    3.469781    1.346018    0.041643    0.007687    0.596988    
#> 402: 0.926278    1.037355    3.469840    1.344744    0.041678    0.007691    0.597005    
#> 403: 0.926290    1.037328    3.469874    1.344414    0.041730    0.007694    0.597029    
#> 404: 0.926213    1.037349    3.469880    1.343700    0.041759    0.007695    0.596926    
#> 405: 0.925935    1.037379    3.469889    1.342630    0.041763    0.007696    0.596947    
#> 406: 0.926052    1.037401    3.469889    1.343071    0.041770    0.007706    0.596932    
#> 407: 0.926364    1.037420    3.469916    1.344400    0.041811    0.007700    0.596900    
#> 408: 0.926314    1.037495    3.469926    1.343744    0.041823    0.007696    0.596860    
#> 409: 0.926159    1.037455    3.469882    1.342997    0.041804    0.007699    0.596760    
#> 410: 0.925874    1.037521    3.469811    1.341886    0.041828    0.007710    0.596719    
#> 411: 0.925614    1.037366    3.469797    1.340773    0.041845    0.007707    0.596671    
#> 412: 0.925554    1.037394    3.469754    1.340179    0.041867    0.007706    0.596560    
#> 413: 0.925458    1.037490    3.469680    1.339890    0.041855    0.007705    0.596585    
#> 414: 0.925115    1.037541    3.469646    1.339336    0.041846    0.007701    0.596632    
#> 415: 0.925446    1.037532    3.469640    1.340318    0.041829    0.007702    0.596673    
#> 416: 0.925880    1.037532    3.469636    1.342456    0.041822    0.007700    0.596694    
#> 417: 0.925955    1.037574    3.469609    1.342676    0.041814    0.007691    0.596680    
#> 418: 0.925890    1.037639    3.469598    1.342589    0.041842    0.007676    0.596666    
#> 419: 0.925796    1.037792    3.469566    1.342260    0.041861    0.007660    0.596646    
#> 420: 0.925703    1.037933    3.469512    1.341905    0.041883    0.007643    0.596643    
#> 421: 0.925547    1.038010    3.469509    1.341371    0.041890    0.007628    0.596666    
#> 422: 0.925988    1.037979    3.469519    1.342646    0.041919    0.007617    0.596708    
#> 423: 0.925927    1.037974    3.469533    1.342209    0.041970    0.007615    0.596751    
#> 424: 0.925615    1.037979    3.469488    1.341314    0.042019    0.007609    0.596717    
#> 425: 0.925898    1.038125    3.469454    1.342936    0.042010    0.007608    0.596689    
#> 426: 0.926499    1.038224    3.469467    1.344725    0.041983    0.007608    0.596697    
#> 427: 0.926603    1.038234    3.469459    1.344687    0.041967    0.007608    0.596676    
#> 428: 0.926344    1.038287    3.469453    1.343679    0.041983    0.007606    0.596652    
#> 429: 0.926195    1.038336    3.469455    1.342914    0.041969    0.007600    0.596575    
#> 430: 0.926109    1.038430    3.469461    1.342772    0.041956    0.007600    0.596584    
#> 431: 0.926393    1.038481    3.469430    1.343636    0.041956    0.007595    0.596466    
#> 432: 0.926504    1.038581    3.469431    1.344184    0.041948    0.007597    0.596465    
#> 433: 0.926364    1.038667    3.469500    1.343116    0.041912    0.007599    0.596446    
#> 434: 0.926120    1.038581    3.469548    1.342321    0.041914    0.007602    0.596370    
#> 435: 0.926057    1.038565    3.469556    1.341532    0.041906    0.007600    0.596303    
#> 436: 0.926236    1.038513    3.469594    1.341728    0.041907    0.007596    0.596331    
#> 437: 0.926370    1.038397    3.469624    1.341667    0.041904    0.007598    0.596291    
#> 438: 0.926576    1.038470    3.469636    1.341929    0.041921    0.007594    0.596264    
#> 439: 0.926569    1.038537    3.469629    1.342208    0.041947    0.007584    0.596152    
#> 440: 0.926390    1.038520    3.469644    1.341490    0.041984    0.007576    0.596077    
#> 441: 0.926430    1.038463    3.469683    1.341592    0.042008    0.007565    0.596007    
#> 442: 0.926250    1.038488    3.469709    1.341117    0.042053    0.007556    0.595955    
#> 443: 0.926118    1.038583    3.469688    1.340240    0.042081    0.007543    0.595959    
#> 444: 0.925760    1.038614    3.469681    1.339099    0.042122    0.007532    0.595952    
#> 445: 0.925405    1.038661    3.469627    1.337967    0.042160    0.007530    0.595959    
#> 446: 0.924866    1.038703    3.469553    1.336627    0.042171    0.007528    0.595925    
#> 447: 0.924847    1.038730    3.469491    1.336773    0.042191    0.007529    0.595896    
#> 448: 0.924358    1.038809    3.469480    1.335645    0.042177    0.007531    0.595933    
#> 449: 0.924443    1.038827    3.469551    1.335674    0.042150    0.007529    0.595956    
#> 450: 0.924360    1.038800    3.469576    1.335320    0.042141    0.007530    0.595993    
#> 451: 0.924767    1.038831    3.469558    1.335944    0.042119    0.007525    0.596090    
#> 452: 0.924718    1.038918    3.469518    1.335625    0.042126    0.007523    0.596145    
#> 453: 0.924346    1.039002    3.469472    1.334423    0.042112    0.007512    0.596182    
#> 454: 0.924202    1.039106    3.469446    1.334034    0.042113    0.007510    0.596201    
#> 455: 0.924047    1.039143    3.469400    1.333740    0.042109    0.007509    0.596190    
#> 456: 0.923785    1.039186    3.469347    1.333317    0.042120    0.007515    0.596230    
#> 457: 0.923759    1.039188    3.469351    1.333780    0.042138    0.007514    0.596179    
#> 458: 0.923803    1.039231    3.469384    1.334059    0.042136    0.007510    0.596137    
#> 459: 0.923427    1.039327    3.469393    1.333252    0.042110    0.007507    0.596174    
#> 460: 0.923117    1.039396    3.469340    1.332624    0.042104    0.007505    0.596160    
#> 461: 0.922855    1.039451    3.469323    1.331888    0.042085    0.007510    0.596087    
#> 462: 0.922764    1.039517    3.469343    1.331528    0.042089    0.007514    0.596033    
#> 463: 0.922776    1.039562    3.469346    1.331509    0.042085    0.007518    0.595982    
#> 464: 0.922937    1.039614    3.469345    1.331663    0.042065    0.007521    0.595943    
#> 465: 0.922788    1.039545    3.469328    1.330980    0.042040    0.007520    0.595928    
#> 466: 0.922880    1.039586    3.469284    1.331372    0.042025    0.007520    0.595893    
#> 467: 0.922886    1.039599    3.469271    1.331782    0.042022    0.007521    0.595849    
#> 468: 0.923111    1.039575    3.469281    1.332617    0.042017    0.007525    0.595868    
#> 469: 0.923447    1.039659    3.469304    1.333382    0.042007    0.007533    0.595887    
#> 470: 0.923403    1.039692    3.469264    1.333892    0.042030    0.007540    0.595875    
#> 471: 0.923264    1.039742    3.469217    1.333661    0.042070    0.007538    0.595868    
#> 472: 0.923337    1.039776    3.469187    1.334430    0.042093    0.007535    0.595853    
#> 473: 0.923221    1.039800    3.469136    1.334373    0.042119    0.007543    0.595811    
#> 474: 0.922923    1.039853    3.469077    1.333884    0.042149    0.007555    0.595806    
#> 475: 0.922640    1.040005    3.469048    1.333197    0.042141    0.007562    0.595799    
#> 476: 0.922362    1.040040    3.469011    1.332491    0.042132    0.007568    0.595790    
#> 477: 0.922355    1.040073    3.469009    1.332515    0.042108    0.007568    0.595737    
#> 478: 0.922261    1.040059    3.469013    1.332380    0.042085    0.007568    0.595746    
#> 479: 0.922328    1.040150    3.469023    1.332436    0.042070    0.007564    0.595768    
#> 480: 0.922325    1.040140    3.469036    1.332543    0.042064    0.007566    0.595806    
#> 481: 0.922525    1.040131    3.469043    1.333259    0.042070    0.007570    0.595785    
#> 482: 0.923002    1.040141    3.469036    1.335244    0.042049    0.007577    0.595780    
#> 483: 0.922854    1.040101    3.469017    1.335480    0.042056    0.007578    0.595809    
#> 484: 0.923208    1.040028    3.468985    1.337660    0.042050    0.007578    0.595822    
#> 485: 0.923412    1.040041    3.468974    1.338872    0.042034    0.007582    0.595842    
#> 486: 0.923708    1.040091    3.468978    1.339703    0.042014    0.007584    0.595841    
#> 487: 0.924015    1.040101    3.468992    1.340655    0.041995    0.007589    0.595849    
#> 488: 0.924217    1.040073    3.469023    1.341242    0.041990    0.007595    0.595851    
#> 489: 0.924535    1.039985    3.469029    1.342499    0.041980    0.007607    0.595827    
#> 490: 0.924819    1.039957    3.469049    1.343596    0.041930    0.007618    0.595783    
#> 491: 0.925005    1.040000    3.469073    1.344436    0.041904    0.007625    0.595762    
#> 492: 0.924824    1.040020    3.469068    1.344164    0.041881    0.007623    0.595831    
#> 493: 0.924498    1.040034    3.469066    1.343368    0.041861    0.007625    0.595879    
#> 494: 0.924377    1.040090    3.469043    1.342761    0.041858    0.007622    0.595885    
#> 495: 0.924392    1.040174    3.469056    1.342524    0.041845    0.007623    0.595875    
#> 496: 0.924458    1.040249    3.469059    1.342286    0.041834    0.007633    0.595908    
#> 497: 0.924423    1.040249    3.469047    1.342399    0.041867    0.007640    0.595960    
#> 498: 0.924489    1.040197    3.469029    1.343029    0.041884    0.007643    0.595992    
#> 499: 0.924782    1.040203    3.469036    1.343716    0.041918    0.007641    0.596025    
#> 500: 0.925317    1.040136    3.469046    1.345290    0.041914    0.007637    0.596066    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.278077    0.980993    3.447604    0.392401    0.089631    0.016800    1.669610    
#> 002: 0.254555    0.999307    3.450943    0.372781    0.085149    0.015960    1.154535    
#> 003: 0.331007    0.957557    3.450918    0.354142    0.080892    0.015162    0.870797    
#> 004: 0.310187    0.982318    3.443575    0.336435    0.076847    0.014404    0.799633    
#> 005: 0.339862    1.008882    3.431659    0.342351    0.073005    0.013684    0.758797    
#> 006: 0.330274    1.019987    3.424088    0.325233    0.069355    0.013596    0.718640    
#> 007: 0.323196    1.006214    3.426730    0.308972    0.073747    0.018446    0.720090    
#> 008: 0.308622    0.997741    3.417611    0.385388    0.074390    0.019631    0.723623    
#> 009: 0.316277    0.981579    3.419257    0.404061    0.070830    0.025232    0.733055    
#> 010: 0.281824    0.987900    3.407178    0.383858    0.068652    0.026861    0.748164    
#> 011: 0.344734    1.002206    3.425708    0.400781    0.072825    0.027747    0.737403    
#> 012: 0.358312    1.001577    3.420684    0.388114    0.069184    0.029157    0.706212    
#> 013: 0.296425    1.013539    3.407222    0.368708    0.069562    0.030974    0.699551    
#> 014: 0.326158    1.016794    3.422447    0.376080    0.066084    0.029425    0.719416    
#> 015: 0.345484    1.014845    3.428541    0.370141    0.062780    0.027954    0.715488    
#> 016: 0.346204    1.031564    3.421231    0.437951    0.059641    0.026556    0.718600    
#> 017: 0.349854    1.029552    3.435569    0.416053    0.056659    0.025228    0.693914    
#> 018: 0.351197    1.031428    3.417026    0.395251    0.059726    0.024198    0.712375    
#> 019: 0.322569    1.027663    3.422972    0.375488    0.061882    0.023393    0.700946    
#> 020: 0.343334    1.026372    3.417829    0.410530    0.065221    0.026411    0.697042    
#> 021: 0.340716    1.011567    3.433523    0.390003    0.061960    0.025090    0.692425    
#> 022: 0.359044    1.014971    3.440388    0.467439    0.058862    0.025137    0.686693    
#> 023: 0.416405    1.018694    3.448648    0.449635    0.055919    0.023880    0.738192    
#> 024: 0.406226    1.032933    3.432022    0.461602    0.062756    0.022686    0.723821    
#> 025: 0.370795    1.013583    3.431594    0.438522    0.059981    0.023995    0.708461    
#> 026: 0.321070    1.040558    3.411671    0.416596    0.071049    0.022795    0.712273    
#> 027: 0.301385    1.069861    3.404152    0.395766    0.078410    0.023039    0.727275    
#> 028: 0.353847    1.032252    3.421224    0.382022    0.074490    0.023842    0.715626    
#> 029: 0.356931    1.036074    3.415439    0.362921    0.070765    0.022650    0.715818    
#> 030: 0.349854    1.031673    3.419396    0.344775    0.067227    0.022510    0.702947    
#> 031: 0.334233    1.018565    3.433767    0.385650    0.079108    0.021385    0.712351    
#> 032: 0.343407    0.999764    3.429053    0.410172    0.075152    0.021873    0.702965    
#> 033: 0.305291    1.024326    3.411588    0.414072    0.071395    0.020779    0.719282    
#> 034: 0.319424    1.049438    3.401971    0.424238    0.073612    0.025342    0.712659    
#> 035: 0.261852    1.028336    3.398574    0.403026    0.078717    0.024075    0.704454    
#> 036: 0.278945    1.053192    3.405946    0.382875    0.085400    0.022871    0.715584    
#> 037: 0.301730    1.050266    3.407476    0.363731    0.081130    0.021728    0.739596    
#> 038: 0.301341    1.021223    3.400078    0.345545    0.081008    0.020641    0.734652    
#> 039: 0.292806    1.031113    3.414662    0.347431    0.076958    0.021468    0.708892    
#> 040: 0.319590    1.026908    3.429741    0.330059    0.073110    0.021672    0.725356    
#> 041: 0.331398    1.021772    3.427098    0.313556    0.069454    0.025140    0.743188    
#> 042: 0.330454    1.004461    3.420469    0.306291    0.065982    0.025972    0.711040    
#> 043: 0.277468    1.041596    3.401283    0.290977    0.062683    0.025330    0.717805    
#> 044: 0.257299    1.032257    3.395411    0.296264    0.059548    0.024063    0.723425    
#> 045: 0.290430    1.057312    3.397460    0.284855    0.056571    0.026617    0.716664    
#> 046: 0.323033    1.032827    3.410716    0.270613    0.056011    0.031914    0.712321    
#> 047: 0.303722    1.038436    3.411795    0.291513    0.059101    0.031806    0.715203    
#> 048: 0.319920    1.021109    3.430452    0.301675    0.064048    0.039898    0.723278    
#> 049: 0.329855    1.025780    3.435101    0.293219    0.063612    0.037903    0.721139    
#> 050: 0.385683    0.996631    3.440141    0.336247    0.060432    0.036008    0.727698    
#> 051: 0.378688    0.996759    3.443370    0.319435    0.057410    0.034807    0.732118    
#> 052: 0.365040    1.017902    3.446138    0.314274    0.055645    0.033066    0.710168    
#> 053: 0.376032    0.997665    3.432544    0.369800    0.060227    0.031413    0.715393    
#> 054: 0.316055    1.010269    3.424531    0.351310    0.077597    0.030534    0.713554    
#> 055: 0.330855    1.003120    3.436745    0.333744    0.073717    0.029007    0.719428    
#> 056: 0.360151    1.010052    3.437554    0.387777    0.070031    0.027557    0.719951    
#> 057: 0.380115    1.006094    3.449263    0.406309    0.066530    0.027815    0.718343    
#> 058: 0.364856    0.987479    3.440142    0.385994    0.063203    0.026424    0.719444    
#> 059: 0.359549    0.969922    3.434464    0.366694    0.060762    0.025986    0.742418    
#> 060: 0.330827    0.970431    3.441214    0.348359    0.081077    0.027122    0.750164    
#> 061: 0.355680    0.975628    3.440215    0.375364    0.079192    0.025766    0.747204    
#> 062: 0.398313    0.994368    3.446765    0.398270    0.084420    0.025210    0.754043    
#> 063: 0.389491    0.968381    3.449337    0.378357    0.081296    0.023949    0.759027    
#> 064: 0.405322    1.005374    3.449306    0.359439    0.077231    0.022752    0.749639    
#> 065: 0.416875    0.979624    3.436513    0.341467    0.073369    0.021614    0.725499    
#> 066: 0.376959    0.994588    3.438884    0.404587    0.082428    0.023598    0.688283    
#> 067: 0.376354    0.993259    3.437107    0.387122    0.078306    0.022418    0.694445    
#> 068: 0.349981    0.999580    3.435379    0.402148    0.074391    0.021297    0.711400    
#> 069: 0.343974    1.007475    3.426237    0.382040    0.070671    0.020232    0.723697    
#> 070: 0.358525    1.007467    3.441821    0.362938    0.075054    0.020135    0.719936    
#> 071: 0.336216    1.026841    3.431239    0.344791    0.071301    0.019129    0.748044    
#> 072: 0.308560    1.006981    3.431927    0.331181    0.067736    0.022169    0.710896    
#> 073: 0.376851    1.000846    3.445409    0.314622    0.070591    0.022224    0.715779    
#> 074: 0.331194    1.005914    3.431117    0.304668    0.076238    0.021498    0.722621    
#> 075: 0.354291    1.011934    3.450820    0.289435    0.072427    0.024561    0.713489    
#> 076: 0.358979    1.010256    3.448329    0.295295    0.068805    0.024564    0.730581    
#> 077: 0.401795    0.979923    3.448089    0.381231    0.065365    0.029264    0.707801    
#> 078: 0.364652    1.005416    3.437706    0.417690    0.067474    0.027801    0.692883    
#> 079: 0.321649    1.013401    3.424901    0.396806    0.072152    0.026411    0.741273    
#> 080: 0.348124    0.996780    3.437587    0.376966    0.079425    0.025090    0.762736    
#> 081: 0.329891    1.014010    3.428950    0.358117    0.075454    0.023836    0.746929    
#> 082: 0.358882    1.007176    3.431030    0.374863    0.073265    0.023033    0.728131    
#> 083: 0.377309    1.022702    3.436940    0.447779    0.069601    0.022291    0.725409    
#> 084: 0.350484    1.028110    3.429612    0.425390    0.066121    0.023670    0.728743    
#> 085: 0.354658    1.047764    3.444715    0.404120    0.062815    0.022486    0.729066    
#> 086: 0.387808    1.027481    3.436444    0.383914    0.059674    0.026242    0.711512    
#> 087: 0.311721    1.011048    3.418070    0.385620    0.056691    0.024930    0.698834    
#> 088: 0.275421    1.005121    3.422752    0.366339    0.053856    0.023683    0.713964    
#> 089: 0.302263    1.029190    3.408170    0.348022    0.059436    0.030438    0.691790    
#> 090: 0.289519    1.027878    3.402297    0.330621    0.069433    0.028916    0.714695    
#> 091: 0.263209    1.017376    3.387303    0.347582    0.065961    0.027470    0.718216    
#> 092: 0.265576    1.042652    3.392309    0.330203    0.062663    0.026096    0.721047    
#> 093: 0.235793    1.030424    3.388405    0.341463    0.064154    0.025529    0.742161    
#> 094: 0.251333    1.041939    3.393299    0.355893    0.080525    0.024252    0.733073    
#> 095: 0.295320    1.032834    3.415559    0.340068    0.076498    0.023039    0.730736    
#> 096: 0.271327    1.023153    3.414517    0.339829    0.072673    0.021888    0.722268    
#> 097: 0.305846    1.043792    3.415695    0.322838    0.069040    0.028426    0.712405    
#> 098: 0.293582    1.057819    3.405002    0.335280    0.065588    0.027815    0.728899    
#> 099: 0.286619    1.038011    3.399632    0.318516    0.062308    0.026425    0.731177    
#> 100: 0.250044    1.047360    3.389794    0.302591    0.069603    0.025103    0.729154    
#> 101: 0.225528    1.024950    3.373239    0.290161    0.066122    0.023848    0.719213    
#> 102: 0.254482    1.032109    3.383349    0.280553    0.062816    0.022656    0.723607    
#> 103: 0.278308    1.043028    3.402901    0.284317    0.059676    0.024200    0.705967    
#> 104: 0.286835    1.041003    3.422659    0.287063    0.066678    0.024464    0.728460    
#> 105: 0.340166    1.014926    3.434637    0.278260    0.070003    0.024212    0.722546    
#> 106: 0.342757    1.005201    3.427707    0.264347    0.066503    0.023002    0.726983    
#> 107: 0.364204    1.016341    3.432705    0.252285    0.063853    0.022361    0.725932    
#> 108: 0.311980    1.011085    3.437009    0.282939    0.068877    0.021243    0.719342    
#> 109: 0.308882    1.001161    3.445246    0.268792    0.065433    0.020181    0.726574    
#> 110: 0.299673    1.022882    3.418307    0.255353    0.062161    0.023122    0.726055    
#> 111: 0.319254    1.021278    3.420142    0.275035    0.068112    0.024753    0.704346    
#> 112: 0.286571    1.012301    3.404568    0.307016    0.072997    0.025059    0.720965    
#> 113: 0.335900    1.030875    3.422635    0.364642    0.069348    0.027972    0.699661    
#> 114: 0.356788    1.015592    3.430658    0.346409    0.066395    0.028308    0.716461    
#> 115: 0.301405    1.009217    3.410090    0.329089    0.063075    0.030526    0.744942    
#> 116: 0.308421    1.032823    3.403108    0.312635    0.059922    0.035980    0.724547    
#> 117: 0.271289    1.041689    3.416863    0.297377    0.060610    0.034181    0.728098    
#> 118: 0.297443    1.020719    3.415968    0.334672    0.057579    0.032472    0.713982    
#> 119: 0.340788    1.014935    3.430664    0.317938    0.054700    0.032109    0.734061    
#> 120: 0.341718    1.015267    3.433627    0.302042    0.051965    0.034930    0.721730    
#> 121: 0.333704    1.055232    3.418178    0.286939    0.060676    0.033184    0.721122    
#> 122: 0.327075    1.026416    3.420855    0.381885    0.058342    0.035303    0.711183    
#> 123: 0.343123    1.055564    3.411429    0.443604    0.056593    0.033538    0.703858    
#> 124: 0.338532    1.061609    3.414956    0.421424    0.053763    0.031861    0.704717    
#> 125: 0.345194    1.052207    3.409534    0.400353    0.062439    0.030268    0.703016    
#> 126: 0.314375    1.049313    3.405439    0.380335    0.061543    0.029269    0.705179    
#> 127: 0.332817    1.051663    3.401484    0.361319    0.058466    0.027805    0.704375    
#> 128: 0.313406    1.028103    3.414552    0.361384    0.062456    0.027977    0.709366    
#> 129: 0.314983    1.032410    3.429404    0.343315    0.067939    0.028596    0.721028    
#> 130: 0.378523    1.042614    3.427038    0.326149    0.064542    0.027304    0.702362    
#> 131: 0.338083    1.012250    3.424742    0.326167    0.079653    0.025939    0.698613    
#> 132: 0.312350    1.015980    3.411561    0.309859    0.075670    0.025845    0.694292    
#> 133: 0.306840    1.011294    3.421421    0.296042    0.073119    0.024553    0.699571    
#> 134: 0.333637    0.999442    3.449509    0.311650    0.069463    0.026969    0.716882    
#> 135: 0.368728    0.980711    3.449782    0.342823    0.065990    0.025620    0.712534    
#> 136: 0.373783    0.978216    3.442495    0.325682    0.062691    0.026230    0.717630    
#> 137: 0.376523    0.983130    3.446412    0.313901    0.059556    0.026610    0.729574    
#> 138: 0.358888    0.995618    3.439311    0.298206    0.056578    0.025681    0.714662    
#> 139: 0.364796    1.009670    3.453894    0.283296    0.056645    0.030541    0.718322    
#> 140: 0.338783    1.022972    3.444020    0.299236    0.056617    0.029014    0.731480    
#> 141: 0.325445    0.999025    3.443253    0.284275    0.054312    0.027563    0.712687    
#> 142: 0.335894    0.985246    3.453136    0.270061    0.051596    0.026185    0.733320    
#> 143: 0.320178    0.994871    3.447305    0.256558    0.051409    0.026161    0.732666    
#> 144: 0.367525    0.997225    3.452722    0.285684    0.048839    0.024853    0.729210    
#> 145: 0.324683    1.028396    3.406057    0.304387    0.048094    0.027623    0.719618    
#> 146: 0.336353    1.022995    3.428177    0.327243    0.056440    0.035920    0.718935    
#> 147: 0.307654    1.018224    3.407475    0.353507    0.057024    0.034124    0.688348    
#> 148: 0.319123    1.021341    3.431262    0.399384    0.054266    0.032417    0.701863    
#> 149: 0.351119    1.025019    3.420501    0.379414    0.061983    0.030797    0.701768    
#> 150: 0.365271    1.016493    3.426874    0.360444    0.061777    0.029257    0.721914    
#> 151: 0.312237    1.031421    3.428035    0.342421    0.067798    0.027794    0.710807    
#> 152: 0.327804    1.015110    3.437917    0.328694    0.054176    0.022763    0.705548    
#> 153: 0.349304    1.023379    3.449481    0.280866    0.051942    0.025149    0.724974    
#> 154: 0.407604    1.020024    3.445831    0.341591    0.055093    0.028107    0.719977    
#> 155: 0.380138    0.982546    3.451411    0.298625    0.038402    0.031894    0.736937    
#> 156: 0.392287    0.982832    3.459968    0.314453    0.036445    0.040661    0.750335    
#> 157: 0.374509    0.984473    3.454589    0.316116    0.042144    0.040833    0.717109    
#> 158: 0.362972    1.003782    3.442277    0.318638    0.043919    0.036976    0.704341    
#> 159: 0.351629    1.025636    3.446009    0.324465    0.045025    0.029712    0.705587    
#> 160: 0.405556    0.998765    3.465514    0.373522    0.061536    0.029269    0.697797    
#> 161: 0.411523    1.012067    3.451404    0.362056    0.055229    0.033795    0.698742    
#> 162: 0.372247    1.014352    3.440136    0.325791    0.050295    0.031179    0.714303    
#> 163: 0.363316    1.014407    3.424888    0.320034    0.064259    0.022922    0.716602    
#> 164: 0.343841    1.012086    3.433935    0.350063    0.055392    0.026062    0.713670    
#> 165: 0.369576    1.004196    3.434564    0.359498    0.054899    0.030253    0.697376    
#> 166: 0.369557    1.035371    3.422003    0.331650    0.054786    0.029592    0.702613    
#> 167: 0.352069    1.038501    3.433342    0.291894    0.064074    0.033529    0.717015    
#> 168: 0.355381    1.035985    3.429179    0.292075    0.068678    0.030493    0.734673    
#> 169: 0.336439    1.067984    3.423532    0.278989    0.068768    0.028452    0.744476    
#> 170: 0.358221    1.031704    3.425778    0.302020    0.062766    0.030164    0.705624    
#> 171: 0.314674    1.035205    3.412143    0.240843    0.057409    0.026225    0.713629    
#> 172: 0.311637    1.047863    3.413453    0.283521    0.050743    0.023217    0.717368    
#> 173: 0.287133    1.062512    3.397838    0.271599    0.046179    0.025026    0.720049    
#> 174: 0.308043    1.048948    3.409801    0.272298    0.048889    0.026615    0.710611    
#> 175: 0.299203    1.050852    3.402496    0.298962    0.047018    0.028352    0.717997    
#> 176: 0.318951    1.044957    3.412415    0.355973    0.044048    0.030592    0.716461    
#> 177: 0.311504    1.028560    3.436191    0.313875    0.053172    0.024917    0.715994    
#> 178: 0.356798    1.015643    3.432345    0.353878    0.061965    0.028018    0.701487    
#> 179: 0.356897    1.027024    3.428278    0.320158    0.062185    0.027677    0.713173    
#> 180: 0.338446    1.009251    3.428478    0.347069    0.053814    0.026445    0.703687    
#> 181: 0.310718    1.013882    3.403092    0.379365    0.050132    0.026078    0.717983    
#> 182: 0.324683    1.010848    3.416642    0.354248    0.043952    0.028632    0.732969    
#> 183: 0.295785    1.030080    3.421433    0.292692    0.041095    0.029872    0.726616    
#> 184: 0.326868    1.017012    3.422600    0.308819    0.037013    0.034578    0.707079    
#> 185: 0.309958    1.024434    3.420802    0.289121    0.034014    0.033874    0.720691    
#> 186: 0.322547    1.052148    3.427762    0.272285    0.043608    0.042324    0.736390    
#> 187: 0.302494    1.025229    3.427397    0.233335    0.051065    0.036549    0.720194    
#> 188: 0.280355    1.049536    3.407905    0.273847    0.058839    0.025970    0.745477    
#> 189: 0.332373    1.044350    3.420134    0.292215    0.059787    0.026410    0.732323    
#> 190: 0.330672    1.038239    3.424697    0.290556    0.056911    0.034183    0.719625    
#> 191: 0.302266    1.041605    3.407777    0.356183    0.057077    0.029639    0.698530    
#> 192: 0.308183    1.038347    3.412753    0.398147    0.056828    0.026271    0.698863    
#> 193: 0.323466    1.043346    3.415016    0.322343    0.052230    0.027412    0.712665    
#> 194: 0.293450    1.027289    3.412178    0.304009    0.064948    0.023949    0.710424    
#> 195: 0.281807    1.033190    3.400880    0.361228    0.049432    0.027963    0.715606    
#> 196: 0.280801    1.025498    3.422554    0.295292    0.058131    0.031444    0.713403    
#> 197: 0.295545    1.031612    3.446752    0.312884    0.063877    0.029571    0.729027    
#> 198: 0.355961    1.002989    3.432615    0.330651    0.051457    0.034840    0.693428    
#> 199: 0.323218    1.012804    3.405696    0.365741    0.053982    0.033691    0.686247    
#> 200: 0.310728    1.020417    3.421265    0.321789    0.063804    0.034462    0.695610    
#> 201: 0.293845    1.020675    3.419075    0.300091    0.064138    0.032401    0.698917    
#> 202: 0.302968    1.025940    3.419318    0.318875    0.059963    0.031630    0.699923    
#> 203: 0.313132    1.022841    3.421468    0.322387    0.056432    0.032285    0.702813    
#> 204: 0.319406    1.014761    3.423170    0.334273    0.055580    0.032703    0.705713    
#> 205: 0.320486    1.015842    3.423195    0.335376    0.056271    0.033153    0.708946    
#> 206: 0.320596    1.020269    3.423482    0.334951    0.056623    0.033276    0.712713    
#> 207: 0.319475    1.021015    3.423306    0.327373    0.054893    0.032898    0.714010    
#> 208: 0.319498    1.019069    3.425106    0.323967    0.054057    0.033246    0.712705    
#> 209: 0.321022    1.015570    3.424996    0.324289    0.052734    0.033506    0.713105    
#> 210: 0.322163    1.013856    3.426155    0.320000    0.052675    0.033401    0.711053    
#> 211: 0.325497    1.013683    3.427134    0.313359    0.053190    0.033498    0.709507    
#> 212: 0.328377    1.012874    3.427479    0.310131    0.051732    0.033484    0.710315    
#> 213: 0.332920    1.009138    3.429942    0.312224    0.050832    0.033868    0.711661    
#> 214: 0.335584    1.007168    3.431276    0.310744    0.050882    0.034442    0.712955    
#> 215: 0.337399    1.005957    3.433174    0.312110    0.050785    0.034955    0.713447    
#> 216: 0.341825    1.004087    3.434575    0.315092    0.051040    0.035251    0.715956    
#> 217: 0.343555    1.004705    3.435057    0.316350    0.050812    0.035001    0.716256    
#> 218: 0.343887    1.005388    3.434946    0.319053    0.050880    0.034805    0.715045    
#> 219: 0.344583    1.004710    3.434175    0.320217    0.050924    0.034717    0.714540    
#> 220: 0.344747    1.004933    3.434202    0.322341    0.050417    0.034623    0.714629    
#> 221: 0.344265    1.005625    3.433915    0.322314    0.050466    0.034723    0.713799    
#> 222: 0.343348    1.006144    3.433139    0.322310    0.050847    0.034868    0.713547    
#> 223: 0.343198    1.007037    3.433063    0.321710    0.051290    0.034925    0.713696    
#> 224: 0.343637    1.007829    3.432980    0.320612    0.050998    0.034921    0.713919    
#> 225: 0.342465    1.006781    3.433500    0.321729    0.050667    0.035183    0.715265    
#> 226: 0.343407    1.005345    3.433924    0.321641    0.050851    0.035105    0.715491    
#> 227: 0.343815    1.004922    3.433864    0.322329    0.050958    0.034993    0.715208    
#> 228: 0.343251    1.005696    3.433321    0.321954    0.051173    0.034947    0.715253    
#> 229: 0.343162    1.005716    3.433262    0.322627    0.051109    0.034857    0.714647    
#> 230: 0.345006    1.005394    3.433520    0.323214    0.051064    0.034851    0.715146    
#> 231: 0.345072    1.005569    3.433791    0.322254    0.050969    0.034757    0.715609    
#> 232: 0.344474    1.005289    3.434040    0.322745    0.050434    0.034581    0.716142    
#> 233: 0.343653    1.004717    3.433863    0.321901    0.050155    0.034555    0.716094    
#> 234: 0.342697    1.004545    3.433709    0.320953    0.050204    0.034388    0.716297    
#> 235: 0.342158    1.004262    3.433700    0.319487    0.050010    0.034463    0.715975    
#> 236: 0.341510    1.004713    3.433318    0.319258    0.049934    0.034507    0.715751    
#> 237: 0.342665    1.004895    3.433385    0.319339    0.049903    0.034553    0.715933    
#> 238: 0.343627    1.005103    3.433209    0.319883    0.050078    0.034638    0.716230    
#> 239: 0.343104    1.006484    3.432878    0.319914    0.050379    0.034835    0.715842    
#> 240: 0.342596    1.007220    3.432884    0.319666    0.050532    0.034841    0.715300    
#> 241: 0.341927    1.007481    3.432745    0.319145    0.050655    0.034843    0.715006    
#> 242: 0.340532    1.007754    3.432042    0.318972    0.050902    0.034765    0.714925    
#> 243: 0.339060    1.008959    3.431367    0.319300    0.051221    0.034596    0.714706    
#> 244: 0.338391    1.009404    3.431257    0.320065    0.051166    0.034540    0.714506    
#> 245: 0.338341    1.009280    3.431283    0.320389    0.051460    0.034523    0.715016    
#> 246: 0.337668    1.009019    3.431286    0.320901    0.051358    0.034608    0.715438    
#> 247: 0.337118    1.008711    3.431319    0.322001    0.051304    0.034673    0.715512    
#> 248: 0.336822    1.009004    3.431173    0.322253    0.051291    0.034527    0.715592    
#> 249: 0.336523    1.009030    3.431180    0.322478    0.051160    0.034508    0.715202    
#> 250: 0.336971    1.009296    3.431180    0.323185    0.051279    0.034470    0.714893    
#> 251: 0.337899    1.009576    3.431527    0.324582    0.051387    0.034418    0.714783    
#> 252: 0.338524    1.009789    3.431961    0.324643    0.051537    0.034392    0.714486    
#> 253: 0.338338    1.010061    3.432162    0.324868    0.051825    0.034359    0.714182    
#> 254: 0.338471    1.010767    3.432232    0.324510    0.052056    0.034202    0.713691    
#> 255: 0.338372    1.011252    3.432167    0.325231    0.052038    0.034026    0.713477    
#> 256: 0.338072    1.011091    3.432141    0.325529    0.052030    0.033807    0.713539    
#> 257: 0.337462    1.011022    3.431966    0.325043    0.051945    0.033636    0.713454    
#> 258: 0.337380    1.010785    3.431911    0.325657    0.051812    0.033464    0.713331    
#> 259: 0.337983    1.010528    3.432150    0.326991    0.051905    0.033408    0.713595    
#> 260: 0.338700    1.010425    3.432448    0.328018    0.051891    0.033431    0.713667    
#> 261: 0.339374    1.010246    3.432754    0.328554    0.051826    0.033457    0.714013    
#> 262: 0.339454    1.010350    3.432737    0.328257    0.051910    0.033433    0.713940    
#> 263: 0.339431    1.010532    3.432706    0.328617    0.051946    0.033308    0.713970    
#> 264: 0.339200    1.010714    3.432669    0.328420    0.051959    0.033263    0.714114    
#> 265: 0.339263    1.010780    3.432687    0.328457    0.051987    0.033310    0.714245    
#> 266: 0.339290    1.011079    3.432704    0.327949    0.051954    0.033365    0.714212    
#> 267: 0.339011    1.010963    3.432843    0.328215    0.052010    0.033453    0.714111    
#> 268: 0.339089    1.010745    3.432873    0.328220    0.051958    0.033511    0.713944    
#> 269: 0.339638    1.010467    3.433007    0.329278    0.051882    0.033522    0.713993    
#> 270: 0.339952    1.010650    3.432910    0.329935    0.051972    0.033530    0.713788    
#> 271: 0.339839    1.010600    3.432745    0.329908    0.051994    0.033508    0.713577    
#> 272: 0.339847    1.010481    3.432658    0.330111    0.052100    0.033528    0.713700    
#> 273: 0.339741    1.010752    3.432562    0.330464    0.052141    0.033550    0.713690    
#> 274: 0.339362    1.010902    3.432501    0.329866    0.052104    0.033564    0.713652    
#> 275: 0.339117    1.010938    3.432422    0.330047    0.052044    0.033519    0.713582    
#> 276: 0.339231    1.010974    3.432530    0.329830    0.052020    0.033493    0.713428    
#> 277: 0.338923    1.011123    3.432595    0.330109    0.051825    0.033449    0.713589    
#> 278: 0.338608    1.011143    3.432670    0.329625    0.051885    0.033395    0.713541    
#> 279: 0.338324    1.010950    3.432744    0.329342    0.051974    0.033365    0.713532    
#> 280: 0.338233    1.011044    3.432817    0.328729    0.052021    0.033285    0.713405    
#> 281: 0.338064    1.011272    3.432862    0.328253    0.052054    0.033259    0.713324    
#> 282: 0.337953    1.011378    3.432929    0.327766    0.052243    0.033300    0.713395    
#> 283: 0.338242    1.011489    3.433003    0.328132    0.052286    0.033367    0.713725    
#> 284: 0.338126    1.011457    3.432984    0.328252    0.052139    0.033389    0.713804    
#> 285: 0.337843    1.011566    3.432799    0.328227    0.052118    0.033379    0.713793    
#> 286: 0.337519    1.011861    3.432620    0.328208    0.052214    0.033319    0.713740    
#> 287: 0.337043    1.012183    3.432384    0.327718    0.052232    0.033268    0.713667    
#> 288: 0.336916    1.012448    3.432208    0.326599    0.052155    0.033179    0.713877    
#> 289: 0.337044    1.012400    3.432256    0.325422    0.052115    0.033165    0.714018    
#> 290: 0.337305    1.012425    3.432253    0.324986    0.051962    0.033136    0.714317    
#> 291: 0.337718    1.012492    3.432398    0.324946    0.051778    0.033171    0.714282    
#> 292: 0.337867    1.012481    3.432335    0.325099    0.051664    0.033170    0.714294    
#> 293: 0.337924    1.012481    3.432334    0.325323    0.051608    0.033153    0.714282    
#> 294: 0.337716    1.012759    3.432180    0.325510    0.051591    0.033137    0.714331    
#> 295: 0.337701    1.012508    3.432138    0.325551    0.051467    0.033205    0.714337    
#> 296: 0.337475    1.012258    3.432161    0.324797    0.051373    0.033286    0.714502    
#> 297: 0.337566    1.012350    3.432138    0.325065    0.051271    0.033318    0.714577    
#> 298: 0.337726    1.012266    3.432034    0.325372    0.051254    0.033297    0.714422    
#> 299: 0.337835    1.012307    3.431910    0.325458    0.051187    0.033259    0.714271    
#> 300: 0.338235    1.012222    3.431973    0.325470    0.051129    0.033232    0.714252    
#> 301: 0.338531    1.011980    3.431858    0.325150    0.051197    0.033184    0.714431    
#> 302: 0.338335    1.012118    3.431721    0.324839    0.051395    0.033144    0.714357    
#> 303: 0.338032    1.012325    3.431603    0.324425    0.051564    0.033108    0.714155    
#> 304: 0.337772    1.012649    3.431489    0.324063    0.051674    0.033024    0.714183    
#> 305: 0.337527    1.012519    3.431435    0.323609    0.051827    0.032969    0.714222    
#> 306: 0.337013    1.012569    3.431207    0.323465    0.051939    0.032920    0.714123    
#> 307: 0.336628    1.012651    3.430982    0.323402    0.052087    0.032862    0.714263    
#> 308: 0.336183    1.012708    3.430799    0.323750    0.052212    0.032816    0.714489    
#> 309: 0.336044    1.012694    3.430572    0.323750    0.052223    0.032762    0.714725    
#> 310: 0.336343    1.012528    3.430499    0.323905    0.052224    0.032704    0.714822    
#> 311: 0.336471    1.012412    3.430554    0.323914    0.052123    0.032688    0.714816    
#> 312: 0.336333    1.012285    3.430367    0.323691    0.052090    0.032686    0.714910    
#> 313: 0.335716    1.012174    3.430168    0.323875    0.052082    0.032688    0.715200    
#> 314: 0.335316    1.012242    3.430046    0.323880    0.052073    0.032634    0.715470    
#> 315: 0.335095    1.012339    3.429926    0.323714    0.052111    0.032556    0.715606    
#> 316: 0.335141    1.012493    3.429910    0.323667    0.052208    0.032496    0.715567    
#> 317: 0.335285    1.012548    3.429905    0.324281    0.052268    0.032451    0.715649    
#> 318: 0.335516    1.012628    3.429858    0.324314    0.052229    0.032453    0.715685    
#> 319: 0.335731    1.012671    3.429913    0.324206    0.052262    0.032491    0.715908    
#> 320: 0.335495    1.012681    3.429848    0.324021    0.052251    0.032471    0.716182    
#> 321: 0.335061    1.012734    3.429719    0.323532    0.052221    0.032456    0.716360    
#> 322: 0.334900    1.012900    3.429584    0.323199    0.052229    0.032452    0.716479    
#> 323: 0.334531    1.012932    3.429558    0.322741    0.052229    0.032463    0.716597    
#> 324: 0.334804    1.012998    3.429604    0.322666    0.052256    0.032466    0.716524    
#> 325: 0.334865    1.013194    3.429568    0.322663    0.052335    0.032420    0.716450    
#> 326: 0.334849    1.013153    3.429503    0.322846    0.052390    0.032392    0.716353    
#> 327: 0.335078    1.013055    3.429649    0.323185    0.052482    0.032390    0.716309    
#> 328: 0.335521    1.013022    3.429712    0.324000    0.052481    0.032366    0.716205    
#> 329: 0.335967    1.012938    3.429852    0.324451    0.052441    0.032323    0.716193    
#> 330: 0.336263    1.012865    3.429928    0.325338    0.052352    0.032260    0.716225    
#> 331: 0.336692    1.012896    3.429996    0.326215    0.052339    0.032208    0.716216    
#> 332: 0.336839    1.012858    3.430133    0.326334    0.052303    0.032163    0.716347    
#> 333: 0.336682    1.012841    3.430064    0.326070    0.052243    0.032170    0.716318    
#> 334: 0.336677    1.012743    3.429898    0.326365    0.052191    0.032196    0.716348    
#> 335: 0.336426    1.012731    3.429808    0.326323    0.052191    0.032214    0.716455    
#> 336: 0.336095    1.012776    3.429674    0.326386    0.052228    0.032221    0.716480    
#> 337: 0.335896    1.013053    3.429569    0.326245    0.052257    0.032205    0.716613    
#> 338: 0.335839    1.013249    3.429551    0.326747    0.052297    0.032194    0.716568    
#> 339: 0.335643    1.013499    3.429388    0.327105    0.052279    0.032210    0.716482    
#> 340: 0.335333    1.013549    3.429268    0.327106    0.052328    0.032199    0.716480    
#> 341: 0.335267    1.013593    3.429208    0.327175    0.052340    0.032192    0.716383    
#> 342: 0.335128    1.013395    3.429218    0.327038    0.052429    0.032177    0.716303    
#> 343: 0.334885    1.013352    3.429173    0.326887    0.052445    0.032140    0.716279    
#> 344: 0.334748    1.013371    3.429081    0.326664    0.052407    0.032121    0.716256    
#> 345: 0.334625    1.013409    3.429042    0.326793    0.052435    0.032139    0.716207    
#> 346: 0.334482    1.013483    3.428848    0.327315    0.052432    0.032140    0.716205    
#> 347: 0.334281    1.013499    3.428734    0.327338    0.052532    0.032143    0.716343    
#> 348: 0.334074    1.013672    3.428655    0.327420    0.052647    0.032103    0.716499    
#> 349: 0.333886    1.013700    3.428602    0.327499    0.052707    0.032095    0.716502    
#> 350: 0.333512    1.013590    3.428491    0.327267    0.052773    0.032042    0.716552    
#> 351: 0.333343    1.013838    3.428359    0.327108    0.052831    0.031989    0.716590    
#> 352: 0.332920    1.013992    3.428257    0.327328    0.052918    0.031944    0.716725    
#> 353: 0.332885    1.014151    3.428130    0.327703    0.053019    0.031913    0.716665    
#> 354: 0.332757    1.014384    3.427991    0.327904    0.053095    0.031916    0.716558    
#> 355: 0.332840    1.014404    3.427879    0.328331    0.053169    0.031879    0.716403    
#> 356: 0.332703    1.014271    3.427865    0.328268    0.053293    0.031846    0.716699    
#> 357: 0.332850    1.014280    3.427899    0.328218    0.053377    0.031838    0.716673    
#> 358: 0.332889    1.014394    3.427825    0.328460    0.053347    0.031834    0.716594    
#> 359: 0.332735    1.014564    3.427771    0.328405    0.053234    0.031839    0.716643    
#> 360: 0.332378    1.014746    3.427502    0.328355    0.053275    0.031813    0.716535    
#> 361: 0.332001    1.014879    3.427388    0.328323    0.053288    0.031755    0.716386    
#> 362: 0.331922    1.014948    3.427345    0.328470    0.053273    0.031693    0.716233    
#> 363: 0.331767    1.014909    3.427335    0.328442    0.053257    0.031641    0.716146    
#> 364: 0.331803    1.014989    3.427272    0.328757    0.053281    0.031614    0.716071    
#> 365: 0.331666    1.014878    3.427250    0.328613    0.053244    0.031580    0.716041    
#> 366: 0.331690    1.014941    3.427171    0.328700    0.053314    0.031565    0.716008    
#> 367: 0.331857    1.015014    3.427123    0.328748    0.053419    0.031518    0.715995    
#> 368: 0.332008    1.015183    3.427105    0.328413    0.053427    0.031503    0.715924    
#> 369: 0.332048    1.015177    3.427136    0.327921    0.053454    0.031483    0.715916    
#> 370: 0.332010    1.015200    3.427108    0.328004    0.053406    0.031467    0.715916    
#> 371: 0.331766    1.015234    3.426996    0.327976    0.053329    0.031443    0.715859    
#> 372: 0.331775    1.015276    3.426928    0.328166    0.053255    0.031459    0.715830    
#> 373: 0.331696    1.015393    3.426879    0.328692    0.053176    0.031480    0.715863    
#> 374: 0.331860    1.015310    3.426877    0.328887    0.053147    0.031490    0.715990    
#> 375: 0.332029    1.015201    3.426966    0.329030    0.053124    0.031458    0.716150    
#> 376: 0.332225    1.015207    3.427049    0.329187    0.053150    0.031461    0.716018    
#> 377: 0.332186    1.015136    3.427026    0.329429    0.053126    0.031410    0.716032    
#> 378: 0.332153    1.015066    3.426962    0.329551    0.053109    0.031357    0.716062    
#> 379: 0.332181    1.014875    3.426947    0.329397    0.053107    0.031321    0.716102    
#> 380: 0.332157    1.014844    3.426924    0.329204    0.053132    0.031261    0.716049    
#> 381: 0.331940    1.014839    3.426827    0.329219    0.053151    0.031215    0.715970    
#> 382: 0.331765    1.014964    3.426741    0.329542    0.053156    0.031202    0.715822    
#> 383: 0.331705    1.014944    3.426687    0.329693    0.053150    0.031212    0.715665    
#> 384: 0.331624    1.014998    3.426666    0.329997    0.053177    0.031202    0.715589    
#> 385: 0.331755    1.015073    3.426684    0.329905    0.053216    0.031194    0.715562    
#> 386: 0.332052    1.015209    3.426742    0.329760    0.053279    0.031184    0.715587    
#> 387: 0.332121    1.015271    3.426838    0.329446    0.053330    0.031196    0.715552    
#> 388: 0.332212    1.015319    3.426903    0.329126    0.053316    0.031203    0.715498    
#> 389: 0.332144    1.015131    3.426921    0.328830    0.053222    0.031227    0.715641    
#> 390: 0.332017    1.015175    3.426925    0.328783    0.053141    0.031232    0.715741    
#> 391: 0.331960    1.015091    3.426923    0.328687    0.053071    0.031249    0.715690    
#> 392: 0.332027    1.015051    3.426932    0.328750    0.052991    0.031219    0.715759    
#> 393: 0.331942    1.014963    3.426902    0.328618    0.052926    0.031224    0.715700    
#> 394: 0.331858    1.015004    3.426871    0.328703    0.052884    0.031231    0.715700    
#> 395: 0.332151    1.015109    3.426882    0.328895    0.052864    0.031234    0.715692    
#> 396: 0.332240    1.015218    3.426829    0.328882    0.052820    0.031238    0.715652    
#> 397: 0.332128    1.015229    3.426822    0.328737    0.052742    0.031240    0.715692    
#> 398: 0.332255    1.015220    3.426867    0.328566    0.052691    0.031242    0.715639    
#> 399: 0.332419    1.015233    3.426924    0.328162    0.052729    0.031203    0.715619    
#> 400: 0.332550    1.015367    3.426982    0.327811    0.052756    0.031164    0.715629    
#> 401: 0.332720    1.015487    3.427014    0.327876    0.052767    0.031134    0.715637    
#> 402: 0.332882    1.015589    3.427041    0.327779    0.052706    0.031127    0.715693    
#> 403: 0.333043    1.015604    3.427071    0.327680    0.052666    0.031099    0.715715    
#> 404: 0.333170    1.015630    3.427024    0.327838    0.052669    0.031043    0.715724    
#> 405: 0.333128    1.015711    3.427006    0.327889    0.052682    0.031003    0.715784    
#> 406: 0.333131    1.015827    3.426957    0.327704    0.052698    0.030981    0.715916    
#> 407: 0.333198    1.015909    3.426984    0.327778    0.052791    0.030956    0.715901    
#> 408: 0.333432    1.015934    3.427023    0.327905    0.052886    0.030927    0.715941    
#> 409: 0.333563    1.015868    3.426997    0.327916    0.052927    0.030883    0.715938    
#> 410: 0.333557    1.015855    3.426954    0.327784    0.053014    0.030835    0.715965    
#> 411: 0.333676    1.015647    3.426971    0.327699    0.053083    0.030790    0.715995    
#> 412: 0.333800    1.015624    3.426969    0.327696    0.053134    0.030763    0.715937    
#> 413: 0.333860    1.015648    3.426932    0.327895    0.053137    0.030725    0.715974    
#> 414: 0.333550    1.015658    3.426892    0.327843    0.053188    0.030681    0.716000    
#> 415: 0.333544    1.015680    3.426879    0.327726    0.053181    0.030648    0.715974    
#> 416: 0.333548    1.015808    3.426906    0.327597    0.053232    0.030617    0.715926    
#> 417: 0.333555    1.015744    3.426956    0.327493    0.053264    0.030589    0.715921    
#> 418: 0.333371    1.015842    3.426972    0.327418    0.053309    0.030562    0.715853    
#> 419: 0.333566    1.015937    3.427044    0.327357    0.053341    0.030562    0.715799    
#> 420: 0.333827    1.015934    3.427143    0.327514    0.053350    0.030553    0.715748    
#> 421: 0.333830    1.015919    3.427220    0.327539    0.053382    0.030532    0.715730    
#> 422: 0.333949    1.015803    3.427272    0.327373    0.053368    0.030516    0.715710    
#> 423: 0.334061    1.015681    3.427278    0.327424    0.053343    0.030507    0.715673    
#> 424: 0.334097    1.015635    3.427279    0.327672    0.053349    0.030521    0.715613    
#> 425: 0.334208    1.015641    3.427272    0.327952    0.053310    0.030572    0.715702    
#> 426: 0.334319    1.015739    3.427234    0.328142    0.053285    0.030579    0.715616    
#> 427: 0.334181    1.015816    3.427213    0.328132    0.053286    0.030570    0.715534    
#> 428: 0.334059    1.015955    3.427151    0.328166    0.053333    0.030541    0.715515    
#> 429: 0.333965    1.016115    3.427115    0.327999    0.053389    0.030503    0.715537    
#> 430: 0.333803    1.016194    3.427057    0.327904    0.053400    0.030470    0.715571    
#> 431: 0.333756    1.016183    3.427043    0.327905    0.053430    0.030416    0.715504    
#> 432: 0.333751    1.016204    3.427101    0.328065    0.053480    0.030401    0.715481    
#> 433: 0.333817    1.016275    3.427119    0.327916    0.053489    0.030377    0.715501    
#> 434: 0.333676    1.016229    3.427104    0.327588    0.053477    0.030367    0.715531    
#> 435: 0.333756    1.016233    3.427078    0.327481    0.053451    0.030351    0.715504    
#> 436: 0.333772    1.016199    3.427125    0.327377    0.053450    0.030357    0.715510    
#> 437: 0.333832    1.016257    3.427065    0.327365    0.053548    0.030344    0.715490    
#> 438: 0.333840    1.016468    3.427049    0.327328    0.053627    0.030316    0.715463    
#> 439: 0.333844    1.016571    3.427022    0.327283    0.053680    0.030290    0.715391    
#> 440: 0.333789    1.016578    3.427036    0.327256    0.053725    0.030271    0.715312    
#> 441: 0.333636    1.016582    3.427042    0.327226    0.053771    0.030257    0.715254    
#> 442: 0.333611    1.016615    3.427044    0.327270    0.053888    0.030245    0.715213    
#> 443: 0.333490    1.016698    3.426987    0.327252    0.053943    0.030246    0.715181    
#> 444: 0.333465    1.016794    3.426885    0.327363    0.053982    0.030267    0.715093    
#> 445: 0.333336    1.016874    3.426844    0.327283    0.054012    0.030274    0.715068    
#> 446: 0.333121    1.016955    3.426777    0.327151    0.053990    0.030264    0.715003    
#> 447: 0.333217    1.016958    3.426769    0.327330    0.053948    0.030288    0.714972    
#> 448: 0.333208    1.016947    3.426789    0.327473    0.053937    0.030307    0.714933    
#> 449: 0.333282    1.016985    3.426870    0.327410    0.053896    0.030315    0.714935    
#> 450: 0.333313    1.016982    3.426913    0.327313    0.053884    0.030329    0.714928    
#> 451: 0.333404    1.017089    3.426904    0.327201    0.053917    0.030339    0.715035    
#> 452: 0.333382    1.017179    3.426914    0.326928    0.053960    0.030319    0.714997    
#> 453: 0.333260    1.017220    3.426813    0.326916    0.053976    0.030308    0.714965    
#> 454: 0.333216    1.017356    3.426759    0.327260    0.054013    0.030277    0.714962    
#> 455: 0.333133    1.017386    3.426720    0.327440    0.053981    0.030247    0.715045    
#> 456: 0.333018    1.017375    3.426682    0.327566    0.053950    0.030223    0.715148    
#> 457: 0.333074    1.017410    3.426687    0.327737    0.053942    0.030201    0.715110    
#> 458: 0.333056    1.017503    3.426697    0.327662    0.053918    0.030188    0.715107    
#> 459: 0.332871    1.017660    3.426676    0.327508    0.053902    0.030185    0.715128    
#> 460: 0.332691    1.017687    3.426664    0.327291    0.053881    0.030191    0.715144    
#> 461: 0.332615    1.017702    3.426693    0.327238    0.053832    0.030209    0.715170    
#> 462: 0.332649    1.017708    3.426764    0.327170    0.053804    0.030216    0.715175    
#> 463: 0.332813    1.017722    3.426833    0.327220    0.053812    0.030213    0.715152    
#> 464: 0.333030    1.017674    3.426863    0.327481    0.053777    0.030202    0.715094    
#> 465: 0.333198    1.017511    3.426904    0.327617    0.053722    0.030199    0.715009    
#> 466: 0.333266    1.017519    3.426918    0.327633    0.053733    0.030197    0.714958    
#> 467: 0.333304    1.017508    3.426960    0.327757    0.053780    0.030188    0.714871    
#> 468: 0.333503    1.017457    3.427025    0.327822    0.053789    0.030197    0.714878    
#> 469: 0.333574    1.017477    3.427095    0.327705    0.053806    0.030189    0.715004    
#> 470: 0.333438    1.017471    3.427053    0.327663    0.053826    0.030184    0.715077    
#> 471: 0.333318    1.017460    3.427041    0.327449    0.053824    0.030149    0.715241    
#> 472: 0.333339    1.017392    3.427060    0.327248    0.053838    0.030119    0.715324    
#> 473: 0.333236    1.017392    3.427064    0.327130    0.053845    0.030105    0.715269    
#> 474: 0.333165    1.017376    3.427086    0.326968    0.053858    0.030109    0.715328    
#> 475: 0.333195    1.017419    3.427097    0.326780    0.053820    0.030102    0.715396    
#> 476: 0.333207    1.017449    3.427094    0.326684    0.053767    0.030110    0.715435    
#> 477: 0.333105    1.017447    3.427129    0.326630    0.053699    0.030132    0.715412    
#> 478: 0.333089    1.017401    3.427169    0.326575    0.053659    0.030136    0.715472    
#> 479: 0.333246    1.017409    3.427180    0.326668    0.053616    0.030136    0.715488    
#> 480: 0.333206    1.017510    3.427136    0.326688    0.053621    0.030125    0.715474    
#> 481: 0.333124    1.017577    3.427089    0.326817    0.053657    0.030101    0.715508    
#> 482: 0.333084    1.017631    3.427015    0.327043    0.053706    0.030083    0.715505    
#> 483: 0.333026    1.017664    3.426998    0.326946    0.053725    0.030063    0.715506    
#> 484: 0.332995    1.017555    3.426999    0.326762    0.053706    0.030045    0.715500    
#> 485: 0.333041    1.017555    3.427013    0.326782    0.053717    0.030031    0.715521    
#> 486: 0.332972    1.017620    3.426993    0.326898    0.053690    0.030017    0.715480    
#> 487: 0.333070    1.017698    3.427004    0.327002    0.053691    0.030011    0.715454    
#> 488: 0.333050    1.017649    3.427049    0.326960    0.053683    0.030012    0.715392    
#> 489: 0.333134    1.017600    3.427025    0.326946    0.053689    0.030003    0.715321    
#> 490: 0.333077    1.017631    3.427021    0.326774    0.053669    0.030008    0.715313    
#> 491: 0.333103    1.017688    3.427049    0.326781    0.053656    0.030020    0.715273    
#> 492: 0.333170    1.017778    3.427036    0.326830    0.053668    0.030044    0.715307    
#> 493: 0.333135    1.017852    3.427019    0.326875    0.053658    0.030050    0.715238    
#> 494: 0.333232    1.017942    3.426992    0.326880    0.053656    0.030033    0.715199    
#> 495: 0.333327    1.017989    3.427009    0.326953    0.053618    0.030031    0.715129    
#> 496: 0.333368    1.018034    3.426988    0.326838    0.053597    0.030029    0.715101    
#> 497: 0.333268    1.018026    3.427000    0.326665    0.053598    0.030034    0.715112    
#> 498: 0.333242    1.017999    3.426979    0.326637    0.053588    0.030042    0.715023    
#> 499: 0.333121    1.018035    3.426923    0.326685    0.053625    0.030026    0.714925    
#> 500: 0.333122    1.018021    3.426884    0.326613    0.053590    0.030016    0.714962    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.303237    0.969138    3.453449    0.392401    0.081841    0.016800    1.779938    
#> 002: 0.243031    1.047020    3.488955    0.372781    0.077749    0.015960    1.056894    
#> 003: 0.354747    1.052486    3.525515    0.377605    0.073862    0.015162    0.791678    
#> 004: 0.380239    1.123388    3.534300    0.358725    0.084161    0.014404    0.674496    
#> 005: 0.468559    1.137643    3.525835    0.363179    0.099547    0.013684    0.605585    
#> 006: 0.413238    1.150398    3.524972    0.345020    0.094570    0.013000    0.567343    
#> 007: 0.393335    1.151012    3.528948    0.353247    0.089842    0.012350    0.564272    
#> 008: 0.372573    1.155620    3.517707    0.349068    0.085349    0.013960    0.543319    
#> 009: 0.387260    1.146331    3.523837    0.358855    0.081082    0.014100    0.546676    
#> 010: 0.402928    1.146987    3.526259    0.435768    0.077028    0.015075    0.546178    
#> 011: 0.454216    1.155682    3.528599    0.445330    0.080954    0.014321    0.542111    
#> 012: 0.446293    1.144379    3.529104    0.470855    0.079002    0.015518    0.531328    
#> 013: 0.394109    1.160532    3.516611    0.447312    0.075052    0.017439    0.538023    
#> 014: 0.424898    1.162665    3.519424    0.428794    0.084578    0.016567    0.546366    
#> 015: 0.428409    1.153877    3.532195    0.424550    0.083191    0.015965    0.523086    
#> 016: 0.437132    1.153825    3.534196    0.457162    0.079032    0.019271    0.520279    
#> 017: 0.423704    1.161983    3.534132    0.446999    0.075080    0.018307    0.501459    
#> 018: 0.428238    1.152095    3.530178    0.424649    0.077413    0.017634    0.498437    
#> 019: 0.417087    1.155941    3.540560    0.403417    0.073543    0.016753    0.499459    
#> 020: 0.423587    1.167906    3.528206    0.383246    0.069866    0.017527    0.504592    
#> 021: 0.427146    1.165099    3.533692    0.414417    0.066372    0.016651    0.485176    
#> 022: 0.444643    1.155782    3.557340    0.432549    0.063054    0.018432    0.488625    
#> 023: 0.508277    1.151687    3.556096    0.446687    0.059901    0.019214    0.507759    
#> 024: 0.487484    1.158272    3.543453    0.427052    0.056906    0.021640    0.503030    
#> 025: 0.458704    1.137762    3.538600    0.452449    0.054114    0.021936    0.502590    
#> 026: 0.425790    1.156378    3.524542    0.429826    0.056550    0.022976    0.511940    
#> 027: 0.425161    1.175763    3.518630    0.448114    0.053723    0.022307    0.519787    
#> 028: 0.460804    1.153411    3.534584    0.425708    0.051037    0.021399    0.512680    
#> 029: 0.449044    1.155091    3.535897    0.405394    0.054006    0.021138    0.511257    
#> 030: 0.434966    1.166639    3.525754    0.423351    0.062138    0.021047    0.513191    
#> 031: 0.399750    1.139959    3.533549    0.402184    0.059031    0.019995    0.510358    
#> 032: 0.418749    1.130404    3.540774    0.382074    0.068911    0.018995    0.507832    
#> 033: 0.423268    1.146425    3.533370    0.387584    0.065465    0.020364    0.514198    
#> 034: 0.437139    1.161159    3.539279    0.426126    0.068589    0.019346    0.513672    
#> 035: 0.411499    1.149108    3.527659    0.419407    0.065159    0.018378    0.503920    
#> 036: 0.414814    1.156347    3.527766    0.398436    0.061901    0.018457    0.510662    
#> 037: 0.426506    1.170979    3.528093    0.417453    0.058806    0.018316    0.525814    
#> 038: 0.409575    1.157097    3.524841    0.405263    0.055866    0.019269    0.512930    
#> 039: 0.422459    1.158572    3.533267    0.385000    0.059084    0.018996    0.508331    
#> 040: 0.432546    1.159541    3.546900    0.372279    0.056130    0.021361    0.526190    
#> 041: 0.427249    1.146677    3.541221    0.353665    0.062262    0.022091    0.522755    
#> 042: 0.469534    1.161009    3.541486    0.393899    0.063343    0.020986    0.500527    
#> 043: 0.439221    1.154517    3.536159    0.374204    0.060851    0.021888    0.504663    
#> 044: 0.430357    1.151448    3.538168    0.391196    0.067144    0.021647    0.509791    
#> 045: 0.427308    1.169663    3.528900    0.381818    0.064713    0.020565    0.519219    
#> 046: 0.414961    1.135163    3.530073    0.362727    0.064812    0.019537    0.515628    
#> 047: 0.426843    1.159077    3.525902    0.377427    0.061571    0.018560    0.522987    
#> 048: 0.414766    1.161404    3.521437    0.422342    0.058493    0.017632    0.517671    
#> 049: 0.409787    1.161562    3.522927    0.401225    0.067918    0.017260    0.511657    
#> 050: 0.433420    1.146474    3.528544    0.423243    0.071043    0.018871    0.518505    
#> 051: 0.420718    1.157569    3.523669    0.428483    0.067526    0.020492    0.519825    
#> 052: 0.442751    1.156989    3.538850    0.407059    0.064150    0.020867    0.511591    
#> 053: 0.430273    1.140386    3.536716    0.395499    0.068477    0.019837    0.513033    
#> 054: 0.440383    1.152560    3.535125    0.396568    0.065053    0.018846    0.523562    
#> 055: 0.425640    1.169615    3.531509    0.376740    0.064688    0.017903    0.515234    
#> 056: 0.433355    1.165020    3.528809    0.378579    0.074831    0.018567    0.532441    
#> 057: 0.437939    1.157470    3.541136    0.420278    0.071089    0.020705    0.531407    
#> 058: 0.437827    1.139279    3.531061    0.399264    0.067535    0.019670    0.537901    
#> 059: 0.423956    1.124973    3.537381    0.444899    0.064158    0.019497    0.531183    
#> 060: 0.433260    1.125354    3.537622    0.450130    0.060950    0.023599    0.525925    
#> 061: 0.472791    1.146406    3.552086    0.536536    0.059195    0.027599    0.530962    
#> 062: 0.472367    1.137976    3.550918    0.509710    0.056235    0.027389    0.533818    
#> 063: 0.501132    1.134081    3.549795    0.484224    0.053784    0.030494    0.534577    
#> 064: 0.462793    1.139847    3.548202    0.460013    0.060743    0.028969    0.536712    
#> 065: 0.463893    1.131210    3.536817    0.437012    0.057706    0.027521    0.517975    
#> 066: 0.455602    1.157499    3.539655    0.417373    0.059493    0.026145    0.516467    
#> 067: 0.453029    1.147062    3.542574    0.397037    0.059454    0.024837    0.503577    
#> 068: 0.416692    1.145402    3.538215    0.406382    0.065562    0.023595    0.512894    
#> 069: 0.419381    1.146157    3.529037    0.402663    0.062284    0.022606    0.518594    
#> 070: 0.434523    1.148193    3.545912    0.409758    0.059170    0.021476    0.521223    
#> 071: 0.410429    1.166440    3.521937    0.407347    0.061639    0.020742    0.509155    
#> 072: 0.421988    1.147710    3.530176    0.430558    0.058557    0.020912    0.506842    
#> 073: 0.441547    1.159048    3.540345    0.469462    0.055629    0.023141    0.508367    
#> 074: 0.449950    1.139385    3.535936    0.454522    0.057025    0.022534    0.509848    
#> 075: 0.452326    1.149648    3.543706    0.506549    0.055003    0.024392    0.513002    
#> 076: 0.436467    1.144286    3.541563    0.481221    0.052252    0.025567    0.508987    
#> 077: 0.448966    1.147649    3.532103    0.457160    0.055222    0.024289    0.512486    
#> 078: 0.424147    1.158257    3.536302    0.436233    0.052461    0.026136    0.498862    
#> 079: 0.421752    1.162259    3.534569    0.464294    0.049838    0.024829    0.509918    
#> 080: 0.438921    1.162834    3.529880    0.464138    0.057749    0.026395    0.506550    
#> 081: 0.438428    1.154505    3.530906    0.490480    0.058897    0.028266    0.504949    
#> 082: 0.431476    1.149803    3.539188    0.465956    0.067030    0.026853    0.511072    
#> 083: 0.428914    1.164254    3.519384    0.501859    0.068736    0.026236    0.521629    
#> 084: 0.411703    1.170602    3.520382    0.508618    0.068041    0.024924    0.519015    
#> 085: 0.409885    1.165835    3.531274    0.483187    0.070543    0.024177    0.521676    
#> 086: 0.432602    1.164069    3.530161    0.511399    0.067202    0.023246    0.512076    
#> 087: 0.412160    1.158717    3.521703    0.485829    0.065801    0.022084    0.504425    
#> 088: 0.368435    1.163144    3.526029    0.463264    0.062511    0.020980    0.519092    
#> 089: 0.380695    1.152481    3.509230    0.440101    0.065719    0.019931    0.522168    
#> 090: 0.401312    1.161978    3.510777    0.446151    0.066427    0.018934    0.526136    
#> 091: 0.397310    1.155600    3.513812    0.450293    0.063105    0.017988    0.528679    
#> 092: 0.408510    1.168586    3.512734    0.438821    0.069075    0.018620    0.508569    
#> 093: 0.394584    1.159478    3.517472    0.447532    0.073022    0.019112    0.515970    
#> 094: 0.392909    1.170919    3.510777    0.451376    0.069371    0.021739    0.510981    
#> 095: 0.379662    1.184922    3.513238    0.477529    0.065902    0.023197    0.507039    
#> 096: 0.398287    1.154414    3.515597    0.453653    0.062607    0.023604    0.500044    
#> 097: 0.385256    1.164237    3.511174    0.447786    0.064440    0.022424    0.499977    
#> 098: 0.407788    1.160047    3.523614    0.425397    0.061218    0.021303    0.515098    
#> 099: 0.425668    1.154550    3.523720    0.404127    0.061081    0.020238    0.509587    
#> 100: 0.410881    1.162792    3.533180    0.383921    0.058027    0.022355    0.503793    
#> 101: 0.400723    1.131826    3.520167    0.415725    0.060936    0.021332    0.506052    
#> 102: 0.400563    1.146814    3.514740    0.422969    0.071230    0.020856    0.501818    
#> 103: 0.412482    1.164092    3.526974    0.409612    0.068907    0.022942    0.500890    
#> 104: 0.407086    1.161765    3.540592    0.447454    0.071396    0.021795    0.512990    
#> 105: 0.432948    1.140738    3.537233    0.431225    0.067827    0.020705    0.516564    
#> 106: 0.418822    1.137423    3.530100    0.439445    0.069215    0.019670    0.506366    
#> 107: 0.430208    1.147939    3.532952    0.417473    0.071688    0.023902    0.507128    
#> 108: 0.468801    1.140075    3.549356    0.396599    0.068104    0.022707    0.517926    
#> 109: 0.459697    1.136381    3.560875    0.401834    0.064698    0.021571    0.529034    
#> 110: 0.453245    1.127964    3.549616    0.381743    0.070189    0.020706    0.522509    
#> 111: 0.441635    1.120807    3.550160    0.373284    0.066679    0.019670    0.507666    
#> 112: 0.436161    1.121840    3.536157    0.383511    0.063345    0.019295    0.510049    
#> 113: 0.433261    1.166311    3.542828    0.375297    0.061080    0.018705    0.503031    
#> 114: 0.440205    1.168273    3.544345    0.356532    0.060765    0.018473    0.513826    
#> 115: 0.455795    1.145565    3.543825    0.366858    0.065378    0.017833    0.524768    
#> 116: 0.445826    1.152348    3.534620    0.400203    0.062147    0.017985    0.516996    
#> 117: 0.437918    1.160755    3.539516    0.393014    0.065660    0.018173    0.512561    
#> 118: 0.464123    1.135700    3.543099    0.373363    0.062702    0.017265    0.518121    
#> 119: 0.450697    1.145425    3.544796    0.400399    0.059567    0.021225    0.507028    
#> 120: 0.417020    1.146125    3.537877    0.380379    0.058854    0.020164    0.506712    
#> 121: 0.426621    1.161070    3.535985    0.385902    0.055911    0.019522    0.506952    
#> 122: 0.456970    1.144623    3.548089    0.416768    0.063332    0.021702    0.503228    
#> 123: 0.488074    1.156126    3.540023    0.452341    0.062884    0.020617    0.506054    
#> 124: 0.473108    1.176535    3.543760    0.465696    0.069387    0.021225    0.504185    
#> 125: 0.465340    1.165032    3.538655    0.442411    0.065918    0.020164    0.512650    
#> 126: 0.427087    1.179160    3.525818    0.420291    0.062622    0.019431    0.509344    
#> 127: 0.431345    1.163575    3.523793    0.399276    0.059491    0.018459    0.518292    
#> 128: 0.423462    1.165860    3.532679    0.379312    0.062368    0.017536    0.519515    
#> 129: 0.434186    1.164202    3.531504    0.403948    0.065800    0.016660    0.517114    
#> 130: 0.451850    1.166133    3.528730    0.465543    0.062510    0.018470    0.510206    
#> 131: 0.431661    1.157387    3.522515    0.442266    0.059385    0.017879    0.518289    
#> 132: 0.378874    1.170673    3.503016    0.420152    0.064471    0.016985    0.521493    
#> 133: 0.418958    1.155429    3.526823    0.399145    0.061774    0.021457    0.521722    
#> 134: 0.437714    1.129447    3.550236    0.379188    0.058685    0.021247    0.513143    
#> 135: 0.458245    1.121612    3.561362    0.360228    0.059180    0.021548    0.509708    
#> 136: 0.446761    1.129039    3.554785    0.383733    0.056221    0.021583    0.513283    
#> 137: 0.484683    1.115655    3.558426    0.432936    0.056232    0.020504    0.522051    
#> 138: 0.459079    1.131899    3.554489    0.430405    0.060298    0.020403    0.522967    
#> 139: 0.450395    1.143471    3.552745    0.408885    0.057283    0.023088    0.528692    
#> 140: 0.468217    1.150513    3.554910    0.388441    0.054419    0.021934    0.533719    
#> 141: 0.446993    1.138747    3.547814    0.369019    0.061528    0.020837    0.524347    
#> 142: 0.448459    1.139918    3.549085    0.379803    0.062265    0.019795    0.526760    
#> 143: 0.429725    1.139940    3.548563    0.360813    0.059152    0.018806    0.523711    
#> 144: 0.477707    1.141887    3.558722    0.396891    0.059516    0.017865    0.506765    
#> 145: 0.447941    1.152434    3.545558    0.381389    0.059061    0.017457    0.501328    
#> 146: 0.458911    1.143921    3.545063    0.376078    0.056108    0.017522    0.511753    
#> 147: 0.406879    1.140658    3.531630    0.398456    0.054488    0.019326    0.501412    
#> 148: 0.423066    1.152760    3.540229    0.403002    0.066835    0.021049    0.495900    
#> 149: 0.427258    1.136434    3.541239    0.382852    0.068639    0.020188    0.510494    
#> 150: 0.449607    1.160384    3.526660    0.396599    0.072332    0.021294    0.532362    
#> 151: 0.419924    1.175232    3.535867    0.376769    0.068715    0.020229    0.520764    
#> 152: 0.418166    1.173037    3.534957    0.386355    0.059231    0.029101    0.500342    
#> 153: 0.422764    1.156570    3.539810    0.378062    0.066249    0.029756    0.510048    
#> 154: 0.443956    1.166279    3.535866    0.400555    0.057434    0.025334    0.521925    
#> 155: 0.412711    1.139550    3.533430    0.400979    0.074185    0.025344    0.509276    
#> 156: 0.428737    1.151142    3.537595    0.372058    0.078591    0.020869    0.538690    
#> 157: 0.433719    1.146106    3.540613    0.403646    0.073572    0.019484    0.536724    
#> 158: 0.443690    1.151954    3.538615    0.399208    0.074693    0.016873    0.530897    
#> 159: 0.409940    1.167109    3.540473    0.378094    0.078435    0.016309    0.520933    
#> 160: 0.435863    1.136724    3.551442    0.396474    0.079312    0.018604    0.522823    
#> 161: 0.428449    1.151061    3.542729    0.358984    0.069050    0.016116    0.518997    
#> 162: 0.413170    1.164671    3.523832    0.356293    0.071034    0.017226    0.525804    
#> 163: 0.437870    1.169112    3.526858    0.366899    0.061989    0.017337    0.522668    
#> 164: 0.422232    1.157391    3.531578    0.352603    0.056701    0.018914    0.517105    
#> 165: 0.433273    1.154073    3.530813    0.416454    0.068458    0.018542    0.520302    
#> 166: 0.448007    1.179170    3.532025    0.369402    0.061513    0.018937    0.535052    
#> 167: 0.465449    1.174594    3.544939    0.352188    0.060744    0.020471    0.533805    
#> 168: 0.464452    1.162402    3.559646    0.337801    0.053952    0.019473    0.529484    
#> 169: 0.473778    1.174139    3.545900    0.388717    0.065368    0.018606    0.522353    
#> 170: 0.467886    1.157882    3.545188    0.340848    0.063969    0.018717    0.508592    
#> 171: 0.440589    1.160636    3.540866    0.292211    0.065206    0.018773    0.503958    
#> 172: 0.408596    1.177902    3.536102    0.355189    0.057694    0.016848    0.499692    
#> 173: 0.423598    1.185717    3.528067    0.367133    0.060682    0.021503    0.487480    
#> 174: 0.432154    1.166812    3.535451    0.397829    0.066622    0.025828    0.501268    
#> 175: 0.424493    1.163750    3.526487    0.412835    0.070017    0.021374    0.495776    
#> 176: 0.444386    1.171147    3.530241    0.421848    0.065855    0.023086    0.492577    
#> 177: 0.469034    1.147085    3.544821    0.402681    0.063662    0.024056    0.501206    
#> 178: 0.457678    1.139733    3.541100    0.412853    0.053314    0.021812    0.508205    
#> 179: 0.470789    1.160202    3.534980    0.474375    0.057299    0.018828    0.522773    
#> 180: 0.432131    1.155312    3.534542    0.417010    0.062091    0.019121    0.525323    
#> 181: 0.432107    1.157985    3.520800    0.375051    0.059627    0.017273    0.531593    
#> 182: 0.404488    1.151752    3.518268    0.344826    0.062560    0.016619    0.534491    
#> 183: 0.412763    1.165774    3.524923    0.294968    0.071221    0.016040    0.539679    
#> 184: 0.411373    1.151526    3.530828    0.310210    0.066422    0.015678    0.542305    
#> 185: 0.402238    1.173232    3.518203    0.328116    0.074735    0.019598    0.527755    
#> 186: 0.401042    1.168851    3.527067    0.338297    0.067405    0.020100    0.521971    
#> 187: 0.420721    1.145534    3.548176    0.362516    0.067737    0.021615    0.501871    
#> 188: 0.418662    1.156635    3.540450    0.389579    0.064404    0.021470    0.493313    
#> 189: 0.411400    1.159291    3.540881    0.387273    0.061662    0.020917    0.501979    
#> 190: 0.439633    1.159505    3.538453    0.371101    0.052876    0.019204    0.508145    
#> 191: 0.411674    1.165279    3.527456    0.376137    0.048550    0.017531    0.512201    
#> 192: 0.420785    1.166235    3.531693    0.403403    0.062553    0.021103    0.493159    
#> 193: 0.462417    1.161612    3.543871    0.414389    0.063694    0.019078    0.496266    
#> 194: 0.434716    1.147004    3.530529    0.388610    0.062860    0.020422    0.503343    
#> 195: 0.420802    1.152534    3.524727    0.414365    0.052484    0.022591    0.507116    
#> 196: 0.413713    1.164018    3.525748    0.374724    0.053924    0.021227    0.517840    
#> 197: 0.388158    1.155530    3.534087    0.377310    0.060528    0.022183    0.526654    
#> 198: 0.453322    1.161484    3.533853    0.380414    0.057253    0.023838    0.514273    
#> 199: 0.425810    1.170249    3.525251    0.408448    0.065455    0.024021    0.510052    
#> 200: 0.393967    1.161767    3.521385    0.411310    0.067801    0.023342    0.523748    
#> 201: 0.400866    1.156214    3.527149    0.395668    0.064594    0.023598    0.515833    
#> 202: 0.397357    1.157779    3.528693    0.395508    0.061285    0.024376    0.512225    
#> 203: 0.410052    1.158764    3.528111    0.393704    0.059947    0.023839    0.511539    
#> 204: 0.416166    1.155925    3.529893    0.405326    0.058235    0.023319    0.510945    
#> 205: 0.419447    1.160743    3.530048    0.401324    0.057269    0.022946    0.515100    
#> 206: 0.422052    1.163710    3.531491    0.394675    0.057458    0.022647    0.514731    
#> 207: 0.427231    1.163737    3.531857    0.390732    0.058206    0.022389    0.513991    
#> 208: 0.430163    1.162891    3.532616    0.388855    0.058651    0.022400    0.513419    
#> 209: 0.434075    1.158861    3.534428    0.386078    0.058410    0.022109    0.513802    
#> 210: 0.437332    1.155560    3.536790    0.385866    0.059007    0.022145    0.513786    
#> 211: 0.440885    1.154191    3.537399    0.384537    0.058544    0.021953    0.513974    
#> 212: 0.442540    1.152537    3.538136    0.384111    0.058667    0.021713    0.513595    
#> 213: 0.444178    1.150534    3.539489    0.384179    0.058795    0.021541    0.512998    
#> 214: 0.446691    1.149356    3.540498    0.384854    0.059399    0.021495    0.512598    
#> 215: 0.447531    1.148642    3.541505    0.385390    0.059981    0.021473    0.512092    
#> 216: 0.450348    1.147064    3.542011    0.388154    0.060263    0.021488    0.512891    
#> 217: 0.450378    1.146715    3.542378    0.388774    0.060445    0.021423    0.512440    
#> 218: 0.450239    1.146794    3.542020    0.390711    0.060577    0.021253    0.512817    
#> 219: 0.447984    1.147036    3.541017    0.391635    0.060668    0.021068    0.513395    
#> 220: 0.445514    1.147182    3.540774    0.392956    0.061179    0.021003    0.513694    
#> 221: 0.444321    1.147145    3.540413    0.391800    0.061005    0.020755    0.513924    
#> 222: 0.443803    1.147708    3.540183    0.390043    0.061016    0.020611    0.514031    
#> 223: 0.444831    1.146788    3.540552    0.389988    0.060748    0.020633    0.513755    
#> 224: 0.446704    1.147187    3.540872    0.389853    0.060652    0.020627    0.513614    
#> 225: 0.445834    1.146012    3.541252    0.389828    0.060394    0.020688    0.514090    
#> 226: 0.446431    1.145538    3.541248    0.389598    0.059912    0.020698    0.514221    
#> 227: 0.447216    1.145242    3.541605    0.390204    0.059785    0.020710    0.514051    
#> 228: 0.447240    1.145756    3.541410    0.391147    0.060029    0.020723    0.513480    
#> 229: 0.446822    1.145848    3.541251    0.391253    0.060177    0.020735    0.513100    
#> 230: 0.447627    1.145616    3.541170    0.392605    0.060309    0.020609    0.513135    
#> 231: 0.447443    1.146354    3.541222    0.391794    0.060465    0.020493    0.513163    
#> 232: 0.446439    1.146799    3.541147    0.392305    0.060843    0.020535    0.512976    
#> 233: 0.446191    1.146737    3.541086    0.394250    0.060995    0.020498    0.513405    
#> 234: 0.445348    1.146891    3.540682    0.395842    0.061197    0.020529    0.513607    
#> 235: 0.444579    1.147262    3.540391    0.396678    0.061450    0.020460    0.513650    
#> 236: 0.443138    1.148015    3.539732    0.397461    0.061855    0.020311    0.513559    
#> 237: 0.442220    1.148158    3.539334    0.398508    0.062145    0.020186    0.514063    
#> 238: 0.441559    1.148180    3.539053    0.399497    0.062067    0.020095    0.514317    
#> 239: 0.440910    1.148719    3.538754    0.398739    0.062062    0.020040    0.514324    
#> 240: 0.440411    1.148830    3.538872    0.396956    0.062059    0.019926    0.514704    
#> 241: 0.440510    1.148406    3.538987    0.395711    0.062057    0.019860    0.514912    
#> 242: 0.440089    1.147849    3.538857    0.396538    0.061981    0.019788    0.515355    
#> 243: 0.440036    1.147771    3.538816    0.397129    0.061959    0.019730    0.515697    
#> 244: 0.439923    1.147630    3.538919    0.397016    0.061951    0.019695    0.515989    
#> 245: 0.440819    1.146904    3.539255    0.397730    0.062182    0.019694    0.516432    
#> 246: 0.441406    1.146548    3.539349    0.398269    0.062134    0.019718    0.516562    
#> 247: 0.441454    1.146253    3.539517    0.398380    0.062235    0.019735    0.516570    
#> 248: 0.441155    1.146559    3.539352    0.397812    0.062362    0.019732    0.516452    
#> 249: 0.440421    1.146802    3.539272    0.397337    0.062368    0.019684    0.516324    
#> 250: 0.440347    1.147225    3.539133    0.397103    0.062368    0.019662    0.516229    
#> 251: 0.440469    1.147528    3.539281    0.397494    0.062491    0.019598    0.516113    
#> 252: 0.440820    1.147685    3.539575    0.398492    0.062665    0.019543    0.515935    
#> 253: 0.440538    1.147808    3.539651    0.398771    0.062723    0.019524    0.515833    
#> 254: 0.440667    1.148228    3.539584    0.398982    0.062786    0.019562    0.515890    
#> 255: 0.440626    1.148581    3.539592    0.399322    0.062895    0.019620    0.515804    
#> 256: 0.440745    1.148592    3.539576    0.399923    0.062971    0.019671    0.515799    
#> 257: 0.440163    1.148386    3.539369    0.399872    0.062857    0.019702    0.515794    
#> 258: 0.439738    1.148398    3.539237    0.400889    0.062734    0.019724    0.515727    
#> 259: 0.439602    1.148564    3.539234    0.401461    0.062656    0.019792    0.515604    
#> 260: 0.439600    1.148700    3.539212    0.401350    0.062685    0.019821    0.515273    
#> 261: 0.440002    1.148684    3.539279    0.401851    0.062752    0.019824    0.515000    
#> 262: 0.440062    1.148875    3.539242    0.401224    0.062770    0.019837    0.514868    
#> 263: 0.439857    1.149247    3.539074    0.401217    0.062891    0.019898    0.514876    
#> 264: 0.439602    1.149444    3.539025    0.401502    0.063241    0.019901    0.515153    
#> 265: 0.439363    1.149653    3.538928    0.401414    0.063548    0.019959    0.515292    
#> 266: 0.439494    1.149818    3.538923    0.400920    0.063680    0.020008    0.515289    
#> 267: 0.439785    1.149739    3.539046    0.401358    0.063708    0.020042    0.515131    
#> 268: 0.439778    1.149606    3.538996    0.401763    0.063677    0.020013    0.515035    
#> 269: 0.440469    1.149353    3.539087    0.401981    0.063718    0.019993    0.515108    
#> 270: 0.440450    1.149341    3.538998    0.401864    0.063695    0.019948    0.514916    
#> 271: 0.440572    1.149353    3.538926    0.402218    0.063674    0.019911    0.514947    
#> 272: 0.440981    1.149119    3.539134    0.401661    0.063596    0.019934    0.515183    
#> 273: 0.441110    1.149165    3.539288    0.401370    0.063677    0.019979    0.515343    
#> 274: 0.441378    1.149258    3.539407    0.401891    0.063646    0.020026    0.515424    
#> 275: 0.441371    1.149313    3.539426    0.401507    0.063638    0.020026    0.515435    
#> 276: 0.441087    1.149550    3.539449    0.401192    0.063702    0.020030    0.515515    
#> 277: 0.440737    1.149963    3.539454    0.400926    0.063805    0.020040    0.515486    
#> 278: 0.440720    1.150009    3.539519    0.401181    0.063825    0.020020    0.515567    
#> 279: 0.440484    1.150067    3.539368    0.401617    0.063972    0.020020    0.515460    
#> 280: 0.440298    1.150322    3.539174    0.402200    0.064041    0.020022    0.515182    
#> 281: 0.440002    1.150615    3.539023    0.402743    0.064130    0.020000    0.515050    
#> 282: 0.439947    1.150918    3.538902    0.402907    0.064335    0.019974    0.515089    
#> 283: 0.439578    1.151090    3.538725    0.403839    0.064429    0.019925    0.515335    
#> 284: 0.438982    1.151067    3.538533    0.404702    0.064476    0.019909    0.515534    
#> 285: 0.438404    1.151064    3.538370    0.404839    0.064627    0.019875    0.515685    
#> 286: 0.437945    1.151103    3.538140    0.404990    0.064792    0.019851    0.515751    
#> 287: 0.438004    1.151049    3.538148    0.404483    0.064890    0.019852    0.515801    
#> 288: 0.438049    1.151003    3.538177    0.404235    0.064910    0.019894    0.515939    
#> 289: 0.437908    1.150932    3.538197    0.403887    0.064819    0.019902    0.515931    
#> 290: 0.438188    1.150788    3.538249    0.403987    0.064892    0.019890    0.516012    
#> 291: 0.438181    1.150803    3.538302    0.403588    0.064896    0.019918    0.515923    
#> 292: 0.438340    1.150721    3.538344    0.403371    0.064822    0.019949    0.515884    
#> 293: 0.438354    1.150654    3.538333    0.402978    0.064801    0.020000    0.515816    
#> 294: 0.438292    1.150709    3.538284    0.403251    0.064807    0.020044    0.515771    
#> 295: 0.438091    1.150584    3.538316    0.403382    0.064832    0.020075    0.515703    
#> 296: 0.438061    1.150548    3.538219    0.403206    0.064821    0.020103    0.515679    
#> 297: 0.438051    1.150677    3.538225    0.403071    0.064816    0.020069    0.515761    
#> 298: 0.437981    1.150600    3.538149    0.402948    0.064800    0.020036    0.515689    
#> 299: 0.438000    1.150669    3.538070    0.402729    0.064759    0.020001    0.515496    
#> 300: 0.438243    1.150535    3.538132    0.403136    0.064677    0.019994    0.515456    
#> 301: 0.438500    1.150436    3.538152    0.403078    0.064622    0.019993    0.515676    
#> 302: 0.438594    1.150506    3.538118    0.402994    0.064604    0.019972    0.515706    
#> 303: 0.438429    1.150645    3.538077    0.402583    0.064619    0.019953    0.515616    
#> 304: 0.438341    1.150930    3.537968    0.402460    0.064711    0.019933    0.515545    
#> 305: 0.438101    1.150985    3.537821    0.402496    0.064683    0.019935    0.515520    
#> 306: 0.437696    1.151015    3.537704    0.402540    0.064615    0.019950    0.515418    
#> 307: 0.437250    1.150925    3.537518    0.402787    0.064577    0.019976    0.515373    
#> 308: 0.436765    1.150820    3.537340    0.403077    0.064478    0.020018    0.515267    
#> 309: 0.436593    1.150676    3.537276    0.403802    0.064462    0.020066    0.515312    
#> 310: 0.436618    1.150516    3.537213    0.404775    0.064381    0.020082    0.515360    
#> 311: 0.436670    1.150438    3.537159    0.405486    0.064302    0.020117    0.515301    
#> 312: 0.436721    1.150262    3.537117    0.406254    0.064166    0.020175    0.515264    
#> 313: 0.436589    1.150082    3.536985    0.407079    0.063993    0.020218    0.515281    
#> 314: 0.436337    1.150077    3.536900    0.407447    0.063898    0.020262    0.515280    
#> 315: 0.436150    1.150163    3.536769    0.407682    0.063949    0.020284    0.515180    
#> 316: 0.436189    1.150142    3.536728    0.407522    0.063949    0.020313    0.515065    
#> 317: 0.436516    1.150065    3.536832    0.408030    0.063896    0.020337    0.515121    
#> 318: 0.436807    1.150178    3.536781    0.408386    0.063921    0.020317    0.515138    
#> 319: 0.436855    1.150184    3.536824    0.408731    0.063920    0.020342    0.515148    
#> 320: 0.436537    1.150089    3.536734    0.408884    0.063928    0.020334    0.515253    
#> 321: 0.436179    1.150150    3.536618    0.408983    0.063857    0.020322    0.515301    
#> 322: 0.435794    1.150104    3.536483    0.408754    0.063870    0.020308    0.515322    
#> 323: 0.435529    1.150042    3.536423    0.408699    0.063915    0.020313    0.515243    
#> 324: 0.435516    1.149938    3.536473    0.408787    0.063951    0.020313    0.515234    
#> 325: 0.435545    1.149988    3.536417    0.408467    0.063943    0.020296    0.515254    
#> 326: 0.435333    1.149966    3.536364    0.408188    0.063979    0.020286    0.515222    
#> 327: 0.435204    1.149965    3.536314    0.407992    0.064047    0.020267    0.515322    
#> 328: 0.435359    1.150054    3.536296    0.408109    0.064060    0.020249    0.515305    
#> 329: 0.435544    1.150222    3.536314    0.408393    0.064073    0.020226    0.515200    
#> 330: 0.435273    1.150354    3.536280    0.408790    0.064091    0.020223    0.514987    
#> 331: 0.435282    1.150478    3.536300    0.408760    0.064107    0.020231    0.514857    
#> 332: 0.435334    1.150594    3.536297    0.408841    0.064133    0.020230    0.514828    
#> 333: 0.435297    1.150662    3.536239    0.408741    0.064160    0.020198    0.514744    
#> 334: 0.435133    1.150592    3.536156    0.408734    0.064197    0.020161    0.514793    
#> 335: 0.434953    1.150666    3.536097    0.408892    0.064216    0.020137    0.514751    
#> 336: 0.434661    1.150886    3.536003    0.409260    0.064300    0.020126    0.514721    
#> 337: 0.434294    1.151300    3.535798    0.409915    0.064352    0.020114    0.514717    
#> 338: 0.433971    1.151536    3.535658    0.410248    0.064406    0.020089    0.514774    
#> 339: 0.433519    1.151774    3.535474    0.410429    0.064554    0.020046    0.514709    
#> 340: 0.433314    1.151798    3.535381    0.410675    0.064668    0.020003    0.514787    
#> 341: 0.433212    1.151954    3.535337    0.410846    0.064807    0.019969    0.514844    
#> 342: 0.433035    1.151925    3.535313    0.411072    0.064873    0.019931    0.514829    
#> 343: 0.432922    1.151990    3.535291    0.410954    0.064935    0.019903    0.514817    
#> 344: 0.432744    1.152019    3.535278    0.410554    0.064957    0.019861    0.514838    
#> 345: 0.432570    1.152014    3.535279    0.410576    0.064979    0.019837    0.514957    
#> 346: 0.432353    1.152132    3.535158    0.410838    0.065052    0.019801    0.514917    
#> 347: 0.432293    1.152155    3.535050    0.411377    0.065068    0.019788    0.515033    
#> 348: 0.431755    1.152346    3.534890    0.411413    0.065116    0.019792    0.515091    
#> 349: 0.431473    1.152328    3.534738    0.411567    0.065106    0.019803    0.515120    
#> 350: 0.431221    1.152421    3.534595    0.411667    0.065175    0.019805    0.515109    
#> 351: 0.431061    1.152561    3.534399    0.411906    0.065170    0.019815    0.515173    
#> 352: 0.430885    1.152737    3.534332    0.412031    0.065170    0.019816    0.515186    
#> 353: 0.430811    1.152881    3.534266    0.412371    0.065145    0.019824    0.515168    
#> 354: 0.430586    1.152966    3.534149    0.412490    0.065177    0.019800    0.515241    
#> 355: 0.430695    1.152919    3.534098    0.412696    0.065193    0.019782    0.515277    
#> 356: 0.430571    1.152898    3.534089    0.412775    0.065204    0.019755    0.515252    
#> 357: 0.430568    1.152914    3.534107    0.412496    0.065247    0.019736    0.515203    
#> 358: 0.430476    1.152995    3.534102    0.412233    0.065242    0.019707    0.515148    
#> 359: 0.430484    1.153048    3.534100    0.411953    0.065311    0.019673    0.515105    
#> 360: 0.430380    1.153022    3.534079    0.411840    0.065311    0.019655    0.515053    
#> 361: 0.430410    1.153031    3.534100    0.411525    0.065358    0.019626    0.515103    
#> 362: 0.430471    1.153048    3.534129    0.411306    0.065382    0.019604    0.514968    
#> 363: 0.430344    1.153053    3.534111    0.411212    0.065407    0.019575    0.514911    
#> 364: 0.430452    1.152983    3.534161    0.411065    0.065464    0.019591    0.514888    
#> 365: 0.430457    1.152844    3.534213    0.410945    0.065507    0.019593    0.514871    
#> 366: 0.430394    1.152805    3.534187    0.410750    0.065556    0.019589    0.514915    
#> 367: 0.430458    1.152777    3.534148    0.410755    0.065548    0.019603    0.514913    
#> 368: 0.430583    1.152819    3.534109    0.411071    0.065500    0.019618    0.514905    
#> 369: 0.430427    1.152832    3.534069    0.410975    0.065436    0.019620    0.514997    
#> 370: 0.430387    1.152900    3.534013    0.410739    0.065446    0.019635    0.515013    
#> 371: 0.430310    1.152985    3.533937    0.410487    0.065472    0.019629    0.515022    
#> 372: 0.430056    1.153078    3.533820    0.410344    0.065498    0.019620    0.515007    
#> 373: 0.429738    1.153215    3.533722    0.410387    0.065504    0.019615    0.515048    
#> 374: 0.429728    1.153237    3.533673    0.410472    0.065448    0.019624    0.515052    
#> 375: 0.429672    1.153299    3.533630    0.410531    0.065402    0.019645    0.515049    
#> 376: 0.429715    1.153364    3.533606    0.410874    0.065361    0.019647    0.515001    
#> 377: 0.429765    1.153535    3.533559    0.411118    0.065347    0.019659    0.514951    
#> 378: 0.429517    1.153608    3.533450    0.411272    0.065307    0.019675    0.514967    
#> 379: 0.429363    1.153604    3.533351    0.411594    0.065260    0.019673    0.514905    
#> 380: 0.429325    1.153532    3.533352    0.411755    0.065198    0.019683    0.514853    
#> 381: 0.429165    1.153512    3.533291    0.411929    0.065233    0.019694    0.514787    
#> 382: 0.428960    1.153632    3.533172    0.412383    0.065184    0.019682    0.514719    
#> 383: 0.428761    1.153647    3.533097    0.412518    0.065160    0.019678    0.514695    
#> 384: 0.428578    1.153635    3.533092    0.412292    0.065173    0.019678    0.514628    
#> 385: 0.428633    1.153666    3.533099    0.412053    0.065174    0.019661    0.514576    
#> 386: 0.428765    1.153833    3.533115    0.411956    0.065151    0.019653    0.514562    
#> 387: 0.428829    1.153924    3.533161    0.411913    0.065125    0.019656    0.514532    
#> 388: 0.428938    1.153943    3.533235    0.411670    0.065167    0.019646    0.514477    
#> 389: 0.429043    1.153860    3.533253    0.411619    0.065181    0.019643    0.514492    
#> 390: 0.428983    1.153950    3.533225    0.411574    0.065236    0.019634    0.514561    
#> 391: 0.429156    1.153929    3.533255    0.411698    0.065242    0.019633    0.514554    
#> 392: 0.429292    1.153896    3.533321    0.411834    0.065234    0.019635    0.514586    
#> 393: 0.429380    1.153823    3.533335    0.411926    0.065247    0.019636    0.514612    
#> 394: 0.429565    1.153797    3.533336    0.411938    0.065232    0.019632    0.514682    
#> 395: 0.429663    1.153909    3.533318    0.411842    0.065214    0.019646    0.514674    
#> 396: 0.429682    1.154015    3.533319    0.411937    0.065169    0.019657    0.514668    
#> 397: 0.429758    1.154021    3.533348    0.411913    0.065134    0.019673    0.514620    
#> 398: 0.429833    1.154015    3.533352    0.411744    0.065075    0.019684    0.514639    
#> 399: 0.429828    1.154040    3.533381    0.411574    0.065024    0.019699    0.514615    
#> 400: 0.429859    1.154061    3.533370    0.411659    0.065004    0.019706    0.514536    
#> 401: 0.429950    1.154113    3.533356    0.411531    0.065029    0.019700    0.514531    
#> 402: 0.430142    1.154161    3.533408    0.411366    0.065072    0.019687    0.514554    
#> 403: 0.430370    1.154121    3.533433    0.411260    0.065129    0.019658    0.514596    
#> 404: 0.430341    1.154107    3.533380    0.411131    0.065125    0.019641    0.514601    
#> 405: 0.430242    1.154165    3.533360    0.411264    0.065113    0.019628    0.514604    
#> 406: 0.430388    1.154146    3.533358    0.411316    0.065048    0.019633    0.514653    
#> 407: 0.430371    1.154143    3.533409    0.411121    0.065006    0.019635    0.514682    
#> 408: 0.430563    1.154157    3.533433    0.411093    0.065024    0.019627    0.514738    
#> 409: 0.430645    1.154132    3.533423    0.411060    0.064977    0.019620    0.514755    
#> 410: 0.430647    1.154148    3.533383    0.410989    0.064918    0.019616    0.514810    
#> 411: 0.430693    1.154011    3.533390    0.410792    0.064844    0.019622    0.514940    
#> 412: 0.430737    1.154047    3.533377    0.410844    0.064799    0.019619    0.514974    
#> 413: 0.430749    1.154103    3.533389    0.410657    0.064753    0.019628    0.515031    
#> 414: 0.430587    1.154105    3.533377    0.410441    0.064718    0.019616    0.514987    
#> 415: 0.430610    1.154157    3.533371    0.410383    0.064741    0.019605    0.514921    
#> 416: 0.430632    1.154202    3.533394    0.410400    0.064724    0.019602    0.514912    
#> 417: 0.430677    1.154199    3.533421    0.410378    0.064695    0.019601    0.514894    
#> 418: 0.430619    1.154179    3.533450    0.410432    0.064636    0.019609    0.514834    
#> 419: 0.430689    1.154195    3.533457    0.410327    0.064613    0.019610    0.514797    
#> 420: 0.430704    1.154236    3.533456    0.410190    0.064633    0.019602    0.514696    
#> 421: 0.430637    1.154302    3.533483    0.410154    0.064620    0.019602    0.514640    
#> 422: 0.430777    1.154292    3.533515    0.410174    0.064614    0.019591    0.514620    
#> 423: 0.430860    1.154287    3.533518    0.410232    0.064652    0.019590    0.514611    
#> 424: 0.430832    1.154275    3.533504    0.410387    0.064674    0.019581    0.514573    
#> 425: 0.430871    1.154297    3.533488    0.410611    0.064646    0.019581    0.514592    
#> 426: 0.430879    1.154400    3.533489    0.410702    0.064654    0.019583    0.514522    
#> 427: 0.430747    1.154443    3.533507    0.410723    0.064642    0.019577    0.514450    
#> 428: 0.430720    1.154508    3.533507    0.410813    0.064657    0.019574    0.514438    
#> 429: 0.430717    1.154543    3.533540    0.410803    0.064627    0.019575    0.514385    
#> 430: 0.430569    1.154579    3.533494    0.410808    0.064573    0.019568    0.514448    
#> 431: 0.430423    1.154645    3.533401    0.410787    0.064574    0.019554    0.514412    
#> 432: 0.430128    1.154780    3.533319    0.410825    0.064571    0.019555    0.514365    
#> 433: 0.429881    1.154876    3.533270    0.410793    0.064554    0.019565    0.514354    
#> 434: 0.429570    1.154884    3.533187    0.410686    0.064516    0.019559    0.514353    
#> 435: 0.429470    1.154904    3.533095    0.410791    0.064472    0.019575    0.514389    
#> 436: 0.429327    1.154942    3.533055    0.411038    0.064481    0.019571    0.514452    
#> 437: 0.429321    1.154917    3.532974    0.411239    0.064489    0.019561    0.514496    
#> 438: 0.429195    1.154993    3.532944    0.411260    0.064494    0.019556    0.514527    
#> 439: 0.429156    1.155083    3.532933    0.411275    0.064486    0.019556    0.514476    
#> 440: 0.429163    1.155101    3.532966    0.411361    0.064445    0.019575    0.514449    
#> 441: 0.429200    1.155098    3.532977    0.411457    0.064402    0.019600    0.514438    
#> 442: 0.429062    1.155131    3.532958    0.411383    0.064365    0.019624    0.514401    
#> 443: 0.428899    1.155246    3.532849    0.411157    0.064355    0.019633    0.514378    
#> 444: 0.428716    1.155361    3.532754    0.411254    0.064344    0.019654    0.514355    
#> 445: 0.428666    1.155391    3.532722    0.411324    0.064345    0.019679    0.514366    
#> 446: 0.428464    1.155459    3.532651    0.411277    0.064333    0.019691    0.514377    
#> 447: 0.428501    1.155521    3.532619    0.411449    0.064343    0.019696    0.514395    
#> 448: 0.428417    1.155594    3.532622    0.411442    0.064328    0.019710    0.514340    
#> 449: 0.428472    1.155637    3.532684    0.411401    0.064337    0.019724    0.514327    
#> 450: 0.428392    1.155634    3.532670    0.411142    0.064352    0.019730    0.514351    
#> 451: 0.428413    1.155595    3.532699    0.410960    0.064340    0.019735    0.514376    
#> 452: 0.428349    1.155593    3.532671    0.410857    0.064310    0.019747    0.514337    
#> 453: 0.428365    1.155624    3.532669    0.410827    0.064291    0.019758    0.514254    
#> 454: 0.428324    1.155738    3.532638    0.410904    0.064266    0.019773    0.514202    
#> 455: 0.428294    1.155878    3.532570    0.410945    0.064278    0.019791    0.514160    
#> 456: 0.428163    1.155914    3.532526    0.410998    0.064268    0.019798    0.514160    
#> 457: 0.428120    1.155956    3.532534    0.411001    0.064314    0.019796    0.514146    
#> 458: 0.428075    1.156023    3.532548    0.411079    0.064339    0.019796    0.514118    
#> 459: 0.427997    1.156093    3.532554    0.411161    0.064351    0.019805    0.514118    
#> 460: 0.427926    1.156139    3.532496    0.411186    0.064348    0.019821    0.514104    
#> 461: 0.427857    1.156173    3.532471    0.411170    0.064374    0.019820    0.514078    
#> 462: 0.427721    1.156238    3.532425    0.411063    0.064367    0.019812    0.514055    
#> 463: 0.427647    1.156330    3.532399    0.411098    0.064353    0.019809    0.514069    
#> 464: 0.427702    1.156430    3.532353    0.411155    0.064376    0.019805    0.514009    
#> 465: 0.427705    1.156371    3.532355    0.411180    0.064389    0.019798    0.513976    
#> 466: 0.427727    1.156392    3.532353    0.411148    0.064388    0.019800    0.513960    
#> 467: 0.427696    1.156313    3.532405    0.411103    0.064345    0.019805    0.513908    
#> 468: 0.427828    1.156312    3.532458    0.411195    0.064320    0.019824    0.513853    
#> 469: 0.427997    1.156388    3.532509    0.411280    0.064304    0.019833    0.513875    
#> 470: 0.428049    1.156367    3.532523    0.411298    0.064254    0.019846    0.513910    
#> 471: 0.428157    1.156307    3.532566    0.411325    0.064244    0.019861    0.513882    
#> 472: 0.428257    1.156263    3.532603    0.411286    0.064225    0.019866    0.513844    
#> 473: 0.428251    1.156231    3.532617    0.411030    0.064226    0.019857    0.513809    
#> 474: 0.428247    1.156205    3.532636    0.410887    0.064250    0.019856    0.513844    
#> 475: 0.428270    1.156248    3.532645    0.410660    0.064289    0.019840    0.513866    
#> 476: 0.428208    1.156248    3.532662    0.410604    0.064292    0.019826    0.513924    
#> 477: 0.428143    1.156257    3.532685    0.410511    0.064300    0.019820    0.513909    
#> 478: 0.428121    1.156294    3.532698    0.410440    0.064287    0.019818    0.513928    
#> 479: 0.428148    1.156348    3.532727    0.410306    0.064258    0.019824    0.513915    
#> 480: 0.428169    1.156355    3.532720    0.410391    0.064264    0.019821    0.513914    
#> 481: 0.428226    1.156403    3.532729    0.410352    0.064242    0.019817    0.513948    
#> 482: 0.428291    1.156419    3.532725    0.410498    0.064231    0.019814    0.513961    
#> 483: 0.428281    1.156406    3.532727    0.410500    0.064235    0.019811    0.513930    
#> 484: 0.428337    1.156325    3.532760    0.410496    0.064235    0.019810    0.513900    
#> 485: 0.428433    1.156338    3.532767    0.410578    0.064242    0.019812    0.513916    
#> 486: 0.428550    1.156374    3.532797    0.410652    0.064235    0.019810    0.513883    
#> 487: 0.428725    1.156345    3.532866    0.410648    0.064252    0.019807    0.513859    
#> 488: 0.428856    1.156335    3.532911    0.410637    0.064245    0.019796    0.513838    
#> 489: 0.429082    1.156293    3.532951    0.410808    0.064263    0.019787    0.513822    
#> 490: 0.429187    1.156241    3.533019    0.411010    0.064290    0.019791    0.513772    
#> 491: 0.429288    1.156225    3.533062    0.411018    0.064283    0.019788    0.513686    
#> 492: 0.429339    1.156243    3.533072    0.411045    0.064242    0.019791    0.513705    
#> 493: 0.429354    1.156234    3.533109    0.411076    0.064219    0.019792    0.513712    
#> 494: 0.429469    1.156257    3.533098    0.410957    0.064177    0.019798    0.513701    
#> 495: 0.429545    1.156251    3.533087    0.410847    0.064179    0.019791    0.513690    
#> 496: 0.429692    1.156272    3.533090    0.410673    0.064142    0.019783    0.513723    
#> 497: 0.429739    1.156233    3.533139    0.410495    0.064143    0.019772    0.513721    
#> 498: 0.429737    1.156174    3.533152    0.410309    0.064131    0.019767    0.513704    
#> 499: 0.429735    1.156166    3.533132    0.410341    0.064096    0.019758    0.513669    
#> 500: 0.429772    1.156102    3.533118    0.410211    0.064086    0.019751    0.513657    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.332025    0.969206    3.444514    0.392401    0.084945    0.016800    1.726809    
#> 002: 0.373816    0.960924    3.442543    0.372781    0.080698    0.015960    1.162631    
#> 003: 0.438902    0.889846    3.433281    0.354142    0.076663    0.015162    0.925857    
#> 004: 0.390370    0.910123    3.424035    0.336435    0.072830    0.014404    0.884908    
#> 005: 0.425646    0.933260    3.409744    0.319613    0.069188    0.013684    0.825232    
#> 006: 0.378807    0.924481    3.395389    0.303633    0.068188    0.013000    0.744830    
#> 007: 0.315116    0.924762    3.381426    0.288451    0.064778    0.013805    0.742554    
#> 008: 0.313009    0.924798    3.373151    0.274029    0.061539    0.015173    0.754503    
#> 009: 0.287907    0.925976    3.366028    0.260327    0.058462    0.014727    0.735891    
#> 010: 0.302860    0.936368    3.366850    0.247311    0.055539    0.019371    0.740446    
#> 011: 0.358249    0.931983    3.374516    0.234945    0.052762    0.019964    0.750427    
#> 012: 0.375647    0.923969    3.375979    0.223198    0.050423    0.018966    0.744262    
#> 013: 0.300128    0.934672    3.364550    0.213849    0.059805    0.018018    0.728671    
#> 014: 0.332362    0.929973    3.370657    0.203156    0.056815    0.017117    0.763389    
#> 015: 0.350420    0.940250    3.383623    0.192999    0.053974    0.016261    0.736622    
#> 016: 0.333225    0.961319    3.379201    0.183349    0.051275    0.015448    0.766841    
#> 017: 0.328068    0.950036    3.379981    0.190430    0.053670    0.018616    0.726014    
#> 018: 0.315273    0.959624    3.367596    0.182786    0.061716    0.017686    0.734237    
#> 019: 0.287521    0.952470    3.364100    0.173647    0.058630    0.016801    0.729890    
#> 020: 0.330109    0.939198    3.374171    0.184904    0.055699    0.016102    0.740409    
#> 021: 0.333345    0.931756    3.382236    0.184969    0.052914    0.015297    0.717420    
#> 022: 0.321554    0.924982    3.387272    0.175720    0.050268    0.014532    0.745787    
#> 023: 0.366879    0.917884    3.395060    0.166934    0.049001    0.013806    0.769345    
#> 024: 0.401911    0.940728    3.397349    0.173250    0.048091    0.013115    0.777519    
#> 025: 0.366825    0.932944    3.390680    0.165152    0.049212    0.013907    0.768264    
#> 026: 0.315547    0.974366    3.360514    0.156895    0.053103    0.014134    0.762139    
#> 027: 0.296458    0.971478    3.365260    0.192020    0.050448    0.019549    0.762941    
#> 028: 0.334253    0.977122    3.366450    0.187450    0.047947    0.018572    0.746043    
#> 029: 0.315581    0.972167    3.351864    0.178078    0.049338    0.017643    0.769798    
#> 030: 0.295510    0.981877    3.350456    0.191557    0.046871    0.016761    0.756306    
#> 031: 0.284914    0.968823    3.359105    0.195191    0.044528    0.018343    0.747049    
#> 032: 0.271706    0.976637    3.360924    0.198986    0.050024    0.017425    0.736568    
#> 033: 0.248667    0.986944    3.341196    0.189036    0.051940    0.016554    0.754417    
#> 034: 0.259059    0.981426    3.333393    0.179585    0.049343    0.015726    0.741302    
#> 035: 0.249753    0.973625    3.336728    0.170605    0.046875    0.014940    0.743112    
#> 036: 0.254849    0.986722    3.336882    0.162075    0.064764    0.014193    0.751018    
#> 037: 0.263144    0.973193    3.345639    0.174942    0.061525    0.014182    0.750982    
#> 038: 0.295477    0.971872    3.350193    0.179329    0.065751    0.014744    0.761744    
#> 039: 0.308915    0.961150    3.368180    0.170362    0.062464    0.016068    0.743765    
#> 040: 0.318809    0.954184    3.372044    0.189527    0.059341    0.016110    0.754366    
#> 041: 0.283719    0.961448    3.353318    0.180051    0.057525    0.015304    0.745392    
#> 042: 0.321076    0.959135    3.355972    0.171048    0.054651    0.014539    0.733488    
#> 043: 0.256098    0.968277    3.347186    0.164661    0.051918    0.013812    0.759384    
#> 044: 0.250633    0.982834    3.352274    0.156428    0.050519    0.013797    0.750475    
#> 045: 0.277398    1.007079    3.348308    0.148607    0.048903    0.014526    0.755071    
#> 046: 0.291136    0.973570    3.361693    0.156547    0.053266    0.014457    0.737844    
#> 047: 0.294493    0.973612    3.359815    0.162449    0.063106    0.017159    0.738249    
#> 048: 0.330206    0.955270    3.364367    0.179576    0.059951    0.020034    0.725542    
#> 049: 0.320710    0.956187    3.376675    0.175889    0.056953    0.019032    0.725905    
#> 050: 0.377116    0.915973    3.386893    0.167095    0.054106    0.018376    0.731965    
#> 051: 0.349671    0.927187    3.386898    0.166054    0.051400    0.017457    0.740592    
#> 052: 0.359672    0.942168    3.396596    0.157751    0.052291    0.016584    0.731513    
#> 053: 0.381310    0.929769    3.384867    0.188932    0.050199    0.015755    0.731820    
#> 054: 0.321371    0.931207    3.385758    0.181837    0.058051    0.015798    0.727424    
#> 055: 0.330804    0.925493    3.378613    0.192457    0.055148    0.015008    0.746931    
#> 056: 0.327945    0.924055    3.374398    0.205244    0.058345    0.019587    0.734680    
#> 057: 0.361923    0.924693    3.389533    0.214840    0.055427    0.021578    0.746383    
#> 058: 0.336757    0.938254    3.365954    0.247259    0.052656    0.020499    0.754090    
#> 059: 0.319675    0.930209    3.369867    0.234896    0.064284    0.019474    0.761071    
#> 060: 0.321011    0.918789    3.380966    0.223151    0.065905    0.020363    0.758135    
#> 061: 0.345515    0.919832    3.377302    0.211993    0.076317    0.021715    0.770168    
#> 062: 0.315309    0.965384    3.381602    0.201394    0.080219    0.020630    0.765572    
#> 063: 0.345020    0.943663    3.371357    0.203637    0.076208    0.019598    0.775832    
#> 064: 0.330984    0.941224    3.374774    0.193455    0.072397    0.018618    0.748993    
#> 065: 0.355935    0.938773    3.367767    0.183782    0.068777    0.017687    0.759175    
#> 066: 0.326663    0.947637    3.377369    0.174593    0.065339    0.016803    0.738239    
#> 067: 0.327974    0.942225    3.366333    0.165864    0.062072    0.015963    0.752110    
#> 068: 0.283082    0.951043    3.375622    0.157570    0.058968    0.015165    0.767599    
#> 069: 0.273920    0.968047    3.364109    0.156759    0.056020    0.014406    0.778042    
#> 070: 0.304669    0.956026    3.375935    0.148921    0.066837    0.013686    0.771637    
#> 071: 0.293694    0.982811    3.350439    0.184996    0.065978    0.013002    0.792060    
#> 072: 0.255253    0.950967    3.357207    0.197421    0.075509    0.016031    0.761104    
#> 073: 0.336889    0.934851    3.387564    0.187550    0.079125    0.015429    0.759714    
#> 074: 0.302716    0.936732    3.378465    0.178172    0.080857    0.014657    0.756545    
#> 075: 0.334962    0.919389    3.397851    0.169264    0.078161    0.013924    0.753051    
#> 076: 0.378531    0.946120    3.397121    0.174796    0.074253    0.014917    0.759417    
#> 077: 0.362220    0.925023    3.378575    0.183122    0.070541    0.017658    0.748968    
#> 078: 0.342005    0.948742    3.379816    0.173966    0.067013    0.016775    0.743841    
#> 079: 0.351342    0.954520    3.386519    0.184157    0.075379    0.015937    0.752585    
#> 080: 0.330289    0.935231    3.385994    0.177594    0.081838    0.015151    0.758300    
#> 081: 0.301693    0.960333    3.377973    0.171844    0.077746    0.014394    0.752961    
#> 082: 0.292543    0.954735    3.369646    0.163252    0.073858    0.014012    0.743648    
#> 083: 0.343476    0.967019    3.376349    0.155090    0.070165    0.013509    0.744611    
#> 084: 0.319321    0.960021    3.374522    0.147335    0.066657    0.012966    0.731793    
#> 085: 0.314399    0.954574    3.381312    0.144465    0.063324    0.012692    0.757958    
#> 086: 0.327256    0.948905    3.375227    0.148613    0.060158    0.013989    0.731800    
#> 087: 0.308426    0.946852    3.363344    0.148103    0.057150    0.013290    0.742643    
#> 088: 0.277069    0.936473    3.362662    0.140698    0.054414    0.014028    0.752507    
#> 089: 0.304153    0.966188    3.353269    0.139072    0.057356    0.013787    0.747846    
#> 090: 0.281657    0.957882    3.355553    0.138978    0.057591    0.013097    0.754662    
#> 091: 0.265793    0.939706    3.347872    0.132029    0.057646    0.012443    0.747051    
#> 092: 0.263545    0.954915    3.348221    0.144122    0.070722    0.012402    0.763237    
#> 093: 0.260418    0.942860    3.350604    0.160176    0.067185    0.011900    0.751805    
#> 094: 0.252213    0.959238    3.340157    0.167569    0.066068    0.011305    0.763421    
#> 095: 0.287873    0.975517    3.357349    0.159191    0.066817    0.010761    0.770366    
#> 096: 0.249668    0.956700    3.351367    0.151231    0.063476    0.011827    0.754871    
#> 097: 0.275138    0.965993    3.350203    0.167765    0.060303    0.011985    0.753119    
#> 098: 0.251723    0.982876    3.357108    0.159377    0.057287    0.011386    0.759822    
#> 099: 0.272774    0.967863    3.343674    0.151408    0.064333    0.011488    0.752811    
#> 100: 0.254935    0.974304    3.345033    0.147714    0.066441    0.010913    0.729902    
#> 101: 0.242033    0.966076    3.335748    0.140328    0.066298    0.010705    0.750832    
#> 102: 0.231815    0.973522    3.330813    0.133312    0.062983    0.010170    0.775256    
#> 103: 0.274214    0.965223    3.347645    0.126646    0.059834    0.010891    0.749339    
#> 104: 0.282064    0.959576    3.365105    0.121757    0.077445    0.010347    0.779265    
#> 105: 0.302264    0.962162    3.363543    0.117275    0.073572    0.009829    0.764570    
#> 106: 0.324820    0.952345    3.364779    0.132941    0.070517    0.009338    0.770082    
#> 107: 0.325171    0.955575    3.372178    0.138363    0.074281    0.008871    0.781637    
#> 108: 0.305141    0.949890    3.364880    0.131445    0.070567    0.008816    0.787505    
#> 109: 0.276863    0.935102    3.368234    0.124872    0.074660    0.008375    0.785288    
#> 110: 0.285254    0.948000    3.353166    0.127692    0.080539    0.007956    0.760553    
#> 111: 0.293331    0.943196    3.357806    0.126098    0.077186    0.007558    0.775912    
#> 112: 0.298775    0.934518    3.355191    0.139518    0.075945    0.007180    0.782333    
#> 113: 0.311873    0.969271    3.361001    0.135554    0.083377    0.006821    0.772048    
#> 114: 0.286846    0.955466    3.364665    0.128776    0.079208    0.006480    0.783290    
#> 115: 0.305751    0.930041    3.362307    0.127419    0.075248    0.006714    0.784184    
#> 116: 0.301544    0.961170    3.364061    0.121048    0.071486    0.007017    0.798399    
#> 117: 0.256486    0.971909    3.355172    0.120993    0.067911    0.006666    0.781933    
#> 118: 0.270732    0.966652    3.353025    0.121672    0.064516    0.008109    0.768793    
#> 119: 0.295285    0.962281    3.363515    0.136370    0.061290    0.008976    0.770204    
#> 120: 0.299781    0.950913    3.355788    0.158797    0.059810    0.011546    0.743021    
#> 121: 0.288156    0.989963    3.354104    0.158585    0.062022    0.013702    0.755139    
#> 122: 0.295452    0.954178    3.366470    0.150656    0.071942    0.013017    0.758443    
#> 123: 0.290010    0.976959    3.355120    0.143123    0.068345    0.012366    0.767318    
#> 124: 0.289678    0.985373    3.352917    0.137504    0.064928    0.012453    0.763376    
#> 125: 0.289936    0.972799    3.346436    0.145569    0.068272    0.011830    0.757186    
#> 126: 0.261092    0.995292    3.340871    0.138290    0.064858    0.014342    0.754096    
#> 127: 0.260625    0.969735    3.333607    0.135978    0.061615    0.013666    0.770930    
#> 128: 0.260275    0.967751    3.357463    0.158023    0.058534    0.015394    0.739708    
#> 129: 0.289604    0.987744    3.351645    0.150122    0.072535    0.014624    0.751393    
#> 130: 0.326307    0.967852    3.358110    0.142616    0.070402    0.013893    0.744418    
#> 131: 0.295436    0.955279    3.349787    0.147563    0.067295    0.013198    0.752353    
#> 132: 0.268292    0.977014    3.341663    0.143059    0.067266    0.012538    0.758206    
#> 133: 0.289921    0.952910    3.355313    0.157149    0.077668    0.011911    0.754973    
#> 134: 0.296452    0.950675    3.361868    0.164661    0.076733    0.013785    0.734653    
#> 135: 0.277375    0.949739    3.357014    0.161887    0.075722    0.013095    0.736733    
#> 136: 0.286870    0.935057    3.367099    0.153793    0.072043    0.014039    0.723370    
#> 137: 0.321280    0.944502    3.368598    0.182440    0.068440    0.013337    0.743227    
#> 138: 0.295939    0.946464    3.361129    0.183131    0.065018    0.014572    0.728743    
#> 139: 0.329380    0.960527    3.372858    0.182614    0.062916    0.016350    0.728851    
#> 140: 0.290235    0.979664    3.361977    0.181792    0.064272    0.015533    0.749371    
#> 141: 0.292134    0.945143    3.363883    0.172703    0.071549    0.015862    0.733408    
#> 142: 0.311046    0.939523    3.381290    0.168432    0.067971    0.015069    0.746461    
#> 143: 0.291377    0.958690    3.369263    0.165605    0.064573    0.015310    0.749367    
#> 144: 0.356029    0.936489    3.390439    0.157324    0.061344    0.014544    0.739007    
#> 145: 0.325752    0.952581    3.371472    0.156415    0.058277    0.013817    0.754023    
#> 146: 0.313245    0.950516    3.381100    0.160193    0.055363    0.014374    0.747557    
#> 147: 0.271223    0.948132    3.362342    0.152183    0.057072    0.013655    0.758319    
#> 148: 0.263668    0.968073    3.360900    0.165349    0.054218    0.013121    0.757991    
#> 149: 0.281330    0.966975    3.355649    0.179813    0.065724    0.013439    0.755054    
#> 150: 0.303494    0.950405    3.351422    0.208962    0.062438    0.014361    0.773022    
#> 151: 0.272356    0.976334    3.352674    0.198513    0.059316    0.015953    0.752964    
#> 152: 0.263500    0.952944    3.354010    0.156959    0.049653    0.014244    0.743385    
#> 153: 0.280586    0.962532    3.360591    0.154240    0.059612    0.017840    0.759199    
#> 154: 0.326991    0.975249    3.367296    0.167572    0.061537    0.018482    0.739117    
#> 155: 0.298138    0.958964    3.359245    0.184294    0.049695    0.019788    0.721237    
#> 156: 0.309199    0.953698    3.360926    0.220589    0.061519    0.021714    0.732376    
#> 157: 0.327888    0.952023    3.370829    0.213871    0.063685    0.020541    0.727548    
#> 158: 0.324175    0.969637    3.356261    0.228820    0.064874    0.022580    0.711974    
#> 159: 0.266676    0.977642    3.360742    0.178816    0.059657    0.021226    0.729565    
#> 160: 0.305412    0.936368    3.371345    0.166685    0.073380    0.017148    0.729381    
#> 161: 0.315532    0.941553    3.371554    0.163328    0.073023    0.016317    0.726037    
#> 162: 0.297698    0.953931    3.362555    0.190821    0.060497    0.020166    0.745373    
#> 163: 0.308261    0.943228    3.354565    0.186051    0.076464    0.018375    0.739364    
#> 164: 0.321859    0.947739    3.364828    0.193873    0.064874    0.021435    0.746778    
#> 165: 0.321006    0.954302    3.367059    0.197516    0.056784    0.022454    0.745979    
#> 166: 0.353419    0.974583    3.365499    0.208340    0.073678    0.020050    0.747147    
#> 167: 0.308520    0.984633    3.371877    0.189138    0.067021    0.019077    0.766614    
#> 168: 0.309580    0.980687    3.363928    0.193573    0.062412    0.015362    0.751381    
#> 169: 0.298185    0.992062    3.355086    0.182802    0.069312    0.012161    0.759509    
#> 170: 0.280578    0.959220    3.355967    0.147001    0.062701    0.014247    0.750078    
#> 171: 0.294463    0.953138    3.366808    0.182699    0.059873    0.014290    0.734811    
#> 172: 0.319556    0.973302    3.360957    0.184989    0.046421    0.015139    0.728510    
#> 173: 0.301533    0.997862    3.349455    0.178110    0.052241    0.018039    0.730416    
#> 174: 0.295697    0.985378    3.363782    0.184417    0.043141    0.019572    0.735733    
#> 175: 0.308424    0.987165    3.356073    0.171565    0.044144    0.021424    0.741222    
#> 176: 0.272708    0.984949    3.359045    0.148930    0.048596    0.019798    0.749687    
#> 177: 0.265260    0.971115    3.364257    0.165705    0.061257    0.022779    0.730893    
#> 178: 0.271330    0.959510    3.363312    0.180923    0.054626    0.021768    0.739768    
#> 179: 0.324942    0.982293    3.356773    0.202019    0.048505    0.016776    0.751734    
#> 180: 0.277115    0.980682    3.343559    0.214090    0.043593    0.021632    0.739972    
#> 181: 0.289487    0.963550    3.338074    0.171795    0.038060    0.017964    0.745596    
#> 182: 0.244452    0.961464    3.346611    0.213385    0.047900    0.019921    0.745155    
#> 183: 0.263334    0.990317    3.343402    0.170494    0.036804    0.016073    0.757315    
#> 184: 0.282773    0.967699    3.351587    0.175924    0.039155    0.016077    0.740192    
#> 185: 0.263135    0.966911    3.350707    0.170383    0.044882    0.017425    0.750103    
#> 186: 0.289149    0.982463    3.362044    0.213036    0.042281    0.022383    0.753065    
#> 187: 0.309583    0.955425    3.370388    0.187724    0.045665    0.021606    0.765706    
#> 188: 0.278770    0.962663    3.360560    0.212945    0.044259    0.016648    0.768492    
#> 189: 0.300111    0.976410    3.366424    0.162387    0.038521    0.017619    0.775054    
#> 190: 0.315030    0.968215    3.376245    0.180920    0.042494    0.016552    0.755672    
#> 191: 0.295681    0.966045    3.360142    0.158791    0.048870    0.016474    0.739155    
#> 192: 0.265347    0.973858    3.365765    0.136972    0.048566    0.015804    0.762520    
#> 193: 0.302545    0.970353    3.360723    0.137360    0.048242    0.012279    0.754165    
#> 194: 0.269417    0.975014    3.354484    0.149576    0.057594    0.012183    0.773532    
#> 195: 0.238893    0.969332    3.343530    0.154515    0.046035    0.013899    0.782834    
#> 196: 0.242961    0.974610    3.350787    0.151147    0.058666    0.015489    0.762056    
#> 197: 0.259535    0.972006    3.375801    0.143570    0.060048    0.015639    0.760269    
#> 198: 0.299510    0.961228    3.361656    0.125126    0.058230    0.012690    0.747280    
#> 199: 0.297614    0.958794    3.365362    0.111845    0.056745    0.010774    0.764518    
#> 200: 0.319643    0.964690    3.374225    0.124902    0.071194    0.010004    0.791733    
#> 201: 0.301264    0.950643    3.376858    0.127198    0.073529    0.010372    0.782079    
#> 202: 0.303976    0.950819    3.375571    0.127366    0.070178    0.011291    0.781117    
#> 203: 0.323942    0.947950    3.377410    0.135397    0.065905    0.012542    0.778182    
#> 204: 0.331470    0.944196    3.379263    0.136364    0.062082    0.013074    0.778360    
#> 205: 0.328965    0.947626    3.379990    0.137900    0.060427    0.013682    0.779708    
#> 206: 0.327413    0.948905    3.380692    0.137724    0.060053    0.013365    0.781634    
#> 207: 0.323861    0.947147    3.379270    0.140808    0.059522    0.013314    0.778814    
#> 208: 0.323583    0.946784    3.378754    0.142192    0.058788    0.013329    0.775603    
#> 209: 0.324997    0.944422    3.378031    0.141579    0.058205    0.013185    0.773913    
#> 210: 0.325962    0.942853    3.378787    0.143121    0.057919    0.013187    0.771857    
#> 211: 0.327637    0.942504    3.379459    0.143009    0.058337    0.013036    0.770933    
#> 212: 0.328548    0.941504    3.379587    0.142921    0.057554    0.013002    0.771321    
#> 213: 0.329796    0.938689    3.380055    0.141069    0.057809    0.012762    0.772318    
#> 214: 0.331087    0.938353    3.379696    0.138695    0.057927    0.012643    0.772690    
#> 215: 0.330696    0.938859    3.379683    0.138518    0.057907    0.012516    0.772920    
#> 216: 0.330670    0.938473    3.379459    0.139957    0.058306    0.012516    0.773545    
#> 217: 0.328983    0.939747    3.378669    0.140927    0.058336    0.012546    0.771786    
#> 218: 0.327909    0.940495    3.377938    0.141634    0.058097    0.012661    0.769621    
#> 219: 0.326966    0.939776    3.377521    0.144687    0.057709    0.012843    0.767665    
#> 220: 0.327081    0.939877    3.377513    0.146348    0.056995    0.012869    0.767043    
#> 221: 0.327260    0.939804    3.377530    0.147368    0.057212    0.012952    0.765800    
#> 222: 0.325964    0.939348    3.377096    0.148241    0.057751    0.013089    0.765366    
#> 223: 0.326301    0.940546    3.376638    0.149365    0.057707    0.013314    0.764007    
#> 224: 0.327004    0.941819    3.376313    0.149909    0.057521    0.013491    0.763233    
#> 225: 0.327120    0.940705    3.376364    0.150748    0.057409    0.013555    0.762753    
#> 226: 0.326706    0.939744    3.376001    0.151363    0.057461    0.013618    0.762292    
#> 227: 0.325256    0.939679    3.375864    0.152324    0.057125    0.013704    0.762113    
#> 228: 0.324280    0.940651    3.374932    0.153675    0.057388    0.013801    0.761960    
#> 229: 0.322977    0.940567    3.374279    0.154190    0.057502    0.013826    0.761067    
#> 230: 0.322943    0.940510    3.373806    0.154377    0.057408    0.013907    0.760300    
#> 231: 0.322596    0.940908    3.373742    0.154740    0.057464    0.013981    0.759713    
#> 232: 0.321520    0.940800    3.373963    0.155049    0.057161    0.014027    0.759240    
#> 233: 0.320903    0.940275    3.373958    0.155054    0.057020    0.014089    0.758632    
#> 234: 0.320303    0.940069    3.373877    0.154844    0.057079    0.014124    0.757754    
#> 235: 0.320379    0.939478    3.373773    0.155682    0.057094    0.014213    0.757208    
#> 236: 0.319827    0.939825    3.373552    0.156105    0.057138    0.014260    0.757343    
#> 237: 0.320178    0.939912    3.373550    0.157286    0.056916    0.014397    0.756985    
#> 238: 0.320632    0.939904    3.373547    0.159000    0.057111    0.014436    0.756998    
#> 239: 0.320312    0.940482    3.373407    0.160075    0.057225    0.014501    0.756313    
#> 240: 0.320562    0.940565    3.373250    0.161013    0.057178    0.014557    0.755226    
#> 241: 0.320658    0.940230    3.373318    0.161177    0.057005    0.014505    0.754919    
#> 242: 0.320662    0.940229    3.373082    0.161135    0.057180    0.014506    0.754998    
#> 243: 0.320150    0.940661    3.373134    0.161111    0.057266    0.014483    0.755061    
#> 244: 0.319843    0.940571    3.373298    0.160915    0.057284    0.014451    0.755367    
#> 245: 0.319702    0.940430    3.373269    0.161649    0.057340    0.014544    0.755616    
#> 246: 0.319197    0.940439    3.373271    0.161738    0.057141    0.014648    0.755321    
#> 247: 0.318797    0.940219    3.373249    0.162715    0.056984    0.014739    0.754949    
#> 248: 0.318098    0.940614    3.373020    0.162809    0.056940    0.014794    0.754338    
#> 249: 0.317161    0.940940    3.372773    0.163724    0.056922    0.014863    0.754334    
#> 250: 0.317304    0.941280    3.373028    0.164267    0.056828    0.014971    0.754123    
#> 251: 0.317587    0.941510    3.373315    0.164425    0.056991    0.015010    0.753905    
#> 252: 0.317717    0.941630    3.373618    0.164298    0.056945    0.015111    0.753498    
#> 253: 0.317527    0.941721    3.373567    0.164200    0.056891    0.015178    0.753444    
#> 254: 0.317515    0.942086    3.373727    0.163909    0.056925    0.015197    0.753293    
#> 255: 0.317603    0.942377    3.373978    0.163272    0.056891    0.015230    0.753347    
#> 256: 0.317956    0.942502    3.373987    0.163251    0.056776    0.015264    0.753073    
#> 257: 0.317520    0.942387    3.373828    0.163129    0.056604    0.015229    0.753076    
#> 258: 0.317012    0.942163    3.373673    0.162608    0.056721    0.015186    0.752983    
#> 259: 0.316581    0.942291    3.373544    0.162493    0.056738    0.015201    0.752934    
#> 260: 0.316077    0.942571    3.373492    0.162815    0.056677    0.015244    0.752440    
#> 261: 0.316216    0.942522    3.373565    0.162843    0.056525    0.015238    0.752258    
#> 262: 0.316454    0.942987    3.373537    0.163335    0.056448    0.015190    0.752330    
#> 263: 0.316277    0.943382    3.373443    0.163301    0.056447    0.015153    0.752420    
#> 264: 0.315724    0.943579    3.373089    0.163068    0.056242    0.015117    0.752862    
#> 265: 0.315621    0.943708    3.372963    0.163129    0.056135    0.015140    0.753154    
#> 266: 0.315849    0.943911    3.372940    0.163367    0.056072    0.015133    0.753049    
#> 267: 0.316037    0.944079    3.373119    0.163457    0.056131    0.015140    0.752964    
#> 268: 0.316056    0.944024    3.373078    0.163367    0.056228    0.015153    0.752873    
#> 269: 0.316565    0.943834    3.373222    0.163326    0.056361    0.015131    0.752975    
#> 270: 0.316949    0.943881    3.373222    0.163380    0.056469    0.015060    0.752703    
#> 271: 0.317045    0.943849    3.373100    0.163565    0.056502    0.015032    0.752785    
#> 272: 0.317156    0.943585    3.373107    0.164042    0.056443    0.015017    0.752922    
#> 273: 0.316915    0.943639    3.373054    0.164180    0.056457    0.015016    0.752875    
#> 274: 0.316492    0.944055    3.372949    0.164476    0.056438    0.015033    0.752681    
#> 275: 0.316322    0.944231    3.372788    0.164852    0.056289    0.015040    0.752441    
#> 276: 0.316113    0.944466    3.372869    0.164867    0.056153    0.015016    0.752433    
#> 277: 0.316122    0.944946    3.372896    0.164943    0.056124    0.014984    0.752422    
#> 278: 0.316122    0.945057    3.372953    0.164945    0.056139    0.014941    0.752464    
#> 279: 0.316004    0.944949    3.373013    0.165032    0.056146    0.014942    0.752477    
#> 280: 0.315812    0.945094    3.372996    0.164858    0.056053    0.014952    0.752228    
#> 281: 0.315467    0.945371    3.372937    0.164962    0.055937    0.014987    0.752181    
#> 282: 0.315214    0.945599    3.372896    0.165094    0.055771    0.015009    0.752089    
#> 283: 0.315120    0.945717    3.372872    0.165153    0.055769    0.015023    0.752226    
#> 284: 0.315090    0.945450    3.372876    0.165309    0.055746    0.015037    0.752070    
#> 285: 0.315469    0.945326    3.372798    0.165985    0.055773    0.015053    0.751940    
#> 286: 0.315326    0.945497    3.372656    0.166159    0.055866    0.015017    0.751960    
#> 287: 0.315253    0.945837    3.372505    0.166640    0.055995    0.014986    0.751963    
#> 288: 0.315353    0.946115    3.372359    0.166992    0.055976    0.014976    0.752094    
#> 289: 0.315588    0.946260    3.372334    0.167543    0.056023    0.014987    0.751916    
#> 290: 0.315597    0.946344    3.372333    0.167696    0.056083    0.014963    0.752091    
#> 291: 0.315784    0.946473    3.372310    0.167726    0.056102    0.014967    0.751928    
#> 292: 0.315578    0.946517    3.372269    0.167932    0.056143    0.014956    0.751723    
#> 293: 0.315308    0.946728    3.372170    0.168036    0.056144    0.014945    0.751482    
#> 294: 0.314947    0.947050    3.371923    0.167709    0.056179    0.014942    0.751396    
#> 295: 0.314884    0.946808    3.371916    0.167769    0.056277    0.014955    0.751130    
#> 296: 0.314769    0.946604    3.371933    0.167742    0.056295    0.014980    0.751085    
#> 297: 0.315038    0.946615    3.371921    0.167752    0.056299    0.015031    0.751104    
#> 298: 0.315110    0.946579    3.371883    0.167595    0.056286    0.015000    0.751205    
#> 299: 0.315314    0.946951    3.371771    0.167538    0.056285    0.014952    0.751303    
#> 300: 0.315471    0.946833    3.371947    0.167447    0.056264    0.014932    0.751345    
#> 301: 0.315548    0.946659    3.371935    0.167349    0.056295    0.014902    0.751532    
#> 302: 0.315159    0.946726    3.371675    0.167632    0.056268    0.014918    0.751373    
#> 303: 0.314728    0.947000    3.371470    0.168001    0.056324    0.014957    0.751091    
#> 304: 0.314647    0.947346    3.371205    0.168021    0.056300    0.014992    0.751144    
#> 305: 0.314262    0.947307    3.370968    0.168238    0.056364    0.015042    0.751168    
#> 306: 0.313819    0.947353    3.370726    0.168409    0.056298    0.015086    0.751227    
#> 307: 0.313425    0.947434    3.370587    0.168427    0.056287    0.015068    0.751454    
#> 308: 0.313013    0.947324    3.370489    0.168232    0.056335    0.015068    0.751652    
#> 309: 0.312975    0.947266    3.370384    0.168065    0.056260    0.015065    0.751786    
#> 310: 0.312955    0.947146    3.370218    0.168205    0.056225    0.015074    0.751828    
#> 311: 0.312767    0.947162    3.370161    0.168017    0.056179    0.015085    0.751841    
#> 312: 0.312521    0.947173    3.370024    0.167932    0.056145    0.015109    0.751813    
#> 313: 0.312172    0.947121    3.369920    0.167720    0.056111    0.015121    0.751888    
#> 314: 0.311677    0.947329    3.369772    0.167570    0.056046    0.015103    0.751967    
#> 315: 0.311234    0.947498    3.369675    0.167342    0.056028    0.015077    0.752061    
#> 316: 0.311077    0.947543    3.369652    0.166929    0.056143    0.015056    0.751995    
#> 317: 0.311225    0.947523    3.369772    0.166738    0.056223    0.015051    0.752061    
#> 318: 0.311266    0.947711    3.369662    0.166910    0.056230    0.015061    0.751999    
#> 319: 0.311218    0.947862    3.369653    0.166934    0.056235    0.015106    0.752036    
#> 320: 0.310775    0.947859    3.369509    0.167113    0.056274    0.015107    0.752172    
#> 321: 0.310382    0.947980    3.369313    0.167381    0.056238    0.015127    0.752107    
#> 322: 0.309943    0.948082    3.369066    0.167316    0.056290    0.015150    0.751993    
#> 323: 0.309029    0.948137    3.368837    0.167233    0.056284    0.015176    0.752086    
#> 324: 0.308746    0.948282    3.368836    0.166846    0.056362    0.015145    0.752100    
#> 325: 0.308438    0.948427    3.368732    0.166479    0.056442    0.015123    0.751955    
#> 326: 0.308180    0.948336    3.368610    0.166494    0.056461    0.015088    0.751894    
#> 327: 0.308180    0.948495    3.368601    0.166434    0.056495    0.015074    0.751831    
#> 328: 0.308284    0.948661    3.368629    0.166267    0.056510    0.015064    0.751734    
#> 329: 0.308677    0.948708    3.368755    0.166161    0.056527    0.015056    0.751650    
#> 330: 0.308724    0.948787    3.368805    0.166032    0.056493    0.015052    0.751803    
#> 331: 0.309001    0.948924    3.368862    0.165939    0.056421    0.015051    0.751822    
#> 332: 0.309215    0.948837    3.369020    0.165767    0.056431    0.015048    0.751824    
#> 333: 0.309255    0.948777    3.368977    0.165870    0.056359    0.015055    0.751744    
#> 334: 0.309010    0.948656    3.368864    0.165729    0.056273    0.015066    0.751748    
#> 335: 0.308651    0.948674    3.368741    0.165735    0.056223    0.015069    0.751764    
#> 336: 0.308309    0.948846    3.368583    0.165787    0.056174    0.015104    0.751894    
#> 337: 0.308071    0.949200    3.368404    0.165942    0.056136    0.015113    0.751987    
#> 338: 0.308088    0.949312    3.368367    0.166068    0.056148    0.015142    0.751876    
#> 339: 0.307851    0.949425    3.368266    0.166144    0.056153    0.015166    0.751775    
#> 340: 0.307675    0.949395    3.368230    0.166242    0.056238    0.015191    0.751688    
#> 341: 0.307820    0.949466    3.368253    0.166294    0.056325    0.015216    0.751738    
#> 342: 0.307626    0.949420    3.368237    0.166350    0.056335    0.015243    0.751656    
#> 343: 0.307284    0.949467    3.368201    0.166289    0.056361    0.015225    0.751662    
#> 344: 0.307417    0.949466    3.368260    0.166257    0.056391    0.015237    0.751835    
#> 345: 0.307512    0.949447    3.368308    0.166267    0.056448    0.015257    0.751786    
#> 346: 0.307476    0.949399    3.368278    0.166290    0.056433    0.015259    0.751699    
#> 347: 0.307677    0.949362    3.368231    0.166400    0.056465    0.015271    0.751798    
#> 348: 0.307555    0.949532    3.368186    0.166574    0.056440    0.015282    0.751844    
#> 349: 0.307669    0.949512    3.368183    0.167028    0.056383    0.015302    0.751759    
#> 350: 0.307464    0.949422    3.368128    0.167091    0.056399    0.015314    0.751729    
#> 351: 0.307427    0.949649    3.368024    0.167279    0.056450    0.015325    0.751694    
#> 352: 0.307153    0.949878    3.368000    0.167491    0.056519    0.015347    0.751852    
#> 353: 0.306943    0.950092    3.367848    0.167645    0.056488    0.015382    0.751823    
#> 354: 0.306814    0.950248    3.367636    0.167931    0.056408    0.015452    0.751717    
#> 355: 0.306836    0.950282    3.367491    0.168042    0.056387    0.015486    0.751681    
#> 356: 0.306601    0.950277    3.367479    0.168011    0.056441    0.015508    0.751861    
#> 357: 0.306726    0.950305    3.367489    0.168049    0.056448    0.015488    0.751880    
#> 358: 0.306615    0.950383    3.367471    0.168071    0.056480    0.015505    0.751747    
#> 359: 0.306375    0.950489    3.367445    0.168116    0.056389    0.015511    0.751684    
#> 360: 0.306158    0.950577    3.367333    0.167961    0.056388    0.015506    0.751522    
#> 361: 0.305883    0.950616    3.367247    0.167719    0.056330    0.015495    0.751467    
#> 362: 0.305882    0.950591    3.367211    0.167666    0.056340    0.015475    0.751354    
#> 363: 0.305788    0.950573    3.367184    0.167556    0.056392    0.015454    0.751248    
#> 364: 0.305925    0.950560    3.367243    0.167681    0.056471    0.015448    0.751288    
#> 365: 0.305985    0.950476    3.367306    0.167665    0.056507    0.015455    0.751195    
#> 366: 0.306145    0.950497    3.367278    0.167700    0.056520    0.015450    0.751093    
#> 367: 0.306215    0.950620    3.367225    0.167812    0.056517    0.015449    0.750982    
#> 368: 0.306433    0.950706    3.367208    0.168072    0.056481    0.015460    0.750863    
#> 369: 0.306367    0.950752    3.367170    0.168323    0.056544    0.015475    0.750795    
#> 370: 0.306172    0.950770    3.367099    0.168409    0.056473    0.015512    0.750763    
#> 371: 0.305818    0.950857    3.366915    0.168480    0.056455    0.015526    0.750733    
#> 372: 0.305590    0.950990    3.366786    0.168667    0.056434    0.015542    0.750584    
#> 373: 0.305304    0.951136    3.366623    0.168861    0.056359    0.015558    0.750575    
#> 374: 0.305141    0.951106    3.366521    0.168977    0.056269    0.015549    0.750661    
#> 375: 0.304999    0.951099    3.366488    0.168880    0.056173    0.015541    0.750782    
#> 376: 0.304817    0.951136    3.366442    0.168787    0.056121    0.015552    0.750728    
#> 377: 0.304754    0.951228    3.366401    0.168794    0.056134    0.015560    0.750726    
#> 378: 0.304473    0.951187    3.366296    0.168653    0.056166    0.015565    0.750844    
#> 379: 0.304351    0.951078    3.366283    0.168485    0.056172    0.015564    0.750811    
#> 380: 0.304231    0.951075    3.366289    0.168406    0.056256    0.015566    0.750783    
#> 381: 0.304015    0.951087    3.366187    0.168465    0.056270    0.015574    0.750727    
#> 382: 0.303882    0.951025    3.366158    0.168467    0.056313    0.015568    0.750645    
#> 383: 0.303945    0.951203    3.366115    0.168427    0.056333    0.015560    0.750514    
#> 384: 0.303802    0.951202    3.366159    0.168326    0.056338    0.015561    0.750478    
#> 385: 0.303759    0.951214    3.366179    0.168198    0.056353    0.015562    0.750551    
#> 386: 0.303898    0.951372    3.366238    0.168100    0.056346    0.015563    0.750601    
#> 387: 0.304185    0.951436    3.366349    0.168149    0.056296    0.015569    0.750601    
#> 388: 0.304379    0.951393    3.366411    0.168255    0.056219    0.015575    0.750637    
#> 389: 0.304276    0.951250    3.366358    0.168281    0.056173    0.015591    0.750778    
#> 390: 0.304107    0.951325    3.366285    0.168356    0.056117    0.015611    0.750724    
#> 391: 0.304076    0.951372    3.366212    0.168304    0.056037    0.015612    0.750667    
#> 392: 0.303998    0.951425    3.366207    0.168136    0.055979    0.015600    0.750771    
#> 393: 0.303907    0.951445    3.366180    0.167812    0.055986    0.015592    0.750804    
#> 394: 0.303925    0.951495    3.366170    0.167670    0.055967    0.015591    0.750811    
#> 395: 0.304069    0.951612    3.366179    0.167597    0.055976    0.015598    0.750794    
#> 396: 0.304163    0.951699    3.366202    0.167476    0.056013    0.015598    0.750715    
#> 397: 0.304452    0.951658    3.366311    0.167516    0.055989    0.015598    0.750646    
#> 398: 0.304820    0.951556    3.366396    0.167716    0.056036    0.015593    0.750683    
#> 399: 0.305034    0.951549    3.366441    0.167920    0.056129    0.015590    0.750661    
#> 400: 0.305258    0.951569    3.366532    0.168160    0.056156    0.015585    0.750713    
#> 401: 0.305250    0.951613    3.366525    0.168315    0.056239    0.015591    0.750674    
#> 402: 0.305139    0.951741    3.366480    0.168448    0.056284    0.015598    0.750609    
#> 403: 0.305198    0.951836    3.366423    0.168566    0.056321    0.015584    0.750534    
#> 404: 0.305359    0.951842    3.366397    0.168678    0.056313    0.015575    0.750491    
#> 405: 0.305328    0.951839    3.366394    0.168822    0.056319    0.015567    0.750486    
#> 406: 0.305478    0.951846    3.366426    0.168748    0.056316    0.015572    0.750568    
#> 407: 0.305686    0.951868    3.366536    0.168651    0.056450    0.015562    0.750518    
#> 408: 0.305909    0.951940    3.366605    0.168555    0.056543    0.015541    0.750514    
#> 409: 0.305942    0.951825    3.366615    0.168372    0.056540    0.015515    0.750547    
#> 410: 0.306092    0.951821    3.366615    0.168309    0.056570    0.015506    0.750563    
#> 411: 0.306258    0.951697    3.366630    0.168239    0.056565    0.015490    0.750589    
#> 412: 0.306252    0.951736    3.366613    0.168196    0.056610    0.015474    0.750558    
#> 413: 0.306217    0.951823    3.366562    0.168249    0.056600    0.015469    0.750545    
#> 414: 0.306213    0.951780    3.366556    0.168270    0.056581    0.015466    0.750428    
#> 415: 0.306202    0.951780    3.366530    0.168295    0.056584    0.015472    0.750262    
#> 416: 0.306301    0.951819    3.366577    0.168284    0.056586    0.015466    0.750132    
#> 417: 0.306306    0.951772    3.366600    0.168292    0.056604    0.015463    0.750093    
#> 418: 0.306216    0.951813    3.366628    0.168323    0.056635    0.015454    0.750094    
#> 419: 0.306240    0.951973    3.366624    0.168362    0.056626    0.015458    0.750045    
#> 420: 0.306301    0.952056    3.366634    0.168373    0.056658    0.015439    0.749950    
#> 421: 0.306305    0.952087    3.366688    0.168296    0.056694    0.015420    0.749926    
#> 422: 0.306439    0.951993    3.366726    0.168206    0.056710    0.015392    0.749918    
#> 423: 0.306601    0.951865    3.366785    0.168203    0.056755    0.015386    0.749904    
#> 424: 0.306629    0.951727    3.366780    0.168156    0.056730    0.015383    0.749926    
#> 425: 0.306895    0.951709    3.366786    0.168234    0.056638    0.015377    0.749974    
#> 426: 0.306946    0.951846    3.366809    0.168365    0.056577    0.015389    0.749957    
#> 427: 0.306889    0.951821    3.366819    0.168466    0.056577    0.015397    0.749896    
#> 428: 0.306857    0.951871    3.366828    0.168481    0.056639    0.015402    0.749902    
#> 429: 0.306957    0.951896    3.366859    0.168563    0.056674    0.015391    0.749851    
#> 430: 0.307014    0.951920    3.366893    0.168607    0.056706    0.015394    0.749743    
#> 431: 0.306966    0.951908    3.366892    0.168512    0.056715    0.015387    0.749694    
#> 432: 0.306918    0.951948    3.366917    0.168488    0.056689    0.015402    0.749696    
#> 433: 0.306937    0.951981    3.366970    0.168587    0.056637    0.015408    0.749679    
#> 434: 0.306984    0.951829    3.367035    0.168643    0.056660    0.015430    0.749577    
#> 435: 0.307162    0.951733    3.367079    0.168742    0.056643    0.015430    0.749506    
#> 436: 0.307317    0.951633    3.367168    0.168648    0.056614    0.015429    0.749518    
#> 437: 0.307534    0.951609    3.367228    0.168601    0.056631    0.015418    0.749514    
#> 438: 0.307646    0.951651    3.367290    0.168594    0.056591    0.015415    0.749465    
#> 439: 0.307783    0.951745    3.367339    0.168612    0.056573    0.015412    0.749437    
#> 440: 0.307710    0.951810    3.367338    0.168486    0.056566    0.015404    0.749460    
#> 441: 0.307619    0.951817    3.367336    0.168241    0.056598    0.015381    0.749485    
#> 442: 0.307423    0.951900    3.367320    0.168034    0.056650    0.015369    0.749485    
#> 443: 0.307297    0.951981    3.367251    0.168036    0.056682    0.015354    0.749448    
#> 444: 0.307152    0.952048    3.367166    0.167952    0.056729    0.015334    0.749510    
#> 445: 0.306954    0.952164    3.367083    0.167826    0.056782    0.015318    0.749626    
#> 446: 0.306664    0.952279    3.366989    0.167787    0.056812    0.015303    0.749631    
#> 447: 0.306733    0.952324    3.366958    0.167785    0.056780    0.015302    0.749571    
#> 448: 0.306729    0.952326    3.366975    0.167735    0.056745    0.015288    0.749526    
#> 449: 0.306875    0.952371    3.367084    0.167772    0.056689    0.015284    0.749532    
#> 450: 0.306918    0.952378    3.367077    0.167947    0.056699    0.015290    0.749513    
#> 451: 0.306989    0.952435    3.367084    0.167934    0.056716    0.015286    0.749472    
#> 452: 0.307034    0.952462    3.367058    0.167941    0.056740    0.015277    0.749418    
#> 453: 0.306988    0.952550    3.366997    0.167890    0.056724    0.015261    0.749435    
#> 454: 0.306903    0.952690    3.366949    0.167792    0.056716    0.015248    0.749435    
#> 455: 0.306903    0.952735    3.366910    0.167805    0.056726    0.015242    0.749447    
#> 456: 0.306781    0.952726    3.366872    0.167874    0.056723    0.015245    0.749457    
#> 457: 0.306742    0.952764    3.366892    0.167797    0.056737    0.015238    0.749407    
#> 458: 0.306766    0.952903    3.366917    0.167726    0.056742    0.015222    0.749377    
#> 459: 0.306595    0.953054    3.366916    0.167713    0.056789    0.015219    0.749315    
#> 460: 0.306538    0.953092    3.366888    0.167770    0.056755    0.015236    0.749279    
#> 461: 0.306460    0.953121    3.366882    0.167879    0.056726    0.015245    0.749267    
#> 462: 0.306395    0.953157    3.366896    0.168031    0.056746    0.015257    0.749226    
#> 463: 0.306449    0.953202    3.366917    0.168225    0.056725    0.015267    0.749181    
#> 464: 0.306490    0.953246    3.366900    0.168302    0.056741    0.015266    0.749132    
#> 465: 0.306478    0.953130    3.366917    0.168276    0.056759    0.015252    0.749220    
#> 466: 0.306390    0.953143    3.366848    0.168305    0.056783    0.015241    0.749165    
#> 467: 0.306264    0.953133    3.366801    0.168169    0.056851    0.015218    0.749120    
#> 468: 0.306352    0.953143    3.366845    0.168159    0.056869    0.015218    0.749198    
#> 469: 0.306415    0.953182    3.366898    0.168096    0.056879    0.015224    0.749264    
#> 470: 0.306362    0.953229    3.366907    0.168150    0.056898    0.015219    0.749302    
#> 471: 0.306175    0.953242    3.366860    0.168161    0.056877    0.015210    0.749291    
#> 472: 0.306215    0.953241    3.366866    0.168130    0.056840    0.015199    0.749369    
#> 473: 0.306154    0.953252    3.366861    0.168049    0.056853    0.015194    0.749341    
#> 474: 0.306151    0.953230    3.366846    0.168151    0.056836    0.015213    0.749353    
#> 475: 0.306187    0.953334    3.366826    0.168186    0.056770    0.015227    0.749380    
#> 476: 0.306222    0.953357    3.366820    0.168224    0.056715    0.015239    0.749410    
#> 477: 0.306237    0.953267    3.366885    0.168229    0.056666    0.015237    0.749390    
#> 478: 0.306216    0.953217    3.366903    0.168264    0.056655    0.015245    0.749421    
#> 479: 0.306334    0.953248    3.366936    0.168258    0.056641    0.015246    0.749468    
#> 480: 0.306445    0.953290    3.366961    0.168293    0.056628    0.015244    0.749561    
#> 481: 0.306362    0.953298    3.366961    0.168233    0.056596    0.015238    0.749601    
#> 482: 0.306455    0.953294    3.366968    0.168140    0.056614    0.015228    0.749681    
#> 483: 0.306384    0.953298    3.366956    0.168021    0.056647    0.015215    0.749681    
#> 484: 0.306307    0.953196    3.366982    0.167889    0.056657    0.015209    0.749707    
#> 485: 0.306336    0.953167    3.367017    0.167733    0.056656    0.015206    0.749771    
#> 486: 0.306388    0.953176    3.367051    0.167619    0.056635    0.015197    0.749779    
#> 487: 0.306523    0.953167    3.367109    0.167571    0.056595    0.015197    0.749784    
#> 488: 0.306523    0.953179    3.367131    0.167495    0.056612    0.015189    0.749750    
#> 489: 0.306657    0.953186    3.367146    0.167458    0.056644    0.015198    0.749691    
#> 490: 0.306777    0.953219    3.367185    0.167529    0.056606    0.015203    0.749664    
#> 491: 0.306849    0.953318    3.367240    0.167534    0.056605    0.015208    0.749595    
#> 492: 0.306825    0.953368    3.367241    0.167666    0.056619    0.015218    0.749566    
#> 493: 0.306756    0.953393    3.367200    0.167744    0.056594    0.015230    0.749594    
#> 494: 0.306759    0.953456    3.367157    0.167797    0.056573    0.015231    0.749590    
#> 495: 0.306787    0.953483    3.367150    0.167883    0.056544    0.015235    0.749546    
#> 496: 0.306919    0.953509    3.367133    0.167994    0.056524    0.015228    0.749538    
#> 497: 0.306946    0.953480    3.367155    0.167990    0.056529    0.015233    0.749569    
#> 498: 0.307023    0.953409    3.367161    0.168022    0.056503    0.015228    0.749550    
#> 499: 0.307096    0.953400    3.367159    0.167973    0.056563    0.015211    0.749552    
#> 500: 0.307222    0.953283    3.367178    0.167970    0.056554    0.015207    0.749576    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.261904    0.966200    3.440894    0.392401    0.080900    0.016800    1.751533    
#> 002: 0.235678    0.977083    3.446251    0.372781    0.076855    0.015960    1.151502    
#> 003: 0.383027    0.907175    3.481554    0.354142    0.098586    0.015162    0.899918    
#> 004: 0.329459    0.879153    3.462530    0.336435    0.093656    0.014404    0.782674    
#> 005: 0.375199    0.889330    3.447456    0.319613    0.099689    0.013684    0.710746    
#> 006: 0.326819    0.884047    3.435842    0.303633    0.096079    0.013000    0.668971    
#> 007: 0.294832    0.896114    3.436671    0.302801    0.091275    0.012350    0.694129    
#> 008: 0.295966    0.898777    3.425775    0.376288    0.086711    0.011732    0.676534    
#> 009: 0.296457    0.885223    3.423908    0.416705    0.087911    0.011783    0.672765    
#> 010: 0.296930    0.901093    3.430513    0.395869    0.099007    0.011194    0.683842    
#> 011: 0.355615    0.920073    3.428460    0.376076    0.098780    0.013165    0.686610    
#> 012: 0.344418    0.916052    3.418325    0.371718    0.103924    0.012506    0.671658    
#> 013: 0.273191    0.925429    3.419709    0.353132    0.098728    0.011881    0.702794    
#> 014: 0.319716    0.925849    3.422662    0.365527    0.093791    0.011287    0.694324    
#> 015: 0.355292    0.909982    3.444034    0.359417    0.089102    0.012276    0.665426    
#> 016: 0.330457    0.945325    3.434089    0.354483    0.084647    0.011662    0.677227    
#> 017: 0.354087    0.934845    3.445031    0.344717    0.080414    0.013697    0.670942    
#> 018: 0.332774    0.923736    3.431284    0.327481    0.076394    0.015709    0.678443    
#> 019: 0.313602    0.925649    3.425258    0.311107    0.080588    0.014923    0.666760    
#> 020: 0.337819    0.927032    3.429899    0.348609    0.090611    0.014177    0.676543    
#> 021: 0.362383    0.895657    3.443972    0.367824    0.086080    0.014365    0.663779    
#> 022: 0.358853    0.908899    3.447444    0.422548    0.092734    0.013646    0.657969    
#> 023: 0.416727    0.927150    3.456407    0.415709    0.088098    0.016140    0.665397    
#> 024: 0.389931    0.928855    3.444715    0.410999    0.083693    0.019586    0.644202    
#> 025: 0.360700    0.914124    3.438851    0.390449    0.088565    0.018606    0.643396    
#> 026: 0.341497    0.939986    3.432076    0.370926    0.084136    0.017676    0.647118    
#> 027: 0.307481    0.952179    3.428329    0.352380    0.081783    0.016792    0.662647    
#> 028: 0.322529    0.933877    3.424067    0.366748    0.077694    0.015953    0.653429    
#> 029: 0.330698    0.943008    3.419093    0.374030    0.089940    0.015155    0.667606    
#> 030: 0.324968    0.952139    3.425385    0.367435    0.085443    0.014674    0.658363    
#> 031: 0.311997    0.920137    3.434039    0.446774    0.085119    0.014615    0.658828    
#> 032: 0.339401    0.900392    3.438766    0.437102    0.080863    0.015345    0.660880    
#> 033: 0.321308    0.923359    3.433083    0.421597    0.076820    0.014578    0.666443    
#> 034: 0.355056    0.935460    3.431803    0.400517    0.082366    0.013849    0.668690    
#> 035: 0.357419    0.920178    3.435294    0.380491    0.094430    0.013157    0.664317    
#> 036: 0.293633    0.934656    3.417088    0.361467    0.089709    0.012700    0.696847    
#> 037: 0.301263    0.951672    3.419185    0.377826    0.085223    0.013625    0.696808    
#> 038: 0.298021    0.937269    3.407652    0.358935    0.080962    0.014800    0.679516    
#> 039: 0.311097    0.932189    3.420399    0.373174    0.084334    0.016604    0.660278    
#> 040: 0.320697    0.941800    3.436462    0.354515    0.100918    0.019810    0.661889    
#> 041: 0.301094    0.940825    3.427468    0.336790    0.095872    0.018820    0.670572    
#> 042: 0.312638    0.932815    3.419272    0.319950    0.091079    0.017879    0.659487    
#> 043: 0.299918    0.940398    3.408975    0.344114    0.088701    0.016985    0.658714    
#> 044: 0.284999    0.952440    3.410944    0.369328    0.084266    0.016136    0.653982    
#> 045: 0.285933    0.962191    3.413142    0.350861    0.080053    0.015329    0.650763    
#> 046: 0.299614    0.947867    3.421152    0.333318    0.084516    0.014562    0.647172    
#> 047: 0.281455    0.952068    3.410663    0.357250    0.083237    0.013834    0.655407    
#> 048: 0.290539    0.939780    3.408337    0.377537    0.083583    0.013142    0.665280    
#> 049: 0.287071    0.943033    3.400334    0.372276    0.093426    0.012485    0.665814    
#> 050: 0.345669    0.920521    3.423790    0.357638    0.101663    0.011861    0.680593    
#> 051: 0.314372    0.944393    3.418513    0.339756    0.103973    0.011268    0.683229    
#> 052: 0.336623    0.944399    3.424914    0.329330    0.098775    0.010705    0.660014    
#> 053: 0.305087    0.939494    3.421581    0.322367    0.093836    0.012203    0.649604    
#> 054: 0.276705    0.931506    3.427541    0.306248    0.089144    0.014501    0.681082    
#> 055: 0.283145    0.930402    3.428858    0.294432    0.085433    0.013776    0.704147    
#> 056: 0.319069    0.912517    3.432246    0.324041    0.081161    0.013087    0.698103    
#> 057: 0.350346    0.905321    3.446394    0.399109    0.091599    0.012432    0.676726    
#> 058: 0.337209    0.909335    3.435679    0.379153    0.087019    0.011811    0.703325    
#> 059: 0.321420    0.884972    3.444598    0.360196    0.090828    0.011220    0.721139    
#> 060: 0.321696    0.875818    3.450347    0.342186    0.095382    0.012121    0.720104    
#> 061: 0.409804    0.880680    3.461621    0.325077    0.098097    0.013190    0.702704    
#> 062: 0.388550    0.884272    3.460257    0.308823    0.096715    0.015715    0.717484    
#> 063: 0.392098    0.890058    3.457909    0.312758    0.103195    0.014929    0.730017    
#> 064: 0.363173    0.891879    3.459822    0.297120    0.117785    0.014183    0.720505    
#> 065: 0.401549    0.896578    3.455585    0.282264    0.111896    0.013474    0.702806    
#> 066: 0.367383    0.912658    3.452840    0.293651    0.106301    0.012800    0.683935    
#> 067: 0.370979    0.890436    3.450660    0.308749    0.100986    0.012160    0.667749    
#> 068: 0.322258    0.890380    3.452891    0.336896    0.095937    0.011890    0.673677    
#> 069: 0.353633    0.906696    3.449603    0.320052    0.091328    0.013505    0.671159    
#> 070: 0.350337    0.913391    3.449806    0.344358    0.086761    0.014003    0.683998    
#> 071: 0.321973    0.931910    3.429017    0.348613    0.082423    0.014331    0.679214    
#> 072: 0.307451    0.917160    3.424202    0.349291    0.085949    0.013614    0.658961    
#> 073: 0.323386    0.928343    3.435662    0.361588    0.086333    0.013793    0.656666    
#> 074: 0.334483    0.890708    3.442845    0.343508    0.082017    0.013343    0.661142    
#> 075: 0.341103    0.891739    3.463971    0.326333    0.077916    0.015514    0.666716    
#> 076: 0.368940    0.923901    3.453122    0.338006    0.074020    0.015421    0.669029    
#> 077: 0.372307    0.902021    3.449631    0.406415    0.085000    0.015819    0.677548    
#> 078: 0.362868    0.907216    3.448418    0.386094    0.089737    0.016371    0.654166    
#> 079: 0.357166    0.908057    3.455820    0.366789    0.088955    0.015553    0.672606    
#> 080: 0.349157    0.907394    3.448312    0.369576    0.084507    0.014775    0.695463    
#> 081: 0.336981    0.935523    3.439268    0.355804    0.085834    0.014036    0.668384    
#> 082: 0.333509    0.921566    3.431069    0.370389    0.083516    0.013335    0.677065    
#> 083: 0.346810    0.953737    3.428227    0.535737    0.103354    0.012668    0.675137    
#> 084: 0.321109    0.939929    3.423655    0.508950    0.098186    0.012035    0.664131    
#> 085: 0.336810    0.926679    3.434903    0.483502    0.093277    0.011433    0.671414    
#> 086: 0.303580    0.936580    3.426323    0.459327    0.088613    0.010861    0.670866    
#> 087: 0.305834    0.939274    3.417486    0.436361    0.096087    0.010318    0.660709    
#> 088: 0.278178    0.934564    3.423936    0.414543    0.095709    0.011201    0.661288    
#> 089: 0.305022    0.936195    3.415211    0.393816    0.090924    0.010641    0.674943    
#> 090: 0.291837    0.932968    3.417330    0.374125    0.086378    0.012034    0.677077    
#> 091: 0.278537    0.939658    3.404850    0.391863    0.098238    0.013697    0.657246    
#> 092: 0.280992    0.955513    3.410261    0.372270    0.095200    0.014993    0.663715    
#> 093: 0.271156    0.940549    3.413989    0.353657    0.090440    0.014682    0.666921    
#> 094: 0.306197    0.952200    3.417769    0.335974    0.085918    0.015225    0.673134    
#> 095: 0.310064    0.939914    3.430769    0.319175    0.081622    0.017193    0.666521    
#> 096: 0.287088    0.930269    3.430364    0.333401    0.077541    0.016333    0.668377    
#> 097: 0.315416    0.948268    3.425501    0.336384    0.077727    0.015517    0.650408    
#> 098: 0.321587    0.967877    3.419130    0.379599    0.083342    0.014741    0.658635    
#> 099: 0.276277    0.928882    3.410235    0.360619    0.079175    0.014004    0.682070    
#> 100: 0.302058    0.934472    3.419816    0.342588    0.081676    0.013304    0.673724    
#> 101: 0.278550    0.914858    3.409254    0.325458    0.077721    0.012638    0.683873    
#> 102: 0.288824    0.927470    3.407731    0.334169    0.075289    0.012006    0.664617    
#> 103: 0.309023    0.939091    3.412628    0.368471    0.079864    0.011406    0.664557    
#> 104: 0.287964    0.938076    3.420576    0.358267    0.075871    0.010836    0.674237    
#> 105: 0.272789    0.934127    3.412438    0.361201    0.086955    0.010294    0.685955    
#> 106: 0.306920    0.940952    3.418728    0.343141    0.087115    0.009779    0.662520    
#> 107: 0.315395    0.951792    3.426397    0.325983    0.091143    0.009290    0.663916    
#> 108: 0.333266    0.923781    3.424636    0.322597    0.086586    0.009302    0.661134    
#> 109: 0.334410    0.926933    3.435496    0.325537    0.089205    0.009689    0.664723    
#> 110: 0.340412    0.917845    3.430125    0.318455    0.094332    0.012256    0.660543    
#> 111: 0.321589    0.919552    3.430033    0.303161    0.095239    0.011643    0.648083    
#> 112: 0.279714    0.914086    3.411381    0.341484    0.104291    0.011061    0.652098    
#> 113: 0.300845    0.956147    3.412907    0.438320    0.099076    0.010508    0.648682    
#> 114: 0.301906    0.957027    3.414275    0.416404    0.104191    0.010905    0.648822    
#> 115: 0.282068    0.934263    3.406228    0.395584    0.105006    0.010757    0.659547    
#> 116: 0.288690    0.942923    3.412388    0.375805    0.099755    0.010629    0.659613    
#> 117: 0.259730    0.944252    3.413945    0.357015    0.097049    0.010097    0.673047    
#> 118: 0.289054    0.924455    3.409900    0.378825    0.109385    0.009592    0.663916    
#> 119: 0.299761    0.933303    3.421499    0.368236    0.103916    0.009910    0.675112    
#> 120: 0.259549    0.932079    3.413404    0.349824    0.099290    0.010105    0.680195    
#> 121: 0.294275    0.959056    3.409868    0.336891    0.094999    0.010143    0.686254    
#> 122: 0.321608    0.950024    3.424031    0.423466    0.090249    0.009636    0.679894    
#> 123: 0.369328    0.963018    3.424597    0.432685    0.085736    0.009610    0.679514    
#> 124: 0.332036    0.957563    3.424278    0.411051    0.089793    0.009130    0.684470    
#> 125: 0.347801    0.955739    3.419898    0.390498    0.102248    0.008673    0.676760    
#> 126: 0.278598    0.957823    3.409431    0.370973    0.110105    0.008239    0.680774    
#> 127: 0.291302    0.945865    3.401129    0.352424    0.114817    0.007827    0.686888    
#> 128: 0.263697    0.936076    3.412986    0.339770    0.109076    0.007686    0.679416    
#> 129: 0.287039    0.943821    3.414475    0.322782    0.115750    0.007301    0.674136    
#> 130: 0.325444    0.938770    3.415435    0.308157    0.109962    0.006936    0.673416    
#> 131: 0.315159    0.933123    3.415065    0.327174    0.104464    0.007673    0.693788    
#> 132: 0.300151    0.932341    3.411513    0.310815    0.099241    0.008575    0.702839    
#> 133: 0.301703    0.954558    3.414696    0.304797    0.094279    0.008147    0.706853    
#> 134: 0.343586    0.899947    3.432065    0.324825    0.089565    0.010334    0.673251    
#> 135: 0.314720    0.914628    3.430211    0.308584    0.092270    0.009818    0.691023    
#> 136: 0.335560    0.888832    3.436645    0.293155    0.088807    0.009327    0.693287    
#> 137: 0.388092    0.880155    3.445665    0.282189    0.099620    0.008860    0.703638    
#> 138: 0.339363    0.911776    3.440728    0.273773    0.108652    0.008417    0.686474    
#> 139: 0.313795    0.915746    3.445058    0.260084    0.116131    0.008250    0.690693    
#> 140: 0.356767    0.918235    3.446600    0.333922    0.110325    0.008074    0.682908    
#> 141: 0.357134    0.885635    3.456351    0.317226    0.105161    0.008443    0.685522    
#> 142: 0.364458    0.900585    3.454752    0.301365    0.112858    0.008021    0.702438    
#> 143: 0.306462    0.924182    3.452177    0.286297    0.118042    0.008756    0.704217    
#> 144: 0.376862    0.921106    3.458501    0.271982    0.112140    0.008318    0.688248    
#> 145: 0.349379    0.930863    3.447975    0.279970    0.106533    0.007902    0.671815    
#> 146: 0.328518    0.925538    3.445542    0.296726    0.101207    0.007507    0.689591    
#> 147: 0.318899    0.904897    3.438897    0.327828    0.096146    0.007438    0.664462    
#> 148: 0.306995    0.926427    3.444105    0.349246    0.092283    0.008992    0.660222    
#> 149: 0.315276    0.901864    3.440919    0.336763    0.087669    0.008909    0.662868    
#> 150: 0.336367    0.897808    3.433645    0.319925    0.087802    0.009129    0.676157    
#> 151: 0.263072    0.945125    3.420431    0.303929    0.095258    0.008673    0.659875    
#> 152: 0.295008    0.932609    3.427871    0.326786    0.109339    0.007641    0.646792    
#> 153: 0.303615    0.942449    3.434229    0.334676    0.101732    0.009203    0.670184    
#> 154: 0.354255    0.932680    3.438134    0.372839    0.099049    0.009981    0.669159    
#> 155: 0.340623    0.906070    3.441243    0.288888    0.086707    0.012538    0.673400    
#> 156: 0.355421    0.909010    3.447697    0.318471    0.084420    0.012472    0.683150    
#> 157: 0.352279    0.894016    3.448348    0.331592    0.078367    0.012376    0.666281    
#> 158: 0.349312    0.936841    3.436718    0.321659    0.077102    0.010469    0.665568    
#> 159: 0.335644    0.926637    3.438222    0.366300    0.077644    0.012004    0.666679    
#> 160: 0.344229    0.891954    3.445744    0.335285    0.080728    0.012237    0.672944    
#> 161: 0.354653    0.913833    3.446463    0.367454    0.097869    0.012857    0.663878    
#> 162: 0.331673    0.939969    3.432644    0.331620    0.096293    0.014232    0.685949    
#> 163: 0.358231    0.909600    3.434218    0.301024    0.076119    0.013619    0.677312    
#> 164: 0.352968    0.921520    3.436600    0.327569    0.078802    0.012599    0.673138    
#> 165: 0.331772    0.917872    3.435651    0.313535    0.078082    0.010437    0.664334    
#> 166: 0.367559    0.947359    3.432001    0.377203    0.076885    0.010341    0.669274    
#> 167: 0.322943    0.942651    3.434534    0.341487    0.076497    0.011852    0.669249    
#> 168: 0.353922    0.928521    3.441897    0.349347    0.074851    0.012392    0.660027    
#> 169: 0.352776    0.947748    3.439004    0.339622    0.083279    0.012413    0.664366    
#> 170: 0.347351    0.926515    3.439495    0.383367    0.068320    0.013656    0.649664    
#> 171: 0.329141    0.939529    3.430033    0.384461    0.086171    0.011162    0.649972    
#> 172: 0.295317    0.954765    3.421184    0.412204    0.078390    0.009497    0.662776    
#> 173: 0.296790    0.956528    3.407681    0.356464    0.084039    0.009423    0.654491    
#> 174: 0.292008    0.940353    3.415197    0.325654    0.088276    0.007377    0.672269    
#> 175: 0.270612    0.929664    3.414027    0.308006    0.092704    0.008671    0.658703    
#> 176: 0.314339    0.948896    3.417547    0.371805    0.093460    0.007172    0.667859    
#> 177: 0.327429    0.930283    3.429161    0.365698    0.089511    0.008633    0.670545    
#> 178: 0.352352    0.913477    3.432079    0.354499    0.110672    0.006906    0.678787    
#> 179: 0.305594    0.947699    3.409612    0.319507    0.104576    0.004534    0.676856    
#> 180: 0.298851    0.937212    3.416157    0.342628    0.115831    0.004421    0.674102    
#> 181: 0.312320    0.943717    3.404626    0.311145    0.114085    0.004490    0.672624    
#> 182: 0.261666    0.953576    3.396125    0.320950    0.116415    0.003708    0.678021    
#> 183: 0.295648    0.966796    3.399663    0.292490    0.110859    0.004421    0.692253    
#> 184: 0.314902    0.916735    3.407810    0.331857    0.127151    0.005826    0.691557    
#> 185: 0.297112    0.941593    3.412328    0.300155    0.121321    0.005885    0.693282    
#> 186: 0.258734    0.963272    3.410889    0.281113    0.119721    0.006376    0.687152    
#> 187: 0.294532    0.925161    3.423960    0.275150    0.089899    0.006402    0.700475    
#> 188: 0.247357    0.957251    3.409828    0.275207    0.101029    0.007174    0.699224    
#> 189: 0.294328    0.969278    3.422549    0.325450    0.112669    0.006038    0.697818    
#> 190: 0.301650    0.953047    3.424286    0.295378    0.109826    0.004658    0.678133    
#> 191: 0.279963    0.953546    3.410035    0.351833    0.107957    0.003914    0.673176    
#> 192: 0.283557    0.955003    3.417431    0.391816    0.106179    0.003623    0.659832    
#> 193: 0.343550    0.941905    3.422934    0.350901    0.109039    0.003627    0.672109    
#> 194: 0.334486    0.927390    3.423482    0.321587    0.109192    0.004811    0.690925    
#> 195: 0.313707    0.933836    3.418965    0.348105    0.095454    0.004279    0.683490    
#> 196: 0.307778    0.937928    3.424076    0.309575    0.113134    0.005414    0.690713    
#> 197: 0.276655    0.925441    3.433679    0.326125    0.096396    0.005726    0.718356    
#> 198: 0.353875    0.907527    3.429295    0.302603    0.108069    0.007102    0.699368    
#> 199: 0.301767    0.922677    3.432354    0.299284    0.097994    0.005490    0.690297    
#> 200: 0.329467    0.900608    3.434828    0.261106    0.097657    0.004800    0.714939    
#> 201: 0.326587    0.895296    3.438349    0.272586    0.098142    0.004246    0.711243    
#> 202: 0.331792    0.895735    3.439985    0.281950    0.098134    0.003945    0.708955    
#> 203: 0.345822    0.895977    3.439747    0.279752    0.103407    0.003871    0.705614    
#> 204: 0.342712    0.896929    3.438937    0.284737    0.110495    0.003726    0.706213    
#> 205: 0.336159    0.903940    3.438510    0.292204    0.117811    0.003727    0.707210    
#> 206: 0.335350    0.910250    3.438874    0.296674    0.117785    0.003781    0.710237    
#> 207: 0.327778    0.910716    3.437428    0.290257    0.116221    0.003877    0.711298    
#> 208: 0.323053    0.911938    3.436418    0.291415    0.114202    0.003932    0.708382    
#> 209: 0.324707    0.910695    3.435846    0.289904    0.112776    0.003965    0.705951    
#> 210: 0.324957    0.908780    3.435751    0.288458    0.112909    0.004010    0.703795    
#> 211: 0.327177    0.909907    3.436111    0.284419    0.113232    0.003942    0.702103    
#> 212: 0.329791    0.909580    3.436169    0.283423    0.112082    0.003911    0.701254    
#> 213: 0.331869    0.908838    3.436097    0.285909    0.111716    0.003914    0.701484    
#> 214: 0.333758    0.908825    3.436139    0.286780    0.111436    0.003962    0.701574    
#> 215: 0.333592    0.909442    3.436665    0.286354    0.111952    0.004073    0.700739    
#> 216: 0.335151    0.909011    3.436726    0.285093    0.111376    0.004130    0.702200    
#> 217: 0.336160    0.910307    3.436887    0.283917    0.110719    0.004158    0.701458    
#> 218: 0.336339    0.912154    3.436268    0.283218    0.110142    0.004201    0.700797    
#> 219: 0.334642    0.912728    3.435520    0.284235    0.110057    0.004229    0.700482    
#> 220: 0.332093    0.913798    3.435150    0.287108    0.110852    0.004275    0.700340    
#> 221: 0.329715    0.914406    3.434492    0.287422    0.111024    0.004333    0.699751    
#> 222: 0.330258    0.914608    3.434117    0.288628    0.110684    0.004440    0.699553    
#> 223: 0.329787    0.914563    3.433783    0.289565    0.110923    0.004557    0.698754    
#> 224: 0.330009    0.914722    3.433706    0.290113    0.111188    0.004610    0.698089    
#> 225: 0.329289    0.913208    3.434062    0.291153    0.111189    0.004665    0.698059    
#> 226: 0.328640    0.912311    3.434064    0.289957    0.110824    0.004696    0.698209    
#> 227: 0.328331    0.912359    3.434182    0.290588    0.110735    0.004709    0.698194    
#> 228: 0.326591    0.913521    3.433730    0.289536    0.110375    0.004794    0.698159    
#> 229: 0.325596    0.913501    3.433394    0.289995    0.109801    0.004866    0.697337    
#> 230: 0.326072    0.913642    3.433000    0.289974    0.109592    0.004887    0.696819    
#> 231: 0.325770    0.914381    3.432957    0.290007    0.109363    0.004902    0.696092    
#> 232: 0.324917    0.914805    3.432916    0.291692    0.108994    0.004923    0.695225    
#> 233: 0.323695    0.914332    3.432810    0.291778    0.108722    0.004910    0.695116    
#> 234: 0.323108    0.914862    3.432790    0.292285    0.108184    0.004904    0.694756    
#> 235: 0.322665    0.915069    3.432663    0.291805    0.108062    0.004900    0.694784    
#> 236: 0.322327    0.915436    3.432479    0.292684    0.107909    0.004897    0.695081    
#> 237: 0.322888    0.915598    3.432360    0.294219    0.108031    0.004871    0.695494    
#> 238: 0.322997    0.915826    3.432228    0.294767    0.108494    0.004872    0.695610    
#> 239: 0.322614    0.916230    3.432070    0.295032    0.108386    0.004857    0.695431    
#> 240: 0.322890    0.916012    3.432116    0.294445    0.108600    0.004851    0.695251    
#> 241: 0.322785    0.915352    3.432305    0.293752    0.108506    0.004856    0.695439    
#> 242: 0.322012    0.915183    3.432122    0.292304    0.108678    0.004875    0.695716    
#> 243: 0.321525    0.915780    3.432024    0.291309    0.108884    0.004884    0.695543    
#> 244: 0.321006    0.916080    3.432096    0.292729    0.108787    0.004916    0.695219    
#> 245: 0.320586    0.916102    3.432026    0.292830    0.108474    0.004920    0.695405    
#> 246: 0.320382    0.916106    3.432072    0.292863    0.108040    0.004969    0.694951    
#> 247: 0.320248    0.916164    3.432181    0.293005    0.107672    0.005015    0.694535    
#> 248: 0.320014    0.917211    3.432082    0.293012    0.107673    0.005027    0.694221    
#> 249: 0.319555    0.917514    3.432022    0.292800    0.107253    0.005020    0.694138    
#> 250: 0.320268    0.917577    3.432112    0.292140    0.106904    0.005036    0.694171    
#> 251: 0.320777    0.918050    3.432347    0.292969    0.106718    0.005075    0.694165    
#> 252: 0.321078    0.918373    3.432589    0.292946    0.106684    0.005111    0.693972    
#> 253: 0.321168    0.918841    3.432735    0.292662    0.106738    0.005131    0.693759    
#> 254: 0.321381    0.919366    3.432844    0.292586    0.106682    0.005151    0.693682    
#> 255: 0.321680    0.919607    3.433037    0.293242    0.106578    0.005188    0.693795    
#> 256: 0.321800    0.919471    3.433126    0.293293    0.106549    0.005222    0.693795    
#> 257: 0.321713    0.919323    3.433161    0.293744    0.106594    0.005221    0.693698    
#> 258: 0.321754    0.918830    3.433260    0.293881    0.106590    0.005209    0.693760    
#> 259: 0.321833    0.918682    3.433298    0.294966    0.106616    0.005193    0.693512    
#> 260: 0.321749    0.918943    3.433335    0.295568    0.106561    0.005181    0.693224    
#> 261: 0.321974    0.918847    3.433361    0.295981    0.106363    0.005183    0.693220    
#> 262: 0.321731    0.918928    3.433306    0.296294    0.106684    0.005176    0.693225    
#> 263: 0.321801    0.919191    3.433298    0.296288    0.106988    0.005206    0.693361    
#> 264: 0.321236    0.919404    3.433138    0.296006    0.107170    0.005223    0.693694    
#> 265: 0.321196    0.919712    3.433072    0.296074    0.107484    0.005252    0.693845    
#> 266: 0.320838    0.920101    3.432965    0.295794    0.107498    0.005271    0.693914    
#> 267: 0.320337    0.920357    3.432881    0.295968    0.107365    0.005281    0.694119    
#> 268: 0.320226    0.920319    3.432641    0.296223    0.107195    0.005300    0.694251    
#> 269: 0.320583    0.920454    3.432506    0.297454    0.107080    0.005308    0.694225    
#> 270: 0.320712    0.920652    3.432277    0.298296    0.106979    0.005309    0.694183    
#> 271: 0.320808    0.920730    3.432078    0.298831    0.106936    0.005300    0.694646    
#> 272: 0.320710    0.920708    3.431884    0.299373    0.107251    0.005299    0.694962    
#> 273: 0.320191    0.920963    3.431700    0.300425    0.107486    0.005302    0.695073    
#> 274: 0.319531    0.921371    3.431549    0.299810    0.107836    0.005288    0.695182    
#> 275: 0.319336    0.921733    3.431367    0.299690    0.108260    0.005278    0.695286    
#> 276: 0.319061    0.921917    3.431404    0.299594    0.108478    0.005265    0.695553    
#> 277: 0.318731    0.922051    3.431423    0.299870    0.108496    0.005268    0.695550    
#> 278: 0.318237    0.922108    3.431425    0.299536    0.108863    0.005257    0.695767    
#> 279: 0.317946    0.922062    3.431387    0.299300    0.108815    0.005246    0.695869    
#> 280: 0.318145    0.922265    3.431418    0.299352    0.108879    0.005239    0.695668    
#> 281: 0.318116    0.922290    3.431470    0.299218    0.109039    0.005223    0.695635    
#> 282: 0.318215    0.922405    3.431519    0.298787    0.109211    0.005221    0.695746    
#> 283: 0.318511    0.922435    3.431582    0.298773    0.109121    0.005221    0.695909    
#> 284: 0.318298    0.922315    3.431593    0.298298    0.109067    0.005211    0.695874    
#> 285: 0.318130    0.922436    3.431400    0.298299    0.108954    0.005216    0.695781    
#> 286: 0.317921    0.922682    3.431280    0.298162    0.108965    0.005217    0.695520    
#> 287: 0.317370    0.922848    3.431140    0.298152    0.108827    0.005234    0.695447    
#> 288: 0.317299    0.922787    3.431035    0.298058    0.108711    0.005249    0.695503    
#> 289: 0.317497    0.922690    3.431085    0.297843    0.108644    0.005249    0.695477    
#> 290: 0.317497    0.922666    3.431091    0.297717    0.108630    0.005249    0.695474    
#> 291: 0.317785    0.922681    3.431207    0.297827    0.108619    0.005250    0.695260    
#> 292: 0.317709    0.922791    3.431115    0.297776    0.108546    0.005239    0.695162    
#> 293: 0.317618    0.922942    3.430992    0.298301    0.108527    0.005237    0.694966    
#> 294: 0.317087    0.923079    3.430798    0.298587    0.108345    0.005238    0.694709    
#> 295: 0.317039    0.922976    3.430662    0.299119    0.108248    0.005246    0.694436    
#> 296: 0.317033    0.922803    3.430616    0.299272    0.108081    0.005259    0.694361    
#> 297: 0.316924    0.922858    3.430638    0.298971    0.107971    0.005269    0.694250    
#> 298: 0.316761    0.922643    3.430684    0.298966    0.107924    0.005260    0.694162    
#> 299: 0.316605    0.922838    3.430613    0.299042    0.107710    0.005238    0.694063    
#> 300: 0.316582    0.922703    3.430639    0.298756    0.107650    0.005236    0.693804    
#> 301: 0.316506    0.922479    3.430571    0.298880    0.107630    0.005225    0.693800    
#> 302: 0.316549    0.922580    3.430485    0.299103    0.107623    0.005228    0.693601    
#> 303: 0.316500    0.922694    3.430426    0.299188    0.107586    0.005237    0.693385    
#> 304: 0.316516    0.922999    3.430324    0.299413    0.107444    0.005248    0.693465    
#> 305: 0.316377    0.922784    3.430314    0.299103    0.107388    0.005267    0.693450    
#> 306: 0.315812    0.922893    3.430187    0.298810    0.107424    0.005282    0.693388    
#> 307: 0.315323    0.922940    3.430044    0.298645    0.107475    0.005273    0.693492    
#> 308: 0.314937    0.923026    3.429893    0.298945    0.107410    0.005277    0.693447    
#> 309: 0.314768    0.922896    3.429772    0.298870    0.107228    0.005290    0.693516    
#> 310: 0.314942    0.922819    3.429667    0.298646    0.107132    0.005289    0.693673    
#> 311: 0.314835    0.922793    3.429594    0.298452    0.107191    0.005296    0.693618    
#> 312: 0.314582    0.922679    3.429478    0.298815    0.107179    0.005303    0.693644    
#> 313: 0.314157    0.922362    3.429391    0.299316    0.107093    0.005298    0.693844    
#> 314: 0.313942    0.922456    3.429332    0.299456    0.107031    0.005297    0.693738    
#> 315: 0.313767    0.922517    3.429280    0.299443    0.106951    0.005298    0.693661    
#> 316: 0.313921    0.922809    3.429285    0.299387    0.106851    0.005296    0.693608    
#> 317: 0.314117    0.922882    3.429304    0.299973    0.106799    0.005289    0.693564    
#> 318: 0.314312    0.922934    3.429251    0.300081    0.106911    0.005289    0.693449    
#> 319: 0.314373    0.922866    3.429231    0.300373    0.107012    0.005288    0.693425    
#> 320: 0.313978    0.922885    3.429116    0.300211    0.106925    0.005274    0.693691    
#> 321: 0.313742    0.923037    3.428950    0.300334    0.106934    0.005266    0.693695    
#> 322: 0.314060    0.923063    3.428859    0.300803    0.106879    0.005270    0.693549    
#> 323: 0.313847    0.923010    3.428835    0.300629    0.106813    0.005268    0.693508    
#> 324: 0.313665    0.923142    3.428833    0.300588    0.106792    0.005272    0.693217    
#> 325: 0.313572    0.923365    3.428776    0.300600    0.106835    0.005270    0.693006    
#> 326: 0.313567    0.923291    3.428676    0.300508    0.106927    0.005261    0.692804    
#> 327: 0.313673    0.923377    3.428691    0.300829    0.106960    0.005265    0.692619    
#> 328: 0.313935    0.923410    3.428669    0.301266    0.107009    0.005262    0.692409    
#> 329: 0.314204    0.923357    3.428730    0.301632    0.106938    0.005260    0.692220    
#> 330: 0.314284    0.923309    3.428739    0.302330    0.106970    0.005260    0.692051    
#> 331: 0.314412    0.923384    3.428706    0.302823    0.107038    0.005258    0.691857    
#> 332: 0.314470    0.923547    3.428680    0.302880    0.107035    0.005259    0.691907    
#> 333: 0.314306    0.923689    3.428583    0.302563    0.107182    0.005262    0.691844    
#> 334: 0.314063    0.923525    3.428429    0.302796    0.107232    0.005266    0.691818    
#> 335: 0.313656    0.923591    3.428250    0.302740    0.107331    0.005259    0.691712    
#> 336: 0.313245    0.923820    3.428108    0.302724    0.107405    0.005260    0.691694    
#> 337: 0.312877    0.924194    3.427911    0.302535    0.107483    0.005264    0.691644    
#> 338: 0.312981    0.924263    3.427853    0.303309    0.107621    0.005255    0.691627    
#> 339: 0.312851    0.924274    3.427801    0.303691    0.107586    0.005249    0.691538    
#> 340: 0.312897    0.924125    3.427833    0.303375    0.107519    0.005253    0.691568    
#> 341: 0.312923    0.924029    3.427832    0.303269    0.107423    0.005256    0.691555    
#> 342: 0.312667    0.923923    3.427812    0.302973    0.107382    0.005262    0.691533    
#> 343: 0.312474    0.923928    3.427808    0.303025    0.107347    0.005278    0.691342    
#> 344: 0.312541    0.923934    3.427840    0.302937    0.107366    0.005289    0.691295    
#> 345: 0.312523    0.923956    3.427893    0.303072    0.107277    0.005303    0.691265    
#> 346: 0.312404    0.923952    3.427868    0.303254    0.107210    0.005305    0.691141    
#> 347: 0.312358    0.923888    3.427799    0.303319    0.107182    0.005307    0.691159    
#> 348: 0.312160    0.923952    3.427742    0.303510    0.107018    0.005313    0.691236    
#> 349: 0.312129    0.923951    3.427649    0.303622    0.106999    0.005322    0.691238    
#> 350: 0.311801    0.923895    3.427522    0.303548    0.106908    0.005336    0.691221    
#> 351: 0.311697    0.924110    3.427458    0.303320    0.106791    0.005350    0.691244    
#> 352: 0.311549    0.924269    3.427467    0.302941    0.106691    0.005364    0.691348    
#> 353: 0.311594    0.924395    3.427453    0.302960    0.106673    0.005368    0.691260    
#> 354: 0.311567    0.924364    3.427390    0.303185    0.106667    0.005363    0.691155    
#> 355: 0.311970    0.924192    3.427374    0.303674    0.106742    0.005363    0.691150    
#> 356: 0.311992    0.924069    3.427431    0.303964    0.106712    0.005371    0.691149    
#> 357: 0.312224    0.924070    3.427459    0.304200    0.106716    0.005368    0.691116    
#> 358: 0.312437    0.924111    3.427572    0.304495    0.106673    0.005369    0.690949    
#> 359: 0.312524    0.924162    3.427608    0.304442    0.106692    0.005370    0.690800    
#> 360: 0.312637    0.924207    3.427542    0.304382    0.106609    0.005379    0.690725    
#> 361: 0.312664    0.924139    3.427494    0.304342    0.106564    0.005391    0.690651    
#> 362: 0.312659    0.924043    3.427498    0.304469    0.106467    0.005390    0.690526    
#> 363: 0.312740    0.923920    3.427524    0.304295    0.106381    0.005395    0.690359    
#> 364: 0.312787    0.923957    3.427538    0.304155    0.106257    0.005407    0.690341    
#> 365: 0.312648    0.923904    3.427551    0.304037    0.106190    0.005420    0.690320    
#> 366: 0.312685    0.923926    3.427528    0.304264    0.106075    0.005431    0.690223    
#> 367: 0.312874    0.923909    3.427547    0.304581    0.106109    0.005437    0.690069    
#> 368: 0.313001    0.923915    3.427536    0.304507    0.106103    0.005439    0.689991    
#> 369: 0.312987    0.923888    3.427546    0.304404    0.106039    0.005442    0.690012    
#> 370: 0.312950    0.923968    3.427544    0.304514    0.105943    0.005452    0.689989    
#> 371: 0.312789    0.924074    3.427440    0.304428    0.105889    0.005461    0.690022    
#> 372: 0.312463    0.924206    3.427351    0.304277    0.105881    0.005457    0.690079    
#> 373: 0.312236    0.924372    3.427244    0.304436    0.105901    0.005454    0.690052    
#> 374: 0.312257    0.924451    3.427170    0.304997    0.105924    0.005454    0.689949    
#> 375: 0.312211    0.924458    3.427130    0.305753    0.105915    0.005460    0.689973    
#> 376: 0.312232    0.924435    3.427116    0.305898    0.105932    0.005460    0.689938    
#> 377: 0.311982    0.924500    3.427094    0.306261    0.105938    0.005460    0.689893    
#> 378: 0.311762    0.924581    3.427047    0.306314    0.105860    0.005459    0.689951    
#> 379: 0.311577    0.924549    3.427027    0.306215    0.105832    0.005457    0.689921    
#> 380: 0.311355    0.924513    3.426944    0.306009    0.105791    0.005455    0.689924    
#> 381: 0.311159    0.924611    3.426881    0.306064    0.105696    0.005458    0.689896    
#> 382: 0.311119    0.924724    3.426850    0.306159    0.105618    0.005455    0.689839    
#> 383: 0.311158    0.924729    3.426850    0.306278    0.105521    0.005453    0.689909    
#> 384: 0.311101    0.924741    3.426870    0.306529    0.105489    0.005456    0.689975    
#> 385: 0.311064    0.924607    3.426902    0.306486    0.105451    0.005458    0.689968    
#> 386: 0.311196    0.924677    3.426955    0.306317    0.105502    0.005466    0.689968    
#> 387: 0.311421    0.924763    3.427004    0.306274    0.105452    0.005479    0.689951    
#> 388: 0.311491    0.924837    3.427045    0.306171    0.105498    0.005489    0.689869    
#> 389: 0.311480    0.924752    3.427042    0.306080    0.105520    0.005488    0.689858    
#> 390: 0.311378    0.924851    3.427009    0.305901    0.105498    0.005491    0.689812    
#> 391: 0.311391    0.924857    3.426968    0.305914    0.105559    0.005492    0.689760    
#> 392: 0.311362    0.925022    3.426969    0.306144    0.105549    0.005493    0.689784    
#> 393: 0.311232    0.924959    3.426938    0.306032    0.105570    0.005496    0.689729    
#> 394: 0.311198    0.925025    3.426865    0.306178    0.105508    0.005504    0.689667    
#> 395: 0.311285    0.925133    3.426801    0.306381    0.105434    0.005510    0.689596    
#> 396: 0.311242    0.925228    3.426760    0.306387    0.105359    0.005516    0.689478    
#> 397: 0.311206    0.925139    3.426798    0.306301    0.105355    0.005524    0.689376    
#> 398: 0.311346    0.925093    3.426840    0.306384    0.105400    0.005534    0.689318    
#> 399: 0.311436    0.925136    3.426889    0.306503    0.105331    0.005544    0.689200    
#> 400: 0.311450    0.925238    3.426893    0.306508    0.105261    0.005553    0.689130    
#> 401: 0.311462    0.925295    3.426896    0.306647    0.105159    0.005562    0.689098    
#> 402: 0.311293    0.925456    3.426855    0.306807    0.105071    0.005575    0.689164    
#> 403: 0.311423    0.925509    3.426835    0.306970    0.105070    0.005580    0.689164    
#> 404: 0.311379    0.925616    3.426785    0.307267    0.105064    0.005582    0.689077    
#> 405: 0.311345    0.925727    3.426787    0.307489    0.105117    0.005580    0.689055    
#> 406: 0.311286    0.925810    3.426772    0.307644    0.105145    0.005575    0.689058    
#> 407: 0.311336    0.925778    3.426800    0.307841    0.105142    0.005573    0.689082    
#> 408: 0.311442    0.925812    3.426802    0.307812    0.105070    0.005573    0.689017    
#> 409: 0.311456    0.925775    3.426766    0.307795    0.105040    0.005569    0.688934    
#> 410: 0.311375    0.925786    3.426702    0.307732    0.105039    0.005578    0.688986    
#> 411: 0.311231    0.925676    3.426663    0.307657    0.105069    0.005585    0.688990    
#> 412: 0.311216    0.925746    3.426632    0.307724    0.104964    0.005594    0.688991    
#> 413: 0.311185    0.925824    3.426567    0.307920    0.104950    0.005598    0.688946    
#> 414: 0.310925    0.925862    3.426531    0.307825    0.104929    0.005606    0.688851    
#> 415: 0.310972    0.925891    3.426488    0.307843    0.104865    0.005615    0.688814    
#> 416: 0.310955    0.925916    3.426486    0.307830    0.104838    0.005626    0.688673    
#> 417: 0.310916    0.925912    3.426452    0.307662    0.104857    0.005635    0.688630    
#> 418: 0.310711    0.925942    3.426397    0.307413    0.104821    0.005642    0.688592    
#> 419: 0.310604    0.926052    3.426327    0.307356    0.104718    0.005654    0.688578    
#> 420: 0.310742    0.926055    3.426300    0.307494    0.104675    0.005665    0.688513    
#> 421: 0.310743    0.926060    3.426340    0.307421    0.104640    0.005678    0.688381    
#> 422: 0.311017    0.925960    3.426400    0.307258    0.104673    0.005697    0.688351    
#> 423: 0.311300    0.925836    3.426467    0.307324    0.104651    0.005706    0.688334    
#> 424: 0.311451    0.925815    3.426489    0.307418    0.104670    0.005705    0.688331    
#> 425: 0.311647    0.925851    3.426509    0.307564    0.104719    0.005703    0.688326    
#> 426: 0.311835    0.925862    3.426547    0.307811    0.104643    0.005707    0.688295    
#> 427: 0.311709    0.925813    3.426554    0.307894    0.104653    0.005712    0.688227    
#> 428: 0.311552    0.925884    3.426516    0.307985    0.104598    0.005724    0.688166    
#> 429: 0.311517    0.925918    3.426503    0.308098    0.104506    0.005739    0.688087    
#> 430: 0.311363    0.926052    3.426471    0.308041    0.104469    0.005746    0.688000    
#> 431: 0.311223    0.926061    3.426418    0.308224    0.104389    0.005750    0.687918    
#> 432: 0.311093    0.926104    3.426417    0.308375    0.104338    0.005755    0.687858    
#> 433: 0.311070    0.926185    3.426404    0.308393    0.104414    0.005752    0.687778    
#> 434: 0.310868    0.926161    3.426385    0.308116    0.104444    0.005755    0.687678    
#> 435: 0.310881    0.926259    3.426366    0.308159    0.104400    0.005759    0.687592    
#> 436: 0.310805    0.926145    3.426338    0.308075    0.104327    0.005765    0.687575    
#> 437: 0.310776    0.926026    3.426306    0.308372    0.104286    0.005775    0.687563    
#> 438: 0.310620    0.926118    3.426296    0.308518    0.104245    0.005771    0.687576    
#> 439: 0.310643    0.926170    3.426267    0.308672    0.104265    0.005772    0.687511    
#> 440: 0.310590    0.926215    3.426258    0.308690    0.104242    0.005772    0.687583    
#> 441: 0.310569    0.926219    3.426265    0.308728    0.104270    0.005773    0.687550    
#> 442: 0.310456    0.926254    3.426275    0.308702    0.104248    0.005765    0.687492    
#> 443: 0.310422    0.926340    3.426256    0.308615    0.104268    0.005762    0.687478    
#> 444: 0.310299    0.926430    3.426207    0.308698    0.104234    0.005764    0.687405    
#> 445: 0.310181    0.926530    3.426148    0.308591    0.104220    0.005763    0.687404    
#> 446: 0.310001    0.926660    3.426091    0.308502    0.104193    0.005760    0.687368    
#> 447: 0.310079    0.926749    3.426076    0.308758    0.104200    0.005758    0.687317    
#> 448: 0.310108    0.926707    3.426080    0.308978    0.104245    0.005753    0.687270    
#> 449: 0.310293    0.926772    3.426167    0.309131    0.104228    0.005756    0.687265    
#> 450: 0.310420    0.926718    3.426230    0.309157    0.104132    0.005758    0.687286    
#> 451: 0.310552    0.926677    3.426274    0.309060    0.104029    0.005768    0.687259    
#> 452: 0.310591    0.926656    3.426285    0.309022    0.103962    0.005771    0.687249    
#> 453: 0.310698    0.926643    3.426305    0.309273    0.103960    0.005772    0.687164    
#> 454: 0.310900    0.926734    3.426299    0.310014    0.103988    0.005770    0.687109    
#> 455: 0.311055    0.926788    3.426293    0.310458    0.103979    0.005766    0.687027    
#> 456: 0.311013    0.926821    3.426270    0.310663    0.103970    0.005767    0.687001    
#> 457: 0.310973    0.926829    3.426252    0.310836    0.103914    0.005771    0.686919    
#> 458: 0.310893    0.926930    3.426268    0.310909    0.103859    0.005783    0.686845    
#> 459: 0.310819    0.927022    3.426265    0.311012    0.103824    0.005793    0.686823    
#> 460: 0.310752    0.927102    3.426242    0.311119    0.103812    0.005800    0.686737    
#> 461: 0.310824    0.927169    3.426249    0.311194    0.103767    0.005811    0.686657    
#> 462: 0.310924    0.927230    3.426274    0.311299    0.103703    0.005822    0.686568    
#> 463: 0.311047    0.927296    3.426300    0.311425    0.103693    0.005825    0.686513    
#> 464: 0.311198    0.927278    3.426326    0.311739    0.103692    0.005825    0.686417    
#> 465: 0.311342    0.927151    3.426349    0.311974    0.103694    0.005828    0.686395    
#> 466: 0.311418    0.927191    3.426314    0.311924    0.103642    0.005830    0.686450    
#> 467: 0.311303    0.927173    3.426298    0.311980    0.103593    0.005837    0.686385    
#> 468: 0.311393    0.927221    3.426296    0.312021    0.103602    0.005837    0.686334    
#> 469: 0.311377    0.927337    3.426285    0.311937    0.103600    0.005832    0.686385    
#> 470: 0.311310    0.927399    3.426271    0.311781    0.103630    0.005829    0.686348    
#> 471: 0.311124    0.927381    3.426230    0.311623    0.103631    0.005829    0.686292    
#> 472: 0.310995    0.927348    3.426216    0.311465    0.103593    0.005829    0.686258    
#> 473: 0.310909    0.927319    3.426227    0.311436    0.103506    0.005836    0.686185    
#> 474: 0.310855    0.927304    3.426212    0.311444    0.103478    0.005843    0.686189    
#> 475: 0.310871    0.927361    3.426189    0.311553    0.103426    0.005843    0.686191    
#> 476: 0.310708    0.927418    3.426124    0.311508    0.103425    0.005840    0.686215    
#> 477: 0.310610    0.927439    3.426102    0.311476    0.103464    0.005835    0.686143    
#> 478: 0.310398    0.927446    3.426064    0.311538    0.103469    0.005833    0.686109    
#> 479: 0.310369    0.927525    3.426037    0.311665    0.103518    0.005831    0.686118    
#> 480: 0.310363    0.927517    3.426049    0.311739    0.103517    0.005832    0.686194    
#> 481: 0.310455    0.927525    3.426048    0.311910    0.103499    0.005835    0.686206    
#> 482: 0.310593    0.927510    3.426037    0.312165    0.103448    0.005843    0.686163    
#> 483: 0.310612    0.927436    3.426044    0.312193    0.103394    0.005847    0.686093    
#> 484: 0.310522    0.927390    3.426027    0.312091    0.103361    0.005848    0.686046    
#> 485: 0.310543    0.927469    3.426038    0.312073    0.103396    0.005857    0.685976    
#> 486: 0.310471    0.927528    3.426029    0.311993    0.103446    0.005858    0.685939    
#> 487: 0.310571    0.927545    3.426083    0.312124    0.103490    0.005862    0.685894    
#> 488: 0.310685    0.927512    3.426149    0.312124    0.103493    0.005870    0.685898    
#> 489: 0.310795    0.927457    3.426205    0.311925    0.103435    0.005875    0.685921    
#> 490: 0.310961    0.927427    3.426269    0.311678    0.103360    0.005877    0.685983    
#> 491: 0.311047    0.927468    3.426345    0.311649    0.103363    0.005880    0.685955    
#> 492: 0.311184    0.927477    3.426382    0.311758    0.103359    0.005883    0.686022    
#> 493: 0.311200    0.927486    3.426402    0.311916    0.103307    0.005892    0.686008    
#> 494: 0.311309    0.927506    3.426390    0.311923    0.103273    0.005897    0.685918    
#> 495: 0.311339    0.927518    3.426397    0.311966    0.103216    0.005902    0.685873    
#> 496: 0.311386    0.927627    3.426385    0.312006    0.103218    0.005911    0.685869    
#> 497: 0.311245    0.927661    3.426349    0.311926    0.103165    0.005913    0.685927    
#> 498: 0.311128    0.927723    3.426280    0.311877    0.103181    0.005907    0.685891    
#> 499: 0.310956    0.927823    3.426210    0.311701    0.103132    0.005905    0.685856    
#> 500: 0.310879    0.927812    3.426148    0.311619    0.103180    0.005902    0.685825    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.308345    0.958690    3.436662    0.392401    0.075863    0.016800    1.546999    
#> 002: 0.452520    0.950233    3.447248    0.372781    0.076384    0.015960    1.109030    
#> 003: 0.601456    0.863235    3.461510    0.354142    0.132100    0.015162    0.780470    
#> 004: 0.593272    0.843920    3.475452    0.336435    0.133573    0.014404    0.704307    
#> 005: 0.650194    0.862988    3.477726    0.319613    0.143225    0.013684    0.674742    
#> 006: 0.593752    0.883209    3.464236    0.303633    0.136064    0.013000    0.638613    
#> 007: 0.592766    0.882017    3.458355    0.288451    0.160208    0.012350    0.639840    
#> 008: 0.548391    0.870351    3.455119    0.274029    0.152198    0.011732    0.630903    
#> 009: 0.536435    0.870298    3.447637    0.260327    0.152108    0.011146    0.624281    
#> 010: 0.537970    0.881505    3.448476    0.247311    0.146532    0.010588    0.623094    
#> 011: 0.575865    0.866902    3.455410    0.234945    0.139205    0.011086    0.626960    
#> 012: 0.567422    0.870197    3.452698    0.223198    0.144076    0.010532    0.632836    
#> 013: 0.527749    0.888953    3.446492    0.248955    0.163877    0.011495    0.625685    
#> 014: 0.552467    0.895008    3.448184    0.236508    0.155683    0.011060    0.662753    
#> 015: 0.582883    0.889425    3.463426    0.226858    0.147899    0.011620    0.627498    
#> 016: 0.579345    0.877453    3.470101    0.238674    0.140504    0.011569    0.645868    
#> 017: 0.590694    0.880183    3.468095    0.226740    0.143558    0.012608    0.625848    
#> 018: 0.596479    0.886929    3.459451    0.264956    0.140241    0.014108    0.623404    
#> 019: 0.553741    0.881673    3.460857    0.251709    0.139379    0.013402    0.619293    
#> 020: 0.589358    0.893665    3.461261    0.270016    0.156246    0.012808    0.619190    
#> 021: 0.593702    0.887249    3.474665    0.256515    0.148433    0.013230    0.622938    
#> 022: 0.601597    0.892215    3.476896    0.243689    0.154224    0.012569    0.633637    
#> 023: 0.662777    0.886084    3.482597    0.251082    0.146512    0.011940    0.661313    
#> 024: 0.651476    0.894336    3.476731    0.251405    0.143408    0.011343    0.653730    
#> 025: 0.613095    0.862359    3.472094    0.241894    0.145556    0.010776    0.629925    
#> 026: 0.589024    0.893579    3.465273    0.244932    0.150107    0.010237    0.633137    
#> 027: 0.599961    0.908411    3.460301    0.291765    0.142601    0.010146    0.649458    
#> 028: 0.628507    0.879046    3.480729    0.277177    0.135471    0.014861    0.624725    
#> 029: 0.654222    0.867370    3.474037    0.267760    0.135745    0.014118    0.658764    
#> 030: 0.630481    0.881914    3.475225    0.254491    0.145581    0.013412    0.641579    
#> 031: 0.574772    0.862706    3.472283    0.278065    0.160419    0.012741    0.640669    
#> 032: 0.587088    0.853001    3.474728    0.264162    0.152398    0.013006    0.629730    
#> 033: 0.582818    0.876953    3.472015    0.250954    0.144778    0.013048    0.628061    
#> 034: 0.614823    0.895509    3.472237    0.238468    0.154773    0.014762    0.621854    
#> 035: 0.599365    0.865698    3.459342    0.226544    0.147035    0.014024    0.625290    
#> 036: 0.581170    0.887743    3.461690    0.245199    0.144926    0.013323    0.634249    
#> 037: 0.579104    0.887280    3.459343    0.253239    0.137680    0.016723    0.633066    
#> 038: 0.606464    0.901007    3.460099    0.258880    0.136379    0.017268    0.628047    
#> 039: 0.606863    0.896702    3.461859    0.251559    0.129560    0.016405    0.612793    
#> 040: 0.602472    0.874751    3.472047    0.247686    0.131279    0.015715    0.622889    
#> 041: 0.584735    0.899009    3.464186    0.253113    0.129809    0.014929    0.621722    
#> 042: 0.607116    0.862272    3.464046    0.263726    0.124839    0.014183    0.623120    
#> 043: 0.573286    0.867729    3.462066    0.260199    0.129713    0.014006    0.610234    
#> 044: 0.574489    0.892799    3.456145    0.271742    0.148748    0.013306    0.627307    
#> 045: 0.588935    0.906005    3.451369    0.302166    0.141311    0.013651    0.626634    
#> 046: 0.608682    0.889290    3.454380    0.287058    0.143509    0.014182    0.621722    
#> 047: 0.594400    0.892843    3.452180    0.286127    0.136333    0.013473    0.623091    
#> 048: 0.566856    0.903383    3.451732    0.271820    0.129516    0.012799    0.632578    
#> 049: 0.549650    0.898799    3.461387    0.258229    0.144594    0.013699    0.636626    
#> 050: 0.633997    0.867255    3.473537    0.277858    0.137364    0.015332    0.662094    
#> 051: 0.619821    0.879443    3.471271    0.268560    0.135123    0.015720    0.644357    
#> 052: 0.622798    0.882415    3.478088    0.282817    0.138982    0.014934    0.635263    
#> 053: 0.611775    0.862704    3.470914    0.278574    0.136602    0.014187    0.627539    
#> 054: 0.588029    0.854981    3.475050    0.264646    0.163884    0.013478    0.659667    
#> 055: 0.604032    0.875160    3.471675    0.251413    0.155690    0.012804    0.652694    
#> 056: 0.614651    0.859995    3.476774    0.238843    0.155800    0.012164    0.649351    
#> 057: 0.605486    0.860206    3.481791    0.241620    0.148010    0.013219    0.670286    
#> 058: 0.630428    0.870083    3.476119    0.235778    0.160466    0.012559    0.649519    
#> 059: 0.613768    0.852781    3.473305    0.241613    0.152443    0.011931    0.654545    
#> 060: 0.605656    0.843671    3.474105    0.229533    0.155184    0.011334    0.668195    
#> 061: 0.607088    0.882024    3.469828    0.218056    0.159719    0.012044    0.676228    
#> 062: 0.614021    0.889127    3.482247    0.207153    0.151733    0.012267    0.669354    
#> 063: 0.649586    0.853737    3.490730    0.200009    0.178914    0.011653    0.654798    
#> 064: 0.624325    0.844091    3.490003    0.190009    0.169969    0.011071    0.655354    
#> 065: 0.646947    0.848841    3.475421    0.192309    0.161470    0.010517    0.640748    
#> 066: 0.632728    0.885596    3.482128    0.197040    0.153397    0.010406    0.644719    
#> 067: 0.615948    0.854783    3.474215    0.187814    0.146500    0.010517    0.650781    
#> 068: 0.575595    0.870022    3.471816    0.200118    0.139175    0.010648    0.670840    
#> 069: 0.572048    0.876012    3.459792    0.204662    0.132216    0.011971    0.651951    
#> 070: 0.574993    0.872547    3.470533    0.210592    0.134213    0.013725    0.643055    
#> 071: 0.583894    0.893410    3.453040    0.262802    0.145994    0.013743    0.655351    
#> 072: 0.551291    0.881067    3.456525    0.255683    0.154472    0.013885    0.636377    
#> 073: 0.600195    0.898860    3.470678    0.289519    0.146748    0.013190    0.639219    
#> 074: 0.587704    0.860464    3.465131    0.276272    0.147319    0.012531    0.637881    
#> 075: 0.587791    0.849059    3.486698    0.278819    0.158630    0.012627    0.627142    
#> 076: 0.620288    0.877206    3.486150    0.302299    0.154398    0.011996    0.626793    
#> 077: 0.653941    0.853029    3.480150    0.293044    0.158973    0.013235    0.633992    
#> 078: 0.634056    0.857463    3.477661    0.286991    0.151025    0.013529    0.622835    
#> 079: 0.620307    0.858872    3.485992    0.272641    0.143473    0.014983    0.644239    
#> 080: 0.622275    0.850363    3.482251    0.270250    0.136300    0.014233    0.657210    
#> 081: 0.593667    0.895422    3.465524    0.272157    0.153501    0.013522    0.642719    
#> 082: 0.591415    0.868198    3.474994    0.258549    0.145826    0.015786    0.640223    
#> 083: 0.589078    0.901614    3.464681    0.245622    0.138535    0.017157    0.630619    
#> 084: 0.621965    0.903477    3.473349    0.259792    0.131608    0.017346    0.616181    
#> 085: 0.601315    0.889059    3.483036    0.246803    0.125028    0.016479    0.621089    
#> 086: 0.586360    0.885551    3.478973    0.235556    0.134695    0.015655    0.612294    
#> 087: 0.597477    0.892435    3.467030    0.265309    0.144235    0.014872    0.633217    
#> 088: 0.576441    0.897012    3.473173    0.252043    0.161427    0.014129    0.630043    
#> 089: 0.609361    0.893422    3.466460    0.239441    0.155064    0.013422    0.639995    
#> 090: 0.583312    0.886162    3.456216    0.227469    0.151105    0.012751    0.646863    
#> 091: 0.566153    0.887838    3.443929    0.216096    0.158229    0.012591    0.654207    
#> 092: 0.564559    0.899541    3.447409    0.205291    0.169502    0.011962    0.653070    
#> 093: 0.531498    0.888487    3.444248    0.208894    0.161026    0.012969    0.648513    
#> 094: 0.533508    0.898851    3.439964    0.198450    0.152975    0.012321    0.646400    
#> 095: 0.543976    0.883527    3.451544    0.188527    0.145326    0.011705    0.637617    
#> 096: 0.511922    0.884771    3.449594    0.179101    0.147015    0.011119    0.638328    
#> 097: 0.562085    0.889410    3.447157    0.193865    0.149572    0.012001    0.633168    
#> 098: 0.528366    0.921532    3.445178    0.216053    0.142093    0.012444    0.635349    
#> 099: 0.570449    0.882896    3.449956    0.205251    0.134989    0.012959    0.631985    
#> 100: 0.557310    0.902226    3.451415    0.244471    0.137763    0.013754    0.617175    
#> 101: 0.551270    0.888227    3.443351    0.232248    0.134550    0.013066    0.618608    
#> 102: 0.544178    0.902953    3.436329    0.231930    0.129977    0.012951    0.627508    
#> 103: 0.576949    0.884741    3.454755    0.248041    0.143574    0.012907    0.625802    
#> 104: 0.583449    0.869862    3.467302    0.257619    0.141562    0.012837    0.630619    
#> 105: 0.571768    0.847060    3.463687    0.244738    0.143952    0.013949    0.630272    
#> 106: 0.583840    0.867115    3.463424    0.264575    0.148169    0.014384    0.629262    
#> 107: 0.602077    0.883983    3.466349    0.279399    0.140764    0.013665    0.625978    
#> 108: 0.583650    0.864349    3.467430    0.275251    0.133726    0.016090    0.620756    
#> 109: 0.583315    0.890350    3.470631    0.261488    0.127040    0.015881    0.636385    
#> 110: 0.600421    0.859455    3.462661    0.248414    0.133813    0.015087    0.623930    
#> 111: 0.584112    0.879272    3.464713    0.238675    0.139382    0.014333    0.616412    
#> 112: 0.564910    0.867179    3.452912    0.226741    0.140943    0.013881    0.623193    
#> 113: 0.566572    0.905645    3.456429    0.241492    0.138088    0.014013    0.618485    
#> 114: 0.583613    0.890330    3.465456    0.267230    0.138928    0.014663    0.620546    
#> 115: 0.604626    0.868122    3.463264    0.257569    0.136559    0.015291    0.631918    
#> 116: 0.604555    0.881129    3.464217    0.248140    0.132156    0.017135    0.630378    
#> 117: 0.562274    0.890590    3.466690    0.254042    0.146003    0.016278    0.641087    
#> 118: 0.588363    0.873443    3.470430    0.256605    0.140959    0.015464    0.624990    
#> 119: 0.581099    0.881347    3.463611    0.259604    0.133912    0.017758    0.634685    
#> 120: 0.559995    0.873585    3.459402    0.263084    0.130487    0.017835    0.629444    
#> 121: 0.556803    0.895119    3.452085    0.273468    0.130415    0.016944    0.643280    
#> 122: 0.573230    0.865217    3.463326    0.259795    0.137018    0.016096    0.637008    
#> 123: 0.617203    0.903175    3.462700    0.246805    0.137954    0.015292    0.626136    
#> 124: 0.596884    0.917573    3.456622    0.249743    0.133439    0.015108    0.627196    
#> 125: 0.612752    0.911138    3.453248    0.271980    0.146286    0.014353    0.621209    
#> 126: 0.572074    0.909963    3.447430    0.281391    0.138972    0.014374    0.618055    
#> 127: 0.596620    0.895982    3.444991    0.311308    0.133655    0.013656    0.626983    
#> 128: 0.553422    0.894648    3.450974    0.295743    0.131024    0.013403    0.640980    
#> 129: 0.571465    0.907493    3.452108    0.280955    0.138698    0.012733    0.645616    
#> 130: 0.614514    0.884080    3.458380    0.266908    0.143913    0.012096    0.627830    
#> 131: 0.599558    0.893787    3.451862    0.253562    0.136718    0.012225    0.646587    
#> 132: 0.562952    0.891903    3.445846    0.240884    0.155059    0.011614    0.652457    
#> 133: 0.573967    0.882549    3.452921    0.290580    0.162398    0.011033    0.653085    
#> 134: 0.583314    0.869356    3.456542    0.276051    0.154279    0.011063    0.646089    
#> 135: 0.567799    0.867848    3.464512    0.262249    0.159360    0.011508    0.640175    
#> 136: 0.585132    0.860971    3.459685    0.249136    0.151392    0.010933    0.643535    
#> 137: 0.589391    0.874431    3.461193    0.244564    0.143823    0.010386    0.640003    
#> 138: 0.559418    0.907089    3.455135    0.256832    0.146340    0.010733    0.630579    
#> 139: 0.556931    0.908203    3.459312    0.265430    0.142792    0.012859    0.615272    
#> 140: 0.562587    0.904639    3.456829    0.252159    0.135652    0.014630    0.626711    
#> 141: 0.587418    0.858876    3.464801    0.267403    0.139091    0.014799    0.609111    
#> 142: 0.624225    0.864035    3.479707    0.281140    0.138355    0.014059    0.626437    
#> 143: 0.605885    0.893330    3.475945    0.268597    0.142243    0.014492    0.632880    
#> 144: 0.650035    0.876160    3.485368    0.300787    0.136110    0.014165    0.620153    
#> 145: 0.625103    0.878490    3.480014    0.285748    0.129304    0.016254    0.608759    
#> 146: 0.617511    0.872054    3.483411    0.287739    0.134546    0.015441    0.623544    
#> 147: 0.574361    0.878503    3.466517    0.273352    0.153441    0.014669    0.620662    
#> 148: 0.563522    0.889594    3.471364    0.259684    0.145769    0.013936    0.621855    
#> 149: 0.580242    0.886413    3.463690    0.290339    0.148752    0.013239    0.610749    
#> 150: 0.609031    0.875678    3.461105    0.275822    0.155212    0.012772    0.623614    
#> 151: 0.583632    0.899116    3.468405    0.271258    0.147451    0.013933    0.614324    
#> 152: 0.582088    0.885765    3.467879    0.255629    0.135128    0.015667    0.601169    
#> 153: 0.615694    0.881385    3.484625    0.245083    0.130888    0.016469    0.624217    
#> 154: 0.632597    0.875462    3.472941    0.232330    0.129380    0.015210    0.633203    
#> 155: 0.609004    0.859467    3.475702    0.196246    0.137304    0.014897    0.630896    
#> 156: 0.610543    0.877241    3.474584    0.231295    0.138194    0.017306    0.641576    
#> 157: 0.606875    0.846489    3.482195    0.290280    0.137420    0.017668    0.655672    
#> 158: 0.642082    0.874587    3.482746    0.236078    0.144579    0.014265    0.651302    
#> 159: 0.605398    0.859650    3.483452    0.243681    0.162171    0.012441    0.649216    
#> 160: 0.613735    0.825201    3.483581    0.222089    0.163630    0.011808    0.651413    
#> 161: 0.623777    0.858807    3.472366    0.253908    0.140585    0.014759    0.649466    
#> 162: 0.592458    0.863773    3.467499    0.225686    0.137816    0.012256    0.643298    
#> 163: 0.591201    0.877123    3.459746    0.201921    0.145059    0.011051    0.640198    
#> 164: 0.598591    0.891789    3.463408    0.219943    0.147163    0.011845    0.623406    
#> 165: 0.603617    0.884117    3.471170    0.252759    0.142350    0.011885    0.627670    
#> 166: 0.622861    0.900500    3.470631    0.256095    0.120310    0.012035    0.637179    
#> 167: 0.603160    0.903490    3.465808    0.237806    0.139197    0.015091    0.648618    
#> 168: 0.612965    0.892943    3.463572    0.294021    0.142147    0.017212    0.628941    
#> 169: 0.604477    0.916075    3.461845    0.272362    0.145271    0.013954    0.639662    
#> 170: 0.592109    0.901125    3.455047    0.290273    0.149517    0.015022    0.624112    
#> 171: 0.547673    0.896156    3.449917    0.279902    0.134202    0.013176    0.620728    
#> 172: 0.542101    0.889267    3.450950    0.268075    0.134132    0.011224    0.617160    
#> 173: 0.567037    0.900887    3.447242    0.267366    0.138093    0.013611    0.615626    
#> 174: 0.612440    0.886008    3.467720    0.307287    0.130683    0.013560    0.615221    
#> 175: 0.585808    0.872479    3.460295    0.256962    0.127664    0.013791    0.621498    
#> 176: 0.566242    0.900081    3.462872    0.246050    0.157710    0.012314    0.620253    
#> 177: 0.608050    0.879596    3.471837    0.252325    0.151441    0.012508    0.617564    
#> 178: 0.627799    0.865399    3.477219    0.237396    0.145151    0.010968    0.615820    
#> 179: 0.642103    0.884950    3.470825    0.232905    0.153539    0.010385    0.640308    
#> 180: 0.589603    0.869297    3.461278    0.259007    0.145133    0.008134    0.632810    
#> 181: 0.580618    0.892075    3.454554    0.245242    0.157837    0.009262    0.622110    
#> 182: 0.557874    0.893007    3.443341    0.269145    0.143109    0.010919    0.635205    
#> 183: 0.568519    0.925983    3.443714    0.269210    0.146316    0.011906    0.630572    
#> 184: 0.532504    0.906936    3.442774    0.268858    0.159985    0.012776    0.634104    
#> 185: 0.524865    0.923790    3.440387    0.243785    0.137048    0.013408    0.632167    
#> 186: 0.555876    0.905774    3.448687    0.263723    0.136352    0.013076    0.639684    
#> 187: 0.572326    0.893666    3.456995    0.260676    0.139284    0.014895    0.630030    
#> 188: 0.566201    0.894466    3.464494    0.241504    0.148546    0.014331    0.640181    
#> 189: 0.586910    0.880377    3.471787    0.210985    0.153299    0.015573    0.647904    
#> 190: 0.591763    0.877947    3.472337    0.259311    0.133264    0.015270    0.628549    
#> 191: 0.595322    0.888464    3.456410    0.281123    0.123486    0.013694    0.621134    
#> 192: 0.578730    0.914649    3.464082    0.257112    0.134918    0.012164    0.605853    
#> 193: 0.615896    0.881048    3.464960    0.273389    0.146330    0.014628    0.610908    
#> 194: 0.571322    0.871212    3.463067    0.282736    0.133316    0.014809    0.619097    
#> 195: 0.534862    0.873781    3.456649    0.268978    0.117698    0.014587    0.632371    
#> 196: 0.574749    0.889091    3.461048    0.249677    0.115082    0.012702    0.630071    
#> 197: 0.561017    0.901591    3.468205    0.231335    0.137297    0.011604    0.639483    
#> 198: 0.585820    0.872022    3.461380    0.233127    0.149341    0.011666    0.633400    
#> 199: 0.561302    0.895392    3.457799    0.212857    0.141769    0.009889    0.631140    
#> 200: 0.561287    0.899315    3.454161    0.231606    0.162753    0.010714    0.645455    
#> 201: 0.557573    0.902260    3.457094    0.243854    0.162147    0.010979    0.641779    
#> 202: 0.557553    0.906927    3.454573    0.243674    0.155162    0.011564    0.644465    
#> 203: 0.564556    0.904137    3.453039    0.242060    0.152242    0.011804    0.643775    
#> 204: 0.565031    0.894770    3.454439    0.240445    0.152300    0.011492    0.646909    
#> 205: 0.565716    0.898035    3.454812    0.243640    0.152511    0.011371    0.647974    
#> 206: 0.565274    0.898277    3.454676    0.253364    0.150778    0.011636    0.648799    
#> 207: 0.563126    0.895434    3.453418    0.255176    0.149776    0.011501    0.647205    
#> 208: 0.563814    0.893201    3.454092    0.252341    0.149595    0.011308    0.645087    
#> 209: 0.567448    0.888670    3.454574    0.247877    0.149248    0.011402    0.643799    
#> 210: 0.569431    0.888025    3.454926    0.247927    0.148584    0.011641    0.642383    
#> 211: 0.572124    0.888516    3.456148    0.247934    0.149450    0.011718    0.640241    
#> 212: 0.574888    0.887292    3.457046    0.245473    0.147857    0.011792    0.640915    
#> 213: 0.577180    0.887207    3.457609    0.242659    0.146581    0.011976    0.642294    
#> 214: 0.579168    0.886958    3.458447    0.241970    0.147068    0.011994    0.642656    
#> 215: 0.578809    0.886930    3.458872    0.240313    0.146772    0.012082    0.642702    
#> 216: 0.581145    0.884886    3.459334    0.239470    0.146498    0.012158    0.643758    
#> 217: 0.580664    0.885529    3.459339    0.239442    0.146276    0.012018    0.642417    
#> 218: 0.580938    0.884883    3.459484    0.238343    0.146009    0.011904    0.641225    
#> 219: 0.581094    0.884580    3.459225    0.239713    0.145694    0.011831    0.640960    
#> 220: 0.581354    0.884421    3.459384    0.241731    0.145357    0.011879    0.640764    
#> 221: 0.581343    0.884745    3.459352    0.242481    0.146251    0.011896    0.639983    
#> 222: 0.581620    0.884455    3.459291    0.243064    0.145923    0.012050    0.639427    
#> 223: 0.583567    0.883553    3.459457    0.243997    0.145236    0.012291    0.639153    
#> 224: 0.585872    0.883554    3.459975    0.244408    0.144375    0.012502    0.638929    
#> 225: 0.586148    0.882103    3.460713    0.245673    0.143359    0.012626    0.639188    
#> 226: 0.586621    0.881368    3.460963    0.244359    0.142949    0.012622    0.638959    
#> 227: 0.586674    0.881409    3.461193    0.244124    0.143408    0.012632    0.638847    
#> 228: 0.585705    0.881916    3.461169    0.243032    0.143204    0.012640    0.638521    
#> 229: 0.585237    0.882411    3.461173    0.242871    0.143223    0.012684    0.637810    
#> 230: 0.586321    0.882527    3.461214    0.242940    0.143113    0.012692    0.637496    
#> 231: 0.586404    0.883368    3.461376    0.243427    0.142327    0.012679    0.636911    
#> 232: 0.585379    0.883578    3.461480    0.242333    0.141836    0.012659    0.636460    
#> 233: 0.584900    0.882932    3.461482    0.241128    0.141337    0.012606    0.636383    
#> 234: 0.583923    0.882940    3.461406    0.240776    0.141139    0.012644    0.636088    
#> 235: 0.583733    0.883160    3.461280    0.240360    0.140575    0.012675    0.635676    
#> 236: 0.583367    0.883580    3.461092    0.239882    0.140496    0.012709    0.635594    
#> 237: 0.584014    0.883359    3.461102    0.240083    0.140672    0.012685    0.636235    
#> 238: 0.584598    0.883443    3.461114    0.240392    0.140935    0.012717    0.636599    
#> 239: 0.585125    0.883461    3.461177    0.241489    0.140540    0.012877    0.636339    
#> 240: 0.585923    0.882979    3.461545    0.242390    0.140170    0.012984    0.635664    
#> 241: 0.587153    0.882038    3.461870    0.243433    0.139979    0.013047    0.635290    
#> 242: 0.587058    0.881320    3.461930    0.243595    0.139839    0.013085    0.635645    
#> 243: 0.586089    0.881779    3.461672    0.242891    0.139797    0.013137    0.635835    
#> 244: 0.585205    0.882253    3.461479    0.244272    0.139965    0.013117    0.636100    
#> 245: 0.584485    0.882076    3.461301    0.244697    0.140299    0.013079    0.636389    
#> 246: 0.584532    0.881817    3.461502    0.244637    0.140396    0.013091    0.636635    
#> 247: 0.584679    0.881740    3.461688    0.245163    0.140742    0.013077    0.636711    
#> 248: 0.583921    0.881841    3.461607    0.244891    0.141512    0.012979    0.636492    
#> 249: 0.583125    0.881564    3.461609    0.244417    0.141746    0.012920    0.636398    
#> 250: 0.583502    0.881762    3.461640    0.244059    0.141890    0.012870    0.636507    
#> 251: 0.583447    0.882088    3.461925    0.242827    0.142094    0.012828    0.636738    
#> 252: 0.583473    0.882487    3.462187    0.241680    0.142554    0.012800    0.636426    
#> 253: 0.583252    0.882758    3.462138    0.240878    0.143047    0.012741    0.636530    
#> 254: 0.583455    0.882873    3.462322    0.240689    0.143047    0.012740    0.636575    
#> 255: 0.583443    0.883130    3.462440    0.241226    0.143170    0.012745    0.636292    
#> 256: 0.583543    0.883147    3.462426    0.241017    0.143427    0.012728    0.636234    
#> 257: 0.583775    0.883135    3.462309    0.241130    0.143443    0.012698    0.636377    
#> 258: 0.583631    0.882915    3.462396    0.240290    0.143324    0.012694    0.636426    
#> 259: 0.583972    0.882688    3.462423    0.240387    0.143183    0.012705    0.636393    
#> 260: 0.584062    0.882841    3.462441    0.240320    0.143050    0.012712    0.636180    
#> 261: 0.584520    0.882795    3.462576    0.240595    0.143067    0.012720    0.635788    
#> 262: 0.584885    0.882871    3.462740    0.240716    0.143191    0.012705    0.635665    
#> 263: 0.585238    0.883035    3.462921    0.240767    0.143399    0.012703    0.635579    
#> 264: 0.585007    0.883102    3.462953    0.240510    0.143727    0.012675    0.635464    
#> 265: 0.585302    0.883169    3.462928    0.240736    0.144222    0.012678    0.635160    
#> 266: 0.585259    0.883334    3.462884    0.240818    0.144121    0.012685    0.635133    
#> 267: 0.584916    0.883538    3.462904    0.240604    0.144041    0.012665    0.635258    
#> 268: 0.585446    0.883186    3.462962    0.241083    0.144217    0.012666    0.635197    
#> 269: 0.586156    0.883115    3.463113    0.241425    0.144268    0.012680    0.635176    
#> 270: 0.586666    0.883023    3.463091    0.241825    0.144339    0.012694    0.634991    
#> 271: 0.586712    0.882877    3.463027    0.242312    0.144513    0.012699    0.634897    
#> 272: 0.586817    0.882626    3.463004    0.243111    0.144798    0.012710    0.634855    
#> 273: 0.587182    0.882540    3.463075    0.244032    0.144996    0.012723    0.634782    
#> 274: 0.587158    0.882590    3.463241    0.245008    0.145287    0.012697    0.634970    
#> 275: 0.587281    0.882670    3.463206    0.245407    0.145589    0.012668    0.634898    
#> 276: 0.587367    0.882847    3.463309    0.246087    0.145870    0.012645    0.634799    
#> 277: 0.587501    0.882987    3.463485    0.246307    0.146078    0.012647    0.634566    
#> 278: 0.587875    0.882681    3.463756    0.246400    0.146263    0.012657    0.634644    
#> 279: 0.587808    0.882389    3.463779    0.246284    0.146273    0.012665    0.634804    
#> 280: 0.587785    0.882599    3.463826    0.246694    0.146277    0.012660    0.634563    
#> 281: 0.587648    0.882998    3.463833    0.246357    0.146374    0.012660    0.634567    
#> 282: 0.587516    0.883113    3.463875    0.246405    0.146574    0.012653    0.634571    
#> 283: 0.587660    0.883243    3.463960    0.246100    0.146623    0.012637    0.634959    
#> 284: 0.587551    0.882990    3.463975    0.245762    0.146704    0.012605    0.635180    
#> 285: 0.587661    0.882847    3.463918    0.245193    0.146729    0.012589    0.635286    
#> 286: 0.587838    0.882931    3.463948    0.244640    0.146780    0.012587    0.635161    
#> 287: 0.587800    0.882903    3.463943    0.244533    0.146599    0.012582    0.635142    
#> 288: 0.588260    0.882439    3.464092    0.244577    0.146485    0.012629    0.635023    
#> 289: 0.588480    0.882301    3.464213    0.245183    0.146516    0.012658    0.634979    
#> 290: 0.588900    0.882294    3.464303    0.245732    0.146624    0.012649    0.635090    
#> 291: 0.589159    0.882271    3.464390    0.245637    0.146470    0.012657    0.634934    
#> 292: 0.589050    0.882293    3.464399    0.245473    0.146228    0.012652    0.634939    
#> 293: 0.588733    0.882216    3.464274    0.245577    0.146108    0.012627    0.634824    
#> 294: 0.588337    0.882215    3.464161    0.245468    0.145957    0.012606    0.634769    
#> 295: 0.588383    0.882062    3.464074    0.245193    0.145863    0.012599    0.634721    
#> 296: 0.588109    0.882229    3.463986    0.245260    0.145813    0.012602    0.634770    
#> 297: 0.588091    0.882468    3.464006    0.245217    0.145518    0.012610    0.634834    
#> 298: 0.588262    0.882563    3.464033    0.245336    0.145592    0.012563    0.634895    
#> 299: 0.588274    0.882696    3.463959    0.245129    0.145593    0.012528    0.634859    
#> 300: 0.588429    0.882711    3.464002    0.244881    0.145420    0.012554    0.634825    
#> 301: 0.588618    0.882607    3.463985    0.245192    0.145545    0.012567    0.634810    
#> 302: 0.588883    0.882601    3.463992    0.245285    0.145665    0.012575    0.634692    
#> 303: 0.588689    0.882654    3.463939    0.245123    0.145675    0.012579    0.634557    
#> 304: 0.588733    0.882883    3.463820    0.244862    0.145603    0.012565    0.634639    
#> 305: 0.588154    0.882797    3.463694    0.244542    0.145496    0.012548    0.634697    
#> 306: 0.587798    0.882720    3.463538    0.244423    0.145572    0.012547    0.634711    
#> 307: 0.587519    0.882619    3.463490    0.244698    0.145559    0.012547    0.634582    
#> 308: 0.587002    0.882412    3.463493    0.244623    0.145348    0.012548    0.634791    
#> 309: 0.586952    0.882282    3.463495    0.244651    0.145368    0.012550    0.634657    
#> 310: 0.587037    0.882343    3.463443    0.244609    0.145223    0.012528    0.634713    
#> 311: 0.586903    0.882522    3.463420    0.244545    0.145095    0.012527    0.634711    
#> 312: 0.586949    0.882462    3.463386    0.244852    0.144944    0.012532    0.634650    
#> 313: 0.586939    0.882244    3.463329    0.244900    0.144769    0.012526    0.634802    
#> 314: 0.586592    0.882353    3.463191    0.244956    0.144910    0.012538    0.634878    
#> 315: 0.586214    0.882564    3.463056    0.244746    0.145003    0.012530    0.634956    
#> 316: 0.586039    0.882813    3.462935    0.244540    0.145015    0.012531    0.635073    
#> 317: 0.586007    0.882944    3.462927    0.244923    0.144979    0.012532    0.635056    
#> 318: 0.585966    0.883031    3.462834    0.244991    0.145037    0.012517    0.635086    
#> 319: 0.585698    0.882993    3.462791    0.244957    0.144952    0.012523    0.635143    
#> 320: 0.585179    0.882930    3.462639    0.244785    0.144919    0.012520    0.635357    
#> 321: 0.584630    0.883090    3.462393    0.244731    0.144855    0.012506    0.635628    
#> 322: 0.584367    0.883032    3.462288    0.244334    0.144920    0.012513    0.635615    
#> 323: 0.583827    0.883121    3.462195    0.244026    0.144938    0.012507    0.635561    
#> 324: 0.583627    0.883218    3.462190    0.243656    0.144914    0.012513    0.635322    
#> 325: 0.583286    0.883427    3.462060    0.243483    0.144818    0.012519    0.635185    
#> 326: 0.583219    0.883383    3.461973    0.243504    0.144813    0.012521    0.635000    
#> 327: 0.583117    0.883470    3.461965    0.243412    0.144739    0.012552    0.634945    
#> 328: 0.583055    0.883591    3.461929    0.243175    0.144591    0.012556    0.634875    
#> 329: 0.583159    0.883644    3.461910    0.243123    0.144693    0.012549    0.634930    
#> 330: 0.582885    0.883802    3.461854    0.242907    0.144820    0.012538    0.635095    
#> 331: 0.582820    0.883970    3.461707    0.242922    0.144912    0.012512    0.635039    
#> 332: 0.582809    0.884059    3.461728    0.242980    0.144817    0.012494    0.635051    
#> 333: 0.582434    0.884136    3.461600    0.242816    0.144704    0.012487    0.634976    
#> 334: 0.582166    0.884137    3.461447    0.242735    0.144731    0.012491    0.634864    
#> 335: 0.581868    0.884307    3.461287    0.242666    0.144692    0.012495    0.634919    
#> 336: 0.581544    0.884442    3.461160    0.243163    0.144728    0.012516    0.635041    
#> 337: 0.581226    0.884774    3.461020    0.243134    0.144753    0.012524    0.635057    
#> 338: 0.581108    0.885032    3.460941    0.243023    0.144820    0.012509    0.635033    
#> 339: 0.580910    0.885164    3.460854    0.242849    0.145001    0.012492    0.635067    
#> 340: 0.580799    0.885057    3.460847    0.242515    0.145111    0.012482    0.635128    
#> 341: 0.580951    0.885096    3.460890    0.242398    0.145168    0.012471    0.635109    
#> 342: 0.580858    0.884953    3.460919    0.242202    0.145136    0.012453    0.635056    
#> 343: 0.580770    0.884937    3.461017    0.242104    0.145112    0.012455    0.634933    
#> 344: 0.580976    0.884851    3.461108    0.242213    0.145009    0.012465    0.634879    
#> 345: 0.581264    0.884821    3.461203    0.242205    0.144949    0.012470    0.634789    
#> 346: 0.581281    0.884752    3.461183    0.241926    0.144945    0.012465    0.634787    
#> 347: 0.581364    0.884657    3.461173    0.241825    0.144932    0.012458    0.634899    
#> 348: 0.581281    0.884671    3.461157    0.241764    0.144970    0.012439    0.634879    
#> 349: 0.581109    0.884575    3.461146    0.241675    0.144933    0.012423    0.634839    
#> 350: 0.580993    0.884420    3.461141    0.241757    0.145038    0.012428    0.634865    
#> 351: 0.581103    0.884447    3.461092    0.241872    0.144913    0.012424    0.634919    
#> 352: 0.580751    0.884672    3.461031    0.241686    0.144826    0.012416    0.635095    
#> 353: 0.580678    0.884741    3.460972    0.241389    0.144823    0.012407    0.635094    
#> 354: 0.580662    0.884787    3.460893    0.241182    0.144804    0.012393    0.635055    
#> 355: 0.580826    0.884785    3.460860    0.241060    0.144823    0.012379    0.635030    
#> 356: 0.580905    0.884804    3.460883    0.241178    0.144862    0.012376    0.635063    
#> 357: 0.581010    0.884878    3.460903    0.241249    0.144916    0.012373    0.634933    
#> 358: 0.581011    0.884849    3.460902    0.241611    0.144969    0.012373    0.634778    
#> 359: 0.580935    0.884924    3.460854    0.241777    0.144972    0.012373    0.634789    
#> 360: 0.580778    0.884993    3.460766    0.241856    0.144974    0.012386    0.634685    
#> 361: 0.580496    0.885055    3.460673    0.241781    0.145013    0.012392    0.634669    
#> 362: 0.580365    0.885095    3.460563    0.241652    0.144928    0.012384    0.634556    
#> 363: 0.580257    0.885048    3.460529    0.241545    0.144930    0.012387    0.634373    
#> 364: 0.580248    0.884945    3.460557    0.241192    0.144833    0.012395    0.634428    
#> 365: 0.580256    0.884856    3.460641    0.241106    0.144754    0.012420    0.634431    
#> 366: 0.580288    0.884749    3.460649    0.241280    0.144729    0.012439    0.634449    
#> 367: 0.580512    0.884653    3.460684    0.241353    0.144698    0.012447    0.634439    
#> 368: 0.580800    0.884662    3.460741    0.241310    0.144672    0.012451    0.634315    
#> 369: 0.580915    0.884589    3.460759    0.241247    0.144605    0.012457    0.634326    
#> 370: 0.580994    0.884709    3.460740    0.241214    0.144484    0.012466    0.634306    
#> 371: 0.580992    0.884785    3.460662    0.241012    0.144436    0.012463    0.634207    
#> 372: 0.581026    0.884763    3.460702    0.241095    0.144532    0.012472    0.634194    
#> 373: 0.580912    0.884849    3.460684    0.241062    0.144488    0.012491    0.634176    
#> 374: 0.580961    0.884854    3.460695    0.241251    0.144388    0.012496    0.634092    
#> 375: 0.580890    0.884881    3.460687    0.241247    0.144224    0.012503    0.634023    
#> 376: 0.580845    0.885004    3.460697    0.241187    0.144183    0.012505    0.633940    
#> 377: 0.580701    0.885084    3.460689    0.241071    0.144195    0.012497    0.633925    
#> 378: 0.580502    0.885137    3.460662    0.241112    0.144155    0.012482    0.633976    
#> 379: 0.580195    0.885091    3.460628    0.240832    0.144155    0.012471    0.634028    
#> 380: 0.580038    0.885066    3.460591    0.240663    0.144187    0.012467    0.633931    
#> 381: 0.579763    0.884945    3.460554    0.240483    0.144263    0.012463    0.633944    
#> 382: 0.579809    0.884973    3.460579    0.240371    0.144115    0.012464    0.633905    
#> 383: 0.579859    0.884975    3.460569    0.240284    0.144084    0.012467    0.633848    
#> 384: 0.579965    0.884923    3.460629    0.240272    0.144040    0.012466    0.633813    
#> 385: 0.580096    0.884807    3.460717    0.240030    0.144027    0.012472    0.633864    
#> 386: 0.580121    0.884893    3.460778    0.239961    0.143946    0.012477    0.633869    
#> 387: 0.580195    0.885029    3.460840    0.239904    0.143981    0.012476    0.633853    
#> 388: 0.580239    0.885210    3.460852    0.240022    0.144008    0.012482    0.633782    
#> 389: 0.580312    0.885035    3.460884    0.240104    0.144000    0.012472    0.633913    
#> 390: 0.580306    0.884972    3.460900    0.240017    0.144015    0.012457    0.633888    
#> 391: 0.580484    0.884908    3.460920    0.239915    0.144032    0.012452    0.633858    
#> 392: 0.580485    0.884834    3.460917    0.239899    0.144124    0.012432    0.633858    
#> 393: 0.580524    0.884723    3.460900    0.239776    0.144206    0.012418    0.633943    
#> 394: 0.580612    0.884768    3.460900    0.239877    0.144231    0.012420    0.633994    
#> 395: 0.580755    0.884912    3.460897    0.239998    0.144308    0.012418    0.633938    
#> 396: 0.580793    0.884975    3.460896    0.239978    0.144253    0.012426    0.633788    
#> 397: 0.580971    0.884930    3.460948    0.240181    0.144183    0.012449    0.633691    
#> 398: 0.581235    0.884890    3.461017    0.240476    0.144138    0.012471    0.633673    
#> 399: 0.581314    0.884903    3.461091    0.240747    0.144071    0.012486    0.633563    
#> 400: 0.581455    0.884918    3.461167    0.240776    0.144051    0.012491    0.633519    
#> 401: 0.581513    0.884916    3.461178    0.240852    0.143967    0.012503    0.633493    
#> 402: 0.581526    0.885011    3.461166    0.240845    0.143981    0.012507    0.633444    
#> 403: 0.581716    0.884940    3.461169    0.240987    0.144032    0.012507    0.633346    
#> 404: 0.581848    0.884883    3.461131    0.241108    0.144024    0.012499    0.633278    
#> 405: 0.582003    0.884823    3.461189    0.241186    0.144150    0.012497    0.633297    
#> 406: 0.582111    0.884793    3.461218    0.241244    0.144225    0.012495    0.633354    
#> 407: 0.582113    0.884772    3.461264    0.241182    0.144336    0.012485    0.633332    
#> 408: 0.582294    0.884743    3.461295    0.241261    0.144493    0.012477    0.633392    
#> 409: 0.582318    0.884787    3.461248    0.241268    0.144562    0.012460    0.633391    
#> 410: 0.582253    0.884823    3.461171    0.241364    0.144570    0.012447    0.633454    
#> 411: 0.582404    0.884654    3.461168    0.241519    0.144642    0.012439    0.633530    
#> 412: 0.582442    0.884773    3.461133    0.241783    0.144685    0.012441    0.633613    
#> 413: 0.582407    0.884804    3.461059    0.242247    0.144724    0.012446    0.633697    
#> 414: 0.582230    0.884859    3.461069    0.242237    0.144848    0.012449    0.633679    
#> 415: 0.582249    0.884825    3.461053    0.242299    0.144864    0.012450    0.633686    
#> 416: 0.582383    0.884823    3.461099    0.242397    0.144908    0.012446    0.633651    
#> 417: 0.582414    0.884857    3.461120    0.242354    0.144968    0.012451    0.633606    
#> 418: 0.582378    0.884809    3.461126    0.242295    0.144978    0.012451    0.633544    
#> 419: 0.582454    0.884745    3.461176    0.242281    0.144953    0.012459    0.633537    
#> 420: 0.582536    0.884649    3.461242    0.242177    0.144986    0.012465    0.633522    
#> 421: 0.582552    0.884604    3.461291    0.242189    0.145057    0.012467    0.633458    
#> 422: 0.582649    0.884540    3.461321    0.242035    0.145038    0.012467    0.633474    
#> 423: 0.582796    0.884473    3.461356    0.241911    0.145012    0.012463    0.633577    
#> 424: 0.582957    0.884464    3.461399    0.241800    0.145004    0.012468    0.633616    
#> 425: 0.583141    0.884519    3.461407    0.241809    0.144913    0.012486    0.633641    
#> 426: 0.583244    0.884589    3.461415    0.241883    0.144920    0.012489    0.633587    
#> 427: 0.583223    0.884566    3.461422    0.241834    0.144991    0.012476    0.633519    
#> 428: 0.583201    0.884631    3.461423    0.241830    0.145064    0.012467    0.633552    
#> 429: 0.583206    0.884685    3.461415    0.241799    0.145064    0.012466    0.633568    
#> 430: 0.583150    0.884702    3.461414    0.241866    0.145060    0.012463    0.633563    
#> 431: 0.582993    0.884642    3.461380    0.241975    0.144976    0.012458    0.633526    
#> 432: 0.582938    0.884646    3.461416    0.242007    0.144975    0.012460    0.633532    
#> 433: 0.582993    0.884641    3.461472    0.242120    0.144977    0.012467    0.633511    
#> 434: 0.582983    0.884494    3.461521    0.242175    0.145048    0.012466    0.633447    
#> 435: 0.582993    0.884471    3.461529    0.242259    0.144991    0.012460    0.633415    
#> 436: 0.583066    0.884402    3.461591    0.242225    0.145063    0.012455    0.633477    
#> 437: 0.583234    0.884317    3.461623    0.242144    0.145110    0.012451    0.633422    
#> 438: 0.583300    0.884411    3.461653    0.242107    0.145097    0.012455    0.633354    
#> 439: 0.583471    0.884427    3.461695    0.242164    0.145103    0.012464    0.633314    
#> 440: 0.583518    0.884426    3.461751    0.242214    0.144997    0.012468    0.633280    
#> 441: 0.583548    0.884429    3.461760    0.242226    0.145006    0.012473    0.633230    
#> 442: 0.583535    0.884498    3.461786    0.242316    0.145070    0.012478    0.633174    
#> 443: 0.583541    0.884612    3.461750    0.242320    0.145061    0.012489    0.633122    
#> 444: 0.583369    0.884797    3.461649    0.242385    0.145040    0.012499    0.633068    
#> 445: 0.583200    0.884867    3.461541    0.242308    0.144957    0.012511    0.633077    
#> 446: 0.582969    0.885040    3.461435    0.242315    0.144881    0.012524    0.633020    
#> 447: 0.582928    0.885157    3.461365    0.242379    0.144754    0.012530    0.633054    
#> 448: 0.582850    0.885161    3.461335    0.242650    0.144706    0.012542    0.632972    
#> 449: 0.582958    0.885168    3.461382    0.242944    0.144585    0.012550    0.632949    
#> 450: 0.583116    0.885084    3.461424    0.243230    0.144548    0.012551    0.632984    
#> 451: 0.583284    0.885031    3.461444    0.243287    0.144505    0.012566    0.632973    
#> 452: 0.583365    0.885057    3.461430    0.243453    0.144494    0.012577    0.632899    
#> 453: 0.583378    0.885008    3.461421    0.243595    0.144487    0.012584    0.632797    
#> 454: 0.583336    0.885118    3.461401    0.243655    0.144485    0.012582    0.632766    
#> 455: 0.583413    0.885199    3.461382    0.243611    0.144450    0.012573    0.632805    
#> 456: 0.583421    0.885185    3.461380    0.243477    0.144401    0.012569    0.632772    
#> 457: 0.583398    0.885188    3.461384    0.243409    0.144376    0.012560    0.632722    
#> 458: 0.583478    0.885249    3.461426    0.243315    0.144310    0.012567    0.632629    
#> 459: 0.583564    0.885353    3.461458    0.243305    0.144245    0.012578    0.632653    
#> 460: 0.583522    0.885377    3.461462    0.243319    0.144137    0.012586    0.632623    
#> 461: 0.583550    0.885419    3.461470    0.243354    0.144083    0.012594    0.632540    
#> 462: 0.583550    0.885413    3.461503    0.243469    0.144014    0.012603    0.632477    
#> 463: 0.583661    0.885471    3.461544    0.243596    0.143927    0.012606    0.632499    
#> 464: 0.583755    0.885485    3.461536    0.243662    0.143880    0.012608    0.632471    
#> 465: 0.583800    0.885414    3.461560    0.243683    0.143833    0.012625    0.632396    
#> 466: 0.583926    0.885418    3.461578    0.243810    0.143834    0.012634    0.632353    
#> 467: 0.584002    0.885344    3.461645    0.243900    0.143791    0.012648    0.632306    
#> 468: 0.584126    0.885256    3.461734    0.243817    0.143791    0.012655    0.632406    
#> 469: 0.584139    0.885288    3.461758    0.243722    0.143805    0.012649    0.632441    
#> 470: 0.584089    0.885368    3.461730    0.243700    0.143699    0.012656    0.632398    
#> 471: 0.583998    0.885386    3.461714    0.243647    0.143681    0.012663    0.632384    
#> 472: 0.583921    0.885370    3.461700    0.243609    0.143629    0.012662    0.632369    
#> 473: 0.583837    0.885437    3.461674    0.243541    0.143561    0.012664    0.632300    
#> 474: 0.583787    0.885440    3.461644    0.243638    0.143526    0.012679    0.632286    
#> 475: 0.583880    0.885565    3.461597    0.243710    0.143459    0.012680    0.632285    
#> 476: 0.583870    0.885565    3.461576    0.243703    0.143382    0.012681    0.632357    
#> 477: 0.583855    0.885565    3.461590    0.243595    0.143300    0.012689    0.632315    
#> 478: 0.583769    0.885607    3.461596    0.243552    0.143204    0.012692    0.632290    
#> 479: 0.583787    0.885641    3.461585    0.243600    0.143169    0.012692    0.632273    
#> 480: 0.583764    0.885602    3.461572    0.243552    0.143115    0.012686    0.632352    
#> 481: 0.583757    0.885599    3.461594    0.243528    0.143094    0.012686    0.632359    
#> 482: 0.583754    0.885572    3.461584    0.243531    0.143105    0.012686    0.632417    
#> 483: 0.583679    0.885522    3.461565    0.243489    0.143087    0.012693    0.632380    
#> 484: 0.583685    0.885428    3.461576    0.243351    0.143052    0.012696    0.632318    
#> 485: 0.583702    0.885453    3.461590    0.243249    0.143153    0.012700    0.632311    
#> 486: 0.583751    0.885459    3.461623    0.243080    0.143203    0.012698    0.632287    
#> 487: 0.583950    0.885426    3.461705    0.242967    0.143289    0.012698    0.632300    
#> 488: 0.584161    0.885344    3.461803    0.242984    0.143226    0.012705    0.632304    
#> 489: 0.584434    0.885297    3.461867    0.242991    0.143255    0.012712    0.632298    
#> 490: 0.584642    0.885212    3.461962    0.242910    0.143227    0.012721    0.632372    
#> 491: 0.584753    0.885127    3.462056    0.242944    0.143204    0.012726    0.632290    
#> 492: 0.584931    0.885124    3.462117    0.243085    0.143177    0.012742    0.632288    
#> 493: 0.585006    0.885102    3.462133    0.243182    0.143118    0.012753    0.632290    
#> 494: 0.585109    0.885094    3.462138    0.243247    0.143034    0.012759    0.632214    
#> 495: 0.585207    0.885076    3.462165    0.243232    0.142980    0.012764    0.632140    
#> 496: 0.585313    0.885184    3.462156    0.243296    0.142996    0.012772    0.632144    
#> 497: 0.585265    0.885218    3.462144    0.243245    0.142959    0.012777    0.632153    
#> 498: 0.585249    0.885228    3.462120    0.243336    0.142944    0.012775    0.632139    
#> 499: 0.585164    0.885237    3.462099    0.243158    0.142915    0.012775    0.632097    
#> 500: 0.585194    0.885260    3.462089    0.243127    0.142867    0.012771    0.632041    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.290940    0.991639    3.444349    0.392401    0.078592    0.016800    1.743571    
#> 002: 0.392653    1.080012    3.473398    0.372781    0.074663    0.020410    1.197955    
#> 003: 0.552127    1.065137    3.518848    0.354142    0.096240    0.019389    0.869022    
#> 004: 0.538250    1.088898    3.520817    0.347862    0.096867    0.021012    0.738965    
#> 005: 0.605190    1.099334    3.516745    0.390766    0.098939    0.019961    0.702265    
#> 006: 0.600531    1.097689    3.520829    0.436223    0.093992    0.021635    0.645047    
#> 007: 0.605172    1.102025    3.527617    0.434927    0.089292    0.027260    0.656871    
#> 008: 0.609985    1.082098    3.531687    0.413413    0.084828    0.029397    0.660221    
#> 009: 0.567709    1.062229    3.515757    0.452153    0.080586    0.027928    0.666617    
#> 010: 0.575492    1.077155    3.525847    0.433103    0.092742    0.026531    0.668041    
#> 011: 0.615908    1.093211    3.526017    0.529852    0.097542    0.025205    0.660273    
#> 012: 0.630173    1.087946    3.529185    0.503359    0.094714    0.023944    0.639730    
#> 013: 0.603064    1.090647    3.516127    0.535578    0.089978    0.022747    0.650569    
#> 014: 0.608701    1.100567    3.516301    0.515784    0.085479    0.021610    0.669506    
#> 015: 0.649767    1.097438    3.532206    0.497360    0.081205    0.025579    0.640078    
#> 016: 0.652679    1.110057    3.532312    0.482076    0.077145    0.024470    0.656570    
#> 017: 0.625518    1.115634    3.533332    0.487600    0.073288    0.025706    0.649999    
#> 018: 0.616012    1.123145    3.505635    0.584149    0.069623    0.024828    0.656509    
#> 019: 0.552908    1.124356    3.500097    0.554942    0.079227    0.027596    0.639138    
#> 020: 0.622333    1.124221    3.515226    0.578868    0.081249    0.028271    0.635189    
#> 021: 0.615753    1.106086    3.529846    0.549925    0.077187    0.032220    0.640630    
#> 022: 0.610803    1.108392    3.533022    0.522428    0.081864    0.030609    0.623877    
#> 023: 0.687658    1.107086    3.538384    0.496307    0.077771    0.029079    0.651560    
#> 024: 0.648055    1.136723    3.534147    0.496174    0.085410    0.029492    0.631709    
#> 025: 0.611515    1.113356    3.515489    0.536427    0.086165    0.028018    0.638615    
#> 026: 0.601037    1.140798    3.507853    0.509606    0.086048    0.026617    0.646225    
#> 027: 0.610356    1.139081    3.508881    0.531253    0.081745    0.025381    0.655217    
#> 028: 0.624093    1.137878    3.513704    0.504690    0.077658    0.029044    0.653473    
#> 029: 0.604747    1.123690    3.498407    0.479456    0.073775    0.027592    0.662584    
#> 030: 0.614332    1.134886    3.506340    0.483148    0.073516    0.026362    0.652207    
#> 031: 0.594117    1.117798    3.517346    0.458991    0.078679    0.025044    0.656771    
#> 032: 0.576793    1.106110    3.518017    0.436041    0.074745    0.024209    0.645551    
#> 033: 0.563591    1.120400    3.509107    0.414239    0.071008    0.023206    0.641534    
#> 034: 0.599946    1.119170    3.522432    0.426164    0.086067    0.023121    0.625943    
#> 035: 0.594421    1.093436    3.512775    0.422198    0.087080    0.021965    0.631041    
#> 036: 0.607301    1.119262    3.516795    0.442274    0.082726    0.024996    0.644011    
#> 037: 0.594136    1.131854    3.515170    0.449349    0.078590    0.027079    0.659485    
#> 038: 0.643339    1.121779    3.518895    0.514596    0.074709    0.025725    0.640339    
#> 039: 0.647623    1.101312    3.525343    0.597389    0.077733    0.025698    0.623987    
#> 040: 0.603830    1.133401    3.520993    0.567519    0.081419    0.030712    0.634839    
#> 041: 0.579606    1.132549    3.504844    0.539143    0.077348    0.029176    0.642096    
#> 042: 0.601381    1.112801    3.511273    0.522624    0.073866    0.027717    0.635661    
#> 043: 0.569177    1.129781    3.496423    0.514741    0.078664    0.026331    0.634673    
#> 044: 0.531799    1.133628    3.502290    0.489004    0.075799    0.025901    0.659081    
#> 045: 0.585211    1.135812    3.506572    0.536548    0.073615    0.024606    0.635224    
#> 046: 0.537750    1.129031    3.497656    0.509720    0.072347    0.024429    0.630284    
#> 047: 0.548651    1.151596    3.488433    0.484234    0.086207    0.023208    0.629907    
#> 048: 0.553427    1.133671    3.494083    0.469447    0.090455    0.022667    0.649580    
#> 049: 0.577698    1.123911    3.495815    0.524195    0.086835    0.021534    0.657178    
#> 050: 0.590589    1.103834    3.499769    0.526753    0.082494    0.025395    0.667881    
#> 051: 0.585861    1.104493    3.499660    0.512328    0.086891    0.027278    0.654123    
#> 052: 0.606280    1.116887    3.511717    0.569729    0.082637    0.025914    0.632337    
#> 053: 0.621209    1.101741    3.515897    0.572874    0.081274    0.028698    0.635915    
#> 054: 0.568276    1.113963    3.522369    0.544231    0.077210    0.032065    0.654309    
#> 055: 0.601185    1.129501    3.518390    0.551102    0.083160    0.030462    0.669957    
#> 056: 0.636219    1.092586    3.524276    0.523547    0.079002    0.030856    0.660656    
#> 057: 0.644571    1.095265    3.528828    0.597742    0.081698    0.029313    0.655692    
#> 058: 0.632214    1.094223    3.518454    0.567854    0.077613    0.027848    0.661452    
#> 059: 0.633838    1.051981    3.533016    0.570727    0.073732    0.026776    0.686752    
#> 060: 0.597370    1.064873    3.525475    0.542190    0.085113    0.025437    0.690591    
#> 061: 0.645021    1.081432    3.536725    0.515081    0.080857    0.027774    0.681249    
#> 062: 0.618569    1.093978    3.533394    0.546314    0.077922    0.026386    0.684938    
#> 063: 0.651829    1.067240    3.526383    0.620320    0.087171    0.025066    0.674854    
#> 064: 0.654494    1.084861    3.547203    0.589304    0.085006    0.023813    0.685466    
#> 065: 0.666673    1.082328    3.534422    0.559839    0.080756    0.024294    0.659926    
#> 066: 0.674185    1.089699    3.530549    0.531847    0.076718    0.025737    0.655836    
#> 067: 0.652993    1.091589    3.528291    0.505254    0.072882    0.030582    0.648928    
#> 068: 0.614703    1.085258    3.544927    0.479992    0.077382    0.029053    0.659557    
#> 069: 0.662820    1.095392    3.535826    0.455992    0.084471    0.027600    0.648012    
#> 070: 0.610700    1.113481    3.525073    0.467012    0.080247    0.026220    0.661015    
#> 071: 0.605398    1.142974    3.498744    0.536857    0.079534    0.024909    0.674804    
#> 072: 0.581514    1.129507    3.501548    0.586090    0.085347    0.023664    0.666822    
#> 073: 0.641821    1.118723    3.515604    0.659054    0.090749    0.022481    0.662014    
#> 074: 0.659960    1.103926    3.519918    0.626101    0.090350    0.021357    0.651943    
#> 075: 0.646018    1.090205    3.544036    0.594796    0.085832    0.021095    0.649607    
#> 076: 0.713463    1.098516    3.553201    0.584014    0.081541    0.021890    0.650966    
#> 077: 0.731537    1.084752    3.547232    0.577081    0.094132    0.020795    0.656052    
#> 078: 0.682224    1.081160    3.546280    0.548227    0.089426    0.023010    0.638211    
#> 079: 0.654843    1.112509    3.538912    0.520816    0.084954    0.023466    0.682926    
#> 080: 0.658670    1.105281    3.534536    0.508790    0.080707    0.025504    0.673464    
#> 081: 0.676848    1.102434    3.535219    0.532280    0.076671    0.025154    0.648420    
#> 082: 0.618506    1.083043    3.535254    0.505666    0.072838    0.024377    0.654540    
#> 083: 0.598175    1.115041    3.527914    0.480383    0.082224    0.023158    0.648833    
#> 084: 0.605608    1.128033    3.516033    0.483657    0.078113    0.023959    0.643863    
#> 085: 0.616135    1.129710    3.528971    0.468134    0.080988    0.022761    0.647127    
#> 086: 0.589415    1.115237    3.513163    0.499668    0.076939    0.021623    0.644144    
#> 087: 0.616487    1.115234    3.509811    0.569284    0.086879    0.020542    0.637624    
#> 088: 0.565941    1.102946    3.516478    0.540820    0.089896    0.019515    0.649022    
#> 089: 0.642032    1.115874    3.517445    0.544324    0.098567    0.021186    0.658589    
#> 090: 0.611211    1.101930    3.512786    0.529812    0.093639    0.020612    0.660418    
#> 091: 0.610160    1.108654    3.502335    0.503322    0.092105    0.026159    0.648664    
#> 092: 0.571966    1.136902    3.502228    0.523879    0.087500    0.029892    0.660151    
#> 093: 0.540215    1.111507    3.506066    0.497685    0.083125    0.030690    0.669389    
#> 094: 0.580108    1.133367    3.500079    0.500759    0.078969    0.029302    0.663381    
#> 095: 0.539753    1.132469    3.513424    0.475721    0.075020    0.038987    0.645688    
#> 096: 0.556074    1.133153    3.505984    0.525995    0.071269    0.037037    0.642495    
#> 097: 0.610886    1.157929    3.503025    0.567166    0.078737    0.035186    0.632714    
#> 098: 0.600708    1.142065    3.527944    0.538808    0.074800    0.033426    0.639166    
#> 099: 0.649827    1.094933    3.521491    0.511867    0.071060    0.031755    0.643569    
#> 100: 0.629089    1.121533    3.524606    0.486274    0.067507    0.030167    0.629209    
#> 101: 0.563419    1.099007    3.501396    0.461960    0.065682    0.028659    0.632565    
#> 102: 0.548208    1.099728    3.494074    0.438862    0.070357    0.027226    0.663603    
#> 103: 0.630740    1.114270    3.512872    0.537774    0.076542    0.028508    0.656508    
#> 104: 0.588504    1.113591    3.525298    0.511683    0.072715    0.030295    0.679568    
#> 105: 0.634500    1.082670    3.536720    0.486098    0.069853    0.028780    0.679561    
#> 106: 0.665814    1.069764    3.541670    0.495071    0.066360    0.027341    0.668055    
#> 107: 0.652144    1.077437    3.538399    0.470317    0.063042    0.025974    0.666162    
#> 108: 0.648368    1.086264    3.535122    0.510878    0.073124    0.028290    0.652815    
#> 109: 0.659580    1.076516    3.548042    0.543450    0.069468    0.032628    0.636273    
#> 110: 0.645719    1.091786    3.523810    0.531331    0.066927    0.034578    0.650553    
#> 111: 0.622806    1.111831    3.526670    0.504764    0.080562    0.032849    0.638000    
#> 112: 0.620279    1.108972    3.511718    0.498789    0.098273    0.031207    0.647229    
#> 113: 0.586805    1.136272    3.512533    0.489462    0.093359    0.029646    0.631372    
#> 114: 0.602470    1.129953    3.515296    0.504483    0.088691    0.028164    0.624669    
#> 115: 0.610189    1.121756    3.510639    0.479259    0.090568    0.026756    0.654337    
#> 116: 0.604086    1.138005    3.505056    0.524431    0.086039    0.025418    0.647417    
#> 117: 0.546258    1.143460    3.501679    0.502555    0.083079    0.024147    0.652355    
#> 118: 0.569716    1.134124    3.501358    0.521100    0.084086    0.022940    0.652923    
#> 119: 0.575901    1.143705    3.493339    0.555234    0.080142    0.023989    0.659080    
#> 120: 0.532268    1.139076    3.490935    0.527472    0.085863    0.026307    0.657966    
#> 121: 0.593056    1.145106    3.505422    0.501098    0.087380    0.026064    0.649897    
#> 122: 0.612370    1.104613    3.511867    0.476043    0.083011    0.024760    0.652122    
#> 123: 0.596028    1.158444    3.497076    0.476789    0.083857    0.023522    0.657305    
#> 124: 0.591050    1.144941    3.496007    0.474000    0.082405    0.022346    0.639069    
#> 125: 0.589483    1.164776    3.500559    0.450300    0.088843    0.021229    0.641438    
#> 126: 0.580604    1.159136    3.492296    0.460020    0.091796    0.021054    0.644588    
#> 127: 0.605461    1.132258    3.489832    0.518624    0.087207    0.021098    0.653526    
#> 128: 0.575264    1.119917    3.515420    0.492693    0.086277    0.021652    0.666667    
#> 129: 0.622917    1.144675    3.517226    0.517827    0.095226    0.020708    0.658154    
#> 130: 0.646634    1.148823    3.509577    0.491936    0.092828    0.019672    0.655188    
#> 131: 0.639162    1.109622    3.507891    0.533346    0.088186    0.020644    0.647378    
#> 132: 0.530554    1.120771    3.495848    0.506679    0.083777    0.024326    0.654169    
#> 133: 0.555603    1.124469    3.498597    0.490763    0.079588    0.023109    0.656774    
#> 134: 0.594963    1.112933    3.502806    0.586441    0.075609    0.025207    0.636244    
#> 135: 0.616189    1.108882    3.514005    0.557119    0.072610    0.024967    0.641104    
#> 136: 0.620528    1.099156    3.514458    0.556582    0.068980    0.029107    0.636034    
#> 137: 0.627643    1.105295    3.526177    0.528753    0.066556    0.030981    0.645624    
#> 138: 0.596735    1.117301    3.515440    0.538496    0.073953    0.029432    0.650173    
#> 139: 0.601276    1.125068    3.520213    0.570122    0.088147    0.027960    0.659421    
#> 140: 0.633542    1.111547    3.518330    0.541616    0.083739    0.033909    0.636686    
#> 141: 0.605720    1.078172    3.524373    0.550758    0.079552    0.035206    0.638035    
#> 142: 0.622421    1.075548    3.541165    0.532175    0.075575    0.033446    0.657912    
#> 143: 0.643118    1.109500    3.525658    0.572351    0.074810    0.031773    0.649849    
#> 144: 0.685317    1.091552    3.538713    0.596269    0.071070    0.030185    0.656088    
#> 145: 0.650538    1.116228    3.523075    0.614144    0.067516    0.028675    0.643967    
#> 146: 0.630952    1.101869    3.529190    0.617058    0.076244    0.027242    0.648540    
#> 147: 0.638826    1.094548    3.519977    0.648975    0.073179    0.028058    0.631359    
#> 148: 0.620402    1.114368    3.531293    0.616526    0.079675    0.027487    0.629801    
#> 149: 0.669975    1.089617    3.526332    0.722711    0.075692    0.029959    0.636467    
#> 150: 0.729178    1.087563    3.522817    0.929429    0.074228    0.032012    0.648179    
#> 151: 0.688832    1.122662    3.517311    0.958470    0.075936    0.030411    0.640768    
#> 152: 0.733528    1.116407    3.533051    0.964926    0.072079    0.025759    0.637805    
#> 153: 0.723822    1.114838    3.528750    1.041884    0.068075    0.025222    0.638630    
#> 154: 0.688808    1.117190    3.526651    0.865432    0.077001    0.023737    0.647029    
#> 155: 0.631118    1.094153    3.515963    0.567219    0.067989    0.022595    0.653802    
#> 156: 0.648322    1.094564    3.534469    0.552895    0.059309    0.029284    0.668738    
#> 157: 0.656233    1.097532    3.538280    0.473208    0.069656    0.028173    0.668212    
#> 158: 0.669865    1.118733    3.530251    0.502453    0.071139    0.023293    0.665063    
#> 159: 0.609389    1.110085    3.532271    0.446625    0.067631    0.029500    0.658307    
#> 160: 0.653615    1.088455    3.528874    0.535295    0.072729    0.030167    0.655990    
#> 161: 0.635222    1.105546    3.532901    0.469849    0.075288    0.029129    0.658957    
#> 162: 0.643226    1.118856    3.528677    0.637889    0.068267    0.028950    0.657178    
#> 163: 0.667385    1.109648    3.523556    0.623119    0.080542    0.028100    0.647926    
#> 164: 0.662812    1.098224    3.524459    0.635959    0.071322    0.027116    0.652909    
#> 165: 0.637418    1.104776    3.521392    0.479791    0.072021    0.026302    0.649206    
#> 166: 0.683439    1.134649    3.522573    0.625812    0.071376    0.027280    0.655744    
#> 167: 0.703637    1.123038    3.533912    0.550427    0.063469    0.029615    0.635598    
#> 168: 0.634839    1.127578    3.523793    0.548714    0.072074    0.025773    0.629531    
#> 169: 0.612134    1.150932    3.511877    0.534619    0.071529    0.027865    0.645692    
#> 170: 0.608219    1.142515    3.511050    0.564381    0.065867    0.028599    0.645942    
#> 171: 0.611543    1.130686    3.509296    0.616450    0.067756    0.024072    0.629505    
#> 172: 0.612700    1.148842    3.504980    0.727353    0.074847    0.024453    0.631971    
#> 173: 0.603759    1.144771    3.476929    0.655355    0.070247    0.023917    0.639409    
#> 174: 0.614819    1.142563    3.493767    0.669826    0.078522    0.019321    0.649327    
#> 175: 0.595560    1.139619    3.480908    0.684648    0.072280    0.020998    0.640910    
#> 176: 0.562270    1.157049    3.497774    0.521082    0.091319    0.017600    0.653161    
#> 177: 0.557085    1.142498    3.506603    0.485687    0.083038    0.021577    0.663619    
#> 178: 0.560848    1.131016    3.498071    0.489443    0.092619    0.020943    0.663663    
#> 179: 0.564818    1.151117    3.490863    0.435781    0.083469    0.020585    0.673288    
#> 180: 0.565860    1.124177    3.494247    0.550467    0.090892    0.019313    0.651111    
#> 181: 0.593582    1.125643    3.495229    0.506529    0.092761    0.018206    0.644441    
#> 182: 0.558645    1.122179    3.491860    0.536589    0.086209    0.021112    0.668961    
#> 183: 0.591247    1.146862    3.494453    0.542636    0.083504    0.024683    0.663823    
#> 184: 0.569682    1.128272    3.501241    0.524230    0.092289    0.024186    0.643674    
#> 185: 0.596039    1.130505    3.498909    0.582604    0.070810    0.024834    0.650853    
#> 186: 0.571772    1.144662    3.502401    0.506289    0.085287    0.021998    0.656824    
#> 187: 0.602192    1.118674    3.513251    0.517865    0.072698    0.023912    0.652634    
#> 188: 0.545214    1.123784    3.506789    0.479095    0.074816    0.024884    0.670464    
#> 189: 0.538063    1.152402    3.502774    0.421184    0.095992    0.023954    0.679847    
#> 190: 0.581371    1.134548    3.508870    0.565105    0.089411    0.025263    0.643269    
#> 191: 0.565679    1.127390    3.496485    0.512382    0.080600    0.024770    0.642696    
#> 192: 0.534184    1.143550    3.494322    0.479864    0.071226    0.023565    0.650173    
#> 193: 0.615076    1.146014    3.512085    0.484171    0.078481    0.025280    0.640094    
#> 194: 0.576592    1.134534    3.510803    0.465718    0.074605    0.024843    0.664303    
#> 195: 0.547142    1.151721    3.498055    0.463336    0.075594    0.026288    0.651292    
#> 196: 0.566850    1.126847    3.502547    0.490964    0.079233    0.023244    0.653437    
#> 197: 0.548070    1.132919    3.511001    0.485931    0.087418    0.023036    0.654232    
#> 198: 0.596667    1.102867    3.512157    0.474261    0.086305    0.022162    0.644507    
#> 199: 0.627360    1.090377    3.523792    0.519909    0.089667    0.020853    0.665976    
#> 200: 0.598824    1.085841    3.527299    0.453938    0.074493    0.020807    0.673407    
#> 201: 0.605929    1.082932    3.531052    0.483698    0.077035    0.021438    0.661841    
#> 202: 0.598830    1.087669    3.529480    0.483424    0.081781    0.021476    0.663807    
#> 203: 0.617603    1.087429    3.528222    0.479518    0.083996    0.020379    0.664435    
#> 204: 0.614930    1.085965    3.528279    0.470910    0.090157    0.019477    0.663626    
#> 205: 0.617070    1.092392    3.527912    0.473496    0.093636    0.019057    0.661956    
#> 206: 0.620457    1.099295    3.528717    0.488155    0.092718    0.019289    0.660994    
#> 207: 0.617964    1.101314    3.526436    0.491371    0.090765    0.019334    0.662469    
#> 208: 0.616146    1.103507    3.525374    0.498125    0.089414    0.019505    0.660015    
#> 209: 0.617450    1.103050    3.524604    0.498007    0.087977    0.019236    0.658948    
#> 210: 0.618754    1.102944    3.524238    0.496581    0.088358    0.019044    0.657731    
#> 211: 0.620910    1.104633    3.524398    0.497363    0.089115    0.018771    0.655061    
#> 212: 0.623572    1.104234    3.524318    0.495189    0.088472    0.018601    0.654589    
#> 213: 0.624919    1.103410    3.524537    0.496034    0.088139    0.018785    0.654385    
#> 214: 0.626329    1.103653    3.524569    0.498311    0.087574    0.018967    0.653360    
#> 215: 0.624491    1.104317    3.524751    0.492557    0.087061    0.019128    0.652777    
#> 216: 0.626020    1.102626    3.524896    0.489220    0.086701    0.019472    0.652944    
#> 217: 0.625544    1.102852    3.525276    0.486974    0.086455    0.019659    0.651558    
#> 218: 0.626392    1.102784    3.525348    0.485649    0.086837    0.019630    0.651087    
#> 219: 0.624562    1.102356    3.524767    0.485660    0.086665    0.019713    0.650449    
#> 220: 0.623380    1.103435    3.524005    0.490238    0.086441    0.020020    0.649625    
#> 221: 0.621555    1.104129    3.523331    0.490884    0.086270    0.020199    0.648932    
#> 222: 0.622223    1.104156    3.522445    0.493988    0.085511    0.020509    0.648732    
#> 223: 0.622570    1.104986    3.522006    0.496663    0.085351    0.020720    0.648273    
#> 224: 0.624751    1.105614    3.522357    0.500112    0.085322    0.020797    0.648359    
#> 225: 0.625162    1.104703    3.522878    0.501170    0.085260    0.020945    0.648255    
#> 226: 0.624049    1.103851    3.522572    0.499447    0.085134    0.021047    0.648069    
#> 227: 0.624019    1.103773    3.522465    0.497467    0.085573    0.021127    0.648311    
#> 228: 0.621950    1.104793    3.521619    0.496441    0.085550    0.021058    0.648526    
#> 229: 0.620266    1.104831    3.521250    0.495483    0.085674    0.021022    0.649019    
#> 230: 0.619174    1.104784    3.520774    0.495300    0.085807    0.020900    0.649233    
#> 231: 0.618826    1.105404    3.520700    0.497216    0.085958    0.020831    0.648636    
#> 232: 0.617786    1.105551    3.520631    0.496074    0.085640    0.020758    0.648213    
#> 233: 0.617354    1.104930    3.520614    0.494288    0.085527    0.020712    0.648421    
#> 234: 0.616071    1.105422    3.520741    0.493242    0.085588    0.020683    0.648023    
#> 235: 0.616223    1.105262    3.520645    0.493497    0.085627    0.020685    0.647695    
#> 236: 0.617221    1.105805    3.520455    0.495792    0.085562    0.020663    0.647571    
#> 237: 0.617945    1.105547    3.520298    0.495776    0.085571    0.020691    0.648145    
#> 238: 0.618583    1.105932    3.520322    0.495315    0.085567    0.020830    0.648938    
#> 239: 0.618278    1.106495    3.520232    0.496613    0.085407    0.020912    0.648924    
#> 240: 0.618037    1.106902    3.520165    0.498005    0.085529    0.021022    0.648556    
#> 241: 0.618210    1.106300    3.520306    0.499638    0.085327    0.021134    0.648583    
#> 242: 0.617997    1.106158    3.520064    0.502023    0.085375    0.021127    0.648701    
#> 243: 0.617653    1.106618    3.519966    0.501685    0.085330    0.021230    0.648694    
#> 244: 0.617337    1.106718    3.520010    0.501580    0.085083    0.021354    0.648712    
#> 245: 0.617088    1.106428    3.520136    0.502378    0.085022    0.021420    0.648999    
#> 246: 0.616690    1.106621    3.519896    0.501885    0.084872    0.021496    0.649212    
#> 247: 0.616189    1.106540    3.519945    0.501217    0.084754    0.021598    0.649209    
#> 248: 0.615605    1.106980    3.519904    0.500145    0.084647    0.021629    0.649083    
#> 249: 0.615280    1.107203    3.520035    0.498504    0.084751    0.021623    0.649100    
#> 250: 0.615630    1.107337    3.520242    0.497305    0.084955    0.021659    0.649137    
#> 251: 0.615309    1.107640    3.520384    0.495682    0.084796    0.021652    0.649756    
#> 252: 0.615586    1.107922    3.520604    0.494143    0.084678    0.021649    0.650202    
#> 253: 0.615419    1.107951    3.520732    0.493361    0.084569    0.021638    0.649982    
#> 254: 0.615691    1.107886    3.520795    0.492836    0.084295    0.021683    0.649968    
#> 255: 0.615871    1.108158    3.520820    0.492333    0.084078    0.021734    0.649918    
#> 256: 0.616339    1.108001    3.520892    0.491660    0.083997    0.021777    0.650131    
#> 257: 0.616030    1.107687    3.520831    0.490800    0.084165    0.021809    0.650437    
#> 258: 0.615374    1.107215    3.520779    0.489509    0.084077    0.021910    0.650741    
#> 259: 0.614698    1.107188    3.520604    0.488902    0.084029    0.021994    0.650745    
#> 260: 0.614073    1.107333    3.520475    0.488351    0.083895    0.022082    0.650381    
#> 261: 0.614626    1.107044    3.520589    0.488708    0.083644    0.022141    0.650410    
#> 262: 0.614857    1.107415    3.520632    0.488692    0.083758    0.022194    0.650329    
#> 263: 0.614149    1.107877    3.520569    0.488225    0.083978    0.022195    0.650358    
#> 264: 0.613953    1.108183    3.520380    0.488545    0.084280    0.022162    0.650573    
#> 265: 0.613553    1.108643    3.520231    0.488450    0.084548    0.022114    0.650757    
#> 266: 0.613881    1.108829    3.520232    0.488744    0.084768    0.022061    0.650975    
#> 267: 0.613558    1.109013    3.520200    0.488227    0.085037    0.021972    0.651019    
#> 268: 0.614066    1.108943    3.520235    0.488856    0.085160    0.021930    0.650914    
#> 269: 0.615049    1.108881    3.520298    0.489761    0.085081    0.021944    0.651094    
#> 270: 0.615105    1.109187    3.520146    0.490341    0.084970    0.021954    0.651006    
#> 271: 0.614704    1.109375    3.519918    0.491302    0.085106    0.021982    0.650923    
#> 272: 0.614536    1.109754    3.519649    0.492558    0.085216    0.022046    0.651150    
#> 273: 0.614176    1.110170    3.519566    0.493784    0.085152    0.022135    0.651417    
#> 274: 0.614071    1.110701    3.519426    0.494628    0.085205    0.022154    0.651441    
#> 275: 0.613767    1.110800    3.519217    0.494641    0.085383    0.022152    0.651322    
#> 276: 0.613660    1.110975    3.519308    0.495186    0.085299    0.022158    0.651103    
#> 277: 0.613394    1.111509    3.519349    0.494908    0.085282    0.022174    0.650746    
#> 278: 0.613221    1.111784    3.519286    0.495073    0.085433    0.022154    0.650611    
#> 279: 0.612721    1.111744    3.519236    0.495811    0.085434    0.022182    0.650695    
#> 280: 0.612583    1.111925    3.519044    0.495936    0.085497    0.022154    0.650526    
#> 281: 0.612030    1.112295    3.518919    0.495510    0.085613    0.022102    0.650405    
#> 282: 0.612083    1.112551    3.518902    0.495472    0.085768    0.022099    0.650395    
#> 283: 0.611520    1.112444    3.518905    0.494314    0.085750    0.022104    0.650599    
#> 284: 0.610972    1.112108    3.518961    0.492453    0.085600    0.022123    0.650575    
#> 285: 0.610494    1.112073    3.518800    0.491428    0.085467    0.022159    0.650515    
#> 286: 0.610291    1.112033    3.518698    0.490913    0.085302    0.022216    0.650376    
#> 287: 0.609878    1.112161    3.518494    0.490718    0.085149    0.022264    0.650220    
#> 288: 0.609722    1.112050    3.518420    0.491379    0.084990    0.022340    0.650318    
#> 289: 0.610652    1.111890    3.518520    0.492673    0.084865    0.022367    0.650349    
#> 290: 0.611188    1.111819    3.518651    0.493443    0.084720    0.022416    0.650395    
#> 291: 0.611837    1.112089    3.518810    0.493574    0.084555    0.022474    0.650116    
#> 292: 0.611874    1.112061    3.518806    0.493854    0.084369    0.022448    0.649968    
#> 293: 0.611852    1.112244    3.518757    0.494506    0.084261    0.022445    0.649957    
#> 294: 0.611143    1.112243    3.518606    0.493723    0.084077    0.022469    0.649974    
#> 295: 0.610695    1.112047    3.518448    0.493500    0.083982    0.022471    0.649896    
#> 296: 0.610189    1.111985    3.518304    0.493635    0.083881    0.022490    0.649725    
#> 297: 0.610194    1.112185    3.518198    0.494178    0.083797    0.022516    0.649517    
#> 298: 0.609897    1.112336    3.518053    0.494294    0.083820    0.022532    0.649377    
#> 299: 0.609597    1.112579    3.517852    0.494301    0.083677    0.022535    0.649167    
#> 300: 0.609431    1.112517    3.517824    0.493728    0.083648    0.022575    0.649056    
#> 301: 0.609517    1.112428    3.517761    0.494487    0.083666    0.022593    0.649019    
#> 302: 0.609519    1.112402    3.517686    0.495073    0.083697    0.022615    0.648962    
#> 303: 0.609192    1.112592    3.517565    0.494731    0.083696    0.022608    0.648950    
#> 304: 0.608849    1.113013    3.517348    0.494459    0.083770    0.022609    0.649097    
#> 305: 0.608815    1.113039    3.517252    0.494388    0.083757    0.022658    0.648954    
#> 306: 0.608851    1.113100    3.517136    0.494605    0.083742    0.022705    0.648835    
#> 307: 0.608763    1.113195    3.517083    0.494813    0.083734    0.022757    0.648861    
#> 308: 0.608517    1.113122    3.517021    0.494754    0.083783    0.022736    0.648870    
#> 309: 0.608414    1.113033    3.516953    0.494509    0.083783    0.022719    0.649163    
#> 310: 0.608633    1.112948    3.516833    0.495125    0.083764    0.022691    0.649239    
#> 311: 0.608564    1.113074    3.516823    0.494959    0.083759    0.022698    0.649152    
#> 312: 0.608408    1.113082    3.516813    0.494656    0.083686    0.022705    0.649174    
#> 313: 0.608470    1.112862    3.516716    0.494850    0.083641    0.022704    0.649345    
#> 314: 0.608219    1.112839    3.516644    0.495214    0.083579    0.022733    0.649386    
#> 315: 0.608047    1.112820    3.516564    0.496003    0.083475    0.022792    0.649388    
#> 316: 0.607972    1.112913    3.516423    0.496366    0.083354    0.022828    0.649364    
#> 317: 0.608066    1.112931    3.516422    0.496272    0.083294    0.022867    0.649488    
#> 318: 0.608104    1.112950    3.516451    0.495922    0.083323    0.022882    0.649472    
#> 319: 0.608537    1.112877    3.516583    0.496195    0.083357    0.022890    0.649545    
#> 320: 0.608293    1.112648    3.516559    0.496219    0.083274    0.022906    0.649640    
#> 321: 0.607845    1.112692    3.516390    0.496189    0.083278    0.022921    0.649754    
#> 322: 0.607835    1.112725    3.516188    0.496834    0.083213    0.022953    0.649759    
#> 323: 0.607337    1.112886    3.516044    0.497256    0.083126    0.022974    0.649796    
#> 324: 0.607093    1.113081    3.515963    0.497378    0.083170    0.022992    0.649812    
#> 325: 0.607043    1.113258    3.515899    0.497368    0.083151    0.023028    0.649662    
#> 326: 0.606732    1.113128    3.515803    0.497464    0.083127    0.023054    0.649526    
#> 327: 0.606624    1.113279    3.515723    0.497481    0.083167    0.023059    0.649519    
#> 328: 0.606655    1.113407    3.515697    0.497439    0.083115    0.023076    0.649396    
#> 329: 0.607079    1.113451    3.515752    0.497795    0.082914    0.023087    0.649368    
#> 330: 0.606884    1.113303    3.515845    0.497837    0.082863    0.023092    0.649405    
#> 331: 0.607023    1.113360    3.515965    0.497415    0.082871    0.023105    0.649421    
#> 332: 0.607371    1.113380    3.516139    0.497244    0.082784    0.023114    0.649414    
#> 333: 0.607535    1.113160    3.516261    0.497233    0.082816    0.023143    0.649438    
#> 334: 0.607777    1.112870    3.516256    0.497308    0.082743    0.023157    0.649442    
#> 335: 0.607829    1.112787    3.516280    0.496852    0.082653    0.023151    0.649468    
#> 336: 0.607670    1.112828    3.516313    0.496457    0.082586    0.023152    0.649538    
#> 337: 0.607502    1.113030    3.516293    0.495880    0.082595    0.023153    0.649620    
#> 338: 0.607533    1.113059    3.516330    0.495707    0.082596    0.023163    0.649591    
#> 339: 0.607630    1.113075    3.516299    0.495502    0.082558    0.023163    0.649582    
#> 340: 0.607649    1.112931    3.516281    0.495634    0.082520    0.023211    0.649529    
#> 341: 0.607870    1.112846    3.516357    0.495822    0.082470    0.023252    0.649415    
#> 342: 0.607444    1.112714    3.516354    0.495531    0.082438    0.023283    0.649380    
#> 343: 0.607385    1.112646    3.516364    0.495742    0.082387    0.023316    0.649197    
#> 344: 0.607541    1.112619    3.516350    0.496205    0.082349    0.023344    0.649218    
#> 345: 0.607632    1.112531    3.516405    0.496323    0.082215    0.023378    0.649171    
#> 346: 0.607270    1.112493    3.516265    0.495913    0.082083    0.023392    0.649153    
#> 347: 0.607188    1.112486    3.516166    0.495996    0.081976    0.023397    0.649249    
#> 348: 0.606891    1.112595    3.516080    0.496133    0.082013    0.023417    0.649253    
#> 349: 0.606558    1.112659    3.515977    0.495771    0.082123    0.023453    0.649267    
#> 350: 0.606344    1.112632    3.515920    0.495924    0.082119    0.023463    0.649295    
#> 351: 0.606411    1.112831    3.515916    0.495776    0.082116    0.023447    0.649344    
#> 352: 0.606245    1.112986    3.515901    0.495533    0.082116    0.023437    0.649391    
#> 353: 0.606492    1.113147    3.515940    0.495325    0.082072    0.023432    0.649392    
#> 354: 0.606288    1.113261    3.515866    0.494726    0.082098    0.023396    0.649471    
#> 355: 0.606595    1.113133    3.515925    0.494550    0.082180    0.023374    0.649519    
#> 356: 0.606716    1.113126    3.516030    0.494834    0.082128    0.023380    0.649644    
#> 357: 0.607462    1.113221    3.516099    0.495837    0.082155    0.023379    0.649756    
#> 358: 0.607578    1.113155    3.516176    0.496021    0.082064    0.023376    0.649709    
#> 359: 0.607487    1.113225    3.516204    0.495718    0.081948    0.023375    0.649648    
#> 360: 0.607279    1.113309    3.516113    0.495639    0.081840    0.023386    0.649559    
#> 361: 0.607341    1.113312    3.516033    0.495913    0.081842    0.023409    0.649467    
#> 362: 0.607534    1.113202    3.515991    0.496265    0.081809    0.023397    0.649399    
#> 363: 0.607553    1.113093    3.515984    0.496423    0.081736    0.023424    0.649242    
#> 364: 0.607626    1.113085    3.515968    0.496957    0.081675    0.023447    0.649128    
#> 365: 0.607384    1.113022    3.515923    0.497059    0.081596    0.023482    0.649187    
#> 366: 0.607109    1.113027    3.515792    0.497240    0.081503    0.023509    0.649189    
#> 367: 0.606911    1.112999    3.515705    0.497108    0.081443    0.023514    0.649132    
#> 368: 0.606969    1.113140    3.515648    0.497282    0.081516    0.023505    0.649049    
#> 369: 0.606864    1.113139    3.515635    0.497248    0.081446    0.023509    0.649099    
#> 370: 0.606614    1.113288    3.515572    0.497461    0.081448    0.023507    0.649050    
#> 371: 0.606300    1.113401    3.515469    0.497233    0.081406    0.023533    0.649035    
#> 372: 0.606014    1.113493    3.515385    0.497238    0.081394    0.023533    0.649018    
#> 373: 0.605668    1.113641    3.515331    0.496751    0.081317    0.023560    0.649094    
#> 374: 0.605811    1.113609    3.515313    0.496690    0.081292    0.023557    0.649024    
#> 375: 0.605696    1.113659    3.515321    0.496496    0.081245    0.023570    0.648962    
#> 376: 0.605636    1.113671    3.515329    0.496642    0.081202    0.023580    0.648898    
#> 377: 0.605511    1.113724    3.515319    0.496331    0.081118    0.023608    0.648826    
#> 378: 0.605340    1.113719    3.515258    0.496160    0.080973    0.023618    0.648828    
#> 379: 0.605052    1.113620    3.515228    0.495867    0.080923    0.023640    0.648755    
#> 380: 0.604855    1.113594    3.515214    0.495738    0.080855    0.023652    0.648700    
#> 381: 0.604715    1.113622    3.515256    0.495646    0.080826    0.023674    0.648641    
#> 382: 0.604752    1.113599    3.515266    0.495505    0.080760    0.023688    0.648590    
#> 383: 0.604800    1.113602    3.515307    0.495362    0.080724    0.023686    0.648475    
#> 384: 0.604594    1.113706    3.515305    0.495213    0.080710    0.023662    0.648513    
#> 385: 0.604655    1.113723    3.515284    0.495442    0.080650    0.023667    0.648439    
#> 386: 0.604900    1.113790    3.515353    0.495615    0.080651    0.023684    0.648433    
#> 387: 0.605349    1.113779    3.515512    0.495803    0.080685    0.023696    0.648351    
#> 388: 0.605588    1.113828    3.515606    0.495850    0.080736    0.023719    0.648287    
#> 389: 0.605577    1.113815    3.515592    0.495835    0.080760    0.023717    0.648327    
#> 390: 0.605340    1.113966    3.515526    0.495436    0.080719    0.023715    0.648344    
#> 391: 0.605470    1.113951    3.515490    0.495744    0.080688    0.023712    0.648237    
#> 392: 0.605531    1.113982    3.515510    0.495954    0.080694    0.023707    0.648188    
#> 393: 0.605499    1.113852    3.515508    0.495810    0.080758    0.023689    0.648182    
#> 394: 0.605641    1.113732    3.515570    0.496242    0.080757    0.023691    0.648153    
#> 395: 0.605989    1.113779    3.515594    0.496751    0.080822    0.023683    0.648197    
#> 396: 0.606178    1.113691    3.515662    0.496904    0.080805    0.023678    0.648151    
#> 397: 0.606254    1.113613    3.515726    0.497326    0.080756    0.023683    0.648184    
#> 398: 0.606469    1.113620    3.515753    0.498179    0.080756    0.023689    0.648136    
#> 399: 0.606638    1.113638    3.515779    0.498847    0.080675    0.023707    0.648089    
#> 400: 0.606701    1.113700    3.515769    0.499280    0.080650    0.023711    0.648051    
#> 401: 0.606678    1.113737    3.515735    0.499495    0.080536    0.023732    0.648127    
#> 402: 0.606675    1.113909    3.515759    0.499688    0.080439    0.023762    0.648189    
#> 403: 0.606964    1.113925    3.515763    0.500207    0.080342    0.023791    0.648112    
#> 404: 0.607024    1.113979    3.515708    0.500585    0.080255    0.023827    0.647962    
#> 405: 0.607072    1.114031    3.515782    0.500407    0.080213    0.023868    0.647951    
#> 406: 0.606974    1.114158    3.515729    0.500378    0.080224    0.023884    0.647985    
#> 407: 0.606857    1.114247    3.515718    0.500253    0.080202    0.023887    0.648009    
#> 408: 0.606832    1.114364    3.515700    0.500077    0.080205    0.023890    0.648058    
#> 409: 0.606847    1.114365    3.515638    0.500151    0.080255    0.023872    0.648036    
#> 410: 0.606805    1.114465    3.515512    0.500669    0.080282    0.023865    0.648002    
#> 411: 0.606968    1.114335    3.515534    0.501671    0.080312    0.023862    0.648019    
#> 412: 0.607244    1.114258    3.515566    0.502374    0.080288    0.023864    0.648035    
#> 413: 0.607549    1.114307    3.515559    0.503403    0.080257    0.023859    0.648017    
#> 414: 0.607436    1.114342    3.515529    0.503522    0.080242    0.023858    0.647934    
#> 415: 0.607471    1.114302    3.515519    0.503741    0.080195    0.023860    0.647914    
#> 416: 0.607396    1.114316    3.515523    0.503759    0.080169    0.023876    0.647923    
#> 417: 0.607354    1.114245    3.515518    0.503582    0.080119    0.023923    0.647919    
#> 418: 0.607051    1.114206    3.515530    0.503340    0.080086    0.023954    0.647902    
#> 419: 0.607056    1.114232    3.515557    0.503144    0.080072    0.023986    0.647876    
#> 420: 0.607132    1.114237    3.515565    0.503013    0.080006    0.024009    0.647859    
#> 421: 0.607172    1.114179    3.515660    0.502960    0.080003    0.024045    0.647800    
#> 422: 0.607504    1.114042    3.515730    0.503185    0.080008    0.024070    0.647764    
#> 423: 0.607860    1.113861    3.515818    0.503394    0.079992    0.024070    0.647744    
#> 424: 0.607932    1.113707    3.515882    0.503116    0.080009    0.024071    0.647756    
#> 425: 0.607974    1.113626    3.515930    0.502864    0.080080    0.024073    0.647858    
#> 426: 0.608066    1.113651    3.515962    0.502965    0.080166    0.024061    0.647882    
#> 427: 0.608080    1.113602    3.516005    0.503045    0.080199    0.024055    0.647888    
#> 428: 0.608158    1.113652    3.516062    0.503344    0.080189    0.024057    0.647893    
#> 429: 0.608309    1.113628    3.516097    0.503287    0.080145    0.024066    0.647872    
#> 430: 0.608464    1.113685    3.516091    0.503550    0.080144    0.024062    0.647851    
#> 431: 0.608534    1.113613    3.516091    0.503776    0.080125    0.024042    0.647762    
#> 432: 0.608462    1.113644    3.516086    0.503933    0.080159    0.024018    0.647743    
#> 433: 0.608380    1.113699    3.516068    0.503817    0.080230    0.024008    0.647665    
#> 434: 0.608235    1.113612    3.516053    0.503585    0.080254    0.023998    0.647620    
#> 435: 0.608242    1.113650    3.516040    0.503476    0.080250    0.023989    0.647556    
#> 436: 0.608158    1.113664    3.516073    0.503175    0.080273    0.023986    0.647558    
#> 437: 0.608193    1.113582    3.516103    0.502944    0.080235    0.023995    0.647504    
#> 438: 0.608291    1.113642    3.516092    0.502950    0.080208    0.024002    0.647419    
#> 439: 0.608429    1.113673    3.516101    0.503055    0.080218    0.023999    0.647318    
#> 440: 0.608557    1.113738    3.516153    0.502850    0.080192    0.023996    0.647339    
#> 441: 0.608650    1.113769    3.516181    0.502487    0.080225    0.023983    0.647321    
#> 442: 0.608460    1.113780    3.516166    0.502133    0.080239    0.023974    0.647266    
#> 443: 0.608492    1.113865    3.516133    0.501906    0.080248    0.023977    0.647280    
#> 444: 0.608411    1.113952    3.516092    0.501631    0.080226    0.023994    0.647248    
#> 445: 0.608467    1.114088    3.516103    0.501517    0.080209    0.024031    0.647274    
#> 446: 0.608339    1.114192    3.516046    0.501439    0.080124    0.024060    0.647233    
#> 447: 0.608351    1.114249    3.516036    0.501578    0.080046    0.024088    0.647228    
#> 448: 0.608352    1.114212    3.516019    0.501914    0.080015    0.024110    0.647198    
#> 449: 0.608396    1.114224    3.516130    0.502060    0.079965    0.024133    0.647269    
#> 450: 0.608463    1.114143    3.516146    0.502308    0.079880    0.024146    0.647370    
#> 451: 0.608501    1.114089    3.516144    0.502249    0.079793    0.024159    0.647480    
#> 452: 0.608451    1.114061    3.516138    0.502198    0.079779    0.024167    0.647449    
#> 453: 0.608353    1.114031    3.516130    0.502112    0.079795    0.024176    0.647406    
#> 454: 0.608078    1.114162    3.516059    0.501751    0.079777    0.024186    0.647406    
#> 455: 0.607969    1.114205    3.515963    0.501643    0.079735    0.024196    0.647424    
#> 456: 0.607795    1.114197    3.515917    0.501439    0.079735    0.024214    0.647453    
#> 457: 0.607654    1.114224    3.515904    0.501212    0.079698    0.024245    0.647448    
#> 458: 0.607620    1.114353    3.515899    0.501144    0.079649    0.024272    0.647365    
#> 459: 0.607442    1.114484    3.515905    0.501115    0.079635    0.024296    0.647353    
#> 460: 0.607328    1.114481    3.515856    0.501229    0.079639    0.024295    0.647312    
#> 461: 0.607288    1.114492    3.515877    0.501396    0.079593    0.024298    0.647303    
#> 462: 0.607314    1.114449    3.515943    0.501609    0.079532    0.024318    0.647316    
#> 463: 0.607435    1.114437    3.516029    0.501603    0.079499    0.024339    0.647292    
#> 464: 0.607516    1.114394    3.516078    0.501355    0.079453    0.024346    0.647273    
#> 465: 0.607545    1.114199    3.516129    0.501111    0.079411    0.024357    0.647283    
#> 466: 0.607601    1.114221    3.516126    0.500980    0.079370    0.024371    0.647326    
#> 467: 0.607695    1.114133    3.516166    0.501093    0.079289    0.024384    0.647277    
#> 468: 0.607959    1.114117    3.516225    0.501099    0.079286    0.024390    0.647355    
#> 469: 0.608112    1.114172    3.516267    0.500909    0.079311    0.024395    0.647452    
#> 470: 0.607974    1.114209    3.516266    0.500758    0.079294    0.024421    0.647423    
#> 471: 0.607873    1.114190    3.516257    0.500594    0.079257    0.024434    0.647489    
#> 472: 0.607814    1.114159    3.516288    0.500314    0.079235    0.024459    0.647525    
#> 473: 0.607721    1.114095    3.516293    0.500035    0.079177    0.024468    0.647500    
#> 474: 0.607689    1.114065    3.516297    0.499971    0.079195    0.024479    0.647549    
#> 475: 0.607765    1.114182    3.516286    0.500061    0.079209    0.024477    0.647515    
#> 476: 0.607822    1.114179    3.516332    0.499969    0.079228    0.024472    0.647531    
#> 477: 0.607789    1.114162    3.516400    0.499830    0.079242    0.024470    0.647535    
#> 478: 0.607741    1.114101    3.516435    0.500023    0.079238    0.024462    0.647651    
#> 479: 0.607904    1.114139    3.516403    0.500589    0.079244    0.024458    0.647717    
#> 480: 0.607964    1.114208    3.516382    0.500961    0.079261    0.024452    0.647691    
#> 481: 0.608073    1.114253    3.516357    0.501129    0.079279    0.024438    0.647670    
#> 482: 0.608171    1.114257    3.516353    0.501100    0.079294    0.024446    0.647693    
#> 483: 0.608134    1.114171    3.516351    0.501027    0.079253    0.024455    0.647710    
#> 484: 0.608235    1.113982    3.516400    0.501033    0.079201    0.024459    0.647730    
#> 485: 0.608303    1.114022    3.516435    0.501042    0.079296    0.024470    0.647777    
#> 486: 0.608333    1.114088    3.516488    0.500959    0.079302    0.024474    0.647791    
#> 487: 0.608620    1.114100    3.516567    0.501083    0.079285    0.024470    0.647798    
#> 488: 0.608695    1.114068    3.516591    0.501475    0.079238    0.024476    0.647759    
#> 489: 0.608806    1.114008    3.516590    0.501683    0.079201    0.024487    0.647731    
#> 490: 0.608928    1.114028    3.516619    0.501738    0.079183    0.024490    0.647703    
#> 491: 0.609005    1.114061    3.516680    0.501679    0.079164    0.024516    0.647664    
#> 492: 0.609021    1.114122    3.516715    0.501631    0.079153    0.024529    0.647672    
#> 493: 0.608974    1.114172    3.516744    0.501601    0.079120    0.024563    0.647619    
#> 494: 0.609177    1.114197    3.516754    0.501891    0.079112    0.024583    0.647543    
#> 495: 0.609331    1.114217    3.516762    0.502078    0.079091    0.024588    0.647510    
#> 496: 0.609568    1.114273    3.516762    0.502381    0.079075    0.024604    0.647467    
#> 497: 0.609588    1.114282    3.516793    0.502502    0.079010    0.024610    0.647475    
#> 498: 0.609741    1.114235    3.516810    0.502874    0.079006    0.024620    0.647445    
#> 499: 0.609733    1.114247    3.516809    0.502871    0.078982    0.024628    0.647377    
#> 500: 0.609814    1.114229    3.516792    0.503021    0.078947    0.024640    0.647304    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.256212    0.982134    3.445674    0.392401    0.083976    0.016800    1.853985    
#> 002: 0.085579    1.034947    3.483875    0.372781    0.079777    0.019067    1.173887    
#> 003: 0.116240    1.002233    3.503446    0.354142    0.075788    0.018474    0.857279    
#> 004: 0.097538    1.031555    3.513310    0.336435    0.088268    0.020759    0.757253    
#> 005: 0.131174    1.035177    3.503597    0.319613    0.083854    0.019721    0.726060    
#> 006: 0.064327    1.041917    3.481512    0.303633    0.079662    0.018735    0.676683    
#> 007: 0.015870    1.044713    3.477118    0.288451    0.085641    0.017798    0.687920    
#> 008: 0.027305    1.048855    3.472951    0.274029    0.081359    0.022377    0.684564    
#> 009: -0.021339   1.047778    3.463173    0.260327    0.077291    0.023795    0.679544    
#> 010: 0.026029    1.053196    3.465344    0.247311    0.073426    0.022605    0.677278    
#> 011: 0.068174    1.064428    3.476119    0.234945    0.096228    0.021475    0.678565    
#> 012: 0.047484    1.049693    3.464649    0.223198    0.091416    0.020401    0.679604    
#> 013: -0.006215   1.048229    3.458805    0.212038    0.097067    0.019381    0.671496    
#> 014: 0.022454    1.043464    3.479633    0.201436    0.092214    0.018412    0.686094    
#> 015: 0.042997    1.050799    3.485906    0.191364    0.087603    0.019597    0.660302    
#> 016: 0.039454    1.053820    3.492979    0.181796    0.083223    0.027276    0.665227    
#> 017: 0.060005    1.059667    3.497856    0.172706    0.079062    0.025912    0.660603    
#> 018: 0.063066    1.052549    3.478765    0.164071    0.088091    0.024616    0.668384    
#> 019: 0.035353    1.064258    3.483896    0.155867    0.091109    0.023385    0.665133    
#> 020: 0.066516    1.052618    3.481501    0.148074    0.102442    0.022216    0.686625    
#> 021: 0.060805    1.045267    3.481555    0.140670    0.097320    0.021105    0.675061    
#> 022: 0.064180    1.047214    3.499513    0.133637    0.092454    0.020050    0.671337    
#> 023: 0.099929    1.050709    3.504735    0.126955    0.087831    0.019048    0.694559    
#> 024: 0.115094    1.056344    3.502101    0.120607    0.083440    0.018547    0.673618    
#> 025: 0.086950    1.039169    3.505292    0.114577    0.079268    0.021283    0.662878    
#> 026: 0.073225    1.054038    3.484349    0.108848    0.075304    0.020219    0.668080    
#> 027: 0.066468    1.064696    3.486846    0.103406    0.071539    0.019208    0.678558    
#> 028: 0.069028    1.075822    3.490019    0.098235    0.076147    0.018572    0.667075    
#> 029: 0.073351    1.061032    3.483418    0.093324    0.088597    0.020205    0.692996    
#> 030: 0.034378    1.079898    3.461117    0.088657    0.089711    0.019195    0.682368    
#> 031: 0.043560    1.057684    3.481179    0.084225    0.088972    0.018235    0.679734    
#> 032: 0.033755    1.033362    3.483539    0.084113    0.084523    0.017323    0.688594    
#> 033: 0.019192    1.067271    3.474730    0.083748    0.080297    0.016856    0.676338    
#> 034: 0.075137    1.078248    3.482178    0.079561    0.085093    0.016013    0.688301    
#> 035: 0.033330    1.053047    3.472471    0.075583    0.083189    0.015212    0.691137    
#> 036: 0.040195    1.075484    3.478919    0.074991    0.083417    0.015468    0.675168    
#> 037: 0.009459    1.090065    3.474885    0.071241    0.081892    0.015877    0.674559    
#> 038: 0.051111    1.079341    3.476132    0.091543    0.079597    0.015084    0.688131    
#> 039: 0.081782    1.050743    3.498655    0.086966    0.076579    0.017944    0.665271    
#> 040: 0.063824    1.064538    3.494627    0.082617    0.072750    0.017391    0.689584    
#> 041: 0.037389    1.037256    3.498329    0.078487    0.069113    0.018232    0.694093    
#> 042: 0.067656    1.043145    3.496452    0.074562    0.065657    0.018095    0.683210    
#> 043: 0.036077    1.052439    3.483081    0.073230    0.062374    0.017843    0.681934    
#> 044: 0.018122    1.075615    3.466630    0.073227    0.067272    0.016951    0.676596    
#> 045: 0.037844    1.081027    3.463764    0.070835    0.076458    0.016103    0.687470    
#> 046: 0.053374    1.075190    3.473403    0.067294    0.086684    0.015298    0.702567    
#> 047: 0.055381    1.080645    3.476343    0.063929    0.082349    0.014533    0.692613    
#> 048: 0.044015    1.056562    3.472440    0.068942    0.084432    0.014051    0.686532    
#> 049: 0.032364    1.057440    3.485622    0.066305    0.089096    0.013387    0.695766    
#> 050: 0.077732    1.020769    3.485239    0.062989    0.086458    0.013166    0.718477    
#> 051: 0.067933    1.027835    3.485272    0.067271    0.082135    0.017225    0.692490    
#> 052: 0.082390    1.050173    3.504994    0.075846    0.078028    0.016635    0.668625    
#> 053: 0.074684    1.051836    3.490794    0.077180    0.074127    0.015804    0.681024    
#> 054: 0.027421    1.043785    3.487876    0.082543    0.087788    0.018181    0.682813    
#> 055: 0.023792    1.033452    3.489411    0.083522    0.094036    0.017272    0.693242    
#> 056: 0.047090    1.033097    3.478789    0.079704    0.089334    0.016976    0.679877    
#> 057: 0.029311    1.050955    3.483479    0.110730    0.084867    0.020282    0.674077    
#> 058: 0.041227    1.050377    3.468875    0.105193    0.080624    0.019268    0.679745    
#> 059: 0.028003    1.032519    3.478121    0.099934    0.076593    0.018305    0.682561    
#> 060: 0.074377    1.022649    3.502673    0.098060    0.072763    0.019192    0.680598    
#> 061: 0.104714    1.023929    3.510396    0.093157    0.074763    0.023090    0.698392    
#> 062: 0.099782    1.040086    3.521967    0.088499    0.104765    0.021935    0.701568    
#> 063: 0.106665    1.017315    3.508103    0.084074    0.099526    0.021533    0.690176    
#> 064: 0.118501    1.031239    3.516849    0.079870    0.094550    0.020457    0.698050    
#> 065: 0.103141    1.025325    3.500209    0.075877    0.089822    0.019434    0.683891    
#> 066: 0.089126    1.043231    3.503350    0.072083    0.085331    0.020392    0.673777    
#> 067: 0.114860    1.013076    3.518103    0.068479    0.081065    0.022375    0.668446    
#> 068: 0.082600    1.039118    3.520335    0.065055    0.082632    0.024775    0.693628    
#> 069: 0.094267    1.033141    3.499709    0.061802    0.078501    0.023536    0.692712    
#> 070: 0.078378    1.053528    3.504617    0.072017    0.078451    0.022359    0.708615    
#> 071: 0.062042    1.087182    3.471783    0.069134    0.089303    0.021241    0.686178    
#> 072: -0.003500   1.039290    3.480381    0.074533    0.084837    0.020179    0.679962    
#> 073: 0.049341    1.052967    3.487815    0.070806    0.082769    0.019170    0.673354    
#> 074: 0.034724    1.021606    3.493163    0.067266    0.078631    0.019069    0.676069    
#> 075: 0.065953    1.032194    3.517176    0.063903    0.076772    0.019301    0.678346    
#> 076: 0.057353    1.051116    3.506675    0.068065    0.073811    0.018336    0.698703    
#> 077: 0.101190    1.016177    3.508901    0.090718    0.088932    0.017419    0.683438    
#> 078: 0.099780    1.022262    3.514116    0.086182    0.087357    0.018669    0.665480    
#> 079: 0.134911    1.053461    3.517038    0.081873    0.082989    0.021953    0.697069    
#> 080: 0.122295    1.031707    3.506082    0.094320    0.089131    0.020855    0.687428    
#> 081: 0.108452    1.048989    3.500968    0.101194    0.087058    0.019812    0.669927    
#> 082: 0.083647    1.018586    3.509104    0.096134    0.082705    0.018822    0.690159    
#> 083: 0.098844    1.035671    3.510438    0.091328    0.078570    0.017880    0.680277    
#> 084: 0.077660    1.048453    3.496242    0.087482    0.074764    0.016986    0.659625    
#> 085: 0.053158    1.070050    3.497858    0.092126    0.081337    0.016488    0.671471    
#> 086: 0.037431    1.050398    3.485706    0.087519    0.080259    0.016664    0.651483    
#> 087: 0.031701    1.048026    3.476262    0.083143    0.076246    0.018072    0.660028    
#> 088: -0.009396   1.056053    3.474752    0.078986    0.072434    0.018427    0.691793    
#> 089: 0.028678    1.075826    3.456070    0.075037    0.093477    0.020093    0.680943    
#> 090: 0.009895    1.079676    3.464170    0.074651    0.092796    0.019088    0.671786    
#> 091: -0.002236   1.064181    3.449951    0.078573    0.088156    0.022082    0.673965    
#> 092: -0.016312   1.084717    3.447934    0.089146    0.083748    0.021821    0.685780    
#> 093: -0.030030   1.063417    3.453621    0.084689    0.079561    0.020730    0.681701    
#> 094: -0.042927   1.088713    3.447126    0.093170    0.079515    0.019693    0.708427    
#> 095: -0.013319   1.097485    3.458970    0.088512    0.076678    0.018798    0.701831    
#> 096: -0.019417   1.075568    3.463492    0.093358    0.072844    0.019425    0.689279    
#> 097: 0.002941    1.097310    3.452774    0.104380    0.074851    0.018453    0.673011    
#> 098: 0.003779    1.099157    3.466979    0.099161    0.071109    0.017601    0.703779    
#> 099: 0.011724    1.064761    3.458078    0.094203    0.070591    0.016741    0.684070    
#> 100: 0.006526    1.069240    3.458768    0.090828    0.073029    0.015904    0.679711    
#> 101: 0.000956    1.063902    3.451283    0.091253    0.082201    0.015109    0.676599    
#> 102: -0.000370   1.083006    3.447039    0.086691    0.095241    0.014353    0.684700    
#> 103: 0.023424    1.064572    3.464513    0.085099    0.090479    0.013635    0.680037    
#> 104: 0.039943    1.064150    3.474312    0.080844    0.085955    0.013554    0.681428    
#> 105: 0.025316    1.039970    3.475506    0.076802    0.097252    0.012877    0.683609    
#> 106: 0.033547    1.046205    3.472116    0.072962    0.092389    0.012893    0.673743    
#> 107: 0.084226    1.075168    3.488283    0.069314    0.087770    0.016995    0.682251    
#> 108: 0.057926    1.072294    3.475764    0.065848    0.083381    0.016386    0.711422    
#> 109: 0.046914    1.054812    3.493190    0.062556    0.079212    0.017508    0.685345    
#> 110: 0.047104    1.049010    3.474351    0.068174    0.079491    0.016632    0.667754    
#> 111: 0.045718    1.054776    3.491813    0.070395    0.075516    0.016426    0.666413    
#> 112: 0.060730    1.038786    3.480185    0.069223    0.098978    0.016089    0.667928    
#> 113: 0.071594    1.070359    3.485146    0.069048    0.094029    0.015284    0.658710    
#> 114: 0.080769    1.063685    3.485494    0.067689    0.091348    0.014520    0.680460    
#> 115: 0.087280    1.032541    3.483768    0.069670    0.086780    0.015596    0.713171    
#> 116: 0.035859    1.049915    3.486323    0.075238    0.082441    0.016335    0.706807    
#> 117: 0.044396    1.077476    3.481181    0.071476    0.088275    0.015519    0.696927    
#> 118: 0.054642    1.040778    3.480014    0.087258    0.083861    0.014743    0.672514    
#> 119: 0.039353    1.062512    3.479395    0.095208    0.087478    0.016932    0.672856    
#> 120: 0.045275    1.059126    3.484943    0.090448    0.083104    0.016139    0.681142    
#> 121: 0.062606    1.064884    3.491558    0.088372    0.078949    0.015916    0.692158    
#> 122: 0.065707    1.033251    3.507218    0.083953    0.081649    0.019675    0.698494    
#> 123: 0.075721    1.067464    3.495019    0.088469    0.077567    0.018691    0.664352    
#> 124: 0.109625    1.073447    3.503519    0.084046    0.073689    0.018806    0.682553    
#> 125: 0.109636    1.045659    3.494738    0.079843    0.070004    0.020213    0.678860    
#> 126: 0.061349    1.059821    3.484607    0.076883    0.066504    0.023626    0.673446    
#> 127: 0.088016    1.042001    3.489878    0.073039    0.063179    0.026785    0.673076    
#> 128: 0.053549    1.062971    3.488868    0.084067    0.079891    0.025446    0.669584    
#> 129: 0.082898    1.052767    3.496766    0.079864    0.088415    0.024174    0.673662    
#> 130: 0.072213    1.055351    3.485529    0.075871    0.083994    0.022965    0.651304    
#> 131: 0.047441    1.052794    3.473113    0.072077    0.090589    0.021817    0.668456    
#> 132: 0.015221    1.043437    3.460519    0.068473    0.091201    0.020726    0.693170    
#> 133: 0.057509    1.041346    3.482154    0.067387    0.086641    0.022958    0.687524    
#> 134: 0.061731    1.028228    3.498925    0.074808    0.082309    0.021810    0.696752    
#> 135: 0.036894    1.027797    3.498096    0.071067    0.083864    0.020720    0.672861    
#> 136: 0.057304    1.030975    3.495632    0.067514    0.079671    0.019684    0.667825    
#> 137: 0.096517    1.032042    3.499137    0.067016    0.075688    0.018700    0.688484    
#> 138: 0.108117    1.039599    3.510220    0.071879    0.082828    0.017765    0.675932    
#> 139: 0.090957    1.050594    3.504396    0.068285    0.081060    0.016876    0.678587    
#> 140: 0.090084    1.052232    3.502382    0.081892    0.077007    0.016790    0.698164    
#> 141: 0.077708    1.015369    3.513302    0.080775    0.080890    0.018447    0.680560    
#> 142: 0.073002    1.027935    3.501708    0.083751    0.076845    0.017524    0.690789    
#> 143: 0.068860    1.027341    3.503949    0.079563    0.076070    0.021981    0.689068    
#> 144: 0.092698    1.043756    3.504116    0.077387    0.073044    0.020882    0.674253    
#> 145: 0.076249    1.037930    3.486771    0.078256    0.071864    0.019838    0.661860    
#> 146: 0.045702    1.044370    3.491378    0.078797    0.068271    0.018846    0.676597    
#> 147: 0.034983    1.033966    3.496740    0.074857    0.064857    0.023218    0.675579    
#> 148: 0.057740    1.046627    3.499580    0.075228    0.066509    0.022057    0.676759    
#> 149: 0.038945    1.059652    3.478072    0.071467    0.073094    0.020954    0.687602    
#> 150: 0.067857    1.042657    3.482007    0.068084    0.084200    0.019906    0.675161    
#> 151: 0.025423    1.064749    3.483403    0.085361    0.081244    0.018911    0.669627    
#> 152: 0.014020    1.059786    3.472268    0.097703    0.069222    0.023259    0.673542    
#> 153: 0.039459    1.056457    3.490398    0.084893    0.076264    0.023829    0.685529    
#> 154: 0.131563    1.034076    3.511852    0.073207    0.058910    0.020517    0.684428    
#> 155: 0.097488    1.021079    3.503666    0.071401    0.082367    0.016980    0.667980    
#> 156: 0.082613    1.031064    3.512996    0.066270    0.079700    0.017661    0.707200    
#> 157: 0.112626    1.018031    3.522842    0.061198    0.079914    0.018417    0.693609    
#> 158: 0.120788    1.042620    3.517065    0.064851    0.084371    0.019409    0.670923    
#> 159: 0.090907    1.042616    3.519103    0.069461    0.078739    0.021031    0.667140    
#> 160: 0.108190    1.013758    3.514528    0.064552    0.083305    0.020321    0.674945    
#> 161: 0.079962    1.018752    3.498110    0.064886    0.086724    0.019286    0.697929    
#> 162: 0.066954    1.046276    3.484655    0.057039    0.100361    0.019242    0.694086    
#> 163: 0.099463    1.051609    3.488731    0.062929    0.088739    0.016871    0.676224    
#> 164: 0.099670    1.051743    3.491358    0.063946    0.085135    0.017627    0.669612    
#> 165: 0.111686    1.044009    3.502110    0.060901    0.092741    0.014715    0.671788    
#> 166: 0.147618    1.063032    3.511302    0.069706    0.080751    0.015777    0.676545    
#> 167: 0.115801    1.047940    3.513848    0.065860    0.063736    0.018211    0.685651    
#> 168: 0.115013    1.053414    3.514264    0.065113    0.062612    0.018349    0.692714    
#> 169: 0.080401    1.063842    3.502850    0.073418    0.068567    0.020394    0.696389    
#> 170: 0.098983    1.024996    3.504199    0.055995    0.054639    0.019440    0.687926    
#> 171: 0.062349    1.047634    3.483512    0.060032    0.072994    0.020051    0.673186    
#> 172: 0.025189    1.074714    3.479492    0.085937    0.095920    0.013449    0.668863    
#> 173: 0.000154    1.094990    3.449828    0.061583    0.086399    0.015703    0.676197    
#> 174: 0.014576    1.089730    3.465580    0.046111    0.078820    0.017408    0.682508    
#> 175: 0.031449    1.067084    3.463617    0.052530    0.083531    0.017229    0.689435    
#> 176: 0.018788    1.089577    3.473113    0.045034    0.085835    0.015368    0.680381    
#> 177: 0.025197    1.069699    3.476570    0.052089    0.073267    0.016683    0.698441    
#> 178: 0.017345    1.061847    3.474918    0.053467    0.081867    0.016262    0.677059    
#> 179: 0.010896    1.075412    3.466832    0.063676    0.087170    0.013422    0.685417    
#> 180: 0.011157    1.073323    3.471649    0.050500    0.073210    0.016998    0.670492    
#> 181: -0.004301   1.074905    3.454564    0.053898    0.078186    0.017214    0.680791    
#> 182: -0.026435   1.086718    3.451896    0.064841    0.070624    0.018794    0.696338    
#> 183: -0.013438   1.097747    3.457929    0.051455    0.063141    0.018434    0.689319    
#> 184: -0.017482   1.071321    3.462987    0.062498    0.075613    0.016495    0.684086    
#> 185: -0.034572   1.077077    3.459346    0.066000    0.065241    0.019291    0.691755    
#> 186: 0.023774    1.101134    3.471419    0.061092    0.082413    0.019865    0.692837    
#> 187: 0.026516    1.071827    3.473594    0.075092    0.076208    0.019726    0.685144    
#> 188: 0.022398    1.082546    3.468962    0.090019    0.067074    0.020899    0.690935    
#> 189: 0.035373    1.095544    3.474952    0.071553    0.085557    0.017149    0.680090    
#> 190: -0.002102   1.075626    3.466229    0.064845    0.080653    0.014710    0.686233    
#> 191: -0.023339   1.087650    3.448755    0.087054    0.082101    0.012952    0.685353    
#> 192: -0.004534   1.078504    3.462593    0.075813    0.076349    0.012652    0.678452    
#> 193: 0.011166    1.100502    3.465977    0.071989    0.087575    0.014362    0.670371    
#> 194: 0.039451    1.083720    3.457960    0.063374    0.079879    0.018355    0.693330    
#> 195: 0.018015    1.083132    3.463770    0.061935    0.076314    0.018692    0.671041    
#> 196: 0.026552    1.078886    3.473035    0.078711    0.069351    0.018425    0.693992    
#> 197: -0.008257   1.077555    3.484327    0.063445    0.079812    0.020392    0.706859    
#> 198: 0.019362    1.070264    3.468026    0.072401    0.075503    0.019130    0.684113    
#> 199: 0.030086    1.046459    3.473454    0.058183    0.085417    0.018603    0.684623    
#> 200: 0.033574    1.061491    3.478438    0.061167    0.092300    0.018061    0.699618    
#> 201: 0.047579    1.057787    3.485185    0.051653    0.085677    0.020639    0.689128    
#> 202: 0.046011    1.061958    3.485916    0.053311    0.078512    0.022431    0.688514    
#> 203: 0.055492    1.059484    3.489215    0.054762    0.076172    0.022784    0.687785    
#> 204: 0.067310    1.050975    3.492721    0.054390    0.075433    0.022550    0.689012    
#> 205: 0.070223    1.054022    3.494966    0.055197    0.074502    0.022567    0.691187    
#> 206: 0.070649    1.058581    3.494059    0.056604    0.074674    0.021771    0.692883    
#> 207: 0.069977    1.056329    3.493296    0.054628    0.074403    0.021961    0.696377    
#> 208: 0.069881    1.054695    3.494523    0.052617    0.073470    0.021917    0.697012    
#> 209: 0.072343    1.052848    3.494093    0.052573    0.074042    0.021651    0.696368    
#> 210: 0.075132    1.050858    3.494485    0.053701    0.075223    0.021451    0.695086    
#> 211: 0.076425    1.051193    3.495339    0.055001    0.075466    0.021142    0.693304    
#> 212: 0.078363    1.051450    3.496929    0.055688    0.074700    0.021482    0.693661    
#> 213: 0.080384    1.048130    3.498173    0.055717    0.073729    0.021706    0.693844    
#> 214: 0.081504    1.047480    3.498037    0.055846    0.073889    0.021566    0.693428    
#> 215: 0.081635    1.047664    3.498200    0.055313    0.074029    0.021338    0.694209    
#> 216: 0.082631    1.046653    3.498103    0.056203    0.074640    0.021014    0.694708    
#> 217: 0.082671    1.047517    3.498205    0.056770    0.074792    0.020699    0.693514    
#> 218: 0.083866    1.048001    3.497552    0.056814    0.074057    0.020394    0.692817    
#> 219: 0.084181    1.047518    3.496854    0.057863    0.074333    0.020143    0.692810    
#> 220: 0.083052    1.048721    3.496922    0.059079    0.074308    0.020213    0.692229    
#> 221: 0.082774    1.048872    3.496940    0.059311    0.074034    0.020085    0.691637    
#> 222: 0.083060    1.048692    3.496674    0.059853    0.074350    0.019975    0.690981    
#> 223: 0.084661    1.048077    3.497083    0.060078    0.074205    0.019905    0.690482    
#> 224: 0.085782    1.049623    3.497461    0.059848    0.074396    0.019890    0.690138    
#> 225: 0.085758    1.048657    3.497937    0.059547    0.074257    0.019787    0.689442    
#> 226: 0.085650    1.047539    3.497651    0.059464    0.074181    0.019751    0.689176    
#> 227: 0.083358    1.048522    3.497153    0.060351    0.074085    0.019665    0.688372    
#> 228: 0.081896    1.049721    3.496163    0.060838    0.074290    0.019681    0.688154    
#> 229: 0.081121    1.049313    3.496000    0.061256    0.073967    0.019730    0.687241    
#> 230: 0.081783    1.049371    3.495890    0.061251    0.074137    0.019584    0.687081    
#> 231: 0.082558    1.049308    3.496074    0.061256    0.074443    0.019552    0.687128    
#> 232: 0.081444    1.048677    3.496531    0.061630    0.074594    0.019591    0.686946    
#> 233: 0.081343    1.047562    3.496721    0.061762    0.074425    0.019592    0.686522    
#> 234: 0.081128    1.047404    3.496966    0.061682    0.074473    0.019637    0.686134    
#> 235: 0.080805    1.047070    3.496868    0.062005    0.074435    0.019544    0.685942    
#> 236: 0.080725    1.047135    3.496874    0.062213    0.074594    0.019390    0.685694    
#> 237: 0.081146    1.046697    3.496899    0.062826    0.074857    0.019245    0.685792    
#> 238: 0.081476    1.046315    3.496941    0.063188    0.075132    0.019113    0.685990    
#> 239: 0.081653    1.046768    3.496954    0.063783    0.075481    0.018993    0.685472    
#> 240: 0.081502    1.046629    3.496921    0.064218    0.075620    0.018945    0.684824    
#> 241: 0.081681    1.045989    3.497104    0.064790    0.075546    0.018931    0.684543    
#> 242: 0.081492    1.045840    3.496846    0.064825    0.075219    0.018910    0.685088    
#> 243: 0.080724    1.045818    3.496785    0.064445    0.074737    0.018883    0.685584    
#> 244: 0.079616    1.045856    3.496796    0.064335    0.074700    0.018839    0.685903    
#> 245: 0.079567    1.045622    3.496782    0.064327    0.074683    0.018736    0.686192    
#> 246: 0.079771    1.045043    3.496937    0.064304    0.074919    0.018715    0.686408    
#> 247: 0.079788    1.044921    3.497003    0.064401    0.075031    0.018685    0.686027    
#> 248: 0.079944    1.045379    3.496990    0.064289    0.075282    0.018595    0.685732    
#> 249: 0.079795    1.045931    3.496942    0.064344    0.075578    0.018530    0.685645    
#> 250: 0.080303    1.046051    3.497251    0.064456    0.075528    0.018549    0.685722    
#> 251: 0.080924    1.046260    3.497735    0.064687    0.075475    0.018576    0.685791    
#> 252: 0.081309    1.046436    3.497980    0.064696    0.075823    0.018539    0.685730    
#> 253: 0.081632    1.046842    3.498079    0.064567    0.076360    0.018544    0.685810    
#> 254: 0.081902    1.047131    3.498335    0.064440    0.076576    0.018558    0.685940    
#> 255: 0.081764    1.047323    3.498414    0.064304    0.076519    0.018624    0.686165    
#> 256: 0.081614    1.047263    3.498367    0.064133    0.076287    0.018642    0.686363    
#> 257: 0.081061    1.046773    3.498298    0.064321    0.076288    0.018622    0.686529    
#> 258: 0.080771    1.046529    3.498177    0.064329    0.076124    0.018605    0.686410    
#> 259: 0.080505    1.046448    3.498020    0.064346    0.076210    0.018615    0.686329    
#> 260: 0.080012    1.046581    3.498007    0.064369    0.076125    0.018570    0.686147    
#> 261: 0.079704    1.046614    3.498040    0.064381    0.076217    0.018589    0.686148    
#> 262: 0.079697    1.046687    3.498024    0.064768    0.076540    0.018579    0.685986    
#> 263: 0.079876    1.047100    3.497974    0.064818    0.076753    0.018592    0.686002    
#> 264: 0.079802    1.047138    3.497925    0.064835    0.077082    0.018559    0.686192    
#> 265: 0.079915    1.047410    3.497819    0.064978    0.077317    0.018529    0.686181    
#> 266: 0.080469    1.047647    3.497841    0.065317    0.077554    0.018459    0.686046    
#> 267: 0.080506    1.047794    3.497749    0.065658    0.077906    0.018395    0.685890    
#> 268: 0.080220    1.047532    3.497547    0.065871    0.077928    0.018362    0.685773    
#> 269: 0.080470    1.047593    3.497545    0.066095    0.078172    0.018359    0.685748    
#> 270: 0.080741    1.047562    3.497413    0.066309    0.078396    0.018343    0.685561    
#> 271: 0.080914    1.047496    3.497286    0.066386    0.078602    0.018339    0.685399    
#> 272: 0.080616    1.047640    3.497061    0.066698    0.078662    0.018379    0.685395    
#> 273: 0.080350    1.047887    3.497036    0.066785    0.078819    0.018349    0.685298    
#> 274: 0.079884    1.048216    3.497036    0.066883    0.078772    0.018330    0.685223    
#> 275: 0.079567    1.048319    3.496807    0.067078    0.078744    0.018321    0.685226    
#> 276: 0.078990    1.048575    3.496792    0.067319    0.078733    0.018310    0.685139    
#> 277: 0.078524    1.048942    3.496789    0.067286    0.078780    0.018235    0.685071    
#> 278: 0.078478    1.048906    3.496855    0.067489    0.079016    0.018144    0.684928    
#> 279: 0.078335    1.048794    3.496862    0.067570    0.079253    0.018115    0.684910    
#> 280: 0.078436    1.048839    3.496879    0.067570    0.079370    0.018053    0.684736    
#> 281: 0.078253    1.048814    3.497010    0.067594    0.079552    0.018020    0.684668    
#> 282: 0.078385    1.048843    3.496927    0.067609    0.079827    0.017969    0.684538    
#> 283: 0.078416    1.048919    3.496886    0.067577    0.079838    0.017931    0.684711    
#> 284: 0.078344    1.048562    3.496928    0.067495    0.079793    0.017868    0.684735    
#> 285: 0.078556    1.048432    3.496850    0.067507    0.079908    0.017788    0.684722    
#> 286: 0.078759    1.048370    3.496774    0.067541    0.080138    0.017719    0.684634    
#> 287: 0.078839    1.048451    3.496766    0.067675    0.080311    0.017678    0.684530    
#> 288: 0.078789    1.048749    3.496562    0.067729    0.080438    0.017646    0.684427    
#> 289: 0.078906    1.048462    3.496556    0.067804    0.080355    0.017644    0.684520    
#> 290: 0.078493    1.048291    3.496460    0.067922    0.080233    0.017645    0.684705    
#> 291: 0.078834    1.048568    3.496613    0.067842    0.080144    0.017716    0.684662    
#> 292: 0.079092    1.048517    3.496694    0.067767    0.080064    0.017733    0.684691    
#> 293: 0.079218    1.048412    3.496649    0.067721    0.080025    0.017746    0.684671    
#> 294: 0.078924    1.048616    3.496476    0.067585    0.080092    0.017722    0.684519    
#> 295: 0.078824    1.048350    3.496462    0.067565    0.080003    0.017737    0.684252    
#> 296: 0.078701    1.048133    3.496538    0.067506    0.079843    0.017768    0.684314    
#> 297: 0.078756    1.048288    3.496494    0.067332    0.079801    0.017784    0.684317    
#> 298: 0.078863    1.048056    3.496518    0.067257    0.079709    0.017792    0.684305    
#> 299: 0.078862    1.048041    3.496531    0.067298    0.079610    0.017787    0.684218    
#> 300: 0.079024    1.047875    3.496661    0.067249    0.079674    0.017775    0.684001    
#> 301: 0.079099    1.047735    3.496523    0.067163    0.079824    0.017749    0.684067    
#> 302: 0.079306    1.047425    3.496587    0.067245    0.079956    0.017718    0.683949    
#> 303: 0.079178    1.047454    3.496543    0.067271    0.079965    0.017723    0.683718    
#> 304: 0.079159    1.047729    3.496399    0.067285    0.080030    0.017719    0.683657    
#> 305: 0.079012    1.047470    3.496394    0.067483    0.080218    0.017725    0.683670    
#> 306: 0.078642    1.047350    3.496292    0.067564    0.080264    0.017724    0.683688    
#> 307: 0.078358    1.047411    3.496009    0.067635    0.080559    0.017715    0.683653    
#> 308: 0.078081    1.047355    3.495987    0.067652    0.080686    0.017700    0.683635    
#> 309: 0.078183    1.047035    3.495953    0.067577    0.080633    0.017716    0.683677    
#> 310: 0.078270    1.047022    3.495831    0.067658    0.080568    0.017705    0.683572    
#> 311: 0.078521    1.047038    3.495894    0.067653    0.080537    0.017730    0.683440    
#> 312: 0.078563    1.047023    3.495879    0.067720    0.080469    0.017732    0.683287    
#> 313: 0.078605    1.046881    3.495841    0.067898    0.080380    0.017733    0.683332    
#> 314: 0.078286    1.046921    3.495706    0.068010    0.080355    0.017752    0.683206    
#> 315: 0.078025    1.046973    3.495680    0.068128    0.080374    0.017751    0.683082    
#> 316: 0.078017    1.047038    3.495694    0.067999    0.080253    0.017770    0.683016    
#> 317: 0.078304    1.046924    3.495903    0.067893    0.080097    0.017801    0.683131    
#> 318: 0.078483    1.047025    3.495899    0.067758    0.079936    0.017801    0.683037    
#> 319: 0.078499    1.047004    3.495912    0.067623    0.079876    0.017830    0.682903    
#> 320: 0.078117    1.046946    3.495886    0.067590    0.079834    0.017825    0.683023    
#> 321: 0.077603    1.047084    3.495719    0.067662    0.079885    0.017801    0.683105    
#> 322: 0.077455    1.046930    3.495641    0.067603    0.079796    0.017800    0.683108    
#> 323: 0.076923    1.046924    3.495515    0.067616    0.079725    0.017812    0.683251    
#> 324: 0.076747    1.046943    3.495473    0.067504    0.079689    0.017789    0.683236    
#> 325: 0.076552    1.047121    3.495434    0.067415    0.079678    0.017815    0.683192    
#> 326: 0.076394    1.047127    3.495317    0.067419    0.079691    0.017810    0.683059    
#> 327: 0.076331    1.047115    3.495324    0.067530    0.079801    0.017779    0.683005    
#> 328: 0.076387    1.047171    3.495330    0.067517    0.079843    0.017754    0.682976    
#> 329: 0.076593    1.047197    3.495350    0.067516    0.079802    0.017742    0.682933    
#> 330: 0.076416    1.047088    3.495373    0.067498    0.079735    0.017740    0.682880    
#> 331: 0.076438    1.047308    3.495403    0.067454    0.079794    0.017741    0.682787    
#> 332: 0.076515    1.047432    3.495439    0.067381    0.079777    0.017754    0.682827    
#> 333: 0.076525    1.047491    3.495394    0.067341    0.079858    0.017734    0.682789    
#> 334: 0.076672    1.047474    3.495340    0.067335    0.079853    0.017691    0.682696    
#> 335: 0.076561    1.047498    3.495262    0.067402    0.079808    0.017683    0.682685    
#> 336: 0.076522    1.047694    3.495174    0.067311    0.079834    0.017664    0.682887    
#> 337: 0.076367    1.047969    3.495048    0.067220    0.079792    0.017667    0.683118    
#> 338: 0.076244    1.047989    3.494993    0.067253    0.079813    0.017643    0.683208    
#> 339: 0.076044    1.048153    3.494900    0.067301    0.079844    0.017619    0.683126    
#> 340: 0.075905    1.048116    3.494894    0.067273    0.079995    0.017603    0.683052    
#> 341: 0.075888    1.048119    3.494885    0.067276    0.080112    0.017591    0.683044    
#> 342: 0.075789    1.047961    3.494859    0.067248    0.080110    0.017591    0.683010    
#> 343: 0.075695    1.047935    3.494914    0.067202    0.080179    0.017579    0.682951    
#> 344: 0.076019    1.047930    3.495046    0.067195    0.080131    0.017568    0.683036    
#> 345: 0.076278    1.047960    3.495081    0.067141    0.080203    0.017576    0.682996    
#> 346: 0.076210    1.048182    3.494929    0.067114    0.080316    0.017562    0.682866    
#> 347: 0.076242    1.048170    3.494836    0.067054    0.080397    0.017571    0.682888    
#> 348: 0.076168    1.048136    3.494814    0.067073    0.080514    0.017568    0.682791    
#> 349: 0.076149    1.048026    3.494744    0.067178    0.080514    0.017566    0.682741    
#> 350: 0.076062    1.047838    3.494709    0.067260    0.080522    0.017549    0.682743    
#> 351: 0.075855    1.047978    3.494582    0.067352    0.080477    0.017535    0.682752    
#> 352: 0.075664    1.048094    3.494547    0.067535    0.080485    0.017519    0.682899    
#> 353: 0.075570    1.048069    3.494449    0.067646    0.080443    0.017522    0.682865    
#> 354: 0.075487    1.048089    3.494282    0.067802    0.080426    0.017518    0.682925    
#> 355: 0.075588    1.047952    3.494226    0.067797    0.080462    0.017528    0.682924    
#> 356: 0.075623    1.047869    3.494262    0.067752    0.080527    0.017538    0.682985    
#> 357: 0.075832    1.047945    3.494291    0.067798    0.080585    0.017542    0.682929    
#> 358: 0.075885    1.047994    3.494301    0.067829    0.080564    0.017517    0.682804    
#> 359: 0.075825    1.048053    3.494250    0.067814    0.080565    0.017498    0.682820    
#> 360: 0.075565    1.047983    3.494084    0.067867    0.080561    0.017480    0.682751    
#> 361: 0.075256    1.047942    3.494003    0.067854    0.080605    0.017458    0.682701    
#> 362: 0.075038    1.047920    3.493852    0.067946    0.080588    0.017455    0.682523    
#> 363: 0.074858    1.047961    3.493713    0.067940    0.080538    0.017443    0.682499    
#> 364: 0.074908    1.048042    3.493643    0.068118    0.080559    0.017434    0.682518    
#> 365: 0.074865    1.047987    3.493645    0.068207    0.080423    0.017443    0.682631    
#> 366: 0.074882    1.047858    3.493579    0.068341    0.080409    0.017444    0.682648    
#> 367: 0.074676    1.047903    3.493497    0.068477    0.080469    0.017445    0.682561    
#> 368: 0.074626    1.047972    3.493445    0.068525    0.080427    0.017466    0.682476    
#> 369: 0.074598    1.047931    3.493397    0.068648    0.080461    0.017455    0.682446    
#> 370: 0.074289    1.048043    3.493297    0.068815    0.080483    0.017441    0.682442    
#> 371: 0.074005    1.048280    3.493086    0.068905    0.080643    0.017400    0.682377    
#> 372: 0.073939    1.048368    3.493023    0.069010    0.080695    0.017374    0.682286    
#> 373: 0.073871    1.048450    3.492945    0.068984    0.080713    0.017361    0.682244    
#> 374: 0.073858    1.048484    3.492891    0.068981    0.080700    0.017370    0.682112    
#> 375: 0.073711    1.048616    3.492854    0.068915    0.080745    0.017376    0.682092    
#> 376: 0.073537    1.048717    3.492817    0.068935    0.080781    0.017385    0.682010    
#> 377: 0.073428    1.048763    3.492781    0.068903    0.080764    0.017405    0.681976    
#> 378: 0.073199    1.048676    3.492691    0.068902    0.080704    0.017412    0.682129    
#> 379: 0.073016    1.048557    3.492711    0.068848    0.080728    0.017411    0.682183    
#> 380: 0.072825    1.048479    3.492759    0.068853    0.080599    0.017419    0.682221    
#> 381: 0.072720    1.048423    3.492752    0.068913    0.080546    0.017414    0.682222    
#> 382: 0.072710    1.048446    3.492734    0.068913    0.080567    0.017393    0.682133    
#> 383: 0.072829    1.048412    3.492758    0.068872    0.080498    0.017396    0.682088    
#> 384: 0.072864    1.048375    3.492813    0.068955    0.080476    0.017382    0.682097    
#> 385: 0.072954    1.048356    3.492840    0.068941    0.080512    0.017402    0.682129    
#> 386: 0.073096    1.048478    3.492881    0.068908    0.080459    0.017434    0.682198    
#> 387: 0.073243    1.048416    3.493031    0.068926    0.080415    0.017456    0.682147    
#> 388: 0.073269    1.048478    3.493035    0.068970    0.080376    0.017467    0.682062    
#> 389: 0.073294    1.048351    3.493070    0.068987    0.080310    0.017494    0.682191    
#> 390: 0.073302    1.048395    3.493075    0.069025    0.080268    0.017519    0.682215    
#> 391: 0.073262    1.048414    3.493079    0.069114    0.080263    0.017514    0.682165    
#> 392: 0.073237    1.048449    3.493109    0.069146    0.080217    0.017503    0.682212    
#> 393: 0.073218    1.048325    3.493083    0.069152    0.080233    0.017480    0.682162    
#> 394: 0.073273    1.048324    3.493075    0.069206    0.080223    0.017473    0.682085    
#> 395: 0.073484    1.048294    3.493104    0.069259    0.080168    0.017474    0.682115    
#> 396: 0.073705    1.048276    3.493162    0.069248    0.080082    0.017482    0.682071    
#> 397: 0.073879    1.048143    3.493285    0.069246    0.080045    0.017496    0.682092    
#> 398: 0.074155    1.047962    3.493463    0.069261    0.080011    0.017512    0.682223    
#> 399: 0.074435    1.047909    3.493602    0.069293    0.079974    0.017528    0.682147    
#> 400: 0.074693    1.047922    3.493735    0.069344    0.079914    0.017533    0.682147    
#> 401: 0.074761    1.047955    3.493767    0.069405    0.079840    0.017537    0.682168    
#> 402: 0.074771    1.047971    3.493815    0.069459    0.079713    0.017551    0.682210    
#> 403: 0.074907    1.047938    3.493834    0.069603    0.079708    0.017558    0.682089    
#> 404: 0.074888    1.047956    3.493780    0.069733    0.079600    0.017554    0.682003    
#> 405: 0.074603    1.048002    3.493744    0.069845    0.079535    0.017545    0.682022    
#> 406: 0.074578    1.048075    3.493731    0.069879    0.079589    0.017531    0.682124    
#> 407: 0.074501    1.048163    3.493710    0.069877    0.079640    0.017522    0.682120    
#> 408: 0.074411    1.048249    3.493706    0.070025    0.079662    0.017508    0.682114    
#> 409: 0.074293    1.048242    3.493661    0.070058    0.079647    0.017503    0.682004    
#> 410: 0.074168    1.048283    3.493561    0.070137    0.079650    0.017475    0.682021    
#> 411: 0.074123    1.048140    3.493554    0.070210    0.079616    0.017463    0.682104    
#> 412: 0.074079    1.048149    3.493545    0.070241    0.079615    0.017456    0.682127    
#> 413: 0.074092    1.048116    3.493524    0.070217    0.079602    0.017451    0.682157    
#> 414: 0.074041    1.048108    3.493526    0.070287    0.079598    0.017429    0.682137    
#> 415: 0.074164    1.048013    3.493566    0.070217    0.079550    0.017424    0.682125    
#> 416: 0.074244    1.048028    3.493619    0.070143    0.079567    0.017429    0.682115    
#> 417: 0.074283    1.047985    3.493662    0.070071    0.079596    0.017422    0.682127    
#> 418: 0.074245    1.048050    3.493710    0.070097    0.079589    0.017426    0.682126    
#> 419: 0.074286    1.048156    3.493702    0.070117    0.079673    0.017430    0.682090    
#> 420: 0.074421    1.048182    3.493692    0.070110    0.079698    0.017430    0.682037    
#> 421: 0.074435    1.048222    3.493695    0.070093    0.079709    0.017426    0.681971    
#> 422: 0.074586    1.048157    3.493676    0.070079    0.079727    0.017409    0.681978    
#> 423: 0.074611    1.048127    3.493694    0.070101    0.079683    0.017406    0.681960    
#> 424: 0.074582    1.048168    3.493624    0.070099    0.079684    0.017400    0.681904    
#> 425: 0.074628    1.048319    3.493574    0.070153    0.079643    0.017409    0.681964    
#> 426: 0.074600    1.048570    3.493479    0.070149    0.079700    0.017405    0.681925    
#> 427: 0.074457    1.048612    3.493476    0.070154    0.079703    0.017393    0.681869    
#> 428: 0.074250    1.048708    3.493410    0.070204    0.079674    0.017395    0.681895    
#> 429: 0.074184    1.048798    3.493392    0.070221    0.079712    0.017399    0.681890    
#> 430: 0.074075    1.048905    3.493352    0.070233    0.079690    0.017413    0.681929    
#> 431: 0.073946    1.048925    3.493309    0.070235    0.079651    0.017405    0.681964    
#> 432: 0.073899    1.049037    3.493295    0.070251    0.079639    0.017404    0.681963    
#> 433: 0.073749    1.049215    3.493273    0.070308    0.079657    0.017392    0.681981    
#> 434: 0.073575    1.049147    3.493269    0.070282    0.079657    0.017379    0.681970    
#> 435: 0.073480    1.049205    3.493203    0.070271    0.079653    0.017385    0.681966    
#> 436: 0.073325    1.049232    3.493185    0.070259    0.079698    0.017377    0.681981    
#> 437: 0.073168    1.049223    3.493105    0.070240    0.079704    0.017361    0.682027    
#> 438: 0.073091    1.049356    3.493059    0.070255    0.079774    0.017344    0.682035    
#> 439: 0.072951    1.049566    3.492969    0.070306    0.079808    0.017334    0.682030    
#> 440: 0.072828    1.049617    3.492963    0.070276    0.079777    0.017341    0.681997    
#> 441: 0.072801    1.049544    3.493002    0.070272    0.079760    0.017352    0.681974    
#> 442: 0.072700    1.049556    3.493012    0.070278    0.079782    0.017355    0.681967    
#> 443: 0.072559    1.049610    3.492964    0.070378    0.079812    0.017344    0.681934    
#> 444: 0.072585    1.049563    3.492929    0.070447    0.079783    0.017352    0.681987    
#> 445: 0.072446    1.049609    3.492812    0.070509    0.079839    0.017340    0.682047    
#> 446: 0.072432    1.049657    3.492755    0.070516    0.079845    0.017322    0.681974    
#> 447: 0.072508    1.049705    3.492766    0.070521    0.079821    0.017313    0.682022    
#> 448: 0.072501    1.049718    3.492809    0.070553    0.079769    0.017334    0.681987    
#> 449: 0.072466    1.049781    3.492871    0.070544    0.079719    0.017362    0.681981    
#> 450: 0.072445    1.049756    3.492864    0.070565    0.079664    0.017398    0.681960    
#> 451: 0.072443    1.049749    3.492841    0.070614    0.079595    0.017421    0.681999    
#> 452: 0.072428    1.049807    3.492827    0.070667    0.079527    0.017444    0.681975    
#> 453: 0.072366    1.049785    3.492800    0.070739    0.079458    0.017467    0.681914    
#> 454: 0.072337    1.049895    3.492744    0.070747    0.079434    0.017461    0.681878    
#> 455: 0.072389    1.049914    3.492731    0.070787    0.079412    0.017455    0.681865    
#> 456: 0.072372    1.049853    3.492720    0.070810    0.079374    0.017460    0.681874    
#> 457: 0.072302    1.049829    3.492728    0.070834    0.079355    0.017483    0.681815    
#> 458: 0.072231    1.049902    3.492720    0.070869    0.079329    0.017507    0.681781    
#> 459: 0.072186    1.049969    3.492695    0.070894    0.079275    0.017517    0.681735    
#> 460: 0.072135    1.050032    3.492623    0.070873    0.079256    0.017518    0.681719    
#> 461: 0.072015    1.049989    3.492634    0.070918    0.079237    0.017514    0.681765    
#> 462: 0.071939    1.049962    3.492635    0.070985    0.079221    0.017506    0.681712    
#> 463: 0.071999    1.050034    3.492634    0.071067    0.079233    0.017510    0.681683    
#> 464: 0.072004    1.050123    3.492581    0.071173    0.079214    0.017507    0.681613    
#> 465: 0.071913    1.050022    3.492552    0.071259    0.079171    0.017496    0.681624    
#> 466: 0.071986    1.050040    3.492547    0.071239    0.079120    0.017502    0.681571    
#> 467: 0.071984    1.049968    3.492584    0.071189    0.079058    0.017509    0.681531    
#> 468: 0.072156    1.049892    3.492646    0.071188    0.079037    0.017520    0.681564    
#> 469: 0.072203    1.049952    3.492692    0.071170    0.079016    0.017539    0.681659    
#> 470: 0.072076    1.050009    3.492662    0.071214    0.079016    0.017553    0.681678    
#> 471: 0.071890    1.049951    3.492636    0.071197    0.078979    0.017559    0.681661    
#> 472: 0.071798    1.049954    3.492600    0.071127    0.078994    0.017563    0.681704    
#> 473: 0.071636    1.049901    3.492567    0.071118    0.079001    0.017541    0.681749    
#> 474: 0.071573    1.049859    3.492560    0.071146    0.079034    0.017521    0.681754    
#> 475: 0.071491    1.049983    3.492500    0.071161    0.079039    0.017508    0.681758    
#> 476: 0.071473    1.049976    3.492462    0.071210    0.079075    0.017497    0.681802    
#> 477: 0.071409    1.050094    3.492434    0.071171    0.079123    0.017493    0.681750    
#> 478: 0.071329    1.050103    3.492419    0.071165    0.079105    0.017493    0.681784    
#> 479: 0.071399    1.050131    3.492436    0.071155    0.079075    0.017499    0.681783    
#> 480: 0.071452    1.050184    3.492445    0.071143    0.079156    0.017494    0.681852    
#> 481: 0.071389    1.050218    3.492393    0.071135    0.079206    0.017482    0.681843    
#> 482: 0.071319    1.050253    3.492325    0.071130    0.079184    0.017483    0.681806    
#> 483: 0.071157    1.050321    3.492209    0.071164    0.079200    0.017485    0.681793    
#> 484: 0.071035    1.050280    3.492145    0.071164    0.079162    0.017486    0.681819    
#> 485: 0.070989    1.050269    3.492160    0.071197    0.079155    0.017496    0.681886    
#> 486: 0.071128    1.050221    3.492225    0.071159    0.079133    0.017488    0.681896    
#> 487: 0.071339    1.050237    3.492293    0.071133    0.079170    0.017490    0.681857    
#> 488: 0.071329    1.050203    3.492307    0.071113    0.079140    0.017493    0.681841    
#> 489: 0.071415    1.050134    3.492310    0.071078    0.079068    0.017494    0.681928    
#> 490: 0.071547    1.050112    3.492351    0.071065    0.079099    0.017492    0.681939    
#> 491: 0.071648    1.050183    3.492414    0.071035    0.079089    0.017497    0.681898    
#> 492: 0.071639    1.050246    3.492393    0.071069    0.079058    0.017502    0.681869    
#> 493: 0.071616    1.050254    3.492406    0.071101    0.079018    0.017516    0.681856    
#> 494: 0.071679    1.050300    3.492377    0.071152    0.078955    0.017529    0.681858    
#> 495: 0.071709    1.050292    3.492364    0.071195    0.078938    0.017526    0.681861    
#> 496: 0.071742    1.050276    3.492344    0.071309    0.078930    0.017528    0.681833    
#> 497: 0.071685    1.050210    3.492303    0.071380    0.078894    0.017532    0.681823    
#> 498: 0.071596    1.050256    3.492243    0.071450    0.078938    0.017527    0.681748    
#> 499: 0.071554    1.050328    3.492200    0.071437    0.078962    0.017521    0.681728    
#> 500: 0.071569    1.050307    3.492179    0.071462    0.078961    0.017516    0.681677    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.255173    0.971558    3.448611    0.392401    0.075815    0.016800    1.762955    
#> 002: 0.330774    1.081619    3.477982    0.372781    0.072024    0.015960    1.181020    
#> 003: 0.521403    1.071197    3.514628    0.375457    0.068423    0.015162    0.840235    
#> 004: 0.556560    1.081164    3.525308    0.398938    0.065002    0.014404    0.730860    
#> 005: 0.636880    1.105034    3.524576    0.585517    0.073534    0.013684    0.660569    
#> 006: 0.643757    1.100339    3.528464    0.590438    0.085370    0.017545    0.547721    
#> 007: 0.622276    1.119294    3.519850    0.591797    0.097059    0.020149    0.522955    
#> 008: 0.613796    1.137067    3.524624    0.586016    0.092206    0.023160    0.517003    
#> 009: 0.596833    1.111853    3.518047    0.584560    0.087596    0.023842    0.521920    
#> 010: 0.623593    1.108421    3.527721    0.762875    0.083216    0.027247    0.513164    
#> 011: 0.661046    1.108911    3.527801    0.791674    0.079055    0.027969    0.509982    
#> 012: 0.664764    1.105784    3.530799    0.752090    0.075102    0.026570    0.509147    
#> 013: 0.654024    1.116302    3.520824    0.750966    0.071347    0.031440    0.507953    
#> 014: 0.676594    1.104374    3.526648    0.817892    0.074725    0.029868    0.512269    
#> 015: 0.686087    1.110295    3.529303    0.788894    0.074211    0.028375    0.504818    
#> 016: 0.672285    1.113680    3.539284    0.776625    0.076187    0.026956    0.508696    
#> 017: 0.683238    1.126616    3.537419    0.810302    0.079192    0.025608    0.495978    
#> 018: 0.663299    1.121784    3.520703    0.769787    0.076627    0.024328    0.501060    
#> 019: 0.657439    1.119458    3.525326    0.768472    0.072903    0.023112    0.495009    
#> 020: 0.671241    1.119069    3.527311    0.744620    0.069258    0.027081    0.510573    
#> 021: 0.657123    1.113656    3.529467    0.707389    0.065795    0.025727    0.500885    
#> 022: 0.691937    1.124171    3.534593    0.755753    0.062506    0.028528    0.499925    
#> 023: 0.750100    1.121846    3.543034    0.825098    0.061926    0.028691    0.497374    
#> 024: 0.708101    1.134235    3.539490    0.783843    0.065449    0.027366    0.498378    
#> 025: 0.685323    1.107197    3.537397    0.744651    0.072130    0.025998    0.502601    
#> 026: 0.677091    1.119733    3.534245    0.707418    0.072019    0.026919    0.511185    
#> 027: 0.701024    1.124036    3.531101    0.776481    0.079389    0.025817    0.511487    
#> 028: 0.652638    1.128245    3.526563    0.737657    0.083957    0.024526    0.503880    
#> 029: 0.643442    1.129510    3.528969    0.700774    0.079759    0.023940    0.515402    
#> 030: 0.637532    1.134578    3.511483    0.755106    0.076497    0.024342    0.517599    
#> 031: 0.599199    1.117198    3.524021    0.717350    0.076096    0.024916    0.525702    
#> 032: 0.612292    1.109909    3.523478    0.698773    0.073585    0.023670    0.518396    
#> 033: 0.636080    1.106514    3.525990    0.710970    0.076437    0.022855    0.509021    
#> 034: 0.664774    1.116772    3.530523    0.735814    0.074293    0.023864    0.510796    
#> 035: 0.658562    1.110358    3.532952    0.699024    0.076544    0.022671    0.495487    
#> 036: 0.646391    1.126482    3.531261    0.664072    0.087253    0.021537    0.506219    
#> 037: 0.626711    1.129069    3.521899    0.633740    0.082890    0.020460    0.518883    
#> 038: 0.701093    1.128586    3.530061    0.803521    0.078745    0.022665    0.516251    
#> 039: 0.675260    1.117222    3.524280    0.782730    0.074808    0.022544    0.508788    
#> 040: 0.662442    1.110791    3.541524    0.743594    0.072054    0.024057    0.517260    
#> 041: 0.650414    1.098616    3.536147    0.706414    0.073102    0.024255    0.512769    
#> 042: 0.703776    1.092269    3.542200    0.674010    0.074653    0.024620    0.514006    
#> 043: 0.682248    1.111085    3.526324    0.660594    0.074217    0.023753    0.517824    
#> 044: 0.670677    1.105456    3.534113    0.634542    0.072947    0.023104    0.510902    
#> 045: 0.639308    1.124911    3.526912    0.603656    0.074022    0.022952    0.502180    
#> 046: 0.625978    1.099438    3.539705    0.573474    0.070321    0.022658    0.511347    
#> 047: 0.668781    1.101592    3.536114    0.595918    0.069842    0.025395    0.506120    
#> 048: 0.687919    1.101464    3.544843    0.666763    0.078103    0.028673    0.512223    
#> 049: 0.669976    1.098419    3.543747    0.633424    0.074333    0.027239    0.513439    
#> 050: 0.715952    1.089463    3.545359    0.752488    0.075536    0.026024    0.525060    
#> 051: 0.745070    1.101626    3.543364    0.840940    0.071759    0.025529    0.516101    
#> 052: 0.779230    1.106537    3.557616    0.897683    0.075950    0.024253    0.498762    
#> 053: 0.756045    1.104543    3.553449    0.922374    0.083885    0.023040    0.505742    
#> 054: 0.675417    1.098258    3.538222    0.876255    0.098120    0.021888    0.512766    
#> 055: 0.661929    1.121659    3.532506    0.832442    0.093214    0.020794    0.520901    
#> 056: 0.696970    1.108399    3.533647    0.790820    0.094855    0.019754    0.526924    
#> 057: 0.697171    1.104635    3.536602    0.807170    0.090112    0.023609    0.513722    
#> 058: 0.665870    1.104140    3.518018    0.766811    0.085606    0.022428    0.519467    
#> 059: 0.689414    1.083876    3.527786    0.804917    0.081326    0.022540    0.534263    
#> 060: 0.680045    1.106363    3.541484    0.764672    0.079322    0.025905    0.520547    
#> 061: 0.695596    1.112008    3.548751    0.726438    0.075356    0.031698    0.519838    
#> 062: 0.685533    1.111097    3.537900    0.690116    0.075616    0.030164    0.527375    
#> 063: 0.691814    1.101552    3.527875    0.701881    0.071835    0.030193    0.532542    
#> 064: 0.631461    1.108210    3.530914    0.666787    0.068283    0.028684    0.536600    
#> 065: 0.670423    1.101975    3.517054    0.680608    0.071300    0.027250    0.528615    
#> 066: 0.641046    1.114598    3.531023    0.646577    0.075899    0.028364    0.520821    
#> 067: 0.634262    1.103218    3.526074    0.635117    0.072104    0.030105    0.512873    
#> 068: 0.610591    1.113025    3.519243    0.676885    0.071013    0.028600    0.523048    
#> 069: 0.617496    1.117570    3.507236    0.724265    0.072408    0.027170    0.534651    
#> 070: 0.635085    1.131653    3.523166    0.724051    0.078334    0.025811    0.513643    
#> 071: 0.668639    1.129075    3.516726    0.789355    0.083166    0.024521    0.533888    
#> 072: 0.672978    1.115371    3.516811    0.815447    0.079410    0.023295    0.525709    
#> 073: 0.706552    1.139386    3.524773    0.920511    0.078943    0.022130    0.521830    
#> 074: 0.692713    1.107477    3.528023    0.874485    0.074996    0.025643    0.506440    
#> 075: 0.661310    1.107024    3.534306    0.830761    0.075821    0.027605    0.503022    
#> 076: 0.651894    1.123324    3.528013    0.789223    0.076570    0.030445    0.501517    
#> 077: 0.693418    1.105252    3.539954    0.847267    0.072742    0.030354    0.503849    
#> 078: 0.680124    1.117212    3.537052    0.804904    0.069105    0.030105    0.494334    
#> 079: 0.665227    1.121700    3.526616    0.764659    0.065650    0.028599    0.501052    
#> 080: 0.671867    1.115116    3.521332    0.866391    0.074038    0.027629    0.510963    
#> 081: 0.683980    1.132893    3.523409    0.869334    0.070936    0.026926    0.510549    
#> 082: 0.652824    1.132050    3.527722    0.825868    0.068666    0.031177    0.518381    
#> 083: 0.682894    1.143870    3.529938    0.792040    0.065232    0.034894    0.518879    
#> 084: 0.682551    1.123468    3.528951    0.767591    0.066038    0.033150    0.522789    
#> 085: 0.680897    1.112119    3.543426    0.782063    0.067193    0.032210    0.518002    
#> 086: 0.663849    1.099812    3.544141    0.742960    0.063833    0.032429    0.516621    
#> 087: 0.707223    1.096827    3.541549    0.847561    0.060642    0.030922    0.505281    
#> 088: 0.672302    1.099424    3.544147    0.805183    0.062091    0.029376    0.512506    
#> 089: 0.667721    1.106245    3.532064    0.764924    0.074026    0.028820    0.514420    
#> 090: 0.679782    1.098776    3.541639    0.730510    0.072918    0.027379    0.524206    
#> 091: 0.685627    1.093871    3.522586    0.849022    0.073087    0.026010    0.512826    
#> 092: 0.659433    1.123905    3.519448    0.817211    0.070628    0.024710    0.505240    
#> 093: 0.628236    1.106268    3.524551    0.776351    0.067096    0.023925    0.526572    
#> 094: 0.655398    1.116856    3.518815    0.737533    0.063742    0.026486    0.521513    
#> 095: 0.647956    1.124128    3.526437    0.700657    0.069725    0.025161    0.519917    
#> 096: 0.635981    1.116986    3.525072    0.699609    0.076236    0.025405    0.512448    
#> 097: 0.668598    1.117486    3.531492    0.715839    0.072424    0.025356    0.521907    
#> 098: 0.657467    1.120272    3.532300    0.680047    0.072852    0.024089    0.504190    
#> 099: 0.682151    1.103229    3.531422    0.746136    0.072813    0.022884    0.496568    
#> 100: 0.669868    1.113288    3.524156    0.708829    0.069172    0.024883    0.494277    
#> 101: 0.645385    1.110441    3.522012    0.673388    0.065713    0.025056    0.499416    
#> 102: 0.640876    1.113345    3.520816    0.639718    0.070110    0.023803    0.512191    
#> 103: 0.659958    1.113967    3.536345    0.737072    0.066605    0.022805    0.515798    
#> 104: 0.676129    1.122164    3.532989    0.764605    0.072942    0.023032    0.519570    
#> 105: 0.683298    1.114187    3.535493    0.729317    0.078266    0.025758    0.523045    
#> 106: 0.681876    1.104503    3.533914    0.762161    0.074353    0.026680    0.512585    
#> 107: 0.682404    1.128855    3.524115    0.815406    0.072568    0.025346    0.519383    
#> 108: 0.671401    1.124151    3.533813    0.827966    0.081015    0.024079    0.523865    
#> 109: 0.674332    1.119536    3.532092    0.786568    0.077389    0.022875    0.534743    
#> 110: 0.658650    1.104248    3.525069    0.747240    0.085996    0.021731    0.524527    
#> 111: 0.676019    1.105898    3.535780    0.709878    0.081696    0.020644    0.517696    
#> 112: 0.679687    1.099811    3.520830    0.680898    0.080014    0.019612    0.519819    
#> 113: 0.646711    1.125382    3.534570    0.659945    0.076327    0.020736    0.510582    
#> 114: 0.655452    1.113021    3.528128    0.651110    0.072510    0.020308    0.505910    
#> 115: 0.651625    1.084215    3.532073    0.652580    0.068885    0.023708    0.518996    
#> 116: 0.720501    1.091444    3.533618    0.756743    0.070701    0.025361    0.515182    
#> 117: 0.671852    1.111971    3.548180    0.718906    0.069580    0.028625    0.514544    
#> 118: 0.731532    1.103029    3.548098    0.902837    0.066101    0.031076    0.504798    
#> 119: 0.750408    1.104623    3.532600    1.008324    0.062796    0.031359    0.512343    
#> 120: 0.699406    1.107078    3.533993    0.957908    0.059656    0.032975    0.517110    
#> 121: 0.698635    1.130991    3.534816    0.910012    0.068015    0.031327    0.520237    
#> 122: 0.703824    1.110906    3.544310    0.864512    0.079081    0.029760    0.511565    
#> 123: 0.743227    1.122055    3.538838    0.865089    0.088836    0.028272    0.505623    
#> 124: 0.695661    1.128881    3.534095    0.839613    0.084395    0.026859    0.506845    
#> 125: 0.666744    1.135715    3.532036    0.797632    0.080175    0.027220    0.499007    
#> 126: 0.665290    1.135628    3.531590    0.757751    0.076166    0.027265    0.497583    
#> 127: 0.683736    1.104146    3.532383    0.719863    0.072358    0.025902    0.503720    
#> 128: 0.670259    1.104399    3.538788    0.683870    0.068740    0.027398    0.517307    
#> 129: 0.685496    1.108680    3.544735    0.676152    0.067995    0.028059    0.516153    
#> 130: 0.720746    1.120889    3.535249    0.692194    0.067362    0.028731    0.517632    
#> 131: 0.674356    1.103117    3.532462    0.692454    0.071390    0.028342    0.522430    
#> 132: 0.637289    1.115892    3.523811    0.657832    0.067821    0.026924    0.521256    
#> 133: 0.617051    1.107091    3.529096    0.631394    0.079778    0.026074    0.513409    
#> 134: 0.656075    1.081899    3.543316    0.710689    0.080175    0.024770    0.509924    
#> 135: 0.688631    1.099511    3.547235    0.679567    0.076166    0.024920    0.511330    
#> 136: 0.663831    1.099717    3.547279    0.692496    0.075572    0.023674    0.503100    
#> 137: 0.711664    1.094891    3.552717    0.704666    0.071793    0.025572    0.522457    
#> 138: 0.717591    1.104242    3.551627    0.753636    0.068204    0.029353    0.511377    
#> 139: 0.646497    1.089807    3.549149    0.715954    0.064794    0.031949    0.517230    
#> 140: 0.658426    1.116288    3.538666    0.740133    0.065795    0.030596    0.518104    
#> 141: 0.651748    1.100159    3.526571    0.845270    0.068526    0.029066    0.533900    
#> 142: 0.715189    1.086299    3.545788    0.848241    0.070205    0.027613    0.541904    
#> 143: 0.690993    1.107780    3.536203    0.874584    0.071280    0.026408    0.529871    
#> 144: 0.753012    1.110826    3.541197    0.874486    0.070009    0.025457    0.508461    
#> 145: 0.742575    1.118451    3.540190    0.869584    0.066509    0.024662    0.518848    
#> 146: 0.788431    1.118496    3.549648    0.960027    0.070494    0.024224    0.516324    
#> 147: 0.714093    1.101498    3.535011    0.912025    0.066969    0.026713    0.502547    
#> 148: 0.688872    1.104512    3.540746    0.866424    0.070029    0.025378    0.507818    
#> 149: 0.710378    1.093019    3.528929    0.893064    0.078386    0.024109    0.500279    
#> 150: 0.769123    1.105596    3.524023    1.145420    0.075994    0.022903    0.515607    
#> 151: 0.729848    1.128783    3.513998    1.200814    0.086568    0.021758    0.510638    
#> 152: 0.727271    1.115219    3.528326    1.153879    0.073818    0.021981    0.495555    
#> 153: 0.758330    1.126010    3.535460    1.247280    0.088022    0.019450    0.510052    
#> 154: 0.749634    1.120455    3.538115    1.116779    0.083176    0.020529    0.513715    
#> 155: 0.702112    1.106571    3.527668    0.900375    0.082229    0.017537    0.523819    
#> 156: 0.728118    1.116248    3.537415    0.852702    0.087369    0.020380    0.520680    
#> 157: 0.702223    1.098926    3.543441    0.815945    0.086475    0.020706    0.532285    
#> 158: 0.696126    1.115623    3.539846    0.730715    0.092164    0.019930    0.537097    
#> 159: 0.682545    1.112495    3.543998    0.668171    0.089660    0.017454    0.537522    
#> 160: 0.715442    1.090033    3.542944    0.703191    0.090799    0.018709    0.527193    
#> 161: 0.708257    1.097302    3.548361    0.662300    0.086493    0.017204    0.526730    
#> 162: 0.667145    1.099242    3.537170    0.625930    0.084848    0.017972    0.538635    
#> 163: 0.679026    1.096822    3.535310    0.697476    0.098157    0.015928    0.522767    
#> 164: 0.676219    1.117700    3.536336    0.637769    0.097054    0.013923    0.502343    
#> 165: 0.639861    1.103683    3.535924    0.622446    0.095067    0.017387    0.505127    
#> 166: 0.681397    1.117209    3.527308    0.658539    0.101501    0.014701    0.520975    
#> 167: 0.705459    1.124689    3.532296    0.699324    0.098845    0.013021    0.540176    
#> 168: 0.687384    1.112443    3.541705    0.776929    0.103050    0.013782    0.532958    
#> 169: 0.692125    1.130900    3.534801    0.764592    0.107534    0.013515    0.541282    
#> 170: 0.689165    1.116213    3.537148    0.732060    0.108771    0.013804    0.523629    
#> 171: 0.681918    1.112714    3.534352    0.788344    0.104064    0.012562    0.511929    
#> 172: 0.676357    1.116364    3.531298    0.882776    0.099235    0.014133    0.524354    
#> 173: 0.689251    1.123865    3.526669    0.818243    0.091506    0.013456    0.515456    
#> 174: 0.681593    1.112678    3.529715    0.664347    0.093823    0.016889    0.511085    
#> 175: 0.627742    1.112559    3.517725    0.693826    0.090364    0.016956    0.528035    
#> 176: 0.600022    1.141340    3.527289    0.570819    0.085039    0.018629    0.512874    
#> 177: 0.660559    1.120182    3.533982    0.647778    0.093561    0.019981    0.516561    
#> 178: 0.647897    1.105574    3.536310    0.557373    0.068700    0.019752    0.515941    
#> 179: 0.672040    1.139177    3.530037    0.582617    0.078277    0.020432    0.527188    
#> 180: 0.658385    1.107841    3.537677    0.638643    0.072950    0.022681    0.519766    
#> 181: 0.693368    1.100243    3.526602    0.668482    0.072977    0.023803    0.520524    
#> 182: 0.670554    1.103510    3.527424    0.642274    0.073041    0.024948    0.512221    
#> 183: 0.652995    1.113836    3.529531    0.589671    0.065537    0.025120    0.517337    
#> 184: 0.656460    1.107717    3.533966    0.666439    0.070340    0.023560    0.521793    
#> 185: 0.653935    1.115293    3.533418    0.657745    0.072197    0.021155    0.514687    
#> 186: 0.655697    1.128002    3.532689    0.597254    0.065116    0.024384    0.538592    
#> 187: 0.679885    1.120625    3.533163    0.724990    0.070318    0.026381    0.529037    
#> 188: 0.681314    1.108641    3.534173    0.771400    0.068584    0.025679    0.528929    
#> 189: 0.649475    1.119429    3.535672    0.652047    0.063081    0.026049    0.516925    
#> 190: 0.626915    1.123120    3.540233    0.578094    0.064342    0.026553    0.506922    
#> 191: 0.668498    1.121384    3.537172    0.623424    0.060566    0.027933    0.522513    
#> 192: 0.683468    1.130658    3.539542    0.670139    0.062106    0.026385    0.517178    
#> 193: 0.676110    1.119705    3.540097    0.765693    0.061490    0.025376    0.510107    
#> 194: 0.672885    1.107917    3.532754    0.686742    0.077027    0.027239    0.516081    
#> 195: 0.627566    1.109663    3.523217    0.648859    0.081456    0.024151    0.516181    
#> 196: 0.669980    1.111407    3.536063    0.728774    0.078191    0.026657    0.522860    
#> 197: 0.626212    1.102382    3.535659    0.687916    0.076971    0.024975    0.533814    
#> 198: 0.724026    1.088573    3.552435    0.766452    0.078685    0.026816    0.521690    
#> 199: 0.684933    1.085971    3.544166    0.733002    0.081377    0.026345    0.532669    
#> 200: 0.674694    1.096049    3.535941    0.768994    0.079265    0.024223    0.529462    
#> 201: 0.679775    1.095090    3.542913    0.794075    0.077877    0.025614    0.525116    
#> 202: 0.688328    1.094479    3.544158    0.795421    0.079452    0.026072    0.521544    
#> 203: 0.707535    1.095031    3.543440    0.820835    0.078279    0.025112    0.523788    
#> 204: 0.709029    1.090498    3.546098    0.815316    0.077306    0.025059    0.524224    
#> 205: 0.712057    1.096829    3.546796    0.803848    0.077739    0.024210    0.524375    
#> 206: 0.717190    1.101732    3.547512    0.832672    0.078615    0.023856    0.524643    
#> 207: 0.714968    1.101734    3.546680    0.815542    0.079915    0.022862    0.524149    
#> 208: 0.711993    1.102650    3.546849    0.800015    0.080539    0.022201    0.523117    
#> 209: 0.715668    1.101460    3.546135    0.812948    0.080225    0.021853    0.521673    
#> 210: 0.717636    1.100092    3.545647    0.813992    0.080251    0.021719    0.520280    
#> 211: 0.720561    1.099452    3.545792    0.821302    0.079373    0.021779    0.519799    
#> 212: 0.717358    1.099006    3.545951    0.814265    0.079028    0.021967    0.519176    
#> 213: 0.717867    1.097653    3.546618    0.811472    0.079239    0.022238    0.520234    
#> 214: 0.718858    1.097411    3.546382    0.813348    0.079488    0.022455    0.520464    
#> 215: 0.719108    1.097924    3.546523    0.804994    0.079507    0.022411    0.520725    
#> 216: 0.722641    1.097091    3.546665    0.808443    0.080065    0.022553    0.521412    
#> 217: 0.723944    1.097825    3.546711    0.808394    0.080669    0.022481    0.521273    
#> 218: 0.724974    1.098049    3.546076    0.813151    0.080733    0.022478    0.521084    
#> 219: 0.722521    1.098279    3.545222    0.813527    0.080707    0.022336    0.520320    
#> 220: 0.719244    1.098441    3.544517    0.810728    0.080564    0.022031    0.520401    
#> 221: 0.715040    1.099301    3.543896    0.804952    0.080539    0.021770    0.520330    
#> 222: 0.713707    1.099542    3.542956    0.803054    0.080844    0.021558    0.520193    
#> 223: 0.714039    1.098969    3.542307    0.804114    0.080908    0.021297    0.520072    
#> 224: 0.715360    1.099317    3.542287    0.807972    0.080618    0.021130    0.520057    
#> 225: 0.716309    1.098469    3.542221    0.808157    0.081083    0.021064    0.519883    
#> 226: 0.716714    1.098512    3.541680    0.808859    0.081179    0.020950    0.519677    
#> 227: 0.717655    1.098450    3.541754    0.811812    0.080823    0.020961    0.519232    
#> 228: 0.716129    1.098730    3.541488    0.806941    0.081009    0.020868    0.518861    
#> 229: 0.714896    1.098816    3.541424    0.803850    0.080862    0.020829    0.518399    
#> 230: 0.714476    1.098441    3.541547    0.800547    0.080751    0.020803    0.517865    
#> 231: 0.714351    1.098308    3.541673    0.798739    0.080891    0.020779    0.517474    
#> 232: 0.713945    1.098484    3.541623    0.798384    0.080732    0.020780    0.517335    
#> 233: 0.713184    1.098134    3.541438    0.798677    0.080515    0.020827    0.517888    
#> 234: 0.711873    1.097945    3.541163    0.797909    0.080285    0.020904    0.517789    
#> 235: 0.711948    1.097764    3.541094    0.799453    0.080077    0.020968    0.517634    
#> 236: 0.712795    1.098240    3.540801    0.805782    0.080177    0.021027    0.517465    
#> 237: 0.713115    1.098338    3.540621    0.808093    0.080480    0.021090    0.517736    
#> 238: 0.713797    1.098165    3.540772    0.807675    0.080620    0.021118    0.518185    
#> 239: 0.714571    1.098545    3.540756    0.809152    0.080856    0.021061    0.518317    
#> 240: 0.715309    1.098461    3.540945    0.808638    0.080879    0.021095    0.518394    
#> 241: 0.716671    1.097385    3.541368    0.809523    0.080687    0.021134    0.518496    
#> 242: 0.716695    1.096888    3.541381    0.810010    0.080500    0.021210    0.518645    
#> 243: 0.715553    1.097029    3.541214    0.807710    0.080291    0.021215    0.518810    
#> 244: 0.714460    1.097080    3.541265    0.805430    0.079974    0.021253    0.518731    
#> 245: 0.713485    1.096661    3.541310    0.802066    0.079614    0.021309    0.518747    
#> 246: 0.712328    1.096544    3.541318    0.799052    0.079313    0.021443    0.518740    
#> 247: 0.711968    1.096228    3.541309    0.798576    0.079329    0.021500    0.518616    
#> 248: 0.712102    1.096560    3.541145    0.801148    0.079618    0.021519    0.518432    
#> 249: 0.711869    1.096849    3.541134    0.802525    0.079761    0.021556    0.518430    
#> 250: 0.712271    1.096997    3.541288    0.803743    0.079840    0.021602    0.518106    
#> 251: 0.712175    1.097468    3.541502    0.803172    0.079788    0.021653    0.518121    
#> 252: 0.712745    1.097884    3.541814    0.802480    0.079853    0.021735    0.517954    
#> 253: 0.711956    1.098275    3.541914    0.799679    0.079922    0.021780    0.518088    
#> 254: 0.711667    1.098535    3.541941    0.798748    0.080016    0.021739    0.518258    
#> 255: 0.711694    1.098852    3.541914    0.798227    0.080119    0.021730    0.518223    
#> 256: 0.711117    1.098984    3.541807    0.797306    0.080070    0.021744    0.518249    
#> 257: 0.710697    1.098728    3.541792    0.796340    0.080027    0.021791    0.518290    
#> 258: 0.710875    1.098534    3.541792    0.797260    0.079845    0.021838    0.518282    
#> 259: 0.710969    1.098541    3.541804    0.797036    0.079755    0.021866    0.518403    
#> 260: 0.710489    1.098505    3.541926    0.795324    0.079728    0.021902    0.518172    
#> 261: 0.710441    1.098289    3.542106    0.793981    0.079694    0.021921    0.517864    
#> 262: 0.710423    1.098402    3.542105    0.794384    0.079543    0.021937    0.517523    
#> 263: 0.710284    1.098616    3.541928    0.794824    0.079478    0.021959    0.517254    
#> 264: 0.710032    1.098697    3.541786    0.794734    0.079445    0.021991    0.517340    
#> 265: 0.709620    1.098858    3.541738    0.794235    0.079295    0.022088    0.517276    
#> 266: 0.709513    1.099163    3.541727    0.795209    0.079151    0.022156    0.517325    
#> 267: 0.709639    1.099270    3.541793    0.798243    0.079086    0.022234    0.517227    
#> 268: 0.710168    1.099259    3.541675    0.801247    0.079182    0.022224    0.517192    
#> 269: 0.710635    1.099166    3.541606    0.802562    0.079093    0.022216    0.517036    
#> 270: 0.710921    1.099448    3.541500    0.804585    0.079047    0.022154    0.516744    
#> 271: 0.710759    1.099664    3.541370    0.805367    0.079114    0.022140    0.516661    
#> 272: 0.710779    1.099673    3.541270    0.805186    0.079102    0.022113    0.516937    
#> 273: 0.710421    1.099813    3.541270    0.805357    0.078982    0.022095    0.517033    
#> 274: 0.710529    1.100006    3.541313    0.804920    0.078881    0.022107    0.517085    
#> 275: 0.710318    1.100129    3.541267    0.803213    0.078611    0.022114    0.517026    
#> 276: 0.710378    1.100307    3.541275    0.803606    0.078492    0.022110    0.516814    
#> 277: 0.710097    1.100453    3.541350    0.802933    0.078400    0.022102    0.516746    
#> 278: 0.710231    1.100361    3.541491    0.803893    0.078391    0.022092    0.516732    
#> 279: 0.710393    1.100172    3.541626    0.804870    0.078527    0.022110    0.516688    
#> 280: 0.710256    1.100239    3.541690    0.804448    0.078519    0.022146    0.516484    
#> 281: 0.710003    1.100320    3.541679    0.805192    0.078416    0.022178    0.516351    
#> 282: 0.710259    1.100564    3.541778    0.807142    0.078337    0.022185    0.516363    
#> 283: 0.710221    1.100693    3.541784    0.807827    0.078340    0.022225    0.516570    
#> 284: 0.710079    1.100799    3.541686    0.807620    0.078396    0.022222    0.516701    
#> 285: 0.709729    1.100892    3.541527    0.806459    0.078409    0.022222    0.516761    
#> 286: 0.708874    1.100931    3.541309    0.805184    0.078379    0.022193    0.516824    
#> 287: 0.707807    1.101026    3.541003    0.804153    0.078412    0.022165    0.516906    
#> 288: 0.707457    1.100879    3.540945    0.803865    0.078471    0.022148    0.517099    
#> 289: 0.707414    1.100828    3.540909    0.803759    0.078384    0.022166    0.516925    
#> 290: 0.707551    1.100835    3.540884    0.804089    0.078305    0.022177    0.516929    
#> 291: 0.707841    1.101051    3.540932    0.804486    0.078298    0.022237    0.516828    
#> 292: 0.707367    1.101245    3.540771    0.804192    0.078296    0.022275    0.516625    
#> 293: 0.707131    1.101632    3.540591    0.804992    0.078220    0.022335    0.516550    
#> 294: 0.706978    1.101792    3.540349    0.805808    0.078115    0.022374    0.516537    
#> 295: 0.706978    1.101764    3.540246    0.806700    0.078010    0.022377    0.516601    
#> 296: 0.706954    1.101874    3.540132    0.806333    0.078043    0.022368    0.516735    
#> 297: 0.707118    1.102040    3.540121    0.806824    0.078088    0.022352    0.516867    
#> 298: 0.706814    1.101971    3.540090    0.805752    0.078062    0.022336    0.516902    
#> 299: 0.706111    1.102069    3.539993    0.804166    0.078047    0.022330    0.516920    
#> 300: 0.705836    1.102003    3.540023    0.803394    0.077983    0.022308    0.516933    
#> 301: 0.705792    1.101888    3.539999    0.803021    0.077950    0.022288    0.516908    
#> 302: 0.705688    1.102030    3.539851    0.802856    0.077843    0.022294    0.516873    
#> 303: 0.705352    1.102106    3.539819    0.801909    0.077848    0.022305    0.516727    
#> 304: 0.705424    1.102307    3.539739    0.802783    0.077831    0.022297    0.516687    
#> 305: 0.705463    1.102221    3.539676    0.802880    0.077778    0.022285    0.516598    
#> 306: 0.704970    1.102221    3.539565    0.802252    0.077676    0.022300    0.516467    
#> 307: 0.704538    1.102247    3.539410    0.801679    0.077582    0.022324    0.516490    
#> 308: 0.704113    1.102307    3.539246    0.800948    0.077593    0.022303    0.516550    
#> 309: 0.704060    1.102253    3.539271    0.800940    0.077601    0.022336    0.516760    
#> 310: 0.703889    1.102421    3.539164    0.801008    0.077558    0.022381    0.516781    
#> 311: 0.703739    1.102618    3.539074    0.801114    0.077422    0.022424    0.516855    
#> 312: 0.703680    1.102648    3.539027    0.801694    0.077292    0.022475    0.516789    
#> 313: 0.703988    1.102538    3.538972    0.803370    0.077245    0.022524    0.516731    
#> 314: 0.704008    1.102668    3.538833    0.804403    0.077144    0.022555    0.516662    
#> 315: 0.703899    1.102978    3.538709    0.805209    0.077086    0.022566    0.516629    
#> 316: 0.703332    1.103245    3.538573    0.804467    0.077263    0.022554    0.516650    
#> 317: 0.703070    1.103355    3.538562    0.803646    0.077324    0.022563    0.516838    
#> 318: 0.702849    1.103481    3.538497    0.802943    0.077312    0.022570    0.516872    
#> 319: 0.702691    1.103499    3.538544    0.802968    0.077311    0.022604    0.516854    
#> 320: 0.702164    1.103455    3.538484    0.802352    0.077439    0.022608    0.516895    
#> 321: 0.701833    1.103618    3.538313    0.801765    0.077586    0.022594    0.517019    
#> 322: 0.701262    1.103705    3.538235    0.801369    0.077718    0.022600    0.516903    
#> 323: 0.700584    1.103758    3.538105    0.800699    0.077724    0.022584    0.516825    
#> 324: 0.700442    1.103947    3.538034    0.800212    0.077683    0.022583    0.516658    
#> 325: 0.700119    1.104181    3.537932    0.799626    0.077634    0.022554    0.516560    
#> 326: 0.699720    1.104189    3.537763    0.798936    0.077585    0.022505    0.516508    
#> 327: 0.699591    1.104281    3.537715    0.799212    0.077537    0.022495    0.516475    
#> 328: 0.699568    1.104422    3.537700    0.799000    0.077505    0.022502    0.516408    
#> 329: 0.699429    1.104541    3.537727    0.798339    0.077521    0.022500    0.516322    
#> 330: 0.699142    1.104574    3.537741    0.797744    0.077534    0.022509    0.516198    
#> 331: 0.698857    1.104725    3.537805    0.796690    0.077506    0.022536    0.516114    
#> 332: 0.698783    1.104726    3.537902    0.795749    0.077476    0.022559    0.516200    
#> 333: 0.698685    1.104716    3.537852    0.795408    0.077429    0.022576    0.516273    
#> 334: 0.698259    1.104688    3.537675    0.794777    0.077425    0.022579    0.516361    
#> 335: 0.698082    1.104720    3.537639    0.794369    0.077409    0.022598    0.516272    
#> 336: 0.697777    1.104837    3.537528    0.794200    0.077354    0.022603    0.516197    
#> 337: 0.697360    1.105074    3.537398    0.793877    0.077361    0.022593    0.516139    
#> 338: 0.697170    1.105177    3.537373    0.793815    0.077317    0.022590    0.516034    
#> 339: 0.696758    1.105360    3.537247    0.793301    0.077396    0.022589    0.515914    
#> 340: 0.696253    1.105336    3.537140    0.792675    0.077454    0.022568    0.515789    
#> 341: 0.696063    1.105432    3.537114    0.792263    0.077479    0.022561    0.515690    
#> 342: 0.695685    1.105296    3.537077    0.791721    0.077493    0.022548    0.515660    
#> 343: 0.695420    1.105251    3.537011    0.791677    0.077511    0.022513    0.515667    
#> 344: 0.695334    1.105136    3.537032    0.791668    0.077538    0.022508    0.515668    
#> 345: 0.695276    1.105099    3.537065    0.791020    0.077598    0.022505    0.515638    
#> 346: 0.694755    1.105074    3.536959    0.789942    0.077660    0.022538    0.515644    
#> 347: 0.694500    1.105001    3.536902    0.789293    0.077639    0.022572    0.515655    
#> 348: 0.693875    1.105036    3.536838    0.788099    0.077688    0.022592    0.515723    
#> 349: 0.693385    1.105021    3.536754    0.787226    0.077696    0.022609    0.515773    
#> 350: 0.693119    1.104948    3.536685    0.786948    0.077741    0.022618    0.515860    
#> 351: 0.692964    1.105024    3.536572    0.786900    0.077813    0.022627    0.515912    
#> 352: 0.692809    1.105141    3.536511    0.786358    0.077827    0.022631    0.515937    
#> 353: 0.692687    1.105290    3.536412    0.785923    0.077808    0.022633    0.515818    
#> 354: 0.692565    1.105420    3.536333    0.785386    0.077739    0.022665    0.515705    
#> 355: 0.692601    1.105337    3.536205    0.785558    0.077705    0.022671    0.515597    
#> 356: 0.692621    1.105366    3.536165    0.785375    0.077740    0.022667    0.515588    
#> 357: 0.692807    1.105409    3.536191    0.785432    0.077693    0.022690    0.515539    
#> 358: 0.692852    1.105491    3.536239    0.785000    0.077630    0.022726    0.515472    
#> 359: 0.692667    1.105574    3.536251    0.784279    0.077524    0.022760    0.515445    
#> 360: 0.692624    1.105625    3.536196    0.783489    0.077534    0.022786    0.515341    
#> 361: 0.692538    1.105608    3.536197    0.783241    0.077466    0.022805    0.515227    
#> 362: 0.692369    1.105571    3.536178    0.782614    0.077449    0.022804    0.515072    
#> 363: 0.692244    1.105485    3.536214    0.782071    0.077468    0.022803    0.514986    
#> 364: 0.692427    1.105433    3.536218    0.782338    0.077539    0.022800    0.514939    
#> 365: 0.692263    1.105427    3.536238    0.781791    0.077570    0.022804    0.514923    
#> 366: 0.691991    1.105350    3.536181    0.780932    0.077590    0.022803    0.514908    
#> 367: 0.691999    1.105362    3.536160    0.780603    0.077541    0.022794    0.514862    
#> 368: 0.692284    1.105370    3.536193    0.780934    0.077464    0.022800    0.514766    
#> 369: 0.692302    1.105320    3.536209    0.781071    0.077442    0.022812    0.514796    
#> 370: 0.692319    1.105396    3.536202    0.781140    0.077425    0.022820    0.514881    
#> 371: 0.692071    1.105517    3.536127    0.780436    0.077465    0.022811    0.514931    
#> 372: 0.691760    1.105626    3.536066    0.780047    0.077478    0.022818    0.514983    
#> 373: 0.691221    1.105817    3.535984    0.778914    0.077450    0.022834    0.515006    
#> 374: 0.691233    1.105887    3.535980    0.778887    0.077401    0.022866    0.514869    
#> 375: 0.691008    1.105854    3.535974    0.778240    0.077327    0.022895    0.514871    
#> 376: 0.690961    1.106001    3.535964    0.777675    0.077238    0.022945    0.514843    
#> 377: 0.690786    1.106070    3.535945    0.777066    0.077181    0.022974    0.514797    
#> 378: 0.690538    1.106105    3.535853    0.776723    0.077156    0.022997    0.514724    
#> 379: 0.690302    1.106072    3.535794    0.776747    0.077089    0.023010    0.514708    
#> 380: 0.690226    1.106153    3.535748    0.777118    0.077110    0.023033    0.514708    
#> 381: 0.690100    1.106207    3.535687    0.777536    0.077096    0.023049    0.514725    
#> 382: 0.689830    1.106189    3.535651    0.777131    0.077110    0.023061    0.514644    
#> 383: 0.689633    1.106147    3.535634    0.776375    0.077144    0.023050    0.514600    
#> 384: 0.689273    1.106146    3.535609    0.775839    0.077124    0.023056    0.514608    
#> 385: 0.689104    1.106179    3.535606    0.775156    0.077112    0.023037    0.514607    
#> 386: 0.689167    1.106244    3.535641    0.774609    0.077089    0.023020    0.514647    
#> 387: 0.689200    1.106329    3.535695    0.774052    0.077049    0.023015    0.514623    
#> 388: 0.689195    1.106334    3.535744    0.773681    0.077026    0.023011    0.514656    
#> 389: 0.689325    1.106197    3.535782    0.774082    0.076997    0.023025    0.514679    
#> 390: 0.689249    1.106179    3.535800    0.773900    0.077004    0.023017    0.514707    
#> 391: 0.689289    1.106159    3.535769    0.773968    0.076996    0.023030    0.514686    
#> 392: 0.689429    1.106079    3.535820    0.774305    0.076985    0.023036    0.514707    
#> 393: 0.689642    1.105929    3.535869    0.774568    0.076976    0.023058    0.514669    
#> 394: 0.689822    1.105852    3.535894    0.774835    0.077001    0.023070    0.514613    
#> 395: 0.689754    1.105898    3.535925    0.774550    0.077003    0.023075    0.514554    
#> 396: 0.689537    1.105965    3.535898    0.774273    0.076988    0.023070    0.514498    
#> 397: 0.689479    1.105977    3.535891    0.774189    0.076970    0.023060    0.514519    
#> 398: 0.689649    1.105961    3.535920    0.774623    0.076965    0.023053    0.514449    
#> 399: 0.689643    1.105938    3.535970    0.774466    0.076980    0.023035    0.514371    
#> 400: 0.689764    1.105969    3.536010    0.774133    0.077033    0.023023    0.514349    
#> 401: 0.689879    1.106022    3.536027    0.773830    0.077074    0.023027    0.514432    
#> 402: 0.690038    1.106185    3.536044    0.773599    0.077131    0.023021    0.514467    
#> 403: 0.690270    1.106288    3.536047    0.773893    0.077165    0.023009    0.514457    
#> 404: 0.690339    1.106317    3.536003    0.774172    0.077152    0.022996    0.514394    
#> 405: 0.690288    1.106338    3.536061    0.773965    0.077101    0.022991    0.514374    
#> 406: 0.690180    1.106385    3.536055    0.773805    0.077087    0.023008    0.514357    
#> 407: 0.690016    1.106452    3.536057    0.773594    0.077065    0.023015    0.514390    
#> 408: 0.690071    1.106530    3.536006    0.773529    0.077082    0.023018    0.514386    
#> 409: 0.689996    1.106548    3.535930    0.773710    0.077088    0.023021    0.514378    
#> 410: 0.689767    1.106666    3.535822    0.774028    0.077099    0.023014    0.514402    
#> 411: 0.689819    1.106504    3.535818    0.774820    0.077064    0.023021    0.514473    
#> 412: 0.689910    1.106553    3.535775    0.775685    0.077124    0.023013    0.514541    
#> 413: 0.689922    1.106675    3.535697    0.776394    0.077200    0.023003    0.514634    
#> 414: 0.689729    1.106725    3.535675    0.776336    0.077244    0.022982    0.514601    
#> 415: 0.689868    1.106771    3.535696    0.776465    0.077279    0.022968    0.514527    
#> 416: 0.689939    1.106751    3.535775    0.776264    0.077302    0.022979    0.514443    
#> 417: 0.690083    1.106695    3.535830    0.776405    0.077308    0.022978    0.514410    
#> 418: 0.690077    1.106578    3.535855    0.776439    0.077302    0.022970    0.514384    
#> 419: 0.689905    1.106545    3.535839    0.776070    0.077374    0.022962    0.514382    
#> 420: 0.689853    1.106513    3.535827    0.775846    0.077432    0.022949    0.514337    
#> 421: 0.689695    1.106508    3.535826    0.775626    0.077471    0.022934    0.514414    
#> 422: 0.689714    1.106471    3.535836    0.775367    0.077471    0.022914    0.514464    
#> 423: 0.689669    1.106450    3.535824    0.775349    0.077507    0.022903    0.514437    
#> 424: 0.689764    1.106479    3.535840    0.775330    0.077543    0.022902    0.514422    
#> 425: 0.689909    1.106490    3.535845    0.775971    0.077493    0.022907    0.514392    
#> 426: 0.689862    1.106547    3.535837    0.776001    0.077463    0.022904    0.514327    
#> 427: 0.689759    1.106581    3.535826    0.775997    0.077434    0.022903    0.514284    
#> 428: 0.689479    1.106712    3.535765    0.775744    0.077491    0.022878    0.514290    
#> 429: 0.689348    1.106843    3.535719    0.775665    0.077524    0.022856    0.514307    
#> 430: 0.689109    1.106903    3.535656    0.775237    0.077538    0.022833    0.514387    
#> 431: 0.688856    1.106954    3.535596    0.774820    0.077521    0.022816    0.514387    
#> 432: 0.688792    1.107004    3.535589    0.774850    0.077509    0.022822    0.514397    
#> 433: 0.688874    1.107054    3.535606    0.775211    0.077428    0.022823    0.514417    
#> 434: 0.688637    1.107040    3.535554    0.774961    0.077364    0.022819    0.514403    
#> 435: 0.688524    1.107093    3.535502    0.774902    0.077321    0.022832    0.514349    
#> 436: 0.688497    1.107101    3.535536    0.774888    0.077288    0.022850    0.514385    
#> 437: 0.688443    1.107065    3.535540    0.774641    0.077261    0.022852    0.514379    
#> 438: 0.688306    1.107150    3.535512    0.774215    0.077244    0.022848    0.514372    
#> 439: 0.688257    1.107240    3.535485    0.773821    0.077204    0.022846    0.514365    
#> 440: 0.688326    1.107301    3.535509    0.773410    0.077197    0.022844    0.514354    
#> 441: 0.688467    1.107308    3.535527    0.773577    0.077173    0.022854    0.514356    
#> 442: 0.688364    1.107366    3.535521    0.773283    0.077182    0.022856    0.514395    
#> 443: 0.688189    1.107478    3.535449    0.773077    0.077142    0.022860    0.514408    
#> 444: 0.688065    1.107626    3.535405    0.772823    0.077109    0.022876    0.514406    
#> 445: 0.687945    1.107691    3.535378    0.772663    0.077099    0.022888    0.514430    
#> 446: 0.687684    1.107773    3.535318    0.772245    0.077074    0.022893    0.514411    
#> 447: 0.687514    1.107827    3.535300    0.771908    0.077057    0.022910    0.514407    
#> 448: 0.687368    1.107845    3.535281    0.771642    0.077010    0.022925    0.514357    
#> 449: 0.687253    1.107882    3.535325    0.771071    0.077004    0.022917    0.514403    
#> 450: 0.687267    1.107815    3.535345    0.770864    0.077050    0.022917    0.514380    
#> 451: 0.687212    1.107748    3.535377    0.770383    0.077115    0.022913    0.514404    
#> 452: 0.687241    1.107741    3.535415    0.769986    0.077132    0.022926    0.514371    
#> 453: 0.687151    1.107727    3.535431    0.769453    0.077067    0.022930    0.514358    
#> 454: 0.687045    1.107826    3.535429    0.768943    0.077033    0.022918    0.514358    
#> 455: 0.687134    1.107877    3.535434    0.769096    0.077042    0.022911    0.514265    
#> 456: 0.687101    1.107851    3.535465    0.768984    0.077063    0.022901    0.514234    
#> 457: 0.687044    1.107782    3.535527    0.768541    0.077077    0.022887    0.514172    
#> 458: 0.687050    1.107837    3.535556    0.768351    0.077089    0.022877    0.514138    
#> 459: 0.687025    1.107880    3.535572    0.768334    0.077132    0.022874    0.514087    
#> 460: 0.686981    1.107846    3.535569    0.768343    0.077135    0.022877    0.514022    
#> 461: 0.687069    1.107836    3.535597    0.768474    0.077166    0.022877    0.513969    
#> 462: 0.687107    1.107873    3.535613    0.768473    0.077171    0.022875    0.513904    
#> 463: 0.687114    1.107989    3.535628    0.768107    0.077178    0.022871    0.513888    
#> 464: 0.687111    1.108074    3.535627    0.767728    0.077152    0.022870    0.513822    
#> 465: 0.687143    1.108015    3.535662    0.767467    0.077142    0.022859    0.513770    
#> 466: 0.687287    1.108030    3.535644    0.767443    0.077136    0.022848    0.513771    
#> 467: 0.687141    1.108000    3.535689    0.766761    0.077158    0.022823    0.513756    
#> 468: 0.687283    1.107976    3.535763    0.766353    0.077134    0.022818    0.513725    
#> 469: 0.687418    1.108021    3.535805    0.766051    0.077137    0.022824    0.513741    
#> 470: 0.687374    1.108040    3.535777    0.766016    0.077110    0.022832    0.513789    
#> 471: 0.687399    1.107973    3.535791    0.766258    0.077089    0.022842    0.513818    
#> 472: 0.687375    1.107919    3.535798    0.766256    0.077079    0.022846    0.513847    
#> 473: 0.687308    1.107908    3.535774    0.766302    0.077080    0.022847    0.513818    
#> 474: 0.687343    1.107883    3.535753    0.766779    0.077067    0.022853    0.513810    
#> 475: 0.687509    1.107899    3.535780    0.767241    0.077055    0.022864    0.513804    
#> 476: 0.687545    1.107885    3.535776    0.767324    0.077044    0.022874    0.513804    
#> 477: 0.687572    1.107883    3.535801    0.767429    0.077012    0.022875    0.513755    
#> 478: 0.687556    1.107866    3.535839    0.767288    0.077005    0.022882    0.513710    
#> 479: 0.687680    1.107922    3.535856    0.767419    0.076997    0.022888    0.513670    
#> 480: 0.687696    1.107916    3.535839    0.767586    0.077006    0.022893    0.513698    
#> 481: 0.687675    1.107924    3.535815    0.767500    0.077021    0.022888    0.513693    
#> 482: 0.687781    1.107931    3.535791    0.767742    0.077055    0.022883    0.513709    
#> 483: 0.687627    1.107932    3.535765    0.767864    0.077053    0.022880    0.513741    
#> 484: 0.687471    1.107873    3.535752    0.767635    0.077042    0.022879    0.513762    
#> 485: 0.687344    1.107880    3.535731    0.767633    0.077047    0.022879    0.513833    
#> 486: 0.687180    1.107903    3.535736    0.767619    0.077030    0.022882    0.513851    
#> 487: 0.687333    1.107891    3.535745    0.768203    0.077027    0.022889    0.513890    
#> 488: 0.687368    1.107929    3.535722    0.768695    0.077052    0.022890    0.513879    
#> 489: 0.687403    1.107973    3.535688    0.768867    0.077097    0.022891    0.513859    
#> 490: 0.687551    1.108004    3.535692    0.769117    0.077134    0.022893    0.513830    
#> 491: 0.687627    1.108065    3.535737    0.768961    0.077132    0.022899    0.513843    
#> 492: 0.687716    1.108139    3.535741    0.769156    0.077150    0.022912    0.513828    
#> 493: 0.687606    1.108152    3.535751    0.769004    0.077131    0.022909    0.513814    
#> 494: 0.687681    1.108192    3.535748    0.769182    0.077129    0.022902    0.513798    
#> 495: 0.687711    1.108208    3.535715    0.769286    0.077122    0.022907    0.513755    
#> 496: 0.687943    1.108338    3.535665    0.769734    0.077098    0.022893    0.513769    
#> 497: 0.688075    1.108378    3.535659    0.770029    0.077152    0.022892    0.513730    
#> 498: 0.688033    1.108373    3.535637    0.769922    0.077164    0.022880    0.513695    
#> 499: 0.687965    1.108401    3.535605    0.769822    0.077228    0.022862    0.513657    
#> 500: 0.688037    1.108383    3.535570    0.769648    0.077211    0.022854    0.513635    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.329582    0.984777    3.447154    0.392401    0.078743    0.016800    1.748713    
#> 002: 0.489297    1.055712    3.474723    0.372781    0.085838    0.015960    1.214722    
#> 003: 0.612028    1.060252    3.483655    0.354142    0.081546    0.018355    0.970937    
#> 004: 0.651140    1.103174    3.483524    0.469457    0.077468    0.020689    0.784413    
#> 005: 0.790348    1.104210    3.485090    0.616524    0.073595    0.020716    0.729644    
#> 006: 0.779048    1.121551    3.485227    0.668706    0.069915    0.025496    0.660876    
#> 007: 0.773140    1.129998    3.469812    0.803794    0.067631    0.031059    0.658834    
#> 008: 0.762911    1.106410    3.464567    0.828371    0.064250    0.036659    0.651070    
#> 009: 0.744899    1.098460    3.466497    0.866654    0.061037    0.036456    0.642211    
#> 010: 0.750311    1.111546    3.472397    0.823321    0.058339    0.036706    0.635289    
#> 011: 0.763577    1.111010    3.480600    0.782155    0.055422    0.041088    0.640867    
#> 012: 0.788780    1.100247    3.498016    0.848393    0.052651    0.042387    0.631060    
#> 013: 0.834361    1.092768    3.491884    0.947726    0.050018    0.050947    0.623707    
#> 014: 0.871767    1.093268    3.491253    1.118689    0.047517    0.048400    0.633812    
#> 015: 0.868536    1.101383    3.498450    1.062754    0.045142    0.049407    0.632415    
#> 016: 0.885973    1.110761    3.495081    1.100579    0.042885    0.046937    0.616104    
#> 017: 0.857071    1.121156    3.494087    1.085679    0.040740    0.044590    0.597525    
#> 018: 0.854277    1.119183    3.478460    1.061467    0.038703    0.042360    0.609203    
#> 019: 0.746636    1.118288    3.471150    1.008394    0.036768    0.042567    0.605862    
#> 020: 0.837064    1.120715    3.483598    1.050828    0.034930    0.045230    0.600952    
#> 021: 0.793541    1.110118    3.479122    0.998287    0.035769    0.042968    0.615304    
#> 022: 0.760505    1.110481    3.482068    0.948373    0.041036    0.042915    0.601910    
#> 023: 0.849570    1.120632    3.495662    0.916365    0.044427    0.042694    0.612471    
#> 024: 0.859614    1.128275    3.495964    0.941346    0.042205    0.042761    0.612446    
#> 025: 0.864132    1.122074    3.480320    1.153617    0.043320    0.040623    0.609839    
#> 026: 0.869081    1.138842    3.471480    1.295700    0.047318    0.038592    0.608746    
#> 027: 0.878197    1.134519    3.467456    1.262761    0.044952    0.037634    0.598047    
#> 028: 0.937563    1.143818    3.470284    1.578143    0.042704    0.041558    0.602161    
#> 029: 0.908615    1.140824    3.466673    1.499236    0.040569    0.042982    0.619414    
#> 030: 0.923308    1.152543    3.467512    1.629776    0.038541    0.043851    0.616933    
#> 031: 0.921772    1.127496    3.487778    1.564170    0.036614    0.048907    0.618164    
#> 032: 0.893843    1.121163    3.492436    1.485962    0.034783    0.051750    0.614802    
#> 033: 0.887563    1.126839    3.487785    1.411664    0.033044    0.049162    0.602737    
#> 034: 0.856373    1.129453    3.494946    1.341081    0.031392    0.053383    0.603767    
#> 035: 0.797210    1.108383    3.483753    1.274027    0.032053    0.050713    0.613868    
#> 036: 0.809634    1.121176    3.483861    1.210325    0.032986    0.048178    0.619335    
#> 037: 0.764961    1.127106    3.477368    1.149809    0.037244    0.045769    0.629307    
#> 038: 0.807476    1.124767    3.474159    1.092319    0.037203    0.046985    0.617442    
#> 039: 0.825767    1.120612    3.472328    1.043373    0.036627    0.044636    0.616946    
#> 040: 0.777777    1.117700    3.476066    0.991205    0.042610    0.044167    0.603413    
#> 041: 0.697325    1.117292    3.465221    0.941644    0.040479    0.041959    0.616166    
#> 042: 0.783460    1.126159    3.464472    0.906964    0.038484    0.039861    0.606842    
#> 043: 0.785755    1.143358    3.459247    0.994083    0.039440    0.039725    0.606314    
#> 044: 0.751671    1.136561    3.462179    0.944379    0.037468    0.037738    0.604617    
#> 045: 0.789874    1.139255    3.472824    1.029798    0.044465    0.037957    0.599875    
#> 046: 0.816858    1.116904    3.473513    1.088365    0.042242    0.037884    0.615794    
#> 047: 0.829173    1.120833    3.476743    1.055224    0.043732    0.037635    0.614482    
#> 048: 0.790087    1.106704    3.481106    1.002463    0.045644    0.041851    0.612223    
#> 049: 0.814829    1.102609    3.481308    0.958251    0.043362    0.044217    0.617942    
#> 050: 0.824036    1.095308    3.493713    1.038356    0.041194    0.048364    0.627088    
#> 051: 0.836818    1.125775    3.471240    0.986438    0.040321    0.045946    0.638471    
#> 052: 0.822426    1.128058    3.484681    0.937116    0.047367    0.043648    0.613018    
#> 053: 0.824357    1.111427    3.489500    0.895793    0.049666    0.046573    0.617210    
#> 054: 0.797734    1.114613    3.484074    0.851004    0.048923    0.044244    0.638899    
#> 055: 0.789611    1.116304    3.478983    0.892467    0.046476    0.042032    0.642168    
#> 056: 0.844227    1.115243    3.472887    1.021105    0.054333    0.039930    0.645607    
#> 057: 0.882077    1.117397    3.486151    1.085651    0.051617    0.037934    0.647537    
#> 058: 0.922190    1.133080    3.484436    1.078023    0.049036    0.040676    0.630940    
#> 059: 0.833909    1.112750    3.477957    1.127050    0.046584    0.048092    0.636190    
#> 060: 0.819369    1.084542    3.486042    1.070698    0.044255    0.052352    0.638412    
#> 061: 0.832294    1.104855    3.490487    1.017163    0.042042    0.057242    0.637275    
#> 062: 0.820466    1.120842    3.482759    1.127665    0.040652    0.057668    0.645979    
#> 063: 0.907029    1.107695    3.474052    1.351535    0.038620    0.054784    0.647485    
#> 064: 0.879010    1.098777    3.483797    1.283958    0.036689    0.056980    0.638472    
#> 065: 0.868970    1.100726    3.476630    1.219760    0.034854    0.054131    0.608135    
#> 066: 0.857378    1.122429    3.468187    1.177592    0.033112    0.051425    0.605779    
#> 067: 0.812666    1.108861    3.478612    1.118713    0.031456    0.050058    0.599443    
#> 068: 0.772011    1.133883    3.475907    1.062777    0.039026    0.049987    0.609066    
#> 069: 0.804781    1.126047    3.471109    1.009638    0.043416    0.047487    0.618178    
#> 070: 0.828682    1.121920    3.485435    0.959156    0.044763    0.053436    0.609340    
#> 071: 0.806631    1.159526    3.459864    1.037528    0.045804    0.050764    0.621121    
#> 072: 0.767572    1.133995    3.471928    0.985651    0.043514    0.048226    0.632867    
#> 073: 0.858788    1.132183    3.496134    1.162834    0.041338    0.048890    0.614993    
#> 074: 0.789839    1.128053    3.465983    1.104692    0.039271    0.046446    0.610219    
#> 075: 0.847437    1.112359    3.480953    1.166465    0.037308    0.044123    0.631090    
#> 076: 0.835223    1.116496    3.493586    1.108142    0.035945    0.050261    0.615990    
#> 077: 0.873845    1.107636    3.502503    1.052735    0.034148    0.049973    0.617773    
#> 078: 0.825499    1.106667    3.487535    1.017421    0.032441    0.047474    0.607196    
#> 079: 0.830191    1.115179    3.486277    1.016712    0.030819    0.047113    0.617399    
#> 080: 0.801980    1.113719    3.488918    0.965877    0.030370    0.052743    0.628473    
#> 081: 0.800411    1.113556    3.471987    0.965811    0.028851    0.054401    0.626427    
#> 082: 0.767876    1.117399    3.477271    0.917521    0.027409    0.059766    0.623390    
#> 083: 0.787070    1.115410    3.474046    0.871645    0.026038    0.056778    0.638186    
#> 084: 0.759230    1.110819    3.483258    0.828063    0.033736    0.053939    0.641951    
#> 085: 0.811766    1.111238    3.506856    0.849768    0.038104    0.051242    0.625438    
#> 086: 0.823791    1.112696    3.482460    0.862635    0.036199    0.048680    0.625557    
#> 087: 0.860044    1.115360    3.489631    1.065701    0.034389    0.046246    0.613460    
#> 088: 0.809464    1.101952    3.499139    1.012416    0.032669    0.044622    0.625262    
#> 089: 0.804852    1.117834    3.483290    0.961795    0.031441    0.042391    0.615638    
#> 090: 0.773942    1.117246    3.475888    0.913705    0.030922    0.040271    0.613582    
#> 091: 0.769023    1.107149    3.469671    0.868020    0.032519    0.040884    0.616130    
#> 092: 0.783475    1.110652    3.472592    0.853834    0.033058    0.038840    0.609344    
#> 093: 0.735496    1.111898    3.476487    0.811143    0.031983    0.043690    0.617172    
#> 094: 0.759450    1.109712    3.481520    0.770585    0.033385    0.048782    0.619312    
#> 095: 0.784366    1.106971    3.497996    0.748069    0.035934    0.055884    0.611314    
#> 096: 0.781094    1.107628    3.493349    0.826713    0.047522    0.053089    0.615821    
#> 097: 0.842118    1.120588    3.488839    0.922578    0.045145    0.050733    0.617912    
#> 098: 0.827744    1.115430    3.484766    0.876449    0.042888    0.053405    0.618671    
#> 099: 0.809073    1.108059    3.485047    0.916270    0.040744    0.052490    0.614717    
#> 100: 0.835832    1.128598    3.491931    0.994548    0.039666    0.054031    0.611382    
#> 101: 0.760760    1.116519    3.475813    0.944821    0.037682    0.055800    0.605984    
#> 102: 0.734796    1.111496    3.474053    0.897580    0.035798    0.053010    0.635865    
#> 103: 0.739860    1.120973    3.481467    0.852701    0.034008    0.050360    0.628613    
#> 104: 0.771277    1.121844    3.490844    0.862020    0.032308    0.055516    0.616294    
#> 105: 0.798184    1.116917    3.479771    0.878888    0.031211    0.052740    0.627639    
#> 106: 0.803509    1.112537    3.474131    0.972960    0.032487    0.053790    0.615329    
#> 107: 0.827940    1.123581    3.477949    1.015433    0.037593    0.051101    0.615826    
#> 108: 0.833817    1.127863    3.489492    1.013392    0.037518    0.048546    0.609810    
#> 109: 0.880455    1.120749    3.489054    1.095976    0.038098    0.046118    0.613356    
#> 110: 0.878922    1.118295    3.471450    1.156642    0.036193    0.043813    0.602379    
#> 111: 0.847314    1.119201    3.485689    1.098810    0.034383    0.044560    0.595332    
#> 112: 0.787189    1.112866    3.472285    1.043870    0.032664    0.051613    0.609207    
#> 113: 0.779857    1.125509    3.473722    0.991676    0.031031    0.051107    0.603383    
#> 114: 0.873821    1.125853    3.478697    1.177626    0.032831    0.048552    0.599697    
#> 115: 0.909534    1.098953    3.477059    1.354021    0.032724    0.046445    0.616942    
#> 116: 0.882744    1.118349    3.463681    1.416741    0.034305    0.052028    0.614065    
#> 117: 0.891795    1.141447    3.476877    1.475324    0.032590    0.054363    0.613568    
#> 118: 0.987578    1.121073    3.489560    1.670221    0.030960    0.053932    0.604298    
#> 119: 0.916100    1.123709    3.478314    1.586710    0.029412    0.055994    0.618393    
#> 120: 0.821140    1.123647    3.479157    1.507374    0.034438    0.053569    0.611080    
#> 121: 0.794278    1.132084    3.485315    1.432005    0.038090    0.050890    0.611884    
#> 122: 0.805938    1.110106    3.486099    1.360405    0.036185    0.048346    0.624064    
#> 123: 0.866424    1.132529    3.472928    1.292385    0.041937    0.045928    0.604349    
#> 124: 0.851915    1.155067    3.479084    1.227766    0.043066    0.046559    0.617153    
#> 125: 0.842123    1.154787    3.464082    1.272590    0.040912    0.044971    0.608292    
#> 126: 0.857331    1.154261    3.464207    1.290801    0.038867    0.046510    0.616516    
#> 127: 0.908306    1.136815    3.467561    1.382318    0.036923    0.051260    0.614377    
#> 128: 0.861389    1.132586    3.474508    1.313202    0.035077    0.049141    0.623680    
#> 129: 0.887346    1.121813    3.489519    1.247542    0.038990    0.046684    0.632066    
#> 130: 0.885846    1.133165    3.485203    1.185165    0.038289    0.044350    0.621250    
#> 131: 0.815750    1.112371    3.472974    1.125907    0.038989    0.043525    0.614680    
#> 132: 0.794087    1.111158    3.467415    1.069611    0.037039    0.041971    0.616865    
#> 133: 0.812339    1.099481    3.475838    1.043154    0.037068    0.042383    0.607019    
#> 134: 0.866103    1.090421    3.490621    1.136720    0.035214    0.042127    0.623217    
#> 135: 0.835927    1.091109    3.490868    1.079884    0.034393    0.048760    0.634902    
#> 136: 0.830492    1.090486    3.491812    1.025890    0.039651    0.046322    0.605292    
#> 137: 0.851504    1.089353    3.504862    0.974595    0.037669    0.048316    0.612961    
#> 138: 0.802306    1.088527    3.491265    0.925866    0.035785    0.045900    0.621821    
#> 139: 0.770438    1.112472    3.488705    0.911511    0.034595    0.043605    0.628158    
#> 140: 0.802890    1.128946    3.494613    0.967282    0.037172    0.054729    0.620729    
#> 141: 0.823975    1.117351    3.483648    1.025302    0.035314    0.056558    0.600509    
#> 142: 0.889923    1.083475    3.496949    1.178610    0.037649    0.053730    0.615490    
#> 143: 0.836378    1.106663    3.484145    1.122257    0.035767    0.054592    0.606617    
#> 144: 0.915518    1.113072    3.496507    1.293408    0.033978    0.052465    0.605172    
#> 145: 0.888883    1.112579    3.482799    1.262083    0.034769    0.049842    0.589706    
#> 146: 0.863714    1.127596    3.473540    1.248873    0.041989    0.047350    0.610413    
#> 147: 0.786619    1.130142    3.464662    1.186429    0.043302    0.044982    0.611133    
#> 148: 0.804445    1.129165    3.479731    1.127107    0.043732    0.042733    0.614353    
#> 149: 0.804329    1.126146    3.468016    1.070752    0.041545    0.044881    0.617045    
#> 150: 0.850567    1.124534    3.471108    1.099216    0.039468    0.046788    0.639854    
#> 151: 0.922881    1.143130    3.474484    1.523304    0.038325    0.046728    0.619651    
#> 152: 0.904264    1.141864    3.476717    1.506052    0.048602    0.043500    0.623094    
#> 153: 0.865861    1.140924    3.466393    1.384693    0.045290    0.043434    0.638408    
#> 154: 0.864767    1.161502    3.461162    1.444389    0.048881    0.044796    0.617090    
#> 155: 0.779557    1.136687    3.452349    1.047521    0.040241    0.043637    0.620120    
#> 156: 0.780253    1.137789    3.474142    0.901870    0.039140    0.054208    0.634754    
#> 157: 0.811567    1.116588    3.487948    0.957277    0.040546    0.056055    0.627746    
#> 158: 0.845005    1.125012    3.478662    0.980389    0.040253    0.046810    0.619055    
#> 159: 0.778635    1.121138    3.479273    0.900608    0.032594    0.042798    0.618259    
#> 160: 0.821079    1.104583    3.479095    1.024488    0.040984    0.037208    0.628474    
#> 161: 0.808902    1.106224    3.480238    0.892607    0.041267    0.038712    0.653148    
#> 162: 0.787925    1.118310    3.481798    0.918830    0.043011    0.034066    0.653391    
#> 163: 0.797650    1.115078    3.479129    0.777727    0.047279    0.033397    0.645661    
#> 164: 0.780880    1.113226    3.474974    0.928167    0.043418    0.034726    0.618093    
#> 165: 0.909973    1.101851    3.488417    1.070246    0.044895    0.035660    0.619522    
#> 166: 0.907932    1.119470    3.492034    1.101199    0.056352    0.042983    0.617615    
#> 167: 0.929708    1.133297    3.492892    1.234397    0.046740    0.040194    0.618611    
#> 168: 0.922238    1.113916    3.497273    1.267678    0.052606    0.042819    0.613059    
#> 169: 0.927868    1.133869    3.488332    1.208380    0.046760    0.039582    0.622213    
#> 170: 0.924243    1.112005    3.499122    1.227116    0.041420    0.039632    0.614295    
#> 171: 0.864549    1.110007    3.498255    1.022939    0.044591    0.035144    0.605696    
#> 172: 0.812740    1.123134    3.491103    0.907667    0.041626    0.035986    0.608666    
#> 173: 0.827869    1.136669    3.475140    0.915275    0.042513    0.034774    0.601248    
#> 174: 0.818632    1.138001    3.478299    0.975769    0.040784    0.042155    0.608485    
#> 175: 0.802564    1.137790    3.472263    1.069177    0.039191    0.040695    0.610261    
#> 176: 0.736703    1.139690    3.468669    0.854399    0.038353    0.044902    0.605188    
#> 177: 0.771462    1.133456    3.474137    0.905663    0.041801    0.050433    0.609427    
#> 178: 0.779128    1.126796    3.479744    0.906129    0.034512    0.049513    0.623168    
#> 179: 0.811330    1.144927    3.478777    0.847265    0.035015    0.054064    0.633385    
#> 180: 0.740275    1.143736    3.479613    0.882070    0.036952    0.048282    0.633758    
#> 181: 0.768306    1.131719    3.450511    0.957636    0.033818    0.047174    0.639764    
#> 182: 0.732305    1.116369    3.451057    0.910799    0.036771    0.047735    0.621728    
#> 183: 0.737499    1.127878    3.447315    0.891234    0.032302    0.052030    0.625429    
#> 184: 0.715404    1.120252    3.457599    0.857028    0.032630    0.052693    0.622922    
#> 185: 0.754934    1.142136    3.459290    0.907243    0.032467    0.040494    0.623131    
#> 186: 0.771595    1.149477    3.458654    0.991188    0.027000    0.042997    0.625110    
#> 187: 0.800354    1.140514    3.464493    0.958120    0.031067    0.039020    0.631300    
#> 188: 0.734662    1.155531    3.461960    0.834489    0.034432    0.042655    0.638284    
#> 189: 0.722682    1.144366    3.478735    0.801375    0.028791    0.048483    0.640212    
#> 190: 0.730889    1.133457    3.478295    0.827969    0.025745    0.043663    0.620869    
#> 191: 0.795191    1.131363    3.477226    0.908955    0.028506    0.041731    0.617800    
#> 192: 0.816813    1.125525    3.474884    0.894402    0.030824    0.046733    0.618942    
#> 193: 0.877328    1.130646    3.485569    1.031974    0.028187    0.048904    0.622571    
#> 194: 0.814264    1.124456    3.473630    0.894417    0.040473    0.048988    0.624435    
#> 195: 0.740561    1.135151    3.471164    0.801243    0.047259    0.048366    0.620941    
#> 196: 0.808167    1.127925    3.479654    0.903122    0.053528    0.043370    0.632906    
#> 197: 0.816515    1.136524    3.499917    1.075735    0.053314    0.043902    0.640535    
#> 198: 0.880534    1.108496    3.488170    1.281918    0.038182    0.037905    0.615916    
#> 199: 0.786838    1.107398    3.482514    0.857839    0.030419    0.044889    0.620548    
#> 200: 0.799727    1.106644    3.475717    1.020237    0.023972    0.047155    0.614290    
#> 201: 0.804629    1.101172    3.483632    1.003180    0.024017    0.049718    0.617457    
#> 202: 0.805307    1.102706    3.482766    1.001532    0.025552    0.050079    0.613742    
#> 203: 0.826825    1.102071    3.481674    1.025729    0.025646    0.049304    0.616755    
#> 204: 0.834190    1.099106    3.485538    1.046830    0.026865    0.049395    0.615087    
#> 205: 0.842453    1.103653    3.485969    1.061132    0.028231    0.049202    0.614937    
#> 206: 0.847115    1.107211    3.486046    1.059802    0.027631    0.050216    0.614748    
#> 207: 0.848126    1.108637    3.484717    1.088531    0.027246    0.049858    0.616451    
#> 208: 0.847724    1.110129    3.484175    1.083892    0.026654    0.050188    0.617171    
#> 209: 0.852765    1.109388    3.483145    1.092947    0.026432    0.050179    0.618013    
#> 210: 0.853325    1.108767    3.483853    1.087948    0.026043    0.050394    0.618102    
#> 211: 0.853398    1.109071    3.484825    1.080565    0.026088    0.050767    0.617669    
#> 212: 0.850591    1.109747    3.484739    1.063863    0.026401    0.050489    0.615949    
#> 213: 0.846873    1.107970    3.485260    1.044524    0.026678    0.050444    0.615776    
#> 214: 0.848608    1.107569    3.485561    1.037338    0.026876    0.050304    0.616006    
#> 215: 0.844666    1.107902    3.485976    1.018629    0.027174    0.050323    0.616213    
#> 216: 0.845294    1.106829    3.486898    1.010437    0.027416    0.050902    0.616625    
#> 217: 0.843879    1.107126    3.487397    1.002533    0.027690    0.051170    0.616373    
#> 218: 0.840970    1.107470    3.486898    0.992378    0.028062    0.051040    0.615966    
#> 219: 0.839215    1.107186    3.486790    0.989683    0.028477    0.051007    0.615980    
#> 220: 0.836256    1.107077    3.486482    0.992945    0.028870    0.050676    0.615962    
#> 221: 0.833729    1.107704    3.486504    0.991677    0.029336    0.050469    0.615113    
#> 222: 0.832037    1.108407    3.485928    0.987547    0.029594    0.050309    0.614445    
#> 223: 0.833194    1.108867    3.485721    0.985970    0.029619    0.050201    0.613937    
#> 224: 0.834878    1.109586    3.485575    0.982901    0.029608    0.050132    0.613779    
#> 225: 0.833427    1.109116    3.485476    0.979750    0.029827    0.050082    0.614116    
#> 226: 0.831754    1.108408    3.485232    0.976188    0.029880    0.049833    0.613900    
#> 227: 0.830782    1.108016    3.485336    0.970457    0.029900    0.049850    0.613502    
#> 228: 0.829022    1.108738    3.485016    0.968350    0.030142    0.049645    0.613165    
#> 229: 0.828361    1.108833    3.484763    0.966914    0.030309    0.049518    0.612676    
#> 230: 0.829684    1.108832    3.484840    0.968203    0.030402    0.049457    0.612385    
#> 231: 0.830181    1.108660    3.485334    0.969570    0.030543    0.049266    0.612293    
#> 232: 0.828481    1.108196    3.485563    0.964403    0.030569    0.049152    0.612327    
#> 233: 0.828145    1.107558    3.485913    0.963775    0.030587    0.049216    0.611962    
#> 234: 0.826754    1.107506    3.485801    0.959773    0.030683    0.049261    0.612094    
#> 235: 0.825382    1.107090    3.485541    0.958859    0.030737    0.049334    0.611995    
#> 236: 0.825863    1.107250    3.485414    0.960816    0.030785    0.049225    0.612277    
#> 237: 0.826150    1.106938    3.485501    0.960080    0.030714    0.049335    0.612910    
#> 238: 0.828131    1.106649    3.485644    0.963125    0.030750    0.049559    0.613417    
#> 239: 0.827621    1.107205    3.485559    0.959775    0.030849    0.049453    0.613754    
#> 240: 0.828316    1.107548    3.485698    0.962156    0.031114    0.049405    0.614028    
#> 241: 0.828050    1.107365    3.485508    0.962844    0.031090    0.049319    0.614593    
#> 242: 0.827370    1.107214    3.485050    0.963809    0.031264    0.049405    0.615104    
#> 243: 0.826929    1.107620    3.484777    0.962340    0.031315    0.049518    0.615509    
#> 244: 0.827219    1.107468    3.485118    0.962091    0.031390    0.049565    0.615293    
#> 245: 0.827526    1.107156    3.485452    0.961660    0.031321    0.049600    0.615567    
#> 246: 0.827714    1.107001    3.485732    0.960882    0.031389    0.049751    0.615642    
#> 247: 0.828927    1.106816    3.485890    0.963144    0.031427    0.049780    0.615613    
#> 248: 0.829566    1.107152    3.486161    0.962457    0.031419    0.049896    0.615377    
#> 249: 0.830243    1.107013    3.486451    0.962512    0.031291    0.049981    0.615468    
#> 250: 0.831380    1.106975    3.486583    0.963989    0.031229    0.049995    0.615525    
#> 251: 0.832247    1.107086    3.486841    0.964189    0.031198    0.050008    0.615718    
#> 252: 0.831816    1.107213    3.487265    0.960087    0.031167    0.050053    0.616112    
#> 253: 0.831185    1.107289    3.487657    0.956876    0.031145    0.050158    0.616286    
#> 254: 0.831011    1.107384    3.488023    0.955279    0.030998    0.050354    0.616374    
#> 255: 0.831306    1.107417    3.488161    0.954154    0.030872    0.050453    0.616365    
#> 256: 0.831153    1.107282    3.488222    0.951155    0.030813    0.050510    0.616470    
#> 257: 0.830873    1.106939    3.488497    0.948618    0.030833    0.050699    0.616626    
#> 258: 0.830831    1.106558    3.488774    0.946891    0.030820    0.050782    0.616773    
#> 259: 0.830925    1.106188    3.489004    0.947174    0.030827    0.050773    0.617092    
#> 260: 0.831184    1.106235    3.489176    0.946191    0.030868    0.050706    0.617117    
#> 261: 0.831330    1.105993    3.489419    0.944522    0.030790    0.050542    0.617205    
#> 262: 0.832285    1.105944    3.489546    0.945194    0.030780    0.050581    0.617222    
#> 263: 0.832497    1.106092    3.489664    0.944523    0.030685    0.050675    0.617139    
#> 264: 0.832769    1.106140    3.489616    0.945665    0.030586    0.050743    0.617149    
#> 265: 0.833235    1.106361    3.489441    0.948709    0.030562    0.050828    0.617303    
#> 266: 0.834323    1.106581    3.489335    0.951889    0.030603    0.050841    0.617523    
#> 267: 0.835183    1.106648    3.489486    0.955024    0.030613    0.050853    0.617798    
#> 268: 0.836035    1.106618    3.489463    0.957561    0.030643    0.050879    0.617636    
#> 269: 0.838062    1.106442    3.489493    0.963256    0.030611    0.050949    0.617438    
#> 270: 0.839241    1.106398    3.489593    0.965423    0.030532    0.051003    0.617295    
#> 271: 0.839193    1.106312    3.489541    0.966623    0.030516    0.050998    0.617393    
#> 272: 0.839476    1.106207    3.489556    0.967250    0.030516    0.050962    0.617577    
#> 273: 0.839197    1.106332    3.489589    0.968420    0.030539    0.050874    0.617622    
#> 274: 0.838929    1.106382    3.489544    0.967970    0.030533    0.050850    0.617516    
#> 275: 0.838722    1.106444    3.489344    0.967825    0.030503    0.050808    0.617391    
#> 276: 0.838927    1.106514    3.489291    0.970394    0.030474    0.050847    0.617381    
#> 277: 0.838680    1.106689    3.489327    0.970613    0.030502    0.050933    0.617502    
#> 278: 0.839077    1.106802    3.489460    0.971821    0.030507    0.050994    0.617681    
#> 279: 0.838989    1.106762    3.489518    0.971970    0.030526    0.051036    0.617822    
#> 280: 0.838462    1.106835    3.489582    0.970778    0.030529    0.051004    0.617816    
#> 281: 0.838699    1.106832    3.489791    0.970607    0.030466    0.050919    0.617921    
#> 282: 0.838546    1.106892    3.490033    0.969071    0.030395    0.050896    0.618209    
#> 283: 0.838361    1.106912    3.490089    0.967843    0.030386    0.050884    0.618443    
#> 284: 0.838741    1.106558    3.490179    0.967651    0.030397    0.050843    0.618284    
#> 285: 0.838534    1.106501    3.490099    0.967617    0.030384    0.050932    0.618356    
#> 286: 0.838492    1.106738    3.489841    0.966570    0.030426    0.050943    0.618576    
#> 287: 0.838196    1.107009    3.489644    0.967364    0.030467    0.050935    0.618697    
#> 288: 0.838468    1.106940    3.489552    0.968417    0.030420    0.051038    0.618867    
#> 289: 0.839252    1.106987    3.489455    0.969699    0.030443    0.051067    0.618874    
#> 290: 0.839096    1.107000    3.489506    0.969033    0.030487    0.051063    0.618966    
#> 291: 0.839013    1.107170    3.489594    0.968370    0.030529    0.051046    0.618762    
#> 292: 0.838505    1.107243    3.489499    0.966922    0.030546    0.050952    0.618657    
#> 293: 0.838361    1.107396    3.489390    0.966539    0.030517    0.050873    0.618821    
#> 294: 0.837865    1.107544    3.489217    0.965433    0.030486    0.050825    0.618947    
#> 295: 0.837403    1.107408    3.489004    0.965327    0.030480    0.050694    0.619027    
#> 296: 0.836799    1.107331    3.488762    0.964901    0.030591    0.050585    0.619163    
#> 297: 0.836366    1.107537    3.488561    0.964858    0.030780    0.050474    0.619365    
#> 298: 0.836600    1.107645    3.488469    0.965909    0.030893    0.050387    0.619330    
#> 299: 0.836726    1.107821    3.488331    0.967067    0.030918    0.050321    0.619302    
#> 300: 0.836429    1.107887    3.488391    0.966170    0.030983    0.050238    0.619317    
#> 301: 0.836506    1.107879    3.488280    0.966286    0.030939    0.050116    0.619587    
#> 302: 0.836676    1.108012    3.488127    0.967093    0.030899    0.050017    0.619775    
#> 303: 0.835862    1.108281    3.487984    0.966077    0.030937    0.049875    0.619700    
#> 304: 0.835586    1.108630    3.487793    0.965727    0.030998    0.049785    0.619678    
#> 305: 0.835275    1.108650    3.487619    0.966447    0.031009    0.049705    0.619712    
#> 306: 0.834885    1.108622    3.487547    0.966647    0.031016    0.049666    0.619703    
#> 307: 0.834607    1.108572    3.487520    0.967227    0.030967    0.049678    0.619832    
#> 308: 0.834191    1.108579    3.487505    0.967019    0.030956    0.049632    0.619972    
#> 309: 0.834483    1.108431    3.487603    0.967951    0.030959    0.049701    0.620111    
#> 310: 0.834456    1.108355    3.487510    0.967340    0.030915    0.049726    0.620279    
#> 311: 0.834225    1.108275    3.487424    0.967391    0.030844    0.049743    0.620379    
#> 312: 0.833585    1.108257    3.487325    0.966644    0.030797    0.049790    0.620365    
#> 313: 0.833381    1.108188    3.487225    0.966046    0.030824    0.049790    0.620504    
#> 314: 0.832959    1.108133    3.487150    0.965581    0.030827    0.049748    0.620579    
#> 315: 0.832657    1.108087    3.487137    0.965358    0.030829    0.049686    0.620629    
#> 316: 0.832525    1.108174    3.487060    0.965483    0.030904    0.049601    0.620622    
#> 317: 0.832481    1.108277    3.487084    0.964944    0.031006    0.049648    0.620611    
#> 318: 0.832575    1.108401    3.487014    0.964486    0.031113    0.049699    0.620524    
#> 319: 0.832540    1.108480    3.487019    0.964822    0.031164    0.049712    0.620536    
#> 320: 0.832340    1.108596    3.486981    0.964802    0.031318    0.049683    0.620584    
#> 321: 0.832123    1.108745    3.486921    0.963987    0.031446    0.049632    0.620777    
#> 322: 0.831617    1.108792    3.486815    0.962386    0.031501    0.049576    0.621015    
#> 323: 0.830749    1.108859    3.486716    0.960741    0.031532    0.049483    0.621074    
#> 324: 0.830343    1.108886    3.486664    0.959571    0.031549    0.049438    0.621079    
#> 325: 0.830033    1.109007    3.486479    0.958632    0.031584    0.049359    0.621054    
#> 326: 0.829807    1.108932    3.486353    0.958607    0.031571    0.049305    0.621046    
#> 327: 0.829270    1.109069    3.486285    0.957944    0.031553    0.049255    0.621030    
#> 328: 0.828896    1.109145    3.486175    0.957543    0.031637    0.049244    0.620894    
#> 329: 0.828770    1.109293    3.486146    0.957249    0.031664    0.049239    0.620734    
#> 330: 0.828464    1.109316    3.486141    0.957228    0.031733    0.049250    0.620612    
#> 331: 0.828401    1.109540    3.486095    0.957365    0.031794    0.049245    0.620513    
#> 332: 0.828241    1.109621    3.486125    0.957267    0.031853    0.049274    0.620572    
#> 333: 0.827676    1.109679    3.486001    0.956242    0.031881    0.049270    0.620546    
#> 334: 0.827158    1.109741    3.485836    0.955284    0.031907    0.049280    0.620460    
#> 335: 0.826609    1.109756    3.485702    0.954178    0.031890    0.049261    0.620437    
#> 336: 0.825858    1.109854    3.485507    0.953576    0.031834    0.049292    0.620550    
#> 337: 0.824900    1.110005    3.485342    0.952837    0.031807    0.049287    0.620624    
#> 338: 0.824333    1.110094    3.485223    0.952117    0.031769    0.049333    0.620593    
#> 339: 0.823688    1.110165    3.485110    0.951120    0.031804    0.049324    0.620646    
#> 340: 0.823412    1.110168    3.485093    0.950632    0.031853    0.049255    0.620554    
#> 341: 0.823689    1.110165    3.485153    0.950800    0.031885    0.049215    0.620438    
#> 342: 0.823120    1.110219    3.485110    0.949799    0.031912    0.049163    0.620340    
#> 343: 0.822999    1.110275    3.485066    0.949976    0.031910    0.049099    0.620297    
#> 344: 0.823234    1.110288    3.485054    0.951203    0.031920    0.049071    0.620318    
#> 345: 0.823640    1.110308    3.485116    0.951506    0.031964    0.049085    0.620191    
#> 346: 0.823556    1.110390    3.485102    0.950292    0.031927    0.049091    0.620125    
#> 347: 0.823441    1.110287    3.485137    0.949501    0.031959    0.049052    0.620094    
#> 348: 0.823276    1.110254    3.485180    0.949636    0.031970    0.049084    0.620106    
#> 349: 0.823067    1.110049    3.485177    0.949258    0.031982    0.049084    0.620082    
#> 350: 0.822586    1.109963    3.485084    0.948294    0.031998    0.049115    0.620085    
#> 351: 0.822537    1.110100    3.485047    0.947972    0.032048    0.049124    0.620135    
#> 352: 0.822308    1.110140    3.485088    0.946941    0.032101    0.049146    0.620272    
#> 353: 0.822345    1.110290    3.485147    0.946032    0.032191    0.049141    0.620287    
#> 354: 0.821973    1.110360    3.485138    0.945161    0.032215    0.049133    0.620214    
#> 355: 0.821938    1.110325    3.485018    0.945441    0.032269    0.049091    0.620231    
#> 356: 0.821911    1.110295    3.484993    0.945184    0.032324    0.049050    0.620254    
#> 357: 0.822253    1.110299    3.484980    0.946453    0.032359    0.049030    0.620178    
#> 358: 0.822117    1.110321    3.484971    0.946180    0.032382    0.049008    0.620123    
#> 359: 0.821761    1.110388    3.484903    0.945309    0.032392    0.048970    0.620032    
#> 360: 0.821641    1.110398    3.484857    0.945014    0.032378    0.048951    0.619951    
#> 361: 0.821189    1.110453    3.484830    0.943838    0.032338    0.048934    0.619876    
#> 362: 0.821028    1.110453    3.484812    0.943220    0.032309    0.048900    0.619773    
#> 363: 0.820904    1.110420    3.484851    0.942594    0.032295    0.048904    0.619656    
#> 364: 0.820795    1.110482    3.484822    0.942018    0.032292    0.048844    0.619614    
#> 365: 0.820590    1.110452    3.484781    0.941525    0.032294    0.048812    0.619729    
#> 366: 0.820290    1.110445    3.484669    0.941159    0.032282    0.048780    0.619695    
#> 367: 0.820020    1.110482    3.484611    0.940226    0.032244    0.048755    0.619700    
#> 368: 0.820183    1.110578    3.484630    0.940123    0.032253    0.048709    0.619585    
#> 369: 0.820124    1.110559    3.484660    0.939793    0.032252    0.048716    0.619483    
#> 370: 0.820084    1.110559    3.484600    0.940312    0.032262    0.048693    0.619493    
#> 371: 0.819746    1.110611    3.484479    0.940418    0.032254    0.048688    0.619431    
#> 372: 0.819673    1.110628    3.484410    0.941173    0.032250    0.048722    0.619507    
#> 373: 0.819394    1.110765    3.484284    0.942148    0.032254    0.048784    0.619434    
#> 374: 0.819121    1.110792    3.484124    0.942326    0.032221    0.048828    0.619479    
#> 375: 0.818656    1.110802    3.484030    0.941673    0.032187    0.048867    0.619511    
#> 376: 0.818616    1.110877    3.483973    0.942489    0.032131    0.048906    0.619510    
#> 377: 0.818628    1.110992    3.483894    0.942986    0.032121    0.048926    0.619450    
#> 378: 0.818243    1.111102    3.483781    0.942517    0.032123    0.048949    0.619432    
#> 379: 0.818157    1.111018    3.483746    0.942801    0.032106    0.049003    0.619383    
#> 380: 0.817777    1.110940    3.483733    0.942014    0.032131    0.049084    0.619432    
#> 381: 0.817317    1.110836    3.483721    0.941262    0.032119    0.049125    0.619466    
#> 382: 0.817210    1.110793    3.483742    0.940938    0.032110    0.049145    0.619448    
#> 383: 0.817256    1.110713    3.483738    0.941466    0.032124    0.049137    0.619321    
#> 384: 0.817001    1.110737    3.483670    0.942021    0.032160    0.049109    0.619383    
#> 385: 0.816842    1.110768    3.483638    0.941882    0.032186    0.049087    0.619424    
#> 386: 0.816662    1.110849    3.483639    0.941333    0.032233    0.049053    0.619497    
#> 387: 0.816802    1.110923    3.483711    0.941282    0.032280    0.049011    0.619500    
#> 388: 0.816941    1.111001    3.483692    0.941773    0.032284    0.048984    0.619428    
#> 389: 0.817096    1.110959    3.483661    0.941972    0.032289    0.048952    0.619447    
#> 390: 0.817004    1.111046    3.483630    0.941669    0.032303    0.048914    0.619428    
#> 391: 0.817139    1.111070    3.483618    0.941309    0.032313    0.048897    0.619403    
#> 392: 0.817107    1.111020    3.483698    0.940852    0.032361    0.048909    0.619365    
#> 393: 0.817092    1.110965    3.483709    0.940387    0.032399    0.048886    0.619354    
#> 394: 0.817367    1.110920    3.483749    0.940730    0.032404    0.048854    0.619313    
#> 395: 0.817793    1.110916    3.483770    0.941885    0.032465    0.048798    0.619343    
#> 396: 0.817764    1.111027    3.483730    0.941999    0.032520    0.048782    0.619348    
#> 397: 0.817994    1.111034    3.483714    0.943394    0.032551    0.048758    0.619311    
#> 398: 0.818295    1.111051    3.483707    0.944675    0.032576    0.048741    0.619288    
#> 399: 0.818484    1.111062    3.483762    0.945331    0.032582    0.048739    0.619244    
#> 400: 0.818680    1.111133    3.483769    0.945848    0.032579    0.048728    0.619205    
#> 401: 0.818911    1.111206    3.483722    0.946620    0.032612    0.048735    0.619331    
#> 402: 0.819153    1.111264    3.483707    0.947427    0.032639    0.048746    0.619294    
#> 403: 0.819752    1.111318    3.483715    0.948972    0.032617    0.048743    0.619331    
#> 404: 0.820162    1.111409    3.483657    0.950658    0.032609    0.048725    0.619336    
#> 405: 0.820202    1.111460    3.483647    0.951151    0.032592    0.048734    0.619351    
#> 406: 0.820474    1.111490    3.483559    0.952350    0.032622    0.048731    0.619345    
#> 407: 0.820485    1.111608    3.483543    0.952805    0.032627    0.048740    0.619401    
#> 408: 0.820853    1.111737    3.483553    0.953300    0.032622    0.048716    0.619400    
#> 409: 0.821203    1.111693    3.483599    0.954415    0.032634    0.048699    0.619382    
#> 410: 0.821327    1.111780    3.483585    0.955621    0.032666    0.048656    0.619384    
#> 411: 0.821752    1.111656    3.483654    0.957608    0.032684    0.048600    0.619442    
#> 412: 0.822133    1.111657    3.483654    0.959312    0.032709    0.048560    0.619510    
#> 413: 0.822452    1.111728    3.483620    0.961593    0.032768    0.048515    0.619538    
#> 414: 0.822404    1.111776    3.483639    0.962051    0.032820    0.048491    0.619486    
#> 415: 0.822344    1.111792    3.483590    0.961795    0.032843    0.048452    0.619453    
#> 416: 0.822336    1.111849    3.483634    0.961535    0.032856    0.048408    0.619448    
#> 417: 0.822250    1.111765    3.483693    0.960632    0.032863    0.048376    0.619483    
#> 418: 0.822143    1.111806    3.483734    0.960223    0.032879    0.048366    0.619415    
#> 419: 0.821931    1.111887    3.483766    0.959478    0.032862    0.048337    0.619419    
#> 420: 0.821786    1.111914    3.483754    0.958946    0.032842    0.048307    0.619450    
#> 421: 0.821615    1.111927    3.483817    0.958573    0.032809    0.048320    0.619482    
#> 422: 0.821837    1.111870    3.483867    0.958672    0.032798    0.048332    0.619449    
#> 423: 0.822122    1.111737    3.483985    0.957958    0.032804    0.048354    0.619450    
#> 424: 0.822167    1.111603    3.484044    0.957213    0.032796    0.048369    0.619465    
#> 425: 0.822195    1.111572    3.484089    0.956627    0.032817    0.048386    0.619487    
#> 426: 0.822069    1.111625    3.484070    0.955968    0.032814    0.048381    0.619525    
#> 427: 0.821915    1.111595    3.484110    0.955488    0.032817    0.048347    0.619575    
#> 428: 0.821889    1.111671    3.484124    0.955151    0.032808    0.048331    0.619562    
#> 429: 0.821725    1.111736    3.484089    0.954744    0.032805    0.048320    0.619570    
#> 430: 0.821499    1.111808    3.484029    0.954738    0.032821    0.048299    0.619610    
#> 431: 0.821225    1.111897    3.483946    0.954535    0.032830    0.048289    0.619585    
#> 432: 0.821010    1.112057    3.483914    0.954473    0.032845    0.048269    0.619580    
#> 433: 0.820914    1.112158    3.483927    0.954204    0.032874    0.048277    0.619577    
#> 434: 0.820696    1.112108    3.483876    0.953709    0.032894    0.048252    0.619610    
#> 435: 0.820506    1.112112    3.483860    0.953357    0.032931    0.048247    0.619543    
#> 436: 0.820471    1.112130    3.483879    0.952866    0.032952    0.048229    0.619529    
#> 437: 0.820452    1.112104    3.483907    0.952414    0.032952    0.048209    0.619500    
#> 438: 0.820346    1.112236    3.483872    0.951858    0.032964    0.048211    0.619510    
#> 439: 0.820510    1.112286    3.483869    0.951819    0.032949    0.048213    0.619464    
#> 440: 0.820520    1.112294    3.483889    0.951698    0.032958    0.048186    0.619420    
#> 441: 0.820506    1.112221    3.483914    0.951310    0.032972    0.048181    0.619345    
#> 442: 0.820468    1.112224    3.483911    0.951104    0.032973    0.048181    0.619276    
#> 443: 0.820363    1.112246    3.483869    0.950520    0.032969    0.048180    0.619299    
#> 444: 0.820153    1.112275    3.483853    0.949913    0.032965    0.048196    0.619261    
#> 445: 0.819853    1.112302    3.483815    0.949483    0.032958    0.048226    0.619325    
#> 446: 0.819665    1.112286    3.483775    0.949307    0.032940    0.048249    0.619358    
#> 447: 0.819471    1.112295    3.483724    0.948929    0.032935    0.048251    0.619433    
#> 448: 0.819303    1.112314    3.483688    0.948983    0.032927    0.048257    0.619435    
#> 449: 0.819116    1.112413    3.483699    0.948981    0.032934    0.048248    0.619459    
#> 450: 0.819027    1.112474    3.483689    0.948800    0.032945    0.048225    0.619463    
#> 451: 0.819021    1.112619    3.483694    0.948774    0.033002    0.048192    0.619458    
#> 452: 0.819118    1.112709    3.483710    0.948920    0.033036    0.048164    0.619407    
#> 453: 0.819113    1.112755    3.483701    0.948719    0.033079    0.048129    0.619380    
#> 454: 0.818937    1.112872    3.483626    0.948396    0.033085    0.048093    0.619338    
#> 455: 0.819036    1.112926    3.483589    0.949272    0.033094    0.048085    0.619309    
#> 456: 0.819041    1.112945    3.483503    0.949963    0.033085    0.048069    0.619291    
#> 457: 0.818944    1.112973    3.483426    0.950246    0.033098    0.048043    0.619254    
#> 458: 0.818723    1.113094    3.483406    0.950051    0.033146    0.048028    0.619228    
#> 459: 0.818511    1.113209    3.483334    0.950433    0.033220    0.048015    0.619207    
#> 460: 0.818249    1.113360    3.483225    0.950347    0.033289    0.048001    0.619205    
#> 461: 0.818104    1.113511    3.483171    0.950304    0.033334    0.048003    0.619189    
#> 462: 0.817984    1.113644    3.483135    0.950434    0.033343    0.048001    0.619148    
#> 463: 0.818143    1.113734    3.483104    0.951296    0.033359    0.047999    0.619120    
#> 464: 0.818401    1.113809    3.483041    0.952045    0.033364    0.048006    0.619076    
#> 465: 0.818480    1.113727    3.483028    0.952647    0.033376    0.048013    0.619035    
#> 466: 0.818637    1.113721    3.482975    0.953412    0.033364    0.048024    0.619028    
#> 467: 0.818336    1.113671    3.482952    0.953332    0.033346    0.048036    0.619015    
#> 468: 0.818348    1.113653    3.482938    0.953461    0.033327    0.048029    0.619051    
#> 469: 0.818315    1.113698    3.482916    0.953248    0.033308    0.048028    0.619116    
#> 470: 0.818006    1.113722    3.482853    0.952888    0.033292    0.048023    0.619156    
#> 471: 0.817907    1.113753    3.482817    0.952832    0.033277    0.048026    0.619171    
#> 472: 0.817779    1.113747    3.482790    0.952633    0.033277    0.048039    0.619225    
#> 473: 0.817557    1.113802    3.482761    0.952042    0.033274    0.048050    0.619213    
#> 474: 0.817513    1.113808    3.482745    0.951931    0.033253    0.048070    0.619253    
#> 475: 0.817582    1.113941    3.482728    0.952169    0.033257    0.048082    0.619282    
#> 476: 0.817538    1.113973    3.482686    0.952108    0.033246    0.048094    0.619275    
#> 477: 0.817402    1.114027    3.482696    0.952027    0.033233    0.048115    0.619240    
#> 478: 0.817132    1.114069    3.482681    0.951731    0.033245    0.048117    0.619253    
#> 479: 0.816994    1.114116    3.482652    0.951771    0.033236    0.048116    0.619277    
#> 480: 0.816939    1.114197    3.482651    0.951713    0.033275    0.048139    0.619322    
#> 481: 0.816846    1.114243    3.482622    0.951914    0.033274    0.048151    0.619328    
#> 482: 0.816693    1.114293    3.482525    0.952046    0.033265    0.048144    0.619345    
#> 483: 0.816445    1.114339    3.482483    0.951750    0.033261    0.048153    0.619319    
#> 484: 0.816234    1.114356    3.482456    0.951320    0.033264    0.048171    0.619302    
#> 485: 0.816130    1.114393    3.482395    0.951359    0.033270    0.048181    0.619302    
#> 486: 0.816065    1.114414    3.482377    0.951122    0.033274    0.048166    0.619239    
#> 487: 0.816233    1.114393    3.482434    0.950848    0.033264    0.048179    0.619249    
#> 488: 0.816419    1.114330    3.482485    0.951243    0.033257    0.048191    0.619206    
#> 489: 0.816526    1.114232    3.482498    0.951167    0.033259    0.048197    0.619196    
#> 490: 0.816623    1.114185    3.482532    0.951209    0.033250    0.048197    0.619206    
#> 491: 0.816938    1.114189    3.482592    0.951694    0.033246    0.048213    0.619226    
#> 492: 0.816955    1.114219    3.482607    0.951486    0.033273    0.048235    0.619269    
#> 493: 0.816887    1.114283    3.482617    0.951332    0.033303    0.048241    0.619243    
#> 494: 0.816892    1.114380    3.482609    0.951167    0.033335    0.048246    0.619201    
#> 495: 0.816827    1.114491    3.482590    0.950946    0.033373    0.048263    0.619134    
#> 496: 0.816868    1.114570    3.482579    0.950884    0.033413    0.048257    0.619078    
#> 497: 0.816738    1.114601    3.482582    0.950753    0.033445    0.048257    0.619080    
#> 498: 0.816865    1.114604    3.482587    0.951260    0.033460    0.048254    0.619021    
#> 499: 0.816867    1.114638    3.482600    0.951036    0.033500    0.048245    0.618957    
#> 500: 0.817027    1.114673    3.482601    0.951398    0.033536    0.048223    0.618919    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.298239    0.962702    3.441519    0.392401    0.077220    0.016800    1.694835    
#> 002: 0.450867    0.981350    3.469019    0.372781    0.073359    0.015960    1.103024    
#> 003: 0.596716    0.930364    3.475502    0.354142    0.088387    0.015162    0.898429    
#> 004: 0.544142    0.941835    3.482656    0.336435    0.100397    0.014404    0.741994    
#> 005: 0.565006    0.940998    3.468142    0.319613    0.116362    0.013684    0.666546    
#> 006: 0.560994    0.937945    3.454814    0.313162    0.110544    0.013000    0.653436    
#> 007: 0.529595    0.984602    3.448830    0.369823    0.119096    0.012412    0.644426    
#> 008: 0.507066    0.949822    3.437559    0.351331    0.113141    0.014300    0.632005    
#> 009: 0.494339    0.940930    3.437718    0.368908    0.107484    0.014865    0.640188    
#> 010: 0.509872    0.943664    3.433902    0.402050    0.117965    0.014122    0.646468    
#> 011: 0.564176    0.953312    3.443462    0.400816    0.115097    0.013416    0.648185    
#> 012: 0.553197    0.953091    3.442402    0.387703    0.117240    0.012745    0.656172    
#> 013: 0.518201    0.967854    3.435473    0.369941    0.111378    0.012630    0.666507    
#> 014: 0.538371    0.942888    3.451685    0.355249    0.105809    0.015304    0.678450    
#> 015: 0.580818    0.944870    3.465205    0.392335    0.107996    0.017239    0.642299    
#> 016: 0.583086    0.965599    3.468838    0.429310    0.102597    0.019340    0.639710    
#> 017: 0.567586    0.955788    3.461029    0.408950    0.097467    0.018373    0.638840    
#> 018: 0.582056    0.961846    3.453487    0.466265    0.095904    0.017454    0.643593    
#> 019: 0.523836    0.973967    3.445961    0.442952    0.103629    0.016581    0.642699    
#> 020: 0.560268    0.971609    3.450247    0.420805    0.118387    0.015786    0.651335    
#> 021: 0.571036    0.955104    3.456200    0.399764    0.112467    0.015488    0.626051    
#> 022: 0.559184    0.967056    3.459091    0.430064    0.109492    0.015507    0.617826    
#> 023: 0.622643    0.942157    3.475110    0.471690    0.104017    0.014836    0.625590    
#> 024: 0.601809    0.960239    3.463440    0.476033    0.098817    0.014356    0.618788    
#> 025: 0.574553    0.951194    3.457124    0.457713    0.093876    0.014939    0.631983    
#> 026: 0.571525    0.983757    3.444622    0.449261    0.089182    0.017501    0.625655    
#> 027: 0.533689    0.996855    3.437304    0.426798    0.096912    0.017966    0.647465    
#> 028: 0.525842    0.966934    3.448474    0.405458    0.092067    0.020102    0.612462    
#> 029: 0.579352    0.969153    3.442488    0.455342    0.087464    0.019097    0.638731    
#> 030: 0.568819    0.990249    3.441299    0.464801    0.100277    0.018142    0.629704    
#> 031: 0.497729    0.958288    3.442588    0.441561    0.096666    0.017235    0.619927    
#> 032: 0.527234    0.950467    3.449550    0.419483    0.091833    0.016866    0.623940    
#> 033: 0.527378    0.955199    3.450190    0.398509    0.087241    0.016633    0.629738    
#> 034: 0.595533    0.964242    3.453917    0.459979    0.100121    0.015802    0.612113    
#> 035: 0.561539    0.963468    3.448898    0.436980    0.101907    0.015715    0.607365    
#> 036: 0.556793    0.972170    3.445004    0.415131    0.096812    0.015300    0.625929    
#> 037: 0.578760    0.977344    3.447029    0.484950    0.091971    0.014973    0.640753    
#> 038: 0.570894    0.958791    3.450045    0.470855    0.087373    0.014373    0.625678    
#> 039: 0.603774    0.951411    3.457801    0.504558    0.083390    0.018018    0.613045    
#> 040: 0.557928    0.952883    3.454006    0.491492    0.086536    0.022215    0.617964    
#> 041: 0.529082    0.963417    3.446299    0.466918    0.092906    0.021104    0.612431    
#> 042: 0.545615    0.973810    3.446359    0.443572    0.090480    0.020049    0.617590    
#> 043: 0.541110    0.971955    3.442296    0.421393    0.096080    0.019047    0.624637    
#> 044: 0.536164    0.971443    3.443993    0.400324    0.093150    0.018094    0.629425    
#> 045: 0.536121    0.982783    3.435107    0.464116    0.088493    0.017190    0.631025    
#> 046: 0.554920    0.965882    3.443986    0.521319    0.086777    0.017182    0.615128    
#> 047: 0.546609    0.981245    3.436048    0.495253    0.082438    0.016720    0.632298    
#> 048: 0.556928    0.977155    3.440765    0.470490    0.081942    0.015884    0.624810    
#> 049: 0.564034    0.967604    3.446195    0.446966    0.092045    0.015090    0.633632    
#> 050: 0.594713    0.943275    3.449122    0.464802    0.090039    0.014335    0.639702    
#> 051: 0.584325    0.949277    3.447054    0.498883    0.102146    0.016209    0.635908    
#> 052: 0.576606    0.964262    3.453729    0.477261    0.097039    0.015858    0.624452    
#> 053: 0.592342    0.954682    3.453041    0.453398    0.092962    0.017634    0.617085    
#> 054: 0.538129    0.953090    3.454194    0.430728    0.090127    0.016935    0.635432    
#> 055: 0.568441    0.958368    3.461237    0.434094    0.097906    0.016088    0.651881    
#> 056: 0.571134    0.940282    3.461076    0.416983    0.094588    0.017367    0.650828    
#> 057: 0.604066    0.954003    3.471866    0.431268    0.089859    0.019009    0.646762    
#> 058: 0.627317    0.941274    3.455775    0.492043    0.085366    0.018238    0.645083    
#> 059: 0.595863    0.913674    3.466948    0.487147    0.081097    0.021242    0.647967    
#> 060: 0.589784    0.913819    3.465197    0.548745    0.089757    0.020180    0.642431    
#> 061: 0.631788    0.937731    3.466028    0.575412    0.085269    0.019171    0.653764    
#> 062: 0.582049    0.953161    3.459561    0.546642    0.082224    0.019056    0.670041    
#> 063: 0.600797    0.932911    3.458063    0.519310    0.102253    0.018103    0.648616    
#> 064: 0.587325    0.945466    3.462724    0.493344    0.097140    0.017198    0.647160    
#> 065: 0.601438    0.925061    3.454561    0.469932    0.092283    0.016707    0.633452    
#> 066: 0.586777    0.952879    3.458104    0.446436    0.087669    0.017106    0.629254    
#> 067: 0.575357    0.949575    3.449777    0.447582    0.088314    0.020183    0.607974    
#> 068: 0.558755    0.939160    3.457608    0.452840    0.084567    0.019600    0.628752    
#> 069: 0.560443    0.947757    3.455196    0.479262    0.081892    0.018620    0.631537    
#> 070: 0.551041    0.957858    3.456686    0.468225    0.077797    0.017988    0.612811    
#> 071: 0.537700    0.977948    3.437831    0.444814    0.083566    0.017089    0.623678    
#> 072: 0.515818    0.938906    3.448982    0.422573    0.079388    0.016234    0.636337    
#> 073: 0.557679    0.964555    3.464502    0.401444    0.079657    0.015837    0.633382    
#> 074: 0.563516    0.934611    3.457526    0.381372    0.081873    0.015773    0.633914    
#> 075: 0.559761    0.924677    3.470996    0.383837    0.088881    0.014985    0.637705    
#> 076: 0.619432    0.942414    3.476644    0.400566    0.086873    0.015534    0.639943    
#> 077: 0.621995    0.921237    3.473074    0.380538    0.091667    0.015074    0.641553    
#> 078: 0.581891    0.937145    3.468965    0.397481    0.087083    0.016537    0.627779    
#> 079: 0.587010    0.952829    3.466361    0.460010    0.082729    0.018884    0.650312    
#> 080: 0.604542    0.946778    3.462039    0.518932    0.078593    0.019459    0.638989    
#> 081: 0.585651    0.961475    3.452516    0.492986    0.093783    0.018486    0.631575    
#> 082: 0.590661    0.950614    3.467856    0.468336    0.097300    0.017562    0.666488    
#> 083: 0.540581    0.967645    3.462699    0.444919    0.101801    0.016684    0.662112    
#> 084: 0.569178    0.965288    3.455055    0.429244    0.098342    0.015850    0.636222    
#> 085: 0.573764    0.973920    3.460925    0.410308    0.101250    0.015057    0.649882    
#> 086: 0.575671    0.976753    3.461275    0.389792    0.115161    0.015072    0.634937    
#> 087: 0.563139    0.957590    3.448106    0.370303    0.127113    0.014319    0.642269    
#> 088: 0.518387    0.976682    3.448294    0.410816    0.120758    0.013877    0.637227    
#> 089: 0.551159    0.969825    3.438607    0.479122    0.114720    0.015478    0.634892    
#> 090: 0.558619    0.978130    3.433598    0.537099    0.108984    0.018066    0.628145    
#> 091: 0.518670    0.973977    3.427261    0.510244    0.103535    0.019771    0.624840    
#> 092: 0.510305    0.996870    3.422751    0.484732    0.105214    0.018782    0.623578    
#> 093: 0.521371    0.969930    3.437003    0.460495    0.104937    0.017843    0.643716    
#> 094: 0.521865    0.977641    3.433255    0.437471    0.102573    0.017193    0.647372    
#> 095: 0.543983    0.991869    3.447913    0.492985    0.097444    0.017693    0.642352    
#> 096: 0.528091    0.971983    3.452933    0.468335    0.097378    0.019240    0.628490    
#> 097: 0.577092    0.981437    3.445194    0.444919    0.107521    0.018278    0.618894    
#> 098: 0.582797    0.974866    3.461587    0.424769    0.102145    0.022624    0.632626    
#> 099: 0.567045    0.938748    3.455777    0.422523    0.097038    0.021493    0.625966    
#> 100: 0.551399    0.950535    3.464518    0.411975    0.092186    0.020419    0.622828    
#> 101: 0.527209    0.950501    3.443371    0.391376    0.087577    0.019398    0.629663    
#> 102: 0.538843    0.947344    3.447934    0.371808    0.100504    0.018428    0.638261    
#> 103: 0.575323    0.947444    3.459180    0.464238    0.105081    0.017506    0.627661    
#> 104: 0.550143    0.953990    3.463897    0.454077    0.099827    0.016631    0.628101    
#> 105: 0.618498    0.937666    3.469129    0.473552    0.094835    0.017974    0.642260    
#> 106: 0.610133    0.923139    3.478293    0.456409    0.090094    0.018008    0.628850    
#> 107: 0.625160    0.925976    3.465539    0.475440    0.085589    0.017426    0.639092    
#> 108: 0.576210    0.940072    3.465252    0.451668    0.096598    0.016555    0.645011    
#> 109: 0.578770    0.940785    3.469183    0.433903    0.091768    0.018861    0.632380    
#> 110: 0.585433    0.957145    3.449886    0.464359    0.087180    0.018151    0.616226    
#> 111: 0.575974    0.960730    3.455576    0.441141    0.085332    0.017244    0.613063    
#> 112: 0.573806    0.950813    3.442921    0.439737    0.081065    0.018420    0.633739    
#> 113: 0.538734    0.982941    3.454842    0.417750    0.077155    0.019011    0.619850    
#> 114: 0.548717    0.971478    3.447268    0.446299    0.084613    0.019072    0.620902    
#> 115: 0.581317    0.951450    3.449040    0.452401    0.085020    0.020285    0.636810    
#> 116: 0.583160    0.964003    3.450699    0.478161    0.102591    0.019403    0.630145    
#> 117: 0.528380    0.978953    3.444273    0.454253    0.097462    0.018433    0.635811    
#> 118: 0.588275    0.958835    3.457943    0.431540    0.112848    0.017511    0.630599    
#> 119: 0.575637    0.969399    3.453522    0.425401    0.107206    0.016636    0.643761    
#> 120: 0.560772    0.960903    3.448308    0.431808    0.101845    0.015804    0.630709    
#> 121: 0.573606    0.983212    3.449995    0.437239    0.111294    0.015014    0.620372    
#> 122: 0.584827    0.949408    3.456944    0.416722    0.105729    0.014263    0.628822    
#> 123: 0.627578    0.990558    3.447081    0.466620    0.100442    0.013550    0.643565    
#> 124: 0.591675    0.996169    3.445420    0.558188    0.101839    0.013062    0.628138    
#> 125: 0.561801    0.986826    3.436572    0.530279    0.096747    0.012408    0.627466    
#> 126: 0.559367    0.989749    3.430935    0.503765    0.114266    0.011969    0.636897    
#> 127: 0.580051    0.975779    3.442676    0.478576    0.110400    0.012277    0.641759    
#> 128: 0.550664    0.967835    3.448151    0.454648    0.104880    0.011663    0.639571    
#> 129: 0.581361    0.958269    3.450096    0.481744    0.106488    0.011163    0.631908    
#> 130: 0.639347    0.959790    3.453047    0.534633    0.104284    0.012134    0.638922    
#> 131: 0.604890    0.941012    3.454085    0.522078    0.099070    0.013123    0.636076    
#> 132: 0.533701    0.982898    3.437442    0.495975    0.094117    0.014849    0.622213    
#> 133: 0.554130    0.969562    3.445867    0.471176    0.089411    0.014521    0.609174    
#> 134: 0.542690    0.955250    3.452934    0.447617    0.084940    0.016056    0.621246    
#> 135: 0.553141    0.952399    3.458645    0.425236    0.083236    0.015253    0.635081    
#> 136: 0.572076    0.936611    3.461783    0.437988    0.079074    0.018079    0.623863    
#> 137: 0.605645    0.933504    3.470098    0.451310    0.094085    0.017175    0.635572    
#> 138: 0.570869    0.957949    3.461344    0.428745    0.116026    0.016317    0.624523    
#> 139: 0.563440    0.957920    3.465704    0.429968    0.110225    0.015582    0.630633    
#> 140: 0.587821    0.951330    3.471454    0.419822    0.104714    0.017203    0.626746    
#> 141: 0.581982    0.922415    3.472379    0.410814    0.099478    0.018391    0.620587    
#> 142: 0.623703    0.936826    3.480824    0.411446    0.094504    0.020015    0.633175    
#> 143: 0.605164    0.961269    3.469073    0.438377    0.089779    0.019020    0.634941    
#> 144: 0.618201    0.950217    3.476251    0.441818    0.092683    0.018905    0.615339    
#> 145: 0.554759    0.965359    3.454596    0.419727    0.088049    0.017960    0.619940    
#> 146: 0.538072    0.959798    3.456322    0.431408    0.088893    0.017062    0.637517    
#> 147: 0.539784    0.948290    3.445052    0.415905    0.090662    0.018541    0.619968    
#> 148: 0.533677    0.958628    3.453513    0.400812    0.097902    0.017636    0.616491    
#> 149: 0.558266    0.954939    3.452562    0.447844    0.094464    0.019345    0.620622    
#> 150: 0.559219    0.952275    3.445819    0.432703    0.098164    0.018378    0.625675    
#> 151: 0.546658    0.990704    3.446007    0.411068    0.099063    0.017459    0.610222    
#> 152: 0.570513    0.974838    3.461866    0.457333    0.080728    0.019575    0.614738    
#> 153: 0.587205    0.961482    3.458243    0.456982    0.082884    0.019825    0.621388    
#> 154: 0.588620    0.961521    3.454575    0.501442    0.078637    0.017378    0.626640    
#> 155: 0.546624    0.966246    3.444321    0.520259    0.082001    0.017038    0.632614    
#> 156: 0.575013    0.968305    3.449000    0.462809    0.076253    0.015903    0.647395    
#> 157: 0.586819    0.950337    3.464341    0.451104    0.085575    0.016079    0.641182    
#> 158: 0.599009    0.967076    3.459901    0.398822    0.086297    0.014398    0.641141    
#> 159: 0.534849    0.952546    3.458542    0.383406    0.087100    0.015763    0.624171    
#> 160: 0.572061    0.940609    3.448959    0.505298    0.092423    0.016253    0.639043    
#> 161: 0.552216    0.957254    3.445222    0.454460    0.084580    0.016947    0.630347    
#> 162: 0.569184    0.977327    3.445681    0.538548    0.086605    0.016258    0.630560    
#> 163: 0.586924    0.958931    3.443916    0.608674    0.095132    0.017137    0.621128    
#> 164: 0.574047    0.969066    3.453560    0.510652    0.081615    0.017929    0.618090    
#> 165: 0.603577    0.957247    3.456811    0.476186    0.084603    0.018080    0.626554    
#> 166: 0.601262    0.994551    3.454188    0.494926    0.081081    0.020258    0.621670    
#> 167: 0.615344    0.982930    3.455530    0.545275    0.078450    0.021253    0.629245    
#> 168: 0.593733    0.981330    3.452325    0.519088    0.077823    0.016305    0.627053    
#> 169: 0.587898    1.008482    3.447594    0.440411    0.079194    0.019339    0.635310    
#> 170: 0.569721    0.979133    3.455318    0.463456    0.072373    0.020039    0.626604    
#> 171: 0.556267    0.972256    3.442626    0.501478    0.088352    0.016684    0.619354    
#> 172: 0.531797    0.996441    3.444490    0.471370    0.093981    0.014865    0.630151    
#> 173: 0.554933    0.979488    3.439232    0.450683    0.088213    0.015426    0.609449    
#> 174: 0.581510    0.975008    3.448647    0.494020    0.085050    0.015424    0.609050    
#> 175: 0.539821    0.977221    3.436210    0.481830    0.075226    0.016627    0.612188    
#> 176: 0.525097    0.988675    3.438918    0.479612    0.090852    0.014843    0.621813    
#> 177: 0.542935    0.964460    3.451848    0.454210    0.085763    0.018157    0.619733    
#> 178: 0.597991    0.963189    3.458377    0.437480    0.088087    0.015917    0.630296    
#> 179: 0.614587    0.971947    3.460685    0.426004    0.095244    0.017681    0.627915    
#> 180: 0.564388    0.956259    3.464706    0.384539    0.101516    0.015337    0.636100    
#> 181: 0.578959    0.963172    3.452247    0.409476    0.102175    0.013313    0.633424    
#> 182: 0.531134    0.982689    3.442387    0.379908    0.080909    0.014870    0.632242    
#> 183: 0.570465    0.990529    3.445696    0.459185    0.092942    0.018043    0.620815    
#> 184: 0.582181    0.965990    3.450180    0.480505    0.089375    0.018182    0.617287    
#> 185: 0.562580    0.973346    3.448850    0.423726    0.083645    0.019611    0.619619    
#> 186: 0.539045    0.983322    3.438221    0.413451    0.090129    0.017439    0.626447    
#> 187: 0.552294    0.965229    3.443584    0.462358    0.088443    0.018463    0.615091    
#> 188: 0.567663    0.960901    3.448838    0.516782    0.087258    0.019926    0.617422    
#> 189: 0.585622    0.972326    3.454859    0.547784    0.090253    0.020056    0.620348    
#> 190: 0.582215    0.957222    3.454525    0.522187    0.075786    0.019546    0.618492    
#> 191: 0.567369    0.965233    3.446452    0.492673    0.075027    0.019947    0.604340    
#> 192: 0.551867    0.976695    3.454328    0.414456    0.085762    0.018796    0.601805    
#> 193: 0.580613    0.975968    3.459658    0.449837    0.094176    0.019303    0.612172    
#> 194: 0.605287    0.959898    3.452526    0.492941    0.089836    0.019196    0.627689    
#> 195: 0.539218    0.968921    3.447768    0.441785    0.085836    0.017461    0.614259    
#> 196: 0.587601    0.964820    3.455268    0.490780    0.075728    0.017093    0.615385    
#> 197: 0.548958    0.971543    3.465164    0.492681    0.090794    0.015993    0.623734    
#> 198: 0.620845    0.941518    3.463411    0.513526    0.092845    0.016867    0.605362    
#> 199: 0.606853    0.935163    3.465219    0.563776    0.098907    0.018093    0.616714    
#> 200: 0.569390    0.932956    3.472217    0.497748    0.094214    0.018691    0.638125    
#> 201: 0.567533    0.932044    3.471333    0.484590    0.094209    0.020261    0.632383    
#> 202: 0.570388    0.935560    3.469898    0.475981    0.091761    0.019913    0.632497    
#> 203: 0.577739    0.938014    3.465762    0.472122    0.090837    0.019371    0.630259    
#> 204: 0.588412    0.938788    3.466893    0.481860    0.092423    0.018721    0.628403    
#> 205: 0.592120    0.947385    3.465208    0.478430    0.093148    0.018393    0.630712    
#> 206: 0.595283    0.952938    3.464710    0.489318    0.092093    0.018348    0.631556    
#> 207: 0.591063    0.952614    3.462681    0.489421    0.091020    0.018265    0.631482    
#> 208: 0.589437    0.953787    3.461808    0.485810    0.089147    0.017966    0.629779    
#> 209: 0.588874    0.953934    3.460301    0.485220    0.088620    0.017410    0.629856    
#> 210: 0.588755    0.953529    3.459852    0.479051    0.087721    0.017292    0.629080    
#> 211: 0.591127    0.953363    3.460142    0.480502    0.087451    0.017063    0.628132    
#> 212: 0.591329    0.952566    3.460169    0.481946    0.087367    0.017107    0.627926    
#> 213: 0.592160    0.951529    3.460411    0.480432    0.087983    0.017358    0.628379    
#> 214: 0.594345    0.950955    3.460651    0.485649    0.088029    0.017342    0.628168    
#> 215: 0.594106    0.950633    3.460990    0.482469    0.087847    0.017282    0.627588    
#> 216: 0.596555    0.948944    3.461586    0.480194    0.087214    0.017257    0.628254    
#> 217: 0.594924    0.949413    3.461710    0.479466    0.087066    0.017367    0.627562    
#> 218: 0.594350    0.949645    3.461302    0.479274    0.086782    0.017362    0.627430    
#> 219: 0.591550    0.949987    3.460405    0.474862    0.086890    0.017309    0.627540    
#> 220: 0.589035    0.950950    3.459960    0.470704    0.087328    0.017329    0.627970    
#> 221: 0.586978    0.951495    3.459181    0.469027    0.087468    0.017374    0.627047    
#> 222: 0.585956    0.951966    3.458287    0.469887    0.087264    0.017496    0.627150    
#> 223: 0.585121    0.952729    3.457642    0.470458    0.087266    0.017589    0.626852    
#> 224: 0.585790    0.953779    3.457328    0.472327    0.087222    0.017570    0.626930    
#> 225: 0.584086    0.953427    3.457338    0.469706    0.087268    0.017707    0.627637    
#> 226: 0.582887    0.952871    3.456923    0.468757    0.086838    0.017795    0.628145    
#> 227: 0.581673    0.953221    3.456524    0.466800    0.087138    0.017858    0.628391    
#> 228: 0.579895    0.954110    3.455822    0.464823    0.087072    0.017939    0.628239    
#> 229: 0.578388    0.953948    3.455363    0.464726    0.086909    0.018035    0.627847    
#> 230: 0.577151    0.953669    3.454814    0.465907    0.086511    0.018033    0.627826    
#> 231: 0.576252    0.954256    3.454593    0.465637    0.086312    0.018049    0.627438    
#> 232: 0.576296    0.954507    3.454639    0.465698    0.086117    0.018116    0.626986    
#> 233: 0.575652    0.954434    3.454732    0.465307    0.086008    0.018118    0.627123    
#> 234: 0.574923    0.954388    3.454660    0.463081    0.086081    0.018168    0.627220    
#> 235: 0.573474    0.954672    3.454360    0.461134    0.086124    0.018155    0.627039    
#> 236: 0.572379    0.955257    3.454031    0.458858    0.085940    0.018131    0.627059    
#> 237: 0.572589    0.955292    3.454089    0.456794    0.086043    0.018068    0.627726    
#> 238: 0.572731    0.954769    3.454120    0.454735    0.086271    0.017973    0.628506    
#> 239: 0.571979    0.955276    3.453935    0.453023    0.086204    0.017914    0.628855    
#> 240: 0.572257    0.955407    3.454251    0.452144    0.086285    0.017908    0.628824    
#> 241: 0.572920    0.954691    3.454511    0.452098    0.086296    0.017926    0.628764    
#> 242: 0.573312    0.954232    3.454581    0.453305    0.086350    0.017894    0.628999    
#> 243: 0.572898    0.954406    3.454673    0.452452    0.086409    0.017898    0.629323    
#> 244: 0.572391    0.954535    3.454551    0.450884    0.086370    0.017852    0.629817    
#> 245: 0.572504    0.954034    3.454629    0.450876    0.086845    0.017830    0.630495    
#> 246: 0.573528    0.954045    3.454679    0.451058    0.087172    0.017755    0.630705    
#> 247: 0.573588    0.953965    3.455007    0.450153    0.087334    0.017763    0.630683    
#> 248: 0.573387    0.954603    3.454897    0.450315    0.087605    0.017738    0.630953    
#> 249: 0.572706    0.954928    3.455038    0.449352    0.087704    0.017711    0.631438    
#> 250: 0.573771    0.955255    3.455237    0.451114    0.087736    0.017714    0.631617    
#> 251: 0.574161    0.955603    3.455548    0.451769    0.087663    0.017669    0.631665    
#> 252: 0.574689    0.955700    3.455915    0.452319    0.087670    0.017610    0.631558    
#> 253: 0.574539    0.955767    3.455993    0.452259    0.087779    0.017567    0.631498    
#> 254: 0.574947    0.956069    3.456024    0.452855    0.087790    0.017558    0.631583    
#> 255: 0.574837    0.956501    3.456013    0.453099    0.087866    0.017530    0.631575    
#> 256: 0.574176    0.956476    3.455902    0.452313    0.088073    0.017471    0.631952    
#> 257: 0.573896    0.956103    3.455838    0.451207    0.088245    0.017441    0.632150    
#> 258: 0.573942    0.955994    3.455634    0.451898    0.088421    0.017431    0.631936    
#> 259: 0.573828    0.955951    3.455504    0.451567    0.088471    0.017452    0.631814    
#> 260: 0.573875    0.956150    3.455342    0.452055    0.088588    0.017469    0.631609    
#> 261: 0.573910    0.956149    3.455428    0.451813    0.088541    0.017471    0.631557    
#> 262: 0.573677    0.956595    3.455341    0.451843    0.088625    0.017468    0.631664    
#> 263: 0.573664    0.956821    3.455353    0.450975    0.088835    0.017520    0.632170    
#> 264: 0.573432    0.956914    3.455444    0.450459    0.089434    0.017521    0.632387    
#> 265: 0.573332    0.957064    3.455386    0.451082    0.089798    0.017525    0.632420    
#> 266: 0.573426    0.957200    3.455398    0.451087    0.089870    0.017479    0.632384    
#> 267: 0.573414    0.957272    3.455575    0.450589    0.089866    0.017470    0.632258    
#> 268: 0.574541    0.956913    3.455762    0.451521    0.089668    0.017457    0.632128    
#> 269: 0.575289    0.956641    3.456008    0.450936    0.089417    0.017453    0.632146    
#> 270: 0.575870    0.956750    3.456015    0.450877    0.089270    0.017422    0.631969    
#> 271: 0.576161    0.956806    3.455962    0.450759    0.089294    0.017413    0.631897    
#> 272: 0.576551    0.956544    3.455992    0.450521    0.089435    0.017443    0.632204    
#> 273: 0.576351    0.956819    3.455942    0.450718    0.089544    0.017481    0.632370    
#> 274: 0.575862    0.957023    3.455898    0.450088    0.089674    0.017484    0.632266    
#> 275: 0.575544    0.957273    3.455874    0.449774    0.089747    0.017483    0.632213    
#> 276: 0.574846    0.957362    3.455857    0.449432    0.089738    0.017544    0.632138    
#> 277: 0.574266    0.957538    3.456002    0.448989    0.089685    0.017635    0.631966    
#> 278: 0.574012    0.957473    3.456166    0.448377    0.089600    0.017653    0.632007    
#> 279: 0.574025    0.957273    3.456357    0.448761    0.089570    0.017673    0.632068    
#> 280: 0.574051    0.957206    3.456408    0.448829    0.089511    0.017678    0.631947    
#> 281: 0.573634    0.957459    3.456423    0.449197    0.089647    0.017677    0.631680    
#> 282: 0.573838    0.957677    3.456493    0.450192    0.089702    0.017681    0.631474    
#> 283: 0.574203    0.957674    3.456602    0.450450    0.089802    0.017688    0.631599    
#> 284: 0.574051    0.957510    3.456601    0.449852    0.089679    0.017679    0.631473    
#> 285: 0.574026    0.957671    3.456478    0.449387    0.089571    0.017690    0.631526    
#> 286: 0.573663    0.957854    3.456293    0.449384    0.089383    0.017720    0.631434    
#> 287: 0.573078    0.958039    3.456100    0.449650    0.089133    0.017774    0.631473    
#> 288: 0.573357    0.958080    3.456102    0.450453    0.088953    0.017840    0.631546    
#> 289: 0.573726    0.958067    3.456122    0.450910    0.088747    0.017876    0.631428    
#> 290: 0.574048    0.958034    3.456165    0.451150    0.088692    0.017877    0.631682    
#> 291: 0.574260    0.958116    3.456215    0.450837    0.088619    0.017864    0.631560    
#> 292: 0.574574    0.958113    3.456309    0.450689    0.088553    0.017861    0.631394    
#> 293: 0.574571    0.958237    3.456311    0.450337    0.088574    0.017869    0.631274    
#> 294: 0.574676    0.958402    3.456255    0.450742    0.088514    0.017876    0.631055    
#> 295: 0.574522    0.958148    3.456213    0.450737    0.088466    0.017885    0.630819    
#> 296: 0.574417    0.957974    3.456151    0.450404    0.088516    0.017910    0.630679    
#> 297: 0.574128    0.958033    3.456086    0.450317    0.088548    0.017932    0.630682    
#> 298: 0.574199    0.957930    3.456024    0.450257    0.088632    0.017957    0.630650    
#> 299: 0.574076    0.958219    3.455862    0.450942    0.088564    0.017991    0.630573    
#> 300: 0.574050    0.958108    3.455780    0.451751    0.088468    0.018029    0.630492    
#> 301: 0.574114    0.958265    3.455579    0.452509    0.088454    0.018036    0.630730    
#> 302: 0.574282    0.958413    3.455436    0.452906    0.088468    0.018039    0.630855    
#> 303: 0.574078    0.958665    3.455280    0.453375    0.088546    0.018024    0.630679    
#> 304: 0.573749    0.959128    3.455047    0.454001    0.088715    0.018012    0.630698    
#> 305: 0.573446    0.959191    3.454933    0.454151    0.088618    0.018051    0.630661    
#> 306: 0.572868    0.959280    3.454774    0.453987    0.088559    0.018083    0.630517    
#> 307: 0.572204    0.959469    3.454668    0.453573    0.088500    0.018112    0.630546    
#> 308: 0.571663    0.959554    3.454500    0.453832    0.088362    0.018119    0.630460    
#> 309: 0.571501    0.959507    3.454393    0.454452    0.088300    0.018124    0.630587    
#> 310: 0.571509    0.959523    3.454277    0.454894    0.088198    0.018123    0.630721    
#> 311: 0.571492    0.959656    3.454209    0.455725    0.088103    0.018141    0.630804    
#> 312: 0.571692    0.959556    3.454126    0.457067    0.088064    0.018150    0.631018    
#> 313: 0.571621    0.959460    3.453998    0.457299    0.088008    0.018175    0.631077    
#> 314: 0.571333    0.959392    3.453925    0.457031    0.087946    0.018189    0.631027    
#> 315: 0.571090    0.959378    3.453847    0.457398    0.087943    0.018206    0.630921    
#> 316: 0.571295    0.959527    3.453772    0.458629    0.087860    0.018210    0.630757    
#> 317: 0.571494    0.959495    3.453715    0.459063    0.087754    0.018186    0.630880    
#> 318: 0.571459    0.959629    3.453652    0.458828    0.087880    0.018147    0.630880    
#> 319: 0.571654    0.959663    3.453739    0.458788    0.087872    0.018112    0.630904    
#> 320: 0.571326    0.959632    3.453731    0.458491    0.087830    0.018079    0.630865    
#> 321: 0.571126    0.959776    3.453691    0.458180    0.087861    0.018027    0.630888    
#> 322: 0.571345    0.959798    3.453689    0.458918    0.087806    0.017990    0.630831    
#> 323: 0.571346    0.959759    3.453637    0.459348    0.087748    0.017957    0.630802    
#> 324: 0.571716    0.959876    3.453644    0.460234    0.087787    0.017921    0.630706    
#> 325: 0.571786    0.960042    3.453609    0.460593    0.087761    0.017888    0.630688    
#> 326: 0.571714    0.959775    3.453590    0.460352    0.087799    0.017877    0.630772    
#> 327: 0.571736    0.959839    3.453609    0.460086    0.087730    0.017842    0.630947    
#> 328: 0.571722    0.959914    3.453587    0.459581    0.087752    0.017816    0.631048    
#> 329: 0.571874    0.959968    3.453631    0.459319    0.087711    0.017771    0.631042    
#> 330: 0.571742    0.960036    3.453699    0.459063    0.087756    0.017747    0.630953    
#> 331: 0.571985    0.960097    3.453830    0.458425    0.087795    0.017725    0.630912    
#> 332: 0.572278    0.960105    3.453899    0.458404    0.087870    0.017718    0.630838    
#> 333: 0.572318    0.960092    3.453873    0.458087    0.087936    0.017696    0.630935    
#> 334: 0.572069    0.959945    3.453762    0.457677    0.088057    0.017664    0.630991    
#> 335: 0.572106    0.959933    3.453662    0.457589    0.088098    0.017612    0.631100    
#> 336: 0.571700    0.960148    3.453517    0.457573    0.088131    0.017571    0.631200    
#> 337: 0.571509    0.960474    3.453317    0.457666    0.088254    0.017557    0.631263    
#> 338: 0.571288    0.960597    3.453190    0.457833    0.088234    0.017523    0.631331    
#> 339: 0.571168    0.960717    3.453072    0.457878    0.088281    0.017501    0.631278    
#> 340: 0.571130    0.960564    3.453037    0.458077    0.088265    0.017499    0.631250    
#> 341: 0.570991    0.960587    3.453006    0.458003    0.088273    0.017498    0.631227    
#> 342: 0.570546    0.960490    3.452934    0.457699    0.088325    0.017482    0.631179    
#> 343: 0.570447    0.960567    3.452907    0.457658    0.088362    0.017483    0.631023    
#> 344: 0.570618    0.960566    3.452873    0.458449    0.088412    0.017479    0.630950    
#> 345: 0.570722    0.960534    3.452865    0.458485    0.088438    0.017471    0.630952    
#> 346: 0.570763    0.960450    3.452772    0.458403    0.088504    0.017473    0.630830    
#> 347: 0.570702    0.960406    3.452699    0.458237    0.088534    0.017484    0.630858    
#> 348: 0.570301    0.960457    3.452616    0.458091    0.088617    0.017482    0.630893    
#> 349: 0.570184    0.960405    3.452597    0.458111    0.088711    0.017461    0.630830    
#> 350: 0.569715    0.960316    3.452556    0.457695    0.088749    0.017446    0.630823    
#> 351: 0.569416    0.960468    3.452525    0.457100    0.088712    0.017424    0.630895    
#> 352: 0.568974    0.960654    3.452482    0.456785    0.088683    0.017422    0.631062    
#> 353: 0.568811    0.960847    3.452427    0.456532    0.088743    0.017431    0.631137    
#> 354: 0.568604    0.960973    3.452338    0.455945    0.088822    0.017412    0.631165    
#> 355: 0.568605    0.960844    3.452354    0.455909    0.088855    0.017415    0.631192    
#> 356: 0.568615    0.960716    3.452427    0.455490    0.088797    0.017425    0.631261    
#> 357: 0.568669    0.960668    3.452480    0.455269    0.088796    0.017436    0.631239    
#> 358: 0.568477    0.960733    3.452510    0.454909    0.088706    0.017428    0.631183    
#> 359: 0.568325    0.960809    3.452469    0.454789    0.088629    0.017436    0.631120    
#> 360: 0.568264    0.960858    3.452341    0.454504    0.088510    0.017427    0.631056    
#> 361: 0.568335    0.960905    3.452329    0.454570    0.088556    0.017442    0.630943    
#> 362: 0.568410    0.960853    3.452338    0.454230    0.088571    0.017435    0.630831    
#> 363: 0.568468    0.960832    3.452332    0.454207    0.088531    0.017426    0.630687    
#> 364: 0.568463    0.960861    3.452305    0.454335    0.088459    0.017428    0.630621    
#> 365: 0.568333    0.960811    3.452302    0.454320    0.088449    0.017416    0.630577    
#> 366: 0.568101    0.960880    3.452210    0.453972    0.088411    0.017411    0.630664    
#> 367: 0.568082    0.960921    3.452197    0.453604    0.088414    0.017406    0.630650    
#> 368: 0.568039    0.960900    3.452170    0.453504    0.088464    0.017404    0.630572    
#> 369: 0.567940    0.960958    3.452135    0.453678    0.088442    0.017396    0.630587    
#> 370: 0.567742    0.961081    3.452052    0.453573    0.088500    0.017367    0.630567    
#> 371: 0.567572    0.961139    3.452000    0.453225    0.088560    0.017358    0.630547    
#> 372: 0.567277    0.961224    3.451923    0.453063    0.088584    0.017343    0.630529    
#> 373: 0.566957    0.961405    3.451811    0.452981    0.088537    0.017350    0.630517    
#> 374: 0.566806    0.961518    3.451730    0.453032    0.088513    0.017373    0.630457    
#> 375: 0.566627    0.961605    3.451647    0.453167    0.088451    0.017402    0.630432    
#> 376: 0.566344    0.961723    3.451550    0.453198    0.088478    0.017426    0.630386    
#> 377: 0.566143    0.961876    3.451483    0.452874    0.088475    0.017433    0.630343    
#> 378: 0.566123    0.961971    3.451445    0.452693    0.088488    0.017428    0.630437    
#> 379: 0.565988    0.961893    3.451430    0.452637    0.088516    0.017428    0.630394    
#> 380: 0.565956    0.961707    3.451460    0.452806    0.088480    0.017420    0.630390    
#> 381: 0.565756    0.961668    3.451416    0.452736    0.088504    0.017432    0.630320    
#> 382: 0.565571    0.961770    3.451333    0.452944    0.088403    0.017441    0.630198    
#> 383: 0.565429    0.961862    3.451228    0.453398    0.088375    0.017440    0.630086    
#> 384: 0.564967    0.961923    3.451147    0.453365    0.088378    0.017428    0.630131    
#> 385: 0.564837    0.962031    3.451072    0.453500    0.088392    0.017432    0.630046    
#> 386: 0.564940    0.962148    3.451059    0.453793    0.088433    0.017447    0.629998    
#> 387: 0.565040    0.962316    3.451041    0.454061    0.088412    0.017450    0.629982    
#> 388: 0.565236    0.962258    3.451081    0.454396    0.088525    0.017464    0.629892    
#> 389: 0.565287    0.962113    3.451064    0.454359    0.088564    0.017456    0.629897    
#> 390: 0.565091    0.962149    3.451003    0.453962    0.088634    0.017437    0.629908    
#> 391: 0.565144    0.962154    3.450959    0.453742    0.088674    0.017421    0.629888    
#> 392: 0.565081    0.962152    3.450978    0.453921    0.088794    0.017406    0.629857    
#> 393: 0.565116    0.962064    3.450916    0.454314    0.088892    0.017399    0.629791    
#> 394: 0.565070    0.962080    3.450856    0.454683    0.088917    0.017388    0.629748    
#> 395: 0.565127    0.962174    3.450837    0.455150    0.088978    0.017384    0.629761    
#> 396: 0.565284    0.962246    3.450844    0.455817    0.088998    0.017392    0.629729    
#> 397: 0.565555    0.962183    3.450900    0.456093    0.088980    0.017402    0.629787    
#> 398: 0.565792    0.962047    3.450980    0.456109    0.088923    0.017408    0.629887    
#> 399: 0.566144    0.961959    3.451087    0.456808    0.088846    0.017421    0.629897    
#> 400: 0.566163    0.961887    3.451154    0.456665    0.088830    0.017426    0.629895    
#> 401: 0.566138    0.961925    3.451133    0.456552    0.088753    0.017431    0.629957    
#> 402: 0.566182    0.961968    3.451114    0.456550    0.088674    0.017443    0.629988    
#> 403: 0.566250    0.962001    3.451078    0.456523    0.088624    0.017435    0.629988    
#> 404: 0.566310    0.962075    3.451002    0.456478    0.088628    0.017424    0.629955    
#> 405: 0.566276    0.962170    3.451025    0.456064    0.088580    0.017424    0.629948    
#> 406: 0.566176    0.962212    3.450985    0.455704    0.088613    0.017411    0.629965    
#> 407: 0.566224    0.962177    3.451011    0.455632    0.088617    0.017391    0.630054    
#> 408: 0.566282    0.962148    3.451022    0.455323    0.088616    0.017371    0.630110    
#> 409: 0.566202    0.962147    3.451023    0.455197    0.088656    0.017352    0.630020    
#> 410: 0.566093    0.962200    3.450961    0.455142    0.088668    0.017342    0.630030    
#> 411: 0.566004    0.962136    3.450924    0.455184    0.088671    0.017327    0.630046    
#> 412: 0.565917    0.962169    3.450923    0.454759    0.088650    0.017313    0.630082    
#> 413: 0.565912    0.962152    3.450929    0.454379    0.088642    0.017317    0.630150    
#> 414: 0.565732    0.962138    3.450961    0.454306    0.088698    0.017304    0.630150    
#> 415: 0.565920    0.962018    3.450977    0.454536    0.088755    0.017294    0.630073    
#> 416: 0.566038    0.962017    3.451022    0.454519    0.088815    0.017295    0.630034    
#> 417: 0.566069    0.962016    3.451010    0.454905    0.088808    0.017291    0.629999    
#> 418: 0.565901    0.961997    3.451045    0.454564    0.088781    0.017285    0.629935    
#> 419: 0.565868    0.962096    3.451042    0.454671    0.088749    0.017297    0.629888    
#> 420: 0.565837    0.962129    3.451049    0.454607    0.088722    0.017307    0.629835    
#> 421: 0.565633    0.962217    3.451025    0.454444    0.088732    0.017309    0.629829    
#> 422: 0.565897    0.962184    3.451065    0.454948    0.088660    0.017322    0.629844    
#> 423: 0.566125    0.962047    3.451135    0.455081    0.088658    0.017313    0.629850    
#> 424: 0.566183    0.961932    3.451131    0.454910    0.088641    0.017312    0.629838    
#> 425: 0.566137    0.961988    3.451115    0.454896    0.088686    0.017309    0.629895    
#> 426: 0.566190    0.962123    3.451096    0.454965    0.088706    0.017311    0.629901    
#> 427: 0.566212    0.962138    3.451105    0.454987    0.088718    0.017318    0.629887    
#> 428: 0.566105    0.962190    3.451103    0.454837    0.088665    0.017322    0.629916    
#> 429: 0.566054    0.962197    3.451114    0.454712    0.088627    0.017339    0.629885    
#> 430: 0.565883    0.962235    3.451078    0.454589    0.088549    0.017357    0.629894    
#> 431: 0.565731    0.962224    3.451010    0.454582    0.088495    0.017353    0.629845    
#> 432: 0.565594    0.962300    3.450979    0.454646    0.088469    0.017350    0.629793    
#> 433: 0.565507    0.962373    3.450937    0.454694    0.088535    0.017343    0.629695    
#> 434: 0.565368    0.962344    3.450917    0.454549    0.088552    0.017350    0.629662    
#> 435: 0.565374    0.962390    3.450893    0.454481    0.088546    0.017351    0.629690    
#> 436: 0.565395    0.962375    3.450936    0.454494    0.088620    0.017364    0.629701    
#> 437: 0.565467    0.962288    3.450946    0.454430    0.088681    0.017369    0.629678    
#> 438: 0.565419    0.962375    3.450939    0.454304    0.088719    0.017368    0.629672    
#> 439: 0.565444    0.962440    3.450962    0.454245    0.088756    0.017373    0.629576    
#> 440: 0.565565    0.962428    3.451034    0.454030    0.088743    0.017385    0.629587    
#> 441: 0.565796    0.962445    3.451078    0.454167    0.088712    0.017393    0.629501    
#> 442: 0.565855    0.962432    3.451094    0.454200    0.088678    0.017399    0.629420    
#> 443: 0.565915    0.962538    3.451069    0.454302    0.088664    0.017412    0.629337    
#> 444: 0.565816    0.962617    3.451016    0.454252    0.088641    0.017422    0.629323    
#> 445: 0.565653    0.962704    3.450938    0.454532    0.088591    0.017426    0.629303    
#> 446: 0.565487    0.962788    3.450871    0.454686    0.088508    0.017433    0.629265    
#> 447: 0.565443    0.962903    3.450805    0.454904    0.088483    0.017436    0.629288    
#> 448: 0.565276    0.962934    3.450793    0.454854    0.088510    0.017435    0.629203    
#> 449: 0.565283    0.962974    3.450868    0.454701    0.088538    0.017430    0.629181    
#> 450: 0.565167    0.962952    3.450886    0.454473    0.088521    0.017437    0.629219    
#> 451: 0.565141    0.962946    3.450904    0.454400    0.088467    0.017449    0.629218    
#> 452: 0.565196    0.962895    3.450919    0.454347    0.088443    0.017449    0.629200    
#> 453: 0.565314    0.962856    3.450960    0.454270    0.088457    0.017451    0.629133    
#> 454: 0.565370    0.962889    3.450967    0.454190    0.088458    0.017455    0.629110    
#> 455: 0.565547    0.962886    3.451000    0.454381    0.088448    0.017457    0.629131    
#> 456: 0.565486    0.962793    3.450995    0.454508    0.088474    0.017460    0.629109    
#> 457: 0.565595    0.962747    3.451043    0.454755    0.088491    0.017477    0.629041    
#> 458: 0.565581    0.962814    3.451070    0.454696    0.088478    0.017493    0.628964    
#> 459: 0.565485    0.962926    3.451056    0.454732    0.088499    0.017504    0.628952    
#> 460: 0.565396    0.962962    3.450988    0.454723    0.088558    0.017501    0.628953    
#> 461: 0.565298    0.962988    3.451000    0.454620    0.088568    0.017498    0.628937    
#> 462: 0.565265    0.963091    3.451001    0.454572    0.088527    0.017515    0.628967    
#> 463: 0.565350    0.963200    3.451023    0.454490    0.088548    0.017528    0.628944    
#> 464: 0.565425    0.963209    3.451013    0.454378    0.088538    0.017534    0.628883    
#> 465: 0.565465    0.963066    3.451050    0.454351    0.088534    0.017549    0.628846    
#> 466: 0.565458    0.963066    3.451052    0.454284    0.088488    0.017561    0.628822    
#> 467: 0.565456    0.962963    3.451102    0.454344    0.088412    0.017585    0.628739    
#> 468: 0.565681    0.962956    3.451178    0.454474    0.088409    0.017596    0.628773    
#> 469: 0.565887    0.963020    3.451233    0.454662    0.088437    0.017596    0.628776    
#> 470: 0.565801    0.963030    3.451219    0.454592    0.088374    0.017609    0.628763    
#> 471: 0.565702    0.963011    3.451186    0.454665    0.088365    0.017622    0.628716    
#> 472: 0.565611    0.962985    3.451158    0.454743    0.088300    0.017635    0.628699    
#> 473: 0.565527    0.962938    3.451158    0.454614    0.088224    0.017637    0.628676    
#> 474: 0.565413    0.962894    3.451191    0.454374    0.088222    0.017636    0.628758    
#> 475: 0.565383    0.962960    3.451184    0.454127    0.088221    0.017623    0.628763    
#> 476: 0.565419    0.962966    3.451188    0.454156    0.088226    0.017623    0.628808    
#> 477: 0.565459    0.962965    3.451199    0.454246    0.088225    0.017627    0.628790    
#> 478: 0.565443    0.962985    3.451207    0.454362    0.088204    0.017627    0.628848    
#> 479: 0.565599    0.962987    3.451228    0.454773    0.088206    0.017628    0.628852    
#> 480: 0.565701    0.962970    3.451251    0.454818    0.088239    0.017622    0.628898    
#> 481: 0.565830    0.962941    3.451262    0.454752    0.088262    0.017613    0.628891    
#> 482: 0.565930    0.962938    3.451249    0.454710    0.088252    0.017612    0.628883    
#> 483: 0.565818    0.962926    3.451245    0.454849    0.088243    0.017615    0.628864    
#> 484: 0.565813    0.962899    3.451228    0.455087    0.088237    0.017616    0.628831    
#> 485: 0.565807    0.962961    3.451209    0.455326    0.088283    0.017625    0.628843    
#> 486: 0.565849    0.963058    3.451193    0.455486    0.088275    0.017623    0.628786    
#> 487: 0.565963    0.963136    3.451202    0.455524    0.088282    0.017615    0.628759    
#> 488: 0.566048    0.963162    3.451232    0.455826    0.088235    0.017609    0.628759    
#> 489: 0.566245    0.963097    3.451248    0.456241    0.088201    0.017611    0.628825    
#> 490: 0.566413    0.963115    3.451241    0.456563    0.088213    0.017605    0.628791    
#> 491: 0.566487    0.963185    3.451265    0.456581    0.088191    0.017604    0.628790    
#> 492: 0.566486    0.963302    3.451261    0.456485    0.088179    0.017597    0.628804    
#> 493: 0.566487    0.963294    3.451307    0.456089    0.088172    0.017606    0.628811    
#> 494: 0.566604    0.963251    3.451337    0.455827    0.088167    0.017620    0.628817    
#> 495: 0.566827    0.963181    3.451379    0.455947    0.088138    0.017616    0.628822    
#> 496: 0.567016    0.963240    3.451387    0.455912    0.088142    0.017615    0.628865    
#> 497: 0.567162    0.963180    3.451423    0.456026    0.088133    0.017616    0.628910    
#> 498: 0.567316    0.963183    3.451432    0.455912    0.088153    0.017612    0.628893    
#> 499: 0.567373    0.963182    3.451416    0.455762    0.088128    0.017612    0.628854    
#> 500: 0.567416    0.963165    3.451367    0.455845    0.088130    0.017601    0.628826    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.319181    0.973365    3.439890    0.392401    0.073702    0.016800    1.688594    
#> 002: 0.386902    1.067270    3.466183    0.372781    0.070017    0.015960    1.148118    
#> 003: 0.589205    1.048627    3.495071    0.354142    0.066516    0.015162    0.911543    
#> 004: 0.582599    1.073542    3.497081    0.420624    0.063190    0.014404    0.802981    
#> 005: 0.666958    1.119478    3.479010    0.456761    0.060030    0.013684    0.715293    
#> 006: 0.642510    1.109773    3.475337    0.489284    0.057029    0.013000    0.672221    
#> 007: 0.626226    1.129724    3.468254    0.638063    0.054178    0.012539    0.675676    
#> 008: 0.600158    1.121252    3.470229    0.606160    0.051469    0.016702    0.686212    
#> 009: 0.594865    1.115880    3.464457    0.575852    0.048895    0.017280    0.674793    
#> 010: 0.641186    1.100495    3.481573    0.547059    0.046450    0.017499    0.683687    
#> 011: 0.690991    1.098227    3.485779    0.519706    0.044128    0.017319    0.677188    
#> 012: 0.686932    1.109824    3.482470    0.525595    0.041922    0.017513    0.650851    
#> 013: 0.684511    1.104867    3.486943    0.642766    0.039825    0.020165    0.643164    
#> 014: 0.701893    1.104613    3.487922    0.673378    0.037834    0.025170    0.661827    
#> 015: 0.669365    1.119890    3.485655    0.639709    0.035942    0.023911    0.646483    
#> 016: 0.704798    1.117866    3.497997    0.631036    0.034145    0.023574    0.640691    
#> 017: 0.708203    1.117864    3.495060    0.697341    0.032438    0.025026    0.636729    
#> 018: 0.717558    1.127066    3.477775    0.709836    0.030816    0.023775    0.654695    
#> 019: 0.682259    1.117706    3.481073    0.688420    0.029275    0.022586    0.644079    
#> 020: 0.735956    1.110162    3.488608    0.729345    0.027812    0.030236    0.643592    
#> 021: 0.756474    1.096718    3.497641    0.764559    0.026421    0.031837    0.628883    
#> 022: 0.743355    1.088906    3.507208    0.726331    0.025100    0.032236    0.621671    
#> 023: 0.804083    1.094750    3.515106    0.719230    0.023845    0.032709    0.630204    
#> 024: 0.738071    1.116703    3.496698    0.727223    0.022653    0.032910    0.638462    
#> 025: 0.675206    1.105899    3.480178    0.755663    0.023467    0.033778    0.625882    
#> 026: 0.694184    1.136805    3.472586    0.717880    0.022293    0.032089    0.646279    
#> 027: 0.660517    1.139339    3.466211    0.681986    0.021179    0.032152    0.656931    
#> 028: 0.728485    1.122391    3.469085    0.813757    0.020120    0.030544    0.632135    
#> 029: 0.702076    1.133283    3.465646    0.773069    0.019114    0.030782    0.646760    
#> 030: 0.736079    1.144217    3.473224    0.793715    0.018158    0.036926    0.641005    
#> 031: 0.726392    1.118391    3.481948    0.785619    0.017250    0.035534    0.635471    
#> 032: 0.669871    1.119079    3.484891    0.746338    0.017632    0.033758    0.641985    
#> 033: 0.699459    1.140225    3.483474    0.745921    0.019172    0.032070    0.641614    
#> 034: 0.733774    1.146171    3.482907    0.750534    0.018213    0.030466    0.631029    
#> 035: 0.693850    1.126541    3.480471    0.713007    0.019658    0.028943    0.632395    
#> 036: 0.698035    1.110146    3.486242    0.677357    0.020050    0.027496    0.640489    
#> 037: 0.736672    1.110779    3.495496    0.643489    0.023612    0.026121    0.660044    
#> 038: 0.714392    1.110193    3.490194    0.611314    0.026934    0.025400    0.650292    
#> 039: 0.745939    1.109467    3.499812    0.680799    0.025588    0.027538    0.658017    
#> 040: 0.709114    1.111854    3.494652    0.708882    0.024308    0.031119    0.638622    
#> 041: 0.667446    1.100182    3.478689    0.673438    0.023093    0.031255    0.633875    
#> 042: 0.711220    1.107784    3.486409    0.706561    0.021938    0.033047    0.625101    
#> 043: 0.688331    1.117835    3.466068    0.735439    0.020841    0.031394    0.647906    
#> 044: 0.656515    1.130909    3.468925    0.698667    0.019799    0.029923    0.633230    
#> 045: 0.687989    1.139669    3.462276    0.687411    0.018809    0.028426    0.648782    
#> 046: 0.728867    1.126576    3.482786    0.751365    0.017869    0.029020    0.644718    
#> 047: 0.715732    1.133344    3.467016    0.751122    0.020438    0.033799    0.639526    
#> 048: 0.659386    1.128163    3.477611    0.713566    0.021441    0.033605    0.645779    
#> 049: 0.689298    1.117799    3.477306    0.677887    0.021723    0.031925    0.655117    
#> 050: 0.738770    1.098331    3.488081    0.777391    0.020637    0.030329    0.637385    
#> 051: 0.748930    1.108553    3.489417    0.749557    0.021112    0.035216    0.651530    
#> 052: 0.737082    1.103239    3.505667    0.712079    0.020057    0.033455    0.651748    
#> 053: 0.718333    1.076148    3.503870    0.676475    0.020260    0.031782    0.659993    
#> 054: 0.695923    1.091772    3.498256    0.642651    0.025809    0.030193    0.653240    
#> 055: 0.701582    1.112731    3.497122    0.610519    0.026823    0.028952    0.656485    
#> 056: 0.757573    1.105507    3.495579    0.731993    0.025481    0.027505    0.650481    
#> 057: 0.737476    1.112560    3.491992    0.729997    0.027649    0.032061    0.643875    
#> 058: 0.698763    1.116338    3.476817    0.724164    0.026266    0.030458    0.640968    
#> 059: 0.699319    1.094799    3.484650    0.784174    0.026304    0.028935    0.642068    
#> 060: 0.730169    1.089294    3.488322    0.790949    0.026874    0.028910    0.644160    
#> 061: 0.704313    1.088055    3.506536    0.751401    0.025798    0.034879    0.647814    
#> 062: 0.712907    1.099326    3.510235    0.713831    0.031727    0.033676    0.660585    
#> 063: 0.771517    1.090664    3.502782    0.678140    0.030141    0.031992    0.668055    
#> 064: 0.749212    1.091955    3.505780    0.659500    0.028634    0.030393    0.651184    
#> 065: 0.773432    1.082732    3.498269    0.633219    0.027202    0.028873    0.638852    
#> 066: 0.763615    1.087913    3.502099    0.655889    0.025842    0.027430    0.637047    
#> 067: 0.693316    1.089012    3.494007    0.623094    0.024550    0.026058    0.638474    
#> 068: 0.682308    1.106048    3.486861    0.591939    0.024517    0.024755    0.653562    
#> 069: 0.691503    1.115369    3.481141    0.632841    0.023292    0.023517    0.671923    
#> 070: 0.697238    1.119994    3.489214    0.647663    0.030002    0.022342    0.654555    
#> 071: 0.653383    1.146177    3.462950    0.615280    0.028502    0.021224    0.670539    
#> 072: 0.635440    1.126449    3.473392    0.584516    0.027077    0.020163    0.639202    
#> 073: 0.691943    1.128251    3.493379    0.585648    0.025723    0.019922    0.637563    
#> 074: 0.638906    1.119014    3.483820    0.556366    0.024437    0.022665    0.649617    
#> 075: 0.708148    1.101183    3.502112    0.613724    0.025163    0.023917    0.644568    
#> 076: 0.736415    1.105913    3.506516    0.655084    0.023905    0.022721    0.649484    
#> 077: 0.774065    1.089450    3.507890    0.637149    0.022710    0.027071    0.659688    
#> 078: 0.777640    1.091204    3.517098    0.733874    0.021574    0.026697    0.651373    
#> 079: 0.767971    1.092209    3.501062    0.796510    0.020495    0.029803    0.655799    
#> 080: 0.755809    1.090668    3.499491    0.756685    0.023542    0.028313    0.656441    
#> 081: 0.727973    1.096181    3.497062    0.718850    0.022365    0.029246    0.655021    
#> 082: 0.728408    1.094578    3.505833    0.682908    0.021247    0.027784    0.648488    
#> 083: 0.767600    1.091046    3.507840    0.648762    0.020185    0.029591    0.657354    
#> 084: 0.694396    1.102208    3.495568    0.616324    0.019175    0.033164    0.642080    
#> 085: 0.673577    1.098825    3.508154    0.660821    0.018217    0.033751    0.649972    
#> 086: 0.707719    1.086621    3.493037    0.627780    0.017306    0.036744    0.646179    
#> 087: 0.645236    1.097503    3.482654    0.596391    0.016441    0.036980    0.642855    
#> 088: 0.573409    1.095697    3.481647    0.566571    0.015619    0.035131    0.668564    
#> 089: 0.639538    1.104531    3.474505    0.541999    0.014838    0.033374    0.658407    
#> 090: 0.608961    1.106418    3.470005    0.525951    0.016396    0.032610    0.658383    
#> 091: 0.606862    1.101856    3.452413    0.531025    0.015576    0.030979    0.669166    
#> 092: 0.655555    1.117503    3.466686    0.618993    0.014797    0.030370    0.643922    
#> 093: 0.582771    1.119364    3.461180    0.588043    0.015608    0.028851    0.670945    
#> 094: 0.626529    1.122695    3.463836    0.558641    0.015964    0.028658    0.651516    
#> 095: 0.653819    1.131138    3.483145    0.575910    0.015166    0.030304    0.651184    
#> 096: 0.631609    1.137841    3.470000    0.567575    0.014408    0.029716    0.649102    
#> 097: 0.679509    1.129911    3.471584    0.660485    0.013687    0.033257    0.659407    
#> 098: 0.668072    1.130117    3.482419    0.627460    0.013003    0.033509    0.669704    
#> 099: 0.676449    1.122443    3.477081    0.605377    0.012747    0.031834    0.658982    
#> 100: 0.670218    1.117313    3.469843    0.681853    0.013710    0.031827    0.626507    
#> 101: 0.662486    1.109567    3.469093    0.647761    0.013024    0.036023    0.626685    
#> 102: 0.636945    1.109762    3.471121    0.615373    0.012373    0.034222    0.643376    
#> 103: 0.650413    1.106776    3.481200    0.632013    0.011754    0.032511    0.644946    
#> 104: 0.645093    1.111536    3.488070    0.600412    0.012659    0.030886    0.658459    
#> 105: 0.680878    1.119265    3.478108    0.621802    0.016198    0.029341    0.669028    
#> 106: 0.719605    1.115226    3.487104    0.657037    0.015388    0.027874    0.660488    
#> 107: 0.758362    1.121435    3.493042    0.679759    0.016173    0.026481    0.656881    
#> 108: 0.706400    1.122332    3.488958    0.669728    0.021131    0.025933    0.654386    
#> 109: 0.701681    1.106412    3.505729    0.636241    0.022971    0.025407    0.654166    
#> 110: 0.700353    1.109549    3.477791    0.634829    0.021850    0.024136    0.634555    
#> 111: 0.670792    1.113462    3.484286    0.633149    0.020757    0.025314    0.626921    
#> 112: 0.656411    1.097140    3.474046    0.601491    0.025667    0.024048    0.633592    
#> 113: 0.669028    1.122163    3.475402    0.591372    0.024384    0.022846    0.624517    
#> 114: 0.732574    1.126594    3.482450    0.756733    0.026877    0.021704    0.629438    
#> 115: 0.818854    1.110728    3.480178    0.912641    0.027634    0.020618    0.645614    
#> 116: 0.816870    1.113350    3.486416    0.929518    0.026374    0.021696    0.652568    
#> 117: 0.743249    1.136149    3.496651    0.883042    0.025055    0.024904    0.649997    
#> 118: 0.774813    1.120437    3.492887    0.864858    0.023803    0.023726    0.647555    
#> 119: 0.717662    1.122847    3.485497    0.821615    0.022613    0.023681    0.667407    
#> 120: 0.660218    1.119111    3.485156    0.780534    0.021482    0.026514    0.649132    
#> 121: 0.689841    1.136603    3.478454    0.741507    0.020408    0.031606    0.656329    
#> 122: 0.698774    1.111774    3.494947    0.704432    0.022387    0.032705    0.654635    
#> 123: 0.726555    1.126566    3.485965    0.669210    0.021268    0.031667    0.638008    
#> 124: 0.720469    1.129664    3.483474    0.678065    0.020204    0.030084    0.646149    
#> 125: 0.746277    1.135078    3.467607    0.828851    0.019194    0.031608    0.635840    
#> 126: 0.734251    1.137556    3.476195    0.821734    0.018235    0.031021    0.636184    
#> 127: 0.792264    1.130163    3.470969    0.918576    0.021060    0.029470    0.639256    
#> 128: 0.761460    1.126994    3.494402    0.925556    0.023393    0.027997    0.648943    
#> 129: 0.746544    1.115828    3.497002    0.879278    0.022223    0.028773    0.651992    
#> 130: 0.749714    1.132197    3.486413    0.835314    0.021112    0.032388    0.643962    
#> 131: 0.729674    1.118472    3.478085    0.793548    0.020056    0.030769    0.642439    
#> 132: 0.676139    1.114847    3.474879    0.753871    0.019723    0.029230    0.650255    
#> 133: 0.727670    1.119517    3.479539    0.779323    0.022723    0.027769    0.653569    
#> 134: 0.729994    1.106347    3.496049    0.779172    0.021587    0.026380    0.635222    
#> 135: 0.748965    1.103583    3.501675    0.740214    0.024146    0.025061    0.647742    
#> 136: 0.728537    1.096370    3.498581    0.721646    0.024113    0.023808    0.630411    
#> 137: 0.783996    1.093575    3.507733    0.749465    0.022907    0.024893    0.640470    
#> 138: 0.732610    1.086141    3.504667    0.711991    0.021762    0.024346    0.651045    
#> 139: 0.708920    1.107014    3.511559    0.676392    0.020819    0.027017    0.647283    
#> 140: 0.757390    1.114183    3.500828    0.683061    0.026599    0.025666    0.661794    
#> 141: 0.783982    1.096368    3.505881    0.771811    0.027075    0.024383    0.642612    
#> 142: 0.802801    1.084847    3.514660    0.858124    0.025721    0.024814    0.661210    
#> 143: 0.775290    1.087031    3.513419    0.815217    0.024435    0.029384    0.667215    
#> 144: 0.799299    1.087822    3.523101    0.774457    0.023213    0.027915    0.661366    
#> 145: 0.762645    1.100507    3.500372    0.735734    0.022053    0.026519    0.645443    
#> 146: 0.699010    1.107059    3.500850    0.698947    0.020950    0.025193    0.658093    
#> 147: 0.663814    1.093651    3.486587    0.664000    0.019902    0.026395    0.651861    
#> 148: 0.660743    1.115167    3.495477    0.630800    0.018907    0.025075    0.645997    
#> 149: 0.687807    1.103912    3.502288    0.599260    0.019122    0.023821    0.668384    
#> 150: 0.696897    1.101770    3.496115    0.569297    0.023380    0.022630    0.661502    
#> 151: 0.676429    1.117905    3.483782    0.577449    0.022211    0.022914    0.648855    
#> 152: 0.634993    1.122869    3.475786    0.662115    0.019322    0.025515    0.649434    
#> 153: 0.644423    1.129637    3.488562    0.553010    0.021132    0.028401    0.659641    
#> 154: 0.656478    1.146192    3.476044    0.539177    0.023828    0.027217    0.641296    
#> 155: 0.656791    1.119523    3.476845    0.539063    0.023591    0.024946    0.642347    
#> 156: 0.682464    1.125292    3.490795    0.547152    0.026049    0.022807    0.655417    
#> 157: 0.728761    1.117746    3.494898    0.682356    0.033004    0.019244    0.654978    
#> 158: 0.727441    1.131321    3.484266    0.708105    0.028850    0.020573    0.647917    
#> 159: 0.683958    1.127652    3.492572    0.561146    0.025042    0.019934    0.647658    
#> 160: 0.743929    1.105602    3.505452    0.649194    0.026032    0.021659    0.654774    
#> 161: 0.705145    1.115742    3.494420    0.667434    0.025373    0.020507    0.662168    
#> 162: 0.679844    1.139237    3.484690    0.611973    0.022986    0.023318    0.659095    
#> 163: 0.642475    1.132399    3.471840    0.541257    0.025015    0.021538    0.652736    
#> 164: 0.673584    1.131993    3.478847    0.605427    0.023142    0.028059    0.630663    
#> 165: 0.672620    1.118829    3.475762    0.709358    0.019166    0.028076    0.636320    
#> 166: 0.684393    1.144186    3.482016    0.649597    0.024887    0.018725    0.640960    
#> 167: 0.738831    1.143770    3.495639    0.781827    0.027019    0.018373    0.658382    
#> 168: 0.720891    1.152899    3.485612    0.731382    0.032952    0.019194    0.629072    
#> 169: 0.707236    1.159725    3.482893    0.679748    0.033557    0.020413    0.633497    
#> 170: 0.706546    1.131707    3.492390    0.679237    0.030642    0.024309    0.633555    
#> 171: 0.642390    1.136144    3.476186    0.527846    0.025324    0.022094    0.631060    
#> 172: 0.625252    1.139565    3.478495    0.509621    0.023459    0.021381    0.644761    
#> 173: 0.658143    1.137705    3.474461    0.569442    0.026907    0.022649    0.641658    
#> 174: 0.691102    1.142395    3.483588    0.545768    0.024565    0.022406    0.625381    
#> 175: 0.667693    1.139308    3.471957    0.565250    0.024448    0.020323    0.637137    
#> 176: 0.667536    1.137177    3.490535    0.464268    0.025310    0.018651    0.644337    
#> 177: 0.660672    1.125271    3.500944    0.497552    0.024426    0.020840    0.649724    
#> 178: 0.735879    1.112923    3.499077    0.544548    0.023364    0.025026    0.641666    
#> 179: 0.776110    1.124258    3.500304    0.722510    0.026542    0.023313    0.644634    
#> 180: 0.703192    1.118727    3.497668    0.517979    0.023679    0.023141    0.652409    
#> 181: 0.693206    1.095010    3.478903    0.573080    0.020753    0.021089    0.646675    
#> 182: 0.653814    1.092193    3.474601    0.567294    0.026933    0.021718    0.659257    
#> 183: 0.683508    1.113017    3.475473    0.628779    0.025002    0.021582    0.656447    
#> 184: 0.694476    1.101864    3.485257    0.615918    0.023553    0.024987    0.638328    
#> 185: 0.705157    1.122349    3.487003    0.639432    0.024733    0.025156    0.642463    
#> 186: 0.718970    1.136778    3.486986    0.721752    0.027051    0.025892    0.652952    
#> 187: 0.717555    1.113762    3.490819    0.614168    0.025345    0.021735    0.648647    
#> 188: 0.646706    1.140789    3.482478    0.501947    0.029314    0.023181    0.666761    
#> 189: 0.648691    1.147643    3.480864    0.525399    0.034286    0.021796    0.648719    
#> 190: 0.659014    1.144330    3.473553    0.585752    0.026435    0.025007    0.627817    
#> 191: 0.668942    1.148804    3.474037    0.647053    0.021820    0.023545    0.635279    
#> 192: 0.682179    1.141952    3.473533    0.638479    0.019726    0.020159    0.643288    
#> 193: 0.713856    1.140293    3.483591    0.646746    0.016810    0.020488    0.654593    
#> 194: 0.655761    1.128077    3.466649    0.630415    0.025840    0.020082    0.660472    
#> 195: 0.615478    1.130367    3.464193    0.572240    0.028126    0.018673    0.660255    
#> 196: 0.650866    1.124690    3.476870    0.587705    0.030668    0.018742    0.661972    
#> 197: 0.673567    1.129484    3.491205    0.583223    0.024874    0.022753    0.653017    
#> 198: 0.717809    1.114106    3.493766    0.651060    0.025817    0.023730    0.640116    
#> 199: 0.690791    1.112182    3.489808    0.566175    0.023101    0.027833    0.648746    
#> 200: 0.707017    1.112500    3.487174    0.633795    0.028153    0.022609    0.645520    
#> 201: 0.711205    1.108643    3.497317    0.643497    0.025234    0.024275    0.641023    
#> 202: 0.710720    1.106291    3.498140    0.629782    0.022957    0.025683    0.639470    
#> 203: 0.723669    1.104724    3.495033    0.645407    0.020857    0.026654    0.643516    
#> 204: 0.728516    1.100866    3.497205    0.677687    0.020509    0.026884    0.644786    
#> 205: 0.732234    1.103207    3.496707    0.690237    0.020273    0.027069    0.647741    
#> 206: 0.728994    1.107236    3.496725    0.689726    0.020364    0.026810    0.646618    
#> 207: 0.733883    1.109049    3.494596    0.720801    0.020456    0.026507    0.645108    
#> 208: 0.732130    1.109496    3.493572    0.709738    0.019918    0.025959    0.643916    
#> 209: 0.729676    1.107190    3.493187    0.703820    0.019545    0.025685    0.644937    
#> 210: 0.731797    1.106127    3.495013    0.697669    0.019138    0.025770    0.645608    
#> 211: 0.733839    1.106309    3.495878    0.693162    0.019001    0.025727    0.644210    
#> 212: 0.736114    1.106121    3.496153    0.687620    0.018688    0.026061    0.644450    
#> 213: 0.736152    1.103857    3.496412    0.682434    0.018480    0.026234    0.645487    
#> 214: 0.734512    1.103334    3.496343    0.673521    0.018157    0.026557    0.646230    
#> 215: 0.732922    1.102844    3.496696    0.665777    0.017891    0.026584    0.647133    
#> 216: 0.733882    1.101775    3.497373    0.660933    0.018060    0.026300    0.648061    
#> 217: 0.732560    1.101850    3.497851    0.656087    0.017937    0.026317    0.647441    
#> 218: 0.730750    1.101995    3.497774    0.649403    0.018025    0.026643    0.647493    
#> 219: 0.728097    1.101723    3.497135    0.646950    0.018095    0.026569    0.647815    
#> 220: 0.724981    1.102000    3.496628    0.647203    0.018031    0.026344    0.648763    
#> 221: 0.723706    1.101464    3.496759    0.645899    0.018056    0.026140    0.648061    
#> 222: 0.723448    1.101300    3.496643    0.644700    0.018069    0.026186    0.647561    
#> 223: 0.723533    1.101054    3.496455    0.644459    0.018068    0.026454    0.647152    
#> 224: 0.723178    1.101568    3.496338    0.644416    0.018063    0.026626    0.646378    
#> 225: 0.722395    1.100647    3.496732    0.643200    0.017959    0.026648    0.646375    
#> 226: 0.721916    1.099992    3.496712    0.641236    0.017921    0.026653    0.646413    
#> 227: 0.722185    1.099881    3.496994    0.642275    0.018042    0.026624    0.646173    
#> 228: 0.720410    1.100538    3.496268    0.641190    0.018155    0.026614    0.646207    
#> 229: 0.717965    1.101026    3.495603    0.640018    0.018178    0.026628    0.646135    
#> 230: 0.716546    1.101372    3.495000    0.637722    0.018247    0.026453    0.646017    
#> 231: 0.715294    1.101414    3.494868    0.636602    0.018309    0.026349    0.645885    
#> 232: 0.713581    1.101229    3.494759    0.633082    0.018393    0.026260    0.645791    
#> 233: 0.712537    1.100870    3.494716    0.632007    0.018566    0.026192    0.645485    
#> 234: 0.712069    1.101189    3.494245    0.631874    0.018739    0.026120    0.645085    
#> 235: 0.710473    1.101124    3.493773    0.628867    0.018828    0.025922    0.644917    
#> 236: 0.709927    1.101372    3.493557    0.627563    0.018969    0.025768    0.645033    
#> 237: 0.710265    1.101473    3.493485    0.626071    0.019040    0.025735    0.645002    
#> 238: 0.711346    1.101349    3.493602    0.627428    0.019239    0.025584    0.645277    
#> 239: 0.711002    1.102232    3.493370    0.627513    0.019366    0.025523    0.645353    
#> 240: 0.711382    1.102374    3.493276    0.630123    0.019593    0.025492    0.645133    
#> 241: 0.711193    1.102210    3.493080    0.632299    0.019781    0.025431    0.645348    
#> 242: 0.711317    1.102173    3.492665    0.632925    0.020188    0.025425    0.645396    
#> 243: 0.710021    1.102247    3.492762    0.630649    0.020489    0.025368    0.646078    
#> 244: 0.709352    1.101878    3.492905    0.628106    0.020614    0.025377    0.646608    
#> 245: 0.709138    1.101587    3.493191    0.626023    0.020608    0.025398    0.647226    
#> 246: 0.709368    1.101399    3.493357    0.624348    0.020470    0.025445    0.647567    
#> 247: 0.709209    1.101122    3.493556    0.623405    0.020342    0.025451    0.647532    
#> 248: 0.708487    1.101352    3.493443    0.621355    0.020244    0.025419    0.647489    
#> 249: 0.708947    1.101501    3.493538    0.622367    0.020248    0.025435    0.647554    
#> 250: 0.709064    1.101741    3.493703    0.620964    0.020327    0.025552    0.647286    
#> 251: 0.709303    1.101957    3.493816    0.620295    0.020415    0.025589    0.647010    
#> 252: 0.709122    1.102227    3.494208    0.618242    0.020573    0.025602    0.646996    
#> 253: 0.708848    1.102521    3.494296    0.617093    0.020627    0.025703    0.646914    
#> 254: 0.708842    1.103123    3.494334    0.617536    0.020687    0.025710    0.646797    
#> 255: 0.708964    1.103496    3.494258    0.618945    0.020701    0.025749    0.646562    
#> 256: 0.709410    1.103478    3.494271    0.620495    0.020711    0.025726    0.646540    
#> 257: 0.709526    1.103408    3.494140    0.621382    0.020676    0.025627    0.646612    
#> 258: 0.709505    1.103066    3.494067    0.620433    0.020651    0.025609    0.646651    
#> 259: 0.709883    1.102940    3.494155    0.622257    0.020595    0.025574    0.647083    
#> 260: 0.710203    1.102871    3.494252    0.621650    0.020538    0.025503    0.647220    
#> 261: 0.710531    1.102749    3.494327    0.620620    0.020491    0.025498    0.647253    
#> 262: 0.711069    1.102723    3.494492    0.620431    0.020483    0.025492    0.647351    
#> 263: 0.711521    1.102791    3.494747    0.620155    0.020457    0.025484    0.647308    
#> 264: 0.711573    1.102661    3.494778    0.620659    0.020379    0.025506    0.647219    
#> 265: 0.711277    1.102803    3.494721    0.620542    0.020422    0.025516    0.647376    
#> 266: 0.711728    1.103097    3.494813    0.620938    0.020451    0.025491    0.647366    
#> 267: 0.711864    1.103392    3.494929    0.621639    0.020596    0.025489    0.647319    
#> 268: 0.712094    1.103310    3.494932    0.622187    0.020636    0.025439    0.647281    
#> 269: 0.713140    1.103110    3.495103    0.623612    0.020610    0.025450    0.647280    
#> 270: 0.713894    1.103085    3.495121    0.623547    0.020566    0.025419    0.647339    
#> 271: 0.713987    1.103126    3.495140    0.624172    0.020549    0.025458    0.647386    
#> 272: 0.714285    1.103036    3.495190    0.624580    0.020527    0.025478    0.647712    
#> 273: 0.713826    1.103327    3.495072    0.624414    0.020532    0.025485    0.647884    
#> 274: 0.713756    1.103639    3.495114    0.622842    0.020500    0.025437    0.647914    
#> 275: 0.713788    1.103825    3.495068    0.622263    0.020452    0.025459    0.647900    
#> 276: 0.713640    1.103811    3.495146    0.622895    0.020481    0.025494    0.647825    
#> 277: 0.713267    1.103766    3.495306    0.622906    0.020466    0.025510    0.647921    
#> 278: 0.713343    1.103925    3.495409    0.623430    0.020509    0.025486    0.648047    
#> 279: 0.713031    1.103863    3.495608    0.622616    0.020521    0.025510    0.648170    
#> 280: 0.712929    1.103882    3.495773    0.622237    0.020496    0.025518    0.648057    
#> 281: 0.712699    1.103927    3.495911    0.621578    0.020420    0.025533    0.648030    
#> 282: 0.712330    1.104244    3.495902    0.620864    0.020386    0.025509    0.648012    
#> 283: 0.712407    1.104435    3.495877    0.620756    0.020296    0.025550    0.648246    
#> 284: 0.712458    1.104379    3.495914    0.621552    0.020215    0.025582    0.648096    
#> 285: 0.712076    1.104324    3.495681    0.622043    0.020159    0.025570    0.648205    
#> 286: 0.711760    1.104431    3.495504    0.621448    0.020114    0.025562    0.648274    
#> 287: 0.711130    1.104592    3.495279    0.621674    0.020088    0.025527    0.648493    
#> 288: 0.710999    1.104735    3.495138    0.621409    0.020092    0.025511    0.648642    
#> 289: 0.711020    1.104832    3.495016    0.621521    0.020033    0.025515    0.648647    
#> 290: 0.710815    1.104853    3.495034    0.621251    0.019970    0.025523    0.648822    
#> 291: 0.710438    1.105124    3.495005    0.620520    0.019966    0.025532    0.648761    
#> 292: 0.710143    1.105173    3.494953    0.620061    0.019943    0.025531    0.648639    
#> 293: 0.709912    1.105183    3.494888    0.619546    0.019892    0.025559    0.648694    
#> 294: 0.709821    1.105126    3.494738    0.619341    0.019854    0.025573    0.648722    
#> 295: 0.709557    1.104873    3.494613    0.619128    0.019819    0.025611    0.648850    
#> 296: 0.709293    1.104731    3.494517    0.618860    0.019808    0.025684    0.648991    
#> 297: 0.709321    1.104762    3.494483    0.618466    0.019762    0.025726    0.649198    
#> 298: 0.709746    1.104700    3.494504    0.619431    0.019709    0.025736    0.649278    
#> 299: 0.709661    1.104683    3.494487    0.619466    0.019686    0.025733    0.649305    
#> 300: 0.709807    1.104514    3.494534    0.619437    0.019668    0.025717    0.649446    
#> 301: 0.709667    1.104334    3.494425    0.618706    0.019689    0.025697    0.649663    
#> 302: 0.709343    1.104344    3.494406    0.617802    0.019713    0.025696    0.649580    
#> 303: 0.708975    1.104459    3.494295    0.617119    0.019696    0.025735    0.649480    
#> 304: 0.708742    1.104676    3.494165    0.617417    0.019655    0.025802    0.649388    
#> 305: 0.708546    1.104650    3.494003    0.618373    0.019639    0.025853    0.649297    
#> 306: 0.708269    1.104635    3.493802    0.618775    0.019638    0.025897    0.649243    
#> 307: 0.707938    1.104611    3.493621    0.619061    0.019651    0.025881    0.649299    
#> 308: 0.707495    1.104634    3.493515    0.619148    0.019740    0.025896    0.649409    
#> 309: 0.707329    1.104531    3.493476    0.619614    0.019746    0.025905    0.649664    
#> 310: 0.707719    1.104375    3.493365    0.620061    0.019784    0.025930    0.649746    
#> 311: 0.708195    1.104271    3.493387    0.620820    0.019780    0.025945    0.649771    
#> 312: 0.707680    1.104259    3.493293    0.619977    0.019794    0.025925    0.649833    
#> 313: 0.707044    1.104102    3.493108    0.618989    0.019825    0.025918    0.649961    
#> 314: 0.706420    1.104128    3.492921    0.618945    0.019834    0.025890    0.650030    
#> 315: 0.705777    1.104133    3.492770    0.618579    0.019822    0.025876    0.650042    
#> 316: 0.705605    1.104090    3.492672    0.618677    0.019820    0.025843    0.649957    
#> 317: 0.705764    1.104090    3.492744    0.618314    0.019838    0.025824    0.650035    
#> 318: 0.705573    1.104178    3.492622    0.617497    0.019800    0.025841    0.649964    
#> 319: 0.705404    1.104197    3.492634    0.617850    0.019778    0.025843    0.650126    
#> 320: 0.705028    1.104219    3.492556    0.618084    0.019766    0.025844    0.650255    
#> 321: 0.704431    1.104366    3.492315    0.617802    0.019754    0.025828    0.650419    
#> 322: 0.703639    1.104504    3.492143    0.616361    0.019765    0.025817    0.650502    
#> 323: 0.702926    1.104634    3.491983    0.615823    0.019753    0.025822    0.650591    
#> 324: 0.702482    1.104729    3.491935    0.615300    0.019774    0.025820    0.650649    
#> 325: 0.702269    1.104923    3.491830    0.615186    0.019774    0.025832    0.650609    
#> 326: 0.702144    1.104897    3.491683    0.615305    0.019828    0.025849    0.650521    
#> 327: 0.702014    1.104879    3.491658    0.615263    0.019862    0.025853    0.650419    
#> 328: 0.702109    1.104866    3.491710    0.615135    0.019878    0.025843    0.650374    
#> 329: 0.702499    1.104831    3.491836    0.615664    0.019886    0.025876    0.650400    
#> 330: 0.702158    1.104797    3.491891    0.615206    0.019867    0.025881    0.650434    
#> 331: 0.702391    1.104929    3.491878    0.615913    0.019851    0.025870    0.650345    
#> 332: 0.702324    1.105017    3.491869    0.616479    0.019805    0.025882    0.650289    
#> 333: 0.702183    1.105040    3.491720    0.616709    0.019758    0.025902    0.650378    
#> 334: 0.701789    1.105037    3.491493    0.616115    0.019714    0.025921    0.650480    
#> 335: 0.701501    1.105117    3.491349    0.615639    0.019717    0.025925    0.650453    
#> 336: 0.701111    1.105262    3.491306    0.614848    0.019744    0.025911    0.650520    
#> 337: 0.700809    1.105453    3.491233    0.614806    0.019738    0.025909    0.650522    
#> 338: 0.700363    1.105637    3.491247    0.614080    0.019735    0.025918    0.650540    
#> 339: 0.699896    1.105777    3.491116    0.613578    0.019709    0.025948    0.650589    
#> 340: 0.699587    1.105736    3.491087    0.612932    0.019740    0.025970    0.650496    
#> 341: 0.699527    1.105707    3.491086    0.612078    0.019740    0.025989    0.650402    
#> 342: 0.699333    1.105637    3.491089    0.611430    0.019736    0.026011    0.650356    
#> 343: 0.699213    1.105610    3.491118    0.611271    0.019753    0.025983    0.650332    
#> 344: 0.699500    1.105573    3.491139    0.612097    0.019761    0.025970    0.650299    
#> 345: 0.699502    1.105579    3.491151    0.612716    0.019743    0.025992    0.650254    
#> 346: 0.699426    1.105735    3.491073    0.612741    0.019730    0.025998    0.650144    
#> 347: 0.699350    1.105667    3.491036    0.612542    0.019756    0.026042    0.650084    
#> 348: 0.699213    1.105715    3.491048    0.612467    0.019787    0.026077    0.649977    
#> 349: 0.699127    1.105641    3.491000    0.612380    0.019787    0.026066    0.649915    
#> 350: 0.698811    1.105496    3.490951    0.612200    0.019763    0.026042    0.649975    
#> 351: 0.698994    1.105530    3.490916    0.612129    0.019760    0.026012    0.649969    
#> 352: 0.698986    1.105617    3.490939    0.611676    0.019774    0.026023    0.649977    
#> 353: 0.698980    1.105743    3.490955    0.610979    0.019759    0.026030    0.649967    
#> 354: 0.699036    1.105761    3.490938    0.610291    0.019715    0.026040    0.649948    
#> 355: 0.699409    1.105647    3.490960    0.610225    0.019696    0.026047    0.650014    
#> 356: 0.699364    1.105561    3.490985    0.610238    0.019740    0.026065    0.650038    
#> 357: 0.699649    1.105586    3.490968    0.610915    0.019757    0.026064    0.649938    
#> 358: 0.699577    1.105729    3.491009    0.610494    0.019801    0.026064    0.649836    
#> 359: 0.699601    1.105786    3.491049    0.610177    0.019834    0.026054    0.649764    
#> 360: 0.699411    1.105812    3.490997    0.609481    0.019849    0.026035    0.649699    
#> 361: 0.699333    1.105871    3.490919    0.609132    0.019833    0.026026    0.649614    
#> 362: 0.699377    1.105932    3.490857    0.608907    0.019819    0.026010    0.649564    
#> 363: 0.699450    1.105877    3.490878    0.608933    0.019802    0.026027    0.649462    
#> 364: 0.699421    1.105888    3.490896    0.608227    0.019769    0.026066    0.649551    
#> 365: 0.699232    1.105817    3.490953    0.607476    0.019763    0.026092    0.649699    
#> 366: 0.699223    1.105724    3.490916    0.607428    0.019755    0.026114    0.649748    
#> 367: 0.699057    1.105723    3.490851    0.607084    0.019751    0.026117    0.649726    
#> 368: 0.699133    1.105843    3.490837    0.606616    0.019714    0.026143    0.649672    
#> 369: 0.699070    1.105910    3.490822    0.606522    0.019704    0.026145    0.649670    
#> 370: 0.698845    1.106057    3.490747    0.606202    0.019691    0.026161    0.649680    
#> 371: 0.698572    1.106197    3.490589    0.606271    0.019690    0.026147    0.649660    
#> 372: 0.698277    1.106320    3.490509    0.606283    0.019691    0.026151    0.649606    
#> 373: 0.697832    1.106516    3.490393    0.606301    0.019678    0.026154    0.649642    
#> 374: 0.697536    1.106521    3.490354    0.606040    0.019671    0.026170    0.649617    
#> 375: 0.697473    1.106529    3.490352    0.605987    0.019690    0.026191    0.649680    
#> 376: 0.697466    1.106610    3.490355    0.605614    0.019714    0.026205    0.649640    
#> 377: 0.697250    1.106752    3.490356    0.605529    0.019735    0.026229    0.649645    
#> 378: 0.697149    1.106822    3.490290    0.605827    0.019739    0.026215    0.649554    
#> 379: 0.697198    1.106790    3.490296    0.606059    0.019744    0.026222    0.649526    
#> 380: 0.697014    1.106820    3.490264    0.605508    0.019760    0.026219    0.649530    
#> 381: 0.696877    1.106807    3.490248    0.605214    0.019777    0.026188    0.649435    
#> 382: 0.696884    1.106750    3.490288    0.604978    0.019772    0.026168    0.649321    
#> 383: 0.697021    1.106638    3.490308    0.605101    0.019795    0.026162    0.649185    
#> 384: 0.696900    1.106573    3.490360    0.604756    0.019776    0.026184    0.649165    
#> 385: 0.696936    1.106594    3.490390    0.604741    0.019763    0.026219    0.649171    
#> 386: 0.696930    1.106724    3.490403    0.604562    0.019720    0.026242    0.649240    
#> 387: 0.697102    1.106833    3.490465    0.604732    0.019690    0.026265    0.649198    
#> 388: 0.696982    1.106942    3.490493    0.604849    0.019655    0.026278    0.649166    
#> 389: 0.696705    1.106926    3.490422    0.604712    0.019637    0.026290    0.649115    
#> 390: 0.696293    1.107038    3.490320    0.604416    0.019620    0.026302    0.648989    
#> 391: 0.696066    1.107077    3.490249    0.604099    0.019601    0.026301    0.648929    
#> 392: 0.695842    1.107039    3.490240    0.603594    0.019579    0.026301    0.648970    
#> 393: 0.695819    1.107005    3.490188    0.603577    0.019575    0.026303    0.648977    
#> 394: 0.695940    1.106986    3.490148    0.603857    0.019560    0.026283    0.649032    
#> 395: 0.696144    1.107071    3.490151    0.604019    0.019553    0.026284    0.649056    
#> 396: 0.696231    1.107161    3.490160    0.603846    0.019557    0.026291    0.649106    
#> 397: 0.696387    1.107142    3.490180    0.604078    0.019551    0.026288    0.649171    
#> 398: 0.696585    1.107050    3.490234    0.604435    0.019561    0.026258    0.649252    
#> 399: 0.696645    1.106995    3.490275    0.604737    0.019556    0.026228    0.649318    
#> 400: 0.696734    1.107054    3.490322    0.604520    0.019561    0.026229    0.649288    
#> 401: 0.696815    1.107146    3.490299    0.604871    0.019591    0.026228    0.649272    
#> 402: 0.696761    1.107253    3.490235    0.604761    0.019573    0.026225    0.649234    
#> 403: 0.696877    1.107337    3.490141    0.605225    0.019569    0.026197    0.649232    
#> 404: 0.696767    1.107414    3.490019    0.605560    0.019541    0.026205    0.649164    
#> 405: 0.696591    1.107423    3.489978    0.605907    0.019526    0.026214    0.649120    
#> 406: 0.696542    1.107412    3.489910    0.606089    0.019507    0.026246    0.649096    
#> 407: 0.696513    1.107470    3.489874    0.606262    0.019500    0.026275    0.649015    
#> 408: 0.696457    1.107608    3.489859    0.606513    0.019503    0.026295    0.649002    
#> 409: 0.696388    1.107692    3.489806    0.606638    0.019494    0.026310    0.648875    
#> 410: 0.696310    1.107770    3.489759    0.606658    0.019485    0.026302    0.648774    
#> 411: 0.696238    1.107680    3.489696    0.607033    0.019507    0.026283    0.648711    
#> 412: 0.696078    1.107659    3.489667    0.607063    0.019501    0.026270    0.648674    
#> 413: 0.695987    1.107654    3.489659    0.606929    0.019503    0.026260    0.648677    
#> 414: 0.695943    1.107631    3.489706    0.606790    0.019482    0.026260    0.648659    
#> 415: 0.696221    1.107590    3.489792    0.606468    0.019443    0.026274    0.648602    
#> 416: 0.696507    1.107596    3.489875    0.606697    0.019410    0.026286    0.648503    
#> 417: 0.696448    1.107564    3.489926    0.606207    0.019382    0.026290    0.648502    
#> 418: 0.696356    1.107580    3.489948    0.605951    0.019394    0.026266    0.648434    
#> 419: 0.696358    1.107648    3.489945    0.605790    0.019394    0.026251    0.648418    
#> 420: 0.696408    1.107692    3.489986    0.605551    0.019401    0.026225    0.648384    
#> 421: 0.696413    1.107724    3.490021    0.605326    0.019410    0.026199    0.648385    
#> 422: 0.696561    1.107660    3.490049    0.605204    0.019403    0.026181    0.648409    
#> 423: 0.696488    1.107578    3.490057    0.604775    0.019389    0.026188    0.648495    
#> 424: 0.696231    1.107581    3.490020    0.604276    0.019376    0.026188    0.648564    
#> 425: 0.696123    1.107623    3.489931    0.604015    0.019369    0.026195    0.648682    
#> 426: 0.695922    1.107712    3.489898    0.603659    0.019356    0.026182    0.648696    
#> 427: 0.695694    1.107751    3.489962    0.603091    0.019333    0.026193    0.648631    
#> 428: 0.695535    1.107798    3.489981    0.602839    0.019314    0.026200    0.648663    
#> 429: 0.695419    1.107773    3.490012    0.602395    0.019322    0.026181    0.648701    
#> 430: 0.695480    1.107788    3.490015    0.602705    0.019321    0.026190    0.648709    
#> 431: 0.695588    1.107819    3.490013    0.602826    0.019317    0.026181    0.648610    
#> 432: 0.695530    1.107915    3.490029    0.602355    0.019333    0.026197    0.648575    
#> 433: 0.695431    1.108011    3.490002    0.602122    0.019314    0.026206    0.648532    
#> 434: 0.695303    1.107999    3.489966    0.602201    0.019283    0.026216    0.648534    
#> 435: 0.695311    1.107996    3.489919    0.602084    0.019259    0.026226    0.648481    
#> 436: 0.695343    1.107954    3.489988    0.601990    0.019237    0.026238    0.648491    
#> 437: 0.695387    1.107920    3.489993    0.601966    0.019215    0.026225    0.648495    
#> 438: 0.695326    1.108081    3.489955    0.602058    0.019208    0.026220    0.648483    
#> 439: 0.695223    1.108227    3.489892    0.602258    0.019208    0.026216    0.648412    
#> 440: 0.694946    1.108347    3.489831    0.602142    0.019207    0.026212    0.648363    
#> 441: 0.694879    1.108371    3.489805    0.601931    0.019223    0.026205    0.648306    
#> 442: 0.694797    1.108443    3.489776    0.601942    0.019240    0.026192    0.648257    
#> 443: 0.694734    1.108495    3.489674    0.602037    0.019244    0.026164    0.648246    
#> 444: 0.694618    1.108547    3.489577    0.602183    0.019275    0.026136    0.648234    
#> 445: 0.694490    1.108608    3.489471    0.602397    0.019304    0.026124    0.648264    
#> 446: 0.694260    1.108731    3.489404    0.602424    0.019332    0.026108    0.648313    
#> 447: 0.694089    1.108846    3.489335    0.602258    0.019348    0.026105    0.648329    
#> 448: 0.693866    1.108965    3.489281    0.602219    0.019350    0.026103    0.648312    
#> 449: 0.693803    1.109120    3.489307    0.602265    0.019368    0.026101    0.648317    
#> 450: 0.693566    1.109198    3.489222    0.602150    0.019377    0.026118    0.648295    
#> 451: 0.693522    1.109320    3.489134    0.602496    0.019390    0.026120    0.648307    
#> 452: 0.693594    1.109393    3.489114    0.602957    0.019385    0.026119    0.648252    
#> 453: 0.693368    1.109461    3.489065    0.602661    0.019391    0.026107    0.648203    
#> 454: 0.693197    1.109536    3.489022    0.602540    0.019391    0.026094    0.648128    
#> 455: 0.693172    1.109551    3.488979    0.602851    0.019383    0.026081    0.648110    
#> 456: 0.693162    1.109539    3.488924    0.603328    0.019383    0.026072    0.648133    
#> 457: 0.693170    1.109515    3.488921    0.603503    0.019372    0.026070    0.648093    
#> 458: 0.693133    1.109592    3.488930    0.603428    0.019380    0.026055    0.648044    
#> 459: 0.692926    1.109677    3.488907    0.603293    0.019382    0.026049    0.647967    
#> 460: 0.692673    1.109712    3.488849    0.603077    0.019362    0.026059    0.647984    
#> 461: 0.692478    1.109789    3.488834    0.602889    0.019360    0.026056    0.647956    
#> 462: 0.692417    1.109885    3.488856    0.602982    0.019355    0.026066    0.647952    
#> 463: 0.692453    1.109974    3.488824    0.603350    0.019347    0.026067    0.647969    
#> 464: 0.692536    1.110068    3.488763    0.603659    0.019348    0.026049    0.647911    
#> 465: 0.692496    1.110024    3.488716    0.603641    0.019349    0.026030    0.647854    
#> 466: 0.692473    1.110093    3.488654    0.603653    0.019356    0.026008    0.647819    
#> 467: 0.692454    1.110142    3.488695    0.603736    0.019373    0.025988    0.647714    
#> 468: 0.692795    1.110164    3.488751    0.604305    0.019386    0.025983    0.647678    
#> 469: 0.692946    1.110244    3.488771    0.604596    0.019385    0.025992    0.647692    
#> 470: 0.692822    1.110311    3.488699    0.604793    0.019409    0.026004    0.647674    
#> 471: 0.692667    1.110342    3.488663    0.604941    0.019418    0.026009    0.647678    
#> 472: 0.692664    1.110379    3.488662    0.604915    0.019421    0.026023    0.647690    
#> 473: 0.692543    1.110426    3.488642    0.604717    0.019422    0.026015    0.647676    
#> 474: 0.692377    1.110427    3.488618    0.604617    0.019423    0.026007    0.647743    
#> 475: 0.692442    1.110511    3.488622    0.604444    0.019418    0.026006    0.647744    
#> 476: 0.692417    1.110545    3.488596    0.604202    0.019410    0.026017    0.647725    
#> 477: 0.692398    1.110593    3.488579    0.604319    0.019411    0.026026    0.647644    
#> 478: 0.692313    1.110583    3.488581    0.604186    0.019410    0.026052    0.647641    
#> 479: 0.692376    1.110588    3.488610    0.604134    0.019429    0.026068    0.647586    
#> 480: 0.692399    1.110613    3.488619    0.603955    0.019440    0.026068    0.647602    
#> 481: 0.692291    1.110634    3.488611    0.603710    0.019427    0.026060    0.647621    
#> 482: 0.692253    1.110653    3.488573    0.603652    0.019426    0.026050    0.647663    
#> 483: 0.692060    1.110684    3.488551    0.603481    0.019441    0.026029    0.647743    
#> 484: 0.691947    1.110648    3.488532    0.603276    0.019427    0.026016    0.647766    
#> 485: 0.691934    1.110697    3.488530    0.603427    0.019419    0.026012    0.647764    
#> 486: 0.692073    1.110736    3.488564    0.603513    0.019409    0.026002    0.647780    
#> 487: 0.692193    1.110756    3.488648    0.603141    0.019418    0.026004    0.647763    
#> 488: 0.692358    1.110661    3.488710    0.603058    0.019405    0.025991    0.647713    
#> 489: 0.692540    1.110572    3.488745    0.602913    0.019404    0.025992    0.647663    
#> 490: 0.692727    1.110578    3.488781    0.602999    0.019404    0.026003    0.647600    
#> 491: 0.692999    1.110662    3.488807    0.603565    0.019423    0.026000    0.647541    
#> 492: 0.692935    1.110745    3.488783    0.603572    0.019439    0.025980    0.647526    
#> 493: 0.692793    1.110795    3.488770    0.603569    0.019458    0.025983    0.647476    
#> 494: 0.692891    1.110901    3.488739    0.603640    0.019472    0.025974    0.647412    
#> 495: 0.693042    1.110974    3.488724    0.603658    0.019464    0.025970    0.647391    
#> 496: 0.693077    1.111044    3.488695    0.603628    0.019467    0.025969    0.647391    
#> 497: 0.692950    1.111063    3.488696    0.603579    0.019471    0.025966    0.647429    
#> 498: 0.692944    1.111102    3.488653    0.604114    0.019485    0.025960    0.647390    
#> 499: 0.692938    1.111115    3.488605    0.604248    0.019505    0.025962    0.647357    
#> 500: 0.693029    1.111104    3.488595    0.604575    0.019506    0.025974    0.647328    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.258307    0.981005    3.445346    0.392401    0.083623    0.016800    1.674889    
#> 002: 0.257155    1.043047    3.494866    0.372781    0.079442    0.015960    1.046358    
#> 003: 0.338026    1.049411    3.510040    0.354142    0.075470    0.015162    0.773081    
#> 004: 0.390625    1.092484    3.521936    0.336435    0.074559    0.014404    0.716860    
#> 005: 0.424935    1.086286    3.512258    0.319613    0.070831    0.013684    0.694611    
#> 006: 0.396614    1.091613    3.508082    0.303633    0.067289    0.013000    0.662371    
#> 007: 0.377333    1.113061    3.503328    0.288451    0.063925    0.012350    0.671134    
#> 008: 0.391485    1.100503    3.509852    0.274448    0.060836    0.013735    0.657076    
#> 009: 0.380795    1.094878    3.511723    0.273390    0.057794    0.013891    0.647666    
#> 010: 0.374894    1.079503    3.509232    0.300063    0.054905    0.014217    0.656420    
#> 011: 0.429941    1.090056    3.515861    0.333579    0.060066    0.014586    0.653806    
#> 012: 0.433228    1.083007    3.519052    0.324715    0.057925    0.013856    0.639427    
#> 013: 0.397924    1.100992    3.510616    0.308716    0.064653    0.014994    0.638179    
#> 014: 0.421414    1.106804    3.517642    0.293280    0.061420    0.014783    0.662028    
#> 015: 0.444742    1.103651    3.528697    0.278616    0.058349    0.016612    0.642539    
#> 016: 0.450745    1.112063    3.531069    0.285680    0.055431    0.017250    0.637739    
#> 017: 0.456258    1.111549    3.538763    0.271396    0.052660    0.018708    0.640057    
#> 018: 0.427497    1.114021    3.505231    0.278630    0.050027    0.017773    0.653831    
#> 019: 0.362461    1.120350    3.495661    0.264698    0.049474    0.020084    0.641544    
#> 020: 0.405121    1.110220    3.513431    0.254505    0.056758    0.019080    0.632272    
#> 021: 0.430138    1.092323    3.533894    0.241780    0.053920    0.018126    0.622524    
#> 022: 0.421863    1.089058    3.546764    0.258624    0.056129    0.018236    0.625623    
#> 023: 0.516284    1.094270    3.545392    0.307578    0.053322    0.017324    0.645796    
#> 024: 0.489872    1.102659    3.541891    0.335723    0.050656    0.017291    0.630753    
#> 025: 0.440990    1.092632    3.541373    0.318937    0.048123    0.019673    0.627348    
#> 026: 0.431258    1.115882    3.524795    0.309108    0.056237    0.018689    0.636243    
#> 027: 0.399921    1.117579    3.518768    0.299370    0.053425    0.017755    0.648821    
#> 028: 0.486403    1.100705    3.537140    0.314979    0.050754    0.019619    0.625360    
#> 029: 0.494221    1.097794    3.527704    0.318045    0.054471    0.019363    0.635098    
#> 030: 0.464899    1.099196    3.526468    0.379420    0.051748    0.018395    0.623698    
#> 031: 0.440337    1.092692    3.526886    0.360449    0.051101    0.017646    0.623511    
#> 032: 0.438669    1.082593    3.532825    0.342427    0.051170    0.018358    0.622453    
#> 033: 0.401675    1.113130    3.516707    0.335258    0.057302    0.018189    0.613979    
#> 034: 0.429257    1.126659    3.519958    0.349062    0.066508    0.017280    0.603641    
#> 035: 0.437890    1.089508    3.522444    0.331609    0.065579    0.016416    0.615071    
#> 036: 0.422923    1.106983    3.521183    0.315028    0.062300    0.015595    0.617684    
#> 037: 0.423116    1.113684    3.523117    0.299277    0.064484    0.015095    0.624029    
#> 038: 0.450054    1.100604    3.522687    0.284313    0.061260    0.014497    0.635393    
#> 039: 0.454723    1.111245    3.537737    0.302396    0.058197    0.013772    0.635936    
#> 040: 0.413114    1.096789    3.535785    0.305447    0.055287    0.016738    0.644204    
#> 041: 0.417000    1.084223    3.524344    0.290175    0.052522    0.015901    0.620263    
#> 042: 0.451328    1.098017    3.517176    0.358291    0.049896    0.015106    0.610979    
#> 043: 0.411375    1.122379    3.506331    0.368352    0.052460    0.014350    0.601853    
#> 044: 0.387356    1.128871    3.507167    0.349935    0.049837    0.014446    0.620214    
#> 045: 0.399947    1.142946    3.503871    0.332438    0.056637    0.014207    0.618616    
#> 046: 0.419198    1.118606    3.513270    0.325483    0.057047    0.017806    0.608280    
#> 047: 0.392095    1.111003    3.508709    0.314047    0.056918    0.017406    0.608687    
#> 048: 0.406439    1.121843    3.512444    0.298344    0.054072    0.018341    0.625933    
#> 049: 0.420354    1.114419    3.510407    0.283427    0.054929    0.018991    0.643109    
#> 050: 0.480320    1.078772    3.522465    0.343066    0.052464    0.018147    0.661042    
#> 051: 0.473719    1.091574    3.526346    0.325912    0.062788    0.017239    0.650217    
#> 052: 0.467114    1.108694    3.538813    0.309617    0.061361    0.016377    0.619021    
#> 053: 0.435595    1.099850    3.526603    0.294770    0.058293    0.016035    0.623199    
#> 054: 0.417328    1.106560    3.527185    0.280032    0.068945    0.016792    0.644108    
#> 055: 0.414310    1.105323    3.523435    0.267909    0.070123    0.015952    0.652692    
#> 056: 0.434391    1.090450    3.523949    0.270043    0.066617    0.017542    0.646715    
#> 057: 0.418179    1.091941    3.530596    0.263614    0.063286    0.016665    0.652237    
#> 058: 0.416723    1.107073    3.520378    0.267179    0.060122    0.015832    0.643281    
#> 059: 0.405657    1.068162    3.523738    0.300568    0.057116    0.015040    0.653719    
#> 060: 0.435300    1.066384    3.540555    0.285540    0.063174    0.016301    0.653390    
#> 061: 0.491544    1.070882    3.554918    0.309633    0.060015    0.019540    0.658899    
#> 062: 0.442692    1.098497    3.550539    0.294152    0.077706    0.019055    0.678227    
#> 063: 0.504033    1.060326    3.557793    0.293720    0.073821    0.018323    0.662157    
#> 064: 0.461744    1.070608    3.559671    0.279034    0.070130    0.018918    0.646148    
#> 065: 0.472369    1.063673    3.537390    0.265082    0.066623    0.021980    0.636314    
#> 066: 0.467070    1.085782    3.539361    0.305169    0.063292    0.022797    0.624130    
#> 067: 0.462865    1.081926    3.540711    0.324815    0.060127    0.021657    0.627381    
#> 068: 0.414131    1.095681    3.542698    0.308574    0.057121    0.020574    0.637227    
#> 069: 0.415926    1.101623    3.525727    0.377195    0.054265    0.019545    0.642803    
#> 070: 0.414565    1.098129    3.532258    0.358335    0.056603    0.018568    0.624532    
#> 071: 0.408674    1.127251    3.509179    0.340418    0.055939    0.017640    0.640178    
#> 072: 0.376009    1.114989    3.498055    0.349741    0.053780    0.016758    0.628480    
#> 073: 0.396401    1.135505    3.505200    0.357037    0.059618    0.015920    0.613866    
#> 074: 0.400376    1.109814    3.501678    0.339186    0.056637    0.015124    0.618233    
#> 075: 0.403149    1.108130    3.517999    0.349957    0.058315    0.014911    0.616630    
#> 076: 0.408792    1.107375    3.528569    0.332460    0.055399    0.014722    0.621219    
#> 077: 0.453365    1.087853    3.526728    0.315837    0.060703    0.014551    0.614813    
#> 078: 0.452548    1.094384    3.532548    0.300045    0.061013    0.018141    0.620267    
#> 079: 0.471588    1.110369    3.536944    0.323888    0.064979    0.020516    0.645702    
#> 080: 0.474466    1.107447    3.534195    0.366343    0.066736    0.019490    0.638941    
#> 081: 0.442162    1.112201    3.520102    0.348026    0.063399    0.018515    0.640940    
#> 082: 0.414247    1.104991    3.525095    0.330625    0.062084    0.017589    0.647227    
#> 083: 0.422028    1.132946    3.522566    0.314094    0.058980    0.016710    0.633883    
#> 084: 0.439181    1.118921    3.522806    0.354494    0.056031    0.016616    0.647591    
#> 085: 0.460614    1.120379    3.532800    0.336769    0.053229    0.015785    0.647055    
#> 086: 0.433497    1.124445    3.530575    0.319931    0.050568    0.015039    0.628463    
#> 087: 0.417726    1.116788    3.515639    0.303934    0.048599    0.016844    0.628652    
#> 088: 0.332384    1.108220    3.508849    0.333155    0.055391    0.016825    0.648091    
#> 089: 0.380868    1.138056    3.494132    0.352362    0.062151    0.016801    0.647786    
#> 090: 0.370452    1.137383    3.488700    0.336935    0.066630    0.015961    0.654121    
#> 091: 0.388005    1.130259    3.486686    0.320088    0.071316    0.015844    0.633534    
#> 092: 0.339374    1.142848    3.483213    0.314224    0.067750    0.015989    0.640060    
#> 093: 0.330755    1.129553    3.482994    0.298513    0.064362    0.018241    0.635578    
#> 094: 0.342492    1.143183    3.479614    0.283587    0.061144    0.017329    0.633121    
#> 095: 0.347624    1.146665    3.506181    0.269408    0.058087    0.020441    0.634686    
#> 096: 0.362557    1.120040    3.505654    0.308068    0.055183    0.020895    0.635431    
#> 097: 0.402465    1.140358    3.509829    0.292665    0.052424    0.019850    0.633640    
#> 098: 0.403254    1.147138    3.518267    0.278031    0.049802    0.018858    0.626225    
#> 099: 0.395780    1.121287    3.496496    0.264130    0.047312    0.017915    0.632881    
#> 100: 0.363579    1.127234    3.503230    0.250923    0.049688    0.017019    0.636972    
#> 101: 0.345464    1.129201    3.483987    0.238377    0.047259    0.016168    0.643965    
#> 102: 0.369783    1.123196    3.484853    0.268696    0.046974    0.016675    0.632269    
#> 103: 0.394885    1.131455    3.504337    0.263469    0.055420    0.016260    0.625597    
#> 104: 0.415795    1.112633    3.514500    0.385601    0.066823    0.017833    0.620397    
#> 105: 0.430800    1.101437    3.525425    0.366321    0.068464    0.017472    0.617523    
#> 106: 0.459576    1.086100    3.533861    0.348005    0.065041    0.018625    0.618881    
#> 107: 0.465079    1.091756    3.539570    0.330604    0.061789    0.017693    0.635624    
#> 108: 0.460596    1.084830    3.540901    0.314074    0.058699    0.019975    0.650627    
#> 109: 0.478959    1.097834    3.549344    0.298371    0.055764    0.021012    0.640959    
#> 110: 0.476029    1.089531    3.534126    0.283452    0.060658    0.020429    0.631271    
#> 111: 0.427579    1.091425    3.533938    0.269279    0.057625    0.019408    0.634740    
#> 112: 0.422627    1.074376    3.530192    0.255815    0.072108    0.020203    0.639870    
#> 113: 0.419980    1.106276    3.525823    0.243025    0.074196    0.019193    0.626566    
#> 114: 0.425846    1.092926    3.527121    0.230873    0.070487    0.018233    0.633099    
#> 115: 0.470679    1.070104    3.530364    0.262571    0.066962    0.017321    0.655722    
#> 116: 0.446898    1.098988    3.523306    0.287909    0.063614    0.017756    0.650297    
#> 117: 0.399215    1.120014    3.526525    0.273513    0.060433    0.016868    0.646679    
#> 118: 0.447063    1.107932    3.528788    0.259838    0.057412    0.016024    0.643360    
#> 119: 0.410955    1.108452    3.526477    0.246846    0.062004    0.017049    0.649466    
#> 120: 0.428940    1.090566    3.523874    0.266730    0.059880    0.016196    0.644145    
#> 121: 0.410552    1.122362    3.520777    0.269278    0.061580    0.015387    0.644851    
#> 122: 0.402299    1.100210    3.516770    0.285940    0.058501    0.014617    0.634528    
#> 123: 0.446915    1.122741    3.515576    0.288477    0.059042    0.013886    0.631326    
#> 124: 0.416363    1.144617    3.509516    0.274053    0.056090    0.015384    0.639535    
#> 125: 0.417488    1.144117    3.501318    0.306309    0.055394    0.014615    0.638265    
#> 126: 0.405158    1.146689    3.501899    0.290994    0.052624    0.018411    0.638601    
#> 127: 0.411778    1.120628    3.499834    0.329697    0.053527    0.017490    0.656595    
#> 128: 0.394559    1.117836    3.521396    0.344254    0.068629    0.016616    0.648273    
#> 129: 0.428196    1.122641    3.521236    0.341703    0.085005    0.015785    0.639827    
#> 130: 0.461106    1.121532    3.524703    0.324617    0.089351    0.014996    0.642823    
#> 131: 0.444044    1.081625    3.529978    0.311606    0.084883    0.015004    0.649958    
#> 132: 0.378309    1.115754    3.508668    0.296026    0.080639    0.015361    0.672109    
#> 133: 0.405497    1.093237    3.517048    0.309205    0.076607    0.014593    0.648914    
#> 134: 0.402335    1.084376    3.534976    0.303579    0.072777    0.016305    0.649907    
#> 135: 0.408751    1.099108    3.532579    0.298951    0.078234    0.016377    0.627422    
#> 136: 0.423073    1.097129    3.531478    0.339720    0.074322    0.017254    0.621846    
#> 137: 0.468443    1.088966    3.525953    0.366505    0.070606    0.016391    0.640327    
#> 138: 0.412019    1.118652    3.520001    0.348179    0.072652    0.015571    0.644912    
#> 139: 0.436620    1.088123    3.535488    0.330771    0.072003    0.015285    0.659787    
#> 140: 0.459145    1.112841    3.536713    0.341333    0.070685    0.015436    0.656704    
#> 141: 0.435443    1.086498    3.534811    0.324267    0.079674    0.014840    0.642793    
#> 142: 0.444584    1.064382    3.545316    0.308053    0.075691    0.014098    0.662827    
#> 143: 0.392603    1.102581    3.533613    0.292651    0.071906    0.016573    0.642217    
#> 144: 0.466896    1.105044    3.540194    0.278018    0.068311    0.017794    0.640678    
#> 145: 0.420936    1.104270    3.527581    0.264117    0.064895    0.019585    0.633994    
#> 146: 0.400203    1.111846    3.530435    0.307064    0.061651    0.018606    0.635941    
#> 147: 0.399255    1.107942    3.516408    0.303160    0.058568    0.023828    0.608680    
#> 148: 0.406738    1.116468    3.530050    0.288002    0.055640    0.022637    0.623663    
#> 149: 0.423453    1.102102    3.531288    0.277403    0.058341    0.022212    0.629868    
#> 150: 0.435375    1.097924    3.519858    0.313241    0.065998    0.022352    0.633883    
#> 151: 0.410501    1.118445    3.520273    0.297579    0.067333    0.021234    0.631612    
#> 152: 0.386299    1.116281    3.517110    0.288999    0.055032    0.020075    0.642452    
#> 153: 0.434089    1.114215    3.536245    0.279809    0.041320    0.016882    0.656595    
#> 154: 0.460204    1.107801    3.529389    0.283481    0.052295    0.016659    0.644389    
#> 155: 0.422697    1.100378    3.526860    0.253884    0.051484    0.018103    0.644980    
#> 156: 0.422182    1.113309    3.532766    0.264667    0.054654    0.018827    0.644099    
#> 157: 0.427404    1.113318    3.526277    0.248632    0.056459    0.016366    0.639392    
#> 158: 0.424873    1.103141    3.521164    0.246435    0.052921    0.013845    0.628569    
#> 159: 0.397436    1.112582    3.522113    0.306033    0.052764    0.015849    0.641901    
#> 160: 0.448980    1.092233    3.533289    0.292219    0.060294    0.015938    0.653045    
#> 161: 0.459118    1.093547    3.522766    0.307359    0.064775    0.012309    0.626602    
#> 162: 0.397710    1.115527    3.507834    0.282747    0.065555    0.009391    0.648184    
#> 163: 0.415783    1.109919    3.506842    0.311678    0.071963    0.009064    0.626679    
#> 164: 0.408373    1.114103    3.513185    0.273783    0.069833    0.010872    0.633496    
#> 165: 0.429202    1.110934    3.520147    0.282380    0.069465    0.011748    0.630253    
#> 166: 0.426568    1.124538    3.525130    0.259638    0.065093    0.011210    0.631621    
#> 167: 0.438628    1.125750    3.530868    0.266497    0.064654    0.011994    0.649992    
#> 168: 0.491271    1.112371    3.542359    0.300444    0.063232    0.012904    0.643478    
#> 169: 0.464129    1.135896    3.524815    0.315856    0.063693    0.014078    0.649161    
#> 170: 0.429666    1.120091    3.510916    0.370747    0.059089    0.014615    0.640341    
#> 171: 0.407934    1.120039    3.507200    0.339238    0.054423    0.012900    0.624234    
#> 172: 0.355305    1.136529    3.500974    0.294856    0.054006    0.011448    0.620220    
#> 173: 0.381362    1.141678    3.500260    0.279235    0.052449    0.014559    0.626614    
#> 174: 0.419462    1.133512    3.512836    0.329091    0.052168    0.015967    0.641953    
#> 175: 0.395627    1.136108    3.508742    0.322977    0.058103    0.018230    0.635055    
#> 176: 0.411108    1.146938    3.518327    0.359770    0.060984    0.015815    0.615582    
#> 177: 0.422131    1.132626    3.524440    0.287403    0.054277    0.020067    0.629551    
#> 178: 0.440702    1.111127    3.529278    0.290151    0.061885    0.016138    0.635908    
#> 179: 0.426755    1.135460    3.520288    0.305319    0.064097    0.013979    0.649828    
#> 180: 0.408398    1.125968    3.523263    0.362103    0.063924    0.012767    0.641911    
#> 181: 0.385124    1.126391    3.494144    0.345943    0.067432    0.014416    0.626182    
#> 182: 0.352434    1.145181    3.494471    0.306930    0.058237    0.014229    0.645799    
#> 183: 0.383892    1.151715    3.494767    0.319275    0.050623    0.015352    0.632515    
#> 184: 0.405810    1.120115    3.503818    0.270872    0.046249    0.015865    0.634598    
#> 185: 0.371969    1.137799    3.502512    0.274222    0.045154    0.016179    0.633528    
#> 186: 0.368998    1.157377    3.505313    0.299207    0.050784    0.017069    0.629688    
#> 187: 0.399860    1.122987    3.514669    0.337873    0.053841    0.016917    0.619276    
#> 188: 0.360212    1.141322    3.510269    0.309573    0.053932    0.018262    0.631796    
#> 189: 0.405337    1.138085    3.523285    0.342942    0.057019    0.018030    0.640925    
#> 190: 0.424254    1.119622    3.524422    0.424784    0.051557    0.020124    0.610131    
#> 191: 0.379722    1.125667    3.508150    0.293489    0.049112    0.019591    0.607058    
#> 192: 0.380746    1.127627    3.516413    0.306064    0.041715    0.019931    0.623668    
#> 193: 0.419559    1.126985    3.520061    0.262725    0.046407    0.017925    0.631048    
#> 194: 0.405514    1.109758    3.506135    0.272616    0.049082    0.020117    0.653688    
#> 195: 0.402944    1.124383    3.518533    0.314655    0.046991    0.026189    0.628241    
#> 196: 0.419835    1.113450    3.518187    0.269246    0.039294    0.026390    0.627248    
#> 197: 0.395775    1.122360    3.533296    0.235334    0.049446    0.026507    0.641845    
#> 198: 0.425838    1.109183    3.527643    0.227396    0.045372    0.026300    0.625814    
#> 199: 0.401129    1.105290    3.522434    0.309500    0.048730    0.023040    0.608906    
#> 200: 0.409688    1.096281    3.522935    0.335349    0.045888    0.020463    0.618054    
#> 201: 0.408515    1.092489    3.532902    0.304843    0.045424    0.020358    0.615647    
#> 202: 0.414019    1.094494    3.532152    0.296811    0.044139    0.020739    0.616112    
#> 203: 0.422156    1.096507    3.528444    0.291285    0.043944    0.020712    0.618853    
#> 204: 0.424704    1.095634    3.527625    0.298524    0.044958    0.020166    0.619870    
#> 205: 0.426121    1.101829    3.526208    0.294030    0.046459    0.019561    0.622720    
#> 206: 0.425151    1.108008    3.524948    0.293807    0.047971    0.019172    0.625082    
#> 207: 0.422528    1.110816    3.521660    0.299504    0.046941    0.019137    0.624380    
#> 208: 0.422493    1.113127    3.520981    0.307197    0.046876    0.018981    0.623392    
#> 209: 0.423374    1.110920    3.519855    0.308377    0.047809    0.018532    0.624083    
#> 210: 0.424125    1.109849    3.519860    0.307320    0.049188    0.018134    0.622975    
#> 211: 0.425760    1.111392    3.520170    0.307364    0.050584    0.017823    0.622538    
#> 212: 0.430515    1.111245    3.520316    0.310290    0.050642    0.017640    0.622854    
#> 213: 0.432450    1.108441    3.521414    0.313124    0.050116    0.017585    0.623611    
#> 214: 0.434474    1.107462    3.521963    0.313201    0.049838    0.017344    0.624268    
#> 215: 0.436822    1.106960    3.523170    0.313692    0.050509    0.017387    0.625164    
#> 216: 0.439648    1.105504    3.524212    0.312158    0.051384    0.017442    0.627004    
#> 217: 0.440792    1.105102    3.525159    0.309968    0.052204    0.017609    0.627194    
#> 218: 0.440351    1.104654    3.524970    0.309636    0.051937    0.017614    0.627199    
#> 219: 0.439921    1.104091    3.524499    0.309995    0.052559    0.017479    0.627464    
#> 220: 0.438757    1.103916    3.524487    0.310937    0.052565    0.017379    0.627507    
#> 221: 0.437512    1.104307    3.523724    0.312312    0.053016    0.017225    0.627275    
#> 222: 0.436072    1.105098    3.522320    0.312427    0.053532    0.017230    0.628074    
#> 223: 0.434731    1.105587    3.521830    0.312394    0.054191    0.017205    0.628095    
#> 224: 0.434282    1.106567    3.521707    0.311839    0.054371    0.017184    0.628271    
#> 225: 0.433173    1.105852    3.521601    0.310794    0.054667    0.017096    0.628595    
#> 226: 0.431735    1.105170    3.521189    0.308620    0.054889    0.017061    0.628996    
#> 227: 0.430528    1.104912    3.521041    0.305643    0.054960    0.017023    0.629193    
#> 228: 0.430083    1.105739    3.520712    0.303198    0.054848    0.016926    0.629205    
#> 229: 0.428501    1.105927    3.520428    0.301009    0.054735    0.016853    0.628793    
#> 230: 0.427537    1.105706    3.520218    0.300245    0.054817    0.016807    0.628900    
#> 231: 0.427620    1.106327    3.520543    0.300026    0.055079    0.016766    0.628459    
#> 232: 0.426732    1.106350    3.520918    0.299371    0.055358    0.016833    0.628855    
#> 233: 0.426418    1.105533    3.521138    0.297845    0.055483    0.016823    0.629299    
#> 234: 0.425986    1.105125    3.521514    0.298166    0.055632    0.016896    0.629722    
#> 235: 0.426050    1.104648    3.521502    0.299095    0.055598    0.016893    0.629679    
#> 236: 0.425894    1.104954    3.521158    0.297902    0.055814    0.016773    0.629797    
#> 237: 0.426864    1.104662    3.521383    0.298605    0.055887    0.016755    0.630350    
#> 238: 0.426831    1.104903    3.521450    0.298430    0.056011    0.016746    0.630652    
#> 239: 0.426359    1.105269    3.521315    0.297605    0.056001    0.016721    0.630857    
#> 240: 0.426323    1.105136    3.521470    0.296499    0.056006    0.016676    0.630811    
#> 241: 0.426379    1.104446    3.521580    0.295870    0.056014    0.016696    0.630913    
#> 242: 0.426514    1.104079    3.521603    0.296129    0.055950    0.016743    0.631437    
#> 243: 0.425682    1.104430    3.521502    0.295706    0.055662    0.016893    0.631632    
#> 244: 0.424846    1.104675    3.521497    0.295626    0.055485    0.016983    0.631998    
#> 245: 0.424442    1.104476    3.521595    0.295779    0.055377    0.017064    0.632547    
#> 246: 0.424085    1.104089    3.521528    0.295512    0.055088    0.017093    0.632846    
#> 247: 0.424467    1.103894    3.521692    0.294901    0.055102    0.017166    0.633137    
#> 248: 0.424684    1.104253    3.521812    0.294639    0.055072    0.017211    0.633076    
#> 249: 0.424011    1.104658    3.521835    0.294989    0.055039    0.017180    0.633082    
#> 250: 0.424654    1.104964    3.522187    0.294096    0.054989    0.017225    0.632957    
#> 251: 0.424854    1.105291    3.522552    0.292822    0.055115    0.017192    0.633078    
#> 252: 0.424929    1.105440    3.522841    0.292400    0.055321    0.017156    0.633008    
#> 253: 0.424473    1.105828    3.522794    0.293452    0.055475    0.017150    0.633018    
#> 254: 0.424772    1.106138    3.522687    0.293684    0.055586    0.017164    0.632813    
#> 255: 0.424805    1.106247    3.522774    0.294459    0.055561    0.017185    0.632818    
#> 256: 0.425128    1.106144    3.522894    0.294851    0.055507    0.017218    0.632685    
#> 257: 0.425647    1.105701    3.523073    0.293954    0.055465    0.017239    0.632980    
#> 258: 0.425814    1.105297    3.523343    0.293450    0.055275    0.017310    0.632936    
#> 259: 0.425842    1.105047    3.523406    0.293498    0.055270    0.017380    0.632815    
#> 260: 0.425545    1.105200    3.523451    0.293553    0.055302    0.017400    0.632639    
#> 261: 0.425494    1.105124    3.523464    0.293895    0.055151    0.017439    0.632716    
#> 262: 0.425372    1.105450    3.523426    0.293226    0.055234    0.017490    0.632616    
#> 263: 0.425152    1.105817    3.523388    0.293776    0.055426    0.017489    0.632541    
#> 264: 0.424702    1.106150    3.523228    0.294092    0.055511    0.017493    0.632537    
#> 265: 0.424757    1.106189    3.523255    0.293173    0.055474    0.017606    0.632634    
#> 266: 0.424962    1.106321    3.523291    0.292205    0.055508    0.017659    0.632646    
#> 267: 0.425192    1.106099    3.523368    0.292837    0.055659    0.017654    0.632606    
#> 268: 0.425586    1.105821    3.523406    0.292908    0.055663    0.017653    0.632535    
#> 269: 0.426088    1.105501    3.523413    0.292439    0.055557    0.017686    0.632509    
#> 270: 0.425913    1.105569    3.523295    0.291887    0.055589    0.017686    0.632439    
#> 271: 0.425862    1.105761    3.523110    0.292289    0.055663    0.017749    0.632957    
#> 272: 0.425669    1.105797    3.523002    0.293197    0.055739    0.017830    0.633220    
#> 273: 0.424988    1.106162    3.522882    0.293344    0.055670    0.017822    0.633488    
#> 274: 0.424620    1.106493    3.522811    0.293376    0.055790    0.017808    0.633451    
#> 275: 0.424290    1.106773    3.522656    0.293220    0.055804    0.017809    0.633361    
#> 276: 0.423866    1.107109    3.522582    0.293667    0.055823    0.017847    0.633330    
#> 277: 0.423471    1.107449    3.522778    0.293084    0.055772    0.017846    0.633323    
#> 278: 0.423704    1.107528    3.522901    0.292842    0.055987    0.017790    0.633328    
#> 279: 0.423601    1.107526    3.522890    0.292950    0.056144    0.017775    0.633388    
#> 280: 0.423525    1.107701    3.522898    0.293136    0.056094    0.017783    0.633281    
#> 281: 0.423290    1.107678    3.522982    0.293034    0.056080    0.017793    0.633308    
#> 282: 0.422964    1.107890    3.522864    0.292692    0.056125    0.017783    0.633299    
#> 283: 0.422695    1.108156    3.522726    0.293411    0.056207    0.017759    0.633608    
#> 284: 0.422298    1.108039    3.522646    0.293760    0.056131    0.017731    0.633601    
#> 285: 0.422124    1.108180    3.522398    0.293882    0.056111    0.017716    0.633427    
#> 286: 0.421957    1.108654    3.522062    0.294904    0.056117    0.017738    0.633445    
#> 287: 0.421752    1.109101    3.521855    0.295153    0.056061    0.017752    0.633574    
#> 288: 0.421949    1.109226    3.521753    0.295705    0.055957    0.017779    0.633618    
#> 289: 0.422611    1.109182    3.521819    0.295540    0.055801    0.017778    0.633769    
#> 290: 0.422791    1.109204    3.521843    0.295028    0.055674    0.017810    0.633959    
#> 291: 0.423103    1.109376    3.521954    0.294717    0.055525    0.017854    0.633978    
#> 292: 0.423349    1.109450    3.521980    0.294762    0.055428    0.017877    0.634218    
#> 293: 0.423243    1.109465    3.521950    0.294592    0.055354    0.017904    0.633998    
#> 294: 0.423123    1.109625    3.521831    0.294754    0.055305    0.017906    0.633840    
#> 295: 0.422849    1.109395    3.521795    0.294289    0.055272    0.017887    0.633687    
#> 296: 0.422766    1.109230    3.521796    0.294442    0.055181    0.017922    0.633711    
#> 297: 0.422641    1.109246    3.521652    0.295018    0.055123    0.017906    0.633595    
#> 298: 0.422550    1.109197    3.521532    0.295176    0.055122    0.017872    0.633478    
#> 299: 0.422401    1.109366    3.521470    0.294958    0.055104    0.017821    0.633424    
#> 300: 0.422471    1.109362    3.521500    0.294817    0.055116    0.017817    0.633309    
#> 301: 0.422597    1.109395    3.521429    0.294523    0.055198    0.017800    0.633321    
#> 302: 0.422550    1.109493    3.521267    0.294183    0.055214    0.017829    0.633215    
#> 303: 0.422363    1.109683    3.521208    0.293871    0.055225    0.017829    0.633123    
#> 304: 0.422182    1.110025    3.521025    0.293970    0.055243    0.017807    0.633059    
#> 305: 0.421946    1.109929    3.520861    0.294029    0.055319    0.017799    0.632975    
#> 306: 0.421616    1.109839    3.520803    0.293693    0.055307    0.017806    0.632878    
#> 307: 0.421508    1.109871    3.520769    0.293262    0.055382    0.017845    0.632871    
#> 308: 0.421211    1.109704    3.520708    0.293158    0.055454    0.017849    0.632912    
#> 309: 0.421235    1.109325    3.520774    0.293307    0.055463    0.017846    0.633189    
#> 310: 0.421340    1.109105    3.520681    0.293258    0.055474    0.017825    0.633428    
#> 311: 0.421449    1.108974    3.520757    0.293369    0.055421    0.017846    0.633461    
#> 312: 0.421153    1.108852    3.520717    0.293084    0.055407    0.017853    0.633493    
#> 313: 0.420904    1.108650    3.520649    0.292996    0.055433    0.017827    0.633695    
#> 314: 0.420558    1.108545    3.520576    0.293102    0.055419    0.017840    0.633694    
#> 315: 0.420352    1.108601    3.520515    0.293339    0.055412    0.017831    0.633749    
#> 316: 0.420698    1.108612    3.520633    0.293438    0.055380    0.017815    0.633651    
#> 317: 0.420905    1.108534    3.520764    0.293485    0.055363    0.017802    0.633817    
#> 318: 0.421022    1.108411    3.520761    0.293228    0.055345    0.017762    0.633878    
#> 319: 0.420991    1.108281    3.520825    0.292968    0.055346    0.017742    0.633925    
#> 320: 0.420817    1.108156    3.520743    0.292614    0.055367    0.017713    0.634094    
#> 321: 0.420478    1.108219    3.520640    0.292363    0.055487    0.017693    0.634118    
#> 322: 0.420371    1.108263    3.520491    0.292290    0.055478    0.017669    0.634110    
#> 323: 0.419978    1.108339    3.520417    0.292460    0.055398    0.017649    0.634124    
#> 324: 0.420139    1.108382    3.520464    0.292926    0.055453    0.017631    0.634028    
#> 325: 0.420264    1.108495    3.520483    0.292873    0.055544    0.017618    0.633920    
#> 326: 0.420392    1.108310    3.520562    0.292851    0.055641    0.017575    0.633966    
#> 327: 0.420655    1.108113    3.520698    0.292499    0.055819    0.017541    0.634123    
#> 328: 0.421091    1.108031    3.520797    0.292801    0.055861    0.017508    0.634098    
#> 329: 0.421623    1.107949    3.520952    0.292843    0.055809    0.017479    0.634080    
#> 330: 0.421388    1.107974    3.520992    0.292613    0.055713    0.017505    0.634026    
#> 331: 0.421452    1.108046    3.521037    0.292627    0.055725    0.017484    0.634002    
#> 332: 0.421470    1.108089    3.521147    0.292604    0.055694    0.017509    0.634042    
#> 333: 0.421353    1.108120    3.521153    0.292767    0.055713    0.017498    0.634068    
#> 334: 0.421137    1.108026    3.521030    0.292936    0.055740    0.017463    0.634114    
#> 335: 0.421068    1.108065    3.520945    0.292658    0.055759    0.017456    0.634194    
#> 336: 0.420969    1.108232    3.520897    0.292512    0.055793    0.017442    0.634243    
#> 337: 0.420939    1.108442    3.520836    0.292471    0.055758    0.017433    0.634238    
#> 338: 0.420804    1.108549    3.520795    0.292372    0.055786    0.017398    0.634358    
#> 339: 0.420449    1.108647    3.520694    0.292415    0.055787    0.017362    0.634427    
#> 340: 0.420329    1.108458    3.520678    0.292715    0.055874    0.017337    0.634449    
#> 341: 0.420349    1.108510    3.520682    0.292825    0.055951    0.017312    0.634509    
#> 342: 0.420028    1.108449    3.520688    0.292773    0.055990    0.017303    0.634455    
#> 343: 0.419864    1.108513    3.520689    0.292822    0.056007    0.017316    0.634364    
#> 344: 0.419929    1.108490    3.520734    0.292808    0.055972    0.017328    0.634385    
#> 345: 0.419892    1.108558    3.520759    0.292632    0.055928    0.017347    0.634375    
#> 346: 0.419908    1.108720    3.520661    0.292804    0.055905    0.017334    0.634247    
#> 347: 0.419929    1.108665    3.520567    0.293003    0.055890    0.017327    0.634321    
#> 348: 0.419586    1.108664    3.520470    0.293046    0.055982    0.017334    0.634331    
#> 349: 0.419291    1.108620    3.520400    0.293246    0.056091    0.017325    0.634275    
#> 350: 0.418857    1.108608    3.520261    0.293486    0.056164    0.017283    0.634211    
#> 351: 0.418725    1.108826    3.520124    0.293750    0.056158    0.017254    0.634220    
#> 352: 0.418271    1.109037    3.519984    0.294167    0.056208    0.017236    0.634357    
#> 353: 0.418121    1.109235    3.519849    0.294725    0.056246    0.017237    0.634480    
#> 354: 0.417865    1.109371    3.519660    0.294738    0.056230    0.017208    0.634643    
#> 355: 0.417890    1.109377    3.519547    0.295206    0.056308    0.017189    0.634644    
#> 356: 0.417876    1.109344    3.519579    0.295964    0.056315    0.017192    0.634659    
#> 357: 0.417860    1.109544    3.519544    0.296113    0.056311    0.017200    0.634646    
#> 358: 0.417729    1.109536    3.519574    0.296233    0.056334    0.017193    0.634544    
#> 359: 0.417620    1.109598    3.519546    0.296472    0.056279    0.017199    0.634459    
#> 360: 0.417502    1.109640    3.519433    0.296399    0.056245    0.017207    0.634328    
#> 361: 0.417406    1.109726    3.519344    0.296531    0.056271    0.017197    0.634165    
#> 362: 0.417469    1.109745    3.519254    0.296737    0.056279    0.017177    0.634052    
#> 363: 0.417339    1.109710    3.519205    0.296761    0.056309    0.017167    0.634035    
#> 364: 0.417145    1.109865    3.519167    0.296726    0.056346    0.017166    0.634068    
#> 365: 0.417304    1.109781    3.519231    0.296645    0.056219    0.017184    0.634170    
#> 366: 0.417333    1.109767    3.519180    0.296526    0.056160    0.017202    0.634290    
#> 367: 0.417492    1.109786    3.519215    0.296439    0.056114    0.017215    0.634315    
#> 368: 0.417745    1.109749    3.519244    0.297142    0.056082    0.017223    0.634234    
#> 369: 0.417792    1.109659    3.519236    0.297552    0.056071    0.017200    0.634224    
#> 370: 0.417688    1.109753    3.519167    0.297412    0.056084    0.017163    0.634240    
#> 371: 0.417425    1.109917    3.518987    0.297387    0.056142    0.017125    0.634294    
#> 372: 0.417244    1.110023    3.518897    0.297437    0.056142    0.017088    0.634336    
#> 373: 0.417052    1.110113    3.518781    0.297518    0.056171    0.017055    0.634380    
#> 374: 0.416913    1.110181    3.518736    0.297579    0.056151    0.017053    0.634377    
#> 375: 0.416759    1.110310    3.518664    0.297620    0.056182    0.017046    0.634389    
#> 376: 0.416761    1.110245    3.518686    0.297263    0.056207    0.017058    0.634265    
#> 377: 0.416683    1.110224    3.518778    0.297301    0.056175    0.017097    0.634196    
#> 378: 0.416780    1.110103    3.518810    0.297359    0.056162    0.017116    0.634215    
#> 379: 0.416766    1.109891    3.518869    0.297423    0.056195    0.017113    0.634220    
#> 380: 0.416660    1.109824    3.518880    0.297322    0.056205    0.017097    0.634185    
#> 381: 0.416371    1.109811    3.518815    0.297291    0.056178    0.017092    0.634109    
#> 382: 0.416308    1.109813    3.518732    0.297604    0.056203    0.017070    0.634061    
#> 383: 0.416486    1.109814    3.518731    0.297761    0.056189    0.017051    0.634040    
#> 384: 0.416400    1.109788    3.518777    0.297613    0.056170    0.017025    0.634083    
#> 385: 0.416516    1.109744    3.518874    0.297577    0.056131    0.017022    0.634086    
#> 386: 0.416599    1.109845    3.518930    0.297645    0.056112    0.017023    0.634095    
#> 387: 0.416868    1.109853    3.519046    0.297614    0.056116    0.017017    0.634058    
#> 388: 0.417023    1.109913    3.519135    0.297759    0.056097    0.017031    0.634029    
#> 389: 0.417187    1.109739    3.519170    0.297784    0.056090    0.017033    0.634093    
#> 390: 0.417198    1.109716    3.519143    0.297855    0.056049    0.017016    0.634113    
#> 391: 0.417271    1.109722    3.519118    0.297979    0.056019    0.016986    0.634174    
#> 392: 0.417562    1.109630    3.519288    0.298117    0.055954    0.016969    0.634238    
#> 393: 0.417777    1.109520    3.519321    0.298016    0.055957    0.016955    0.634276    
#> 394: 0.418017    1.109443    3.519376    0.298605    0.055938    0.016957    0.634259    
#> 395: 0.418289    1.109466    3.519455    0.298909    0.055962    0.016947    0.634217    
#> 396: 0.418390    1.109523    3.519515    0.299072    0.055990    0.016936    0.634188    
#> 397: 0.418465    1.109381    3.519619    0.299064    0.055940    0.016934    0.634325    
#> 398: 0.418699    1.109296    3.519722    0.298970    0.055964    0.016952    0.634347    
#> 399: 0.418954    1.109214    3.519834    0.298899    0.055980    0.016969    0.634335    
#> 400: 0.419081    1.109234    3.519897    0.298844    0.055952    0.016970    0.634283    
#> 401: 0.419116    1.109249    3.519937    0.298859    0.055906    0.016988    0.634328    
#> 402: 0.419091    1.109295    3.519924    0.298619    0.055815    0.017005    0.634451    
#> 403: 0.419271    1.109343    3.519962    0.298406    0.055723    0.017021    0.634480    
#> 404: 0.419304    1.109356    3.519886    0.298310    0.055668    0.017022    0.634469    
#> 405: 0.419330    1.109420    3.519869    0.298088    0.055644    0.017013    0.634454    
#> 406: 0.419463    1.109475    3.519875    0.298151    0.055650    0.017014    0.634529    
#> 407: 0.419590    1.109602    3.519899    0.298333    0.055691    0.017002    0.634497    
#> 408: 0.419795    1.109675    3.519960    0.298116    0.055716    0.016997    0.634556    
#> 409: 0.419789    1.109673    3.519893    0.298059    0.055798    0.016971    0.634524    
#> 410: 0.419706    1.109683    3.519775    0.298221    0.055856    0.016958    0.634525    
#> 411: 0.419720    1.109514    3.519744    0.298216    0.055867    0.016963    0.634685    
#> 412: 0.419725    1.109531    3.519665    0.298307    0.055863    0.016972    0.634634    
#> 413: 0.419757    1.109559    3.519610    0.298621    0.055840    0.016972    0.634615    
#> 414: 0.419689    1.109590    3.519600    0.298562    0.055813    0.016959    0.634655    
#> 415: 0.419935    1.109574    3.519609    0.298663    0.055725    0.016947    0.634639    
#> 416: 0.420181    1.109656    3.519672    0.299017    0.055745    0.016942    0.634603    
#> 417: 0.420250    1.109641    3.519686    0.299247    0.055756    0.016944    0.634525    
#> 418: 0.420201    1.109673    3.519707    0.299414    0.055799    0.016954    0.634455    
#> 419: 0.420291    1.109764    3.519724    0.299765    0.055856    0.016964    0.634336    
#> 420: 0.420335    1.109843    3.519712    0.300057    0.055868    0.016960    0.634270    
#> 421: 0.420284    1.109886    3.519730    0.300152    0.055873    0.016969    0.634202    
#> 422: 0.420448    1.109838    3.519772    0.300040    0.055888    0.016972    0.634201    
#> 423: 0.420689    1.109732    3.519816    0.300018    0.055903    0.016968    0.634265    
#> 424: 0.420711    1.109730    3.519772    0.300313    0.055901    0.016970    0.634249    
#> 425: 0.420809    1.109787    3.519702    0.300706    0.055888    0.016971    0.634277    
#> 426: 0.420916    1.109912    3.519663    0.301073    0.055886    0.016959    0.634232    
#> 427: 0.420714    1.109899    3.519674    0.301324    0.055882    0.016948    0.634268    
#> 428: 0.420759    1.109884    3.519718    0.301354    0.055897    0.016945    0.634262    
#> 429: 0.420770    1.109792    3.519783    0.301214    0.055909    0.016945    0.634282    
#> 430: 0.420897    1.109799    3.519836    0.301109    0.055925    0.016946    0.634302    
#> 431: 0.420962    1.109764    3.519841    0.301226    0.055933    0.016948    0.634228    
#> 432: 0.420952    1.109805    3.519858    0.301564    0.055929    0.016949    0.634168    
#> 433: 0.420986    1.109941    3.519843    0.301623    0.055961    0.016949    0.634134    
#> 434: 0.420778    1.109871    3.519814    0.301624    0.055959    0.016941    0.634115    
#> 435: 0.420755    1.109928    3.519765    0.301724    0.055930    0.016941    0.634089    
#> 436: 0.420639    1.109909    3.519759    0.301769    0.055941    0.016939    0.634057    
#> 437: 0.420580    1.109978    3.519710    0.301626    0.055962    0.016938    0.634108    
#> 438: 0.420486    1.110165    3.519662    0.301546    0.055997    0.016925    0.634078    
#> 439: 0.420446    1.110186    3.519656    0.301263    0.056037    0.016921    0.634037    
#> 440: 0.420395    1.110246    3.519692    0.301211    0.056037    0.016922    0.633991    
#> 441: 0.420384    1.110135    3.519727    0.301122    0.056025    0.016935    0.633952    
#> 442: 0.420313    1.110188    3.519743    0.301035    0.056080    0.016940    0.633907    
#> 443: 0.420189    1.110188    3.519709    0.300824    0.056118    0.016955    0.633935    
#> 444: 0.420066    1.110154    3.519653    0.300649    0.056117    0.016975    0.633911    
#> 445: 0.419959    1.110152    3.519650    0.300581    0.056100    0.016984    0.633951    
#> 446: 0.419810    1.110172    3.519628    0.300383    0.056101    0.016984    0.633924    
#> 447: 0.419885    1.110139    3.519660    0.300416    0.056075    0.016978    0.633907    
#> 448: 0.419941    1.110136    3.519692    0.300245    0.056071    0.016976    0.633824    
#> 449: 0.420032    1.110175    3.519801    0.300138    0.056071    0.016992    0.633802    
#> 450: 0.420124    1.110109    3.519846    0.300160    0.056028    0.017002    0.633751    
#> 451: 0.420253    1.110080    3.519883    0.300235    0.055997    0.017008    0.633723    
#> 452: 0.420250    1.110086    3.519901    0.300092    0.055971    0.017010    0.633692    
#> 453: 0.420214    1.110071    3.519868    0.299839    0.055927    0.017009    0.633701    
#> 454: 0.420121    1.110192    3.519826    0.299914    0.055933    0.017011    0.633608    
#> 455: 0.420081    1.110198    3.519815    0.299996    0.055886    0.017014    0.633618    
#> 456: 0.420098    1.110129    3.519808    0.299925    0.055825    0.017030    0.633667    
#> 457: 0.419972    1.110067    3.519823    0.299899    0.055771    0.017046    0.633647    
#> 458: 0.419848    1.110127    3.519856    0.299847    0.055703    0.017062    0.633702    
#> 459: 0.419841    1.110159    3.519881    0.299863    0.055622    0.017087    0.633691    
#> 460: 0.419805    1.110235    3.519852    0.299781    0.055587    0.017091    0.633733    
#> 461: 0.419724    1.110262    3.519867    0.299585    0.055543    0.017086    0.633843    
#> 462: 0.419717    1.110271    3.519931    0.299421    0.055527    0.017086    0.633823    
#> 463: 0.419804    1.110289    3.520004    0.299281    0.055523    0.017101    0.633838    
#> 464: 0.419916    1.110301    3.520049    0.299055    0.055526    0.017099    0.633784    
#> 465: 0.420058    1.110113    3.520137    0.298793    0.055518    0.017105    0.633782    
#> 466: 0.420314    1.110053    3.520188    0.298969    0.055528    0.017109    0.633768    
#> 467: 0.420312    1.109952    3.520209    0.299286    0.055505    0.017106    0.633709    
#> 468: 0.420461    1.109912    3.520248    0.299518    0.055501    0.017107    0.633698    
#> 469: 0.420665    1.109954    3.520324    0.299577    0.055494    0.017103    0.633747    
#> 470: 0.420710    1.109903    3.520316    0.299589    0.055496    0.017098    0.633720    
#> 471: 0.420640    1.109870    3.520292    0.299555    0.055472    0.017101    0.633704    
#> 472: 0.420671    1.109870    3.520290    0.299630    0.055501    0.017102    0.633693    
#> 473: 0.420568    1.109906    3.520263    0.299697    0.055485    0.017101    0.633682    
#> 474: 0.420495    1.109897    3.520242    0.299562    0.055514    0.017097    0.633783    
#> 475: 0.420429    1.110054    3.520190    0.299352    0.055485    0.017094    0.633844    
#> 476: 0.420447    1.110059    3.520188    0.299315    0.055494    0.017098    0.633896    
#> 477: 0.420335    1.110100    3.520173    0.299359    0.055492    0.017095    0.633890    
#> 478: 0.420180    1.110099    3.520132    0.299297    0.055470    0.017084    0.633941    
#> 479: 0.420130    1.110185    3.520123    0.299176    0.055471    0.017075    0.633943    
#> 480: 0.420168    1.110178    3.520147    0.299248    0.055498    0.017074    0.633936    
#> 481: 0.420157    1.110151    3.520175    0.299159    0.055534    0.017068    0.633903    
#> 482: 0.420264    1.110174    3.520189    0.299146    0.055588    0.017059    0.633839    
#> 483: 0.420209    1.110144    3.520197    0.299054    0.055607    0.017047    0.633796    
#> 484: 0.420134    1.110051    3.520247    0.299000    0.055604    0.017031    0.633832    
#> 485: 0.420278    1.110048    3.520290    0.299153    0.055637    0.017028    0.633849    
#> 486: 0.420452    1.110048    3.520319    0.299174    0.055649    0.017022    0.633851    
#> 487: 0.420649    1.109990    3.520362    0.299324    0.055683    0.017018    0.633827    
#> 488: 0.420733    1.109986    3.520380    0.299389    0.055681    0.017008    0.633774    
#> 489: 0.420813    1.109988    3.520382    0.299421    0.055685    0.017001    0.633788    
#> 490: 0.420879    1.110033    3.520388    0.299369    0.055683    0.016990    0.633734    
#> 491: 0.420852    1.110141    3.520408    0.299279    0.055711    0.016987    0.633699    
#> 492: 0.420835    1.110179    3.520414    0.299025    0.055739    0.016996    0.633735    
#> 493: 0.420944    1.110143    3.520488    0.298929    0.055734    0.017012    0.633734    
#> 494: 0.421211    1.110141    3.520522    0.299033    0.055736    0.017014    0.633756    
#> 495: 0.421412    1.110134    3.520557    0.298924    0.055698    0.017012    0.633774    
#> 496: 0.421580    1.110150    3.520563    0.298971    0.055693    0.017013    0.633761    
#> 497: 0.421474    1.110135    3.520545    0.298864    0.055654    0.017010    0.633821    
#> 498: 0.421407    1.110165    3.520508    0.298634    0.055663    0.016997    0.633802    
#> 499: 0.421327    1.110214    3.520456    0.298691    0.055656    0.016989    0.633779    
#> 500: 0.421209    1.110172    3.520404    0.298744    0.055641    0.016975    0.633790    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.296047    0.971128    3.447393    0.392401    0.081228    0.016800    1.637480    
#> 002: 0.349562    0.948631    3.485409    0.372781    0.077167    0.015960    1.091306    
#> 003: 0.441873    0.910186    3.494221    0.354142    0.087758    0.015162    0.846419    
#> 004: 0.389527    0.900590    3.496020    0.336435    0.083370    0.014404    0.763206    
#> 005: 0.399035    0.925639    3.477703    0.319613    0.084693    0.013684    0.712348    
#> 006: 0.361037    0.922773    3.464915    0.303633    0.100199    0.013000    0.669553    
#> 007: 0.290819    0.940099    3.454853    0.288451    0.102981    0.012350    0.679071    
#> 008: 0.310503    0.929932    3.449599    0.274029    0.097832    0.011907    0.685174    
#> 009: 0.248743    0.940791    3.433898    0.260327    0.109615    0.011311    0.676566    
#> 010: 0.267210    0.939984    3.435411    0.247311    0.104134    0.010746    0.677339    
#> 011: 0.290760    0.952171    3.435401    0.234945    0.098927    0.011257    0.704615    
#> 012: 0.274329    0.970496    3.418217    0.223198    0.100404    0.010694    0.694155    
#> 013: 0.228670    0.967137    3.406900    0.223668    0.107556    0.011372    0.677741    
#> 014: 0.262082    0.972347    3.411918    0.212724    0.102178    0.010803    0.701743    
#> 015: 0.293972    0.959263    3.440165    0.202088    0.097069    0.010263    0.648774    
#> 016: 0.273808    0.976888    3.441505    0.191983    0.092216    0.015495    0.669530    
#> 017: 0.311459    0.969035    3.445793    0.210220    0.102880    0.014721    0.663235    
#> 018: 0.275360    0.978186    3.430499    0.199709    0.103185    0.013985    0.678513    
#> 019: 0.251905    0.975582    3.434847    0.191710    0.099453    0.013285    0.676640    
#> 020: 0.282240    0.981488    3.431056    0.182124    0.094480    0.012621    0.677021    
#> 021: 0.281944    0.955924    3.436357    0.203565    0.096302    0.011990    0.653553    
#> 022: 0.280700    0.963277    3.444882    0.195399    0.091486    0.011391    0.648506    
#> 023: 0.356184    0.953988    3.454092    0.185629    0.087190    0.012817    0.666771    
#> 024: 0.359382    0.971341    3.452889    0.207264    0.082831    0.012176    0.683481    
#> 025: 0.330995    0.946082    3.450176    0.230998    0.088425    0.012978    0.671898    
#> 026: 0.320201    0.954361    3.444659    0.219448    0.091830    0.017964    0.660378    
#> 027: 0.290050    0.976331    3.436766    0.214779    0.087239    0.019674    0.690867    
#> 028: 0.342699    0.962082    3.459002    0.204040    0.085746    0.018691    0.649792    
#> 029: 0.324193    0.955029    3.445689    0.193838    0.084417    0.017756    0.680940    
#> 030: 0.341653    0.962090    3.450651    0.184146    0.081311    0.016868    0.653429    
#> 031: 0.308227    0.947542    3.456104    0.174939    0.093563    0.016025    0.668044    
#> 032: 0.311062    0.927938    3.456183    0.166192    0.088885    0.015224    0.660924    
#> 033: 0.310045    0.938075    3.452735    0.190904    0.084999    0.016159    0.661092    
#> 034: 0.337266    0.977244    3.445151    0.204695    0.091307    0.016231    0.657925    
#> 035: 0.289973    0.952086    3.431714    0.194460    0.092199    0.015420    0.642249    
#> 036: 0.290622    0.965696    3.430614    0.184737    0.087589    0.016858    0.655706    
#> 037: 0.283206    0.974216    3.427729    0.192736    0.083210    0.016015    0.665831    
#> 038: 0.322178    0.982336    3.433574    0.200768    0.085636    0.016408    0.662813    
#> 039: 0.316851    0.957286    3.449435    0.190730    0.081354    0.018747    0.651298    
#> 040: 0.300760    0.975467    3.449858    0.216773    0.077286    0.017809    0.662703    
#> 041: 0.281798    0.970972    3.441562    0.223121    0.091465    0.021485    0.647636    
#> 042: 0.322947    0.957675    3.444100    0.237234    0.086892    0.020411    0.649690    
#> 043: 0.272563    0.971156    3.428026    0.225373    0.082547    0.019390    0.648531    
#> 044: 0.276085    0.980767    3.425708    0.214104    0.083273    0.018421    0.653656    
#> 045: 0.246141    0.996887    3.423449    0.203399    0.079109    0.017500    0.679232    
#> 046: 0.283101    0.981480    3.427452    0.204266    0.075154    0.016625    0.677546    
#> 047: 0.296403    0.979948    3.429598    0.204994    0.076708    0.017473    0.656871    
#> 048: 0.287924    0.976519    3.434949    0.204603    0.081777    0.016772    0.673524    
#> 049: 0.292636    0.990717    3.440153    0.195984    0.102032    0.015933    0.671133    
#> 050: 0.356903    0.920766    3.448855    0.204700    0.096930    0.015136    0.700526    
#> 051: 0.306487    0.953071    3.439920    0.194894    0.092084    0.014379    0.689643    
#> 052: 0.309997    0.960770    3.457515    0.185150    0.087479    0.013660    0.668548    
#> 053: 0.332002    0.939426    3.458528    0.220627    0.111183    0.012977    0.672297    
#> 054: 0.313776    0.936982    3.453002    0.212504    0.119081    0.014521    0.678774    
#> 055: 0.331121    0.932061    3.454430    0.201879    0.119499    0.013951    0.659331    
#> 056: 0.322208    0.940236    3.454816    0.191785    0.113524    0.014310    0.652180    
#> 057: 0.352236    0.921822    3.466726    0.182196    0.107848    0.015659    0.668106    
#> 058: 0.336197    0.947725    3.447674    0.199820    0.102455    0.014876    0.674756    
#> 059: 0.331074    0.907166    3.459410    0.207577    0.100239    0.018046    0.677080    
#> 060: 0.349362    0.924270    3.459532    0.215098    0.103149    0.017144    0.675614    
#> 061: 0.315584    0.956909    3.452014    0.204343    0.111674    0.016287    0.673530    
#> 062: 0.313553    0.962783    3.453539    0.194411    0.106090    0.016324    0.684851    
#> 063: 0.342758    0.939210    3.457763    0.207608    0.105208    0.015508    0.678808    
#> 064: 0.318005    0.951358    3.457799    0.225999    0.115381    0.014732    0.683583    
#> 065: 0.324821    0.945984    3.444080    0.214699    0.109612    0.013996    0.672854    
#> 066: 0.322847    0.982794    3.447957    0.203964    0.105739    0.013296    0.666460    
#> 067: 0.295603    0.943899    3.440168    0.193766    0.100452    0.012780    0.670160    
#> 068: 0.256861    0.952801    3.443643    0.184078    0.102229    0.013328    0.685461    
#> 069: 0.271657    0.964971    3.430223    0.174874    0.097117    0.014180    0.704383    
#> 070: 0.270799    0.974087    3.439233    0.190498    0.101573    0.016828    0.674961    
#> 071: 0.262655    0.996633    3.425679    0.189540    0.096494    0.017705    0.687384    
#> 072: 0.257915    0.967783    3.432357    0.200132    0.095946    0.019228    0.666093    
#> 073: 0.276928    0.979733    3.444682    0.208098    0.091149    0.018614    0.662409    
#> 074: 0.281469    0.951893    3.434668    0.197693    0.094459    0.017684    0.650563    
#> 075: 0.314904    0.937946    3.462615    0.190336    0.095970    0.016799    0.659811    
#> 076: 0.325004    0.939154    3.468973    0.180819    0.091172    0.015959    0.666004    
#> 077: 0.356029    0.937764    3.458268    0.176924    0.086613    0.015162    0.673346    
#> 078: 0.337527    0.954808    3.462860    0.169355    0.089663    0.014403    0.662893    
#> 079: 0.332317    0.943797    3.466197    0.215716    0.092499    0.015040    0.677160    
#> 080: 0.368098    0.940442    3.469112    0.204930    0.095780    0.016395    0.664406    
#> 081: 0.352540    0.954876    3.462518    0.213092    0.090991    0.016062    0.658514    
#> 082: 0.351645    0.946955    3.468015    0.202438    0.098241    0.015259    0.676445    
#> 083: 0.339742    0.958949    3.465749    0.192316    0.093329    0.016321    0.653070    
#> 084: 0.330832    0.940631    3.458480    0.182700    0.088663    0.016786    0.662665    
#> 085: 0.326640    0.954960    3.468181    0.173567    0.090518    0.016420    0.657012    
#> 086: 0.325974    0.962069    3.458196    0.167511    0.085992    0.015599    0.667890    
#> 087: 0.314140    0.961788    3.449034    0.173676    0.081692    0.017406    0.670881    
#> 088: 0.249520    0.949747    3.440407    0.201330    0.084948    0.016535    0.679190    
#> 089: 0.281521    0.980471    3.423221    0.191263    0.104607    0.015709    0.670920    
#> 090: 0.262077    0.978519    3.421521    0.186153    0.102106    0.014923    0.670456    
#> 091: 0.285385    0.961723    3.430306    0.190210    0.097001    0.014177    0.649847    
#> 092: 0.272028    0.970813    3.424367    0.205552    0.099818    0.013573    0.671310    
#> 093: 0.249523    0.976566    3.422292    0.195274    0.094827    0.013483    0.675386    
#> 094: 0.255750    0.976360    3.423679    0.185511    0.107632    0.013332    0.670076    
#> 095: 0.296324    0.986192    3.444803    0.199085    0.102251    0.013283    0.682239    
#> 096: 0.284723    0.969150    3.443300    0.189131    0.097138    0.012619    0.661354    
#> 097: 0.311209    0.989590    3.438046    0.189811    0.092281    0.013074    0.658853    
#> 098: 0.290210    0.980464    3.439594    0.180321    0.087667    0.014923    0.674073    
#> 099: 0.267479    0.969478    3.418433    0.186127    0.099997    0.014177    0.658725    
#> 100: 0.241851    0.995973    3.419382    0.194920    0.105102    0.013468    0.646572    
#> 101: 0.226916    0.982856    3.404757    0.206747    0.099847    0.012795    0.655429    
#> 102: 0.245431    1.005210    3.400851    0.206413    0.094854    0.012155    0.662815    
#> 103: 0.282764    0.991223    3.421466    0.196093    0.102168    0.011547    0.656014    
#> 104: 0.252641    0.974867    3.428004    0.196785    0.109834    0.011100    0.661355    
#> 105: 0.261824    0.967805    3.423102    0.229194    0.112835    0.010545    0.656058    
#> 106: 0.269314    0.967886    3.427603    0.250067    0.107194    0.010017    0.654280    
#> 107: 0.304406    0.960942    3.433549    0.237564    0.101834    0.010069    0.645369    
#> 108: 0.283168    0.950694    3.432766    0.225686    0.104440    0.009566    0.665982    
#> 109: 0.307674    0.944641    3.453730    0.214401    0.099218    0.009112    0.667727    
#> 110: 0.295679    0.942720    3.440583    0.203681    0.117881    0.008657    0.667077    
#> 111: 0.333103    0.934580    3.454892    0.193497    0.111987    0.008224    0.663993    
#> 112: 0.296980    0.916449    3.451696    0.183822    0.106388    0.008534    0.678698    
#> 113: 0.301424    0.965726    3.444674    0.174631    0.101069    0.008740    0.663754    
#> 114: 0.301272    0.977741    3.439017    0.165900    0.096015    0.009363    0.682361    
#> 115: 0.303779    0.955146    3.436906    0.164581    0.094206    0.009305    0.691943    
#> 116: 0.299956    0.964724    3.439203    0.171844    0.096845    0.012635    0.691464    
#> 117: 0.293385    0.974288    3.446156    0.196896    0.092003    0.012003    0.675578    
#> 118: 0.334485    0.948419    3.450928    0.209071    0.087403    0.012401    0.676044    
#> 119: 0.325747    0.957594    3.452906    0.217304    0.090086    0.012151    0.673204    
#> 120: 0.305628    0.951107    3.444973    0.206439    0.087332    0.014524    0.656035    
#> 121: 0.331642    0.978545    3.445140    0.232315    0.091759    0.016770    0.658409    
#> 122: 0.315941    0.947345    3.453814    0.220699    0.093069    0.015932    0.664055    
#> 123: 0.352366    0.963281    3.445831    0.209664    0.088415    0.015135    0.671411    
#> 124: 0.317757    0.986573    3.443721    0.199181    0.083995    0.015189    0.659920    
#> 125: 0.291024    0.977630    3.433148    0.189222    0.081076    0.014429    0.652392    
#> 126: 0.276647    0.991260    3.427664    0.179761    0.081315    0.013708    0.664372    
#> 127: 0.305355    0.959432    3.433455    0.170773    0.086524    0.013022    0.680623    
#> 128: 0.277927    0.959548    3.441823    0.182834    0.082198    0.012371    0.686886    
#> 129: 0.333313    0.969703    3.449883    0.203661    0.086092    0.011760    0.665155    
#> 130: 0.343915    0.970980    3.456236    0.193478    0.086091    0.011350    0.654947    
#> 131: 0.333761    0.944098    3.451561    0.183804    0.084792    0.010783    0.661059    
#> 132: 0.296405    0.982257    3.432946    0.183953    0.101790    0.010628    0.686607    
#> 133: 0.305383    0.956643    3.445962    0.175863    0.122323    0.011580    0.684481    
#> 134: 0.342006    0.927485    3.460654    0.173711    0.116207    0.013671    0.681138    
#> 135: 0.321243    0.935060    3.462208    0.180143    0.119344    0.013019    0.664428    
#> 136: 0.342900    0.900562    3.471455    0.197881    0.113376    0.014058    0.659585    
#> 137: 0.380294    0.914860    3.482547    0.199228    0.107708    0.013355    0.674598    
#> 138: 0.357350    0.939915    3.474422    0.197538    0.102322    0.015065    0.664644    
#> 139: 0.369832    0.938398    3.479670    0.187662    0.097206    0.016862    0.669476    
#> 140: 0.355257    0.948890    3.465408    0.192415    0.098931    0.018484    0.668820    
#> 141: 0.304236    0.954851    3.447856    0.210748    0.094052    0.017560    0.664027    
#> 142: 0.347001    0.950509    3.467998    0.225181    0.089350    0.016682    0.672969    
#> 143: 0.305162    0.962716    3.451148    0.223360    0.091801    0.015848    0.671358    
#> 144: 0.341795    0.938059    3.466558    0.212192    0.087211    0.015055    0.652552    
#> 145: 0.300479    0.962880    3.447085    0.201582    0.082851    0.014303    0.665194    
#> 146: 0.285447    0.966966    3.446940    0.192831    0.089311    0.015465    0.668927    
#> 147: 0.268667    0.965365    3.441286    0.183189    0.084846    0.016706    0.651671    
#> 148: 0.277108    0.977672    3.450043    0.174030    0.080603    0.016533    0.668118    
#> 149: 0.272658    0.961777    3.451275    0.165328    0.088857    0.015707    0.672752    
#> 150: 0.292549    0.976091    3.437059    0.165877    0.092090    0.014921    0.675402    
#> 151: 0.262509    0.987988    3.433507    0.171660    0.104566    0.014273    0.673768    
#> 152: 0.302941    0.976837    3.450573    0.161640    0.088073    0.014054    0.674672    
#> 153: 0.301393    0.960460    3.454496    0.178748    0.093108    0.011472    0.688520    
#> 154: 0.331094    0.968952    3.458700    0.183575    0.099316    0.013747    0.685030    
#> 155: 0.309066    0.947949    3.446598    0.208076    0.110971    0.012256    0.666588    
#> 156: 0.329907    0.949852    3.459418    0.203663    0.097195    0.011025    0.688937    
#> 157: 0.319887    0.944713    3.458704    0.163706    0.125143    0.009919    0.686247    
#> 158: 0.352198    0.955994    3.457641    0.193837    0.118771    0.009116    0.667071    
#> 159: 0.299168    0.947971    3.460171    0.163053    0.110247    0.009742    0.664182    
#> 160: 0.320755    0.918893    3.465013    0.174514    0.120415    0.011941    0.674289    
#> 161: 0.343230    0.918886    3.458315    0.188333    0.104569    0.012416    0.678902    
#> 162: 0.304232    0.960402    3.445789    0.202863    0.099893    0.011760    0.673454    
#> 163: 0.328257    0.948321    3.443307    0.190287    0.122344    0.013966    0.668566    
#> 164: 0.318651    0.952434    3.448467    0.204941    0.112530    0.014119    0.670571    
#> 165: 0.350376    0.953318    3.455443    0.200044    0.094315    0.014317    0.656215    
#> 166: 0.343984    0.989842    3.449005    0.208150    0.116288    0.013762    0.658896    
#> 167: 0.348589    0.979553    3.461124    0.221741    0.115401    0.012324    0.664241    
#> 168: 0.341203    0.955120    3.453250    0.201161    0.096722    0.010035    0.662572    
#> 169: 0.351046    0.987023    3.452749    0.197560    0.110782    0.008848    0.675155    
#> 170: 0.335784    0.963720    3.446756    0.159595    0.101611    0.008824    0.670784    
#> 171: 0.288929    0.960047    3.444436    0.174199    0.103285    0.008988    0.649561    
#> 172: 0.292944    0.981679    3.443828    0.153256    0.098129    0.009159    0.661199    
#> 173: 0.279291    0.974564    3.432981    0.161103    0.089310    0.010095    0.669878    
#> 174: 0.294824    0.967024    3.438268    0.158481    0.093169    0.009504    0.675683    
#> 175: 0.279738    0.971458    3.426901    0.171733    0.094828    0.008091    0.679995    
#> 176: 0.274330    0.989234    3.434319    0.152590    0.109615    0.006850    0.674188    
#> 177: 0.296132    0.973540    3.440522    0.190166    0.106451    0.007525    0.665145    
#> 178: 0.302690    0.940679    3.441871    0.198761    0.108070    0.008941    0.645464    
#> 179: 0.316691    0.984294    3.438514    0.192367    0.090994    0.010487    0.666005    
#> 180: 0.287643    0.988457    3.435777    0.155108    0.086545    0.011859    0.678767    
#> 181: 0.275071    0.977325    3.418629    0.150078    0.075178    0.008994    0.687282    
#> 182: 0.240369    0.990164    3.412369    0.206696    0.081020    0.010600    0.684281    
#> 183: 0.249476    1.004851    3.417385    0.171783    0.075758    0.010032    0.688965    
#> 184: 0.287406    0.973275    3.425215    0.162562    0.076347    0.009631    0.698151    
#> 185: 0.252842    0.999140    3.421824    0.183031    0.085998    0.009508    0.689324    
#> 186: 0.247079    1.003873    3.426537    0.222608    0.090559    0.013095    0.669442    
#> 187: 0.238257    0.987384    3.428023    0.216473    0.081635    0.014592    0.663644    
#> 188: 0.259019    1.006026    3.421533    0.213776    0.088024    0.014442    0.675758    
#> 189: 0.291044    0.995022    3.431881    0.181911    0.085094    0.016700    0.675417    
#> 190: 0.272440    0.980432    3.440842    0.175850    0.077715    0.013425    0.678055    
#> 191: 0.253098    1.003129    3.425204    0.170445    0.079950    0.010915    0.661224    
#> 192: 0.275014    0.996725    3.432224    0.160123    0.085789    0.010956    0.664237    
#> 193: 0.293591    0.997194    3.425817    0.170841    0.085105    0.009210    0.662555    
#> 194: 0.258871    0.988852    3.417635    0.167018    0.098248    0.008406    0.669784    
#> 195: 0.261158    0.974346    3.419464    0.160587    0.082316    0.007864    0.675062    
#> 196: 0.261308    0.978429    3.423551    0.180589    0.085758    0.008244    0.682716    
#> 197: 0.236206    0.970872    3.444143    0.161505    0.101752    0.006843    0.702771    
#> 198: 0.278924    0.958207    3.436522    0.165767    0.105175    0.007974    0.676305    
#> 199: 0.274707    0.978237    3.428445    0.131268    0.117414    0.006448    0.673301    
#> 200: 0.258926    0.981575    3.427834    0.159723    0.123453    0.006599    0.692264    
#> 201: 0.262644    0.976230    3.431051    0.155410    0.124231    0.007433    0.691461    
#> 202: 0.268916    0.973677    3.432546    0.161174    0.118796    0.007418    0.688300    
#> 203: 0.279154    0.970138    3.432286    0.167325    0.111687    0.007187    0.687319    
#> 204: 0.286380    0.968696    3.433412    0.170403    0.111986    0.007003    0.692190    
#> 205: 0.286117    0.972926    3.433406    0.173482    0.110637    0.006882    0.693157    
#> 206: 0.287470    0.973365    3.433928    0.171765    0.110848    0.006990    0.693313    
#> 207: 0.287640    0.971206    3.433692    0.175880    0.111817    0.006996    0.695202    
#> 208: 0.287196    0.970256    3.434115    0.175180    0.109655    0.007039    0.693524    
#> 209: 0.289232    0.968121    3.434236    0.175723    0.107268    0.007140    0.691026    
#> 210: 0.290881    0.967288    3.434539    0.176492    0.108136    0.007213    0.687942    
#> 211: 0.293163    0.967611    3.435952    0.177986    0.107732    0.007252    0.684664    
#> 212: 0.295130    0.967193    3.436684    0.178038    0.107461    0.007151    0.683435    
#> 213: 0.296635    0.965838    3.437332    0.175688    0.106663    0.007318    0.683141    
#> 214: 0.298053    0.965534    3.437765    0.173896    0.106373    0.007469    0.682406    
#> 215: 0.298245    0.964927    3.438648    0.173484    0.106056    0.007597    0.681244    
#> 216: 0.301125    0.963542    3.439137    0.174828    0.107275    0.007691    0.681537    
#> 217: 0.302456    0.964176    3.439512    0.175384    0.106788    0.007715    0.680499    
#> 218: 0.301996    0.964225    3.439394    0.175679    0.107326    0.007728    0.679836    
#> 219: 0.300595    0.963578    3.438896    0.175997    0.106940    0.007829    0.678562    
#> 220: 0.299607    0.963387    3.439280    0.176430    0.106660    0.007919    0.677950    
#> 221: 0.298083    0.963706    3.439011    0.177046    0.106133    0.008005    0.677358    
#> 222: 0.299171    0.963068    3.439320    0.176586    0.105930    0.008194    0.677149    
#> 223: 0.300502    0.962983    3.439566    0.176203    0.105320    0.008317    0.676820    
#> 224: 0.302482    0.963002    3.440225    0.176296    0.104301    0.008360    0.676464    
#> 225: 0.302924    0.961162    3.440814    0.176810    0.103905    0.008385    0.677024    
#> 226: 0.302712    0.960184    3.440761    0.177948    0.103785    0.008346    0.676846    
#> 227: 0.302591    0.959470    3.441150    0.178940    0.103726    0.008313    0.676392    
#> 228: 0.302619    0.959720    3.440904    0.179953    0.104261    0.008274    0.676098    
#> 229: 0.302349    0.959088    3.440694    0.180315    0.104585    0.008228    0.675343    
#> 230: 0.302633    0.958475    3.440400    0.181014    0.104767    0.008144    0.675855    
#> 231: 0.301956    0.959007    3.440489    0.181169    0.104915    0.008066    0.676222    
#> 232: 0.300773    0.958871    3.440776    0.180989    0.104833    0.008038    0.676501    
#> 233: 0.300687    0.958108    3.440702    0.181281    0.104810    0.008059    0.676843    
#> 234: 0.300741    0.958132    3.440686    0.181569    0.105560    0.008106    0.676440    
#> 235: 0.301003    0.958029    3.440571    0.182158    0.105393    0.008049    0.676786    
#> 236: 0.301079    0.958642    3.440383    0.183125    0.105952    0.008036    0.676960    
#> 237: 0.301946    0.958679    3.440431    0.183474    0.106250    0.008117    0.677453    
#> 238: 0.302206    0.958728    3.440448    0.184985    0.106641    0.008129    0.677664    
#> 239: 0.301850    0.959117    3.440413    0.185376    0.106888    0.008136    0.677599    
#> 240: 0.302099    0.958770    3.440526    0.185962    0.107201    0.008131    0.677128    
#> 241: 0.302720    0.957524    3.440843    0.185744    0.107062    0.008104    0.677123    
#> 242: 0.302703    0.956914    3.440958    0.185399    0.107125    0.008079    0.677714    
#> 243: 0.302003    0.957398    3.441009    0.185590    0.107144    0.008064    0.678046    
#> 244: 0.301480    0.957615    3.441143    0.184848    0.107115    0.008035    0.678563    
#> 245: 0.300979    0.957323    3.441224    0.184802    0.106960    0.008028    0.678834    
#> 246: 0.301024    0.957347    3.441338    0.184234    0.106474    0.008096    0.679088    
#> 247: 0.301000    0.956900    3.441663    0.184110    0.106162    0.008111    0.679085    
#> 248: 0.301351    0.957027    3.441857    0.183567    0.106231    0.008093    0.679110    
#> 249: 0.301178    0.957079    3.441915    0.183793    0.106446    0.008091    0.678994    
#> 250: 0.301786    0.957162    3.442216    0.183936    0.106536    0.008100    0.679101    
#> 251: 0.302328    0.957366    3.442616    0.183687    0.106683    0.008077    0.679730    
#> 252: 0.302933    0.957315    3.442996    0.184156    0.107116    0.008061    0.679710    
#> 253: 0.302897    0.957234    3.443087    0.183939    0.107204    0.008067    0.679551    
#> 254: 0.303348    0.957278    3.443324    0.183164    0.107288    0.008043    0.679473    
#> 255: 0.303466    0.957718    3.443560    0.182279    0.107201    0.008062    0.679791    
#> 256: 0.303737    0.957729    3.443688    0.181994    0.106964    0.008052    0.679861    
#> 257: 0.303686    0.957348    3.443832    0.182203    0.106874    0.008087    0.679964    
#> 258: 0.303363    0.957021    3.443887    0.182512    0.106757    0.008091    0.680249    
#> 259: 0.303210    0.957031    3.443903    0.182560    0.106578    0.008108    0.680154    
#> 260: 0.303136    0.957138    3.444010    0.182638    0.106721    0.008089    0.680101    
#> 261: 0.302792    0.957200    3.443977    0.182464    0.106584    0.008066    0.680125    
#> 262: 0.302876    0.957338    3.443970    0.182808    0.106324    0.008079    0.679895    
#> 263: 0.302766    0.957670    3.443977    0.182823    0.106541    0.008096    0.679749    
#> 264: 0.302756    0.957640    3.443964    0.183285    0.106354    0.008097    0.680151    
#> 265: 0.302754    0.957878    3.443895    0.183733    0.106385    0.008113    0.680556    
#> 266: 0.302523    0.958233    3.443831    0.184346    0.106317    0.008125    0.680672    
#> 267: 0.302489    0.958437    3.443844    0.184929    0.106406    0.008144    0.680477    
#> 268: 0.302484    0.958427    3.443706    0.184646    0.106412    0.008151    0.680329    
#> 269: 0.303227    0.958450    3.443693    0.184707    0.106445    0.008167    0.680329    
#> 270: 0.303182    0.958775    3.443557    0.184631    0.106479    0.008170    0.680105    
#> 271: 0.303103    0.959093    3.443311    0.184724    0.106526    0.008170    0.680140    
#> 272: 0.302931    0.959079    3.443073    0.184796    0.106580    0.008135    0.680187    
#> 273: 0.302470    0.959394    3.442907    0.184914    0.106648    0.008119    0.680076    
#> 274: 0.302179    0.959548    3.442949    0.184927    0.106603    0.008126    0.680062    
#> 275: 0.302206    0.959731    3.442857    0.185278    0.106408    0.008159    0.680173    
#> 276: 0.301969    0.959991    3.443012    0.185154    0.106551    0.008204    0.679992    
#> 277: 0.302257    0.960139    3.443216    0.185077    0.106409    0.008246    0.679641    
#> 278: 0.302296    0.959915    3.443445    0.185255    0.106316    0.008273    0.679549    
#> 279: 0.302406    0.959813    3.443515    0.185338    0.106298    0.008307    0.679615    
#> 280: 0.302317    0.959852    3.443578    0.185069    0.105995    0.008334    0.679386    
#> 281: 0.302045    0.960040    3.443616    0.184919    0.105717    0.008344    0.679469    
#> 282: 0.301837    0.960321    3.443629    0.184782    0.105748    0.008345    0.679365    
#> 283: 0.301988    0.960387    3.443689    0.184850    0.105635    0.008370    0.679473    
#> 284: 0.301876    0.960286    3.443689    0.184977    0.105428    0.008382    0.679388    
#> 285: 0.301865    0.960577    3.443580    0.185469    0.105413    0.008404    0.679470    
#> 286: 0.301732    0.960744    3.443487    0.185713    0.105237    0.008427    0.679509    
#> 287: 0.301776    0.961065    3.443332    0.186230    0.105163    0.008442    0.679295    
#> 288: 0.301801    0.960973    3.443196    0.186174    0.105165    0.008465    0.679308    
#> 289: 0.301829    0.961042    3.443122    0.186337    0.105105    0.008488    0.679287    
#> 290: 0.301821    0.961004    3.443055    0.186201    0.105113    0.008482    0.679306    
#> 291: 0.302239    0.961145    3.443140    0.186154    0.104978    0.008485    0.679336    
#> 292: 0.302296    0.960958    3.443151    0.186091    0.104982    0.008476    0.679277    
#> 293: 0.302075    0.961160    3.442984    0.185791    0.104896    0.008476    0.679257    
#> 294: 0.301758    0.961419    3.442785    0.185654    0.104774    0.008464    0.679221    
#> 295: 0.301539    0.961333    3.442685    0.185776    0.104718    0.008458    0.679078    
#> 296: 0.301485    0.961327    3.442669    0.185875    0.104557    0.008487    0.679207    
#> 297: 0.301730    0.961374    3.442561    0.185844    0.104480    0.008491    0.679201    
#> 298: 0.301742    0.961346    3.442481    0.186008    0.104425    0.008487    0.679040    
#> 299: 0.301709    0.961489    3.442420    0.186007    0.104369    0.008488    0.678856    
#> 300: 0.301788    0.961450    3.442503    0.186116    0.104313    0.008476    0.678796    
#> 301: 0.301903    0.961419    3.442509    0.186035    0.104432    0.008480    0.678845    
#> 302: 0.301620    0.961620    3.442387    0.186059    0.104499    0.008483    0.678869    
#> 303: 0.301186    0.961781    3.442219    0.186219    0.104381    0.008497    0.678894    
#> 304: 0.301179    0.962080    3.442158    0.186259    0.104397    0.008502    0.678876    
#> 305: 0.300991    0.961831    3.442145    0.186154    0.104268    0.008518    0.678791    
#> 306: 0.300563    0.961822    3.441979    0.185906    0.104250    0.008534    0.678794    
#> 307: 0.300338    0.961882    3.441851    0.185906    0.104300    0.008559    0.678936    
#> 308: 0.299867    0.961928    3.441743    0.185779    0.104326    0.008583    0.678985    
#> 309: 0.299775    0.961794    3.441648    0.185677    0.104176    0.008606    0.679087    
#> 310: 0.299895    0.961757    3.441529    0.185685    0.104167    0.008629    0.679127    
#> 311: 0.299915    0.961669    3.441551    0.185200    0.104027    0.008648    0.679007    
#> 312: 0.299714    0.961539    3.441489    0.184995    0.104002    0.008657    0.678939    
#> 313: 0.299183    0.961350    3.441359    0.184763    0.103943    0.008686    0.679011    
#> 314: 0.298746    0.961513    3.441213    0.184671    0.103889    0.008702    0.679189    
#> 315: 0.298270    0.961806    3.441070    0.184504    0.103984    0.008713    0.679401    
#> 316: 0.298222    0.961949    3.440999    0.184206    0.104124    0.008722    0.679372    
#> 317: 0.298000    0.962102    3.440896    0.184055    0.104266    0.008709    0.679419    
#> 318: 0.298122    0.962255    3.440810    0.184267    0.104306    0.008713    0.679358    
#> 319: 0.297999    0.962280    3.440689    0.184187    0.104333    0.008724    0.679396    
#> 320: 0.297608    0.962433    3.440583    0.184518    0.104412    0.008744    0.679455    
#> 321: 0.297318    0.962701    3.440358    0.184792    0.104411    0.008759    0.679414    
#> 322: 0.297208    0.962687    3.440177    0.185052    0.104522    0.008791    0.679299    
#> 323: 0.296813    0.962822    3.440103    0.185193    0.104507    0.008802    0.679203    
#> 324: 0.296711    0.962953    3.440104    0.185161    0.104588    0.008801    0.678976    
#> 325: 0.296828    0.963043    3.440107    0.185125    0.104562    0.008786    0.678883    
#> 326: 0.296973    0.963007    3.440060    0.185266    0.104662    0.008784    0.678714    
#> 327: 0.297232    0.963068    3.440070    0.185639    0.104689    0.008790    0.678704    
#> 328: 0.297424    0.963125    3.440067    0.185573    0.104747    0.008794    0.678580    
#> 329: 0.297571    0.963120    3.440122    0.185400    0.104882    0.008785    0.678636    
#> 330: 0.297444    0.963187    3.440118    0.185271    0.104738    0.008785    0.678675    
#> 331: 0.297593    0.963286    3.440059    0.185241    0.104556    0.008808    0.678598    
#> 332: 0.297589    0.963305    3.440054    0.185173    0.104454    0.008816    0.678601    
#> 333: 0.297483    0.963267    3.440015    0.185394    0.104384    0.008849    0.678541    
#> 334: 0.297237    0.963162    3.439908    0.185383    0.104352    0.008865    0.678476    
#> 335: 0.296928    0.963278    3.439742    0.185707    0.104294    0.008887    0.678404    
#> 336: 0.296445    0.963419    3.439628    0.185863    0.104215    0.008902    0.678418    
#> 337: 0.296182    0.963794    3.439502    0.186164    0.104118    0.008903    0.678425    
#> 338: 0.296276    0.963862    3.439478    0.186505    0.104048    0.008897    0.678303    
#> 339: 0.296094    0.963895    3.439447    0.186548    0.104025    0.008890    0.678184    
#> 340: 0.295928    0.963826    3.439435    0.186585    0.104074    0.008890    0.678086    
#> 341: 0.295875    0.963962    3.439436    0.186646    0.104135    0.008898    0.678003    
#> 342: 0.295716    0.963954    3.439394    0.186709    0.104190    0.008902    0.677855    
#> 343: 0.295372    0.963962    3.439374    0.186565    0.104216    0.008891    0.677877    
#> 344: 0.295263    0.963971    3.439353    0.186436    0.104241    0.008886    0.678047    
#> 345: 0.295016    0.963959    3.439293    0.186332    0.104324    0.008885    0.678235    
#> 346: 0.294855    0.964017    3.439162    0.186314    0.104281    0.008884    0.678278    
#> 347: 0.294827    0.964065    3.439037    0.186242    0.104270    0.008888    0.678419    
#> 348: 0.294693    0.964032    3.438988    0.186243    0.104277    0.008882    0.678461    
#> 349: 0.294594    0.963804    3.438961    0.186266    0.104261    0.008868    0.678648    
#> 350: 0.294399    0.963708    3.438908    0.186340    0.104296    0.008854    0.678681    
#> 351: 0.294251    0.963844    3.438813    0.186459    0.104352    0.008841    0.678750    
#> 352: 0.293863    0.964029    3.438731    0.186697    0.104500    0.008841    0.678873    
#> 353: 0.293765    0.964235    3.438652    0.186851    0.104413    0.008865    0.678772    
#> 354: 0.293747    0.964340    3.438498    0.187222    0.104307    0.008891    0.678664    
#> 355: 0.293907    0.964236    3.438435    0.187329    0.104300    0.008896    0.678718    
#> 356: 0.293860    0.964180    3.438442    0.187161    0.104351    0.008889    0.678835    
#> 357: 0.293893    0.964254    3.438412    0.187003    0.104322    0.008890    0.678821    
#> 358: 0.293956    0.964247    3.438470    0.186858    0.104208    0.008901    0.678758    
#> 359: 0.293822    0.964405    3.438457    0.186780    0.104137    0.008901    0.678781    
#> 360: 0.293627    0.964468    3.438338    0.186613    0.104210    0.008895    0.678786    
#> 361: 0.293379    0.964497    3.438225    0.186448    0.104152    0.008893    0.678702    
#> 362: 0.293373    0.964525    3.438140    0.186223    0.104089    0.008906    0.678616    
#> 363: 0.293206    0.964556    3.438070    0.186105    0.104120    0.008905    0.678434    
#> 364: 0.293189    0.964626    3.438051    0.186188    0.104160    0.008903    0.678426    
#> 365: 0.293041    0.964603    3.438064    0.186076    0.104151    0.008910    0.678387    
#> 366: 0.292937    0.964594    3.437978    0.185948    0.104095    0.008923    0.678355    
#> 367: 0.292996    0.964727    3.437962    0.186015    0.104178    0.008921    0.678367    
#> 368: 0.293217    0.964828    3.437918    0.186282    0.104186    0.008924    0.678254    
#> 369: 0.293216    0.964833    3.437886    0.186776    0.104218    0.008933    0.678108    
#> 370: 0.293285    0.964916    3.437837    0.186960    0.104161    0.008944    0.677950    
#> 371: 0.293203    0.965007    3.437730    0.187223    0.104103    0.008960    0.677837    
#> 372: 0.293126    0.965090    3.437686    0.187550    0.104131    0.008961    0.677828    
#> 373: 0.292998    0.965234    3.437637    0.187808    0.104085    0.008963    0.677844    
#> 374: 0.293040    0.965322    3.437580    0.187781    0.104079    0.008969    0.677826    
#> 375: 0.292952    0.965471    3.437547    0.187746    0.104087    0.008969    0.677772    
#> 376: 0.292853    0.965596    3.437500    0.187755    0.104186    0.008971    0.677663    
#> 377: 0.292800    0.965635    3.437460    0.187767    0.104251    0.008963    0.677659    
#> 378: 0.292623    0.965672    3.437412    0.187773    0.104250    0.008963    0.677655    
#> 379: 0.292445    0.965584    3.437384    0.187882    0.104177    0.008974    0.677637    
#> 380: 0.292242    0.965640    3.437321    0.187959    0.104136    0.009002    0.677533    
#> 381: 0.291949    0.965769    3.437243    0.187997    0.104139    0.009018    0.677494    
#> 382: 0.291735    0.965804    3.437186    0.187841    0.104105    0.009022    0.677445    
#> 383: 0.291766    0.965861    3.437151    0.187759    0.104078    0.009017    0.677447    
#> 384: 0.291667    0.965933    3.437152    0.187656    0.104104    0.009024    0.677450    
#> 385: 0.291743    0.965997    3.437181    0.187709    0.104130    0.009041    0.677451    
#> 386: 0.291786    0.966326    3.437153    0.187685    0.104054    0.009040    0.677573    
#> 387: 0.291802    0.966478    3.437184    0.187639    0.103999    0.009046    0.677541    
#> 388: 0.291799    0.966481    3.437213    0.187558    0.103935    0.009048    0.677508    
#> 389: 0.291862    0.966282    3.437252    0.187597    0.103881    0.009037    0.677548    
#> 390: 0.291887    0.966328    3.437275    0.187707    0.103857    0.009021    0.677693    
#> 391: 0.292008    0.966297    3.437261    0.187681    0.103822    0.009016    0.677676    
#> 392: 0.292084    0.966233    3.437314    0.187653    0.103823    0.009001    0.677704    
#> 393: 0.292064    0.966108    3.437282    0.187609    0.103809    0.009000    0.677671    
#> 394: 0.292047    0.966103    3.437264    0.187497    0.103877    0.008988    0.677722    
#> 395: 0.292236    0.966157    3.437302    0.187434    0.103964    0.008977    0.677754    
#> 396: 0.292512    0.966179    3.437357    0.187346    0.103950    0.008965    0.677721    
#> 397: 0.292677    0.966026    3.437442    0.187509    0.103894    0.008967    0.677712    
#> 398: 0.292912    0.965888    3.437560    0.187665    0.103893    0.008982    0.677697    
#> 399: 0.293098    0.965831    3.437692    0.187739    0.103894    0.008997    0.677651    
#> 400: 0.293232    0.965814    3.437764    0.187798    0.103910    0.009004    0.677602    
#> 401: 0.293291    0.965770    3.437806    0.187744    0.103855    0.009009    0.677596    
#> 402: 0.293361    0.965791    3.437849    0.187744    0.103815    0.009015    0.677607    
#> 403: 0.293519    0.965743    3.437886    0.187785    0.103809    0.009022    0.677547    
#> 404: 0.293564    0.965684    3.437871    0.187529    0.103757    0.009021    0.677499    
#> 405: 0.293575    0.965734    3.437890    0.187541    0.103746    0.009029    0.677426    
#> 406: 0.293722    0.965716    3.437928    0.187572    0.103802    0.009037    0.677482    
#> 407: 0.293777    0.965637    3.437937    0.187678    0.103921    0.009026    0.677432    
#> 408: 0.293765    0.965628    3.437930    0.187711    0.103998    0.009015    0.677440    
#> 409: 0.293658    0.965557    3.437870    0.187628    0.104007    0.009008    0.677440    
#> 410: 0.293586    0.965533    3.437814    0.187492    0.104106    0.009004    0.677568    
#> 411: 0.293611    0.965339    3.437794    0.187618    0.104156    0.008992    0.677660    
#> 412: 0.293501    0.965346    3.437751    0.187559    0.104255    0.008979    0.677722    
#> 413: 0.293322    0.965389    3.437647    0.187404    0.104286    0.008973    0.677848    
#> 414: 0.293116    0.965378    3.437630    0.187343    0.104329    0.008962    0.677826    
#> 415: 0.293134    0.965358    3.437605    0.187298    0.104390    0.008963    0.677781    
#> 416: 0.293122    0.965437    3.437572    0.187350    0.104487    0.008965    0.677721    
#> 417: 0.293040    0.965457    3.437539    0.187428    0.104569    0.008964    0.677716    
#> 418: 0.292727    0.965599    3.437449    0.187540    0.104652    0.008956    0.677767    
#> 419: 0.292603    0.965736    3.437373    0.187581    0.104674    0.008951    0.677840    
#> 420: 0.292544    0.965791    3.437323    0.187662    0.104693    0.008942    0.677817    
#> 421: 0.292362    0.965827    3.437312    0.187687    0.104778    0.008928    0.677840    
#> 422: 0.292382    0.965783    3.437304    0.187733    0.104810    0.008920    0.677793    
#> 423: 0.292438    0.965687    3.437302    0.187755    0.104914    0.008916    0.677837    
#> 424: 0.292304    0.965664    3.437280    0.187814    0.104878    0.008909    0.677888    
#> 425: 0.292449    0.965698    3.437270    0.187898    0.104766    0.008905    0.677972    
#> 426: 0.292534    0.965809    3.437278    0.187918    0.104684    0.008907    0.677942    
#> 427: 0.292484    0.965810    3.437288    0.187874    0.104596    0.008909    0.677866    
#> 428: 0.292382    0.965796    3.437282    0.187787    0.104599    0.008912    0.677805    
#> 429: 0.292412    0.965801    3.437286    0.187751    0.104575    0.008915    0.677728    
#> 430: 0.292398    0.965851    3.437289    0.187721    0.104557    0.008916    0.677643    
#> 431: 0.292253    0.965793    3.437247    0.187619    0.104506    0.008912    0.677607    
#> 432: 0.292179    0.965829    3.437261    0.187596    0.104475    0.008916    0.677564    
#> 433: 0.292227    0.965934    3.437321    0.187701    0.104426    0.008930    0.677558    
#> 434: 0.292225    0.965893    3.437379    0.187777    0.104389    0.008940    0.677503    
#> 435: 0.292339    0.965798    3.437420    0.187633    0.104323    0.008942    0.677483    
#> 436: 0.292384    0.965601    3.437474    0.187417    0.104230    0.008942    0.677533    
#> 437: 0.292430    0.965389    3.437522    0.187354    0.104241    0.008949    0.677592    
#> 438: 0.292588    0.965410    3.437570    0.187303    0.104182    0.008963    0.677532    
#> 439: 0.292685    0.965447    3.437590    0.187246    0.104242    0.008957    0.677498    
#> 440: 0.292627    0.965443    3.437628    0.187092    0.104246    0.008952    0.677481    
#> 441: 0.292676    0.965398    3.437693    0.186840    0.104313    0.008947    0.677506    
#> 442: 0.292707    0.965420    3.437739    0.186823    0.104421    0.008947    0.677464    
#> 443: 0.292755    0.965468    3.437752    0.186855    0.104447    0.008958    0.677393    
#> 444: 0.292800    0.965505    3.437717    0.186858    0.104455    0.008968    0.677349    
#> 445: 0.292758    0.965498    3.437674    0.186959    0.104354    0.008978    0.677353    
#> 446: 0.292588    0.965543    3.437643    0.187046    0.104282    0.008982    0.677310    
#> 447: 0.292690    0.965544    3.437672    0.187036    0.104202    0.008997    0.677250    
#> 448: 0.292604    0.965585    3.437686    0.186962    0.104170    0.009012    0.677156    
#> 449: 0.292702    0.965618    3.437790    0.186862    0.104143    0.009020    0.677133    
#> 450: 0.292768    0.965526    3.437850    0.186754    0.104072    0.009041    0.677143    
#> 451: 0.292967    0.965493    3.437900    0.186775    0.104051    0.009055    0.677105    
#> 452: 0.293002    0.965543    3.437899    0.186735    0.104027    0.009059    0.677080    
#> 453: 0.292912    0.965524    3.437901    0.186696    0.104013    0.009052    0.677009    
#> 454: 0.292892    0.965627    3.437857    0.186497    0.104043    0.009049    0.676996    
#> 455: 0.292918    0.965652    3.437817    0.186491    0.104070    0.009045    0.676967    
#> 456: 0.292938    0.965598    3.437824    0.186467    0.104028    0.009052    0.676921    
#> 457: 0.292951    0.965461    3.437891    0.186446    0.103987    0.009061    0.676864    
#> 458: 0.292973    0.965499    3.437954    0.186437    0.103939    0.009069    0.676757    
#> 459: 0.292945    0.965586    3.437982    0.186421    0.103934    0.009066    0.676729    
#> 460: 0.292880    0.965582    3.437962    0.186348    0.103936    0.009071    0.676705    
#> 461: 0.292813    0.965608    3.437975    0.186455    0.103915    0.009079    0.676623    
#> 462: 0.292810    0.965639    3.438019    0.186479    0.103890    0.009079    0.676577    
#> 463: 0.292968    0.965689    3.438061    0.186550    0.103896    0.009073    0.676549    
#> 464: 0.293093    0.965688    3.438076    0.186592    0.103909    0.009075    0.676487    
#> 465: 0.293169    0.965558    3.438102    0.186540    0.103895    0.009073    0.676497    
#> 466: 0.293226    0.965516    3.438091    0.186615    0.103877    0.009075    0.676529    
#> 467: 0.293217    0.965446    3.438102    0.186446    0.103856    0.009076    0.676471    
#> 468: 0.293491    0.965428    3.438189    0.186503    0.103836    0.009088    0.676484    
#> 469: 0.293590    0.965505    3.438231    0.186537    0.103786    0.009102    0.676408    
#> 470: 0.293546    0.965521    3.438225    0.186533    0.103753    0.009120    0.676298    
#> 471: 0.293357    0.965455    3.438196    0.186529    0.103669    0.009128    0.676280    
#> 472: 0.293305    0.965396    3.438193    0.186385    0.103607    0.009139    0.676263    
#> 473: 0.293216    0.965436    3.438182    0.186259    0.103551    0.009148    0.676186    
#> 474: 0.293163    0.965412    3.438178    0.186316    0.103568    0.009159    0.676098    
#> 475: 0.293271    0.965471    3.438149    0.186281    0.103533    0.009163    0.676092    
#> 476: 0.293301    0.965370    3.438153    0.186443    0.103492    0.009172    0.676090    
#> 477: 0.293366    0.965333    3.438197    0.186501    0.103431    0.009186    0.676012    
#> 478: 0.293316    0.965353    3.438181    0.186546    0.103366    0.009201    0.675955    
#> 479: 0.293326    0.965423    3.438177    0.186584    0.103306    0.009207    0.675915    
#> 480: 0.293327    0.965498    3.438186    0.186562    0.103280    0.009215    0.675931    
#> 481: 0.293289    0.965471    3.438181    0.186576    0.103270    0.009217    0.675924    
#> 482: 0.293377    0.965442    3.438164    0.186617    0.103261    0.009218    0.675954    
#> 483: 0.293353    0.965356    3.438158    0.186550    0.103295    0.009213    0.675943    
#> 484: 0.293290    0.965278    3.438142    0.186601    0.103300    0.009214    0.675892    
#> 485: 0.293262    0.965299    3.438120    0.186633    0.103360    0.009217    0.675839    
#> 486: 0.293162    0.965309    3.438115    0.186634    0.103356    0.009213    0.675796    
#> 487: 0.293280    0.965305    3.438141    0.186678    0.103359    0.009212    0.675796    
#> 488: 0.293322    0.965195    3.438188    0.186697    0.103418    0.009208    0.675853    
#> 489: 0.293455    0.965171    3.438200    0.186757    0.103470    0.009205    0.675883    
#> 490: 0.293617    0.965111    3.438262    0.186895    0.103502    0.009201    0.675889    
#> 491: 0.293700    0.965103    3.438344    0.186959    0.103565    0.009200    0.675855    
#> 492: 0.293815    0.965060    3.438394    0.187028    0.103616    0.009196    0.675940    
#> 493: 0.293879    0.965086    3.438419    0.186988    0.103636    0.009203    0.675897    
#> 494: 0.294049    0.965143    3.438429    0.186893    0.103608    0.009206    0.675854    
#> 495: 0.294201    0.965174    3.438467    0.186953    0.103514    0.009217    0.675835    
#> 496: 0.294339    0.965265    3.438442    0.187062    0.103485    0.009223    0.675842    
#> 497: 0.294280    0.965331    3.438439    0.187137    0.103486    0.009224    0.675858    
#> 498: 0.294252    0.965372    3.438400    0.187183    0.103435    0.009230    0.675757    
#> 499: 0.294211    0.965379    3.438346    0.187232    0.103455    0.009240    0.675695    
#> 500: 0.294138    0.965417    3.438277    0.187205    0.103394    0.009250    0.675654    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.273307    0.969405    3.446800    0.392401    0.081845    0.016800    1.511835    
#> 002: 0.283988    0.985671    3.475129    0.372781    0.077753    0.015960    0.969431    
#> 003: 0.381538    0.931115    3.497043    0.354142    0.073865    0.015162    0.764659    
#> 004: 0.321232    0.935423    3.481741    0.336435    0.077759    0.014404    0.694976    
#> 005: 0.359211    0.962886    3.484799    0.319613    0.080459    0.014055    0.663019    
#> 006: 0.345728    0.969098    3.470716    0.303633    0.076436    0.014340    0.620478    
#> 007: 0.298234    0.971849    3.452743    0.288451    0.072614    0.016176    0.618894    
#> 008: 0.285334    0.974691    3.449260    0.274029    0.070631    0.018320    0.607701    
#> 009: 0.236011    0.970383    3.442260    0.260327    0.067099    0.019537    0.601393    
#> 010: 0.252364    0.966229    3.444662    0.247311    0.063744    0.021211    0.616236    
#> 011: 0.285689    0.976544    3.447476    0.234945    0.060557    0.021630    0.625268    
#> 012: 0.303799    0.989089    3.439081    0.223198    0.058574    0.020548    0.611430    
#> 013: 0.233819    0.998088    3.422371    0.212038    0.057155    0.019521    0.596369    
#> 014: 0.278460    1.002868    3.432232    0.201436    0.062175    0.018545    0.599442    
#> 015: 0.299940    0.997187    3.453065    0.191364    0.059066    0.019605    0.595481    
#> 016: 0.298148    0.983788    3.462909    0.181796    0.057127    0.025528    0.592013    
#> 017: 0.302658    0.980163    3.458359    0.191792    0.054271    0.024251    0.576711    
#> 018: 0.302102    0.987521    3.440821    0.182202    0.054078    0.023039    0.589028    
#> 019: 0.240594    1.002050    3.430005    0.173092    0.058961    0.021887    0.583110    
#> 020: 0.228414    1.003906    3.424565    0.164438    0.056551    0.020792    0.598366    
#> 021: 0.258433    1.008726    3.436876    0.163358    0.053724    0.019753    0.584882    
#> 022: 0.215645    1.011867    3.431413    0.155190    0.051037    0.020962    0.594260    
#> 023: 0.275061    1.012785    3.436570    0.173286    0.052117    0.023993    0.595851    
#> 024: 0.311915    1.008874    3.443220    0.190235    0.049511    0.022794    0.594217    
#> 025: 0.315281    0.994488    3.446613    0.209030    0.050242    0.023795    0.584896    
#> 026: 0.287264    1.003782    3.441813    0.198578    0.047730    0.028730    0.576483    
#> 027: 0.277825    1.003931    3.443726    0.191917    0.045344    0.027651    0.592388    
#> 028: 0.281369    1.003086    3.440694    0.215456    0.043076    0.028360    0.579395    
#> 029: 0.300960    1.009514    3.433455    0.228430    0.040923    0.027936    0.599446    
#> 030: 0.291277    1.018073    3.433663    0.217008    0.040797    0.028997    0.587478    
#> 031: 0.259361    1.010034    3.433102    0.206158    0.043181    0.027547    0.565329    
#> 032: 0.241636    1.009445    3.429214    0.204967    0.041022    0.026170    0.571566    
#> 033: 0.229726    1.024540    3.425951    0.194719    0.048000    0.028531    0.576516    
#> 034: 0.269484    1.029837    3.433568    0.194370    0.045600    0.027105    0.571804    
#> 035: 0.223435    1.007767    3.423655    0.184651    0.045347    0.029611    0.562794    
#> 036: 0.239425    1.014325    3.427416    0.194851    0.043080    0.031910    0.575980    
#> 037: 0.253640    1.011468    3.429919    0.205748    0.040926    0.030315    0.586848    
#> 038: 0.257416    1.012635    3.421090    0.207841    0.038880    0.034147    0.601451    
#> 039: 0.285022    0.995872    3.443979    0.197449    0.047587    0.032439    0.597518    
#> 040: 0.290938    0.991600    3.446943    0.207157    0.045207    0.030817    0.593647    
#> 041: 0.279792    0.996870    3.441903    0.223009    0.051469    0.032541    0.591372    
#> 042: 0.316578    0.990961    3.444611    0.225760    0.048896    0.030914    0.584087    
#> 043: 0.260815    1.007811    3.426591    0.214472    0.046451    0.029449    0.576568    
#> 044: 0.212825    1.018384    3.417099    0.203749    0.048656    0.027976    0.576934    
#> 045: 0.234156    1.030186    3.407859    0.211520    0.046223    0.026578    0.584623    
#> 046: 0.233018    1.004668    3.421208    0.200944    0.043912    0.029272    0.585372    
#> 047: 0.280720    0.999543    3.439316    0.190897    0.041716    0.029081    0.578195    
#> 048: 0.282598    1.001003    3.444099    0.181352    0.039630    0.027627    0.587000    
#> 049: 0.219486    1.016926    3.431042    0.172285    0.049311    0.026246    0.596939    
#> 050: 0.273401    0.993937    3.439465    0.178755    0.049146    0.024934    0.619404    
#> 051: 0.286135    0.998577    3.433591    0.169817    0.051132    0.023695    0.615940    
#> 052: 0.305255    0.992735    3.451042    0.179392    0.048575    0.026547    0.574712    
#> 053: 0.284245    0.985125    3.440740    0.170422    0.052977    0.025220    0.592007    
#> 054: 0.252927    1.002754    3.444937    0.161901    0.050328    0.029776    0.595660    
#> 055: 0.252021    0.990999    3.446808    0.153806    0.047812    0.028288    0.597452    
#> 056: 0.263405    0.987649    3.444668    0.146116    0.055673    0.028356    0.590010    
#> 057: 0.259419    0.994423    3.447710    0.143529    0.052890    0.027708    0.592318    
#> 058: 0.258916    1.001500    3.434869    0.139450    0.050245    0.026322    0.597078    
#> 059: 0.263522    0.980094    3.436592    0.165250    0.047733    0.027692    0.597271    
#> 060: 0.258533    0.969917    3.443256    0.171784    0.045346    0.030050    0.606335    
#> 061: 0.318409    0.979914    3.464729    0.182808    0.044959    0.031246    0.622669    
#> 062: 0.307466    0.985270    3.460624    0.209631    0.042711    0.032048    0.621945    
#> 063: 0.359917    0.964308    3.457387    0.199149    0.041294    0.030446    0.627418    
#> 064: 0.313173    0.983278    3.464851    0.189192    0.045101    0.028923    0.625575    
#> 065: 0.287692    0.979852    3.442588    0.179732    0.043415    0.027477    0.600484    
#> 066: 0.302781    1.001491    3.452661    0.171926    0.048399    0.026103    0.601643    
#> 067: 0.250802    1.011764    3.426092    0.163330    0.057245    0.024798    0.590098    
#> 068: 0.211784    1.010453    3.431520    0.156352    0.059810    0.024284    0.592629    
#> 069: 0.217085    1.015615    3.415364    0.148687    0.056819    0.023070    0.596461    
#> 070: 0.242214    1.028960    3.430440    0.186533    0.053978    0.027313    0.601927    
#> 071: 0.234665    1.013831    3.421085    0.177206    0.051279    0.027783    0.602386    
#> 072: 0.205265    0.983152    3.419119    0.180427    0.048715    0.028310    0.607779    
#> 073: 0.245396    1.014541    3.430992    0.229758    0.048282    0.027350    0.588257    
#> 074: 0.234663    1.001840    3.420429    0.218270    0.055915    0.026002    0.589998    
#> 075: 0.262781    1.006292    3.434843    0.217290    0.059322    0.026900    0.596240    
#> 076: 0.247522    1.018389    3.436739    0.206426    0.056356    0.030051    0.581673    
#> 077: 0.278568    1.006956    3.440692    0.196104    0.053538    0.028548    0.594056    
#> 078: 0.249957    1.013839    3.439925    0.186299    0.050861    0.028158    0.575609    
#> 079: 0.267308    1.014324    3.432950    0.197958    0.048318    0.029918    0.587244    
#> 080: 0.289342    1.001781    3.444662    0.215873    0.045902    0.034993    0.587936    
#> 081: 0.254210    1.004358    3.435927    0.206412    0.043607    0.033243    0.584677    
#> 082: 0.252435    1.004478    3.436170    0.196091    0.045114    0.031581    0.597773    
#> 083: 0.265530    1.023838    3.430540    0.199612    0.042858    0.030002    0.589532    
#> 084: 0.259034    1.017755    3.430269    0.189632    0.040715    0.028502    0.590615    
#> 085: 0.250773    1.011569    3.448303    0.180150    0.040562    0.030711    0.600969    
#> 086: 0.250469    1.018260    3.430571    0.174025    0.038534    0.030706    0.580607    
#> 087: 0.237794    1.014690    3.426368    0.176227    0.038106    0.030054    0.591725    
#> 088: 0.215791    1.005095    3.429654    0.178396    0.042333    0.028551    0.616648    
#> 089: 0.219803    1.030002    3.415186    0.177549    0.054226    0.028311    0.594121    
#> 090: 0.214415    1.033361    3.412826    0.168672    0.055614    0.026896    0.598849    
#> 091: 0.192628    1.012291    3.395035    0.189735    0.052833    0.029898    0.591231    
#> 092: 0.210067    1.024241    3.411311    0.185231    0.050191    0.028887    0.603281    
#> 093: 0.211367    1.000117    3.421663    0.175969    0.049908    0.027442    0.613093    
#> 094: 0.210501    1.009620    3.418129    0.167171    0.048209    0.026556    0.608126    
#> 095: 0.220626    1.007587    3.426938    0.164616    0.045798    0.026523    0.601460    
#> 096: 0.223502    1.009262    3.423647    0.156385    0.052481    0.025197    0.589748    
#> 097: 0.263307    1.018938    3.433370    0.188790    0.049857    0.023937    0.580468    
#> 098: 0.272097    1.020585    3.442577    0.179351    0.047364    0.025061    0.599338    
#> 099: 0.257605    1.004174    3.431101    0.180130    0.048544    0.023808    0.593608    
#> 100: 0.275655    1.013123    3.438030    0.201787    0.048747    0.024387    0.576495    
#> 101: 0.230546    1.013106    3.419463    0.201640    0.046310    0.025014    0.582731    
#> 102: 0.238632    1.005245    3.414003    0.196163    0.045485    0.023763    0.585282    
#> 103: 0.257659    1.003159    3.433265    0.212489    0.043211    0.025970    0.573573    
#> 104: 0.248298    1.002026    3.436169    0.224548    0.041050    0.028982    0.578965    
#> 105: 0.281559    0.996512    3.443729    0.223815    0.044341    0.027533    0.582548    
#> 106: 0.273766    1.004810    3.435298    0.218151    0.050093    0.026156    0.576614    
#> 107: 0.293984    1.001064    3.447326    0.229059    0.048583    0.030699    0.584126    
#> 108: 0.279529    0.997397    3.446046    0.217606    0.046154    0.029164    0.603603    
#> 109: 0.254527    1.001547    3.447765    0.206726    0.044238    0.028947    0.594435    
#> 110: 0.269819    0.997438    3.438648    0.196390    0.050623    0.027499    0.578244    
#> 111: 0.280533    1.006518    3.433371    0.202304    0.048092    0.027640    0.579629    
#> 112: 0.246889    0.988143    3.427812    0.206132    0.045687    0.029978    0.597235    
#> 113: 0.255174    1.017626    3.437067    0.198846    0.043403    0.028480    0.592466    
#> 114: 0.244390    1.000914    3.437397    0.204526    0.041233    0.027056    0.598517    
#> 115: 0.282787    0.987519    3.434289    0.206897    0.048840    0.027521    0.607032    
#> 116: 0.288301    1.003821    3.431164    0.196552    0.052592    0.026145    0.596688    
#> 117: 0.266835    0.994572    3.449092    0.186725    0.053901    0.024838    0.593889    
#> 118: 0.298447    0.973303    3.456266    0.185864    0.051206    0.025726    0.599494    
#> 119: 0.296591    0.972472    3.457209    0.176634    0.048645    0.024440    0.606383    
#> 120: 0.289207    0.972033    3.454687    0.172320    0.046213    0.024641    0.601767    
#> 121: 0.286573    1.015232    3.449567    0.163704    0.043902    0.024453    0.605824    
#> 122: 0.287529    0.984146    3.449727    0.190240    0.052333    0.023231    0.603390    
#> 123: 0.312750    1.002030    3.445385    0.180728    0.049717    0.022069    0.616353    
#> 124: 0.284167    1.028653    3.447672    0.171692    0.053172    0.023166    0.603097    
#> 125: 0.298672    1.002868    3.442557    0.179095    0.050513    0.022008    0.600200    
#> 126: 0.243157    1.021703    3.429454    0.174696    0.050024    0.020907    0.600693    
#> 127: 0.277926    1.005138    3.424041    0.197891    0.047522    0.021850    0.604955    
#> 128: 0.228463    1.009051    3.435776    0.187996    0.047158    0.020757    0.593777    
#> 129: 0.272613    1.022943    3.437227    0.178596    0.044800    0.025842    0.597500    
#> 130: 0.281621    1.016651    3.431699    0.174771    0.043897    0.027028    0.580630    
#> 131: 0.242397    1.003310    3.420859    0.172158    0.041702    0.025677    0.609037    
#> 132: 0.212762    1.016457    3.401255    0.163551    0.047048    0.026883    0.600602    
#> 133: 0.201597    1.012852    3.414064    0.180296    0.052259    0.033618    0.591959    
#> 134: 0.249319    0.998941    3.438426    0.189719    0.049646    0.033915    0.596056    
#> 135: 0.264717    0.990683    3.446003    0.180233    0.050792    0.032219    0.581629    
#> 136: 0.288293    0.992956    3.447344    0.175370    0.048253    0.030608    0.585179    
#> 137: 0.302828    0.984394    3.455640    0.195441    0.045840    0.029645    0.579094    
#> 138: 0.288354    0.987569    3.453624    0.185669    0.047266    0.028163    0.580434    
#> 139: 0.303797    0.994702    3.461771    0.200397    0.044902    0.033848    0.582416    
#> 140: 0.320417    0.980269    3.463305    0.211032    0.042657    0.035125    0.603440    
#> 141: 0.302782    0.961628    3.463143    0.211166    0.040524    0.033369    0.597108    
#> 142: 0.301916    0.960533    3.462281    0.213204    0.038498    0.033047    0.609651    
#> 143: 0.278431    1.004040    3.451946    0.202543    0.043202    0.031395    0.602067    
#> 144: 0.294797    1.009112    3.462737    0.192416    0.045587    0.029825    0.593011    
#> 145: 0.287093    1.011133    3.453780    0.182795    0.048647    0.028334    0.585956    
#> 146: 0.277499    1.002030    3.454293    0.173656    0.046215    0.026917    0.586763    
#> 147: 0.266529    0.985693    3.446788    0.164973    0.044252    0.027842    0.586036    
#> 148: 0.269506    0.988861    3.448395    0.156724    0.051036    0.026450    0.586819    
#> 149: 0.269433    0.974952    3.447826    0.175799    0.053866    0.025128    0.591575    
#> 150: 0.303436    0.981740    3.439092    0.167009    0.051173    0.023871    0.596279    
#> 151: 0.259906    0.998825    3.440228    0.169004    0.055294    0.022678    0.591451    
#> 152: 0.231474    0.996475    3.426926    0.182137    0.044414    0.022258    0.583941    
#> 153: 0.218828    1.020902    3.421537    0.171802    0.051265    0.021219    0.599904    
#> 154: 0.237745    1.023643    3.426913    0.156563    0.041339    0.021806    0.597542    
#> 155: 0.235877    1.002896    3.426128    0.157368    0.058991    0.016247    0.586144    
#> 156: 0.261755    1.010708    3.431252    0.143195    0.060453    0.013837    0.601429    
#> 157: 0.264095    1.007463    3.433326    0.177720    0.069688    0.016730    0.599987    
#> 158: 0.260506    1.018576    3.433501    0.154559    0.061896    0.018251    0.591452    
#> 159: 0.254384    0.997244    3.438293    0.161434    0.059970    0.019697    0.605284    
#> 160: 0.300402    0.973391    3.453562    0.177969    0.056949    0.023584    0.598844    
#> 161: 0.319516    0.986488    3.457874    0.179515    0.051216    0.023446    0.596657    
#> 162: 0.280800    1.008721    3.444504    0.171965    0.050043    0.024383    0.601978    
#> 163: 0.318342    1.001651    3.443140    0.192132    0.059319    0.025833    0.591969    
#> 164: 0.294171    0.999498    3.445715    0.179747    0.049783    0.025500    0.602159    
#> 165: 0.297091    0.982324    3.454993    0.175320    0.054608    0.027580    0.592330    
#> 166: 0.296822    1.012839    3.444245    0.177471    0.064888    0.023597    0.593332    
#> 167: 0.300154    1.014543    3.449040    0.201852    0.055788    0.023941    0.600490    
#> 168: 0.304010    1.016401    3.456257    0.188127    0.054274    0.023328    0.606014    
#> 169: 0.283455    1.024098    3.449038    0.170996    0.057382    0.024968    0.615742    
#> 170: 0.297309    1.008964    3.446417    0.167791    0.053397    0.025049    0.594367    
#> 171: 0.273920    1.004305    3.443212    0.158037    0.055808    0.019529    0.568770    
#> 172: 0.256653    1.027552    3.443178    0.143981    0.061549    0.018861    0.575318    
#> 173: 0.262453    1.036718    3.425574    0.187936    0.049964    0.016260    0.576036    
#> 174: 0.269438    1.010331    3.443637    0.169559    0.060029    0.017900    0.584664    
#> 175: 0.273797    1.002893    3.438989    0.177129    0.052662    0.020518    0.599977    
#> 176: 0.265681    1.019075    3.442400    0.173652    0.053713    0.021401    0.578545    
#> 177: 0.276314    1.011792    3.442991    0.183806    0.052267    0.017606    0.584189    
#> 178: 0.254017    1.004173    3.436594    0.136005    0.052169    0.017916    0.597513    
#> 179: 0.295947    1.015409    3.448406    0.165521    0.038504    0.019706    0.609018    
#> 180: 0.279864    1.002875    3.448226    0.149993    0.043820    0.023249    0.601494    
#> 181: 0.274278    0.989047    3.429739    0.164530    0.035727    0.021857    0.604457    
#> 182: 0.226968    0.999041    3.421283    0.176888    0.042579    0.022761    0.617674    
#> 183: 0.241479    1.020998    3.427374    0.166186    0.048932    0.021475    0.598656    
#> 184: 0.244054    0.993432    3.436236    0.171499    0.048067    0.021389    0.596301    
#> 185: 0.246239    1.011772    3.428788    0.166398    0.051148    0.021083    0.587973    
#> 186: 0.239468    1.037759    3.421625    0.186754    0.047354    0.022296    0.603207    
#> 187: 0.266578    1.014087    3.418925    0.219597    0.048990    0.024332    0.591265    
#> 188: 0.236239    1.031242    3.423921    0.184178    0.051525    0.028452    0.591920    
#> 189: 0.276150    1.029191    3.433880    0.190155    0.051545    0.024995    0.591182    
#> 190: 0.277666    1.012694    3.439535    0.172842    0.043207    0.023857    0.580706    
#> 191: 0.252269    1.010518    3.433923    0.210113    0.040520    0.026195    0.573142    
#> 192: 0.259560    1.019981    3.435292    0.206680    0.047973    0.029227    0.564867    
#> 193: 0.284560    1.022678    3.430040    0.219489    0.049290    0.025725    0.578547    
#> 194: 0.262803    1.006629    3.430246    0.210472    0.050785    0.025041    0.573594    
#> 195: 0.219295    1.015948    3.421689    0.202824    0.047509    0.025461    0.579335    
#> 196: 0.217395    1.016738    3.421143    0.206152    0.043115    0.024426    0.593225    
#> 197: 0.221590    1.009412    3.434596    0.191741    0.052830    0.024842    0.599697    
#> 198: 0.241308    1.013650    3.424087    0.183892    0.057694    0.027024    0.580249    
#> 199: 0.255009    1.011258    3.431869    0.204715    0.062243    0.026250    0.588915    
#> 200: 0.269050    1.009096    3.431119    0.232394    0.064470    0.023366    0.603268    
#> 201: 0.256668    1.006285    3.435560    0.224173    0.061573    0.024899    0.601077    
#> 202: 0.254506    1.008981    3.433949    0.228321    0.057386    0.025319    0.597774    
#> 203: 0.260970    1.006400    3.432187    0.228358    0.055056    0.025817    0.598155    
#> 204: 0.261072    1.002111    3.432841    0.222507    0.053988    0.026206    0.597277    
#> 205: 0.262969    1.004288    3.432727    0.225168    0.052686    0.025892    0.600822    
#> 206: 0.263164    1.009224    3.431480    0.229624    0.052248    0.025882    0.600269    
#> 207: 0.262116    1.011332    3.430250    0.227978    0.053639    0.025223    0.598462    
#> 208: 0.261766    1.011462    3.430388    0.222789    0.051798    0.025048    0.597156    
#> 209: 0.265563    1.009095    3.431374    0.221534    0.051203    0.024438    0.596750    
#> 210: 0.266207    1.007946    3.432283    0.217891    0.050943    0.024242    0.595679    
#> 211: 0.265927    1.008187    3.432912    0.214341    0.050498    0.023908    0.595218    
#> 212: 0.267449    1.007451    3.433817    0.209512    0.051206    0.023719    0.594357    
#> 213: 0.268848    1.006059    3.435006    0.205966    0.051824    0.023860    0.595054    
#> 214: 0.269933    1.005953    3.435953    0.204719    0.052051    0.023782    0.594455    
#> 215: 0.270685    1.006076    3.436894    0.203678    0.052297    0.023842    0.594021    
#> 216: 0.271531    1.004962    3.437224    0.205084    0.052795    0.023975    0.595466    
#> 217: 0.272347    1.004297    3.437541    0.203886    0.052814    0.023969    0.595046    
#> 218: 0.272056    1.004417    3.437766    0.202462    0.053113    0.023880    0.593734    
#> 219: 0.270799    1.003391    3.437137    0.202399    0.052670    0.023772    0.593433    
#> 220: 0.270230    1.003413    3.437273    0.202722    0.052553    0.024008    0.593105    
#> 221: 0.269487    1.003342    3.436943    0.202863    0.052393    0.024056    0.592943    
#> 222: 0.269139    1.003467    3.436588    0.202208    0.052047    0.024224    0.592874    
#> 223: 0.269623    1.003577    3.436488    0.201556    0.051810    0.024191    0.592311    
#> 224: 0.270912    1.003731    3.436233    0.201593    0.051536    0.024120    0.591703    
#> 225: 0.270159    1.003009    3.436361    0.201903    0.051194    0.024188    0.591268    
#> 226: 0.269449    1.002516    3.435929    0.201125    0.050730    0.024187    0.591128    
#> 227: 0.269075    1.002560    3.435758    0.201094    0.050426    0.024235    0.590594    
#> 228: 0.268039    1.003573    3.435012    0.201604    0.050404    0.024386    0.590012    
#> 229: 0.266461    1.004231    3.434253    0.201613    0.050201    0.024416    0.589766    
#> 230: 0.265527    1.004525    3.433697    0.200919    0.049892    0.024287    0.590152    
#> 231: 0.264782    1.005237    3.433502    0.200255    0.049817    0.024132    0.589980    
#> 232: 0.263312    1.005346    3.433275    0.200157    0.049686    0.024090    0.589714    
#> 233: 0.262157    1.004904    3.433041    0.200492    0.049742    0.024146    0.589258    
#> 234: 0.261169    1.004829    3.432706    0.200952    0.049849    0.024121    0.589117    
#> 235: 0.260570    1.004797    3.432494    0.200695    0.050058    0.024041    0.588999    
#> 236: 0.260597    1.004924    3.432431    0.200691    0.050287    0.024009    0.589058    
#> 237: 0.260905    1.004843    3.432639    0.200599    0.050473    0.024044    0.589488    
#> 238: 0.260804    1.004553    3.432530    0.200904    0.050484    0.024071    0.589700    
#> 239: 0.259788    1.005022    3.431986    0.200674    0.050627    0.023981    0.589725    
#> 240: 0.259042    1.004921    3.432083    0.199896    0.050701    0.023809    0.589907    
#> 241: 0.259061    1.004260    3.432214    0.199689    0.050640    0.023726    0.590109    
#> 242: 0.258416    1.004202    3.431920    0.198848    0.050808    0.023666    0.590190    
#> 243: 0.257746    1.004702    3.431552    0.197740    0.050758    0.023646    0.590486    
#> 244: 0.257161    1.004791    3.431737    0.197429    0.050616    0.023684    0.590487    
#> 245: 0.257299    1.004593    3.431899    0.196938    0.050588    0.023769    0.590751    
#> 246: 0.257250    1.004306    3.431794    0.196703    0.050482    0.023790    0.590931    
#> 247: 0.256336    1.004041    3.431784    0.195824    0.050427    0.023799    0.591556    
#> 248: 0.255881    1.004436    3.431669    0.195770    0.050452    0.023782    0.591591    
#> 249: 0.255084    1.004383    3.431448    0.195405    0.050468    0.023760    0.591898    
#> 250: 0.255227    1.004686    3.431423    0.194863    0.050537    0.023739    0.592146    
#> 251: 0.255846    1.004768    3.431760    0.194775    0.050542    0.023775    0.592209    
#> 252: 0.256724    1.004938    3.432249    0.194529    0.050535    0.023708    0.592463    
#> 253: 0.256897    1.005257    3.432362    0.194179    0.050522    0.023704    0.592797    
#> 254: 0.257410    1.005648    3.432461    0.193931    0.050573    0.023708    0.592984    
#> 255: 0.257779    1.005454    3.432670    0.193703    0.050560    0.023672    0.593104    
#> 256: 0.257894    1.005092    3.432796    0.192835    0.050673    0.023621    0.593434    
#> 257: 0.258306    1.004617    3.432920    0.192585    0.050700    0.023598    0.593468    
#> 258: 0.258509    1.004089    3.433040    0.192401    0.050637    0.023577    0.593308    
#> 259: 0.258812    1.003678    3.433015    0.192143    0.050519    0.023610    0.593195    
#> 260: 0.258614    1.003745    3.433028    0.192181    0.050494    0.023608    0.592898    
#> 261: 0.258946    1.003698    3.433100    0.192717    0.050461    0.023608    0.592675    
#> 262: 0.259014    1.003909    3.433221    0.192976    0.050370    0.023642    0.592434    
#> 263: 0.258798    1.004181    3.433162    0.192848    0.050320    0.023701    0.592582    
#> 264: 0.258342    1.004219    3.433115    0.192931    0.050405    0.023716    0.592805    
#> 265: 0.258104    1.004372    3.433077    0.193449    0.050498    0.023712    0.592697    
#> 266: 0.258256    1.004648    3.433032    0.193616    0.050594    0.023666    0.592590    
#> 267: 0.258369    1.004554    3.433195    0.193703    0.050533    0.023701    0.592392    
#> 268: 0.258422    1.004346    3.433115    0.193800    0.050436    0.023675    0.592325    
#> 269: 0.258886    1.004273    3.433187    0.193869    0.050275    0.023663    0.592627    
#> 270: 0.259094    1.004518    3.433214    0.193642    0.050229    0.023606    0.592529    
#> 271: 0.259391    1.004540    3.433269    0.193410    0.050156    0.023548    0.592775    
#> 272: 0.259461    1.004442    3.433276    0.192795    0.050143    0.023524    0.592953    
#> 273: 0.259438    1.004493    3.433470    0.192580    0.050168    0.023493    0.593053    
#> 274: 0.259666    1.004621    3.433673    0.192393    0.050184    0.023507    0.593009    
#> 275: 0.259774    1.004665    3.433674    0.192015    0.050100    0.023539    0.593067    
#> 276: 0.260039    1.004656    3.433890    0.192259    0.050142    0.023588    0.592959    
#> 277: 0.260318    1.004945    3.434129    0.192393    0.050161    0.023638    0.592883    
#> 278: 0.260253    1.005142    3.434283    0.192350    0.050191    0.023660    0.592742    
#> 279: 0.260202    1.005208    3.434176    0.192377    0.050254    0.023744    0.592656    
#> 280: 0.259870    1.005283    3.434069    0.192478    0.050225    0.023815    0.592453    
#> 281: 0.259819    1.005396    3.434124    0.192347    0.050166    0.023838    0.592496    
#> 282: 0.259780    1.005579    3.434130    0.192340    0.050110    0.023856    0.592520    
#> 283: 0.260048    1.005672    3.434276    0.192375    0.050049    0.023903    0.592610    
#> 284: 0.260271    1.005499    3.434371    0.192420    0.049892    0.023940    0.592525    
#> 285: 0.260468    1.005633    3.434355    0.192615    0.049871    0.023974    0.592481    
#> 286: 0.260629    1.005571    3.434383    0.192766    0.049756    0.024059    0.592475    
#> 287: 0.260569    1.005558    3.434366    0.192743    0.049733    0.024173    0.592505    
#> 288: 0.260771    1.005454    3.434461    0.192712    0.049708    0.024223    0.592621    
#> 289: 0.261029    1.005401    3.434444    0.192657    0.049599    0.024213    0.592649    
#> 290: 0.261451    1.005324    3.434566    0.192649    0.049620    0.024229    0.592617    
#> 291: 0.261614    1.005547    3.434670    0.192507    0.049564    0.024236    0.592465    
#> 292: 0.261830    1.005442    3.434660    0.192607    0.049525    0.024252    0.592324    
#> 293: 0.261907    1.005480    3.434603    0.192501    0.049529    0.024278    0.592175    
#> 294: 0.261752    1.005586    3.434533    0.192529    0.049412    0.024290    0.592141    
#> 295: 0.261640    1.005425    3.434478    0.192501    0.049332    0.024296    0.592005    
#> 296: 0.261612    1.005469    3.434440    0.192384    0.049319    0.024292    0.591950    
#> 297: 0.261502    1.005515    3.434454    0.192138    0.049273    0.024304    0.592000    
#> 298: 0.261196    1.005568    3.434338    0.192257    0.049260    0.024329    0.591922    
#> 299: 0.260993    1.005553    3.434397    0.192233    0.049194    0.024394    0.591799    
#> 300: 0.261317    1.005402    3.434514    0.192427    0.049117    0.024413    0.591709    
#> 301: 0.261703    1.005187    3.434572    0.192889    0.049079    0.024422    0.591750    
#> 302: 0.261729    1.005168    3.434521    0.192905    0.049106    0.024409    0.591805    
#> 303: 0.261664    1.005295    3.434391    0.192531    0.049194    0.024369    0.591833    
#> 304: 0.261677    1.005497    3.434289    0.192377    0.049293    0.024308    0.591785    
#> 305: 0.261392    1.005357    3.434205    0.192178    0.049324    0.024271    0.591721    
#> 306: 0.261090    1.005383    3.434032    0.192086    0.049392    0.024253    0.591694    
#> 307: 0.260568    1.005407    3.433799    0.192125    0.049438    0.024266    0.591854    
#> 308: 0.259876    1.005423    3.433515    0.192346    0.049528    0.024281    0.591994    
#> 309: 0.259396    1.005459    3.433340    0.192655    0.049557    0.024306    0.592075    
#> 310: 0.259207    1.005420    3.433213    0.192901    0.049510    0.024314    0.592163    
#> 311: 0.259186    1.005450    3.433210    0.193014    0.049455    0.024351    0.592073    
#> 312: 0.259089    1.005418    3.433167    0.193512    0.049395    0.024375    0.592064    
#> 313: 0.258891    1.005317    3.433048    0.193967    0.049364    0.024443    0.592046    
#> 314: 0.258474    1.005357    3.432859    0.194278    0.049334    0.024491    0.591990    
#> 315: 0.258053    1.005456    3.432725    0.194338    0.049376    0.024563    0.591940    
#> 316: 0.257997    1.005519    3.432667    0.194420    0.049393    0.024613    0.591796    
#> 317: 0.258138    1.005552    3.432761    0.194585    0.049428    0.024624    0.591789    
#> 318: 0.258343    1.005646    3.432737    0.194562    0.049466    0.024610    0.591695    
#> 319: 0.258425    1.005646    3.432748    0.194639    0.049489    0.024581    0.591643    
#> 320: 0.258353    1.005625    3.432737    0.194712    0.049510    0.024564    0.591695    
#> 321: 0.258286    1.005683    3.432723    0.194662    0.049571    0.024558    0.591687    
#> 322: 0.258549    1.005647    3.432699    0.194448    0.049563    0.024557    0.591658    
#> 323: 0.258147    1.005662    3.432611    0.194415    0.049542    0.024569    0.591665    
#> 324: 0.258130    1.005839    3.432634    0.194626    0.049581    0.024566    0.591672    
#> 325: 0.258172    1.005901    3.432580    0.194445    0.049548    0.024540    0.591645    
#> 326: 0.258193    1.005780    3.432623    0.194342    0.049600    0.024543    0.591569    
#> 327: 0.258384    1.005512    3.432774    0.194222    0.049600    0.024502    0.591580    
#> 328: 0.258464    1.005536    3.432795    0.194042    0.049593    0.024469    0.591513    
#> 329: 0.258706    1.005711    3.432880    0.193960    0.049590    0.024434    0.591493    
#> 330: 0.258598    1.005738    3.432892    0.193616    0.049510    0.024427    0.591450    
#> 331: 0.258827    1.005758    3.433009    0.193479    0.049432    0.024451    0.591442    
#> 332: 0.258950    1.005738    3.433085    0.193451    0.049434    0.024452    0.591510    
#> 333: 0.258644    1.005791    3.433016    0.193238    0.049419    0.024470    0.591530    
#> 334: 0.258438    1.005820    3.432903    0.193135    0.049424    0.024435    0.591463    
#> 335: 0.258219    1.005945    3.432776    0.193109    0.049377    0.024426    0.591315    
#> 336: 0.257961    1.006110    3.432656    0.192999    0.049344    0.024411    0.591362    
#> 337: 0.257882    1.006389    3.432559    0.193054    0.049292    0.024413    0.591408    
#> 338: 0.257772    1.006537    3.432565    0.192878    0.049214    0.024408    0.591522    
#> 339: 0.257558    1.006695    3.432428    0.192792    0.049226    0.024411    0.591661    
#> 340: 0.257401    1.006639    3.432343    0.192551    0.049183    0.024431    0.591654    
#> 341: 0.257265    1.006674    3.432364    0.192414    0.049126    0.024451    0.591646    
#> 342: 0.257043    1.006651    3.432325    0.192256    0.049140    0.024458    0.591546    
#> 343: 0.256707    1.006814    3.432212    0.191993    0.049134    0.024463    0.591490    
#> 344: 0.256578    1.006869    3.432175    0.191778    0.049161    0.024473    0.591438    
#> 345: 0.256484    1.006955    3.432119    0.191682    0.049161    0.024465    0.591459    
#> 346: 0.256242    1.007009    3.431991    0.191534    0.049171    0.024467    0.591442    
#> 347: 0.256062    1.006961    3.431918    0.191533    0.049088    0.024484    0.591547    
#> 348: 0.255747    1.007073    3.431857    0.191369    0.049068    0.024483    0.591629    
#> 349: 0.255622    1.007093    3.431743    0.191320    0.049034    0.024472    0.591646    
#> 350: 0.255567    1.007071    3.431670    0.191587    0.049017    0.024459    0.591672    
#> 351: 0.255490    1.007210    3.431621    0.191575    0.048979    0.024442    0.591750    
#> 352: 0.255265    1.007309    3.431541    0.191525    0.048954    0.024483    0.591801    
#> 353: 0.255347    1.007479    3.431514    0.191431    0.048906    0.024486    0.591906    
#> 354: 0.255329    1.007518    3.431456    0.191433    0.048859    0.024477    0.591941    
#> 355: 0.255639    1.007386    3.431498    0.191568    0.048832    0.024501    0.591952    
#> 356: 0.255644    1.007243    3.431540    0.191471    0.048874    0.024466    0.592065    
#> 357: 0.255599    1.007167    3.431519    0.191545    0.048840    0.024459    0.592008    
#> 358: 0.255558    1.007194    3.431540    0.191519    0.048815    0.024477    0.591909    
#> 359: 0.255356    1.007391    3.431466    0.191386    0.048830    0.024489    0.591867    
#> 360: 0.255241    1.007456    3.431311    0.191328    0.048819    0.024481    0.591858    
#> 361: 0.254848    1.007602    3.431156    0.191131    0.048841    0.024475    0.591864    
#> 362: 0.254663    1.007724    3.430997    0.191015    0.048831    0.024476    0.591821    
#> 363: 0.254559    1.007664    3.430983    0.190773    0.048835    0.024471    0.591771    
#> 364: 0.254533    1.007671    3.430996    0.190535    0.048860    0.024455    0.591822    
#> 365: 0.254638    1.007574    3.431094    0.190310    0.048936    0.024419    0.591849    
#> 366: 0.254791    1.007460    3.431098    0.190201    0.048962    0.024402    0.591908    
#> 367: 0.254966    1.007503    3.431087    0.190256    0.048973    0.024398    0.591903    
#> 368: 0.255118    1.007546    3.431110    0.190086    0.048916    0.024394    0.591901    
#> 369: 0.255113    1.007541    3.431123    0.189882    0.048880    0.024385    0.591942    
#> 370: 0.254897    1.007681    3.431020    0.189698    0.048884    0.024369    0.591980    
#> 371: 0.254575    1.007773    3.430859    0.189567    0.048907    0.024359    0.591970    
#> 372: 0.254337    1.007958    3.430724    0.189541    0.048995    0.024339    0.591996    
#> 373: 0.254109    1.008116    3.430604    0.189558    0.048989    0.024330    0.592059    
#> 374: 0.254219    1.008197    3.430584    0.189790    0.048954    0.024363    0.591954    
#> 375: 0.254200    1.008248    3.430576    0.189913    0.048977    0.024365    0.591956    
#> 376: 0.254254    1.008323    3.430583    0.189997    0.049015    0.024361    0.591854    
#> 377: 0.254227    1.008330    3.430598    0.190125    0.049008    0.024354    0.591771    
#> 378: 0.254147    1.008336    3.430560    0.190231    0.048943    0.024370    0.591784    
#> 379: 0.254120    1.008298    3.430554    0.190293    0.048841    0.024386    0.591741    
#> 380: 0.254088    1.008230    3.430587    0.190263    0.048791    0.024392    0.591684    
#> 381: 0.253996    1.008219    3.430583    0.190193    0.048780    0.024407    0.591581    
#> 382: 0.253852    1.008287    3.430497    0.190209    0.048693    0.024428    0.591510    
#> 383: 0.253679    1.008396    3.430395    0.189946    0.048679    0.024408    0.591476    
#> 384: 0.253422    1.008444    3.430278    0.189769    0.048717    0.024387    0.591448    
#> 385: 0.253422    1.008525    3.430244    0.189598    0.048731    0.024373    0.591457    
#> 386: 0.253531    1.008625    3.430302    0.189442    0.048714    0.024382    0.591492    
#> 387: 0.253717    1.008698    3.430435    0.189246    0.048669    0.024399    0.591401    
#> 388: 0.253971    1.008698    3.430522    0.189078    0.048663    0.024405    0.591342    
#> 389: 0.253984    1.008573    3.430592    0.188904    0.048654    0.024411    0.591420    
#> 390: 0.254053    1.008522    3.430644    0.188659    0.048626    0.024415    0.591442    
#> 391: 0.254188    1.008379    3.430678    0.188476    0.048631    0.024425    0.591455    
#> 392: 0.254387    1.008304    3.430801    0.188552    0.048614    0.024448    0.591418    
#> 393: 0.254592    1.008175    3.430842    0.188632    0.048597    0.024468    0.591315    
#> 394: 0.254664    1.008151    3.430865    0.188529    0.048591    0.024451    0.591319    
#> 395: 0.254841    1.008216    3.430906    0.188541    0.048607    0.024460    0.591303    
#> 396: 0.255029    1.008227    3.430995    0.188449    0.048620    0.024463    0.591229    
#> 397: 0.255123    1.008148    3.431065    0.188492    0.048627    0.024466    0.591212    
#> 398: 0.255356    1.008074    3.431138    0.188515    0.048606    0.024486    0.591209    
#> 399: 0.255620    1.008069    3.431217    0.188667    0.048560    0.024497    0.591198    
#> 400: 0.255709    1.008068    3.431289    0.188624    0.048558    0.024493    0.591176    
#> 401: 0.255683    1.008051    3.431285    0.188607    0.048623    0.024461    0.591245    
#> 402: 0.255665    1.008105    3.431312    0.188475    0.048653    0.024454    0.591292    
#> 403: 0.255853    1.008080    3.431359    0.188419    0.048642    0.024447    0.591377    
#> 404: 0.256016    1.008037    3.431365    0.188328    0.048587    0.024437    0.591435    
#> 405: 0.256032    1.008055    3.431392    0.188296    0.048554    0.024432    0.591405    
#> 406: 0.256080    1.008111    3.431346    0.188335    0.048538    0.024412    0.591393    
#> 407: 0.256016    1.008153    3.431358    0.188304    0.048549    0.024403    0.591382    
#> 408: 0.256077    1.008212    3.431350    0.188311    0.048588    0.024391    0.591385    
#> 409: 0.256151    1.008167    3.431394    0.188306    0.048553    0.024378    0.591351    
#> 410: 0.256092    1.008098    3.431400    0.188278    0.048548    0.024384    0.591387    
#> 411: 0.256162    1.007897    3.431424    0.188348    0.048517    0.024389    0.591482    
#> 412: 0.256202    1.007864    3.431430    0.188301    0.048490    0.024391    0.591466    
#> 413: 0.256226    1.007886    3.431424    0.188106    0.048488    0.024383    0.591539    
#> 414: 0.256153    1.007884    3.431484    0.187986    0.048507    0.024354    0.591581    
#> 415: 0.256292    1.007829    3.431502    0.187879    0.048556    0.024326    0.591606    
#> 416: 0.256474    1.007836    3.431595    0.187842    0.048570    0.024330    0.591583    
#> 417: 0.256552    1.007794    3.431665    0.187870    0.048532    0.024328    0.591565    
#> 418: 0.256457    1.007787    3.431668    0.187860    0.048516    0.024331    0.591523    
#> 419: 0.256404    1.007897    3.431614    0.187993    0.048501    0.024338    0.591461    
#> 420: 0.256316    1.007945    3.431563    0.188015    0.048490    0.024342    0.591407    
#> 421: 0.256215    1.008019    3.431536    0.188044    0.048475    0.024352    0.591398    
#> 422: 0.256272    1.007961    3.431550    0.187979    0.048476    0.024345    0.591427    
#> 423: 0.256269    1.007869    3.431585    0.187825    0.048495    0.024332    0.591509    
#> 424: 0.256247    1.007855    3.431570    0.187796    0.048499    0.024312    0.591524    
#> 425: 0.256392    1.007890    3.431593    0.187762    0.048493    0.024298    0.591613    
#> 426: 0.256496    1.007890    3.431667    0.187593    0.048546    0.024270    0.591604    
#> 427: 0.256541    1.007797    3.431746    0.187417    0.048552    0.024262    0.591569    
#> 428: 0.256591    1.007741    3.431834    0.187314    0.048554    0.024256    0.591560    
#> 429: 0.256714    1.007666    3.431925    0.187180    0.048548    0.024261    0.591557    
#> 430: 0.256777    1.007585    3.431955    0.187095    0.048539    0.024271    0.591543    
#> 431: 0.256828    1.007565    3.432001    0.187018    0.048549    0.024250    0.591519    
#> 432: 0.256880    1.007623    3.432044    0.186854    0.048564    0.024244    0.591546    
#> 433: 0.256972    1.007665    3.432096    0.186655    0.048558    0.024229    0.591618    
#> 434: 0.256976    1.007548    3.432147    0.186552    0.048542    0.024220    0.591638    
#> 435: 0.257057    1.007462    3.432180    0.186454    0.048517    0.024235    0.591614    
#> 436: 0.257120    1.007393    3.432256    0.186351    0.048497    0.024239    0.591660    
#> 437: 0.257239    1.007357    3.432307    0.186267    0.048501    0.024246    0.591629    
#> 438: 0.257291    1.007484    3.432328    0.186178    0.048481    0.024239    0.591664    
#> 439: 0.257479    1.007585    3.432368    0.186157    0.048474    0.024235    0.591608    
#> 440: 0.257573    1.007593    3.432432    0.186194    0.048451    0.024240    0.591586    
#> 441: 0.257697    1.007545    3.432456    0.186219    0.048448    0.024253    0.591499    
#> 442: 0.257612    1.007558    3.432434    0.186259    0.048472    0.024264    0.591406    
#> 443: 0.257488    1.007695    3.432369    0.186250    0.048471    0.024272    0.591337    
#> 444: 0.257408    1.007819    3.432282    0.186344    0.048459    0.024281    0.591254    
#> 445: 0.257278    1.007921    3.432187    0.186462    0.048410    0.024308    0.591265    
#> 446: 0.257093    1.007981    3.432088    0.186520    0.048370    0.024313    0.591201    
#> 447: 0.257054    1.008012    3.432035    0.186516    0.048320    0.024331    0.591187    
#> 448: 0.257006    1.007996    3.432035    0.186527    0.048284    0.024339    0.591102    
#> 449: 0.257196    1.008076    3.432128    0.186658    0.048287    0.024348    0.591069    
#> 450: 0.257278    1.008051    3.432141    0.186772    0.048313    0.024353    0.591084    
#> 451: 0.257297    1.008099    3.432115    0.186835    0.048349    0.024360    0.591118    
#> 452: 0.257223    1.008131    3.432094    0.186800    0.048349    0.024345    0.591084    
#> 453: 0.257087    1.008139    3.432068    0.186827    0.048340    0.024348    0.591025    
#> 454: 0.257057    1.008221    3.432081    0.186807    0.048350    0.024343    0.591044    
#> 455: 0.257049    1.008298    3.432065    0.186747    0.048368    0.024352    0.591009    
#> 456: 0.256925    1.008267    3.432074    0.186749    0.048388    0.024358    0.591024    
#> 457: 0.256924    1.008270    3.432106    0.186705    0.048406    0.024374    0.590971    
#> 458: 0.256843    1.008355    3.432111    0.186660    0.048435    0.024380    0.590985    
#> 459: 0.256710    1.008437    3.432096    0.186717    0.048455    0.024386    0.590936    
#> 460: 0.256611    1.008545    3.432063    0.186693    0.048481    0.024391    0.590903    
#> 461: 0.256540    1.008596    3.432050    0.186671    0.048516    0.024387    0.590843    
#> 462: 0.256451    1.008627    3.432037    0.186721    0.048515    0.024383    0.590780    
#> 463: 0.256469    1.008672    3.432062    0.186753    0.048518    0.024392    0.590749    
#> 464: 0.256541    1.008680    3.432054    0.186816    0.048517    0.024407    0.590689    
#> 465: 0.256586    1.008609    3.432077    0.186895    0.048534    0.024405    0.590658    
#> 466: 0.256584    1.008631    3.432033    0.186961    0.048524    0.024406    0.590673    
#> 467: 0.256453    1.008570    3.432032    0.186933    0.048475    0.024422    0.590654    
#> 468: 0.256566    1.008573    3.432072    0.186952    0.048441    0.024443    0.590640    
#> 469: 0.256564    1.008671    3.432075    0.186958    0.048429    0.024464    0.590673    
#> 470: 0.256428    1.008691    3.432018    0.186937    0.048387    0.024488    0.590683    
#> 471: 0.256204    1.008681    3.431973    0.186879    0.048353    0.024493    0.590719    
#> 472: 0.256032    1.008690    3.431916    0.186737    0.048361    0.024506    0.590755    
#> 473: 0.255903    1.008749    3.431886    0.186659    0.048359    0.024497    0.590736    
#> 474: 0.255850    1.008772    3.431882    0.186686    0.048364    0.024496    0.590779    
#> 475: 0.255891    1.008847    3.431895    0.186721    0.048343    0.024504    0.590714    
#> 476: 0.255857    1.008861    3.431896    0.186755    0.048333    0.024513    0.590668    
#> 477: 0.255848    1.008881    3.431930    0.186762    0.048321    0.024519    0.590590    
#> 478: 0.255826    1.008901    3.431957    0.186706    0.048287    0.024513    0.590541    
#> 479: 0.255887    1.008923    3.431986    0.186669    0.048287    0.024509    0.590528    
#> 480: 0.255939    1.008909    3.431988    0.186662    0.048292    0.024517    0.590569    
#> 481: 0.255904    1.008912    3.431987    0.186769    0.048275    0.024513    0.590565    
#> 482: 0.255891    1.008940    3.431941    0.186895    0.048281    0.024514    0.590556    
#> 483: 0.255803    1.008893    3.431941    0.186860    0.048320    0.024510    0.590524    
#> 484: 0.255822    1.008764    3.431963    0.186873    0.048331    0.024509    0.590537    
#> 485: 0.255838    1.008753    3.431973    0.186899    0.048348    0.024511    0.590555    
#> 486: 0.255801    1.008759    3.431974    0.186923    0.048318    0.024514    0.590573    
#> 487: 0.256038    1.008734    3.432073    0.187000    0.048290    0.024520    0.590637    
#> 488: 0.256142    1.008673    3.432151    0.186931    0.048305    0.024521    0.590647    
#> 489: 0.256285    1.008604    3.432198    0.186936    0.048333    0.024513    0.590646    
#> 490: 0.256459    1.008585    3.432297    0.186922    0.048362    0.024505    0.590680    
#> 491: 0.256584    1.008564    3.432357    0.186858    0.048367    0.024489    0.590688    
#> 492: 0.256679    1.008578    3.432394    0.186841    0.048383    0.024477    0.590723    
#> 493: 0.256793    1.008570    3.432468    0.186864    0.048435    0.024474    0.590770    
#> 494: 0.256966    1.008565    3.432494    0.186785    0.048465    0.024465    0.590789    
#> 495: 0.257063    1.008542    3.432537    0.186765    0.048467    0.024450    0.590787    
#> 496: 0.257106    1.008552    3.432542    0.186757    0.048452    0.024431    0.590763    
#> 497: 0.257160    1.008491    3.432566    0.186752    0.048435    0.024432    0.590769    
#> 498: 0.257191    1.008412    3.432589    0.186839    0.048417    0.024435    0.590712    
#> 499: 0.257196    1.008396    3.432608    0.186836    0.048402    0.024444    0.590662    
#> 500: 0.257221    1.008346    3.432626    0.186849    0.048369    0.024446    0.590639    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.311352    0.966984    3.443248    0.392401    0.083856    0.016800    1.783043    
#> 002: 0.345713    1.065771    3.460509    0.372781    0.079663    0.017052    1.220000    
#> 003: 0.478894    1.016982    3.493887    0.354142    0.091788    0.016199    0.902225    
#> 004: 0.438056    1.023749    3.498156    0.336435    0.087199    0.015389    0.821365    
#> 005: 0.499165    1.037081    3.492682    0.319613    0.082839    0.014620    0.789482    
#> 006: 0.458407    1.039300    3.485831    0.303633    0.092304    0.013889    0.751285    
#> 007: 0.438540    1.046041    3.481244    0.288451    0.096615    0.013194    0.757621    
#> 008: 0.413230    1.034669    3.477255    0.274029    0.095676    0.015839    0.768645    
#> 009: 0.388088    1.025254    3.469711    0.260327    0.090892    0.015047    0.769032    
#> 010: 0.388610    1.018306    3.471553    0.247311    0.086348    0.014295    0.786979    
#> 011: 0.484064    1.020574    3.493688    0.234945    0.107118    0.013580    0.783111    
#> 012: 0.469143    1.024398    3.478025    0.223198    0.103582    0.012901    0.770728    
#> 013: 0.417675    1.029389    3.473440    0.212038    0.107827    0.012256    0.768999    
#> 014: 0.440089    1.038957    3.477589    0.221003    0.102435    0.014324    0.775990    
#> 015: 0.465849    1.028080    3.493541    0.209952    0.097314    0.013608    0.775286    
#> 016: 0.494586    1.031529    3.504496    0.199455    0.092448    0.013686    0.785350    
#> 017: 0.501645    1.045349    3.496811    0.189966    0.087825    0.015086    0.762022    
#> 018: 0.496202    1.051043    3.479460    0.180467    0.083434    0.014331    0.786392    
#> 019: 0.400479    1.060202    3.471606    0.171444    0.079262    0.014323    0.747871    
#> 020: 0.429970    1.055923    3.478264    0.162872    0.080185    0.014704    0.747605    
#> 021: 0.419732    1.033340    3.494051    0.154728    0.079094    0.013969    0.752687    
#> 022: 0.469863    1.028976    3.509740    0.146992    0.079195    0.013870    0.736810    
#> 023: 0.520257    1.021442    3.511997    0.139642    0.075235    0.014934    0.765326    
#> 024: 0.533623    1.049188    3.515527    0.145481    0.092315    0.014187    0.749380    
#> 025: 0.530759    1.005494    3.515464    0.148924    0.087699    0.013478    0.757815    
#> 026: 0.496113    1.041730    3.495777    0.147254    0.099828    0.012804    0.768108    
#> 027: 0.446431    1.069995    3.490227    0.145275    0.101995    0.012164    0.762595    
#> 028: 0.482809    1.029433    3.499995    0.138011    0.096895    0.011556    0.760570    
#> 029: 0.485401    1.019195    3.491062    0.131110    0.099630    0.010978    0.766988    
#> 030: 0.490437    1.045936    3.490254    0.124555    0.095008    0.010429    0.764282    
#> 031: 0.480215    1.012715    3.510300    0.140137    0.104370    0.009907    0.757999    
#> 032: 0.493383    0.991122    3.514566    0.133130    0.104164    0.009412    0.755536    
#> 033: 0.482438    1.010986    3.506165    0.126474    0.099403    0.008941    0.754195    
#> 034: 0.507071    1.021249    3.506897    0.120150    0.103027    0.008494    0.770161    
#> 035: 0.460662    1.006972    3.494310    0.125945    0.104477    0.008070    0.752220    
#> 036: 0.450272    1.011245    3.493011    0.119648    0.100138    0.007666    0.765381    
#> 037: 0.452740    1.027728    3.502498    0.113666    0.104313    0.007283    0.772270    
#> 038: 0.472141    1.043809    3.487949    0.126499    0.107263    0.006919    0.795735    
#> 039: 0.486959    1.007092    3.505559    0.120174    0.101900    0.007332    0.753091    
#> 040: 0.507696    1.033048    3.510317    0.124415    0.096805    0.006966    0.766612    
#> 041: 0.445568    1.033611    3.494726    0.126415    0.091965    0.006617    0.758490    
#> 042: 0.475436    1.023268    3.495968    0.156677    0.087367    0.006286    0.734385    
#> 043: 0.434179    1.023417    3.487463    0.148843    0.087748    0.005972    0.763215    
#> 044: 0.406915    1.053674    3.486491    0.141401    0.083361    0.005884    0.770891    
#> 045: 0.423761    1.093939    3.466654    0.134331    0.087750    0.005589    0.780405    
#> 046: 0.462416    1.058955    3.471884    0.127614    0.101248    0.005454    0.775387    
#> 047: 0.452810    1.053522    3.476526    0.121233    0.096186    0.006791    0.746133    
#> 048: 0.439264    1.029265    3.476880    0.115172    0.099395    0.007325    0.744812    
#> 049: 0.415908    1.040684    3.480705    0.109413    0.094426    0.006958    0.775272    
#> 050: 0.476836    1.014397    3.477326    0.140391    0.089704    0.008043    0.787514    
#> 051: 0.445963    1.037383    3.471129    0.133372    0.085219    0.008080    0.775824    
#> 052: 0.404590    1.046473    3.474213    0.126703    0.080958    0.007676    0.755715    
#> 053: 0.427065    1.038739    3.472529    0.128241    0.076910    0.010061    0.749192    
#> 054: 0.403180    1.039520    3.473713    0.121829    0.101988    0.010552    0.760239    
#> 055: 0.403127    1.052937    3.476617    0.115737    0.099098    0.010035    0.776772    
#> 056: 0.417329    1.020841    3.485230    0.119743    0.094143    0.009533    0.770755    
#> 057: 0.425995    1.004068    3.494820    0.134784    0.089855    0.009156    0.785029    
#> 058: 0.427138    1.010427    3.474847    0.128045    0.088532    0.008698    0.803138    
#> 059: 0.455176    1.009293    3.481232    0.131566    0.101351    0.008263    0.794084    
#> 060: 0.449804    0.983415    3.498882    0.142629    0.101878    0.007850    0.778063    
#> 061: 0.511867    1.000007    3.509512    0.171117    0.096784    0.011617    0.797303    
#> 062: 0.507015    1.040565    3.515034    0.176106    0.099246    0.011723    0.787871    
#> 063: 0.540328    0.997805    3.516875    0.169594    0.094283    0.012062    0.788945    
#> 064: 0.486842    1.002092    3.513395    0.161115    0.096487    0.011505    0.766628    
#> 065: 0.480050    0.995743    3.506732    0.153059    0.091663    0.012188    0.750792    
#> 066: 0.476565    1.013056    3.515297    0.156891    0.087080    0.012823    0.737712    
#> 067: 0.474036    1.014183    3.500641    0.149046    0.082726    0.015037    0.750379    
#> 068: 0.439370    1.032911    3.503212    0.141594    0.078590    0.014285    0.804936    
#> 069: 0.425454    1.051900    3.480529    0.148280    0.082862    0.013571    0.808377    
#> 070: 0.454560    1.048824    3.493693    0.147419    0.088431    0.012892    0.775641    
#> 071: 0.425910    1.071237    3.470833    0.162754    0.102141    0.012247    0.792048    
#> 072: 0.405619    1.035864    3.472033    0.172419    0.100843    0.011635    0.763910    
#> 073: 0.421356    1.044413    3.488204    0.163798    0.095801    0.011053    0.780860    
#> 074: 0.386078    1.028289    3.482898    0.155608    0.103538    0.010501    0.783987    
#> 075: 0.434991    1.018689    3.502541    0.147828    0.103628    0.009976    0.744806    
#> 076: 0.468617    1.036479    3.501223    0.140436    0.098446    0.009477    0.766818    
#> 077: 0.481632    1.022204    3.493706    0.133414    0.104799    0.009003    0.744219    
#> 078: 0.477380    1.027112    3.499841    0.126744    0.102452    0.009518    0.742222    
#> 079: 0.455910    1.055295    3.494212    0.126037    0.097329    0.009042    0.774918    
#> 080: 0.481476    1.040440    3.487669    0.143280    0.104438    0.008590    0.779827    
#> 081: 0.453223    1.051859    3.488758    0.158935    0.099216    0.008160    0.758210    
#> 082: 0.454184    1.029847    3.489752    0.150989    0.094255    0.007866    0.766215    
#> 083: 0.437372    1.076200    3.484339    0.144401    0.096168    0.007473    0.758837    
#> 084: 0.438033    1.071184    3.473833    0.137181    0.091359    0.007707    0.762388    
#> 085: 0.407667    1.077947    3.474533    0.133012    0.086791    0.007322    0.781278    
#> 086: 0.390159    1.068496    3.460397    0.127333    0.082452    0.008385    0.753507    
#> 087: 0.402659    1.036994    3.463359    0.120967    0.091239    0.007965    0.766539    
#> 088: 0.394494    1.035770    3.473949    0.133922    0.092271    0.008655    0.772745    
#> 089: 0.433692    1.059192    3.467408    0.127226    0.090014    0.009226    0.756774    
#> 090: 0.395223    1.036989    3.476149    0.120865    0.098824    0.008765    0.762728    
#> 091: 0.401940    1.037622    3.462510    0.145078    0.098437    0.008327    0.755373    
#> 092: 0.406801    1.060742    3.460797    0.137824    0.093515    0.008100    0.755374    
#> 093: 0.397254    1.037884    3.467932    0.140384    0.096986    0.008816    0.774785    
#> 094: 0.372057    1.056673    3.461058    0.133365    0.092136    0.008555    0.774108    
#> 095: 0.406893    1.051197    3.473703    0.142700    0.093743    0.008127    0.774160    
#> 096: 0.398998    1.039493    3.465099    0.143758    0.089056    0.007721    0.772559    
#> 097: 0.432927    1.060965    3.467304    0.136570    0.084603    0.007406    0.757202    
#> 098: 0.411770    1.072855    3.474857    0.134119    0.084992    0.007036    0.774561    
#> 099: 0.418722    1.054975    3.461819    0.141520    0.084067    0.006705    0.768397    
#> 100: 0.415521    1.065455    3.467234    0.137060    0.102956    0.007149    0.761303    
#> 101: 0.371905    1.047759    3.446925    0.143231    0.097808    0.006791    0.758532    
#> 102: 0.342896    1.077813    3.432934    0.136070    0.112689    0.006452    0.773934    
#> 103: 0.389600    1.064836    3.444567    0.132973    0.107055    0.006129    0.757278    
#> 104: 0.408664    1.052720    3.461703    0.161229    0.101702    0.005823    0.749044    
#> 105: 0.416887    1.047688    3.462308    0.171938    0.096617    0.005531    0.740641    
#> 106: 0.414350    1.036110    3.460105    0.167772    0.091786    0.005377    0.751552    
#> 107: 0.446639    1.053705    3.471188    0.159383    0.087197    0.006072    0.772003    
#> 108: 0.432574    1.038277    3.466119    0.169531    0.105799    0.006067    0.765882    
#> 109: 0.394855    1.077910    3.475171    0.161054    0.100509    0.005764    0.764290    
#> 110: 0.402052    1.055229    3.462306    0.153002    0.095484    0.005475    0.769645    
#> 111: 0.394137    1.041119    3.468818    0.145352    0.108896    0.005202    0.761744    
#> 112: 0.411604    1.009732    3.473871    0.154737    0.128729    0.004942    0.759163    
#> 113: 0.441918    1.057034    3.474999    0.147000    0.122293    0.004694    0.752205    
#> 114: 0.421959    1.033367    3.476978    0.139650    0.116178    0.004460    0.765969    
#> 115: 0.443097    1.020371    3.474487    0.135687    0.110369    0.004237    0.794279    
#> 116: 0.401888    1.030915    3.474700    0.128903    0.104851    0.004646    0.774333    
#> 117: 0.418672    1.052355    3.476023    0.143733    0.099608    0.005161    0.762262    
#> 118: 0.440279    1.037642    3.476800    0.153413    0.100841    0.004903    0.765591    
#> 119: 0.431413    1.052421    3.474778    0.145742    0.102147    0.004784    0.762287    
#> 120: 0.434563    1.037705    3.474816    0.140423    0.103686    0.005966    0.754518    
#> 121: 0.439361    1.067585    3.475704    0.170242    0.099960    0.005791    0.752350    
#> 122: 0.474712    1.019579    3.483682    0.165639    0.094962    0.008412    0.744977    
#> 123: 0.498071    1.052070    3.486247    0.157357    0.113302    0.007991    0.769026    
#> 124: 0.506436    1.065687    3.499313    0.149489    0.107637    0.008101    0.774398    
#> 125: 0.507393    1.056157    3.489952    0.151155    0.102255    0.012932    0.742671    
#> 126: 0.433409    1.048708    3.466526    0.143598    0.097143    0.014605    0.743410    
#> 127: 0.401496    1.046654    3.457872    0.157095    0.095757    0.013875    0.749847    
#> 128: 0.399674    1.065406    3.476081    0.160677    0.099355    0.013181    0.744440    
#> 129: 0.440547    1.055016    3.477141    0.164393    0.108690    0.012522    0.755183    
#> 130: 0.466869    1.052804    3.474814    0.156173    0.103255    0.011896    0.733164    
#> 131: 0.418977    1.039228    3.470100    0.148364    0.100072    0.011301    0.746954    
#> 132: 0.391183    1.057821    3.452133    0.157776    0.095068    0.010736    0.757656    
#> 133: 0.416842    1.045575    3.459346    0.165742    0.090315    0.010199    0.768664    
#> 134: 0.451010    1.034644    3.477707    0.171566    0.086822    0.009689    0.750272    
#> 135: 0.424298    1.038237    3.475580    0.165767    0.099370    0.009205    0.746503    
#> 136: 0.413833    1.031678    3.470466    0.184645    0.094401    0.008745    0.735482    
#> 137: 0.459068    1.022991    3.480159    0.175413    0.091216    0.008328    0.755142    
#> 138: 0.461041    1.041660    3.484830    0.166642    0.095829    0.009047    0.753410    
#> 139: 0.458571    1.043364    3.490542    0.158310    0.102129    0.011368    0.750337    
#> 140: 0.472997    1.053264    3.496529    0.167334    0.107255    0.010800    0.758546    
#> 141: 0.429432    1.017953    3.499045    0.158967    0.101893    0.010260    0.761775    
#> 142: 0.472994    1.010493    3.505847    0.151019    0.096798    0.009747    0.761129    
#> 143: 0.469154    1.035008    3.498210    0.143468    0.091958    0.011831    0.751853    
#> 144: 0.491113    1.020000    3.510438    0.136294    0.087360    0.011240    0.757077    
#> 145: 0.455853    1.038641    3.490625    0.129480    0.082992    0.011141    0.744673    
#> 146: 0.431898    1.031492    3.491150    0.123006    0.078843    0.012506    0.752710    
#> 147: 0.441749    1.007061    3.492348    0.116855    0.074900    0.013560    0.726729    
#> 148: 0.464651    1.022603    3.498608    0.118427    0.075439    0.012882    0.735136    
#> 149: 0.448662    1.020677    3.492966    0.112505    0.086709    0.012238    0.753890    
#> 150: 0.452146    1.024875    3.481057    0.106880    0.101693    0.011626    0.778927    
#> 151: 0.403887    1.065037    3.476208    0.101536    0.102610    0.011045    0.780392    
#> 152: 0.429862    1.037843    3.486130    0.102417    0.100550    0.009025    0.759672    
#> 153: 0.443383    1.036419    3.489976    0.109450    0.093339    0.008610    0.774744    
#> 154: 0.492889    1.044864    3.496281    0.103986    0.089998    0.010000    0.772108    
#> 155: 0.464558    1.040162    3.486957    0.082443    0.074423    0.012115    0.750873    
#> 156: 0.443781    1.049971    3.491972    0.088880    0.078097    0.012833    0.764719    
#> 157: 0.498523    0.998756    3.524223    0.104339    0.081571    0.013636    0.765204    
#> 158: 0.515213    1.018248    3.515017    0.093663    0.092575    0.014101    0.741090    
#> 159: 0.452498    1.034901    3.510235    0.114123    0.086082    0.014794    0.754337    
#> 160: 0.495965    1.000663    3.512289    0.111424    0.085924    0.013247    0.741736    
#> 161: 0.475780    1.027509    3.506715    0.118216    0.083231    0.013056    0.744828    
#> 162: 0.468643    1.037353    3.493609    0.102330    0.091939    0.013634    0.743912    
#> 163: 0.494250    1.016545    3.495067    0.112747    0.085851    0.011205    0.751115    
#> 164: 0.500037    1.027941    3.499226    0.163419    0.080019    0.012750    0.757902    
#> 165: 0.497649    1.020791    3.503601    0.136566    0.081280    0.011134    0.749399    
#> 166: 0.516325    1.046012    3.504537    0.134735    0.076308    0.009134    0.766462    
#> 167: 0.494382    1.039618    3.509022    0.156795    0.080510    0.010458    0.767817    
#> 168: 0.481917    1.049602    3.500392    0.139179    0.080658    0.012931    0.763716    
#> 169: 0.463189    1.076645    3.487909    0.131287    0.094198    0.011664    0.779180    
#> 170: 0.477130    1.034523    3.496801    0.128979    0.082660    0.011347    0.749051    
#> 171: 0.447633    1.023293    3.489268    0.095195    0.089437    0.009244    0.750505    
#> 172: 0.449485    1.050787    3.482281    0.078455    0.090092    0.007695    0.768964    
#> 173: 0.462054    1.056888    3.484277    0.094787    0.071734    0.009233    0.747070    
#> 174: 0.452889    1.035391    3.490660    0.087125    0.075402    0.011397    0.734098    
#> 175: 0.447435    1.039034    3.482777    0.093041    0.085499    0.013695    0.749943    
#> 176: 0.455517    1.037519    3.496850    0.104840    0.077171    0.013360    0.754861    
#> 177: 0.464134    1.016090    3.502640    0.094375    0.083282    0.014139    0.752763    
#> 178: 0.455024    1.027944    3.498786    0.081110    0.082211    0.012451    0.752006    
#> 179: 0.495361    1.042353    3.500697    0.099854    0.094998    0.009542    0.749797    
#> 180: 0.477240    1.019565    3.498591    0.126619    0.090590    0.010700    0.744864    
#> 181: 0.466513    1.015502    3.488313    0.122636    0.102121    0.014312    0.739704    
#> 182: 0.424196    1.033708    3.474000    0.091052    0.097021    0.012638    0.759979    
#> 183: 0.439989    1.053408    3.482017    0.067968    0.086238    0.013015    0.744519    
#> 184: 0.415606    1.040395    3.480511    0.069563    0.069394    0.010951    0.770285    
#> 185: 0.408986    1.049899    3.479918    0.076500    0.058301    0.009540    0.788058    
#> 186: 0.435970    1.074634    3.483782    0.081686    0.071017    0.012263    0.772357    
#> 187: 0.461160    1.047417    3.495801    0.101165    0.073106    0.012423    0.768692    
#> 188: 0.436666    1.066365    3.488430    0.109507    0.083260    0.011051    0.778013    
#> 189: 0.471745    1.042542    3.491489    0.115184    0.098247    0.009124    0.789686    
#> 190: 0.471025    1.022604    3.511126    0.115007    0.083718    0.013372    0.750167    
#> 191: 0.427190    1.044226    3.481166    0.116847    0.078416    0.013198    0.758705    
#> 192: 0.413614    1.056427    3.484228    0.155488    0.081865    0.009980    0.743073    
#> 193: 0.482551    1.042656    3.495104    0.123961    0.101289    0.010578    0.725236    
#> 194: 0.468512    1.011068    3.491898    0.145389    0.090503    0.010980    0.748271    
#> 195: 0.417552    1.027843    3.486794    0.154886    0.078943    0.012066    0.753380    
#> 196: 0.454631    1.037415    3.491817    0.132947    0.088090    0.012580    0.744292    
#> 197: 0.444078    1.038797    3.508470    0.123132    0.082855    0.012635    0.752269    
#> 198: 0.485174    1.023344    3.495669    0.112951    0.075041    0.013870    0.750479    
#> 199: 0.484771    1.033011    3.489877    0.140452    0.079732    0.009966    0.750761    
#> 200: 0.460663    1.021619    3.494990    0.126243    0.083979    0.009850    0.765408    
#> 201: 0.466466    1.011733    3.496526    0.123507    0.085773    0.009516    0.759478    
#> 202: 0.464440    1.014085    3.492643    0.129602    0.087670    0.010123    0.754508    
#> 203: 0.473544    1.013931    3.492364    0.128506    0.089463    0.010564    0.755909    
#> 204: 0.484988    1.006823    3.495164    0.133481    0.087369    0.011371    0.757442    
#> 205: 0.483665    1.010392    3.496757    0.128682    0.086911    0.012375    0.759044    
#> 206: 0.484025    1.016479    3.497168    0.125408    0.087112    0.012442    0.762948    
#> 207: 0.480766    1.017448    3.496480    0.123340    0.084556    0.012602    0.766279    
#> 208: 0.484694    1.016361    3.498060    0.119557    0.083900    0.012666    0.765851    
#> 209: 0.487391    1.013428    3.498817    0.117251    0.084421    0.013030    0.766076    
#> 210: 0.490728    1.011903    3.500191    0.114784    0.084875    0.013273    0.766393    
#> 211: 0.491897    1.013050    3.501474    0.111038    0.084761    0.013481    0.765691    
#> 212: 0.491322    1.013748    3.501849    0.109390    0.083635    0.013893    0.765716    
#> 213: 0.493446    1.011601    3.502780    0.108934    0.082429    0.013946    0.766890    
#> 214: 0.495170    1.010901    3.503443    0.107692    0.081993    0.013928    0.766574    
#> 215: 0.493709    1.010887    3.503974    0.107420    0.081844    0.013978    0.766240    
#> 216: 0.493669    1.010437    3.504150    0.107932    0.081624    0.014106    0.766030    
#> 217: 0.493677    1.011521    3.504209    0.108691    0.081183    0.014043    0.764882    
#> 218: 0.493800    1.012538    3.503750    0.108899    0.080255    0.014118    0.763703    
#> 219: 0.493224    1.013180    3.502874    0.109282    0.080768    0.013974    0.763391    
#> 220: 0.491795    1.013775    3.502617    0.109396    0.080758    0.013887    0.763893    
#> 221: 0.491030    1.013942    3.502279    0.110676    0.081149    0.013735    0.763663    
#> 222: 0.490427    1.014256    3.501994    0.110659    0.081430    0.013728    0.763356    
#> 223: 0.491630    1.014194    3.502453    0.109962    0.081879    0.013723    0.762288    
#> 224: 0.493356    1.015633    3.502805    0.109443    0.082553    0.013722    0.761818    
#> 225: 0.494993    1.013758    3.503665    0.109487    0.082984    0.013599    0.761504    
#> 226: 0.495312    1.012143    3.503680    0.109728    0.083179    0.013507    0.761540    
#> 227: 0.494511    1.013027    3.504102    0.109957    0.083212    0.013404    0.761819    
#> 228: 0.493917    1.014298    3.503598    0.111185    0.083014    0.013354    0.761233    
#> 229: 0.492726    1.014845    3.503022    0.111322    0.082847    0.013354    0.760392    
#> 230: 0.492875    1.014617    3.502571    0.111555    0.082804    0.013349    0.760552    
#> 231: 0.492068    1.015079    3.502449    0.111725    0.082664    0.013367    0.759921    
#> 232: 0.490664    1.015323    3.502644    0.111856    0.082779    0.013348    0.759631    
#> 233: 0.490530    1.014577    3.502891    0.111642    0.082527    0.013371    0.759555    
#> 234: 0.490232    1.014352    3.503158    0.111517    0.082554    0.013361    0.759562    
#> 235: 0.489473    1.014367    3.502785    0.111237    0.082761    0.013330    0.759390    
#> 236: 0.489008    1.015190    3.502571    0.110969    0.082934    0.013291    0.759719    
#> 237: 0.489276    1.015375    3.502502    0.110724    0.083231    0.013307    0.759896    
#> 238: 0.489161    1.015706    3.502504    0.110060    0.083595    0.013275    0.760367    
#> 239: 0.488669    1.016402    3.502337    0.109062    0.083660    0.013323    0.760563    
#> 240: 0.487977    1.016323    3.502337    0.108986    0.083667    0.013351    0.760158    
#> 241: 0.487425    1.015638    3.502431    0.108320    0.083885    0.013321    0.760305    
#> 242: 0.486843    1.015302    3.502084    0.107540    0.083884    0.013360    0.760857    
#> 243: 0.485703    1.015748    3.501969    0.107554    0.083732    0.013383    0.761505    
#> 244: 0.484582    1.016149    3.501970    0.107656    0.083750    0.013375    0.761669    
#> 245: 0.484772    1.015980    3.502118    0.107725    0.084023    0.013296    0.761981    
#> 246: 0.484672    1.015771    3.502229    0.107878    0.083876    0.013312    0.762002    
#> 247: 0.484339    1.015665    3.502507    0.107813    0.083830    0.013324    0.761731    
#> 248: 0.484269    1.015660    3.502651    0.107935    0.083789    0.013287    0.761545    
#> 249: 0.484340    1.015677    3.502764    0.108115    0.083964    0.013262    0.761199    
#> 250: 0.484576    1.015902    3.503028    0.107669    0.084070    0.013275    0.761297    
#> 251: 0.485100    1.016668    3.503431    0.107451    0.084192    0.013248    0.761588    
#> 252: 0.485389    1.016765    3.503746    0.107518    0.084272    0.013248    0.761515    
#> 253: 0.485695    1.016883    3.503911    0.107596    0.084393    0.013331    0.761485    
#> 254: 0.485390    1.016985    3.504091    0.107504    0.084466    0.013341    0.761331    
#> 255: 0.485375    1.017109    3.504165    0.107673    0.084371    0.013333    0.761281    
#> 256: 0.484979    1.017174    3.504003    0.108044    0.084478    0.013295    0.761089    
#> 257: 0.484312    1.017225    3.503869    0.108173    0.084425    0.013250    0.761134    
#> 258: 0.484222    1.017135    3.503891    0.108058    0.084404    0.013192    0.761036    
#> 259: 0.484089    1.016997    3.503823    0.108235    0.084766    0.013122    0.760898    
#> 260: 0.483954    1.017204    3.503943    0.108142    0.084833    0.013074    0.760626    
#> 261: 0.483764    1.017365    3.504014    0.108377    0.084766    0.013083    0.760327    
#> 262: 0.483981    1.017387    3.504159    0.108456    0.084808    0.013086    0.760314    
#> 263: 0.483812    1.017828    3.504029    0.108696    0.085034    0.013099    0.760177    
#> 264: 0.483647    1.017764    3.503932    0.108751    0.085174    0.013069    0.760158    
#> 265: 0.483398    1.017715    3.503984    0.108699    0.085340    0.013078    0.759958    
#> 266: 0.483825    1.018158    3.504031    0.108357    0.085499    0.013047    0.760142    
#> 267: 0.483810    1.018400    3.504027    0.108274    0.085495    0.013016    0.760359    
#> 268: 0.483616    1.018328    3.503807    0.108351    0.085533    0.013015    0.760492    
#> 269: 0.484322    1.018312    3.503748    0.108263    0.085458    0.013023    0.760968    
#> 270: 0.484880    1.018916    3.503545    0.107958    0.085335    0.012997    0.761175    
#> 271: 0.484927    1.019253    3.503358    0.107815    0.085381    0.012999    0.761293    
#> 272: 0.484652    1.019535    3.503190    0.107624    0.085379    0.012999    0.761341    
#> 273: 0.484105    1.019754    3.503117    0.107582    0.085396    0.012981    0.761319    
#> 274: 0.483509    1.019831    3.503097    0.107430    0.085500    0.012951    0.761051    
#> 275: 0.483520    1.020025    3.502920    0.107199    0.085659    0.012929    0.760988    
#> 276: 0.483568    1.020323    3.502988    0.106950    0.085699    0.012887    0.761213    
#> 277: 0.483558    1.020609    3.503119    0.106601    0.085675    0.012848    0.761273    
#> 278: 0.483313    1.020723    3.503203    0.106231    0.085877    0.012827    0.761413    
#> 279: 0.482990    1.020698    3.503210    0.106114    0.086069    0.012804    0.761476    
#> 280: 0.483127    1.020918    3.503276    0.106079    0.086201    0.012778    0.761405    
#> 281: 0.482838    1.021074    3.503365    0.105829    0.086282    0.012759    0.761388    
#> 282: 0.482964    1.021158    3.503475    0.105527    0.086268    0.012755    0.761625    
#> 283: 0.483221    1.021049    3.503581    0.105473    0.085994    0.012757    0.761694    
#> 284: 0.483193    1.021024    3.503545    0.105473    0.085954    0.012746    0.761663    
#> 285: 0.483156    1.021247    3.503306    0.105219    0.086146    0.012719    0.761928    
#> 286: 0.483261    1.021356    3.503190    0.105058    0.086307    0.012702    0.761893    
#> 287: 0.483165    1.021509    3.503126    0.104723    0.086442    0.012664    0.761963    
#> 288: 0.483188    1.021400    3.503169    0.104561    0.086456    0.012631    0.762080    
#> 289: 0.483348    1.021170    3.503173    0.104267    0.086449    0.012606    0.762468    
#> 290: 0.482905    1.021114    3.503025    0.104200    0.086390    0.012609    0.762779    
#> 291: 0.483172    1.021444    3.503149    0.103982    0.086319    0.012645    0.762849    
#> 292: 0.483270    1.021395    3.503184    0.104273    0.086395    0.012634    0.762915    
#> 293: 0.483173    1.021423    3.503127    0.104651    0.086359    0.012624    0.762886    
#> 294: 0.482888    1.021536    3.503055    0.104633    0.086262    0.012600    0.762671    
#> 295: 0.483014    1.021279    3.503053    0.104766    0.086128    0.012567    0.762620    
#> 296: 0.482710    1.021299    3.502960    0.105006    0.086156    0.012582    0.762730    
#> 297: 0.482499    1.021476    3.502856    0.105023    0.086072    0.012616    0.762721    
#> 298: 0.482357    1.021344    3.502806    0.105241    0.086059    0.012610    0.762769    
#> 299: 0.482464    1.021329    3.502870    0.105109    0.086117    0.012588    0.762948    
#> 300: 0.482356    1.021257    3.502893    0.105132    0.086343    0.012575    0.762962    
#> 301: 0.482281    1.021087    3.502737    0.105033    0.086611    0.012549    0.763080    
#> 302: 0.482227    1.020974    3.502705    0.104973    0.086806    0.012535    0.763190    
#> 303: 0.481932    1.021087    3.502706    0.104703    0.086952    0.012552    0.763135    
#> 304: 0.481979    1.021283    3.502644    0.104750    0.086907    0.012538    0.763173    
#> 305: 0.481658    1.020956    3.502608    0.104730    0.086908    0.012524    0.763236    
#> 306: 0.481129    1.021034    3.502418    0.104706    0.086843    0.012535    0.763257    
#> 307: 0.480886    1.021133    3.502349    0.104849    0.087077    0.012540    0.763315    
#> 308: 0.480657    1.021024    3.502319    0.105013    0.087126    0.012547    0.763479    
#> 309: 0.481009    1.020822    3.502380    0.104825    0.087137    0.012576    0.763643    
#> 310: 0.481475    1.020542    3.502411    0.104974    0.087307    0.012560    0.763740    
#> 311: 0.481657    1.020322    3.502535    0.105116    0.087342    0.012549    0.763625    
#> 312: 0.481538    1.020185    3.502510    0.104883    0.087332    0.012558    0.763623    
#> 313: 0.481638    1.020038    3.502474    0.104591    0.087320    0.012543    0.763951    
#> 314: 0.481281    1.020284    3.502303    0.104590    0.087361    0.012535    0.763914    
#> 315: 0.480803    1.020533    3.502218    0.104746    0.087185    0.012529    0.763835    
#> 316: 0.480565    1.020800    3.502088    0.104688    0.087221    0.012509    0.763946    
#> 317: 0.480274    1.020826    3.501991    0.104750    0.087069    0.012500    0.764031    
#> 318: 0.480147    1.020964    3.501807    0.104750    0.086910    0.012502    0.764076    
#> 319: 0.480111    1.021033    3.501713    0.104713    0.086896    0.012495    0.764090    
#> 320: 0.479589    1.021169    3.501475    0.104792    0.086872    0.012476    0.764262    
#> 321: 0.479110    1.021347    3.501257    0.104990    0.086892    0.012452    0.764470    
#> 322: 0.478760    1.021422    3.501056    0.105039    0.086788    0.012422    0.764537    
#> 323: 0.478189    1.021476    3.500944    0.105274    0.086691    0.012417    0.764549    
#> 324: 0.478160    1.021737    3.500929    0.105444    0.086688    0.012405    0.764389    
#> 325: 0.477964    1.022067    3.500822    0.105417    0.086734    0.012406    0.764222    
#> 326: 0.477767    1.022002    3.500682    0.105279    0.086784    0.012412    0.764387    
#> 327: 0.477598    1.022055    3.500674    0.105558    0.086963    0.012435    0.764533    
#> 328: 0.477501    1.022175    3.500582    0.105647    0.086990    0.012410    0.764539    
#> 329: 0.477499    1.022401    3.500497    0.105686    0.086941    0.012388    0.764627    
#> 330: 0.477204    1.022541    3.500419    0.105527    0.086876    0.012375    0.764700    
#> 331: 0.477003    1.022807    3.500298    0.105452    0.086976    0.012346    0.764614    
#> 332: 0.476825    1.022786    3.500257    0.105283    0.086998    0.012318    0.764681    
#> 333: 0.476550    1.022841    3.500127    0.105214    0.087048    0.012296    0.764617    
#> 334: 0.476099    1.022813    3.499926    0.105347    0.087085    0.012275    0.764458    
#> 335: 0.475707    1.022929    3.499737    0.105422    0.087096    0.012253    0.764427    
#> 336: 0.475329    1.023155    3.499599    0.105433    0.087136    0.012244    0.764570    
#> 337: 0.475120    1.023648    3.499427    0.105478    0.087191    0.012243    0.764595    
#> 338: 0.475160    1.023887    3.499471    0.105541    0.087231    0.012229    0.764612    
#> 339: 0.474964    1.024111    3.499457    0.105784    0.087188    0.012243    0.764544    
#> 340: 0.474670    1.024166    3.499422    0.105858    0.087210    0.012242    0.764537    
#> 341: 0.474471    1.024235    3.499386    0.105949    0.087226    0.012258    0.764563    
#> 342: 0.474175    1.024174    3.499349    0.105933    0.087327    0.012262    0.764518    
#> 343: 0.473896    1.024102    3.499360    0.105838    0.087356    0.012259    0.764487    
#> 344: 0.473992    1.024066    3.499423    0.105580    0.087324    0.012266    0.764536    
#> 345: 0.474093    1.023989    3.499471    0.105557    0.087348    0.012283    0.764471    
#> 346: 0.474216    1.023948    3.499431    0.105477    0.087307    0.012287    0.764307    
#> 347: 0.474254    1.023896    3.499359    0.105627    0.087333    0.012317    0.764247    
#> 348: 0.474022    1.023969    3.499226    0.105673    0.087318    0.012337    0.764167    
#> 349: 0.473937    1.024047    3.499159    0.105638    0.087209    0.012364    0.764097    
#> 350: 0.473692    1.024027    3.499029    0.105520    0.087119    0.012378    0.764182    
#> 351: 0.473483    1.024218    3.498953    0.105314    0.087037    0.012379    0.764274    
#> 352: 0.473049    1.024369    3.498908    0.105264    0.087001    0.012382    0.764418    
#> 353: 0.472805    1.024471    3.498873    0.105223    0.086904    0.012384    0.764362    
#> 354: 0.472585    1.024530    3.498763    0.105255    0.086819    0.012407    0.764316    
#> 355: 0.472707    1.024580    3.498726    0.105431    0.086808    0.012404    0.764284    
#> 356: 0.472691    1.024502    3.498767    0.105454    0.086802    0.012420    0.764332    
#> 357: 0.472823    1.024591    3.498750    0.105628    0.086756    0.012434    0.764242    
#> 358: 0.472695    1.024729    3.498704    0.105794    0.086672    0.012434    0.764066    
#> 359: 0.472462    1.024983    3.498645    0.105787    0.086556    0.012440    0.764040    
#> 360: 0.472221    1.025134    3.498492    0.105673    0.086524    0.012432    0.763950    
#> 361: 0.471929    1.025193    3.498363    0.105596    0.086481    0.012422    0.763942    
#> 362: 0.471804    1.025263    3.498249    0.105672    0.086399    0.012416    0.763848    
#> 363: 0.471579    1.025310    3.498138    0.105573    0.086355    0.012422    0.763832    
#> 364: 0.471469    1.025349    3.498088    0.105596    0.086387    0.012442    0.763898    
#> 365: 0.471458    1.025178    3.498169    0.105577    0.086310    0.012449    0.763979    
#> 366: 0.471441    1.025180    3.498146    0.105596    0.086351    0.012452    0.764004    
#> 367: 0.471543    1.025202    3.498155    0.105928    0.086357    0.012440    0.763920    
#> 368: 0.471693    1.025197    3.498180    0.106076    0.086283    0.012439    0.763913    
#> 369: 0.471789    1.025151    3.498152    0.106233    0.086298    0.012438    0.763860    
#> 370: 0.471593    1.025239    3.498091    0.106368    0.086223    0.012436    0.763861    
#> 371: 0.471516    1.025401    3.497926    0.106419    0.086137    0.012417    0.763923    
#> 372: 0.471511    1.025482    3.497874    0.106482    0.086050    0.012416    0.763920    
#> 373: 0.471432    1.025730    3.497756    0.106704    0.086035    0.012405    0.763923    
#> 374: 0.471400    1.025840    3.497652    0.106736    0.086040    0.012400    0.763915    
#> 375: 0.471214    1.025913    3.497615    0.106770    0.086035    0.012389    0.763988    
#> 376: 0.471058    1.026062    3.497583    0.106836    0.086052    0.012392    0.763898    
#> 377: 0.470832    1.026213    3.497471    0.106920    0.085997    0.012395    0.763852    
#> 378: 0.470477    1.026313    3.497327    0.107114    0.085983    0.012393    0.763884    
#> 379: 0.470232    1.026278    3.497267    0.107330    0.086076    0.012372    0.763860    
#> 380: 0.469938    1.026305    3.497209    0.107314    0.086131    0.012354    0.763826    
#> 381: 0.469730    1.026323    3.497151    0.107283    0.086256    0.012333    0.763804    
#> 382: 0.469608    1.026276    3.497124    0.107282    0.086324    0.012326    0.763691    
#> 383: 0.469739    1.026209    3.497158    0.107221    0.086289    0.012334    0.763564    
#> 384: 0.469689    1.026073    3.497236    0.107260    0.086197    0.012337    0.763571    
#> 385: 0.469809    1.026043    3.497270    0.107355    0.086171    0.012338    0.763595    
#> 386: 0.470099    1.026154    3.497372    0.107423    0.086108    0.012366    0.763630    
#> 387: 0.470267    1.026088    3.497483    0.107418    0.086104    0.012383    0.763553    
#> 388: 0.470384    1.026068    3.497538    0.107272    0.086093    0.012396    0.763476    
#> 389: 0.470357    1.025933    3.497533    0.107237    0.086025    0.012403    0.763574    
#> 390: 0.470137    1.026003    3.497472    0.107298    0.086024    0.012405    0.763574    
#> 391: 0.470110    1.025949    3.497449    0.107375    0.085941    0.012407    0.763506    
#> 392: 0.470197    1.025899    3.497493    0.107501    0.085833    0.012415    0.763584    
#> 393: 0.470216    1.025878    3.497516    0.107677    0.085723    0.012422    0.763592    
#> 394: 0.470140    1.025845    3.497521    0.107674    0.085652    0.012438    0.763616    
#> 395: 0.470306    1.025962    3.497512    0.107659    0.085607    0.012457    0.763814    
#> 396: 0.470547    1.026005    3.497527    0.107543    0.085555    0.012473    0.763773    
#> 397: 0.470777    1.025967    3.497582    0.107388    0.085487    0.012472    0.763798    
#> 398: 0.470926    1.025864    3.497641    0.107328    0.085528    0.012463    0.763882    
#> 399: 0.471015    1.025908    3.497673    0.107447    0.085614    0.012457    0.763830    
#> 400: 0.471124    1.025855    3.497750    0.107422    0.085636    0.012450    0.763819    
#> 401: 0.471112    1.025909    3.497744    0.107462    0.085575    0.012464    0.763891    
#> 402: 0.471112    1.026068    3.497764    0.107452    0.085478    0.012476    0.763937    
#> 403: 0.471404    1.026081    3.497805    0.107396    0.085424    0.012471    0.763928    
#> 404: 0.471548    1.026166    3.497753    0.107392    0.085408    0.012465    0.763969    
#> 405: 0.471512    1.026257    3.497746    0.107465    0.085491    0.012451    0.763928    
#> 406: 0.471594    1.026282    3.497690    0.107652    0.085451    0.012441    0.763935    
#> 407: 0.471691    1.026209    3.497748    0.107746    0.085515    0.012445    0.763867    
#> 408: 0.471719    1.026258    3.497758    0.107763    0.085574    0.012434    0.763833    
#> 409: 0.471589    1.026152    3.497716    0.107852    0.085650    0.012422    0.763709    
#> 410: 0.471475    1.026162    3.497662    0.107851    0.085721    0.012410    0.763686    
#> 411: 0.471545    1.025982    3.497648    0.107907    0.085819    0.012408    0.763774    
#> 412: 0.471560    1.025988    3.497640    0.107908    0.085895    0.012407    0.763657    
#> 413: 0.471578    1.026008    3.497595    0.107848    0.085898    0.012407    0.763696    
#> 414: 0.471378    1.026053    3.497596    0.107852    0.085852    0.012411    0.763708    
#> 415: 0.471485    1.026014    3.497593    0.107907    0.085797    0.012432    0.763662    
#> 416: 0.471654    1.026095    3.497595    0.107987    0.085799    0.012440    0.763601    
#> 417: 0.471813    1.026057    3.497611    0.107952    0.085900    0.012446    0.763573    
#> 418: 0.471670    1.026170    3.497585    0.107968    0.085989    0.012443    0.763478    
#> 419: 0.471635    1.026337    3.497554    0.107993    0.086027    0.012445    0.763340    
#> 420: 0.471691    1.026428    3.497530    0.107993    0.086046    0.012434    0.763187    
#> 421: 0.471613    1.026475    3.497544    0.107946    0.086021    0.012421    0.763071    
#> 422: 0.471705    1.026399    3.497544    0.107866    0.085965    0.012412    0.763131    
#> 423: 0.471792    1.026364    3.497531    0.107854    0.085985    0.012410    0.763193    
#> 424: 0.471763    1.026321    3.497517    0.107877    0.085973    0.012406    0.763200    
#> 425: 0.471858    1.026362    3.497530    0.107903    0.085960    0.012418    0.763290    
#> 426: 0.471877    1.026389    3.497512    0.107937    0.085919    0.012406    0.763312    
#> 427: 0.471814    1.026374    3.497525    0.107840    0.085943    0.012409    0.763226    
#> 428: 0.471638    1.026441    3.497548    0.107905    0.085981    0.012408    0.763182    
#> 429: 0.471660    1.026429    3.497580    0.107872    0.086022    0.012403    0.763138    
#> 430: 0.471630    1.026552    3.497550    0.107876    0.085984    0.012413    0.763077    
#> 431: 0.471591    1.026660    3.497469    0.107877    0.085951    0.012418    0.763072    
#> 432: 0.471654    1.026818    3.497493    0.107796    0.085939    0.012439    0.763036    
#> 433: 0.471729    1.026987    3.497564    0.107684    0.085920    0.012456    0.763064    
#> 434: 0.471666    1.026925    3.497614    0.107569    0.085889    0.012463    0.762986    
#> 435: 0.471660    1.026904    3.497617    0.107503    0.085914    0.012467    0.762910    
#> 436: 0.471569    1.026805    3.497654    0.107492    0.085906    0.012471    0.762902    
#> 437: 0.471648    1.026742    3.497646    0.107541    0.085891    0.012469    0.762836    
#> 438: 0.471745    1.026862    3.497674    0.107460    0.085979    0.012458    0.762791    
#> 439: 0.471766    1.026904    3.497689    0.107416    0.085995    0.012447    0.762788    
#> 440: 0.471697    1.026961    3.497703    0.107386    0.086047    0.012438    0.762759    
#> 441: 0.471723    1.026937    3.497756    0.107420    0.086018    0.012434    0.762764    
#> 442: 0.471794    1.026935    3.497820    0.107482    0.086053    0.012428    0.762728    
#> 443: 0.471704    1.026990    3.497764    0.107567    0.086166    0.012415    0.762684    
#> 444: 0.471705    1.027038    3.497703    0.107660    0.086200    0.012398    0.762665    
#> 445: 0.471614    1.027085    3.497623    0.107725    0.086318    0.012385    0.762707    
#> 446: 0.471470    1.027092    3.497572    0.107669    0.086322    0.012365    0.762688    
#> 447: 0.471458    1.027205    3.497534    0.107743    0.086393    0.012353    0.762681    
#> 448: 0.471252    1.027342    3.497491    0.107759    0.086390    0.012346    0.762675    
#> 449: 0.471108    1.027442    3.497518    0.107778    0.086335    0.012347    0.762716    
#> 450: 0.470984    1.027432    3.497505    0.107803    0.086282    0.012359    0.762712    
#> 451: 0.470911    1.027425    3.497463    0.107834    0.086228    0.012367    0.762758    
#> 452: 0.470775    1.027453    3.497430    0.107815    0.086203    0.012368    0.762691    
#> 453: 0.470597    1.027432    3.497379    0.107867    0.086165    0.012372    0.762652    
#> 454: 0.470544    1.027558    3.497315    0.107978    0.086182    0.012359    0.762589    
#> 455: 0.470536    1.027556    3.497270    0.108054    0.086139    0.012348    0.762625    
#> 456: 0.470405    1.027505    3.497237    0.108032    0.086090    0.012343    0.762645    
#> 457: 0.470319    1.027524    3.497272    0.108016    0.086040    0.012330    0.762631    
#> 458: 0.470274    1.027593    3.497311    0.107974    0.085988    0.012333    0.762602    
#> 459: 0.470168    1.027737    3.497317    0.107967    0.085934    0.012342    0.762588    
#> 460: 0.470000    1.027778    3.497275    0.108015    0.085859    0.012348    0.762557    
#> 461: 0.469870    1.027820    3.497281    0.108116    0.085786    0.012346    0.762591    
#> 462: 0.469813    1.027874    3.497295    0.108183    0.085788    0.012338    0.762570    
#> 463: 0.469957    1.027990    3.497281    0.108179    0.085789    0.012342    0.762573    
#> 464: 0.469937    1.028074    3.497256    0.108164    0.085769    0.012337    0.762542    
#> 465: 0.469918    1.027850    3.497288    0.108197    0.085741    0.012342    0.762642    
#> 466: 0.470032    1.027901    3.497251    0.108191    0.085700    0.012332    0.762693    
#> 467: 0.470092    1.027851    3.497279    0.108106    0.085684    0.012325    0.762741    
#> 468: 0.470252    1.027792    3.497332    0.108094    0.085621    0.012326    0.762836    
#> 469: 0.470262    1.027850    3.497345    0.108106    0.085604    0.012320    0.762941    
#> 470: 0.470125    1.027880    3.497301    0.108070    0.085620    0.012327    0.762997    
#> 471: 0.469956    1.027863    3.497252    0.107985    0.085585    0.012318    0.763020    
#> 472: 0.469897    1.027900    3.497248    0.108031    0.085601    0.012307    0.762986    
#> 473: 0.469736    1.027924    3.497236    0.108060    0.085608    0.012305    0.762979    
#> 474: 0.469658    1.027904    3.497208    0.108007    0.085601    0.012301    0.762985    
#> 475: 0.469595    1.028001    3.497167    0.108004    0.085552    0.012301    0.763001    
#> 476: 0.469610    1.028036    3.497120    0.108007    0.085517    0.012289    0.763082    
#> 477: 0.469476    1.028097    3.497116    0.108086    0.085538    0.012278    0.763039    
#> 478: 0.469328    1.028120    3.497077    0.108157    0.085550    0.012262    0.763030    
#> 479: 0.469343    1.028141    3.497046    0.108172    0.085554    0.012249    0.763048    
#> 480: 0.469329    1.028211    3.497024    0.108170    0.085631    0.012237    0.763112    
#> 481: 0.469186    1.028253    3.497016    0.108147    0.085674    0.012226    0.763140    
#> 482: 0.469247    1.028280    3.496994    0.108192    0.085686    0.012221    0.763181    
#> 483: 0.469276    1.028248    3.496999    0.108139    0.085691    0.012214    0.763209    
#> 484: 0.469318    1.028134    3.497013    0.108165    0.085670    0.012203    0.763337    
#> 485: 0.469354    1.028110    3.497045    0.108109    0.085673    0.012209    0.763470    
#> 486: 0.469412    1.028171    3.497051    0.108008    0.085650    0.012208    0.763422    
#> 487: 0.469608    1.028204    3.497133    0.107975    0.085701    0.012214    0.763359    
#> 488: 0.469582    1.028225    3.497157    0.107913    0.085671    0.012215    0.763351    
#> 489: 0.469692    1.028184    3.497171    0.107895    0.085632    0.012216    0.763421    
#> 490: 0.469757    1.028181    3.497225    0.107883    0.085621    0.012221    0.763461    
#> 491: 0.469853    1.028252    3.497290    0.107937    0.085640    0.012223    0.763399    
#> 492: 0.469824    1.028284    3.497301    0.108032    0.085639    0.012221    0.763363    
#> 493: 0.469853    1.028221    3.497334    0.108146    0.085623    0.012226    0.763296    
#> 494: 0.469862    1.028287    3.497294    0.108132    0.085606    0.012219    0.763215    
#> 495: 0.469889    1.028315    3.497293    0.108031    0.085573    0.012222    0.763226    
#> 496: 0.470022    1.028365    3.497276    0.107977    0.085602    0.012219    0.763267    
#> 497: 0.469956    1.028340    3.497274    0.107987    0.085610    0.012218    0.763266    
#> 498: 0.469961    1.028250    3.497280    0.107996    0.085606    0.012210    0.763243    
#> 499: 0.469991    1.028241    3.497264    0.108006    0.085629    0.012197    0.763199    
#> 500: 0.470046    1.028157    3.497258    0.107990    0.085637    0.012187    0.763231    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.350190    0.964449    3.444291    0.392401    0.086982    0.016800    1.662139    
#> 002: 0.457392    0.957938    3.439319    0.372781    0.082633    0.015960    1.176933    
#> 003: 0.576870    0.865947    3.458127    0.354142    0.078502    0.015162    0.918135    
#> 004: 0.535489    0.863527    3.443745    0.336435    0.074577    0.014404    0.846640    
#> 005: 0.589651    0.875172    3.422789    0.319613    0.076452    0.013684    0.803492    
#> 006: 0.560416    0.889097    3.417226    0.303633    0.074368    0.013000    0.755447    
#> 007: 0.544106    0.894793    3.413207    0.312352    0.087324    0.012350    0.765439    
#> 008: 0.513988    0.889823    3.407494    0.296734    0.100021    0.011773    0.777927    
#> 009: 0.500411    0.880512    3.414581    0.281898    0.096328    0.011184    0.776184    
#> 010: 0.550762    0.884923    3.417187    0.292465    0.098453    0.010625    0.770893    
#> 011: 0.574428    0.863319    3.426079    0.283926    0.093530    0.010310    0.782709    
#> 012: 0.573127    0.870556    3.414578    0.293384    0.088854    0.009795    0.772746    
#> 013: 0.521876    0.861497    3.415028    0.278714    0.084501    0.009305    0.778326    
#> 014: 0.520419    0.876514    3.411634    0.264779    0.103090    0.008840    0.793913    
#> 015: 0.547527    0.867171    3.423076    0.254401    0.097935    0.008398    0.784591    
#> 016: 0.573467    0.883915    3.432267    0.241681    0.093038    0.007978    0.785774    
#> 017: 0.564618    0.880096    3.437708    0.263823    0.101295    0.007579    0.769014    
#> 018: 0.576719    0.893194    3.417361    0.263088    0.098812    0.007592    0.781469    
#> 019: 0.504559    0.876880    3.415165    0.259136    0.093871    0.007213    0.769073    
#> 020: 0.532407    0.894306    3.419976    0.246179    0.099863    0.006852    0.789412    
#> 021: 0.529626    0.869977    3.421832    0.233870    0.094870    0.006509    0.782743    
#> 022: 0.526596    0.888125    3.428306    0.222177    0.094178    0.006184    0.772727    
#> 023: 0.579889    0.886960    3.428826    0.268707    0.089469    0.005875    0.791081    
#> 024: 0.583270    0.895025    3.431405    0.279499    0.090084    0.005581    0.782765    
#> 025: 0.614644    0.881349    3.429383    0.349841    0.095739    0.005302    0.779228    
#> 026: 0.588034    0.887055    3.433940    0.332349    0.105321    0.005037    0.777589    
#> 027: 0.604643    0.889165    3.432374    0.315731    0.112559    0.004851    0.791498    
#> 028: 0.608487    0.879278    3.442237    0.303270    0.106931    0.005095    0.758678    
#> 029: 0.596109    0.887579    3.426802    0.368057    0.101585    0.004840    0.769103    
#> 030: 0.581935    0.888837    3.424522    0.349654    0.127413    0.004793    0.759602    
#> 031: 0.558845    0.870246    3.426895    0.351835    0.121043    0.004553    0.752385    
#> 032: 0.543872    0.857613    3.431456    0.334244    0.114991    0.004527    0.746736    
#> 033: 0.545097    0.882823    3.428734    0.317531    0.109241    0.005660    0.754964    
#> 034: 0.563177    0.879091    3.428431    0.301655    0.108826    0.005573    0.760556    
#> 035: 0.554134    0.868581    3.422792    0.286572    0.103385    0.005295    0.765732    
#> 036: 0.542372    0.890864    3.414014    0.327587    0.098577    0.006124    0.769548    
#> 037: 0.524160    0.884820    3.421342    0.311208    0.093648    0.005906    0.780026    
#> 038: 0.539959    0.894780    3.414262    0.334327    0.094189    0.005956    0.768656    
#> 039: 0.550806    0.898371    3.411040    0.317611    0.089480    0.006955    0.768232    
#> 040: 0.506406    0.911611    3.412220    0.323338    0.088919    0.006607    0.776371    
#> 041: 0.541977    0.887961    3.415686    0.397664    0.084473    0.006277    0.744504    
#> 042: 0.581207    0.875826    3.415739    0.383098    0.091828    0.005963    0.761360    
#> 043: 0.539253    0.886413    3.409992    0.363943    0.087237    0.006155    0.748778    
#> 044: 0.521699    0.907949    3.407696    0.374161    0.097461    0.005959    0.742614    
#> 045: 0.543794    0.925164    3.399155    0.394896    0.092588    0.006277    0.748683    
#> 046: 0.540863    0.907540    3.409265    0.375151    0.094049    0.005963    0.748114    
#> 047: 0.542183    0.914127    3.406537    0.356394    0.089347    0.006592    0.771307    
#> 048: 0.516833    0.906820    3.404629    0.338574    0.084880    0.006738    0.770263    
#> 049: 0.521121    0.880218    3.419560    0.321645    0.093438    0.006777    0.775668    
#> 050: 0.588852    0.859322    3.418559    0.338909    0.088766    0.006439    0.792861    
#> 051: 0.536080    0.906662    3.411658    0.321964    0.084328    0.006117    0.811612    
#> 052: 0.554444    0.887901    3.421189    0.305866    0.090090    0.005811    0.778915    
#> 053: 0.545452    0.880868    3.429649    0.290573    0.099792    0.005520    0.780554    
#> 054: 0.519208    0.864364    3.432187    0.276044    0.105428    0.005244    0.788012    
#> 055: 0.540450    0.894575    3.421169    0.262242    0.100156    0.004982    0.778852    
#> 056: 0.571087    0.870879    3.427843    0.249130    0.101513    0.004733    0.789100    
#> 057: 0.573350    0.830895    3.431961    0.268069    0.096438    0.005629    0.798923    
#> 058: 0.557355    0.846301    3.423703    0.254665    0.093289    0.005347    0.798348    
#> 059: 0.577180    0.815364    3.434629    0.269975    0.090242    0.006246    0.820092    
#> 060: 0.552212    0.811982    3.442060    0.256477    0.095222    0.005933    0.821195    
#> 061: 0.565855    0.841731    3.432914    0.243653    0.100927    0.005637    0.812584    
#> 062: 0.544200    0.855201    3.438119    0.258234    0.095881    0.005355    0.828760    
#> 063: 0.568858    0.850470    3.433494    0.245322    0.106032    0.005087    0.807799    
#> 064: 0.536129    0.870321    3.434776    0.233056    0.100731    0.004833    0.803613    
#> 065: 0.556955    0.849599    3.428014    0.228875    0.097299    0.004591    0.782370    
#> 066: 0.554681    0.872304    3.426500    0.236642    0.098460    0.004368    0.757416    
#> 067: 0.564424    0.862031    3.424256    0.259771    0.093537    0.004149    0.769463    
#> 068: 0.505272    0.894424    3.423922    0.259836    0.103068    0.003942    0.786939    
#> 069: 0.526784    0.900131    3.414737    0.267256    0.106015    0.004585    0.791653    
#> 070: 0.531954    0.874931    3.426087    0.282667    0.100714    0.004576    0.764437    
#> 071: 0.489344    0.884527    3.408715    0.268533    0.100749    0.004937    0.781303    
#> 072: 0.449553    0.866083    3.399458    0.273236    0.095712    0.005958    0.772957    
#> 073: 0.507824    0.906022    3.412168    0.340997    0.090926    0.006569    0.775303    
#> 074: 0.526795    0.883093    3.408960    0.323947    0.086380    0.006241    0.787795    
#> 075: 0.543551    0.853614    3.432597    0.307750    0.088206    0.006702    0.778548    
#> 076: 0.575067    0.874893    3.440022    0.292363    0.084614    0.006367    0.769165    
#> 077: 0.588643    0.858235    3.424569    0.321243    0.094743    0.006049    0.763207    
#> 078: 0.547109    0.881043    3.426063    0.305181    0.090899    0.005746    0.769600    
#> 079: 0.561158    0.888594    3.427164    0.327882    0.086354    0.005459    0.801294    
#> 080: 0.571153    0.879397    3.420981    0.356352    0.106294    0.005196    0.801407    
#> 081: 0.565133    0.896340    3.418563    0.338534    0.100979    0.006198    0.783512    
#> 082: 0.572611    0.874732    3.430227    0.333713    0.095930    0.007421    0.791651    
#> 083: 0.590666    0.891567    3.431215    0.342126    0.091134    0.007906    0.761719    
#> 084: 0.567941    0.895742    3.424949    0.325020    0.086577    0.007511    0.750457    
#> 085: 0.576609    0.913790    3.428529    0.308769    0.082248    0.007135    0.766615    
#> 086: 0.547571    0.898971    3.429997    0.293330    0.085488    0.007099    0.762253    
#> 087: 0.543099    0.894456    3.417606    0.278664    0.102575    0.006744    0.769546    
#> 088: 0.503588    0.891177    3.419436    0.264731    0.097446    0.006407    0.784710    
#> 089: 0.523403    0.901194    3.408100    0.251494    0.098924    0.006212    0.789220    
#> 090: 0.505326    0.903423    3.403799    0.238919    0.093978    0.005902    0.809334    
#> 091: 0.479231    0.884511    3.393123    0.226973    0.099100    0.005607    0.798552    
#> 092: 0.498714    0.924857    3.394839    0.255903    0.094145    0.005326    0.805142    
#> 093: 0.468704    0.897118    3.402811    0.243108    0.089438    0.005591    0.792095    
#> 094: 0.470629    0.908456    3.392928    0.241836    0.093963    0.005311    0.821942    
#> 095: 0.478963    0.924411    3.402039    0.231949    0.099210    0.005046    0.802579    
#> 096: 0.480099    0.918947    3.405301    0.223138    0.101782    0.004794    0.782115    
#> 097: 0.535636    0.919002    3.411670    0.244718    0.103370    0.004554    0.777436    
#> 098: 0.532320    0.915553    3.420494    0.244343    0.098202    0.004326    0.781979    
#> 099: 0.507538    0.870597    3.412284    0.243153    0.096224    0.004829    0.773069    
#> 100: 0.508006    0.883328    3.410228    0.275770    0.091413    0.004842    0.771352    
#> 101: 0.469697    0.878219    3.397619    0.261981    0.099154    0.004600    0.776310    
#> 102: 0.503358    0.898284    3.389313    0.282504    0.106846    0.004370    0.781997    
#> 103: 0.535619    0.906169    3.400290    0.268379    0.101504    0.004151    0.780095    
#> 104: 0.507064    0.895519    3.401308    0.300594    0.096429    0.003944    0.757840    
#> 105: 0.509855    0.901105    3.398135    0.285565    0.101198    0.003747    0.771278    
#> 106: 0.495485    0.915817    3.397260    0.271286    0.096138    0.003656    0.767462    
#> 107: 0.550654    0.911634    3.404577    0.323562    0.091331    0.003474    0.782048    
#> 108: 0.528873    0.911069    3.402287    0.307384    0.119954    0.003300    0.784077    
#> 109: 0.498619    0.914152    3.407270    0.292015    0.113957    0.003135    0.788808    
#> 110: 0.543272    0.882514    3.402650    0.277414    0.108259    0.002978    0.782553    
#> 111: 0.513919    0.886158    3.411244    0.263543    0.107845    0.002829    0.792105    
#> 112: 0.518721    0.859858    3.405619    0.250366    0.104490    0.002688    0.796199    
#> 113: 0.516077    0.900825    3.409124    0.237848    0.099265    0.002553    0.778135    
#> 114: 0.519391    0.897625    3.414295    0.250442    0.096494    0.002426    0.787608    
#> 115: 0.563038    0.863013    3.413081    0.260477    0.091669    0.002304    0.790342    
#> 116: 0.543026    0.893399    3.417926    0.247453    0.103329    0.002692    0.766028    
#> 117: 0.508808    0.903681    3.415993    0.235081    0.110775    0.002557    0.807417    
#> 118: 0.507000    0.869141    3.418290    0.223326    0.122100    0.002429    0.820389    
#> 119: 0.535889    0.884383    3.418758    0.223631    0.115995    0.002412    0.816257    
#> 120: 0.541085    0.874878    3.423941    0.237661    0.110195    0.002291    0.797029    
#> 121: 0.570365    0.894252    3.419666    0.271205    0.133455    0.002177    0.782490    
#> 122: 0.535299    0.873631    3.420452    0.257645    0.126782    0.002068    0.782547    
#> 123: 0.585694    0.867244    3.424760    0.244762    0.120443    0.001965    0.792036    
#> 124: 0.565425    0.887774    3.424451    0.232524    0.114421    0.002389    0.773678    
#> 125: 0.562484    0.906105    3.418447    0.225192    0.108700    0.002471    0.773131    
#> 126: 0.510312    0.905074    3.413202    0.213933    0.105452    0.003022    0.793261    
#> 127: 0.534915    0.896123    3.411641    0.236577    0.100180    0.002900    0.800466    
#> 128: 0.524008    0.892069    3.415131    0.224749    0.095171    0.002774    0.803053    
#> 129: 0.543730    0.900864    3.420049    0.213511    0.099370    0.002635    0.796408    
#> 130: 0.542928    0.920636    3.417113    0.202836    0.094401    0.002504    0.793872    
#> 131: 0.550531    0.868003    3.421326    0.229783    0.112503    0.002778    0.811630    
#> 132: 0.508025    0.888942    3.412120    0.248664    0.106877    0.003091    0.774945    
#> 133: 0.527016    0.878348    3.410247    0.236230    0.101534    0.003093    0.785231    
#> 134: 0.564270    0.888341    3.414856    0.278252    0.101508    0.004709    0.772675    
#> 135: 0.549121    0.881744    3.419650    0.281359    0.096433    0.004648    0.786266    
#> 136: 0.558264    0.880187    3.424626    0.267291    0.091611    0.004416    0.792497    
#> 137: 0.605351    0.855172    3.434480    0.311054    0.089272    0.004195    0.792390    
#> 138: 0.563124    0.872681    3.433018    0.319421    0.084808    0.004143    0.767150    
#> 139: 0.555955    0.889798    3.437755    0.303450    0.085777    0.004729    0.772256    
#> 140: 0.554279    0.905320    3.434419    0.288277    0.089822    0.005884    0.779429    
#> 141: 0.570004    0.855192    3.440905    0.273863    0.085331    0.005590    0.780503    
#> 142: 0.601362    0.848648    3.454802    0.280033    0.081064    0.005425    0.789475    
#> 143: 0.533514    0.874368    3.445640    0.267831    0.077852    0.005419    0.804288    
#> 144: 0.599428    0.873285    3.453887    0.254439    0.081698    0.005148    0.791514    
#> 145: 0.585998    0.894873    3.441924    0.241720    0.082808    0.004891    0.765371    
#> 146: 0.586519    0.879913    3.445296    0.276020    0.084701    0.005552    0.773737    
#> 147: 0.542931    0.862986    3.436306    0.262219    0.098175    0.005724    0.752401    
#> 148: 0.545600    0.880494    3.443211    0.277188    0.093266    0.005438    0.758378    
#> 149: 0.574582    0.861626    3.446958    0.278068    0.093612    0.005166    0.778787    
#> 150: 0.582994    0.859462    3.442466    0.264164    0.097927    0.004954    0.785222    
#> 151: 0.533638    0.895639    3.430418    0.268011    0.096903    0.005207    0.784888    
#> 152: 0.560653    0.884941    3.435497    0.328978    0.095149    0.004600    0.766889    
#> 153: 0.561187    0.877539    3.438027    0.269120    0.090258    0.005781    0.776782    
#> 154: 0.581028    0.869773    3.441126    0.242048    0.082188    0.006708    0.780498    
#> 155: 0.552048    0.862010    3.434429    0.246999    0.070444    0.008197    0.771920    
#> 156: 0.551148    0.877180    3.440621    0.287635    0.079340    0.008271    0.767111    
#> 157: 0.576805    0.859533    3.438994    0.299188    0.070277    0.009053    0.779974    
#> 158: 0.564699    0.882078    3.430353    0.275480    0.087799    0.007626    0.766723    
#> 159: 0.521081    0.889177    3.429668    0.273565    0.098953    0.006639    0.775900    
#> 160: 0.567377    0.847298    3.436879    0.287132    0.112824    0.006978    0.769762    
#> 161: 0.606720    0.873618    3.431920    0.336300    0.093217    0.008135    0.753783    
#> 162: 0.539059    0.905681    3.414779    0.301419    0.090023    0.005314    0.787266    
#> 163: 0.551177    0.865369    3.420904    0.281757    0.092131    0.005575    0.773388    
#> 164: 0.562615    0.874802    3.428650    0.224276    0.086768    0.005586    0.772756    
#> 165: 0.571660    0.849309    3.441773    0.256972    0.080112    0.006517    0.782013    
#> 166: 0.585722    0.898896    3.439820    0.231449    0.088342    0.005090    0.761402    
#> 167: 0.561936    0.895113    3.443824    0.230071    0.087451    0.006659    0.771764    
#> 168: 0.579383    0.903099    3.439326    0.299923    0.085544    0.006719    0.755982    
#> 169: 0.562054    0.934249    3.427760    0.239912    0.087226    0.005389    0.800321    
#> 170: 0.549978    0.899136    3.424297    0.241754    0.087792    0.004673    0.768963    
#> 171: 0.543645    0.881650    3.427861    0.249282    0.095020    0.004481    0.752900    
#> 172: 0.516765    0.900392    3.420860    0.216843    0.074500    0.003633    0.781165    
#> 173: 0.549571    0.912674    3.412368    0.258645    0.077311    0.004714    0.776522    
#> 174: 0.558278    0.889066    3.412155    0.275512    0.078138    0.004682    0.752274    
#> 175: 0.521700    0.900145    3.416537    0.209484    0.079507    0.004414    0.776623    
#> 176: 0.536898    0.907441    3.423815    0.269013    0.083242    0.005024    0.766536    
#> 177: 0.567963    0.874516    3.432233    0.260999    0.098943    0.003319    0.770597    
#> 178: 0.573227    0.865073    3.431715    0.254066    0.097657    0.003346    0.783367    
#> 179: 0.602981    0.886747    3.433065    0.252598    0.108258    0.003673    0.793012    
#> 180: 0.553575    0.863116    3.434600    0.196164    0.098972    0.002778    0.794429    
#> 181: 0.558275    0.844274    3.429337    0.183842    0.110311    0.002364    0.792327    
#> 182: 0.530915    0.873732    3.424212    0.215330    0.091481    0.003096    0.786075    
#> 183: 0.554367    0.877403    3.425250    0.206950    0.104675    0.003548    0.765622    
#> 184: 0.528268    0.874326    3.422307    0.215890    0.089648    0.003513    0.778766    
#> 185: 0.522832    0.907764    3.422056    0.185953    0.090569    0.003429    0.785207    
#> 186: 0.546575    0.913312    3.427070    0.194345    0.090797    0.003645    0.786416    
#> 187: 0.556223    0.900441    3.433062    0.250669    0.093133    0.005030    0.784471    
#> 188: 0.488477    0.914638    3.427113    0.215354    0.083361    0.005284    0.807075    
#> 189: 0.533446    0.895975    3.422068    0.242465    0.085690    0.005028    0.771748    
#> 190: 0.534716    0.884832    3.426309    0.202533    0.082937    0.006302    0.773751    
#> 191: 0.514833    0.888180    3.415615    0.237070    0.083890    0.005452    0.757575    
#> 192: 0.513604    0.898033    3.417055    0.326344    0.101011    0.005835    0.739069    
#> 193: 0.572724    0.907470    3.422439    0.337859    0.098014    0.005511    0.753719    
#> 194: 0.536312    0.887352    3.419385    0.297810    0.096285    0.006481    0.768759    
#> 195: 0.522318    0.883570    3.416622    0.252177    0.066920    0.006450    0.781491    
#> 196: 0.518736    0.889449    3.423542    0.273830    0.072643    0.008534    0.778778    
#> 197: 0.525490    0.892576    3.433714    0.284760    0.073833    0.009363    0.771898    
#> 198: 0.600463    0.872596    3.426897    0.312976    0.063121    0.009559    0.764409    
#> 199: 0.539335    0.874373    3.427025    0.241347    0.071401    0.007907    0.769316    
#> 200: 0.517339    0.870967    3.422247    0.250247    0.076676    0.009571    0.789469    
#> 201: 0.538562    0.866638    3.429114    0.291144    0.077414    0.008645    0.783815    
#> 202: 0.553117    0.871436    3.428218    0.319860    0.080773    0.008576    0.783106    
#> 203: 0.565460    0.867007    3.426897    0.324633    0.086058    0.008264    0.783090    
#> 204: 0.568074    0.860685    3.426538    0.329112    0.086252    0.007854    0.785055    
#> 205: 0.568484    0.867237    3.427408    0.340639    0.085714    0.007720    0.785980    
#> 206: 0.563858    0.874825    3.426829    0.345568    0.084773    0.007893    0.783579    
#> 207: 0.560799    0.876541    3.425689    0.344165    0.083542    0.007914    0.780385    
#> 208: 0.559019    0.878329    3.425286    0.340304    0.082195    0.007854    0.779113    
#> 209: 0.559189    0.876534    3.424566    0.340628    0.081194    0.008055    0.777539    
#> 210: 0.561427    0.875669    3.424864    0.343947    0.081055    0.008093    0.774932    
#> 211: 0.564538    0.877232    3.425292    0.344299    0.080361    0.008127    0.773039    
#> 212: 0.566747    0.876995    3.425587    0.340670    0.079861    0.007940    0.773521    
#> 213: 0.568480    0.875436    3.425993    0.335262    0.080165    0.007985    0.772615    
#> 214: 0.571188    0.875456    3.426366    0.335138    0.080931    0.007957    0.771235    
#> 215: 0.571050    0.876880    3.426542    0.335073    0.080697    0.008099    0.770221    
#> 216: 0.570011    0.876625    3.426169    0.334147    0.080269    0.008210    0.770460    
#> 217: 0.566700    0.878339    3.425517    0.332190    0.079785    0.008137    0.769693    
#> 218: 0.566718    0.880497    3.424638    0.330873    0.080257    0.008081    0.769025    
#> 219: 0.565148    0.881022    3.423375    0.330832    0.080135    0.008024    0.768797    
#> 220: 0.563796    0.882313    3.422911    0.332775    0.080011    0.008070    0.768658    
#> 221: 0.563493    0.882810    3.422553    0.334656    0.080172    0.008095    0.768063    
#> 222: 0.564027    0.882695    3.422333    0.335366    0.080229    0.008182    0.767413    
#> 223: 0.564895    0.883254    3.422396    0.335492    0.079811    0.008232    0.766724    
#> 224: 0.565304    0.883553    3.422841    0.335632    0.079161    0.008231    0.766631    
#> 225: 0.565461    0.882442    3.423217    0.337891    0.078600    0.008345    0.766365    
#> 226: 0.565679    0.881342    3.423215    0.337046    0.078572    0.008300    0.767106    
#> 227: 0.564328    0.881999    3.423134    0.336252    0.078460    0.008267    0.767296    
#> 228: 0.563592    0.882508    3.422958    0.334412    0.078536    0.008222    0.767673    
#> 229: 0.562595    0.881906    3.422707    0.332623    0.078466    0.008185    0.767824    
#> 230: 0.563628    0.881370    3.422584    0.331250    0.078339    0.008147    0.768218    
#> 231: 0.563597    0.881289    3.422931    0.330372    0.078263    0.008104    0.768256    
#> 232: 0.562439    0.880781    3.423536    0.328162    0.078064    0.008108    0.768209    
#> 233: 0.562839    0.880026    3.423964    0.328995    0.077650    0.008141    0.768311    
#> 234: 0.563025    0.879480    3.424561    0.329313    0.077654    0.008121    0.768560    
#> 235: 0.562824    0.878921    3.424663    0.328410    0.077655    0.008135    0.768211    
#> 236: 0.563570    0.878701    3.424416    0.329291    0.077677    0.008134    0.767964    
#> 237: 0.565136    0.878615    3.424346    0.330557    0.077815    0.008127    0.768454    
#> 238: 0.565787    0.878820    3.424398    0.332285    0.078068    0.008149    0.768727    
#> 239: 0.565271    0.879250    3.424385    0.332538    0.078363    0.008201    0.768662    
#> 240: 0.565198    0.879041    3.424536    0.331232    0.078599    0.008217    0.768646    
#> 241: 0.565175    0.878341    3.424593    0.331025    0.078666    0.008188    0.768532    
#> 242: 0.564273    0.878282    3.424247    0.330867    0.078950    0.008185    0.769001    
#> 243: 0.562567    0.878628    3.423888    0.330320    0.078983    0.008179    0.769693    
#> 244: 0.562199    0.878654    3.423788    0.332236    0.078917    0.008227    0.769840    
#> 245: 0.562289    0.878115    3.423913    0.331827    0.079208    0.008240    0.770024    
#> 246: 0.562286    0.877676    3.424158    0.331828    0.079287    0.008292    0.769778    
#> 247: 0.561895    0.877258    3.424330    0.330390    0.079233    0.008333    0.769620    
#> 248: 0.561664    0.877365    3.424461    0.329354    0.079200    0.008303    0.769470    
#> 249: 0.561200    0.877357    3.424549    0.328725    0.079179    0.008276    0.769264    
#> 250: 0.561546    0.877676    3.424694    0.328353    0.079082    0.008231    0.769258    
#> 251: 0.561626    0.877992    3.424985    0.326417    0.079252    0.008190    0.769601    
#> 252: 0.562152    0.877775    3.425341    0.325861    0.079352    0.008157    0.769658    
#> 253: 0.561638    0.877801    3.425511    0.325481    0.079763    0.008103    0.769586    
#> 254: 0.562180    0.877947    3.425787    0.325801    0.079878    0.008058    0.769657    
#> 255: 0.562514    0.877830    3.426054    0.326077    0.080087    0.008023    0.769596    
#> 256: 0.562704    0.877497    3.426191    0.324905    0.080401    0.007993    0.769866    
#> 257: 0.562872    0.877328    3.426214    0.324908    0.080693    0.007968    0.769986    
#> 258: 0.562456    0.877389    3.426154    0.324101    0.080934    0.007905    0.770301    
#> 259: 0.562103    0.877316    3.426080    0.323620    0.081098    0.007882    0.770364    
#> 260: 0.561640    0.877559    3.426135    0.322969    0.081169    0.007906    0.769969    
#> 261: 0.562295    0.877517    3.426267    0.323655    0.081175    0.007907    0.769698    
#> 262: 0.562754    0.878074    3.426431    0.323706    0.081211    0.007926    0.769910    
#> 263: 0.562118    0.878767    3.426338    0.322917    0.081307    0.007933    0.770454    
#> 264: 0.561643    0.879166    3.426162    0.322363    0.081551    0.007947    0.770653    
#> 265: 0.562116    0.879242    3.426129    0.323409    0.081760    0.008015    0.770770    
#> 266: 0.562437    0.879457    3.426033    0.324200    0.081699    0.008056    0.770547    
#> 267: 0.562200    0.879531    3.425929    0.325345    0.081450    0.008072    0.770624    
#> 268: 0.561964    0.879451    3.425756    0.325311    0.081432    0.008071    0.770368    
#> 269: 0.562249    0.879411    3.425707    0.324704    0.081422    0.008077    0.770250    
#> 270: 0.561995    0.879571    3.425520    0.324755    0.081392    0.008079    0.769984    
#> 271: 0.561564    0.879779    3.425285    0.324222    0.081413    0.008081    0.769989    
#> 272: 0.561269    0.879643    3.425202    0.323457    0.081437    0.008067    0.770376    
#> 273: 0.561107    0.879876    3.425213    0.323645    0.081522    0.008058    0.770493    
#> 274: 0.561179    0.879911    3.425277    0.323573    0.081732    0.008040    0.770162    
#> 275: 0.561237    0.880010    3.425206    0.323377    0.081901    0.008023    0.770037    
#> 276: 0.560841    0.880178    3.425263    0.323733    0.081942    0.008009    0.769792    
#> 277: 0.560692    0.880189    3.425428    0.323829    0.081869    0.008008    0.769738    
#> 278: 0.560522    0.880327    3.425381    0.323767    0.081735    0.008010    0.769619    
#> 279: 0.560254    0.880198    3.425408    0.322867    0.081756    0.007989    0.769641    
#> 280: 0.560076    0.880178    3.425488    0.322416    0.081839    0.007976    0.769479    
#> 281: 0.559578    0.880094    3.425600    0.321274    0.082067    0.007963    0.769595    
#> 282: 0.559178    0.880194    3.425682    0.320395    0.082201    0.007954    0.769671    
#> 283: 0.559425    0.880127    3.425791    0.320430    0.082391    0.007939    0.769967    
#> 284: 0.559169    0.879690    3.425825    0.320305    0.082467    0.007938    0.770230    
#> 285: 0.559306    0.879594    3.425819    0.320630    0.082510    0.007965    0.770311    
#> 286: 0.559207    0.879878    3.425699    0.320941    0.082671    0.007984    0.770233    
#> 287: 0.558973    0.880063    3.425585    0.320980    0.082896    0.007994    0.770209    
#> 288: 0.559234    0.880004    3.425575    0.320669    0.082811    0.007985    0.770228    
#> 289: 0.559590    0.880036    3.425575    0.320538    0.082818    0.007980    0.770213    
#> 290: 0.559549    0.880087    3.425562    0.320196    0.083005    0.007950    0.770044    
#> 291: 0.559718    0.880204    3.425593    0.319612    0.083023    0.007921    0.770028    
#> 292: 0.559302    0.880010    3.425560    0.318859    0.082993    0.007888    0.770056    
#> 293: 0.559103    0.880017    3.425521    0.318403    0.083032    0.007863    0.770205    
#> 294: 0.559105    0.880245    3.425464    0.317951    0.083098    0.007847    0.770326    
#> 295: 0.558710    0.879856    3.425445    0.318083    0.083287    0.007830    0.770293    
#> 296: 0.558737    0.879615    3.425463    0.318259    0.083407    0.007823    0.770184    
#> 297: 0.558874    0.879711    3.425485    0.318074    0.083454    0.007813    0.770242    
#> 298: 0.559437    0.879714    3.425536    0.318216    0.083693    0.007783    0.770170    
#> 299: 0.559727    0.879843    3.425583    0.318225    0.083749    0.007753    0.769914    
#> 300: 0.560227    0.879657    3.425758    0.318248    0.083745    0.007749    0.769747    
#> 301: 0.560446    0.879441    3.425754    0.318002    0.083827    0.007735    0.769856    
#> 302: 0.560515    0.879453    3.425788    0.317433    0.083904    0.007716    0.769817    
#> 303: 0.560544    0.879522    3.425780    0.316849    0.084125    0.007700    0.769750    
#> 304: 0.560674    0.879726    3.425659    0.316454    0.084227    0.007667    0.769894    
#> 305: 0.560051    0.879706    3.425572    0.315614    0.084214    0.007641    0.770088    
#> 306: 0.559682    0.879702    3.425357    0.314992    0.084219    0.007631    0.770189    
#> 307: 0.559539    0.879799    3.425265    0.314950    0.084332    0.007624    0.770363    
#> 308: 0.559092    0.879882    3.425112    0.315538    0.084268    0.007634    0.770617    
#> 309: 0.558939    0.879835    3.424966    0.316068    0.084312    0.007638    0.770591    
#> 310: 0.559136    0.879877    3.424751    0.316912    0.084308    0.007639    0.770573    
#> 311: 0.559012    0.880019    3.424654    0.317235    0.084209    0.007651    0.770459    
#> 312: 0.558728    0.880062    3.424435    0.317405    0.084121    0.007657    0.770442    
#> 313: 0.558387    0.879999    3.424305    0.317266    0.083934    0.007659    0.770602    
#> 314: 0.557821    0.880155    3.424138    0.316876    0.083958    0.007652    0.770672    
#> 315: 0.557260    0.880413    3.423983    0.316464    0.083937    0.007636    0.770813    
#> 316: 0.557101    0.880483    3.423952    0.315700    0.084057    0.007622    0.770851    
#> 317: 0.556978    0.880609    3.423963    0.315030    0.084142    0.007611    0.770874    
#> 318: 0.556795    0.880560    3.423857    0.315050    0.084254    0.007593    0.770846    
#> 319: 0.556755    0.880397    3.423856    0.315274    0.084291    0.007580    0.770768    
#> 320: 0.556375    0.880312    3.423783    0.315091    0.084329    0.007564    0.770838    
#> 321: 0.555984    0.880404    3.423618    0.315124    0.084239    0.007545    0.771011    
#> 322: 0.555613    0.880531    3.423489    0.314733    0.084278    0.007538    0.771021    
#> 323: 0.555003    0.880763    3.423366    0.314587    0.084241    0.007541    0.771133    
#> 324: 0.554748    0.881010    3.423331    0.314485    0.084211    0.007538    0.771166    
#> 325: 0.554677    0.881261    3.423247    0.314062    0.084158    0.007524    0.771205    
#> 326: 0.554457    0.881115    3.423140    0.313321    0.084087    0.007510    0.771362    
#> 327: 0.554514    0.881155    3.423158    0.312941    0.083993    0.007502    0.771597    
#> 328: 0.554419    0.881262    3.423056    0.312265    0.083984    0.007491    0.771730    
#> 329: 0.554302    0.881349    3.423016    0.311829    0.083932    0.007459    0.771867    
#> 330: 0.554016    0.881464    3.422958    0.311112    0.084041    0.007433    0.771993    
#> 331: 0.554080    0.881745    3.422885    0.310916    0.084124    0.007420    0.772059    
#> 332: 0.554004    0.881711    3.422819    0.310779    0.084151    0.007405    0.772099    
#> 333: 0.553498    0.881708    3.422720    0.310370    0.084078    0.007396    0.772230    
#> 334: 0.553276    0.881655    3.422570    0.310336    0.084115    0.007394    0.772263    
#> 335: 0.552759    0.881675    3.422410    0.310346    0.084122    0.007386    0.772207    
#> 336: 0.552319    0.881802    3.422260    0.310290    0.084107    0.007384    0.772215    
#> 337: 0.552246    0.882103    3.422142    0.310489    0.084242    0.007374    0.772213    
#> 338: 0.552104    0.882165    3.422135    0.310096    0.084420    0.007345    0.772278    
#> 339: 0.552022    0.882178    3.422133    0.309804    0.084562    0.007327    0.772255    
#> 340: 0.551965    0.881939    3.422132    0.309337    0.084668    0.007308    0.772237    
#> 341: 0.552073    0.881900    3.422185    0.308777    0.084765    0.007300    0.772312    
#> 342: 0.551898    0.881704    3.422167    0.308360    0.084787    0.007286    0.772395    
#> 343: 0.551739    0.881739    3.422205    0.308019    0.084783    0.007289    0.772335    
#> 344: 0.551617    0.881765    3.422254    0.307431    0.084668    0.007288    0.772361    
#> 345: 0.551583    0.881802    3.422275    0.307139    0.084718    0.007285    0.772348    
#> 346: 0.551270    0.882000    3.422180    0.306823    0.084629    0.007283    0.772238    
#> 347: 0.551302    0.881985    3.422078    0.307320    0.084654    0.007287    0.772292    
#> 348: 0.551078    0.882147    3.421993    0.307117    0.084693    0.007275    0.772438    
#> 349: 0.550973    0.882077    3.421948    0.307094    0.084645    0.007272    0.772485    
#> 350: 0.550677    0.882027    3.421883    0.307143    0.084695    0.007260    0.772515    
#> 351: 0.550601    0.882258    3.421767    0.307176    0.084810    0.007243    0.772632    
#> 352: 0.550290    0.882371    3.421715    0.307207    0.084866    0.007219    0.772815    
#> 353: 0.550289    0.882634    3.421679    0.306874    0.085009    0.007206    0.772860    
#> 354: 0.550282    0.882776    3.421581    0.306648    0.085075    0.007192    0.772785    
#> 355: 0.550365    0.882743    3.421520    0.306317    0.085112    0.007176    0.772851    
#> 356: 0.550294    0.882649    3.421513    0.306341    0.085162    0.007155    0.772972    
#> 357: 0.550483    0.882709    3.421554    0.306504    0.085164    0.007147    0.772939    
#> 358: 0.550568    0.882719    3.421612    0.306738    0.084993    0.007145    0.772853    
#> 359: 0.550460    0.882893    3.421595    0.306919    0.084902    0.007151    0.772816    
#> 360: 0.550318    0.882970    3.421490    0.307269    0.084844    0.007161    0.772612    
#> 361: 0.550048    0.883005    3.421422    0.307070    0.084852    0.007163    0.772583    
#> 362: 0.550017    0.883031    3.421414    0.306747    0.084896    0.007162    0.772563    
#> 363: 0.550020    0.883007    3.421414    0.306444    0.084846    0.007155    0.772582    
#> 364: 0.550217    0.883059    3.421442    0.306437    0.084795    0.007150    0.772673    
#> 365: 0.550271    0.883045    3.421475    0.306341    0.084791    0.007156    0.772686    
#> 366: 0.550313    0.883107    3.421454    0.306451    0.084864    0.007164    0.772602    
#> 367: 0.550459    0.883068    3.421416    0.306615    0.084903    0.007160    0.772633    
#> 368: 0.550445    0.883244    3.421344    0.306553    0.084840    0.007156    0.772566    
#> 369: 0.550162    0.883391    3.421250    0.306277    0.084761    0.007158    0.772692    
#> 370: 0.549892    0.883582    3.421167    0.306045    0.084715    0.007166    0.772693    
#> 371: 0.549759    0.883640    3.421054    0.306136    0.084618    0.007163    0.772631    
#> 372: 0.549642    0.883731    3.421001    0.306567    0.084567    0.007165    0.772586    
#> 373: 0.549652    0.883958    3.420944    0.306887    0.084516    0.007165    0.772530    
#> 374: 0.549778    0.884071    3.420923    0.307054    0.084473    0.007157    0.772409    
#> 375: 0.549660    0.884054    3.420872    0.306962    0.084343    0.007145    0.772352    
#> 376: 0.549706    0.884098    3.420857    0.307077    0.084373    0.007140    0.772229    
#> 377: 0.549722    0.884105    3.420896    0.307101    0.084411    0.007128    0.772204    
#> 378: 0.549750    0.883982    3.420919    0.307000    0.084446    0.007123    0.772269    
#> 379: 0.549705    0.883798    3.420977    0.306686    0.084418    0.007120    0.772292    
#> 380: 0.549597    0.883811    3.420953    0.306482    0.084531    0.007117    0.772259    
#> 381: 0.549381    0.883820    3.420939    0.306348    0.084657    0.007112    0.772219    
#> 382: 0.549249    0.883875    3.420901    0.306439    0.084764    0.007104    0.772115    
#> 383: 0.549152    0.883844    3.420904    0.306258    0.084875    0.007104    0.772078    
#> 384: 0.549061    0.883786    3.420940    0.306033    0.084927    0.007102    0.772036    
#> 385: 0.549179    0.883772    3.420967    0.305962    0.085023    0.007097    0.772003    
#> 386: 0.549439    0.883852    3.420991    0.306158    0.085102    0.007091    0.772046    
#> 387: 0.549671    0.883918    3.421064    0.306104    0.085156    0.007092    0.772083    
#> 388: 0.549755    0.883882    3.421094    0.305817    0.085184    0.007081    0.772100    
#> 389: 0.549737    0.883697    3.421123    0.305774    0.085172    0.007069    0.772243    
#> 390: 0.549524    0.883706    3.421111    0.305612    0.085265    0.007057    0.772319    
#> 391: 0.549454    0.883669    3.421053    0.305406    0.085336    0.007047    0.772257    
#> 392: 0.549463    0.883725    3.421062    0.305533    0.085304    0.007034    0.772253    
#> 393: 0.549467    0.883730    3.421043    0.305362    0.085280    0.007022    0.772223    
#> 394: 0.549347    0.883874    3.420981    0.305096    0.085264    0.007013    0.772179    
#> 395: 0.549473    0.884081    3.420940    0.304890    0.085325    0.007005    0.772201    
#> 396: 0.549581    0.884213    3.420918    0.304765    0.085315    0.006996    0.772176    
#> 397: 0.549462    0.884222    3.420911    0.304634    0.085307    0.006988    0.772165    
#> 398: 0.549668    0.884223    3.420952    0.304696    0.085334    0.006982    0.772167    
#> 399: 0.549737    0.884269    3.421014    0.304602    0.085382    0.006980    0.772169    
#> 400: 0.549691    0.884266    3.421038    0.304383    0.085466    0.006968    0.772252    
#> 401: 0.549860    0.884345    3.421054    0.304366    0.085440    0.006965    0.772341    
#> 402: 0.549929    0.884422    3.421055    0.304232    0.085554    0.006960    0.772327    
#> 403: 0.550059    0.884424    3.421022    0.304001    0.085634    0.006958    0.772323    
#> 404: 0.549958    0.884526    3.420962    0.303768    0.085746    0.006945    0.772275    
#> 405: 0.549850    0.884607    3.420952    0.303787    0.085741    0.006940    0.772275    
#> 406: 0.549890    0.884596    3.420953    0.304000    0.085766    0.006936    0.772360    
#> 407: 0.549900    0.884767    3.420932    0.304220    0.085820    0.006929    0.772414    
#> 408: 0.549935    0.884848    3.420904    0.304214    0.085873    0.006919    0.772507    
#> 409: 0.549854    0.884776    3.420828    0.303960    0.085886    0.006903    0.772546    
#> 410: 0.549791    0.884814    3.420741    0.303684    0.085923    0.006898    0.772535    
#> 411: 0.549868    0.884671    3.420701    0.303678    0.085911    0.006893    0.772607    
#> 412: 0.549765    0.884762    3.420667    0.303642    0.085896    0.006892    0.772660    
#> 413: 0.549772    0.884892    3.420604    0.303548    0.085860    0.006887    0.772713    
#> 414: 0.549542    0.884948    3.420568    0.303560    0.085898    0.006885    0.772629    
#> 415: 0.549643    0.884959    3.420547    0.303405    0.085936    0.006879    0.772592    
#> 416: 0.549748    0.885031    3.420546    0.303352    0.085973    0.006875    0.772576    
#> 417: 0.549720    0.885047    3.420526    0.303426    0.085960    0.006868    0.772526    
#> 418: 0.549417    0.885085    3.420463    0.303273    0.085928    0.006864    0.772553    
#> 419: 0.549300    0.885250    3.420432    0.303524    0.085892    0.006860    0.772479    
#> 420: 0.549299    0.885280    3.420450    0.303400    0.085877    0.006855    0.772405    
#> 421: 0.549296    0.885282    3.420523    0.303419    0.085885    0.006855    0.772353    
#> 422: 0.549532    0.885177    3.420565    0.303334    0.085853    0.006859    0.772308    
#> 423: 0.549792    0.885069    3.420608    0.303242    0.085920    0.006860    0.772326    
#> 424: 0.549780    0.885040    3.420572    0.303214    0.085908    0.006861    0.772325    
#> 425: 0.549821    0.885067    3.420580    0.303198    0.085844    0.006858    0.772382    
#> 426: 0.549929    0.885178    3.420621    0.303170    0.085776    0.006859    0.772457    
#> 427: 0.549833    0.885134    3.420645    0.302990    0.085774    0.006856    0.772480    
#> 428: 0.549757    0.885098    3.420645    0.302842    0.085834    0.006853    0.772589    
#> 429: 0.549823    0.885115    3.420692    0.302645    0.085828    0.006848    0.772599    
#> 430: 0.549866    0.885104    3.420714    0.302352    0.085837    0.006843    0.772654    
#> 431: 0.549866    0.885002    3.420729    0.301982    0.085897    0.006841    0.772701    
#> 432: 0.549754    0.885048    3.420719    0.301641    0.085906    0.006841    0.772678    
#> 433: 0.549695    0.885141    3.420750    0.301455    0.085935    0.006845    0.772655    
#> 434: 0.549560    0.885083    3.420756    0.301270    0.085931    0.006845    0.772561    
#> 435: 0.549614    0.885104    3.420743    0.301137    0.085922    0.006850    0.772525    
#> 436: 0.549576    0.885089    3.420748    0.300998    0.085896    0.006858    0.772521    
#> 437: 0.549457    0.885027    3.420704    0.300973    0.085929    0.006853    0.772503    
#> 438: 0.549314    0.885165    3.420697    0.300896    0.086012    0.006847    0.772458    
#> 439: 0.549412    0.885227    3.420709    0.300866    0.086028    0.006841    0.772414    
#> 440: 0.549345    0.885303    3.420692    0.300870    0.086046    0.006835    0.772399    
#> 441: 0.549369    0.885257    3.420681    0.300941    0.086017    0.006835    0.772317    
#> 442: 0.549166    0.885377    3.420672    0.300735    0.086019    0.006831    0.772260    
#> 443: 0.549083    0.885510    3.420631    0.300530    0.085991    0.006835    0.772263    
#> 444: 0.548949    0.885692    3.420562    0.300622    0.085939    0.006843    0.772286    
#> 445: 0.548866    0.885840    3.420475    0.300724    0.085967    0.006844    0.772348    
#> 446: 0.548641    0.885956    3.420392    0.300742    0.085900    0.006842    0.772363    
#> 447: 0.548717    0.885988    3.420386    0.300795    0.085855    0.006839    0.772403    
#> 448: 0.548739    0.886030    3.420397    0.300819    0.085861    0.006843    0.772328    
#> 449: 0.548859    0.886113    3.420492    0.300736    0.085834    0.006845    0.772333    
#> 450: 0.548944    0.886106    3.420537    0.300714    0.085887    0.006848    0.772356    
#> 451: 0.549189    0.886064    3.420547    0.300771    0.085916    0.006849    0.772430    
#> 452: 0.549272    0.886052    3.420531    0.300917    0.085990    0.006849    0.772420    
#> 453: 0.549295    0.886020    3.420480    0.301064    0.086020    0.006844    0.772354    
#> 454: 0.549223    0.886150    3.420408    0.301092    0.085968    0.006835    0.772307    
#> 455: 0.549153    0.886210    3.420364    0.300960    0.086021    0.006825    0.772366    
#> 456: 0.548936    0.886195    3.420342    0.300823    0.086076    0.006820    0.772387    
#> 457: 0.548892    0.886226    3.420350    0.300724    0.086140    0.006810    0.772303    
#> 458: 0.548816    0.886323    3.420389    0.300569    0.086152    0.006808    0.772310    
#> 459: 0.548709    0.886440    3.420395    0.300556    0.086179    0.006813    0.772314    
#> 460: 0.548710    0.886513    3.420371    0.300656    0.086162    0.006821    0.772264    
#> 461: 0.548688    0.886568    3.420417    0.300547    0.086106    0.006829    0.772302    
#> 462: 0.548663    0.886600    3.420465    0.300638    0.086022    0.006831    0.772274    
#> 463: 0.548702    0.886637    3.420505    0.300544    0.085981    0.006834    0.772254    
#> 464: 0.548795    0.886679    3.420520    0.300673    0.085935    0.006833    0.772162    
#> 465: 0.548777    0.886518    3.420531    0.300700    0.085904    0.006832    0.772150    
#> 466: 0.548763    0.886588    3.420525    0.300686    0.085905    0.006832    0.772073    
#> 467: 0.548726    0.886560    3.420531    0.300657    0.085899    0.006831    0.771992    
#> 468: 0.548690    0.886587    3.420515    0.300587    0.085896    0.006837    0.772084    
#> 469: 0.548677    0.886724    3.420513    0.300323    0.085941    0.006835    0.772186    
#> 470: 0.548548    0.886825    3.420478    0.300432    0.085930    0.006844    0.772269    
#> 471: 0.548479    0.886816    3.420465    0.300381    0.085900    0.006851    0.772251    
#> 472: 0.548484    0.886825    3.420472    0.300599    0.085862    0.006849    0.772266    
#> 473: 0.548382    0.886853    3.420476    0.300746    0.085857    0.006852    0.772226    
#> 474: 0.548284    0.886897    3.420453    0.300735    0.085830    0.006865    0.772194    
#> 475: 0.548286    0.886974    3.420451    0.300872    0.085819    0.006874    0.772149    
#> 476: 0.548231    0.887009    3.420432    0.300895    0.085768    0.006876    0.772175    
#> 477: 0.548195    0.886965    3.420438    0.300808    0.085687    0.006878    0.772093    
#> 478: 0.548125    0.886894    3.420439    0.300811    0.085650    0.006878    0.772091    
#> 479: 0.548246    0.886959    3.420458    0.300970    0.085584    0.006879    0.772079    
#> 480: 0.548327    0.886862    3.420511    0.301078    0.085629    0.006876    0.772086    
#> 481: 0.548440    0.886813    3.420530    0.301276    0.085709    0.006873    0.772030    
#> 482: 0.548535    0.886798    3.420535    0.301479    0.085730    0.006873    0.771977    
#> 483: 0.548471    0.886767    3.420554    0.301505    0.085684    0.006878    0.771955    
#> 484: 0.548487    0.886600    3.420591    0.301642    0.085688    0.006885    0.771988    
#> 485: 0.548533    0.886557    3.420608    0.301590    0.085742    0.006883    0.772054    
#> 486: 0.548536    0.886577    3.420608    0.301667    0.085724    0.006884    0.772010    
#> 487: 0.548751    0.886586    3.420656    0.301803    0.085734    0.006887    0.771927    
#> 488: 0.548796    0.886614    3.420690    0.301712    0.085680    0.006890    0.771881    
#> 489: 0.548887    0.886557    3.420703    0.301900    0.085664    0.006890    0.771811    
#> 490: 0.548907    0.886572    3.420726    0.301881    0.085622    0.006890    0.771780    
#> 491: 0.548934    0.886629    3.420762    0.301896    0.085563    0.006894    0.771690    
#> 492: 0.549007    0.886691    3.420777    0.302087    0.085551    0.006896    0.771754    
#> 493: 0.548972    0.886704    3.420768    0.302041    0.085514    0.006908    0.771771    
#> 494: 0.549028    0.886762    3.420735    0.301933    0.085480    0.006913    0.771705    
#> 495: 0.549124    0.886811    3.420761    0.301919    0.085482    0.006912    0.771592    
#> 496: 0.549242    0.886845    3.420754    0.302086    0.085472    0.006914    0.771601    
#> 497: 0.549258    0.886901    3.420745    0.302299    0.085541    0.006908    0.771555    
#> 498: 0.549330    0.886875    3.420725    0.302527    0.085550    0.006901    0.771523    
#> 499: 0.549303    0.886812    3.420719    0.302502    0.085550    0.006896    0.771507    
#> 500: 0.549325    0.886689    3.420730    0.302550    0.085514    0.006894    0.771461    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.323158    0.973261    3.439530    0.392401    0.081461    0.016800    1.805238    
#> 002: 0.416640    0.985065    3.457066    0.372781    0.077388    0.015960    1.199425    
#> 003: 0.536212    0.969002    3.458022    0.354142    0.073518    0.015162    0.901408    
#> 004: 0.535946    0.969982    3.460345    0.444608    0.069842    0.014404    0.810329    
#> 005: 0.588515    1.007133    3.441069    0.590204    0.066350    0.013684    0.746595    
#> 006: 0.570766    1.013636    3.438242    0.578860    0.063033    0.013000    0.693823    
#> 007: 0.484014    1.017193    3.422945    0.549917    0.059881    0.015128    0.689839    
#> 008: 0.547932    1.011995    3.419224    0.651260    0.056887    0.017858    0.672689    
#> 009: 0.527090    1.008582    3.413311    0.653693    0.054043    0.017649    0.681010    
#> 010: 0.500815    1.006149    3.411797    0.621008    0.051340    0.023593    0.686488    
#> 011: 0.550762    1.014210    3.417869    0.664236    0.059810    0.022413    0.674977    
#> 012: 0.552763    1.005831    3.423809    0.646337    0.057895    0.021293    0.676058    
#> 013: 0.509932    1.018404    3.421523    0.625235    0.058372    0.023914    0.678341    
#> 014: 0.580865    0.990608    3.444678    0.647205    0.055454    0.022719    0.678405    
#> 015: 0.610977    1.007980    3.442181    0.735168    0.052681    0.021583    0.677955    
#> 016: 0.602829    1.017132    3.441508    0.718970    0.053289    0.022432    0.676507    
#> 017: 0.579670    1.023393    3.438939    0.683022    0.051504    0.022984    0.659902    
#> 018: 0.582765    1.016305    3.428441    0.723565    0.066295    0.022927    0.649791    
#> 019: 0.571789    1.002198    3.433344    0.687386    0.062980    0.021780    0.654380    
#> 020: 0.609394    0.999553    3.451269    0.653017    0.059831    0.024291    0.669198    
#> 021: 0.609259    0.992888    3.446057    0.633494    0.056840    0.023077    0.651429    
#> 022: 0.627058    1.002683    3.460807    0.642018    0.053998    0.021923    0.663237    
#> 023: 0.681117    0.988270    3.470321    0.632835    0.051298    0.021305    0.706184    
#> 024: 0.649700    1.011626    3.453241    0.650603    0.048733    0.020240    0.695148    
#> 025: 0.566722    0.994536    3.446921    0.618073    0.046296    0.021057    0.687705    
#> 026: 0.550827    1.047634    3.419750    0.587169    0.044613    0.020004    0.684730    
#> 027: 0.540076    1.050354    3.424798    0.557810    0.046582    0.020059    0.703239    
#> 028: 0.574029    1.023340    3.432045    0.635503    0.046472    0.019056    0.676784    
#> 029: 0.602490    1.003142    3.432159    0.679249    0.051846    0.018665    0.671977    
#> 030: 0.573135    1.019093    3.427168    0.645286    0.049254    0.018990    0.661101    
#> 031: 0.569325    1.005334    3.433042    0.656491    0.046791    0.018041    0.644852    
#> 032: 0.559195    1.001943    3.436905    0.703856    0.048301    0.017161    0.644646    
#> 033: 0.550247    1.023144    3.432279    0.677688    0.054278    0.016303    0.651840    
#> 034: 0.581522    1.031379    3.435190    0.643803    0.051564    0.017489    0.653369    
#> 035: 0.566520    1.005690    3.432913    0.611613    0.048986    0.016614    0.650664    
#> 036: 0.580497    1.018628    3.437054    0.581904    0.055330    0.015784    0.666310    
#> 037: 0.556711    1.033086    3.430915    0.590598    0.052563    0.015545    0.681611    
#> 038: 0.575360    1.022652    3.430102    0.582135    0.052498    0.019596    0.681856    
#> 039: 0.575802    1.011727    3.434624    0.621564    0.053199    0.021814    0.671551    
#> 040: 0.557643    1.021952    3.443919    0.590486    0.050539    0.020723    0.684919    
#> 041: 0.559318    1.009978    3.436522    0.560962    0.049174    0.019687    0.682696    
#> 042: 0.582453    1.010178    3.439106    0.532914    0.046715    0.020612    0.653077    
#> 043: 0.535871    1.016643    3.427453    0.516695    0.044379    0.019582    0.656792    
#> 044: 0.593318    1.029438    3.430770    0.608099    0.045040    0.019568    0.653472    
#> 045: 0.565000    1.040554    3.415615    0.601257    0.050896    0.020378    0.647546    
#> 046: 0.579549    1.015649    3.438583    0.610315    0.048351    0.019359    0.648462    
#> 047: 0.628080    1.028025    3.429563    0.837625    0.047075    0.018391    0.653657    
#> 048: 0.653592    1.009278    3.430381    0.947326    0.045860    0.023356    0.650302    
#> 049: 0.621105    1.013236    3.434109    0.899959    0.046218    0.022189    0.649624    
#> 050: 0.603696    1.000516    3.448051    0.854961    0.046533    0.024214    0.658143    
#> 051: 0.595880    1.009386    3.435155    0.812213    0.048577    0.023003    0.666994    
#> 052: 0.592871    1.007535    3.448356    0.771603    0.060647    0.021853    0.666664    
#> 053: 0.606379    0.996736    3.446488    0.733023    0.057615    0.020761    0.657172    
#> 054: 0.557323    1.022787    3.433788    0.696371    0.062110    0.019723    0.671374    
#> 055: 0.549758    1.031846    3.422732    0.725610    0.059219    0.018736    0.683344    
#> 056: 0.581072    1.011888    3.423329    0.774166    0.069566    0.017800    0.684671    
#> 057: 0.596121    1.011444    3.441824    0.764285    0.066087    0.017812    0.683733    
#> 058: 0.610584    1.009027    3.438136    0.726071    0.062783    0.020717    0.690737    
#> 059: 0.562195    0.978007    3.446529    0.689767    0.069386    0.019681    0.695412    
#> 060: 0.604837    0.956517    3.463945    0.655279    0.065917    0.022506    0.718275    
#> 061: 0.631094    0.961361    3.475596    0.622515    0.062621    0.025483    0.714737    
#> 062: 0.646434    0.985816    3.478511    0.591389    0.068210    0.026808    0.715932    
#> 063: 0.663787    0.956405    3.476930    0.561820    0.064800    0.032447    0.712743    
#> 064: 0.664285    0.977716    3.476053    0.607008    0.061560    0.030825    0.697562    
#> 065: 0.667209    0.970393    3.469334    0.611131    0.058482    0.029284    0.668422    
#> 066: 0.666386    0.991779    3.461122    0.633537    0.055558    0.027820    0.664162    
#> 067: 0.625201    0.990185    3.443199    0.715052    0.052780    0.026429    0.658282    
#> 068: 0.584713    1.001037    3.448736    0.701644    0.050141    0.025107    0.680977    
#> 069: 0.554639    1.012644    3.414858    0.666562    0.047634    0.023852    0.692813    
#> 070: 0.533204    1.019299    3.431750    0.633234    0.048433    0.022659    0.685171    
#> 071: 0.536629    1.041990    3.412056    0.655814    0.049268    0.021526    0.697851    
#> 072: 0.512377    1.023545    3.417115    0.623023    0.050592    0.020738    0.675194    
#> 073: 0.563522    1.033656    3.452906    0.591872    0.048328    0.024056    0.669595    
#> 074: 0.576549    1.018522    3.447391    0.592807    0.045912    0.026100    0.662109    
#> 075: 0.622853    0.996630    3.468651    0.688575    0.048459    0.024795    0.669035    
#> 076: 0.647734    1.001276    3.465752    0.741693    0.046036    0.025077    0.669423    
#> 077: 0.662183    0.999890    3.452089    0.789311    0.043734    0.023823    0.666371    
#> 078: 0.637310    0.992243    3.456016    0.749846    0.046452    0.022632    0.663978    
#> 079: 0.572131    1.012153    3.442525    0.712353    0.049325    0.021501    0.673487    
#> 080: 0.575003    1.009373    3.443697    0.676736    0.055908    0.024271    0.671838    
#> 081: 0.592648    1.018141    3.443428    0.642899    0.053112    0.023058    0.666886    
#> 082: 0.577442    1.008032    3.448307    0.639195    0.050457    0.021905    0.672759    
#> 083: 0.701315    1.003161    3.448000    0.971784    0.047934    0.025328    0.664602    
#> 084: 0.636405    1.000241    3.445310    0.923195    0.055873    0.024062    0.653650    
#> 085: 0.682851    0.985167    3.470462    0.903232    0.053079    0.022859    0.675828    
#> 086: 0.707761    0.993460    3.462373    0.985984    0.050425    0.026232    0.660146    
#> 087: 0.698654    0.999387    3.445188    0.999722    0.047904    0.024920    0.665213    
#> 088: 0.620157    0.988205    3.443410    0.949736    0.045509    0.023674    0.661353    
#> 089: 0.612150    0.995454    3.438858    0.902249    0.043233    0.022490    0.641686    
#> 090: 0.575554    0.995459    3.432436    0.857136    0.049740    0.021366    0.653058    
#> 091: 0.594525    0.995161    3.425708    0.814280    0.047253    0.020341    0.670066    
#> 092: 0.588556    0.998963    3.434932    0.773566    0.044890    0.020769    0.667376    
#> 093: 0.593880    0.997159    3.431588    0.734887    0.046115    0.019791    0.675036    
#> 094: 0.595515    1.025014    3.431335    0.754078    0.044102    0.018801    0.678353    
#> 095: 0.579359    1.016237    3.437559    0.716374    0.053514    0.017861    0.677066    
#> 096: 0.569838    1.002377    3.435115    0.680555    0.050838    0.016968    0.665359    
#> 097: 0.625757    1.018868    3.438243    0.646528    0.048296    0.016168    0.679491    
#> 098: 0.627920    1.024077    3.437038    0.686711    0.045881    0.015360    0.662146    
#> 099: 0.537598    1.009307    3.422445    0.652375    0.045469    0.019007    0.676899    
#> 100: 0.536567    1.007011    3.424954    0.619756    0.046211    0.021986    0.672630    
#> 101: 0.498967    1.004659    3.416510    0.620251    0.050575    0.023087    0.676343    
#> 102: 0.543794    1.008138    3.409359    0.613634    0.050943    0.021932    0.673190    
#> 103: 0.583823    1.012650    3.433712    0.772511    0.048396    0.020944    0.658004    
#> 104: 0.609990    1.009935    3.450181    0.733886    0.047347    0.020562    0.686944    
#> 105: 0.649301    0.992739    3.454050    0.749522    0.058536    0.020832    0.674619    
#> 106: 0.628966    1.002472    3.433819    0.741604    0.062019    0.019790    0.677959    
#> 107: 0.607764    1.008783    3.439690    0.704524    0.058918    0.023360    0.666152    
#> 108: 0.586741    1.005525    3.445451    0.669297    0.055972    0.022192    0.701084    
#> 109: 0.609186    0.999128    3.457101    0.650512    0.053174    0.021783    0.693727    
#> 110: 0.604353    0.990560    3.441541    0.632593    0.050515    0.020693    0.689972    
#> 111: 0.638703    1.000106    3.446258    0.600963    0.048381    0.019659    0.683341    
#> 112: 0.573771    0.981274    3.434181    0.570915    0.047266    0.018676    0.690445    
#> 113: 0.601246    1.011816    3.446342    0.743157    0.051723    0.017742    0.657091    
#> 114: 0.663156    1.006384    3.451759    0.706000    0.052714    0.017561    0.664576    
#> 115: 0.644473    0.974608    3.442062    0.670700    0.060171    0.017090    0.681170    
#> 116: 0.622758    1.006828    3.448759    0.640763    0.057162    0.020807    0.680840    
#> 117: 0.588909    1.006625    3.441833    0.736876    0.054799    0.021717    0.670401    
#> 118: 0.652277    1.010461    3.444488    0.838924    0.052059    0.020944    0.654866    
#> 119: 0.616413    1.005817    3.442159    0.796978    0.054490    0.026621    0.673190    
#> 120: 0.564119    1.007904    3.439480    0.757129    0.051765    0.025290    0.670043    
#> 121: 0.608506    1.026466    3.446313    0.719273    0.049177    0.027180    0.664909    
#> 122: 0.630791    1.002495    3.454272    0.817274    0.048686    0.028313    0.674835    
#> 123: 0.709729    1.021814    3.450722    0.975291    0.046252    0.028028    0.674197    
#> 124: 0.662751    1.030422    3.450373    0.926527    0.043939    0.027000    0.672404    
#> 125: 0.643275    1.036569    3.443903    0.880200    0.041742    0.025650    0.663469    
#> 126: 0.578498    1.048593    3.425116    0.836190    0.039655    0.025498    0.668305    
#> 127: 0.590415    1.029692    3.432224    0.794381    0.037672    0.024223    0.670906    
#> 128: 0.596666    1.024793    3.437907    0.754662    0.041453    0.023598    0.668673    
#> 129: 0.577578    1.025313    3.448450    0.716929    0.055586    0.022418    0.663288    
#> 130: 0.637878    1.028430    3.451568    0.681082    0.052807    0.021297    0.652260    
#> 131: 0.627218    0.997413    3.450886    0.647028    0.053991    0.020233    0.661627    
#> 132: 0.590551    0.999408    3.438951    0.614677    0.065190    0.019221    0.660316    
#> 133: 0.538793    1.004890    3.436494    0.583943    0.074282    0.018260    0.683466    
#> 134: 0.576161    1.004620    3.438666    0.641151    0.070568    0.017347    0.674434    
#> 135: 0.628408    0.990785    3.452679    0.628053    0.067040    0.016480    0.673937    
#> 136: 0.584851    0.977729    3.453624    0.596650    0.063688    0.016121    0.670945    
#> 137: 0.606972    0.981396    3.450298    0.566818    0.060503    0.015315    0.688315    
#> 138: 0.550635    1.010489    3.439040    0.538477    0.057478    0.014549    0.674458    
#> 139: 0.562445    1.018707    3.439832    0.612179    0.056742    0.016266    0.674016    
#> 140: 0.555969    1.033091    3.441494    0.659577    0.061687    0.018166    0.701670    
#> 141: 0.548136    1.002619    3.436910    0.626598    0.077848    0.017257    0.681063    
#> 142: 0.578452    0.986343    3.453653    0.595268    0.078623    0.017809    0.688216    
#> 143: 0.531322    1.006984    3.446029    0.565505    0.074692    0.020681    0.690506    
#> 144: 0.633270    1.009798    3.448831    0.656412    0.070957    0.019647    0.670727    
#> 145: 0.607143    1.008107    3.438485    0.699647    0.067409    0.020585    0.675850    
#> 146: 0.608956    1.008751    3.447577    0.664664    0.064039    0.019556    0.688913    
#> 147: 0.586706    1.008627    3.432759    0.631431    0.060837    0.020020    0.673612    
#> 148: 0.570355    1.008381    3.444163    0.661481    0.057795    0.019825    0.668836    
#> 149: 0.573228    1.008763    3.438253    0.654062    0.054905    0.018834    0.666982    
#> 150: 0.589964    1.015135    3.419653    0.697030    0.062098    0.017892    0.682463    
#> 151: 0.527321    1.023171    3.414626    0.694856    0.058993    0.018956    0.672248    
#> 152: 0.504503    1.025629    3.422433    0.637898    0.053171    0.023246    0.670920    
#> 153: 0.532458    1.027571    3.433991    0.596936    0.059578    0.022990    0.694313    
#> 154: 0.573800    1.031258    3.436194    0.642297    0.048536    0.026173    0.689483    
#> 155: 0.541148    1.006771    3.436015    0.620449    0.055353    0.020998    0.665891    
#> 156: 0.568819    1.016435    3.441132    0.658561    0.066895    0.019897    0.667577    
#> 157: 0.584169    1.004594    3.439107    0.625488    0.061310    0.020374    0.658360    
#> 158: 0.578432    1.039687    3.434913    0.582265    0.063638    0.020358    0.662278    
#> 159: 0.535390    1.035139    3.444067    0.542981    0.055237    0.016810    0.673497    
#> 160: 0.577174    0.996002    3.454907    0.538155    0.061916    0.014371    0.689532    
#> 161: 0.601949    1.020464    3.455104    0.532034    0.056688    0.014906    0.673346    
#> 162: 0.599658    1.020348    3.454371    0.533088    0.057218    0.016123    0.686935    
#> 163: 0.588209    1.007355    3.444857    0.511984    0.068569    0.016460    0.682277    
#> 164: 0.583673    1.003232    3.447201    0.536940    0.054599    0.020720    0.662255    
#> 165: 0.613665    0.990899    3.447932    0.579275    0.052501    0.021917    0.660502    
#> 166: 0.634363    1.025574    3.449551    0.586999    0.050984    0.019074    0.681696    
#> 167: 0.612095    1.029709    3.459471    0.510991    0.053869    0.018368    0.694914    
#> 168: 0.618837    1.031938    3.456505    0.516630    0.048424    0.017778    0.694876    
#> 169: 0.595280    1.027005    3.458063    0.528209    0.056123    0.015560    0.701728    
#> 170: 0.622925    0.990442    3.464222    0.537308    0.054773    0.015948    0.684225    
#> 171: 0.604035    0.989117    3.453825    0.603270    0.053935    0.018532    0.674375    
#> 172: 0.625457    1.008605    3.451721    0.721481    0.040401    0.017658    0.667605    
#> 173: 0.605190    1.021622    3.442705    0.585666    0.048934    0.017501    0.655348    
#> 174: 0.600080    1.005688    3.455780    0.592382    0.042018    0.017692    0.660513    
#> 175: 0.574604    1.016874    3.437240    0.582734    0.051950    0.020877    0.638834    
#> 176: 0.579958    1.012629    3.449201    0.586059    0.042706    0.024409    0.638281    
#> 177: 0.608793    1.019802    3.452482    0.586662    0.045663    0.030962    0.656504    
#> 178: 0.646050    1.002528    3.451208    0.651008    0.050644    0.025335    0.663691    
#> 179: 0.665486    1.024170    3.451105    0.613048    0.057936    0.021587    0.684050    
#> 180: 0.613480    1.000617    3.450980    0.667088    0.051380    0.025031    0.660869    
#> 181: 0.618922    0.992597    3.429950    0.645719    0.038656    0.024855    0.675852    
#> 182: 0.592014    1.001351    3.428523    0.647353    0.044119    0.030670    0.686423    
#> 183: 0.571569    1.009999    3.430526    0.554680    0.039265    0.026747    0.687254    
#> 184: 0.557653    1.000593    3.423952    0.668548    0.032510    0.026476    0.674033    
#> 185: 0.564489    0.992775    3.439549    0.615648    0.042817    0.026741    0.680109    
#> 186: 0.548748    1.020513    3.434055    0.622076    0.041712    0.029201    0.662080    
#> 187: 0.552812    1.005692    3.437547    0.543176    0.037172    0.030373    0.658592    
#> 188: 0.559215    1.014833    3.430312    0.572440    0.035288    0.027666    0.675445    
#> 189: 0.565149    1.010189    3.444329    0.644083    0.034506    0.025745    0.668068    
#> 190: 0.593121    1.017501    3.447387    0.580743    0.037601    0.025461    0.652742    
#> 191: 0.616083    1.018789    3.446521    0.705035    0.042586    0.023579    0.646791    
#> 192: 0.599555    1.004944    3.453130    0.626621    0.045956    0.024194    0.647316    
#> 193: 0.606327    1.010658    3.451606    0.579631    0.047004    0.021214    0.654104    
#> 194: 0.565200    1.009869    3.439989    0.471404    0.051858    0.020581    0.691551    
#> 195: 0.529222    1.011506    3.441317    0.488855    0.047855    0.020725    0.684395    
#> 196: 0.545731    1.011784    3.443971    0.515247    0.051076    0.021562    0.679656    
#> 197: 0.541785    1.003859    3.457803    0.489975    0.043757    0.023055    0.698170    
#> 198: 0.600943    0.993171    3.450201    0.430164    0.043941    0.021811    0.666089    
#> 199: 0.569903    0.995151    3.451076    0.422913    0.047634    0.023547    0.667040    
#> 200: 0.579598    0.985177    3.455225    0.440766    0.052064    0.022887    0.677072    
#> 201: 0.579533    0.984593    3.463552    0.461693    0.049736    0.022654    0.677708    
#> 202: 0.600874    0.983600    3.467185    0.494716    0.047364    0.023211    0.676541    
#> 203: 0.619498    0.983566    3.467001    0.514518    0.044278    0.023905    0.674407    
#> 204: 0.625200    0.979178    3.468152    0.532075    0.040758    0.024433    0.676111    
#> 205: 0.628437    0.983577    3.466985    0.559623    0.038945    0.025516    0.679015    
#> 206: 0.631873    0.988895    3.466133    0.576373    0.038838    0.025608    0.679977    
#> 207: 0.625721    0.992421    3.462617    0.570314    0.038918    0.025348    0.678350    
#> 208: 0.623791    0.995270    3.460482    0.571077    0.039017    0.025406    0.676737    
#> 209: 0.622699    0.995241    3.458552    0.575409    0.039670    0.025254    0.675521    
#> 210: 0.622252    0.995739    3.458127    0.583751    0.038983    0.024945    0.674802    
#> 211: 0.623437    0.996639    3.457817    0.589540    0.038642    0.024945    0.672887    
#> 212: 0.622403    0.996613    3.457577    0.594236    0.038583    0.025128    0.671838    
#> 213: 0.624739    0.994581    3.457092    0.603916    0.038969    0.024853    0.672343    
#> 214: 0.623552    0.993923    3.456760    0.604419    0.038918    0.024776    0.673234    
#> 215: 0.623223    0.993580    3.456938    0.605465    0.038955    0.024789    0.674685    
#> 216: 0.625148    0.991547    3.457355    0.604388    0.039173    0.024913    0.676261    
#> 217: 0.624165    0.991252    3.457698    0.599944    0.038776    0.025040    0.677221    
#> 218: 0.623815    0.991473    3.457360    0.596989    0.038177    0.025218    0.677990    
#> 219: 0.620754    0.991741    3.456575    0.594233    0.037911    0.025414    0.678689    
#> 220: 0.618866    0.991806    3.456104    0.594335    0.037353    0.025359    0.679554    
#> 221: 0.617777    0.992200    3.456233    0.590658    0.037074    0.025221    0.679890    
#> 222: 0.615418    0.991928    3.455923    0.590088    0.037420    0.024926    0.680128    
#> 223: 0.616950    0.992549    3.455894    0.593335    0.037550    0.024714    0.680165    
#> 224: 0.619261    0.992974    3.455999    0.593447    0.037891    0.024504    0.679948    
#> 225: 0.619010    0.992371    3.456417    0.595988    0.038082    0.024433    0.679853    
#> 226: 0.617813    0.991873    3.455913    0.594583    0.038378    0.024288    0.679777    
#> 227: 0.616496    0.991578    3.455551    0.593844    0.038268    0.024239    0.679237    
#> 228: 0.614233    0.992144    3.454560    0.592319    0.038364    0.024060    0.678732    
#> 229: 0.611806    0.992070    3.453636    0.593131    0.038555    0.023960    0.678372    
#> 230: 0.611423    0.991908    3.453286    0.593344    0.038835    0.023891    0.678374    
#> 231: 0.611984    0.992204    3.453560    0.595948    0.039346    0.023782    0.677755    
#> 232: 0.612270    0.992090    3.453681    0.598208    0.039735    0.023673    0.677038    
#> 233: 0.611348    0.991697    3.453502    0.598484    0.039908    0.023569    0.676713    
#> 234: 0.610918    0.991605    3.453376    0.598623    0.040041    0.023480    0.676869    
#> 235: 0.610600    0.991368    3.453117    0.599039    0.040153    0.023382    0.676868    
#> 236: 0.609406    0.991832    3.452518    0.598440    0.040315    0.023266    0.676595    
#> 237: 0.610632    0.992021    3.452470    0.600466    0.040490    0.023346    0.676715    
#> 238: 0.611846    0.992184    3.452626    0.600100    0.040660    0.023346    0.677111    
#> 239: 0.611291    0.992814    3.452169    0.601827    0.040959    0.023371    0.677161    
#> 240: 0.610748    0.992894    3.452122    0.602007    0.041173    0.023327    0.676820    
#> 241: 0.610320    0.992416    3.452117    0.602074    0.041320    0.023252    0.676752    
#> 242: 0.609577    0.992202    3.451708    0.601995    0.041439    0.023187    0.677149    
#> 243: 0.607966    0.992564    3.451382    0.602109    0.041406    0.023152    0.677257    
#> 244: 0.607138    0.992591    3.451116    0.604742    0.041490    0.023105    0.677098    
#> 245: 0.606393    0.992467    3.450930    0.605045    0.041636    0.023169    0.677324    
#> 246: 0.605380    0.992166    3.450758    0.604332    0.041643    0.023250    0.677375    
#> 247: 0.605163    0.991960    3.450674    0.605875    0.041755    0.023264    0.677112    
#> 248: 0.604941    0.992646    3.450377    0.606227    0.041915    0.023285    0.676917    
#> 249: 0.604292    0.992934    3.450262    0.606417    0.042008    0.023339    0.676574    
#> 250: 0.604425    0.993314    3.450223    0.608120    0.042039    0.023369    0.676527    
#> 251: 0.605540    0.993680    3.450332    0.610617    0.042235    0.023395    0.676572    
#> 252: 0.606116    0.993900    3.450684    0.610613    0.042348    0.023402    0.676565    
#> 253: 0.606005    0.994084    3.450768    0.610326    0.042505    0.023470    0.676560    
#> 254: 0.606066    0.994547    3.450989    0.609240    0.042524    0.023485    0.676412    
#> 255: 0.606012    0.994703    3.451032    0.609920    0.042430    0.023533    0.676147    
#> 256: 0.606526    0.994547    3.450964    0.610244    0.042328    0.023507    0.676216    
#> 257: 0.606403    0.994398    3.450972    0.609400    0.042093    0.023510    0.676188    
#> 258: 0.606300    0.994087    3.450942    0.610481    0.042082    0.023471    0.676056    
#> 259: 0.606525    0.994115    3.450877    0.611705    0.042152    0.023451    0.675896    
#> 260: 0.606639    0.994262    3.450989    0.611353    0.042062    0.023505    0.675449    
#> 261: 0.606585    0.994030    3.451013    0.610389    0.042018    0.023552    0.675156    
#> 262: 0.606378    0.994011    3.450890    0.609624    0.042047    0.023596    0.675201    
#> 263: 0.605560    0.994302    3.450851    0.607738    0.041953    0.023644    0.675533    
#> 264: 0.604647    0.994566    3.450786    0.606384    0.041772    0.023642    0.675904    
#> 265: 0.604280    0.994780    3.450688    0.605502    0.041643    0.023669    0.676271    
#> 266: 0.604122    0.995276    3.450592    0.605646    0.041643    0.023689    0.676398    
#> 267: 0.603785    0.995449    3.450613    0.605266    0.041679    0.023701    0.676424    
#> 268: 0.603774    0.995322    3.450578    0.605623    0.041736    0.023659    0.676244    
#> 269: 0.604944    0.995375    3.450646    0.608484    0.041847    0.023617    0.675906    
#> 270: 0.605807    0.995576    3.450609    0.611546    0.042030    0.023516    0.675561    
#> 271: 0.606051    0.995663    3.450547    0.612297    0.042063    0.023453    0.675541    
#> 272: 0.606025    0.995667    3.450499    0.612805    0.042081    0.023432    0.675960    
#> 273: 0.605851    0.995941    3.450460    0.612700    0.042148    0.023379    0.676106    
#> 274: 0.605666    0.996506    3.450302    0.612393    0.042248    0.023295    0.676204    
#> 275: 0.606401    0.996647    3.450142    0.615474    0.042132    0.023251    0.676109    
#> 276: 0.606868    0.996744    3.450268    0.616418    0.042135    0.023243    0.676258    
#> 277: 0.607058    0.997013    3.450445    0.617653    0.042251    0.023255    0.676590    
#> 278: 0.606396    0.997124    3.450422    0.616579    0.042325    0.023246    0.676865    
#> 279: 0.605914    0.996956    3.450461    0.615166    0.042489    0.023223    0.676961    
#> 280: 0.605551    0.996897    3.450534    0.613872    0.042581    0.023243    0.676748    
#> 281: 0.604990    0.996842    3.450519    0.613009    0.042522    0.023277    0.676603    
#> 282: 0.604923    0.997021    3.450369    0.613606    0.042529    0.023222    0.676568    
#> 283: 0.605027    0.997275    3.450329    0.615018    0.042601    0.023172    0.676982    
#> 284: 0.605245    0.997166    3.450357    0.614909    0.042682    0.023139    0.676893    
#> 285: 0.605475    0.997244    3.450233    0.616653    0.042894    0.023112    0.676843    
#> 286: 0.605404    0.997512    3.450078    0.617687    0.043144    0.023032    0.676957    
#> 287: 0.604822    0.997852    3.449727    0.618791    0.043332    0.022949    0.676926    
#> 288: 0.604858    0.998076    3.449500    0.619557    0.043457    0.022872    0.677045    
#> 289: 0.605535    0.998094    3.449483    0.620752    0.043545    0.022846    0.676980    
#> 290: 0.605982    0.998122    3.449447    0.621086    0.043650    0.022845    0.676973    
#> 291: 0.606233    0.998259    3.449524    0.621385    0.043708    0.022859    0.676818    
#> 292: 0.606098    0.998297    3.449559    0.621328    0.043844    0.022855    0.676665    
#> 293: 0.605707    0.998397    3.449574    0.620918    0.043947    0.022827    0.676705    
#> 294: 0.605481    0.998524    3.449460    0.620972    0.044025    0.022812    0.676550    
#> 295: 0.605325    0.998352    3.449418    0.621234    0.044051    0.022774    0.676462    
#> 296: 0.605517    0.998299    3.449366    0.620544    0.044042    0.022751    0.676594    
#> 297: 0.605509    0.998425    3.449309    0.620983    0.044087    0.022722    0.676544    
#> 298: 0.605624    0.998340    3.449308    0.620326    0.044097    0.022663    0.676513    
#> 299: 0.605879    0.998430    3.449285    0.620755    0.044131    0.022627    0.676459    
#> 300: 0.605798    0.998383    3.449257    0.620964    0.044193    0.022634    0.676325    
#> 301: 0.605448    0.998295    3.449137    0.620413    0.044207    0.022600    0.676470    
#> 302: 0.605177    0.998359    3.448995    0.620433    0.044194    0.022589    0.676270    
#> 303: 0.604759    0.998634    3.448825    0.620482    0.044307    0.022595    0.676139    
#> 304: 0.604343    0.998919    3.448641    0.620405    0.044344    0.022610    0.676193    
#> 305: 0.603985    0.998815    3.448557    0.619664    0.044464    0.022601    0.676207    
#> 306: 0.603579    0.998699    3.448476    0.619489    0.044465    0.022634    0.676151    
#> 307: 0.603631    0.998540    3.448439    0.619368    0.044561    0.022650    0.676205    
#> 308: 0.603658    0.998573    3.448403    0.619869    0.044618    0.022633    0.676205    
#> 309: 0.603823    0.998404    3.448445    0.620162    0.044620    0.022613    0.676240    
#> 310: 0.604173    0.998275    3.448420    0.620196    0.044644    0.022616    0.676154    
#> 311: 0.604569    0.998270    3.448416    0.621392    0.044669    0.022627    0.676022    
#> 312: 0.604749    0.998019    3.448429    0.622190    0.044699    0.022675    0.675925    
#> 313: 0.604857    0.997753    3.448380    0.623480    0.044624    0.022699    0.675929    
#> 314: 0.603810    0.997837    3.448114    0.622698    0.044641    0.022709    0.675884    
#> 315: 0.603042    0.997942    3.447923    0.621944    0.044719    0.022665    0.675827    
#> 316: 0.602666    0.998172    3.447820    0.621448    0.044776    0.022612    0.675737    
#> 317: 0.602907    0.998252    3.447827    0.621701    0.044815    0.022603    0.675645    
#> 318: 0.602853    0.998502    3.447747    0.621183    0.044768    0.022604    0.675621    
#> 319: 0.602813    0.998661    3.447795    0.621112    0.044770    0.022638    0.675730    
#> 320: 0.602505    0.998713    3.447654    0.621525    0.044805    0.022636    0.675710    
#> 321: 0.602263    0.998822    3.447529    0.621688    0.044830    0.022640    0.675774    
#> 322: 0.601774    0.998931    3.447308    0.621216    0.044877    0.022631    0.675752    
#> 323: 0.600879    0.999122    3.447070    0.620623    0.044869    0.022614    0.675685    
#> 324: 0.600375    0.999521    3.446963    0.620231    0.044918    0.022585    0.675637    
#> 325: 0.600364    0.999812    3.446773    0.620750    0.044954    0.022541    0.675684    
#> 326: 0.600409    0.999845    3.446648    0.621611    0.044945    0.022525    0.675639    
#> 327: 0.600643    0.999821    3.446694    0.622106    0.044920    0.022546    0.675721    
#> 328: 0.601133    0.999725    3.446789    0.623197    0.044874    0.022550    0.675721    
#> 329: 0.601408    0.999823    3.446792    0.623871    0.044907    0.022577    0.675639    
#> 330: 0.601389    0.999773    3.446817    0.625031    0.044858    0.022592    0.675527    
#> 331: 0.601838    0.999833    3.446825    0.626308    0.044871    0.022585    0.675414    
#> 332: 0.602043    0.999835    3.446910    0.626372    0.044865    0.022548    0.675489    
#> 333: 0.602060    0.999882    3.446833    0.626144    0.044900    0.022520    0.675382    
#> 334: 0.602125    0.999799    3.446676    0.626574    0.044932    0.022485    0.675371    
#> 335: 0.601812    0.999749    3.446593    0.626282    0.044923    0.022477    0.675252    
#> 336: 0.601370    0.999803    3.446536    0.625401    0.044921    0.022476    0.675160    
#> 337: 0.600857    1.000029    3.446484    0.624473    0.044933    0.022481    0.675206    
#> 338: 0.600783    1.000149    3.446438    0.625207    0.044945    0.022499    0.675158    
#> 339: 0.600621    1.000236    3.446391    0.625101    0.044916    0.022525    0.675102    
#> 340: 0.600581    1.000092    3.446406    0.624826    0.044937    0.022539    0.675146    
#> 341: 0.600718    1.000098    3.446466    0.625238    0.045075    0.022586    0.675159    
#> 342: 0.600517    0.999927    3.446481    0.625435    0.045105    0.022613    0.675264    
#> 343: 0.600497    0.999699    3.446473    0.625972    0.045179    0.022579    0.675315    
#> 344: 0.600514    0.999561    3.446541    0.626352    0.045152    0.022570    0.675374    
#> 345: 0.600761    0.999557    3.446609    0.627094    0.045184    0.022588    0.675245    
#> 346: 0.600989    0.999567    3.446610    0.627883    0.045232    0.022569    0.675071    
#> 347: 0.600861    0.999497    3.446543    0.627336    0.045267    0.022557    0.675140    
#> 348: 0.600657    0.999558    3.446434    0.627130    0.045321    0.022537    0.675188    
#> 349: 0.600592    0.999527    3.446406    0.627217    0.045286    0.022532    0.675236    
#> 350: 0.600267    0.999454    3.446412    0.626422    0.045315    0.022517    0.675308    
#> 351: 0.600142    0.999499    3.446406    0.625989    0.045312    0.022517    0.675299    
#> 352: 0.599994    0.999559    3.446420    0.625623    0.045331    0.022523    0.675462    
#> 353: 0.600039    0.999634    3.446372    0.625709    0.045329    0.022541    0.675390    
#> 354: 0.600203    0.999725    3.446322    0.625540    0.045312    0.022570    0.675406    
#> 355: 0.600864    0.999635    3.446414    0.625795    0.045310    0.022549    0.675445    
#> 356: 0.601279    0.999560    3.446573    0.625516    0.045326    0.022527    0.675561    
#> 357: 0.601363    0.999534    3.446666    0.625032    0.045316    0.022481    0.675590    
#> 358: 0.601529    0.999533    3.446704    0.625174    0.045369    0.022489    0.675510    
#> 359: 0.601539    0.999662    3.446682    0.625346    0.045339    0.022490    0.675447    
#> 360: 0.601377    0.999730    3.446597    0.625406    0.045313    0.022500    0.675321    
#> 361: 0.601381    0.999809    3.446503    0.626146    0.045229    0.022492    0.675286    
#> 362: 0.601421    0.999891    3.446472    0.626368    0.045205    0.022496    0.675133    
#> 363: 0.601473    0.999894    3.446484    0.626598    0.045145    0.022480    0.675080    
#> 364: 0.601761    0.999940    3.446491    0.626991    0.045140    0.022471    0.675033    
#> 365: 0.601785    0.999917    3.446497    0.627533    0.045138    0.022484    0.675070    
#> 366: 0.601714    1.000018    3.446366    0.628166    0.045220    0.022470    0.675109    
#> 367: 0.601497    1.000086    3.446252    0.628354    0.045209    0.022457    0.675114    
#> 368: 0.601680    1.000158    3.446173    0.628600    0.045158    0.022460    0.675040    
#> 369: 0.601454    1.000135    3.446108    0.628637    0.045209    0.022484    0.675022    
#> 370: 0.601165    1.000229    3.446055    0.628356    0.045246    0.022528    0.675018    
#> 371: 0.600918    1.000363    3.445896    0.628819    0.045315    0.022560    0.674894    
#> 372: 0.600513    1.000491    3.445758    0.629158    0.045300    0.022587    0.674886    
#> 373: 0.600138    1.000672    3.445617    0.629241    0.045250    0.022605    0.674924    
#> 374: 0.600327    1.000709    3.445599    0.630152    0.045238    0.022626    0.674869    
#> 375: 0.600494    1.000718    3.445581    0.630963    0.045242    0.022626    0.674885    
#> 376: 0.600460    1.000787    3.445564    0.630903    0.045263    0.022680    0.674818    
#> 377: 0.600313    1.000838    3.445497    0.631074    0.045321    0.022731    0.674789    
#> 378: 0.600129    1.000857    3.445365    0.630950    0.045287    0.022769    0.674691    
#> 379: 0.599670    1.000814    3.445275    0.630383    0.045271    0.022786    0.674686    
#> 380: 0.599445    1.000838    3.445244    0.629797    0.045271    0.022817    0.674653    
#> 381: 0.599578    1.000849    3.445161    0.630388    0.045292    0.022836    0.674623    
#> 382: 0.599349    1.001010    3.445053    0.630589    0.045313    0.022844    0.674546    
#> 383: 0.599194    1.001105    3.444947    0.630875    0.045279    0.022844    0.674429    
#> 384: 0.598900    1.001216    3.444844    0.631249    0.045298    0.022861    0.674345    
#> 385: 0.598806    1.001328    3.444769    0.631269    0.045303    0.022859    0.674334    
#> 386: 0.598711    1.001576    3.444726    0.631198    0.045349    0.022853    0.674370    
#> 387: 0.598788    1.001725    3.444780    0.631180    0.045346    0.022858    0.674317    
#> 388: 0.599001    1.001805    3.444808    0.631501    0.045292    0.022852    0.674290    
#> 389: 0.599039    1.001674    3.444824    0.631714    0.045266    0.022857    0.674339    
#> 390: 0.599007    1.001739    3.444766    0.631940    0.045226    0.022851    0.674351    
#> 391: 0.599039    1.001719    3.444752    0.632041    0.045216    0.022858    0.674285    
#> 392: 0.598934    1.001736    3.444795    0.631964    0.045183    0.022842    0.674386    
#> 393: 0.598868    1.001677    3.444789    0.631705    0.045168    0.022844    0.674452    
#> 394: 0.599040    1.001709    3.444775    0.632022    0.045155    0.022829    0.674504    
#> 395: 0.599345    1.001813    3.444772    0.632675    0.045126    0.022830    0.674501    
#> 396: 0.599487    1.001915    3.444777    0.632950    0.045155    0.022812    0.674586    
#> 397: 0.599566    1.001871    3.444788    0.633327    0.045140    0.022800    0.674701    
#> 398: 0.599812    1.001860    3.444779    0.634146    0.045131    0.022760    0.674748    
#> 399: 0.599576    1.002005    3.444730    0.634111    0.045143    0.022730    0.674789    
#> 400: 0.599588    1.002129    3.444709    0.634033    0.045125    0.022712    0.674932    
#> 401: 0.599412    1.002245    3.444637    0.633750    0.045171    0.022724    0.674951    
#> 402: 0.599275    1.002359    3.444561    0.633839    0.045207    0.022716    0.674934    
#> 403: 0.599189    1.002462    3.444490    0.633839    0.045244    0.022683    0.674887    
#> 404: 0.598987    1.002589    3.444385    0.633972    0.045229    0.022665    0.674856    
#> 405: 0.599157    1.002649    3.444368    0.634255    0.045183    0.022654    0.674857    
#> 406: 0.598995    1.002733    3.444326    0.634101    0.045112    0.022675    0.674859    
#> 407: 0.599053    1.002837    3.444385    0.634058    0.045104    0.022683    0.674825    
#> 408: 0.599177    1.002950    3.444363    0.633793    0.045111    0.022678    0.674814    
#> 409: 0.599159    1.002914    3.444337    0.633601    0.045083    0.022670    0.674788    
#> 410: 0.598970    1.002954    3.444256    0.633530    0.045062    0.022661    0.674809    
#> 411: 0.598927    1.002789    3.444254    0.633342    0.045021    0.022666    0.674950    
#> 412: 0.599119    1.002715    3.444300    0.633170    0.045051    0.022670    0.675040    
#> 413: 0.599327    1.002692    3.444346    0.633160    0.045030    0.022660    0.675117    
#> 414: 0.599181    1.002663    3.444388    0.632859    0.044974    0.022651    0.675152    
#> 415: 0.599189    1.002627    3.444494    0.632471    0.044937    0.022655    0.675153    
#> 416: 0.599385    1.002696    3.444611    0.631714    0.044907    0.022646    0.675192    
#> 417: 0.599668    1.002611    3.444685    0.631651    0.044899    0.022628    0.675181    
#> 418: 0.599761    1.002580    3.444768    0.631421    0.044890    0.022630    0.675062    
#> 419: 0.599891    1.002595    3.444857    0.631069    0.044884    0.022623    0.675034    
#> 420: 0.599973    1.002535    3.444933    0.630520    0.044898    0.022599    0.674955    
#> 421: 0.600000    1.002492    3.445015    0.630019    0.044873    0.022584    0.674905    
#> 422: 0.600248    1.002414    3.445054    0.630088    0.044846    0.022557    0.674881    
#> 423: 0.600338    1.002313    3.445089    0.630291    0.044858    0.022550    0.674793    
#> 424: 0.600378    1.002253    3.445103    0.630392    0.044899    0.022538    0.674791    
#> 425: 0.600542    1.002214    3.445102    0.630514    0.044862    0.022551    0.674821    
#> 426: 0.600754    1.002291    3.445091    0.631312    0.044828    0.022569    0.674789    
#> 427: 0.600714    1.002327    3.445097    0.631626    0.044814    0.022578    0.674763    
#> 428: 0.600612    1.002392    3.445065    0.631565    0.044859    0.022555    0.674712    
#> 429: 0.600433    1.002510    3.445011    0.631648    0.044913    0.022530    0.674730    
#> 430: 0.600286    1.002592    3.444966    0.631472    0.044924    0.022508    0.674804    
#> 431: 0.600219    1.002565    3.444928    0.631659    0.044938    0.022486    0.674747    
#> 432: 0.600154    1.002624    3.444904    0.631762    0.044923    0.022489    0.674719    
#> 433: 0.600178    1.002712    3.444937    0.631636    0.044888    0.022481    0.674761    
#> 434: 0.600002    1.002715    3.444953    0.631006    0.044910    0.022461    0.674798    
#> 435: 0.599980    1.002677    3.444986    0.630452    0.044906    0.022459    0.674802    
#> 436: 0.600038    1.002654    3.445051    0.630211    0.044904    0.022450    0.674927    
#> 437: 0.600077    1.002647    3.445055    0.629968    0.044908    0.022431    0.675005    
#> 438: 0.600190    1.002823    3.445094    0.630106    0.044898    0.022408    0.675011    
#> 439: 0.600191    1.002934    3.445127    0.629490    0.044881    0.022389    0.674996    
#> 440: 0.600094    1.003014    3.445136    0.629161    0.044874    0.022379    0.674983    
#> 441: 0.599976    1.003020    3.445153    0.628849    0.044861    0.022374    0.674905    
#> 442: 0.599867    1.003058    3.445189    0.628664    0.044872    0.022370    0.674817    
#> 443: 0.599935    1.003081    3.445183    0.628681    0.044889    0.022351    0.674786    
#> 444: 0.599923    1.003189    3.445090    0.628900    0.044908    0.022328    0.674720    
#> 445: 0.599699    1.003227    3.445019    0.628667    0.044969    0.022309    0.674728    
#> 446: 0.599481    1.003323    3.444951    0.629006    0.045031    0.022290    0.674658    
#> 447: 0.599410    1.003409    3.444909    0.629282    0.045090    0.022280    0.674566    
#> 448: 0.599410    1.003459    3.444907    0.629580    0.045106    0.022270    0.674521    
#> 449: 0.599351    1.003514    3.444950    0.629562    0.045096    0.022255    0.674578    
#> 450: 0.599375    1.003520    3.444963    0.629530    0.045113    0.022240    0.674602    
#> 451: 0.599357    1.003554    3.444950    0.629333    0.045160    0.022214    0.674629    
#> 452: 0.599294    1.003567    3.444972    0.629343    0.045160    0.022206    0.674588    
#> 453: 0.599308    1.003551    3.444944    0.629474    0.045121    0.022203    0.674528    
#> 454: 0.599404    1.003640    3.444904    0.630382    0.045095    0.022196    0.674468    
#> 455: 0.599663    1.003630    3.444924    0.631467    0.045152    0.022193    0.674411    
#> 456: 0.599717    1.003580    3.444916    0.631857    0.045197    0.022177    0.674359    
#> 457: 0.599818    1.003551    3.444964    0.631909    0.045226    0.022156    0.674287    
#> 458: 0.599888    1.003578    3.445023    0.631841    0.045218    0.022146    0.674240    
#> 459: 0.599646    1.003668    3.445047    0.631306    0.045223    0.022133    0.674238    
#> 460: 0.599503    1.003718    3.445032    0.630802    0.045216    0.022130    0.674234    
#> 461: 0.599472    1.003749    3.445053    0.630491    0.045223    0.022120    0.674208    
#> 462: 0.599374    1.003806    3.445064    0.630394    0.045243    0.022099    0.674169    
#> 463: 0.599456    1.003847    3.445070    0.630548    0.045266    0.022083    0.674197    
#> 464: 0.599489    1.003902    3.445033    0.630948    0.045297    0.022074    0.674148    
#> 465: 0.599623    1.003821    3.445017    0.631463    0.045307    0.022054    0.674130    
#> 466: 0.599636    1.003812    3.444971    0.631715    0.045324    0.022033    0.674106    
#> 467: 0.599681    1.003807    3.444985    0.631906    0.045369    0.021991    0.674051    
#> 468: 0.599904    1.003768    3.445068    0.632108    0.045384    0.021982    0.674092    
#> 469: 0.600021    1.003846    3.445108    0.631891    0.045384    0.021977    0.674178    
#> 470: 0.600067    1.003896    3.445091    0.631955    0.045400    0.021945    0.674240    
#> 471: 0.600063    1.003891    3.445088    0.632003    0.045413    0.021925    0.674292    
#> 472: 0.600068    1.003875    3.445071    0.632065    0.045433    0.021904    0.674296    
#> 473: 0.600014    1.003925    3.445045    0.631866    0.045473    0.021885    0.674207    
#> 474: 0.599871    1.003977    3.444989    0.631657    0.045479    0.021879    0.674215    
#> 475: 0.599846    1.004076    3.444973    0.631642    0.045484    0.021876    0.674191    
#> 476: 0.599873    1.004071    3.444954    0.631642    0.045493    0.021885    0.674190    
#> 477: 0.599813    1.004072    3.444979    0.631274    0.045501    0.021907    0.674169    
#> 478: 0.599760    1.004080    3.444985    0.631316    0.045546    0.021918    0.674149    
#> 479: 0.599918    1.004113    3.445001    0.631725    0.045554    0.021924    0.674168    
#> 480: 0.600045    1.004193    3.444960    0.632264    0.045566    0.021922    0.674206    
#> 481: 0.600099    1.004216    3.444962    0.632318    0.045563    0.021917    0.674205    
#> 482: 0.599939    1.004239    3.444908    0.632151    0.045573    0.021907    0.674259    
#> 483: 0.599659    1.004217    3.444878    0.631822    0.045585    0.021895    0.674279    
#> 484: 0.599516    1.004103    3.444877    0.631171    0.045584    0.021897    0.674314    
#> 485: 0.599458    1.004081    3.444876    0.630957    0.045551    0.021889    0.674378    
#> 486: 0.599594    1.004088    3.444963    0.630766    0.045505    0.021891    0.674387    
#> 487: 0.599877    1.004133    3.445052    0.630676    0.045494    0.021899    0.674445    
#> 488: 0.599987    1.004082    3.445110    0.630339    0.045465    0.021895    0.674443    
#> 489: 0.600092    1.004045    3.445112    0.629945    0.045463    0.021896    0.674448    
#> 490: 0.600143    1.004013    3.445128    0.629863    0.045453    0.021900    0.674367    
#> 491: 0.600218    1.004034    3.445179    0.629920    0.045452    0.021904    0.674333    
#> 492: 0.600144    1.004081    3.445171    0.629814    0.045420    0.021922    0.674446    
#> 493: 0.600048    1.004120    3.445148    0.629712    0.045392    0.021932    0.674494    
#> 494: 0.600167    1.004121    3.445146    0.629769    0.045341    0.021926    0.674503    
#> 495: 0.600152    1.004181    3.445119    0.629647    0.045318    0.021926    0.674495    
#> 496: 0.600114    1.004272    3.445049    0.629863    0.045316    0.021916    0.674506    
#> 497: 0.599935    1.004341    3.444979    0.629923    0.045340    0.021904    0.674518    
#> 498: 0.599876    1.004329    3.444893    0.630156    0.045330    0.021896    0.674478    
#> 499: 0.599781    1.004348    3.444823    0.630027    0.045355    0.021880    0.674445    
#> 500: 0.599747    1.004266    3.444812    0.629869    0.045383    0.021868    0.674449    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.313879    0.966076    3.438993    0.392401    0.076512    0.016800    1.865367    
#> 002: 0.296222    0.976543    3.439939    0.372781    0.072686    0.015960    1.294533    
#> 003: 0.376587    0.911986    3.442942    0.354142    0.069052    0.015162    1.027862    
#> 004: 0.296484    0.937436    3.422822    0.352958    0.065599    0.014404    0.954502    
#> 005: 0.293936    0.947396    3.393464    0.335310    0.062319    0.013684    0.904718    
#> 006: 0.306858    0.941264    3.387689    0.420856    0.059203    0.013000    0.828350    
#> 007: 0.258911    0.958110    3.370275    0.445759    0.056243    0.012350    0.819922    
#> 008: 0.240536    0.947984    3.357277    0.456070    0.053431    0.011732    0.803936    
#> 009: 0.234143    0.937045    3.369009    0.447220    0.050759    0.013043    0.797926    
#> 010: 0.204743    0.939926    3.351519    0.620354    0.048221    0.012820    0.795773    
#> 011: 0.296593    0.953495    3.360071    0.589337    0.045810    0.012179    0.797148    
#> 012: 0.290425    0.942499    3.355628    0.650535    0.043520    0.013850    0.792910    
#> 013: 0.229655    0.946978    3.358772    0.618009    0.041344    0.015921    0.816931    
#> 014: 0.273704    0.947374    3.367141    0.587108    0.039277    0.015125    0.793604    
#> 015: 0.305417    0.946100    3.388697    0.557753    0.037313    0.014550    0.782538    
#> 016: 0.310467    0.959189    3.393642    0.529865    0.035447    0.016215    0.791113    
#> 017: 0.294111    0.944795    3.390922    0.569003    0.033675    0.016042    0.744588    
#> 018: 0.291902    0.965765    3.357309    0.552933    0.031991    0.015240    0.781230    
#> 019: 0.265595    0.979998    3.354779    0.540433    0.031700    0.014478    0.774620    
#> 020: 0.257086    0.973077    3.364861    0.513411    0.037640    0.013754    0.779592    
#> 021: 0.284621    0.960012    3.366691    0.554981    0.035758    0.013067    0.783676    
#> 022: 0.238286    0.961705    3.366062    0.603997    0.033970    0.012413    0.795141    
#> 023: 0.345159    0.973158    3.379030    0.686211    0.032272    0.011836    0.799772    
#> 024: 0.351261    0.988920    3.375400    0.708894    0.030658    0.011651    0.769670    
#> 025: 0.303730    0.977287    3.368722    0.715397    0.032089    0.011090    0.778328    
#> 026: 0.300153    0.991080    3.367185    0.679627    0.033718    0.010535    0.789566    
#> 027: 0.285768    0.978855    3.363007    0.675070    0.032032    0.010009    0.772476    
#> 028: 0.313939    0.982019    3.366159    0.641316    0.030431    0.010565    0.771503    
#> 029: 0.317615    0.974587    3.363299    0.707199    0.028909    0.012427    0.770197    
#> 030: 0.303202    0.981223    3.364631    0.671839    0.027464    0.014209    0.768318    
#> 031: 0.322209    0.960649    3.371769    0.833614    0.026090    0.013499    0.764821    
#> 032: 0.259597    0.964021    3.375189    0.791934    0.024786    0.013656    0.764370    
#> 033: 0.241416    0.987756    3.353174    0.752337    0.028093    0.012973    0.773015    
#> 034: 0.244849    0.986435    3.345609    0.714720    0.032490    0.014574    0.782358    
#> 035: 0.238208    0.961996    3.343837    0.678984    0.030865    0.014236    0.767303    
#> 036: 0.273558    0.978641    3.338990    0.734552    0.029322    0.015579    0.779460    
#> 037: 0.261293    0.984079    3.351883    0.697824    0.034296    0.014800    0.801731    
#> 038: 0.311416    0.983735    3.349435    0.755023    0.034676    0.014060    0.785470    
#> 039: 0.277856    0.981753    3.352542    0.717272    0.032942    0.013357    0.784723    
#> 040: 0.302113    0.986550    3.353960    0.728943    0.031295    0.012689    0.781226    
#> 041: 0.354182    0.964805    3.366787    0.853340    0.029730    0.012055    0.753185    
#> 042: 0.323630    0.961896    3.363261    0.810673    0.028243    0.011452    0.760319    
#> 043: 0.227244    0.993132    3.344312    0.770139    0.032944    0.011203    0.762716    
#> 044: 0.260266    0.995635    3.346025    0.731632    0.031297    0.010643    0.770882    
#> 045: 0.299038    1.009085    3.341355    0.805655    0.040616    0.010111    0.742927    
#> 046: 0.257089    0.985965    3.346981    0.765372    0.038585    0.009605    0.755893    
#> 047: 0.269954    0.999060    3.334586    0.727104    0.037478    0.009418    0.762731    
#> 048: 0.226525    0.968639    3.339112    0.690749    0.035604    0.011492    0.764609    
#> 049: 0.245521    0.969069    3.349697    0.656211    0.033824    0.012655    0.773706    
#> 050: 0.282718    0.960866    3.347980    0.699706    0.033322    0.012023    0.792367    
#> 051: 0.237007    0.991843    3.331235    0.664721    0.034305    0.011421    0.812368    
#> 052: 0.324604    0.995765    3.344882    0.859247    0.033112    0.010850    0.782117    
#> 053: 0.264753    0.974862    3.343012    0.816285    0.031456    0.010308    0.796081    
#> 054: 0.178806    0.982799    3.345903    0.775471    0.029883    0.009792    0.817592    
#> 055: 0.221952    0.993856    3.350031    0.736697    0.028389    0.009303    0.807760    
#> 056: 0.281002    0.989948    3.357231    0.699862    0.030714    0.008838    0.823045    
#> 057: 0.312796    0.982334    3.370696    0.664869    0.033987    0.008396    0.811866    
#> 058: 0.285390    0.980668    3.359110    0.631626    0.035088    0.008489    0.803045    
#> 059: 0.261812    0.957765    3.360086    0.601730    0.044177    0.009797    0.810686    
#> 060: 0.276168    0.953668    3.376865    0.571644    0.041968    0.009971    0.818897    
#> 061: 0.308195    0.961505    3.368272    0.577088    0.039870    0.009473    0.816516    
#> 062: 0.301785    0.961880    3.380574    0.642075    0.041440    0.008999    0.810863    
#> 063: 0.298369    0.943750    3.366438    0.609971    0.039368    0.009992    0.812946    
#> 064: 0.290930    0.963941    3.373881    0.669318    0.037400    0.011708    0.786581    
#> 065: 0.321094    0.940474    3.371557    0.648100    0.035530    0.013998    0.794886    
#> 066: 0.306957    0.953107    3.363870    0.668535    0.033754    0.013926    0.753781    
#> 067: 0.284283    0.955837    3.358656    0.682273    0.032066    0.018274    0.769234    
#> 068: 0.259227    0.970183    3.364771    0.648159    0.030463    0.017360    0.783445    
#> 069: 0.266598    0.976094    3.360033    0.630065    0.028939    0.016492    0.796209    
#> 070: 0.248380    0.963872    3.364145    0.655127    0.030144    0.015667    0.775225    
#> 071: 0.212365    0.996827    3.336120    0.622371    0.033604    0.014884    0.794290    
#> 072: 0.227639    0.980093    3.331328    0.709603    0.031924    0.014140    0.789285    
#> 073: 0.271374    0.988358    3.352594    0.854162    0.031009    0.013433    0.773743    
#> 074: 0.257661    0.975504    3.354952    0.811454    0.034436    0.012761    0.765451    
#> 075: 0.252323    0.974262    3.374608    0.770881    0.032714    0.012123    0.794297    
#> 076: 0.342736    0.967181    3.390086    0.732337    0.031081    0.015224    0.785898    
#> 077: 0.350327    0.951974    3.374931    0.695720    0.031486    0.014463    0.791703    
#> 078: 0.331191    0.951155    3.379360    0.660934    0.029912    0.013740    0.795007    
#> 079: 0.320758    0.961737    3.386507    0.652954    0.032334    0.013053    0.826983    
#> 080: 0.340498    0.939837    3.393789    0.701610    0.032853    0.013684    0.837983    
#> 081: 0.354685    0.921616    3.399948    0.666530    0.031210    0.015081    0.813466    
#> 082: 0.321997    0.932247    3.404177    0.633203    0.029650    0.014560    0.809232    
#> 083: 0.300013    0.942076    3.391809    0.601543    0.028167    0.013832    0.809339    
#> 084: 0.261028    0.951887    3.368925    0.571466    0.035461    0.013141    0.802917    
#> 085: 0.310853    0.966562    3.374475    0.542893    0.034419    0.012484    0.814103    
#> 086: 0.287449    0.969845    3.370925    0.515748    0.036859    0.011859    0.793125    
#> 087: 0.257277    0.963668    3.366655    0.489961    0.035016    0.011487    0.788635    
#> 088: 0.227461    0.953841    3.371298    0.522230    0.033265    0.010912    0.805252    
#> 089: 0.225777    0.984268    3.350814    0.496119    0.031602    0.010646    0.779875    
#> 090: 0.252721    0.984787    3.352763    0.603026    0.030022    0.010114    0.785592    
#> 091: 0.249654    0.962718    3.343248    0.653716    0.028521    0.009708    0.781053    
#> 092: 0.252946    0.982670    3.343553    0.661526    0.027095    0.010273    0.776496    
#> 093: 0.235930    0.971120    3.349979    0.628450    0.025740    0.010248    0.797139    
#> 094: 0.248728    0.967175    3.344506    0.597028    0.024453    0.011708    0.795368    
#> 095: 0.218121    0.970573    3.354655    0.567176    0.023230    0.013614    0.771534    
#> 096: 0.203704    0.980119    3.347363    0.538817    0.022069    0.012933    0.770734    
#> 097: 0.255691    0.985821    3.350987    0.563321    0.020965    0.012976    0.776174    
#> 098: 0.287101    0.987811    3.370859    0.581624    0.019917    0.012327    0.804455    
#> 099: 0.276747    0.973645    3.352726    0.618333    0.018921    0.013930    0.783521    
#> 100: 0.277023    0.965324    3.358402    0.653306    0.017975    0.014064    0.783965    
#> 101: 0.235931    0.963434    3.343200    0.620641    0.018378    0.013676    0.774417    
#> 102: 0.258562    0.954009    3.340901    0.652813    0.017459    0.014034    0.773520    
#> 103: 0.274984    0.958092    3.356689    0.695010    0.016586    0.015391    0.757924    
#> 104: 0.290231    0.965862    3.366279    0.791233    0.015757    0.016168    0.766005    
#> 105: 0.286260    0.970241    3.353857    0.751671    0.015856    0.015359    0.773899    
#> 106: 0.267239    0.978916    3.354007    0.714088    0.015753    0.016098    0.763482    
#> 107: 0.277071    0.982660    3.359046    0.720976    0.016545    0.017429    0.767375    
#> 108: 0.282260    0.978301    3.365619    0.698661    0.017346    0.017333    0.787673    
#> 109: 0.278689    0.961858    3.378980    0.663728    0.017007    0.017305    0.778941    
#> 110: 0.321118    0.977671    3.357808    0.686339    0.016157    0.016440    0.770306    
#> 111: 0.289817    0.980535    3.367029    0.652022    0.015647    0.015618    0.766774    
#> 112: 0.291347    0.958234    3.358448    0.621784    0.017413    0.015618    0.775490    
#> 113: 0.290012    0.985488    3.368617    0.590695    0.017235    0.019399    0.765559    
#> 114: 0.274431    0.984821    3.361981    0.630878    0.017212    0.019208    0.772347    
#> 115: 0.310902    0.958109    3.357091    0.710355    0.016352    0.021111    0.772129    
#> 116: 0.295470    0.963321    3.367039    0.674837    0.015534    0.023262    0.767614    
#> 117: 0.266527    0.980040    3.363284    0.667540    0.014757    0.022099    0.772798    
#> 118: 0.283675    0.978089    3.373328    0.634163    0.017257    0.020994    0.774317    
#> 119: 0.288300    0.979555    3.360127    0.752869    0.019244    0.020984    0.798357    
#> 120: 0.270440    0.965376    3.355812    0.734496    0.018401    0.021075    0.774787    
#> 121: 0.273745    0.976722    3.354074    0.711973    0.020515    0.020829    0.786434    
#> 122: 0.276695    0.969522    3.365918    0.676374    0.019489    0.019787    0.793606    
#> 123: 0.320734    0.989072    3.362019    0.642556    0.022130    0.018798    0.781595    
#> 124: 0.283374    1.009272    3.350863    0.744521    0.025287    0.017858    0.783508    
#> 125: 0.279115    1.017571    3.343952    0.707294    0.024648    0.016965    0.761800    
#> 126: 0.271804    1.015064    3.345337    0.671930    0.025580    0.016117    0.776887    
#> 127: 0.273780    0.997171    3.338746    0.688186    0.024301    0.015311    0.768334    
#> 128: 0.223023    0.990288    3.344773    0.653777    0.034042    0.014545    0.772747    
#> 129: 0.286871    0.986695    3.363609    0.661236    0.035482    0.014061    0.761720    
#> 130: 0.318539    1.009415    3.365519    0.675620    0.033708    0.014349    0.760679    
#> 131: 0.298374    0.986635    3.347547    0.699388    0.037103    0.013632    0.749657    
#> 132: 0.244777    0.991472    3.335829    0.664418    0.035248    0.013578    0.764525    
#> 133: 0.248358    0.972530    3.351675    0.635830    0.033486    0.012899    0.771289    
#> 134: 0.303971    0.957518    3.371399    0.720992    0.031811    0.013509    0.764216    
#> 135: 0.316594    0.953851    3.370832    0.697202    0.030221    0.012834    0.788802    
#> 136: 0.286247    0.947837    3.361469    0.727577    0.028825    0.012192    0.777663    
#> 137: 0.360244    0.960658    3.368836    0.824301    0.027384    0.011582    0.789316    
#> 138: 0.329488    0.966783    3.367693    0.850503    0.028356    0.011668    0.776079    
#> 139: 0.308468    0.972089    3.364500    0.807978    0.037623    0.011084    0.780468    
#> 140: 0.298419    0.979374    3.369623    0.767579    0.042285    0.012335    0.786160    
#> 141: 0.278053    0.958890    3.370541    0.749846    0.040171    0.011718    0.766985    
#> 142: 0.304203    0.935876    3.379949    0.712354    0.038163    0.011132    0.782388    
#> 143: 0.239394    0.949835    3.373819    0.676736    0.036254    0.011747    0.783391    
#> 144: 0.283210    0.953921    3.384876    0.642899    0.034442    0.011636    0.762316    
#> 145: 0.311157    0.955258    3.370318    0.610754    0.032720    0.011054    0.765084    
#> 146: 0.276904    0.983945    3.378360    0.610978    0.031084    0.013188    0.779423    
#> 147: 0.287243    0.971830    3.375741    0.606254    0.029529    0.012529    0.775699    
#> 148: 0.269084    0.971786    3.381535    0.575941    0.030043    0.011903    0.766890    
#> 149: 0.284388    0.963213    3.378642    0.612263    0.028541    0.011307    0.801644    
#> 150: 0.269520    0.961189    3.360197    0.605363    0.027114    0.010742    0.811727    
#> 151: 0.226700    0.968664    3.352083    0.575095    0.032532    0.010205    0.789861    
#> 152: 0.227938    0.973738    3.352060    0.631176    0.039408    0.008805    0.797388    
#> 153: 0.235570    1.012390    3.348491    0.580067    0.037790    0.005944    0.785310    
#> 154: 0.256965    1.010596    3.352368    0.578540    0.040962    0.008211    0.792292    
#> 155: 0.252946    0.966006    3.354091    0.616092    0.029315    0.007881    0.775949    
#> 156: 0.279017    0.976228    3.364429    0.685382    0.033599    0.009425    0.782558    
#> 157: 0.316788    0.959295    3.368253    0.723994    0.028003    0.012280    0.789456    
#> 158: 0.305753    0.973438    3.367148    0.659685    0.022842    0.010023    0.766753    
#> 159: 0.248709    0.983728    3.362916    0.597242    0.022433    0.010588    0.774305    
#> 160: 0.302617    0.961044    3.372201    0.508986    0.023329    0.012245    0.787535    
#> 161: 0.280218    0.985037    3.364562    0.583384    0.021395    0.012878    0.777171    
#> 162: 0.284368    1.005654    3.358912    0.651988    0.024274    0.011778    0.785111    
#> 163: 0.325439    0.988164    3.347324    0.765255    0.028027    0.011115    0.769629    
#> 164: 0.354057    0.978286    3.375144    0.742432    0.022926    0.012901    0.776635    
#> 165: 0.334996    0.964472    3.380077    0.736365    0.018916    0.016022    0.782910    
#> 166: 0.374283    0.986450    3.365365    0.959991    0.017451    0.016860    0.789893    
#> 167: 0.334753    0.996004    3.365449    0.885157    0.017355    0.018670    0.782323    
#> 168: 0.354661    1.000526    3.357853    0.972634    0.019995    0.013488    0.771579    
#> 169: 0.365423    1.009056    3.344699    1.014470    0.015324    0.014470    0.776927    
#> 170: 0.369287    0.992349    3.354869    1.212287    0.015725    0.016235    0.782094    
#> 171: 0.276998    1.003173    3.344834    0.844798    0.016804    0.011976    0.774970    
#> 172: 0.250405    1.004808    3.345985    0.640690    0.017643    0.013917    0.783050    
#> 173: 0.231235    1.008546    3.326129    0.751877    0.020542    0.015233    0.790216    
#> 174: 0.294938    1.001714    3.347412    0.779972    0.022975    0.016154    0.774063    
#> 175: 0.275313    0.997016    3.331177    0.740860    0.031349    0.019534    0.770537    
#> 176: 0.277186    1.007604    3.342551    0.792383    0.027104    0.017440    0.780001    
#> 177: 0.289707    0.986151    3.360452    0.818413    0.025806    0.017153    0.780597    
#> 178: 0.259047    0.974526    3.347729    0.722729    0.034101    0.013340    0.789209    
#> 179: 0.302771    0.999122    3.332765    0.876451    0.027032    0.014568    0.787726    
#> 180: 0.311420    0.980661    3.349762    0.853172    0.022526    0.013580    0.764637    
#> 181: 0.282055    0.973526    3.335087    0.732894    0.021201    0.014321    0.785219    
#> 182: 0.271723    0.983154    3.329286    0.836437    0.025823    0.014251    0.798208    
#> 183: 0.263137    0.999777    3.336457    0.769178    0.022073    0.010793    0.795055    
#> 184: 0.239933    0.961475    3.350180    0.699414    0.018520    0.010088    0.806478    
#> 185: 0.209933    0.975750    3.343683    0.614364    0.018861    0.009441    0.813669    
#> 186: 0.208598    0.995218    3.340740    0.687865    0.020159    0.011154    0.787997    
#> 187: 0.268926    0.986052    3.346994    0.739806    0.023547    0.009230    0.792017    
#> 188: 0.211494    1.002474    3.342909    0.702545    0.027510    0.007225    0.800120    
#> 189: 0.242937    1.010156    3.345251    0.625913    0.029377    0.006978    0.826094    
#> 190: 0.254661    0.999175    3.348791    0.588135    0.026111    0.007561    0.806591    
#> 191: 0.214960    0.994351    3.335758    0.554742    0.031711    0.008422    0.789659    
#> 192: 0.216744    1.000542    3.338799    0.658767    0.032264    0.009567    0.792135    
#> 193: 0.295711    0.988503    3.347535    0.735482    0.025720    0.009389    0.770059    
#> 194: 0.281446    0.986893    3.335320    0.768032    0.023269    0.009057    0.775036    
#> 195: 0.201191    0.996989    3.331363    0.687431    0.023863    0.010445    0.777384    
#> 196: 0.215273    1.007093    3.334564    0.643522    0.028414    0.009950    0.782558    
#> 197: 0.207723    1.007411    3.351573    0.676279    0.028598    0.011135    0.782762    
#> 198: 0.289421    0.995074    3.344053    0.682390    0.022561    0.013616    0.763571    
#> 199: 0.214433    0.987226    3.345098    0.632700    0.023886    0.014241    0.746782    
#> 200: 0.225278    0.991227    3.337669    0.770055    0.016882    0.010840    0.785039    
#> 201: 0.251720    0.986559    3.342204    0.809026    0.015162    0.012579    0.783849    
#> 202: 0.276198    0.985602    3.346340    0.849463    0.015735    0.013490    0.779925    
#> 203: 0.292907    0.983288    3.347524    0.861411    0.015516    0.013898    0.782707    
#> 204: 0.301595    0.980846    3.350357    0.869206    0.016068    0.014782    0.781703    
#> 205: 0.307208    0.984390    3.351795    0.867858    0.016459    0.015606    0.781615    
#> 206: 0.311763    0.987738    3.352606    0.873150    0.016784    0.015657    0.780423    
#> 207: 0.311953    0.987353    3.352841    0.861914    0.016379    0.015475    0.780557    
#> 208: 0.318300    0.985872    3.354894    0.861295    0.016821    0.015217    0.780075    
#> 209: 0.323401    0.983961    3.355422    0.869240    0.017481    0.014728    0.778877    
#> 210: 0.324538    0.981850    3.355889    0.866251    0.017215    0.014195    0.778427    
#> 211: 0.320021    0.980875    3.356605    0.846788    0.017137    0.013825    0.778523    
#> 212: 0.317841    0.980103    3.356560    0.832318    0.017188    0.013586    0.778304    
#> 213: 0.314161    0.978072    3.355946    0.820483    0.017561    0.013455    0.779756    
#> 214: 0.312792    0.976617    3.356221    0.819332    0.017750    0.013450    0.779908    
#> 215: 0.311174    0.975931    3.356657    0.812083    0.017832    0.013493    0.779871    
#> 216: 0.311764    0.974655    3.357244    0.805647    0.017866    0.013567    0.779866    
#> 217: 0.309400    0.974384    3.357846    0.795599    0.017917    0.013590    0.778911    
#> 218: 0.310037    0.974863    3.357396    0.796740    0.017829    0.013621    0.778916    
#> 219: 0.309327    0.975070    3.356147    0.801263    0.017778    0.013698    0.778403    
#> 220: 0.306727    0.975751    3.355613    0.805675    0.017863    0.013744    0.778434    
#> 221: 0.306388    0.975495    3.355333    0.807513    0.018050    0.013692    0.777774    
#> 222: 0.304814    0.975301    3.354993    0.808600    0.018318    0.013575    0.777700    
#> 223: 0.305935    0.974734    3.354949    0.812114    0.018593    0.013366    0.778199    
#> 224: 0.306305    0.974532    3.354921    0.818395    0.018939    0.013161    0.778093    
#> 225: 0.306221    0.973809    3.354973    0.821590    0.019337    0.013038    0.777896    
#> 226: 0.305194    0.972861    3.354694    0.819529    0.019730    0.013022    0.777946    
#> 227: 0.303775    0.972626    3.354651    0.818235    0.019788    0.013036    0.778243    
#> 228: 0.303286    0.973044    3.354077    0.822012    0.019994    0.013178    0.778197    
#> 229: 0.300950    0.973221    3.353380    0.819573    0.020229    0.013231    0.778104    
#> 230: 0.300962    0.973073    3.353276    0.820377    0.020375    0.013259    0.778001    
#> 231: 0.300036    0.973330    3.353346    0.820012    0.020465    0.013301    0.777329    
#> 232: 0.298454    0.973219    3.353371    0.816400    0.020576    0.013370    0.776816    
#> 233: 0.298604    0.972834    3.353763    0.816600    0.020609    0.013573    0.776519    
#> 234: 0.298236    0.972981    3.354285    0.812202    0.020507    0.013721    0.777150    
#> 235: 0.297367    0.972931    3.354096    0.808970    0.020550    0.013816    0.776974    
#> 236: 0.296857    0.973580    3.354040    0.806434    0.020618    0.013835    0.776701    
#> 237: 0.296439    0.973415    3.354170    0.803859    0.020566    0.013881    0.776374    
#> 238: 0.296649    0.973299    3.354507    0.804955    0.020541    0.013981    0.776565    
#> 239: 0.295890    0.973238    3.354662    0.800857    0.020485    0.013976    0.776602    
#> 240: 0.295981    0.973018    3.355133    0.795188    0.020370    0.013916    0.776651    
#> 241: 0.296146    0.972437    3.355556    0.792270    0.020297    0.013896    0.776610    
#> 242: 0.295205    0.971984    3.355542    0.789290    0.020342    0.013886    0.777031    
#> 243: 0.294510    0.972232    3.355591    0.785441    0.020428    0.014006    0.777356    
#> 244: 0.294939    0.971984    3.355721    0.786870    0.020536    0.014194    0.777426    
#> 245: 0.295153    0.971782    3.355877    0.787089    0.020689    0.014270    0.777410    
#> 246: 0.295001    0.971545    3.356021    0.786984    0.020869    0.014387    0.777617    
#> 247: 0.293778    0.971427    3.356109    0.784162    0.021039    0.014298    0.777674    
#> 248: 0.292982    0.971524    3.355969    0.782091    0.021071    0.014245    0.777473    
#> 249: 0.292284    0.971389    3.356132    0.778299    0.021128    0.014212    0.777468    
#> 250: 0.293056    0.971435    3.356543    0.776522    0.021130    0.014276    0.777332    
#> 251: 0.294337    0.971388    3.357169    0.774208    0.021075    0.014317    0.777040    
#> 252: 0.294988    0.971395    3.357701    0.772867    0.021049    0.014323    0.776787    
#> 253: 0.295229    0.971574    3.358005    0.769908    0.021028    0.014342    0.776662    
#> 254: 0.295934    0.971856    3.358396    0.769299    0.020957    0.014312    0.776945    
#> 255: 0.296827    0.971968    3.358856    0.769286    0.020840    0.014336    0.777385    
#> 256: 0.297123    0.971776    3.359112    0.766092    0.020817    0.014331    0.777659    
#> 257: 0.297498    0.971281    3.359352    0.764637    0.020761    0.014323    0.777835    
#> 258: 0.296895    0.970660    3.359576    0.760266    0.020728    0.014289    0.777825    
#> 259: 0.296294    0.970212    3.359666    0.756689    0.020791    0.014276    0.777612    
#> 260: 0.296805    0.970041    3.359971    0.757476    0.020825    0.014282    0.777548    
#> 261: 0.298101    0.969805    3.360249    0.761944    0.020815    0.014250    0.777516    
#> 262: 0.298102    0.969831    3.360364    0.762060    0.020832    0.014227    0.777387    
#> 263: 0.297836    0.969861    3.360445    0.761555    0.020804    0.014209    0.777632    
#> 264: 0.297853    0.969929    3.360396    0.762449    0.020797    0.014189    0.777863    
#> 265: 0.297956    0.969879    3.360471    0.762651    0.020732    0.014197    0.778434    
#> 266: 0.298106    0.970090    3.360425    0.762822    0.020681    0.014177    0.778531    
#> 267: 0.297808    0.970337    3.360316    0.765234    0.020624    0.014181    0.778779    
#> 268: 0.297584    0.970452    3.360241    0.765152    0.020622    0.014188    0.778698    
#> 269: 0.297390    0.970347    3.360286    0.764995    0.020589    0.014196    0.778606    
#> 270: 0.297114    0.970402    3.360045    0.764190    0.020612    0.014182    0.778340    
#> 271: 0.297179    0.970354    3.359901    0.765271    0.020588    0.014182    0.778260    
#> 272: 0.296976    0.970217    3.359817    0.764573    0.020597    0.014208    0.778276    
#> 273: 0.296816    0.970315    3.359854    0.764310    0.020624    0.014210    0.778024    
#> 274: 0.296491    0.970306    3.359921    0.763731    0.020610    0.014189    0.777807    
#> 275: 0.296142    0.970407    3.359817    0.762169    0.020603    0.014192    0.777612    
#> 276: 0.296236    0.970535    3.360023    0.761338    0.020525    0.014213    0.777464    
#> 277: 0.296297    0.970698    3.360225    0.760450    0.020460    0.014237    0.777463    
#> 278: 0.296154    0.970826    3.360286    0.761240    0.020472    0.014226    0.777307    
#> 279: 0.295658    0.970653    3.360253    0.761415    0.020520    0.014232    0.777398    
#> 280: 0.295614    0.970766    3.360355    0.759254    0.020626    0.014192    0.777347    
#> 281: 0.295069    0.970786    3.360429    0.757368    0.020684    0.014157    0.777461    
#> 282: 0.294652    0.970958    3.360446    0.755518    0.020749    0.014111    0.777576    
#> 283: 0.294474    0.971059    3.360571    0.754197    0.020828    0.014107    0.777713    
#> 284: 0.294205    0.970905    3.360607    0.751918    0.020905    0.014079    0.777474    
#> 285: 0.294225    0.970895    3.360493    0.751359    0.021015    0.014095    0.777221    
#> 286: 0.294538    0.970930    3.360439    0.750539    0.021171    0.014092    0.777224    
#> 287: 0.294166    0.970972    3.360369    0.749533    0.021273    0.014112    0.777308    
#> 288: 0.294302    0.970823    3.360344    0.748208    0.021271    0.014117    0.777544    
#> 289: 0.294501    0.970710    3.360281    0.748169    0.021330    0.014119    0.777591    
#> 290: 0.294293    0.970782    3.360189    0.747794    0.021348    0.014097    0.777811    
#> 291: 0.293840    0.971058    3.360152    0.746711    0.021392    0.014078    0.777832    
#> 292: 0.293419    0.971203    3.360131    0.745172    0.021453    0.014030    0.777785    
#> 293: 0.293271    0.971431    3.360012    0.743559    0.021492    0.014028    0.777762    
#> 294: 0.292260    0.971733    3.359775    0.743100    0.021511    0.014063    0.777769    
#> 295: 0.292206    0.971692    3.359596    0.743275    0.021493    0.014075    0.777580    
#> 296: 0.292518    0.971619    3.359456    0.745473    0.021482    0.014085    0.777654    
#> 297: 0.292619    0.971675    3.359371    0.745507    0.021525    0.014089    0.777543    
#> 298: 0.293118    0.971732    3.359346    0.746402    0.021600    0.014121    0.777363    
#> 299: 0.293526    0.971779    3.359253    0.747739    0.021622    0.014108    0.777267    
#> 300: 0.293878    0.971696    3.359360    0.747973    0.021657    0.014095    0.777085    
#> 301: 0.294400    0.971465    3.359382    0.748490    0.021657    0.014047    0.777117    
#> 302: 0.294658    0.971413    3.359489    0.748082    0.021599    0.014048    0.776935    
#> 303: 0.294485    0.971525    3.359537    0.747657    0.021624    0.014037    0.776628    
#> 304: 0.294675    0.971570    3.359527    0.746844    0.021620    0.014029    0.776596    
#> 305: 0.294580    0.971444    3.359524    0.746062    0.021658    0.014009    0.776475    
#> 306: 0.294136    0.971353    3.359380    0.744852    0.021659    0.013973    0.776532    
#> 307: 0.293857    0.971222    3.359283    0.744832    0.021673    0.013940    0.776692    
#> 308: 0.293583    0.971101    3.359178    0.745157    0.021710    0.013898    0.776986    
#> 309: 0.293319    0.970916    3.359093    0.745748    0.021729    0.013846    0.777310    
#> 310: 0.294132    0.970817    3.359010    0.748853    0.021696    0.013830    0.777478    
#> 311: 0.294731    0.970774    3.358993    0.750305    0.021688    0.013827    0.777448    
#> 312: 0.294977    0.970668    3.358955    0.751087    0.021698    0.013847    0.777393    
#> 313: 0.294863    0.970534    3.358902    0.751121    0.021748    0.013861    0.777434    
#> 314: 0.294464    0.970429    3.358835    0.750096    0.021747    0.013825    0.777399    
#> 315: 0.293947    0.970447    3.358755    0.748864    0.021710    0.013799    0.777482    
#> 316: 0.293545    0.970648    3.358655    0.747473    0.021730    0.013763    0.777468    
#> 317: 0.293193    0.970801    3.358570    0.746503    0.021779    0.013734    0.777620    
#> 318: 0.293171    0.970895    3.358452    0.747130    0.021802    0.013725    0.777619    
#> 319: 0.293012    0.970860    3.358404    0.747890    0.021825    0.013722    0.777696    
#> 320: 0.292578    0.970854    3.358297    0.747836    0.021816    0.013700    0.777914    
#> 321: 0.292326    0.970923    3.358190    0.746838    0.021867    0.013694    0.778052    
#> 322: 0.292028    0.970943    3.358012    0.746290    0.021870    0.013703    0.778151    
#> 323: 0.291201    0.971048    3.357808    0.745304    0.021881    0.013704    0.778222    
#> 324: 0.290859    0.971156    3.357729    0.745041    0.021881    0.013684    0.778229    
#> 325: 0.290327    0.971327    3.357608    0.743754    0.021889    0.013671    0.778138    
#> 326: 0.289972    0.971134    3.357522    0.742559    0.021876    0.013657    0.778040    
#> 327: 0.289983    0.971159    3.357522    0.742037    0.021857    0.013634    0.777960    
#> 328: 0.289860    0.971185    3.357489    0.741279    0.021846    0.013619    0.777947    
#> 329: 0.289966    0.971183    3.357518    0.740852    0.021819    0.013616    0.777895    
#> 330: 0.289455    0.971083    3.357572    0.738761    0.021811    0.013635    0.778046    
#> 331: 0.289424    0.971157    3.357590    0.737296    0.021821    0.013658    0.778019    
#> 332: 0.289236    0.971100    3.357642    0.736060    0.021777    0.013682    0.778033    
#> 333: 0.289035    0.971079    3.357647    0.734706    0.021778    0.013675    0.778016    
#> 334: 0.288895    0.971069    3.357570    0.734319    0.021769    0.013645    0.777893    
#> 335: 0.288672    0.971054    3.357500    0.733501    0.021773    0.013622    0.777891    
#> 336: 0.288524    0.971138    3.357500    0.733305    0.021762    0.013600    0.777900    
#> 337: 0.288333    0.971350    3.357427    0.733189    0.021742    0.013580    0.777951    
#> 338: 0.287997    0.971508    3.357382    0.733051    0.021727    0.013581    0.777907    
#> 339: 0.287716    0.971591    3.357305    0.733076    0.021711    0.013589    0.777893    
#> 340: 0.287706    0.971390    3.357381    0.732875    0.021675    0.013596    0.777958    
#> 341: 0.288061    0.971227    3.357476    0.733280    0.021663    0.013611    0.777902    
#> 342: 0.287851    0.971114    3.357487    0.732860    0.021644    0.013631    0.777806    
#> 343: 0.287486    0.971127    3.357587    0.731793    0.021635    0.013623    0.777803    
#> 344: 0.287217    0.971122    3.357621    0.730603    0.021590    0.013629    0.777935    
#> 345: 0.287236    0.971113    3.357702    0.729781    0.021596    0.013635    0.777833    
#> 346: 0.287194    0.971160    3.357665    0.729025    0.021583    0.013623    0.777788    
#> 347: 0.287526    0.971111    3.357632    0.729215    0.021597    0.013627    0.777794    
#> 348: 0.287348    0.971196    3.357587    0.728746    0.021606    0.013633    0.777971    
#> 349: 0.287206    0.971166    3.357529    0.728522    0.021604    0.013655    0.777980    
#> 350: 0.287106    0.971239    3.357467    0.729170    0.021617    0.013664    0.777948    
#> 351: 0.287060    0.971442    3.357398    0.729290    0.021652    0.013674    0.777835    
#> 352: 0.286738    0.971556    3.357374    0.728664    0.021653    0.013683    0.777957    
#> 353: 0.286432    0.971765    3.357313    0.727220    0.021682    0.013686    0.778032    
#> 354: 0.286078    0.971920    3.357179    0.726547    0.021741    0.013681    0.777962    
#> 355: 0.286034    0.971863    3.357164    0.725786    0.021773    0.013690    0.777895    
#> 356: 0.286048    0.971845    3.357150    0.725135    0.021796    0.013682    0.778184    
#> 357: 0.286282    0.971825    3.357179    0.725309    0.021765    0.013683    0.778128    
#> 358: 0.286360    0.971806    3.357298    0.725463    0.021742    0.013678    0.778189    
#> 359: 0.286426    0.971766    3.357328    0.725507    0.021701    0.013705    0.778156    
#> 360: 0.286465    0.971792    3.357250    0.725398    0.021658    0.013704    0.778118    
#> 361: 0.286368    0.971835    3.357215    0.724525    0.021594    0.013709    0.778128    
#> 362: 0.286602    0.971764    3.357219    0.723944    0.021580    0.013710    0.778080    
#> 363: 0.286677    0.971642    3.357290    0.723041    0.021574    0.013713    0.778121    
#> 364: 0.286850    0.971652    3.357309    0.723113    0.021580    0.013701    0.778147    
#> 365: 0.286876    0.971707    3.357303    0.723025    0.021576    0.013699    0.778152    
#> 366: 0.286935    0.971737    3.357231    0.722838    0.021585    0.013692    0.778206    
#> 367: 0.287123    0.971749    3.357201    0.723664    0.021569    0.013685    0.778195    
#> 368: 0.287238    0.971812    3.357176    0.723812    0.021555    0.013675    0.778178    
#> 369: 0.287128    0.971817    3.357186    0.723438    0.021556    0.013695    0.778208    
#> 370: 0.286865    0.971928    3.357203    0.722561    0.021551    0.013693    0.778236    
#> 371: 0.286747    0.972016    3.357122    0.722603    0.021554    0.013677    0.778104    
#> 372: 0.286401    0.972125    3.357000    0.722948    0.021526    0.013673    0.778176    
#> 373: 0.286063    0.972288    3.356833    0.723861    0.021506    0.013686    0.778143    
#> 374: 0.286057    0.972321    3.356741    0.724505    0.021462    0.013692    0.778127    
#> 375: 0.285896    0.972378    3.356709    0.724729    0.021450    0.013689    0.778139    
#> 376: 0.285839    0.972380    3.356677    0.725400    0.021432    0.013706    0.778131    
#> 377: 0.285785    0.972339    3.356691    0.725445    0.021418    0.013705    0.778213    
#> 378: 0.285422    0.972340    3.356567    0.724999    0.021405    0.013738    0.778267    
#> 379: 0.284854    0.972231    3.356515    0.724279    0.021409    0.013763    0.778215    
#> 380: 0.284563    0.972219    3.356492    0.724221    0.021397    0.013763    0.778146    
#> 381: 0.284194    0.972213    3.356381    0.724281    0.021371    0.013766    0.778116    
#> 382: 0.284109    0.972174    3.356324    0.724554    0.021382    0.013759    0.777994    
#> 383: 0.283967    0.972112    3.356340    0.723852    0.021365    0.013746    0.777956    
#> 384: 0.283993    0.972042    3.356397    0.723218    0.021357    0.013737    0.777962    
#> 385: 0.284148    0.972020    3.356422    0.723566    0.021390    0.013724    0.777959    
#> 386: 0.284427    0.972047    3.356513    0.723757    0.021437    0.013721    0.777927    
#> 387: 0.284681    0.972046    3.356648    0.723713    0.021459    0.013713    0.777890    
#> 388: 0.284896    0.972098    3.356720    0.723480    0.021453    0.013698    0.777888    
#> 389: 0.285131    0.971938    3.356756    0.723645    0.021450    0.013681    0.778001    
#> 390: 0.284940    0.971865    3.356777    0.723015    0.021417    0.013679    0.778058    
#> 391: 0.284983    0.971784    3.356760    0.722773    0.021411    0.013663    0.778018    
#> 392: 0.285177    0.971721    3.356843    0.723258    0.021419    0.013655    0.777931    
#> 393: 0.285193    0.971635    3.356833    0.723285    0.021426    0.013642    0.777941    
#> 394: 0.285057    0.971611    3.356803    0.723057    0.021406    0.013640    0.777891    
#> 395: 0.285251    0.971674    3.356806    0.722949    0.021392    0.013644    0.777851    
#> 396: 0.285181    0.971758    3.356796    0.722906    0.021401    0.013636    0.777768    
#> 397: 0.285038    0.971735    3.356840    0.722396    0.021392    0.013615    0.777888    
#> 398: 0.285192    0.971687    3.356888    0.722429    0.021413    0.013603    0.777910    
#> 399: 0.285062    0.971768    3.356932    0.722249    0.021464    0.013603    0.777927    
#> 400: 0.285014    0.971908    3.356963    0.721923    0.021473    0.013600    0.778023    
#> 401: 0.285017    0.972012    3.356983    0.721559    0.021492    0.013601    0.778064    
#> 402: 0.284873    0.972118    3.356990    0.721038    0.021494    0.013604    0.778115    
#> 403: 0.285102    0.972148    3.357043    0.720825    0.021484    0.013610    0.778095    
#> 404: 0.285100    0.972170    3.357031    0.720350    0.021491    0.013607    0.778088    
#> 405: 0.285076    0.972224    3.357029    0.720761    0.021462    0.013618    0.778158    
#> 406: 0.285193    0.972228    3.356996    0.721340    0.021447    0.013642    0.778199    
#> 407: 0.285234    0.972294    3.357039    0.721501    0.021430    0.013669    0.778254    
#> 408: 0.285558    0.972344    3.357105    0.721324    0.021412    0.013691    0.778264    
#> 409: 0.285571    0.972291    3.357105    0.720836    0.021401    0.013698    0.778216    
#> 410: 0.285245    0.972333    3.356987    0.720150    0.021440    0.013692    0.778259    
#> 411: 0.285212    0.972223    3.356932    0.720009    0.021446    0.013692    0.778312    
#> 412: 0.285162    0.972215    3.356873    0.720004    0.021467    0.013704    0.778332    
#> 413: 0.285242    0.972220    3.356787    0.720051    0.021465    0.013711    0.778364    
#> 414: 0.285002    0.972257    3.356763    0.720016    0.021454    0.013716    0.778402    
#> 415: 0.285136    0.972270    3.356718    0.720114    0.021433    0.013711    0.778378    
#> 416: 0.285185    0.972328    3.356692    0.720066    0.021405    0.013704    0.778347    
#> 417: 0.285270    0.972288    3.356684    0.720172    0.021406    0.013701    0.778287    
#> 418: 0.285073    0.972309    3.356672    0.719437    0.021395    0.013691    0.778274    
#> 419: 0.285099    0.972357    3.356665    0.719566    0.021388    0.013695    0.778167    
#> 420: 0.285279    0.972381    3.356716    0.719343    0.021356    0.013703    0.778063    
#> 421: 0.285450    0.972396    3.356766    0.719555    0.021313    0.013695    0.778036    
#> 422: 0.285390    0.972364    3.356756    0.719356    0.021295    0.013703    0.778045    
#> 423: 0.285357    0.972318    3.356751    0.718987    0.021289    0.013724    0.778093    
#> 424: 0.285106    0.972257    3.356690    0.718893    0.021289    0.013726    0.778070    
#> 425: 0.285003    0.972291    3.356652    0.719104    0.021329    0.013718    0.778067    
#> 426: 0.285012    0.972317    3.356609    0.719370    0.021349    0.013705    0.778070    
#> 427: 0.284692    0.972312    3.356566    0.718855    0.021365    0.013683    0.778082    
#> 428: 0.284539    0.972351    3.356583    0.718034    0.021374    0.013664    0.778070    
#> 429: 0.284642    0.972361    3.356635    0.717518    0.021368    0.013657    0.778061    
#> 430: 0.284490    0.972370    3.356652    0.717136    0.021351    0.013657    0.778008    
#> 431: 0.284383    0.972412    3.356682    0.716381    0.021340    0.013647    0.777922    
#> 432: 0.284110    0.972482    3.356694    0.715507    0.021330    0.013645    0.777934    
#> 433: 0.283953    0.972562    3.356712    0.715155    0.021334    0.013635    0.777974    
#> 434: 0.283930    0.972559    3.356752    0.714780    0.021338    0.013627    0.777950    
#> 435: 0.284082    0.972543    3.356794    0.714642    0.021346    0.013613    0.777907    
#> 436: 0.284128    0.972498    3.356850    0.713935    0.021355    0.013615    0.777839    
#> 437: 0.284349    0.972473    3.356884    0.713521    0.021351    0.013620    0.777870    
#> 438: 0.284310    0.972549    3.356875    0.713373    0.021356    0.013604    0.777827    
#> 439: 0.284254    0.972595    3.356839    0.713165    0.021358    0.013604    0.777774    
#> 440: 0.284101    0.972656    3.356824    0.713093    0.021367    0.013597    0.777722    
#> 441: 0.284077    0.972675    3.356811    0.712895    0.021369    0.013592    0.777662    
#> 442: 0.283987    0.972683    3.356810    0.712471    0.021372    0.013588    0.777594    
#> 443: 0.284025    0.972722    3.356819    0.712547    0.021376    0.013584    0.777601    
#> 444: 0.284052    0.972753    3.356853    0.712629    0.021375    0.013593    0.777522    
#> 445: 0.284075    0.972685    3.356886    0.712635    0.021387    0.013591    0.777536    
#> 446: 0.284092    0.972689    3.356894    0.712151    0.021410    0.013579    0.777562    
#> 447: 0.284294    0.972731    3.356918    0.711883    0.021447    0.013573    0.777598    
#> 448: 0.284270    0.972723    3.357001    0.711480    0.021437    0.013569    0.777662    
#> 449: 0.284364    0.972745    3.357133    0.711534    0.021434    0.013565    0.777721    
#> 450: 0.284469    0.972723    3.357211    0.711582    0.021434    0.013560    0.777701    
#> 451: 0.284653    0.972744    3.357252    0.711436    0.021436    0.013564    0.777695    
#> 452: 0.284565    0.972798    3.357246    0.711092    0.021430    0.013566    0.777669    
#> 453: 0.284460    0.972864    3.357192    0.710973    0.021412    0.013561    0.777718    
#> 454: 0.284279    0.972947    3.357126    0.710451    0.021394    0.013553    0.777786    
#> 455: 0.284169    0.973022    3.357061    0.709885    0.021376    0.013560    0.777828    
#> 456: 0.284005    0.973028    3.357030    0.709193    0.021359    0.013561    0.777892    
#> 457: 0.283991    0.973017    3.357029    0.708959    0.021349    0.013565    0.777847    
#> 458: 0.283912    0.973176    3.357023    0.708553    0.021354    0.013554    0.777866    
#> 459: 0.283744    0.973326    3.356990    0.708611    0.021371    0.013553    0.777877    
#> 460: 0.283819    0.973365    3.356942    0.709235    0.021364    0.013543    0.777876    
#> 461: 0.283653    0.973445    3.356916    0.709172    0.021340    0.013537    0.777921    
#> 462: 0.283546    0.973535    3.356907    0.709222    0.021337    0.013534    0.777882    
#> 463: 0.283420    0.973567    3.356951    0.708807    0.021369    0.013541    0.777868    
#> 464: 0.283422    0.973565    3.356990    0.708443    0.021388    0.013538    0.777822    
#> 465: 0.283416    0.973468    3.357034    0.708417    0.021387    0.013523    0.777791    
#> 466: 0.283479    0.973494    3.357031    0.708032    0.021373    0.013516    0.777845    
#> 467: 0.283351    0.973500    3.357015    0.707829    0.021381    0.013501    0.777837    
#> 468: 0.283500    0.973479    3.357052    0.707649    0.021381    0.013485    0.777919    
#> 469: 0.283632    0.973521    3.357081    0.707372    0.021402    0.013471    0.778128    
#> 470: 0.283486    0.973600    3.357052    0.707494    0.021426    0.013466    0.778252    
#> 471: 0.283454    0.973602    3.357039    0.707158    0.021422    0.013456    0.778324    
#> 472: 0.283524    0.973610    3.357053    0.707082    0.021446    0.013441    0.778376    
#> 473: 0.283562    0.973671    3.357059    0.707164    0.021458    0.013442    0.778369    
#> 474: 0.283489    0.973708    3.357028    0.707300    0.021455    0.013453    0.778391    
#> 475: 0.283431    0.973802    3.357012    0.707285    0.021452    0.013458    0.778363    
#> 476: 0.283183    0.973802    3.356955    0.706926    0.021453    0.013457    0.778407    
#> 477: 0.283135    0.973804    3.356963    0.707003    0.021447    0.013454    0.778431    
#> 478: 0.283087    0.973777    3.356973    0.706948    0.021468    0.013449    0.778502    
#> 479: 0.283134    0.973816    3.356957    0.707003    0.021489    0.013443    0.778531    
#> 480: 0.283242    0.973869    3.356977    0.707165    0.021534    0.013453    0.778494    
#> 481: 0.283354    0.973887    3.356968    0.707570    0.021574    0.013445    0.778478    
#> 482: 0.283536    0.973887    3.356949    0.707851    0.021598    0.013445    0.778564    
#> 483: 0.283341    0.973911    3.356881    0.707677    0.021614    0.013438    0.778579    
#> 484: 0.283206    0.973868    3.356844    0.707869    0.021617    0.013429    0.778557    
#> 485: 0.283004    0.973923    3.356838    0.707563    0.021611    0.013424    0.778610    
#> 486: 0.283050    0.973982    3.356839    0.707960    0.021612    0.013411    0.778645    
#> 487: 0.283292    0.974019    3.356907    0.708243    0.021616    0.013412    0.778688    
#> 488: 0.283219    0.973990    3.356965    0.707961    0.021615    0.013410    0.778692    
#> 489: 0.283386    0.973922    3.357007    0.707991    0.021614    0.013406    0.778739    
#> 490: 0.283397    0.973910    3.357035    0.707873    0.021615    0.013395    0.778743    
#> 491: 0.283357    0.973948    3.357089    0.707574    0.021606    0.013399    0.778750    
#> 492: 0.283257    0.974011    3.357075    0.707547    0.021624    0.013391    0.778753    
#> 493: 0.282985    0.974003    3.357042    0.706956    0.021633    0.013385    0.778825    
#> 494: 0.282882    0.974062    3.357004    0.706232    0.021630    0.013383    0.778880    
#> 495: 0.282898    0.974168    3.357007    0.705962    0.021643    0.013375    0.778878    
#> 496: 0.283017    0.974281    3.356967    0.705896    0.021651    0.013372    0.778921    
#> 497: 0.283152    0.974273    3.356979    0.706254    0.021663    0.013376    0.778988    
#> 498: 0.283397    0.974250    3.357020    0.706835    0.021670    0.013372    0.778931    
#> 499: 0.283589    0.974252    3.357045    0.707231    0.021670    0.013366    0.778914    
#> 500: 0.283739    0.974215    3.357033    0.707496    0.021670    0.013359    0.778857    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.324624    0.972700    3.439980    0.392401    0.081888    0.016800    1.607648    
#> 002: 0.522881    0.974078    3.436015    0.372781    0.077794    0.015960    1.147551    
#> 003: 0.585535    0.899937    3.437100    0.354142    0.073904    0.015162    0.939181    
#> 004: 0.550529    0.934262    3.438588    0.336435    0.070209    0.014404    0.877898    
#> 005: 0.585857    0.964631    3.432317    0.319613    0.066698    0.013684    0.854787    
#> 006: 0.533722    0.957600    3.420001    0.303633    0.063363    0.013000    0.824843    
#> 007: 0.504806    0.975409    3.417381    0.288451    0.060195    0.012350    0.849789    
#> 008: 0.456902    0.970089    3.401070    0.274029    0.057185    0.011732    0.863653    
#> 009: 0.475630    0.957337    3.398537    0.260327    0.054326    0.011146    0.873083    
#> 010: 0.508739    0.952743    3.403420    0.247311    0.051610    0.012166    0.843125    
#> 011: 0.480114    0.966151    3.404388    0.234945    0.049029    0.012602    0.868690    
#> 012: 0.519741    0.990993    3.393828    0.223198    0.046578    0.012757    0.831195    
#> 013: 0.478946    0.975833    3.396265    0.212038    0.044249    0.013893    0.844970    
#> 014: 0.516228    0.968053    3.396467    0.201436    0.045862    0.013198    0.847831    
#> 015: 0.535267    0.971675    3.418430    0.191364    0.044775    0.012538    0.824376    
#> 016: 0.518578    0.986537    3.420761    0.181796    0.042536    0.013417    0.837451    
#> 017: 0.549875    0.966482    3.429085    0.172706    0.040410    0.014009    0.823112    
#> 018: 0.525010    0.983640    3.399199    0.164071    0.053393    0.013308    0.840108    
#> 019: 0.476413    0.988561    3.394659    0.155867    0.050723    0.012643    0.836938    
#> 020: 0.494607    0.989740    3.407799    0.148074    0.048187    0.012011    0.858987    
#> 021: 0.500761    0.982674    3.406728    0.140670    0.045777    0.011410    0.853587    
#> 022: 0.455182    0.990639    3.401703    0.133637    0.043489    0.010840    0.855969    
#> 023: 0.534198    0.984611    3.419860    0.126955    0.041314    0.010298    0.872344    
#> 024: 0.573498    0.989712    3.428715    0.120607    0.039248    0.009783    0.876700    
#> 025: 0.552907    0.961726    3.423243    0.114577    0.050055    0.009294    0.866295    
#> 026: 0.530504    0.981135    3.419553    0.108848    0.047552    0.008829    0.858089    
#> 027: 0.519945    0.988195    3.420716    0.118482    0.045174    0.008731    0.862131    
#> 028: 0.546862    0.983277    3.433129    0.112557    0.042916    0.008295    0.861922    
#> 029: 0.554376    0.963560    3.420087    0.106930    0.040770    0.007880    0.902383    
#> 030: 0.526384    0.985618    3.414548    0.101583    0.042370    0.007486    0.899573    
#> 031: 0.487380    0.976640    3.415244    0.096504    0.040252    0.007112    0.876959    
#> 032: 0.465178    0.978231    3.418488    0.091679    0.038239    0.006756    0.878335    
#> 033: 0.478521    1.003264    3.405868    0.087095    0.037992    0.006418    0.888546    
#> 034: 0.505951    1.004761    3.407384    0.082740    0.036373    0.006097    0.881993    
#> 035: 0.466066    0.993821    3.400095    0.078603    0.035317    0.005792    0.888134    
#> 036: 0.457925    0.989701    3.400445    0.074673    0.039512    0.005503    0.892968    
#> 037: 0.462626    0.998739    3.399741    0.070939    0.037536    0.005228    0.910602    
#> 038: 0.490072    0.983484    3.392071    0.072826    0.038234    0.004966    0.916373    
#> 039: 0.521618    0.971805    3.404209    0.069185    0.044350    0.004718    0.892078    
#> 040: 0.499625    0.979992    3.405079    0.065725    0.049444    0.004482    0.863364    
#> 041: 0.467779    0.950452    3.413498    0.062439    0.046972    0.004258    0.881649    
#> 042: 0.521030    0.962223    3.416364    0.067363    0.053715    0.004045    0.853818    
#> 043: 0.481983    0.991623    3.404803    0.063995    0.057055    0.004352    0.887878    
#> 044: 0.467371    1.014803    3.399464    0.060795    0.054202    0.005072    0.858733    
#> 045: 0.479988    1.032235    3.393253    0.081784    0.051492    0.005313    0.873073    
#> 046: 0.479449    1.004084    3.394801    0.080249    0.048917    0.005117    0.891743    
#> 047: 0.524367    0.995301    3.399020    0.076237    0.048374    0.004861    0.875833    
#> 048: 0.480445    0.972047    3.402382    0.072425    0.045955    0.005338    0.890242    
#> 049: 0.493474    0.962410    3.410418    0.068804    0.043657    0.005489    0.899116    
#> 050: 0.548425    0.946115    3.410842    0.072159    0.046630    0.006121    0.883516    
#> 051: 0.494827    0.986828    3.402250    0.075491    0.050022    0.005815    0.863485    
#> 052: 0.512027    1.003443    3.414311    0.071716    0.047521    0.005524    0.861772    
#> 053: 0.519250    0.984362    3.412320    0.070822    0.048117    0.005945    0.850142    
#> 054: 0.449372    0.987007    3.405770    0.067281    0.058477    0.005647    0.880869    
#> 055: 0.457097    0.968039    3.412362    0.063917    0.055553    0.005365    0.899915    
#> 056: 0.490006    0.974538    3.406919    0.060721    0.065718    0.005097    0.869115    
#> 057: 0.489924    0.969360    3.423407    0.063734    0.062432    0.005599    0.901043    
#> 058: 0.525493    0.940693    3.418313    0.060548    0.059310    0.005319    0.889095    
#> 059: 0.530139    0.933311    3.426432    0.070191    0.063389    0.005053    0.890370    
#> 060: 0.512368    0.942202    3.436196    0.066681    0.060219    0.004801    0.894383    
#> 061: 0.528458    0.942524    3.433730    0.066534    0.059415    0.005553    0.894323    
#> 062: 0.505676    0.978071    3.432833    0.063208    0.056444    0.005276    0.901796    
#> 063: 0.523874    0.959422    3.421057    0.066672    0.053622    0.005012    0.877633    
#> 064: 0.506785    1.010726    3.413295    0.063338    0.060059    0.004761    0.867528    
#> 065: 0.499459    0.978945    3.403858    0.066234    0.058087    0.004523    0.855039    
#> 066: 0.489935    1.006442    3.400599    0.066850    0.055183    0.004999    0.863891    
#> 067: 0.478973    0.997679    3.394519    0.063507    0.052424    0.005339    0.856660    
#> 068: 0.445800    1.000702    3.399791    0.061746    0.049802    0.005464    0.877015    
#> 069: 0.448237    1.005037    3.387036    0.058658    0.047312    0.005587    0.880435    
#> 070: 0.495460    0.990597    3.403012    0.064530    0.044947    0.005979    0.871455    
#> 071: 0.487541    1.011109    3.395633    0.079535    0.044089    0.007325    0.872859    
#> 072: 0.441843    0.979694    3.396431    0.075558    0.046413    0.007433    0.876512    
#> 073: 0.511015    0.983929    3.413967    0.091584    0.044092    0.008132    0.845928    
#> 074: 0.483465    0.984587    3.411545    0.087005    0.050062    0.007725    0.858232    
#> 075: 0.510626    0.962683    3.438576    0.082654    0.047559    0.007339    0.867427    
#> 076: 0.540069    0.995032    3.429238    0.078522    0.046309    0.006972    0.867832    
#> 077: 0.574730    0.966578    3.417472    0.074596    0.043994    0.006624    0.881301    
#> 078: 0.557033    0.969394    3.425126    0.076064    0.041794    0.006292    0.860312    
#> 079: 0.560890    0.981060    3.437585    0.093370    0.048940    0.006991    0.878825    
#> 080: 0.536376    0.974756    3.427676    0.089614    0.062682    0.007950    0.877178    
#> 081: 0.531038    0.986198    3.427824    0.085133    0.059548    0.007553    0.863241    
#> 082: 0.543851    0.958292    3.436635    0.080876    0.056571    0.007175    0.865294    
#> 083: 0.517885    0.965845    3.436754    0.076832    0.053742    0.006816    0.867669    
#> 084: 0.527143    0.982145    3.424307    0.072991    0.051055    0.006476    0.871168    
#> 085: 0.525108    0.974456    3.427334    0.069341    0.048502    0.006152    0.899166    
#> 086: 0.548873    0.955473    3.426159    0.065874    0.049264    0.005844    0.884889    
#> 087: 0.495633    0.959454    3.408849    0.078725    0.054036    0.005552    0.893841    
#> 088: 0.454379    0.978778    3.405537    0.074789    0.056925    0.005274    0.866490    
#> 089: 0.465673    0.991093    3.396724    0.071050    0.054079    0.005011    0.878991    
#> 090: 0.467815    0.989605    3.401141    0.067497    0.051375    0.004760    0.893445    
#> 091: 0.453057    0.989687    3.387526    0.064122    0.049565    0.004522    0.883413    
#> 092: 0.462285    0.999804    3.390720    0.061548    0.061180    0.004296    0.884728    
#> 093: 0.441101    0.977563    3.394317    0.058470    0.058121    0.004081    0.896605    
#> 094: 0.401404    1.002733    3.378262    0.055547    0.055215    0.003877    0.912847    
#> 095: 0.448283    1.001719    3.381841    0.054574    0.052455    0.003683    0.887269    
#> 096: 0.411365    1.009080    3.381943    0.061518    0.051913    0.004056    0.897205    
#> 097: 0.450847    1.022369    3.386048    0.058442    0.052098    0.003853    0.880773    
#> 098: 0.448742    1.024078    3.393713    0.055520    0.049493    0.003660    0.916234    
#> 099: 0.442316    1.007673    3.383631    0.052744    0.047018    0.003906    0.903423    
#> 100: 0.434652    0.990739    3.381379    0.063959    0.044668    0.004408    0.866678    
#> 101: 0.416641    0.988463    3.384746    0.060761    0.042434    0.004188    0.861313    
#> 102: 0.402551    1.006605    3.374295    0.057723    0.055727    0.003978    0.862398    
#> 103: 0.428235    1.003878    3.382603    0.054837    0.052941    0.003779    0.882681    
#> 104: 0.467567    1.005564    3.390412    0.052095    0.058880    0.003590    0.885360    
#> 105: 0.443893    1.003234    3.390754    0.049490    0.058055    0.003411    0.904832    
#> 106: 0.462360    0.986723    3.386803    0.052306    0.057624    0.003240    0.884573    
#> 107: 0.484837    1.003287    3.393222    0.061362    0.058290    0.003078    0.895333    
#> 108: 0.478928    0.990990    3.390769    0.065836    0.062249    0.002924    0.880570    
#> 109: 0.465786    0.980089    3.407056    0.062544    0.059137    0.002778    0.892790    
#> 110: 0.444242    0.986891    3.397734    0.059417    0.060984    0.002639    0.890639    
#> 111: 0.445187    0.989039    3.394232    0.056446    0.057934    0.002507    0.899711    
#> 112: 0.433828    0.969496    3.390487    0.054503    0.055038    0.002382    0.910213    
#> 113: 0.441303    1.009729    3.387151    0.051778    0.052286    0.002263    0.892675    
#> 114: 0.426902    1.002211    3.390984    0.049189    0.049671    0.002150    0.928356    
#> 115: 0.457626    0.999415    3.383085    0.050409    0.055884    0.002042    0.953010    
#> 116: 0.412188    1.028911    3.389132    0.047888    0.056536    0.002102    0.950984    
#> 117: 0.417922    1.027074    3.391885    0.048408    0.059830    0.001997    0.920312    
#> 118: 0.435876    0.992250    3.396586    0.045987    0.056838    0.001897    0.903685    
#> 119: 0.434386    0.980706    3.395925    0.044527    0.053996    0.002010    0.903891    
#> 120: 0.457699    0.985621    3.395491    0.042301    0.053754    0.001909    0.889874    
#> 121: 0.471056    1.014305    3.394357    0.040516    0.051066    0.002388    0.897246    
#> 122: 0.466973    0.999596    3.396051    0.038490    0.075974    0.002268    0.896422    
#> 123: 0.513766    1.012651    3.402266    0.036565    0.072176    0.002155    0.893614    
#> 124: 0.525848    1.019829    3.404952    0.036257    0.073007    0.002047    0.879158    
#> 125: 0.523622    0.977077    3.409415    0.039253    0.069357    0.002098    0.885155    
#> 126: 0.494278    0.992764    3.401001    0.054129    0.065889    0.002098    0.871035    
#> 127: 0.480957    0.979459    3.396177    0.051423    0.062594    0.002289    0.877280    
#> 128: 0.485600    1.004266    3.406259    0.048852    0.059465    0.002963    0.910360    
#> 129: 0.505663    1.005971    3.405983    0.053490    0.067901    0.002961    0.908320    
#> 130: 0.531839    0.995354    3.407335    0.050815    0.064506    0.002827    0.873981    
#> 131: 0.475798    0.971714    3.400179    0.048275    0.061281    0.003061    0.891021    
#> 132: 0.447783    0.972956    3.392482    0.045861    0.058217    0.002908    0.909037    
#> 133: 0.459455    0.998373    3.392182    0.046325    0.055610    0.002763    0.875123    
#> 134: 0.476915    0.965951    3.397416    0.057916    0.063619    0.002625    0.891009    
#> 135: 0.451615    0.981865    3.397870    0.055021    0.063016    0.002494    0.911135    
#> 136: 0.439094    0.969392    3.391781    0.052270    0.064177    0.002369    0.880416    
#> 137: 0.475963    0.997623    3.395639    0.049656    0.060969    0.002250    0.900460    
#> 138: 0.473481    0.998424    3.394485    0.047173    0.057920    0.002138    0.894777    
#> 139: 0.465672    1.025106    3.399929    0.044815    0.055024    0.002394    0.892152    
#> 140: 0.485396    1.028435    3.404217    0.043330    0.053063    0.002739    0.887442    
#> 141: 0.480148    0.992277    3.413196    0.045846    0.063016    0.003375    0.874589    
#> 142: 0.487424    0.966749    3.411907    0.053820    0.066129    0.003489    0.872976    
#> 143: 0.474983    0.991701    3.417364    0.057562    0.062823    0.003388    0.877185    
#> 144: 0.526715    0.988597    3.422663    0.054684    0.059682    0.003219    0.857751    
#> 145: 0.500626    0.994290    3.414145    0.051950    0.056698    0.003058    0.877493    
#> 146: 0.488475    0.982766    3.419402    0.051040    0.053863    0.002905    0.874672    
#> 147: 0.467550    0.964243    3.419685    0.048488    0.051170    0.002760    0.865183    
#> 148: 0.500320    0.980221    3.419692    0.046064    0.048611    0.002622    0.899944    
#> 149: 0.491636    0.990657    3.414945    0.045342    0.058993    0.002491    0.893333    
#> 150: 0.495303    0.996246    3.411335    0.047180    0.064119    0.002366    0.881295    
#> 151: 0.490047    1.013245    3.405934    0.062775    0.060913    0.002248    0.890018    
#> 152: 0.498678    0.993514    3.404778    0.067007    0.054921    0.002699    0.886881    
#> 153: 0.491245    1.019690    3.403093    0.063598    0.059911    0.001727    0.899268    
#> 154: 0.501696    0.998629    3.409024    0.042608    0.062186    0.001542    0.895715    
#> 155: 0.482635    0.970772    3.405103    0.033089    0.059761    0.001021    0.890204    
#> 156: 0.471860    0.995950    3.410902    0.032019    0.070462    0.000852    0.901952    
#> 157: 0.463962    0.993209    3.413080    0.033410    0.070538    0.000778    0.898973    
#> 158: 0.489818    0.998094    3.414568    0.034598    0.080855    0.000700    0.888221    
#> 159: 0.479882    0.987914    3.413294    0.027011    0.062726    0.000553    0.897890    
#> 160: 0.513808    0.962854    3.415464    0.034809    0.068902    0.000512    0.888564    
#> 161: 0.502048    0.987752    3.414611    0.035576    0.078160    0.000612    0.901544    
#> 162: 0.477003    0.995731    3.402824    0.029558    0.068178    0.000528    0.919873    
#> 163: 0.493655    0.986769    3.403005    0.027080    0.075201    0.000434    0.912746    
#> 164: 0.519492    0.984016    3.403922    0.024995    0.075966    0.000473    0.897251    
#> 165: 0.523059    0.970885    3.411131    0.027795    0.062265    0.000510    0.916090    
#> 166: 0.494954    1.012008    3.409361    0.037392    0.070659    0.000385    0.898849    
#> 167: 0.504667    0.997138    3.409488    0.045570    0.069029    0.000485    0.886344    
#> 168: 0.517941    0.997029    3.413569    0.041939    0.061030    0.000436    0.902062    
#> 169: 0.524028    1.043225    3.406995    0.050547    0.063622    0.000303    0.917667    
#> 170: 0.503424    0.995943    3.407531    0.043914    0.066449    0.000256    0.894731    
#> 171: 0.476272    0.983527    3.408572    0.038148    0.072759    0.000241    0.891655    
#> 172: 0.467060    1.000661    3.405788    0.030119    0.053208    0.000216    0.909084    
#> 173: 0.480396    1.011082    3.404766    0.036543    0.062126    0.000286    0.889504    
#> 174: 0.481782    0.987066    3.402637    0.038952    0.076856    0.000360    0.901366    
#> 175: 0.477795    0.995958    3.400333    0.046706    0.067702    0.000285    0.895814    
#> 176: 0.486471    1.010869    3.400844    0.025280    0.068017    0.000268    0.917405    
#> 177: 0.488164    1.005370    3.404626    0.018455    0.066366    0.000245    0.897590    
#> 178: 0.472098    1.001739    3.404226    0.015842    0.055160    0.000247    0.910594    
#> 179: 0.491803    1.009306    3.407965    0.019329    0.065755    0.000234    0.914668    
#> 180: 0.504030    1.010622    3.407163    0.017007    0.055674    0.000231    0.914674    
#> 181: 0.490250    0.995622    3.403007    0.017619    0.056726    0.000185    0.921570    
#> 182: 0.464783    0.992695    3.404088    0.028661    0.066804    0.000203    0.906883    
#> 183: 0.439936    1.009551    3.403241    0.025381    0.066607    0.000196    0.917079    
#> 184: 0.462867    0.998128    3.402583    0.015821    0.063494    0.000210    0.907818    
#> 185: 0.477601    0.999207    3.399050    0.016073    0.076621    0.000223    0.910228    
#> 186: 0.475575    1.010581    3.402184    0.019556    0.051638    0.000317    0.911401    
#> 187: 0.428673    0.990263    3.404076    0.023638    0.062954    0.000359    0.912991    
#> 188: 0.435099    0.999064    3.397443    0.020918    0.066003    0.000467    0.924793    
#> 189: 0.470071    1.008563    3.401523    0.014189    0.061377    0.000363    0.933263    
#> 190: 0.469614    0.993153    3.407010    0.011904    0.060538    0.000295    0.937070    
#> 191: 0.462476    0.984892    3.406755    0.008288    0.073455    0.000209    0.928703    
#> 192: 0.467325    0.996281    3.405815    0.008644    0.068765    0.000301    0.925778    
#> 193: 0.473019    1.003384    3.404243    0.009163    0.063606    0.000228    0.925188    
#> 194: 0.467213    0.980277    3.402726    0.009245    0.065063    0.000312    0.935038    
#> 195: 0.454213    0.977447    3.400241    0.010938    0.047722    0.000326    0.937608    
#> 196: 0.447347    0.990661    3.402424    0.011266    0.054402    0.000270    0.927879    
#> 197: 0.450870    1.017551    3.407643    0.014351    0.058310    0.000364    0.924905    
#> 198: 0.475399    0.980497    3.402920    0.013113    0.062752    0.000403    0.906503    
#> 199: 0.462323    0.974811    3.404390    0.017167    0.060856    0.000377    0.916583    
#> 200: 0.451107    0.989384    3.399800    0.016950    0.066780    0.000409    0.918468    
#> 201: 0.458654    0.985553    3.400995    0.015448    0.068419    0.000521    0.902140    
#> 202: 0.471214    0.985231    3.400652    0.016583    0.065567    0.000589    0.904710    
#> 203: 0.474991    0.980935    3.401632    0.019036    0.061136    0.000627    0.901533    
#> 204: 0.480602    0.976711    3.402430    0.018995    0.058715    0.000600    0.904172    
#> 205: 0.483201    0.982526    3.402829    0.018956    0.059490    0.000582    0.906705    
#> 206: 0.483645    0.985990    3.404159    0.019083    0.059655    0.000580    0.909164    
#> 207: 0.482171    0.984335    3.403727    0.018675    0.061250    0.000577    0.911565    
#> 208: 0.481561    0.983106    3.403436    0.018506    0.060539    0.000560    0.913602    
#> 209: 0.480841    0.981958    3.403273    0.018552    0.060269    0.000545    0.914178    
#> 210: 0.483237    0.982648    3.403350    0.018653    0.059756    0.000536    0.913173    
#> 211: 0.482190    0.984271    3.403416    0.018754    0.059529    0.000520    0.913098    
#> 212: 0.482548    0.984617    3.403705    0.018709    0.059667    0.000521    0.912429    
#> 213: 0.484409    0.981797    3.403666    0.018333    0.060561    0.000524    0.914385    
#> 214: 0.486154    0.982893    3.403561    0.018235    0.061769    0.000527    0.914423    
#> 215: 0.486828    0.983369    3.403748    0.018028    0.061916    0.000533    0.914921    
#> 216: 0.488144    0.982095    3.403813    0.018160    0.062845    0.000537    0.916487    
#> 217: 0.488042    0.983954    3.403498    0.018410    0.062753    0.000565    0.916014    
#> 218: 0.488444    0.985201    3.403206    0.018441    0.062782    0.000566    0.916360    
#> 219: 0.488985    0.984532    3.403074    0.018578    0.063097    0.000568    0.915734    
#> 220: 0.488806    0.985053    3.403045    0.018515    0.063315    0.000561    0.915751    
#> 221: 0.488294    0.985053    3.403062    0.018395    0.063437    0.000555    0.916442    
#> 222: 0.487408    0.985774    3.403152    0.018340    0.063780    0.000549    0.916071    
#> 223: 0.488322    0.985991    3.403307    0.018391    0.063577    0.000542    0.915311    
#> 224: 0.489201    0.986894    3.403538    0.018379    0.063060    0.000537    0.915695    
#> 225: 0.489304    0.985623    3.403752    0.018422    0.062998    0.000532    0.915634    
#> 226: 0.489751    0.984634    3.403711    0.018528    0.062960    0.000525    0.915019    
#> 227: 0.489109    0.984393    3.403796    0.018518    0.062484    0.000517    0.914614    
#> 228: 0.488462    0.985577    3.403632    0.018641    0.062603    0.000516    0.914071    
#> 229: 0.487788    0.985054    3.403664    0.018657    0.062272    0.000512    0.913889    
#> 230: 0.486881    0.984334    3.403639    0.018717    0.062032    0.000509    0.914040    
#> 231: 0.487181    0.984657    3.403694    0.018794    0.061666    0.000508    0.914561    
#> 232: 0.486890    0.984532    3.403895    0.018861    0.061636    0.000511    0.914839    
#> 233: 0.487254    0.983709    3.404103    0.018942    0.061819    0.000515    0.914481    
#> 234: 0.486443    0.984489    3.404189    0.019038    0.061950    0.000517    0.914565    
#> 235: 0.486477    0.984259    3.404178    0.019181    0.061884    0.000510    0.914618    
#> 236: 0.486609    0.984570    3.404151    0.019389    0.061914    0.000503    0.914432    
#> 237: 0.486845    0.984295    3.404137    0.019352    0.062027    0.000500    0.914843    
#> 238: 0.486762    0.984652    3.404128    0.019275    0.062302    0.000496    0.915371    
#> 239: 0.486859    0.985019    3.404178    0.019306    0.062188    0.000495    0.915387    
#> 240: 0.486972    0.984819    3.404144    0.019404    0.062225    0.000491    0.915093    
#> 241: 0.486858    0.984321    3.404172    0.019428    0.062003    0.000488    0.915236    
#> 242: 0.486990    0.984221    3.404091    0.019538    0.061998    0.000488    0.915727    
#> 243: 0.486439    0.984403    3.404093    0.019625    0.062272    0.000492    0.915875    
#> 244: 0.485456    0.984273    3.404097    0.019695    0.062363    0.000493    0.915781    
#> 245: 0.485499    0.983917    3.404117    0.019870    0.062123    0.000495    0.915881    
#> 246: 0.485628    0.983670    3.404267    0.019907    0.061967    0.000497    0.915797    
#> 247: 0.485476    0.983276    3.404407    0.020013    0.061871    0.000497    0.915863    
#> 248: 0.485756    0.983262    3.404484    0.020086    0.062107    0.000496    0.915720    
#> 249: 0.485793    0.983281    3.404601    0.020087    0.062018    0.000495    0.915798    
#> 250: 0.486125    0.983656    3.404710    0.020239    0.061829    0.000498    0.915640    
#> 251: 0.486083    0.984147    3.404784    0.020148    0.061911    0.000500    0.915786    
#> 252: 0.486046    0.984536    3.404800    0.020143    0.061660    0.000500    0.915816    
#> 253: 0.485864    0.984994    3.404810    0.020108    0.061525    0.000499    0.915711    
#> 254: 0.485405    0.985427    3.404873    0.020079    0.061330    0.000498    0.915465    
#> 255: 0.485246    0.986034    3.404977    0.019991    0.061453    0.000498    0.915491    
#> 256: 0.485274    0.985922    3.404986    0.020011    0.061648    0.000498    0.915136    
#> 257: 0.485103    0.985628    3.405040    0.020052    0.061615    0.000497    0.914847    
#> 258: 0.485512    0.985304    3.405011    0.020022    0.061581    0.000496    0.914921    
#> 259: 0.485554    0.985231    3.404954    0.019940    0.061420    0.000495    0.915309    
#> 260: 0.485471    0.985323    3.404949    0.019974    0.061389    0.000498    0.915093    
#> 261: 0.485579    0.985327    3.404998    0.019993    0.061469    0.000502    0.914749    
#> 262: 0.485777    0.985424    3.404956    0.020070    0.061654    0.000505    0.914299    
#> 263: 0.485772    0.985943    3.404870    0.020045    0.061645    0.000505    0.914069    
#> 264: 0.485978    0.985913    3.404801    0.020080    0.061795    0.000505    0.914126    
#> 265: 0.486107    0.986119    3.404802    0.020150    0.061844    0.000508    0.914036    
#> 266: 0.486133    0.986844    3.404749    0.020265    0.061738    0.000509    0.913714    
#> 267: 0.485978    0.987204    3.404774    0.020261    0.061632    0.000509    0.913507    
#> 268: 0.485612    0.986867    3.404711    0.020369    0.061694    0.000508    0.913330    
#> 269: 0.485492    0.986772    3.404654    0.020445    0.061675    0.000510    0.913251    
#> 270: 0.485744    0.987044    3.404517    0.020501    0.061746    0.000510    0.913180    
#> 271: 0.485835    0.987059    3.404455    0.020528    0.061830    0.000510    0.912960    
#> 272: 0.485974    0.987000    3.404389    0.020467    0.061882    0.000511    0.913094    
#> 273: 0.485921    0.987564    3.404347    0.020469    0.061931    0.000512    0.913275    
#> 274: 0.485525    0.987829    3.404363    0.020559    0.062022    0.000512    0.913204    
#> 275: 0.485654    0.987792    3.404316    0.020567    0.061906    0.000511    0.913510    
#> 276: 0.485546    0.987545    3.404336    0.020680    0.061903    0.000513    0.913421    
#> 277: 0.485233    0.987791    3.404369    0.020704    0.061877    0.000512    0.913405    
#> 278: 0.485016    0.987891    3.404371    0.020634    0.061748    0.000512    0.913612    
#> 279: 0.484765    0.988116    3.404349    0.020582    0.061840    0.000512    0.913770    
#> 280: 0.484917    0.988499    3.404371    0.020574    0.061817    0.000511    0.913815    
#> 281: 0.484880    0.988768    3.404334    0.020628    0.061739    0.000513    0.913829    
#> 282: 0.485028    0.988859    3.404347    0.020653    0.061780    0.000514    0.914003    
#> 283: 0.485162    0.989124    3.404344    0.020601    0.061902    0.000515    0.914212    
#> 284: 0.485023    0.988858    3.404347    0.020511    0.061960    0.000516    0.914169    
#> 285: 0.485043    0.988635    3.404310    0.020461    0.061990    0.000515    0.914310    
#> 286: 0.485070    0.988952    3.404278    0.020430    0.061820    0.000515    0.914716    
#> 287: 0.485230    0.989037    3.404240    0.020470    0.061915    0.000515    0.914620    
#> 288: 0.485300    0.989225    3.404200    0.020559    0.061777    0.000515    0.914591    
#> 289: 0.485497    0.989022    3.404117    0.020638    0.061782    0.000516    0.914601    
#> 290: 0.485464    0.989143    3.404057    0.020718    0.061979    0.000517    0.914420    
#> 291: 0.485671    0.989364    3.404044    0.020788    0.062033    0.000518    0.914188    
#> 292: 0.485710    0.989406    3.404009    0.020863    0.062011    0.000519    0.914091    
#> 293: 0.485637    0.989580    3.403971    0.020915    0.061998    0.000521    0.913895    
#> 294: 0.485381    0.989861    3.403892    0.020947    0.061895    0.000523    0.913881    
#> 295: 0.485185    0.989578    3.403830    0.021008    0.061961    0.000522    0.913880    
#> 296: 0.485133    0.989556    3.403890    0.021063    0.062110    0.000522    0.913851    
#> 297: 0.484984    0.989572    3.403910    0.021056    0.062082    0.000524    0.913965    
#> 298: 0.485100    0.989649    3.403927    0.021111    0.062031    0.000525    0.913791    
#> 299: 0.484994    0.989762    3.403936    0.021120    0.062005    0.000524    0.913746    
#> 300: 0.484796    0.989690    3.403977    0.021124    0.061914    0.000523    0.913713    
#> 301: 0.484663    0.989420    3.403974    0.021159    0.061893    0.000523    0.913566    
#> 302: 0.484546    0.989470    3.403932    0.021223    0.061808    0.000524    0.913442    
#> 303: 0.484237    0.989619    3.403908    0.021218    0.061845    0.000523    0.913267    
#> 304: 0.484067    0.989815    3.403906    0.021244    0.061836    0.000523    0.913185    
#> 305: 0.483977    0.989573    3.403943    0.021247    0.061787    0.000524    0.913341    
#> 306: 0.483755    0.989648    3.403916    0.021224    0.061617    0.000524    0.913443    
#> 307: 0.483714    0.989547    3.403862    0.021244    0.061550    0.000523    0.913498    
#> 308: 0.483591    0.989484    3.403852    0.021205    0.061467    0.000523    0.913690    
#> 309: 0.483726    0.989256    3.403833    0.021127    0.061504    0.000522    0.913948    
#> 310: 0.483866    0.989277    3.403787    0.021114    0.061456    0.000522    0.913958    
#> 311: 0.484079    0.989415    3.403780    0.021113    0.061449    0.000522    0.913851    
#> 312: 0.483967    0.989351    3.403748    0.021133    0.061387    0.000522    0.913764    
#> 313: 0.483797    0.989266    3.403732    0.021158    0.061290    0.000522    0.913863    
#> 314: 0.483660    0.989349    3.403673    0.021200    0.061238    0.000521    0.913626    
#> 315: 0.483322    0.989544    3.403658    0.021262    0.061265    0.000521    0.913573    
#> 316: 0.483143    0.989585    3.403676    0.021269    0.061374    0.000520    0.913602    
#> 317: 0.482925    0.989587    3.403691    0.021349    0.061416    0.000519    0.913633    
#> 318: 0.483054    0.989605    3.403687    0.021373    0.061447    0.000518    0.913688    
#> 319: 0.483212    0.989535    3.403687    0.021395    0.061438    0.000517    0.913592    
#> 320: 0.483114    0.989668    3.403647    0.021460    0.061670    0.000517    0.913468    
#> 321: 0.482822    0.989792    3.403592    0.021431    0.061652    0.000516    0.913675    
#> 322: 0.482781    0.989816    3.403528    0.021415    0.061711    0.000515    0.913714    
#> 323: 0.482582    0.989866    3.403499    0.021425    0.061729    0.000515    0.913835    
#> 324: 0.482448    0.990096    3.403518    0.021421    0.061780    0.000514    0.913710    
#> 325: 0.482382    0.990303    3.403515    0.021398    0.061741    0.000513    0.913814    
#> 326: 0.482375    0.990157    3.403473    0.021382    0.061663    0.000511    0.913978    
#> 327: 0.482062    0.990308    3.403440    0.021442    0.061665    0.000509    0.913986    
#> 328: 0.481991    0.990555    3.403426    0.021429    0.061720    0.000509    0.913958    
#> 329: 0.482012    0.990435    3.403453    0.021452    0.061762    0.000509    0.914198    
#> 330: 0.481604    0.990470    3.403478    0.021432    0.061772    0.000509    0.914486    
#> 331: 0.481614    0.990662    3.403452    0.021404    0.061850    0.000508    0.914557    
#> 332: 0.481674    0.990538    3.403457    0.021403    0.061894    0.000508    0.914567    
#> 333: 0.481783    0.990533    3.403397    0.021410    0.061798    0.000509    0.914558    
#> 334: 0.481755    0.990521    3.403369    0.021397    0.061731    0.000508    0.914400    
#> 335: 0.481634    0.990506    3.403325    0.021441    0.061655    0.000507    0.914272    
#> 336: 0.481416    0.990596    3.403291    0.021504    0.061562    0.000507    0.914248    
#> 337: 0.481214    0.990877    3.403256    0.021530    0.061683    0.000507    0.914107    
#> 338: 0.481080    0.990989    3.403250    0.021532    0.061777    0.000507    0.913979    
#> 339: 0.481091    0.991135    3.403214    0.021558    0.061875    0.000507    0.913812    
#> 340: 0.481024    0.991035    3.403203    0.021588    0.062102    0.000506    0.913847    
#> 341: 0.480918    0.991006    3.403183    0.021607    0.062235    0.000505    0.913778    
#> 342: 0.480956    0.990928    3.403181    0.021588    0.062250    0.000506    0.913683    
#> 343: 0.480888    0.990826    3.403208    0.021559    0.062193    0.000506    0.913638    
#> 344: 0.481075    0.990818    3.403267    0.021550    0.062267    0.000508    0.913602    
#> 345: 0.481308    0.990837    3.403283    0.021552    0.062321    0.000508    0.913550    
#> 346: 0.481408    0.990991    3.403288    0.021558    0.062343    0.000507    0.913558    
#> 347: 0.481476    0.990845    3.403244    0.021587    0.062365    0.000508    0.913506    
#> 348: 0.481336    0.990978    3.403230    0.021589    0.062413    0.000508    0.913475    
#> 349: 0.481376    0.991049    3.403205    0.021580    0.062370    0.000509    0.913553    
#> 350: 0.481362    0.990917    3.403178    0.021611    0.062382    0.000510    0.913547    
#> 351: 0.481153    0.991142    3.403138    0.021605    0.062423    0.000511    0.913398    
#> 352: 0.481018    0.991243    3.403122    0.021567    0.062440    0.000511    0.913350    
#> 353: 0.481228    0.991418    3.403140    0.021583    0.062474    0.000512    0.913283    
#> 354: 0.481368    0.991407    3.403136    0.021616    0.062402    0.000512    0.913170    
#> 355: 0.481388    0.991198    3.403135    0.021605    0.062453    0.000513    0.913215    
#> 356: 0.481345    0.991076    3.403156    0.021637    0.062546    0.000513    0.913267    
#> 357: 0.481366    0.991183    3.403160    0.021656    0.062531    0.000511    0.913217    
#> 358: 0.481368    0.991188    3.403163    0.021653    0.062555    0.000511    0.913146    
#> 359: 0.481317    0.991336    3.403174    0.021652    0.062587    0.000511    0.913254    
#> 360: 0.481314    0.991393    3.403133    0.021643    0.062583    0.000510    0.913199    
#> 361: 0.481133    0.991292    3.403097    0.021602    0.062502    0.000509    0.913270    
#> 362: 0.481008    0.991203    3.403077    0.021571    0.062464    0.000508    0.913396    
#> 363: 0.480882    0.991117    3.403061    0.021563    0.062489    0.000507    0.913434    
#> 364: 0.480937    0.991185    3.403036    0.021594    0.062517    0.000507    0.913358    
#> 365: 0.480900    0.991165    3.403047    0.021599    0.062582    0.000506    0.913361    
#> 366: 0.480990    0.991068    3.403039    0.021621    0.062576    0.000506    0.913292    
#> 367: 0.481035    0.991007    3.403048    0.021609    0.062494    0.000505    0.913400    
#> 368: 0.481034    0.991093    3.403051    0.021602    0.062532    0.000504    0.913431    
#> 369: 0.480986    0.991087    3.403060    0.021604    0.062544    0.000504    0.913433    
#> 370: 0.480986    0.991104    3.403084    0.021646    0.062546    0.000504    0.913476    
#> 371: 0.480956    0.991111    3.403069    0.021643    0.062587    0.000504    0.913428    
#> 372: 0.480850    0.991158    3.403038    0.021673    0.062707    0.000504    0.913333    
#> 373: 0.480726    0.991231    3.403000    0.021677    0.062697    0.000503    0.913343    
#> 374: 0.480703    0.991224    3.402971    0.021679    0.062623    0.000503    0.913336    
#> 375: 0.480647    0.991308    3.402947    0.021654    0.062539    0.000502    0.913409    
#> 376: 0.480587    0.991361    3.402954    0.021673    0.062420    0.000502    0.913406    
#> 377: 0.480690    0.991427    3.402957    0.021688    0.062472    0.000502    0.913321    
#> 378: 0.480571    0.991450    3.402936    0.021665    0.062564    0.000503    0.913311    
#> 379: 0.480616    0.991313    3.402965    0.021655    0.062520    0.000504    0.913304    
#> 380: 0.480587    0.991250    3.402959    0.021651    0.062543    0.000504    0.913202    
#> 381: 0.480619    0.991233    3.402957    0.021649    0.062541    0.000503    0.913257    
#> 382: 0.480671    0.991134    3.402956    0.021642    0.062556    0.000503    0.913375    
#> 383: 0.480770    0.990992    3.402969    0.021617    0.062621    0.000503    0.913355    
#> 384: 0.480735    0.990859    3.402967    0.021630    0.062655    0.000502    0.913198    
#> 385: 0.480675    0.990911    3.402966    0.021659    0.062643    0.000502    0.913238    
#> 386: 0.480767    0.991196    3.402972    0.021618    0.062666    0.000502    0.913385    
#> 387: 0.480779    0.991208    3.402987    0.021611    0.062621    0.000501    0.913343    
#> 388: 0.480726    0.991303    3.402976    0.021613    0.062559    0.000501    0.913425    
#> 389: 0.480748    0.991248    3.402972    0.021639    0.062567    0.000500    0.913492    
#> 390: 0.480676    0.991308    3.402957    0.021645    0.062614    0.000500    0.913555    
#> 391: 0.480600    0.991314    3.402934    0.021649    0.062629    0.000499    0.913571    
#> 392: 0.480479    0.991427    3.402938    0.021664    0.062672    0.000499    0.913610    
#> 393: 0.480405    0.991380    3.402937    0.021684    0.062735    0.000500    0.913637    
#> 394: 0.480374    0.991310    3.402936    0.021681    0.062741    0.000500    0.913609    
#> 395: 0.480477    0.991331    3.402942    0.021657    0.062773    0.000501    0.913591    
#> 396: 0.480554    0.991410    3.402942    0.021662    0.062812    0.000500    0.913549    
#> 397: 0.480619    0.991368    3.402955    0.021708    0.062805    0.000500    0.913487    
#> 398: 0.480763    0.991258    3.402977    0.021733    0.062809    0.000499    0.913540    
#> 399: 0.480786    0.991259    3.402989    0.021725    0.062815    0.000500    0.913682    
#> 400: 0.480747    0.991339    3.402996    0.021751    0.062808    0.000501    0.913648    
#> 401: 0.480647    0.991416    3.402991    0.021742    0.062845    0.000501    0.913627    
#> 402: 0.480577    0.991454    3.403000    0.021720    0.062959    0.000500    0.913610    
#> 403: 0.480675    0.991519    3.403015    0.021749    0.063028    0.000501    0.913573    
#> 404: 0.480810    0.991540    3.403018    0.021784    0.063074    0.000500    0.913528    
#> 405: 0.480804    0.991470    3.403031    0.021773    0.063075    0.000501    0.913579    
#> 406: 0.480805    0.991502    3.403029    0.021760    0.063068    0.000502    0.913583    
#> 407: 0.480811    0.991457    3.403053    0.021750    0.063129    0.000502    0.913558    
#> 408: 0.480802    0.991552    3.403090    0.021775    0.063220    0.000501    0.913579    
#> 409: 0.480761    0.991538    3.403068    0.021790    0.063206    0.000500    0.913592    
#> 410: 0.480692    0.991597    3.403041    0.021804    0.063217    0.000499    0.913591    
#> 411: 0.480632    0.991411    3.403019    0.021833    0.063171    0.000499    0.913638    
#> 412: 0.480589    0.991445    3.402992    0.021865    0.063138    0.000499    0.913617    
#> 413: 0.480515    0.991455    3.402958    0.021903    0.063135    0.000498    0.913574    
#> 414: 0.480460    0.991472    3.402943    0.021955    0.063207    0.000498    0.913474    
#> 415: 0.480560    0.991442    3.402954    0.021968    0.063207    0.000499    0.913412    
#> 416: 0.480695    0.991475    3.402953    0.021944    0.063169    0.000498    0.913454    
#> 417: 0.480905    0.991441    3.402960    0.021944    0.063180    0.000498    0.913473    
#> 418: 0.480858    0.991370    3.402945    0.021929    0.063212    0.000497    0.913505    
#> 419: 0.480755    0.991475    3.402931    0.021926    0.063155    0.000496    0.913601    
#> 420: 0.480829    0.991442    3.402941    0.021922    0.063146    0.000496    0.913558    
#> 421: 0.480806    0.991437    3.402945    0.021902    0.063124    0.000496    0.913546    
#> 422: 0.480779    0.991351    3.402945    0.021927    0.063086    0.000496    0.913548    
#> 423: 0.480805    0.991373    3.402940    0.021920    0.063149    0.000495    0.913506    
#> 424: 0.480712    0.991297    3.402908    0.021891    0.063107    0.000495    0.913628    
#> 425: 0.480893    0.991316    3.402895    0.021922    0.063026    0.000495    0.913761    
#> 426: 0.480871    0.991441    3.402901    0.021911    0.063003    0.000495    0.913827    
#> 427: 0.480843    0.991512    3.402899    0.021899    0.063026    0.000494    0.913802    
#> 428: 0.480658    0.991625    3.402888    0.021925    0.063045    0.000494    0.913670    
#> 429: 0.480554    0.991603    3.402904    0.021936    0.063022    0.000493    0.913660    
#> 430: 0.480546    0.991627    3.402892    0.021986    0.063016    0.000493    0.913548    
#> 431: 0.480466    0.991651    3.402887    0.022024    0.062999    0.000493    0.913516    
#> 432: 0.480442    0.991815    3.402880    0.022013    0.062994    0.000493    0.913533    
#> 433: 0.480443    0.991986    3.402875    0.022002    0.062994    0.000494    0.913498    
#> 434: 0.480392    0.992001    3.402892    0.022025    0.063034    0.000494    0.913453    
#> 435: 0.480415    0.991965    3.402909    0.022037    0.063020    0.000494    0.913444    
#> 436: 0.480270    0.991940    3.402925    0.022028    0.063019    0.000494    0.913530    
#> 437: 0.480270    0.991902    3.402916    0.022030    0.063023    0.000494    0.913571    
#> 438: 0.480240    0.991948    3.402903    0.022015    0.062984    0.000494    0.913623    
#> 439: 0.480203    0.992024    3.402891    0.022014    0.062935    0.000493    0.913596    
#> 440: 0.480114    0.992064    3.402889    0.022002    0.062876    0.000493    0.913674    
#> 441: 0.479988    0.992065    3.402883    0.022000    0.062803    0.000494    0.913784    
#> 442: 0.479902    0.992179    3.402897    0.022015    0.062805    0.000495    0.913840    
#> 443: 0.479896    0.992249    3.402910    0.022044    0.062825    0.000496    0.913845    
#> 444: 0.479873    0.992289    3.402901    0.022054    0.062806    0.000497    0.913838    
#> 445: 0.479878    0.992280    3.402892    0.022066    0.062739    0.000498    0.913864    
#> 446: 0.479902    0.992291    3.402874    0.022079    0.062725    0.000498    0.913893    
#> 447: 0.479886    0.992377    3.402868    0.022052    0.062722    0.000499    0.913965    
#> 448: 0.479865    0.992426    3.402862    0.022067    0.062764    0.000499    0.913874    
#> 449: 0.479806    0.992502    3.402872    0.022080    0.062733    0.000499    0.913935    
#> 450: 0.479896    0.992518    3.402869    0.022088    0.062779    0.000498    0.913902    
#> 451: 0.479943    0.992555    3.402849    0.022115    0.062777    0.000497    0.913946    
#> 452: 0.479865    0.992552    3.402825    0.022123    0.062777    0.000497    0.913907    
#> 453: 0.479853    0.992523    3.402817    0.022131    0.062774    0.000496    0.913809    
#> 454: 0.479876    0.992630    3.402822    0.022125    0.062739    0.000496    0.913789    
#> 455: 0.479841    0.992656    3.402813    0.022104    0.062814    0.000497    0.913804    
#> 456: 0.479733    0.992650    3.402809    0.022111    0.062853    0.000497    0.913819    
#> 457: 0.479735    0.992545    3.402824    0.022118    0.062848    0.000497    0.913805    
#> 458: 0.479763    0.992685    3.402830    0.022105    0.062888    0.000496    0.913874    
#> 459: 0.479654    0.992753    3.402828    0.022081    0.062911    0.000496    0.913856    
#> 460: 0.479611    0.992765    3.402820    0.022063    0.062884    0.000495    0.913922    
#> 461: 0.479474    0.992867    3.402832    0.022088    0.062881    0.000495    0.913898    
#> 462: 0.479494    0.992928    3.402836    0.022101    0.062903    0.000495    0.913860    
#> 463: 0.479543    0.993030    3.402839    0.022090    0.062861    0.000495    0.913891    
#> 464: 0.479592    0.993081    3.402844    0.022094    0.062812    0.000494    0.913910    
#> 465: 0.479485    0.992981    3.402830    0.022105    0.062864    0.000494    0.914037    
#> 466: 0.479522    0.993066    3.402808    0.022104    0.062889    0.000495    0.914056    
#> 467: 0.479578    0.993018    3.402805    0.022100    0.062855    0.000495    0.914085    
#> 468: 0.479748    0.993063    3.402811    0.022104    0.062822    0.000495    0.914192    
#> 469: 0.479763    0.993167    3.402808    0.022109    0.062767    0.000494    0.914257    
#> 470: 0.479651    0.993210    3.402809    0.022102    0.062715    0.000494    0.914379    
#> 471: 0.479535    0.993150    3.402807    0.022114    0.062711    0.000494    0.914406    
#> 472: 0.479531    0.993121    3.402805    0.022096    0.062662    0.000494    0.914434    
#> 473: 0.479427    0.993162    3.402810    0.022091    0.062698    0.000493    0.914408    
#> 474: 0.479349    0.993084    3.402821    0.022109    0.062685    0.000493    0.914435    
#> 475: 0.479371    0.993176    3.402821    0.022100    0.062660    0.000493    0.914408    
#> 476: 0.479385    0.993189    3.402808    0.022113    0.062612    0.000493    0.914433    
#> 477: 0.479372    0.993224    3.402801    0.022100    0.062552    0.000493    0.914399    
#> 478: 0.479311    0.993212    3.402793    0.022097    0.062536    0.000493    0.914351    
#> 479: 0.479259    0.993280    3.402779    0.022101    0.062491    0.000493    0.914439    
#> 480: 0.479240    0.993312    3.402789    0.022092    0.062522    0.000493    0.914559    
#> 481: 0.479172    0.993276    3.402802    0.022111    0.062525    0.000493    0.914607    
#> 482: 0.479273    0.993268    3.402802    0.022140    0.062561    0.000493    0.914556    
#> 483: 0.479216    0.993273    3.402790    0.022151    0.062612    0.000493    0.914563    
#> 484: 0.479335    0.993180    3.402787    0.022150    0.062659    0.000492    0.914504    
#> 485: 0.479467    0.993196    3.402785    0.022139    0.062665    0.000491    0.914513    
#> 486: 0.479528    0.993188    3.402778    0.022130    0.062680    0.000491    0.914498    
#> 487: 0.479614    0.993190    3.402789    0.022138    0.062677    0.000491    0.914473    
#> 488: 0.479548    0.993122    3.402789    0.022163    0.062691    0.000490    0.914453    
#> 489: 0.479519    0.993126    3.402787    0.022187    0.062701    0.000490    0.914423    
#> 490: 0.479570    0.993205    3.402787    0.022210    0.062617    0.000490    0.914399    
#> 491: 0.479584    0.993300    3.402784    0.022224    0.062591    0.000490    0.914366    
#> 492: 0.479539    0.993300    3.402786    0.022247    0.062573    0.000490    0.914324    
#> 493: 0.479444    0.993304    3.402786    0.022260    0.062562    0.000491    0.914385    
#> 494: 0.479381    0.993339    3.402787    0.022270    0.062492    0.000491    0.914459    
#> 495: 0.479463    0.993360    3.402808    0.022297    0.062485    0.000492    0.914421    
#> 496: 0.479526    0.993440    3.402811    0.022306    0.062480    0.000492    0.914394    
#> 497: 0.479552    0.993467    3.402820    0.022324    0.062502    0.000492    0.914370    
#> 498: 0.479587    0.993475    3.402817    0.022346    0.062434    0.000493    0.914376    
#> 499: 0.479626    0.993457    3.402821    0.022345    0.062465    0.000493    0.914401    
#> 500: 0.479625    0.993490    3.402819    0.022355    0.062470    0.000493    0.914378    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.288273    0.961892    3.441070    0.392401    0.078857    0.016800    1.744613    
#> 002: 0.277654    0.925428    3.465366    0.372781    0.074914    0.015960    1.079795    
#> 003: 0.361341    0.826864    3.455708    0.354142    0.071168    0.015162    0.807804    
#> 004: 0.276689    0.835456    3.452846    0.336435    0.082901    0.014404    0.695527    
#> 005: 0.234962    0.841979    3.431926    0.319613    0.078756    0.013684    0.625361    
#> 006: 0.214043    0.852146    3.403850    0.303633    0.080139    0.013000    0.566100    
#> 007: 0.197399    0.871825    3.397654    0.288451    0.087482    0.012350    0.574069    
#> 008: 0.184511    0.881392    3.391007    0.274029    0.093548    0.012035    0.570264    
#> 009: 0.147305    0.867646    3.388599    0.260327    0.088871    0.014261    0.569850    
#> 010: 0.187398    0.879832    3.386252    0.247311    0.084427    0.013548    0.557165    
#> 011: 0.193167    0.886032    3.383322    0.234945    0.086880    0.012870    0.572848    
#> 012: 0.178863    0.874953    3.380052    0.223198    0.082536    0.012329    0.557876    
#> 013: 0.132272    0.908019    3.368576    0.212038    0.080779    0.012987    0.568458    
#> 014: 0.201828    0.897628    3.385628    0.201436    0.076740    0.016904    0.564327    
#> 015: 0.188398    0.887924    3.391331    0.193860    0.072903    0.017942    0.544132    
#> 016: 0.197535    0.888007    3.393322    0.204389    0.069258    0.020100    0.553239    
#> 017: 0.180181    0.887136    3.387429    0.194169    0.065795    0.022654    0.543020    
#> 018: 0.162841    0.889728    3.374539    0.184461    0.064397    0.021522    0.563014    
#> 019: 0.138734    0.893855    3.369722    0.189508    0.061177    0.020446    0.547946    
#> 020: 0.133977    0.906305    3.367964    0.181739    0.072062    0.019957    0.555093    
#> 021: 0.156178    0.904922    3.381159    0.199259    0.068459    0.020658    0.538352    
#> 022: 0.164331    0.895575    3.385994    0.236352    0.065036    0.022578    0.538536    
#> 023: 0.216898    0.900718    3.387455    0.224534    0.061785    0.021504    0.550047    
#> 024: 0.186960    0.911218    3.382720    0.213307    0.058695    0.020429    0.553436    
#> 025: 0.189287    0.894382    3.386777    0.202642    0.066198    0.019735    0.551789    
#> 026: 0.178742    0.904045    3.382963    0.192510    0.062888    0.019850    0.555256    
#> 027: 0.165008    0.910754    3.380691    0.182884    0.059744    0.020023    0.561992    
#> 028: 0.183575    0.886465    3.391407    0.173740    0.056756    0.019022    0.548212    
#> 029: 0.190997    0.892291    3.386035    0.165053    0.053919    0.019573    0.574836    
#> 030: 0.198544    0.896709    3.385483    0.178192    0.051223    0.022235    0.561207    
#> 031: 0.164323    0.887255    3.393422    0.169282    0.062530    0.021123    0.569067    
#> 032: 0.163612    0.875350    3.398380    0.160818    0.059404    0.020067    0.558431    
#> 033: 0.169944    0.887947    3.384296    0.187992    0.056433    0.019064    0.557216    
#> 034: 0.183485    0.888420    3.400251    0.178592    0.061069    0.018646    0.552454    
#> 035: 0.175861    0.872689    3.392734    0.178173    0.066321    0.018433    0.541690    
#> 036: 0.186116    0.890915    3.400957    0.169264    0.063005    0.022615    0.558100    
#> 037: 0.185380    0.882281    3.396338    0.187922    0.066526    0.021484    0.541188    
#> 038: 0.198168    0.879835    3.384825    0.204487    0.064875    0.020410    0.545509    
#> 039: 0.208306    0.886722    3.403986    0.194413    0.065858    0.024034    0.519760    
#> 040: 0.204486    0.875319    3.407202    0.202040    0.062565    0.022832    0.546144    
#> 041: 0.177610    0.879632    3.385829    0.191938    0.066644    0.024053    0.554781    
#> 042: 0.213881    0.883197    3.390046    0.212216    0.063311    0.023191    0.531607    
#> 043: 0.194377    0.887190    3.384648    0.201606    0.066139    0.023188    0.545342    
#> 044: 0.181397    0.889593    3.391981    0.191525    0.062832    0.022028    0.550723    
#> 045: 0.171851    0.900532    3.383783    0.210065    0.061248    0.020927    0.535469    
#> 046: 0.163322    0.891433    3.380557    0.221273    0.060688    0.020537    0.542357    
#> 047: 0.146078    0.897175    3.375955    0.210209    0.058606    0.019864    0.545834    
#> 048: 0.158895    0.899196    3.381086    0.242900    0.064707    0.024007    0.542957    
#> 049: 0.179523    0.900363    3.382578    0.230755    0.068295    0.022807    0.539000    
#> 050: 0.184915    0.876192    3.390921    0.222172    0.064880    0.021667    0.547644    
#> 051: 0.202267    0.873948    3.393531    0.211064    0.067974    0.020583    0.547617    
#> 052: 0.229097    0.867519    3.413676    0.200511    0.064892    0.020737    0.552914    
#> 053: 0.218198    0.868347    3.402067    0.196203    0.061648    0.023301    0.553190    
#> 054: 0.188417    0.874553    3.398771    0.198571    0.058565    0.024115    0.559430    
#> 055: 0.198947    0.876535    3.399979    0.197779    0.055637    0.025766    0.559003    
#> 056: 0.208150    0.863280    3.402254    0.198993    0.054044    0.024644    0.561649    
#> 057: 0.179736    0.877554    3.397302    0.208695    0.062146    0.023412    0.566711    
#> 058: 0.172825    0.889476    3.380232    0.198261    0.059039    0.022241    0.569897    
#> 059: 0.169261    0.872446    3.380271    0.203595    0.057476    0.021129    0.560216    
#> 060: 0.161537    0.867927    3.382473    0.203774    0.061072    0.023825    0.564093    
#> 061: 0.198541    0.883722    3.397379    0.247884    0.060359    0.026332    0.574215    
#> 062: 0.192355    0.888347    3.403489    0.235489    0.064505    0.026992    0.559524    
#> 063: 0.232159    0.873039    3.402586    0.223715    0.061279    0.026439    0.572068    
#> 064: 0.211067    0.877019    3.401329    0.212529    0.058215    0.025117    0.573353    
#> 065: 0.196442    0.881742    3.390941    0.212445    0.055429    0.023861    0.547485    
#> 066: 0.212823    0.898547    3.394739    0.201823    0.059100    0.022668    0.562712    
#> 067: 0.196149    0.869802    3.392699    0.205118    0.056145    0.025090    0.551274    
#> 068: 0.175014    0.874813    3.400935    0.203435    0.061532    0.027141    0.558152    
#> 069: 0.194975    0.874914    3.395020    0.208412    0.058944    0.025784    0.556833    
#> 070: 0.213899    0.878872    3.402929    0.214905    0.062066    0.024495    0.543858    
#> 071: 0.203858    0.868009    3.388319    0.204733    0.058963    0.023968    0.554622    
#> 072: 0.193960    0.875949    3.391928    0.209325    0.063846    0.024682    0.535646    
#> 073: 0.192638    0.871874    3.403973    0.198859    0.068589    0.023512    0.531671    
#> 074: 0.200532    0.861824    3.398085    0.196765    0.065159    0.022337    0.533766    
#> 075: 0.196979    0.860334    3.406616    0.186927    0.075615    0.021220    0.539953    
#> 076: 0.221427    0.860400    3.413429    0.182283    0.071834    0.024598    0.540710    
#> 077: 0.238349    0.842198    3.415697    0.177919    0.068243    0.023368    0.550009    
#> 078: 0.219908    0.863713    3.413588    0.185347    0.064830    0.022200    0.539608    
#> 079: 0.225153    0.882082    3.402963    0.224530    0.071032    0.024104    0.542556    
#> 080: 0.207471    0.874534    3.393168    0.243547    0.067481    0.027151    0.567057    
#> 081: 0.198266    0.876543    3.400056    0.231369    0.064106    0.025803    0.547475    
#> 082: 0.199736    0.879530    3.395349    0.219801    0.060901    0.024513    0.563797    
#> 083: 0.191052    0.890678    3.394777    0.208811    0.057856    0.023287    0.539495    
#> 084: 0.189141    0.874351    3.387735    0.226086    0.055573    0.024852    0.534918    
#> 085: 0.193909    0.892971    3.403111    0.214782    0.058315    0.024716    0.538351    
#> 086: 0.170553    0.891955    3.380289    0.204724    0.059687    0.023480    0.536918    
#> 087: 0.167838    0.893919    3.376825    0.194488    0.056703    0.024447    0.557964    
#> 088: 0.137524    0.897391    3.380802    0.214918    0.054931    0.023623    0.564817    
#> 089: 0.140362    0.903619    3.363708    0.211589    0.065863    0.023840    0.551810    
#> 090: 0.148203    0.904501    3.372530    0.227238    0.068060    0.027289    0.539569    
#> 091: 0.150473    0.888191    3.368359    0.235830    0.064657    0.025924    0.549098    
#> 092: 0.155902    0.915102    3.367394    0.231532    0.064722    0.024628    0.550677    
#> 093: 0.133960    0.894887    3.372824    0.219956    0.065764    0.023397    0.561437    
#> 094: 0.150693    0.905455    3.375026    0.208958    0.067760    0.022362    0.551393    
#> 095: 0.172645    0.901275    3.388097    0.211356    0.064372    0.021373    0.541343    
#> 096: 0.157038    0.890252    3.380468    0.208963    0.062686    0.020305    0.540002    
#> 097: 0.173893    0.909662    3.378573    0.198515    0.061565    0.019632    0.536760    
#> 098: 0.170085    0.906164    3.387939    0.188589    0.065158    0.019212    0.543644    
#> 099: 0.166244    0.882122    3.379628    0.194321    0.063090    0.020722    0.533075    
#> 100: 0.185046    0.891730    3.391156    0.186704    0.062257    0.020504    0.540994    
#> 101: 0.163071    0.891084    3.375582    0.192994    0.059144    0.022090    0.538551    
#> 102: 0.184240    0.895289    3.380775    0.196424    0.056899    0.022310    0.536159    
#> 103: 0.176839    0.891626    3.390347    0.213713    0.061168    0.022989    0.541919    
#> 104: 0.166138    0.892008    3.391729    0.228028    0.063906    0.022106    0.550505    
#> 105: 0.192614    0.873924    3.395807    0.241986    0.062192    0.023081    0.553234    
#> 106: 0.199986    0.874590    3.393360    0.229887    0.059537    0.024102    0.535208    
#> 107: 0.191989    0.892956    3.391017    0.218392    0.065157    0.022897    0.541931    
#> 108: 0.198304    0.886990    3.397384    0.207473    0.061899    0.021909    0.556282    
#> 109: 0.199700    0.878219    3.400784    0.224409    0.062595    0.020813    0.555972    
#> 110: 0.211301    0.852370    3.397883    0.213188    0.059465    0.023542    0.546016    
#> 111: 0.208313    0.869270    3.399625    0.202529    0.056492    0.022365    0.543599    
#> 112: 0.198142    0.861001    3.389434    0.194284    0.053667    0.022495    0.552659    
#> 113: 0.200902    0.890791    3.395426    0.186861    0.058903    0.021749    0.536511    
#> 114: 0.199156    0.902568    3.390990    0.177518    0.060833    0.022212    0.549664    
#> 115: 0.204841    0.880195    3.387292    0.192181    0.066364    0.021101    0.568507    
#> 116: 0.195968    0.872959    3.387019    0.204167    0.065318    0.020046    0.547917    
#> 117: 0.172043    0.891877    3.391809    0.193958    0.062052    0.019044    0.562839    
#> 118: 0.161315    0.894778    3.382642    0.195011    0.062107    0.020321    0.551298    
#> 119: 0.167426    0.913347    3.377465    0.196684    0.073022    0.019305    0.556053    
#> 120: 0.164265    0.896746    3.382453    0.213063    0.069371    0.019032    0.546222    
#> 121: 0.169023    0.912985    3.385740    0.202410    0.070014    0.018101    0.554126    
#> 122: 0.181791    0.897461    3.388114    0.196204    0.066513    0.017196    0.546418    
#> 123: 0.185761    0.910708    3.381176    0.197037    0.071274    0.017833    0.551682    
#> 124: 0.165721    0.923741    3.376050    0.187185    0.067710    0.016941    0.574159    
#> 125: 0.170720    0.927868    3.378372    0.196493    0.065618    0.016357    0.565316    
#> 126: 0.159465    0.918464    3.374585    0.195026    0.068145    0.016918    0.575305    
#> 127: 0.181882    0.891315    3.373791    0.217009    0.066902    0.018377    0.577861    
#> 128: 0.168117    0.885015    3.380029    0.206159    0.065187    0.019602    0.577056    
#> 129: 0.187355    0.885470    3.393169    0.220786    0.061928    0.024689    0.549570    
#> 130: 0.211683    0.884739    3.384275    0.221904    0.062116    0.024863    0.533290    
#> 131: 0.196455    0.885766    3.385310    0.223009    0.059010    0.023620    0.547308    
#> 132: 0.177550    0.891912    3.379317    0.211859    0.071577    0.022439    0.536086    
#> 133: 0.187795    0.880207    3.380001    0.228492    0.069944    0.025681    0.535455    
#> 134: 0.181251    0.867508    3.393281    0.217067    0.066447    0.027998    0.540877    
#> 135: 0.181532    0.870493    3.388142    0.206214    0.063125    0.026598    0.538442    
#> 136: 0.197746    0.873296    3.397629    0.206850    0.059969    0.025268    0.535125    
#> 137: 0.220282    0.878000    3.396080    0.230190    0.062438    0.024005    0.536336    
#> 138: 0.188584    0.889066    3.389988    0.218681    0.059316    0.026280    0.532128    
#> 139: 0.181508    0.886017    3.399502    0.236484    0.064900    0.028307    0.528480    
#> 140: 0.198331    0.881601    3.398162    0.246531    0.070115    0.029506    0.546527    
#> 141: 0.186523    0.848850    3.401764    0.234204    0.066609    0.028031    0.547048    
#> 142: 0.201876    0.862192    3.404489    0.222494    0.063279    0.026629    0.554791    
#> 143: 0.182294    0.893328    3.395626    0.211369    0.062079    0.027076    0.559656    
#> 144: 0.198129    0.881841    3.396392    0.200801    0.064398    0.025723    0.546520    
#> 145: 0.179573    0.890933    3.382828    0.190761    0.068192    0.024436    0.554149    
#> 146: 0.165749    0.901830    3.387601    0.184064    0.064782    0.023818    0.561720    
#> 147: 0.128116    0.878816    3.382027    0.174861    0.061543    0.022627    0.556823    
#> 148: 0.157803    0.901476    3.387189    0.178576    0.066186    0.025248    0.550247    
#> 149: 0.149806    0.879253    3.378510    0.172365    0.062876    0.023986    0.564396    
#> 150: 0.177117    0.869963    3.372901    0.216426    0.059733    0.022851    0.557876    
#> 151: 0.159317    0.886526    3.384903    0.205604    0.056746    0.022847    0.552936    
#> 152: 0.169778    0.894778    3.385764    0.204669    0.051757    0.022705    0.536725    
#> 153: 0.203310    0.883859    3.398444    0.195845    0.052788    0.025152    0.547303    
#> 154: 0.199788    0.890049    3.388814    0.205854    0.062544    0.020268    0.538640    
#> 155: 0.170274    0.871636    3.387096    0.197130    0.067927    0.020535    0.534297    
#> 156: 0.180246    0.880615    3.391640    0.194467    0.065192    0.020245    0.553634    
#> 157: 0.196261    0.874290    3.395501    0.197018    0.071952    0.017816    0.564030    
#> 158: 0.212964    0.882227    3.398778    0.202216    0.060801    0.021467    0.555401    
#> 159: 0.186615    0.886535    3.401952    0.175540    0.053311    0.026765    0.557934    
#> 160: 0.196850    0.870317    3.396395    0.182318    0.056594    0.023049    0.547341    
#> 161: 0.204152    0.868901    3.399169    0.190399    0.045672    0.025902    0.546699    
#> 162: 0.188132    0.882410    3.385686    0.223866    0.062266    0.027960    0.549852    
#> 163: 0.202344    0.891946    3.381090    0.235957    0.064623    0.026662    0.539090    
#> 164: 0.188470    0.895842    3.384156    0.231654    0.065567    0.025723    0.540492    
#> 165: 0.207537    0.865399    3.397334    0.237088    0.066110    0.030586    0.553163    
#> 166: 0.231784    0.888729    3.400318    0.242729    0.069811    0.034704    0.540729    
#> 167: 0.209095    0.889161    3.400422    0.220930    0.064415    0.028126    0.545493    
#> 168: 0.195585    0.893075    3.396040    0.213480    0.065130    0.023369    0.546864    
#> 169: 0.200382    0.910596    3.384611    0.227962    0.057380    0.024836    0.550419    
#> 170: 0.189890    0.910172    3.386777    0.212671    0.057713    0.024891    0.552038    
#> 171: 0.148651    0.888246    3.382930    0.186201    0.056622    0.023801    0.536007    
#> 172: 0.150575    0.902819    3.381000    0.204269    0.060817    0.024281    0.527711    
#> 173: 0.174656    0.894620    3.385046    0.204077    0.059542    0.023341    0.516607    
#> 174: 0.172923    0.902907    3.382810    0.214062    0.063370    0.023764    0.520437    
#> 175: 0.157829    0.898901    3.373602    0.215759    0.061941    0.026555    0.532565    
#> 176: 0.158871    0.895151    3.387209    0.211693    0.057771    0.022319    0.544011    
#> 177: 0.177508    0.881532    3.398527    0.198048    0.061502    0.025857    0.543576    
#> 178: 0.220374    0.868777    3.402476    0.219420    0.061050    0.026888    0.533718    
#> 179: 0.220588    0.878983    3.400082    0.221386    0.053875    0.025292    0.548378    
#> 180: 0.193011    0.881261    3.401539    0.191137    0.051757    0.021875    0.561698    
#> 181: 0.191074    0.883502    3.382209    0.176692    0.047877    0.021108    0.552114    
#> 182: 0.147729    0.898470    3.374355    0.160465    0.054564    0.021889    0.566320    
#> 183: 0.165055    0.910211    3.384179    0.149119    0.068801    0.018560    0.569058    
#> 184: 0.155747    0.894548    3.380729    0.159009    0.053529    0.019152    0.557804    
#> 185: 0.151630    0.902154    3.373366    0.156195    0.052464    0.021749    0.552409    
#> 186: 0.166333    0.907073    3.379629    0.182748    0.058236    0.022477    0.546778    
#> 187: 0.186907    0.891931    3.385086    0.198840    0.064666    0.019531    0.542441    
#> 188: 0.158913    0.909146    3.380346    0.211811    0.073040    0.019939    0.555650    
#> 189: 0.158107    0.898183    3.381188    0.205061    0.073878    0.018972    0.548640    
#> 190: 0.153995    0.906331    3.375704    0.194291    0.069581    0.020101    0.532595    
#> 191: 0.143878    0.918222    3.372371    0.190152    0.070336    0.021097    0.530943    
#> 192: 0.157126    0.919558    3.381973    0.168300    0.070432    0.020657    0.541169    
#> 193: 0.184999    0.914023    3.387814    0.181161    0.060956    0.022399    0.546831    
#> 194: 0.154614    0.908760    3.375709    0.196926    0.067463    0.018184    0.543471    
#> 195: 0.143731    0.903353    3.374821    0.211122    0.068608    0.019955    0.544182    
#> 196: 0.137813    0.904082    3.374393    0.215270    0.064049    0.022681    0.542534    
#> 197: 0.140723    0.900891    3.386376    0.220970    0.072822    0.021703    0.558549    
#> 198: 0.179264    0.882333    3.378996    0.216700    0.064529    0.025010    0.533593    
#> 199: 0.184609    0.887948    3.389480    0.224613    0.066069    0.018334    0.551057    
#> 200: 0.185313    0.882581    3.396238    0.186841    0.059338    0.019899    0.556673    
#> 201: 0.189968    0.877682    3.398569    0.178054    0.060293    0.023341    0.555277    
#> 202: 0.184678    0.880570    3.395850    0.179057    0.063665    0.022333    0.555610    
#> 203: 0.191329    0.878044    3.394228    0.179259    0.064189    0.021518    0.555889    
#> 204: 0.195354    0.876051    3.395778    0.185756    0.065841    0.021152    0.552807    
#> 205: 0.192057    0.879539    3.395033    0.186062    0.066781    0.021062    0.552208    
#> 206: 0.187727    0.883350    3.394547    0.182469    0.069091    0.020856    0.552766    
#> 207: 0.185595    0.883539    3.393429    0.182218    0.069599    0.020377    0.553335    
#> 208: 0.186237    0.883540    3.393723    0.181331    0.068154    0.020064    0.554184    
#> 209: 0.187297    0.880468    3.393508    0.182489    0.068980    0.019702    0.555116    
#> 210: 0.187430    0.878581    3.394225    0.183951    0.068760    0.019602    0.554843    
#> 211: 0.189099    0.878132    3.394518    0.185119    0.069103    0.019416    0.553740    
#> 212: 0.191008    0.877905    3.395048    0.189099    0.069959    0.019146    0.552851    
#> 213: 0.193368    0.876478    3.395699    0.192565    0.070495    0.018918    0.552434    
#> 214: 0.193846    0.876352    3.395881    0.191488    0.070884    0.018608    0.552102    
#> 215: 0.193882    0.877058    3.396266    0.191086    0.071703    0.018440    0.552614    
#> 216: 0.196619    0.876947    3.396364    0.192310    0.072510    0.018187    0.553718    
#> 217: 0.197394    0.877357    3.396480    0.193080    0.073128    0.018103    0.552947    
#> 218: 0.197823    0.877554    3.396362    0.193324    0.073374    0.018154    0.552082    
#> 219: 0.197142    0.877783    3.395784    0.193400    0.072673    0.018368    0.552187    
#> 220: 0.196184    0.878161    3.395308    0.192627    0.072581    0.018756    0.552604    
#> 221: 0.195461    0.878942    3.394889    0.192716    0.071891    0.019092    0.552850    
#> 222: 0.194666    0.879591    3.394190    0.194341    0.071609    0.019406    0.552975    
#> 223: 0.193868    0.878988    3.393820    0.195892    0.071471    0.019635    0.552895    
#> 224: 0.194518    0.879253    3.393968    0.196097    0.071539    0.019707    0.553092    
#> 225: 0.193937    0.878102    3.394225    0.195475    0.071391    0.019731    0.553402    
#> 226: 0.193847    0.878193    3.393943    0.195638    0.071414    0.019829    0.553035    
#> 227: 0.192814    0.878563    3.393846    0.194252    0.071317    0.019933    0.552924    
#> 228: 0.192054    0.879606    3.393113    0.194215    0.071465    0.019951    0.552870    
#> 229: 0.190735    0.879658    3.392625    0.193969    0.071385    0.019965    0.552613    
#> 230: 0.190569    0.879743    3.392436    0.193926    0.071482    0.019953    0.552295    
#> 231: 0.190484    0.879581    3.392644    0.193501    0.071470    0.020047    0.551908    
#> 232: 0.189693    0.879901    3.392587    0.193668    0.071308    0.020052    0.551686    
#> 233: 0.189015    0.879755    3.392511    0.193718    0.070891    0.020097    0.551836    
#> 234: 0.187793    0.880039    3.392251    0.193866    0.070649    0.020188    0.551811    
#> 235: 0.187694    0.879992    3.392174    0.194190    0.070594    0.020148    0.551670    
#> 236: 0.187610    0.880657    3.391905    0.193870    0.070850    0.020064    0.551566    
#> 237: 0.187476    0.881002    3.391788    0.194126    0.070882    0.020012    0.552004    
#> 238: 0.187491    0.881058    3.391770    0.193992    0.070798    0.019936    0.552341    
#> 239: 0.186992    0.881579    3.391510    0.193676    0.070971    0.019890    0.552218    
#> 240: 0.186566    0.881496    3.391551    0.192878    0.070865    0.019782    0.552194    
#> 241: 0.186380    0.881213    3.391512    0.192147    0.070812    0.019643    0.552450    
#> 242: 0.185917    0.880910    3.391415    0.191077    0.070936    0.019511    0.552956    
#> 243: 0.185234    0.881351    3.391189    0.189962    0.071224    0.019459    0.553538    
#> 244: 0.184603    0.881472    3.391309    0.188489    0.071155    0.019384    0.554169    
#> 245: 0.184420    0.881488    3.391271    0.188393    0.070948    0.019440    0.554557    
#> 246: 0.184904    0.881500    3.391428    0.188070    0.070803    0.019435    0.554791    
#> 247: 0.185162    0.881622    3.391513    0.187814    0.070453    0.019414    0.555149    
#> 248: 0.184977    0.882042    3.391498    0.187644    0.070102    0.019414    0.555236    
#> 249: 0.184927    0.881969    3.391569    0.187630    0.070077    0.019457    0.555165    
#> 250: 0.185017    0.881962    3.391605    0.187724    0.070215    0.019436    0.555142    
#> 251: 0.185230    0.882340    3.391749    0.187847    0.070138    0.019419    0.555088    
#> 252: 0.185571    0.882667    3.391847    0.188502    0.069898    0.019456    0.554984    
#> 253: 0.185653    0.882814    3.391880    0.188997    0.069646    0.019507    0.555172    
#> 254: 0.185729    0.882945    3.391906    0.188849    0.069467    0.019489    0.555116    
#> 255: 0.185888    0.883274    3.392064    0.188752    0.069303    0.019496    0.555210    
#> 256: 0.185782    0.883277    3.392054    0.188990    0.069212    0.019481    0.555104    
#> 257: 0.185762    0.883098    3.392039    0.189668    0.069073    0.019476    0.555093    
#> 258: 0.185614    0.882821    3.392050    0.190032    0.069039    0.019508    0.555302    
#> 259: 0.185767    0.882565    3.392145    0.190253    0.068899    0.019538    0.555188    
#> 260: 0.185912    0.882436    3.392266    0.190353    0.068738    0.019467    0.554980    
#> 261: 0.186291    0.882257    3.392282    0.190864    0.068619    0.019461    0.555119    
#> 262: 0.186372    0.882286    3.392165    0.190964    0.068522    0.019417    0.555178    
#> 263: 0.186444    0.882401    3.392135    0.191291    0.068364    0.019392    0.555101    
#> 264: 0.186210    0.882437    3.392030    0.191358    0.068325    0.019370    0.555277    
#> 265: 0.186040    0.882647    3.392031    0.191072    0.068439    0.019304    0.555534    
#> 266: 0.186459    0.882738    3.392104    0.190917    0.068686    0.019235    0.555887    
#> 267: 0.186658    0.882636    3.392388    0.190678    0.068821    0.019215    0.556044    
#> 268: 0.187017    0.882441    3.392489    0.190613    0.068794    0.019190    0.556213    
#> 269: 0.187644    0.882418    3.392553    0.190540    0.068650    0.019213    0.556216    
#> 270: 0.187967    0.882650    3.392524    0.190647    0.068648    0.019254    0.556045    
#> 271: 0.187960    0.882830    3.392411    0.190855    0.068621    0.019335    0.556083    
#> 272: 0.188218    0.882681    3.392436    0.190822    0.068610    0.019384    0.556253    
#> 273: 0.187943    0.882834    3.392458    0.190691    0.068633    0.019398    0.556234    
#> 274: 0.187696    0.883112    3.392431    0.190484    0.068506    0.019360    0.556355    
#> 275: 0.187589    0.883204    3.392395    0.190062    0.068383    0.019328    0.556352    
#> 276: 0.187304    0.883451    3.392417    0.189782    0.068431    0.019326    0.556232    
#> 277: 0.187255    0.883611    3.392451    0.189776    0.068385    0.019338    0.556195    
#> 278: 0.187097    0.883668    3.392452    0.189977    0.068455    0.019325    0.556076    
#> 279: 0.186648    0.883548    3.392313    0.190283    0.068457    0.019326    0.556201    
#> 280: 0.186377    0.883793    3.392226    0.190822    0.068351    0.019338    0.556139    
#> 281: 0.185901    0.884024    3.391998    0.191472    0.068277    0.019368    0.556036    
#> 282: 0.185719    0.884256    3.391927    0.191519    0.068272    0.019356    0.556150    
#> 283: 0.185563    0.884240    3.391920    0.191907    0.068270    0.019353    0.556316    
#> 284: 0.185096    0.884080    3.391895    0.192154    0.068110    0.019337    0.556354    
#> 285: 0.184939    0.883970    3.391756    0.192317    0.068016    0.019320    0.556383    
#> 286: 0.184446    0.883942    3.391515    0.192528    0.068113    0.019293    0.556200    
#> 287: 0.184117    0.884160    3.391405    0.192515    0.068168    0.019287    0.555905    
#> 288: 0.183938    0.884245    3.391349    0.192366    0.068178    0.019287    0.555881    
#> 289: 0.183727    0.884380    3.391295    0.192116    0.068211    0.019288    0.555928    
#> 290: 0.183789    0.884285    3.391343    0.191972    0.068082    0.019255    0.556071    
#> 291: 0.184096    0.884365    3.391484    0.191917    0.068110    0.019252    0.555996    
#> 292: 0.184286    0.884376    3.391543    0.192221    0.068148    0.019262    0.555991    
#> 293: 0.184421    0.884201    3.391593    0.192204    0.068151    0.019271    0.555993    
#> 294: 0.184362    0.884157    3.391550    0.192393    0.068091    0.019267    0.555883    
#> 295: 0.184236    0.884025    3.391529    0.192423    0.068035    0.019310    0.555663    
#> 296: 0.184090    0.884071    3.391429    0.192474    0.068000    0.019335    0.555596    
#> 297: 0.183926    0.884234    3.391390    0.192565    0.068046    0.019363    0.555629    
#> 298: 0.184063    0.884110    3.391358    0.192558    0.067971    0.019387    0.555755    
#> 299: 0.184035    0.884244    3.391284    0.192573    0.067910    0.019403    0.555694    
#> 300: 0.184222    0.884246    3.391342    0.192623    0.067997    0.019368    0.555637    
#> 301: 0.184388    0.884350    3.391291    0.192450    0.067992    0.019358    0.555752    
#> 302: 0.184341    0.884461    3.391262    0.192278    0.067981    0.019341    0.555919    
#> 303: 0.184333    0.884562    3.391255    0.192277    0.067967    0.019344    0.555758    
#> 304: 0.184435    0.884780    3.391225    0.192539    0.067928    0.019377    0.555696    
#> 305: 0.184435    0.884594    3.391182    0.192580    0.067976    0.019410    0.555573    
#> 306: 0.184252    0.884585    3.391071    0.192549    0.068060    0.019421    0.555431    
#> 307: 0.183823    0.884642    3.390881    0.192415    0.068115    0.019407    0.555588    
#> 308: 0.183672    0.884639    3.390756    0.192506    0.068233    0.019405    0.555536    
#> 309: 0.183815    0.884529    3.390751    0.192548    0.068255    0.019377    0.555648    
#> 310: 0.184011    0.884427    3.390749    0.192509    0.068332    0.019374    0.555811    
#> 311: 0.184059    0.884328    3.390825    0.192578    0.068415    0.019352    0.555806    
#> 312: 0.184081    0.884112    3.390878    0.192551    0.068635    0.019302    0.555816    
#> 313: 0.184038    0.883878    3.390870    0.192469    0.068725    0.019266    0.555954    
#> 314: 0.183843    0.883862    3.390846    0.192581    0.068835    0.019222    0.556118    
#> 315: 0.183724    0.883963    3.390832    0.192734    0.068950    0.019189    0.556156    
#> 316: 0.183850    0.884015    3.390865    0.192888    0.069041    0.019177    0.556100    
#> 317: 0.183981    0.883939    3.390941    0.192629    0.069141    0.019134    0.556261    
#> 318: 0.184039    0.884059    3.390966    0.192439    0.069222    0.019117    0.556228    
#> 319: 0.184124    0.884100    3.391039    0.192169    0.069304    0.019087    0.556241    
#> 320: 0.183967    0.883960    3.391034    0.192008    0.069350    0.019072    0.556335    
#> 321: 0.184000    0.883933    3.391018    0.192063    0.069367    0.019085    0.556425    
#> 322: 0.184076    0.883877    3.391020    0.192175    0.069308    0.019084    0.556497    
#> 323: 0.184016    0.883920    3.391041    0.192217    0.069342    0.019076    0.556456    
#> 324: 0.184044    0.884002    3.391035    0.192315    0.069398    0.019065    0.556341    
#> 325: 0.183845    0.884144    3.390954    0.192239    0.069455    0.019043    0.556243    
#> 326: 0.183724    0.884129    3.390859    0.192096    0.069520    0.019047    0.556196    
#> 327: 0.183901    0.884154    3.390910    0.192024    0.069538    0.019046    0.556317    
#> 328: 0.184061    0.884188    3.390974    0.191910    0.069454    0.019099    0.556289    
#> 329: 0.184364    0.884217    3.391081    0.191821    0.069409    0.019129    0.556256    
#> 330: 0.184353    0.884165    3.391213    0.191649    0.069330    0.019153    0.556266    
#> 331: 0.184507    0.884225    3.391336    0.191523    0.069233    0.019178    0.556226    
#> 332: 0.184715    0.884245    3.391440    0.191412    0.069194    0.019214    0.556352    
#> 333: 0.185014    0.884227    3.391458    0.191615    0.069222    0.019252    0.556378    
#> 334: 0.185150    0.884015    3.391444    0.191839    0.069268    0.019262    0.556505    
#> 335: 0.185029    0.884091    3.391352    0.191790    0.069205    0.019245    0.556530    
#> 336: 0.184776    0.884264    3.391265    0.191775    0.069163    0.019241    0.556513    
#> 337: 0.184605    0.884567    3.391109    0.191945    0.069114    0.019248    0.556435    
#> 338: 0.184500    0.884698    3.391063    0.192086    0.069055    0.019262    0.556318    
#> 339: 0.184375    0.884689    3.390985    0.192084    0.069035    0.019269    0.556283    
#> 340: 0.184382    0.884520    3.390976    0.192278    0.069043    0.019297    0.556173    
#> 341: 0.184542    0.884517    3.390992    0.192440    0.069025    0.019311    0.556106    
#> 342: 0.184443    0.884316    3.391045    0.192378    0.069036    0.019321    0.556093    
#> 343: 0.184220    0.884308    3.391023    0.192286    0.069087    0.019332    0.556120    
#> 344: 0.184187    0.884294    3.391007    0.192235    0.069019    0.019348    0.556160    
#> 345: 0.184230    0.884250    3.391051    0.192392    0.068872    0.019379    0.556144    
#> 346: 0.184141    0.884279    3.390930    0.192635    0.068797    0.019386    0.556112    
#> 347: 0.183969    0.884256    3.390841    0.192947    0.068743    0.019422    0.556072    
#> 348: 0.183694    0.884325    3.390741    0.193059    0.068777    0.019442    0.556091    
#> 349: 0.183603    0.884250    3.390725    0.193151    0.068762    0.019452    0.556114    
#> 350: 0.183498    0.884069    3.390717    0.193103    0.068749    0.019451    0.556127    
#> 351: 0.183362    0.884240    3.390611    0.192995    0.068732    0.019454    0.556223    
#> 352: 0.183080    0.884452    3.390536    0.193117    0.068745    0.019512    0.556422    
#> 353: 0.182896    0.884644    3.390497    0.193247    0.068678    0.019538    0.556403    
#> 354: 0.182919    0.884730    3.390424    0.193548    0.068648    0.019572    0.556332    
#> 355: 0.183083    0.884689    3.390404    0.193808    0.068603    0.019603    0.556332    
#> 356: 0.183205    0.884669    3.390397    0.193862    0.068552    0.019602    0.556439    
#> 357: 0.183352    0.884768    3.390362    0.194004    0.068490    0.019615    0.556336    
#> 358: 0.183403    0.884830    3.390358    0.193950    0.068462    0.019614    0.556269    
#> 359: 0.183260    0.884905    3.390311    0.193806    0.068444    0.019580    0.556346    
#> 360: 0.183061    0.884897    3.390223    0.193582    0.068377    0.019557    0.556297    
#> 361: 0.183017    0.884922    3.390166    0.193315    0.068269    0.019557    0.556274    
#> 362: 0.183058    0.884913    3.390116    0.193204    0.068203    0.019565    0.556169    
#> 363: 0.183082    0.884828    3.390119    0.193276    0.068133    0.019565    0.556079    
#> 364: 0.183048    0.884835    3.390075    0.193392    0.068072    0.019554    0.556102    
#> 365: 0.183014    0.884762    3.390066    0.193383    0.068002    0.019551    0.556102    
#> 366: 0.183133    0.884751    3.390018    0.193260    0.067961    0.019532    0.556137    
#> 367: 0.183232    0.884715    3.390044    0.193198    0.067946    0.019510    0.556086    
#> 368: 0.183311    0.884768    3.390000    0.193258    0.067913    0.019502    0.556035    
#> 369: 0.183317    0.884784    3.389976    0.193279    0.067887    0.019500    0.555953    
#> 370: 0.183325    0.884891    3.389965    0.193304    0.067875    0.019511    0.555978    
#> 371: 0.183264    0.885014    3.389927    0.193253    0.067851    0.019516    0.555957    
#> 372: 0.183047    0.885116    3.389876    0.193071    0.067851    0.019514    0.555996    
#> 373: 0.182917    0.885238    3.389798    0.193070    0.067796    0.019518    0.556055    
#> 374: 0.182945    0.885284    3.389795    0.193040    0.067748    0.019523    0.556064    
#> 375: 0.182887    0.885311    3.389844    0.192979    0.067744    0.019534    0.556141    
#> 376: 0.182929    0.885406    3.389878    0.192905    0.067712    0.019533    0.556128    
#> 377: 0.182849    0.885494    3.389879    0.192893    0.067606    0.019539    0.556152    
#> 378: 0.182729    0.885576    3.389871    0.192898    0.067497    0.019564    0.556251    
#> 379: 0.182672    0.885534    3.389826    0.193034    0.067445    0.019586    0.556176    
#> 380: 0.182499    0.885548    3.389758    0.193000    0.067364    0.019597    0.556145    
#> 381: 0.182384    0.885542    3.389710    0.192947    0.067345    0.019602    0.556116    
#> 382: 0.182172    0.885590    3.389650    0.192933    0.067313    0.019606    0.556055    
#> 383: 0.182218    0.885653    3.389595    0.192902    0.067319    0.019595    0.556062    
#> 384: 0.182153    0.885612    3.389578    0.192863    0.067270    0.019594    0.556040    
#> 385: 0.182322    0.885654    3.389568    0.192877    0.067256    0.019609    0.555985    
#> 386: 0.182481    0.885738    3.389638    0.192851    0.067252    0.019629    0.556013    
#> 387: 0.182643    0.885794    3.389709    0.192918    0.067251    0.019630    0.555989    
#> 388: 0.182689    0.885843    3.389753    0.192867    0.067227    0.019629    0.555986    
#> 389: 0.182712    0.885759    3.389745    0.192773    0.067210    0.019629    0.556044    
#> 390: 0.182625    0.885863    3.389684    0.192742    0.067201    0.019635    0.556007    
#> 391: 0.182664    0.885918    3.389619    0.192656    0.067202    0.019632    0.555995    
#> 392: 0.182669    0.885953    3.389617    0.192656    0.067182    0.019619    0.556106    
#> 393: 0.182661    0.885889    3.389595    0.192613    0.067153    0.019614    0.556086    
#> 394: 0.182639    0.885926    3.389557    0.192523    0.067148    0.019618    0.556125    
#> 395: 0.182759    0.885939    3.389567    0.192415    0.067175    0.019632    0.556097    
#> 396: 0.182903    0.885907    3.389587    0.192463    0.067202    0.019639    0.556016    
#> 397: 0.182902    0.885841    3.389620    0.192476    0.067216    0.019653    0.555975    
#> 398: 0.182950    0.885768    3.389665    0.192421    0.067237    0.019665    0.555948    
#> 399: 0.183036    0.885767    3.389711    0.192368    0.067263    0.019666    0.555923    
#> 400: 0.183077    0.885697    3.389733    0.192370    0.067237    0.019665    0.555907    
#> 401: 0.182995    0.885748    3.389712    0.192392    0.067305    0.019647    0.555994    
#> 402: 0.182972    0.885807    3.389726    0.192354    0.067264    0.019639    0.556086    
#> 403: 0.183144    0.885815    3.389777    0.192263    0.067229    0.019632    0.556138    
#> 404: 0.183184    0.885763    3.389764    0.192259    0.067159    0.019628    0.556121    
#> 405: 0.183192    0.885759    3.389766    0.192189    0.067130    0.019633    0.556140    
#> 406: 0.183173    0.885758    3.389762    0.192116    0.067115    0.019636    0.556154    
#> 407: 0.183177    0.885757    3.389761    0.192160    0.067085    0.019647    0.556117    
#> 408: 0.183163    0.885914    3.389748    0.192100    0.067112    0.019653    0.556167    
#> 409: 0.183199    0.885896    3.389756    0.192082    0.067095    0.019659    0.556114    
#> 410: 0.183165    0.885905    3.389742    0.192154    0.067041    0.019665    0.556145    
#> 411: 0.183205    0.885799    3.389750    0.192236    0.066992    0.019688    0.556180    
#> 412: 0.183223    0.885845    3.389756    0.192177    0.066925    0.019683    0.556241    
#> 413: 0.183106    0.885847    3.389740    0.192006    0.066852    0.019692    0.556344    
#> 414: 0.182995    0.885834    3.389711    0.191888    0.066802    0.019695    0.556323    
#> 415: 0.183029    0.885877    3.389699    0.191834    0.066800    0.019708    0.556289    
#> 416: 0.183118    0.885944    3.389716    0.191930    0.066794    0.019726    0.556256    
#> 417: 0.183133    0.885903    3.389746    0.192000    0.066764    0.019735    0.556197    
#> 418: 0.183100    0.885907    3.389759    0.191982    0.066708    0.019734    0.556119    
#> 419: 0.183116    0.885955    3.389770    0.192036    0.066694    0.019754    0.556079    
#> 420: 0.183144    0.886050    3.389746    0.192078    0.066687    0.019768    0.555951    
#> 421: 0.183007    0.886106    3.389727    0.192110    0.066631    0.019776    0.555871    
#> 422: 0.183037    0.886091    3.389707    0.192156    0.066608    0.019789    0.555818    
#> 423: 0.182912    0.886074    3.389654    0.192187    0.066588    0.019799    0.555806    
#> 424: 0.182649    0.886128    3.389550    0.192142    0.066613    0.019787    0.555828    
#> 425: 0.182541    0.886221    3.389409    0.192225    0.066683    0.019774    0.555886    
#> 426: 0.182444    0.886402    3.389309    0.192242    0.066737    0.019766    0.555826    
#> 427: 0.182286    0.886451    3.389288    0.192243    0.066762    0.019760    0.555773    
#> 428: 0.182193    0.886470    3.389279    0.192124    0.066730    0.019767    0.555730    
#> 429: 0.182079    0.886502    3.389269    0.192068    0.066703    0.019767    0.555691    
#> 430: 0.182030    0.886572    3.389236    0.192097    0.066715    0.019764    0.555713    
#> 431: 0.181991    0.886627    3.389199    0.192064    0.066775    0.019744    0.555644    
#> 432: 0.181956    0.886772    3.389185    0.192076    0.066814    0.019719    0.555623    
#> 433: 0.181924    0.886811    3.389162    0.192074    0.066854    0.019696    0.555600    
#> 434: 0.181874    0.886758    3.389164    0.192056    0.066850    0.019687    0.555558    
#> 435: 0.181861    0.886786    3.389149    0.192112    0.066879    0.019670    0.555495    
#> 436: 0.181882    0.886731    3.389192    0.192118    0.066988    0.019648    0.555529    
#> 437: 0.182011    0.886637    3.389231    0.192169    0.067031    0.019639    0.555552    
#> 438: 0.181950    0.886702    3.389230    0.192186    0.067021    0.019643    0.555508    
#> 439: 0.181944    0.886778    3.389211    0.192195    0.067052    0.019645    0.555455    
#> 440: 0.181914    0.886823    3.389242    0.192258    0.067069    0.019645    0.555408    
#> 441: 0.181900    0.886829    3.389224    0.192223    0.067062    0.019638    0.555352    
#> 442: 0.181768    0.886895    3.389181    0.192242    0.067086    0.019635    0.555285    
#> 443: 0.181641    0.887027    3.389098    0.192310    0.067104    0.019631    0.555223    
#> 444: 0.181456    0.887204    3.389006    0.192339    0.067112    0.019625    0.555178    
#> 445: 0.181242    0.887285    3.388937    0.192361    0.067069    0.019625    0.555182    
#> 446: 0.180972    0.887409    3.388832    0.192328    0.067056    0.019616    0.555162    
#> 447: 0.180907    0.887475    3.388792    0.192260    0.067066    0.019611    0.555185    
#> 448: 0.180799    0.887500    3.388778    0.192103    0.067071    0.019598    0.555154    
#> 449: 0.180818    0.887517    3.388855    0.191864    0.067101    0.019591    0.555195    
#> 450: 0.180788    0.887482    3.388877    0.191664    0.067132    0.019600    0.555227    
#> 451: 0.180792    0.887474    3.388893    0.191516    0.067160    0.019605    0.555282    
#> 452: 0.180873    0.887481    3.388904    0.191265    0.067172    0.019580    0.555346    
#> 453: 0.180838    0.887512    3.388912    0.191045    0.067152    0.019562    0.555373    
#> 454: 0.180826    0.887611    3.388907    0.190957    0.067156    0.019568    0.555337    
#> 455: 0.180819    0.887611    3.388920    0.190926    0.067088    0.019573    0.555302    
#> 456: 0.180767    0.887564    3.388902    0.190973    0.067073    0.019588    0.555258    
#> 457: 0.180765    0.887545    3.388903    0.191057    0.067049    0.019623    0.555181    
#> 458: 0.180736    0.887634    3.388895    0.191134    0.067025    0.019639    0.555141    
#> 459: 0.180462    0.887757    3.388797    0.191209    0.066969    0.019643    0.555188    
#> 460: 0.180291    0.887771    3.388702    0.191288    0.066953    0.019647    0.555202    
#> 461: 0.180155    0.887835    3.388647    0.191332    0.066917    0.019650    0.555164    
#> 462: 0.179960    0.887938    3.388591    0.191263    0.066902    0.019662    0.555109    
#> 463: 0.179893    0.888012    3.388583    0.191224    0.066905    0.019676    0.555080    
#> 464: 0.179936    0.888082    3.388552    0.191159    0.066868    0.019693    0.555002    
#> 465: 0.179967    0.888012    3.388593    0.191054    0.066851    0.019689    0.554949    
#> 466: 0.180044    0.888020    3.388592    0.190986    0.066834    0.019696    0.554926    
#> 467: 0.180041    0.887996    3.388626    0.190922    0.066819    0.019700    0.554842    
#> 468: 0.180208    0.887971    3.388680    0.190970    0.066800    0.019710    0.554800    
#> 469: 0.180272    0.888037    3.388707    0.191096    0.066780    0.019718    0.554784    
#> 470: 0.180195    0.888078    3.388695    0.191184    0.066782    0.019729    0.554767    
#> 471: 0.180170    0.888029    3.388688    0.191246    0.066745    0.019728    0.554752    
#> 472: 0.180108    0.888002    3.388676    0.191278    0.066786    0.019730    0.554742    
#> 473: 0.180016    0.887998    3.388634    0.191279    0.066783    0.019723    0.554719    
#> 474: 0.179916    0.887994    3.388599    0.191281    0.066803    0.019726    0.554741    
#> 475: 0.179886    0.888104    3.388543    0.191258    0.066814    0.019715    0.554764    
#> 476: 0.179809    0.888107    3.388516    0.191280    0.066815    0.019715    0.554773    
#> 477: 0.179787    0.888122    3.388506    0.191242    0.066828    0.019706    0.554714    
#> 478: 0.179689    0.888110    3.388513    0.191214    0.066833    0.019708    0.554733    
#> 479: 0.179675    0.888093    3.388545    0.191190    0.066857    0.019700    0.554743    
#> 480: 0.179707    0.888094    3.388549    0.191183    0.066939    0.019696    0.554730    
#> 481: 0.179745    0.888078    3.388548    0.191042    0.066961    0.019685    0.554744    
#> 482: 0.179828    0.888064    3.388522    0.191059    0.066982    0.019680    0.554782    
#> 483: 0.179789    0.888048    3.388476    0.191124    0.067027    0.019681    0.554778    
#> 484: 0.179769    0.887959    3.388499    0.191193    0.067011    0.019690    0.554774    
#> 485: 0.179764    0.887940    3.388521    0.191277    0.066979    0.019710    0.554801    
#> 486: 0.179769    0.887939    3.388555    0.191261    0.066957    0.019714    0.554760    
#> 487: 0.179872    0.887929    3.388618    0.191256    0.066954    0.019717    0.554729    
#> 488: 0.179925    0.887928    3.388629    0.191153    0.066987    0.019709    0.554697    
#> 489: 0.180043    0.887883    3.388647    0.191140    0.066973    0.019712    0.554692    
#> 490: 0.180180    0.887875    3.388676    0.191216    0.066963    0.019715    0.554658    
#> 491: 0.180239    0.887881    3.388708    0.191167    0.066949    0.019727    0.554631    
#> 492: 0.180222    0.887922    3.388696    0.191105    0.066974    0.019722    0.554665    
#> 493: 0.180224    0.887966    3.388703    0.191076    0.067025    0.019716    0.554703    
#> 494: 0.180256    0.888085    3.388672    0.191004    0.067076    0.019711    0.554696    
#> 495: 0.180223    0.888128    3.388653    0.190968    0.067087    0.019697    0.554676    
#> 496: 0.180202    0.888230    3.388613    0.190899    0.067101    0.019692    0.554665    
#> 497: 0.180227    0.888201    3.388612    0.190927    0.067060    0.019688    0.554704    
#> 498: 0.180207    0.888195    3.388597    0.190918    0.067041    0.019692    0.554644    
#> 499: 0.180208    0.888221    3.388561    0.191028    0.067019    0.019706    0.554582    
#> 500: 0.180214    0.888255    3.388531    0.191121    0.067012    0.019718    0.554508    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.285997    0.975556    3.446302    0.392401    0.081462    0.016800    1.674855    
#> 002: 0.344679    1.061775    3.475473    0.372781    0.077389    0.018334    1.136093    
#> 003: 0.476258    1.048703    3.503072    0.354142    0.073519    0.017417    0.910879    
#> 004: 0.409125    1.065549    3.494919    0.336435    0.069843    0.016547    0.794561    
#> 005: 0.451568    1.073227    3.485833    0.319613    0.066351    0.015719    0.774892    
#> 006: 0.445520    1.071065    3.486737    0.303633    0.063033    0.014933    0.734105    
#> 007: 0.398425    1.083136    3.474781    0.296334    0.063046    0.014187    0.730192    
#> 008: 0.390868    1.082158    3.469192    0.281517    0.064315    0.016319    0.721857    
#> 009: 0.375299    1.075620    3.464826    0.267441    0.062099    0.018383    0.718646    
#> 010: 0.383548    1.084430    3.462678    0.254069    0.060366    0.017895    0.721518    
#> 011: 0.432309    1.091892    3.470862    0.241366    0.063758    0.018626    0.717555    
#> 012: 0.395461    1.080223    3.462886    0.269769    0.060571    0.021489    0.701941    
#> 013: 0.335108    1.088021    3.450189    0.257091    0.057542    0.020415    0.716363    
#> 014: 0.419947    1.095992    3.471233    0.271193    0.074649    0.019394    0.731081    
#> 015: 0.438645    1.093801    3.491643    0.257633    0.070917    0.021058    0.695121    
#> 016: 0.441172    1.096483    3.499562    0.244752    0.067371    0.023789    0.702714    
#> 017: 0.428122    1.095424    3.486677    0.245574    0.064002    0.022600    0.696608    
#> 018: 0.434081    1.088141    3.464886    0.266565    0.060802    0.021470    0.706516    
#> 019: 0.390429    1.081876    3.468933    0.253236    0.057762    0.020396    0.703757    
#> 020: 0.420973    1.086829    3.479789    0.255641    0.059038    0.019376    0.714776    
#> 021: 0.427816    1.055449    3.488750    0.242859    0.056086    0.018408    0.708744    
#> 022: 0.416390    1.072793    3.497945    0.230716    0.053282    0.018445    0.711926    
#> 023: 0.485226    1.076350    3.507367    0.226573    0.053897    0.017967    0.720509    
#> 024: 0.493932    1.092336    3.502008    0.236462    0.051202    0.023417    0.705853    
#> 025: 0.445278    1.062453    3.490274    0.249845    0.048642    0.022246    0.703809    
#> 026: 0.426528    1.080464    3.479916    0.237353    0.046210    0.021134    0.713083    
#> 027: 0.405151    1.095076    3.479933    0.240009    0.044366    0.020077    0.719007    
#> 028: 0.449298    1.080492    3.485036    0.232536    0.042148    0.023389    0.703057    
#> 029: 0.453383    1.070566    3.480644    0.287880    0.047603    0.026070    0.716146    
#> 030: 0.466695    1.089302    3.478788    0.292865    0.045223    0.027343    0.721566    
#> 031: 0.427306    1.074227    3.487692    0.324688    0.042962    0.033028    0.710992    
#> 032: 0.400965    1.056100    3.489124    0.308453    0.040814    0.031377    0.705061    
#> 033: 0.389428    1.077514    3.474569    0.293031    0.038773    0.033020    0.719393    
#> 034: 0.423884    1.093346    3.476805    0.289928    0.037553    0.031369    0.702086    
#> 035: 0.396311    1.084680    3.469703    0.293415    0.037832    0.029800    0.696589    
#> 036: 0.401768    1.079706    3.475593    0.284230    0.038034    0.030226    0.681737    
#> 037: 0.373610    1.086351    3.473983    0.270018    0.038695    0.028715    0.708742    
#> 038: 0.408095    1.081113    3.472235    0.295847    0.036760    0.027279    0.702877    
#> 039: 0.425792    1.073830    3.488979    0.281054    0.038373    0.026970    0.688461    
#> 040: 0.420475    1.080412    3.488219    0.348582    0.039155    0.025622    0.703488    
#> 041: 0.375247    1.074684    3.469780    0.331153    0.037964    0.024341    0.706431    
#> 042: 0.421838    1.079665    3.473197    0.314595    0.038417    0.023124    0.695898    
#> 043: 0.385693    1.109722    3.451342    0.319438    0.041262    0.024843    0.681167    
#> 044: 0.366574    1.110804    3.450968    0.303466    0.043200    0.023601    0.702980    
#> 045: 0.351088    1.131729    3.439713    0.288293    0.047532    0.022421    0.700659    
#> 046: 0.326807    1.128413    3.445478    0.273878    0.045296    0.021300    0.705349    
#> 047: 0.350617    1.117154    3.447461    0.260184    0.045794    0.020235    0.704471    
#> 048: 0.361527    1.101026    3.453165    0.247175    0.051558    0.019223    0.710459    
#> 049: 0.383959    1.109169    3.466094    0.255505    0.054616    0.018588    0.709388    
#> 050: 0.426941    1.090550    3.473296    0.268773    0.066592    0.017659    0.726156    
#> 051: 0.412443    1.085381    3.465775    0.255334    0.070829    0.016776    0.721094    
#> 052: 0.428532    1.089874    3.480507    0.242567    0.067288    0.015937    0.702231    
#> 053: 0.431754    1.078085    3.476785    0.230439    0.063923    0.015140    0.716917    
#> 054: 0.396256    1.076713    3.480203    0.224873    0.060727    0.015037    0.728405    
#> 055: 0.444541    1.058312    3.493341    0.264458    0.057691    0.016078    0.736028    
#> 056: 0.461678    1.054213    3.495540    0.255994    0.054806    0.018292    0.721676    
#> 057: 0.477535    1.064260    3.496048    0.254064    0.052066    0.017378    0.723891    
#> 058: 0.446334    1.065629    3.484220    0.242320    0.054967    0.017171    0.711572    
#> 059: 0.422680    1.023519    3.487301    0.249368    0.052219    0.018701    0.727904    
#> 060: 0.426040    1.028633    3.496628    0.236900    0.054141    0.019785    0.745206    
#> 061: 0.453401    1.045647    3.498768    0.225055    0.051434    0.021737    0.770164    
#> 062: 0.463838    1.051738    3.504701    0.304290    0.063937    0.020650    0.772571    
#> 063: 0.475455    1.039533    3.502322    0.289075    0.065409    0.023067    0.755000    
#> 064: 0.446677    1.054280    3.504271    0.284781    0.062139    0.021913    0.746096    
#> 065: 0.482513    1.033209    3.494005    0.270542    0.059032    0.021270    0.742307    
#> 066: 0.477846    1.053383    3.503031    0.258339    0.056080    0.021015    0.735644    
#> 067: 0.450513    1.053261    3.494901    0.245422    0.053276    0.024390    0.691412    
#> 068: 0.409521    1.074414    3.494291    0.233151    0.053972    0.023170    0.712693    
#> 069: 0.422023    1.092783    3.479562    0.272269    0.054821    0.023019    0.716232    
#> 070: 0.416499    1.094722    3.478953    0.299704    0.052080    0.024318    0.713923    
#> 071: 0.388095    1.124909    3.455554    0.284719    0.057177    0.023102    0.725437    
#> 072: 0.347863    1.086538    3.457048    0.270483    0.054319    0.021947    0.719144    
#> 073: 0.408859    1.093999    3.475649    0.332886    0.051603    0.024543    0.701143    
#> 074: 0.383100    1.081122    3.464092    0.316241    0.049023    0.023316    0.709422    
#> 075: 0.416855    1.078304    3.486301    0.300429    0.046571    0.022228    0.699697    
#> 076: 0.441117    1.074621    3.489033    0.321248    0.044243    0.023037    0.701579    
#> 077: 0.466899    1.060427    3.481608    0.312067    0.042031    0.022735    0.719835    
#> 078: 0.437281    1.071659    3.492389    0.296464    0.039929    0.021703    0.690722    
#> 079: 0.432858    1.091293    3.486073    0.301874    0.045928    0.020618    0.715559    
#> 080: 0.441826    1.079398    3.489694    0.300700    0.043632    0.021815    0.720176    
#> 081: 0.468016    1.070149    3.502663    0.285665    0.041450    0.024615    0.703884    
#> 082: 0.466972    1.059513    3.510031    0.271382    0.039378    0.023384    0.726859    
#> 083: 0.479386    1.051441    3.505968    0.257812    0.037409    0.022215    0.724135    
#> 084: 0.449124    1.066065    3.491407    0.244922    0.043579    0.021104    0.700386    
#> 085: 0.419074    1.078842    3.491599    0.232676    0.044852    0.020049    0.717398    
#> 086: 0.422673    1.080162    3.484167    0.221042    0.051197    0.019046    0.710105    
#> 087: 0.405755    1.083989    3.471303    0.221216    0.050546    0.021356    0.700355    
#> 088: 0.354578    1.069622    3.473764    0.220145    0.048019    0.020288    0.723247    
#> 089: 0.379923    1.098408    3.459018    0.227779    0.062011    0.019274    0.709013    
#> 090: 0.357977    1.088949    3.467272    0.216390    0.058910    0.019695    0.718900    
#> 091: 0.371078    1.076970    3.451811    0.222963    0.055965    0.022326    0.711351    
#> 092: 0.344122    1.128786    3.444482    0.258061    0.053166    0.026436    0.709838    
#> 093: 0.331290    1.103872    3.458422    0.245158    0.050508    0.029082    0.740812    
#> 094: 0.374385    1.110741    3.455181    0.242530    0.047983    0.027628    0.720867    
#> 095: 0.394642    1.110787    3.479873    0.230404    0.047738    0.026411    0.735439    
#> 096: 0.353080    1.126456    3.461379    0.218883    0.049733    0.025091    0.710530    
#> 097: 0.369652    1.117060    3.462878    0.216474    0.053394    0.023836    0.711852    
#> 098: 0.364935    1.119814    3.466683    0.216401    0.050724    0.022645    0.713101    
#> 099: 0.336406    1.111826    3.439555    0.269245    0.053422    0.021512    0.700222    
#> 100: 0.345874    1.103620    3.449762    0.268559    0.052239    0.020437    0.693680    
#> 101: 0.344732    1.095945    3.434774    0.255131    0.056112    0.019415    0.705959    
#> 102: 0.347576    1.096076    3.441826    0.242375    0.053307    0.018444    0.711530    
#> 103: 0.373579    1.094730    3.448402    0.230256    0.050641    0.017522    0.706782    
#> 104: 0.370363    1.106299    3.461229    0.218743    0.048109    0.018726    0.729604    
#> 105: 0.363459    1.098641    3.466265    0.207806    0.046948    0.018426    0.733782    
#> 106: 0.408877    1.103452    3.474982    0.229397    0.045044    0.018170    0.695207    
#> 107: 0.419692    1.105412    3.482483    0.256901    0.050284    0.022304    0.714777    
#> 108: 0.416720    1.095275    3.484680    0.308696    0.053943    0.023410    0.729023    
#> 109: 0.404764    1.083464    3.491904    0.293261    0.051246    0.022240    0.723238    
#> 110: 0.415467    1.074138    3.471976    0.288776    0.048684    0.023677    0.701320    
#> 111: 0.421204    1.077311    3.479050    0.275440    0.049562    0.022493    0.680935    
#> 112: 0.430892    1.064280    3.470896    0.286984    0.047084    0.021604    0.701816    
#> 113: 0.415850    1.097933    3.479754    0.272635    0.044730    0.024936    0.695169    
#> 114: 0.440255    1.091091    3.487439    0.259003    0.042493    0.023689    0.709414    
#> 115: 0.453289    1.059440    3.479372    0.247515    0.045052    0.022505    0.732616    
#> 116: 0.391167    1.090894    3.467945    0.235140    0.045459    0.024408    0.718804    
#> 117: 0.384577    1.107224    3.476883    0.260820    0.044036    0.025452    0.712988    
#> 118: 0.426952    1.094430    3.481125    0.247779    0.057549    0.024180    0.695458    
#> 119: 0.423851    1.092866    3.483727    0.283510    0.054671    0.022971    0.698590    
#> 120: 0.377295    1.075867    3.471038    0.269335    0.056072    0.021822    0.693828    
#> 121: 0.414824    1.112990    3.465417    0.255868    0.066221    0.020731    0.715593    
#> 122: 0.401780    1.077085    3.472244    0.243075    0.062910    0.019694    0.704602    
#> 123: 0.422844    1.105318    3.463386    0.230921    0.059764    0.018710    0.707991    
#> 124: 0.414033    1.152123    3.464746    0.235566    0.070678    0.017774    0.702959    
#> 125: 0.413142    1.130478    3.463166    0.223788    0.067144    0.017126    0.716575    
#> 126: 0.380043    1.129367    3.457569    0.224558    0.063787    0.016270    0.734487    
#> 127: 0.396601    1.099964    3.452581    0.234813    0.060598    0.020433    0.737285    
#> 128: 0.392750    1.090778    3.468375    0.228949    0.059572    0.019411    0.710673    
#> 129: 0.437335    1.103145    3.480740    0.278128    0.067756    0.018441    0.708896    
#> 130: 0.441236    1.099211    3.475515    0.265093    0.064368    0.017519    0.693369    
#> 131: 0.399379    1.088573    3.463840    0.257769    0.069297    0.020748    0.693831    
#> 132: 0.365543    1.103677    3.449926    0.261667    0.065832    0.021535    0.714215    
#> 133: 0.386063    1.099021    3.452417    0.331202    0.062540    0.022523    0.717205    
#> 134: 0.454922    1.068288    3.488261    0.359219    0.059413    0.024392    0.706250    
#> 135: 0.450503    1.060016    3.488216    0.341258    0.056443    0.024467    0.715104    
#> 136: 0.426917    1.043850    3.482898    0.324195    0.053620    0.023244    0.712399    
#> 137: 0.452947    1.042541    3.480100    0.307986    0.050939    0.022082    0.720502    
#> 138: 0.401823    1.071466    3.471474    0.292586    0.048392    0.020977    0.711920    
#> 139: 0.416695    1.089687    3.486363    0.291665    0.053839    0.019929    0.706452    
#> 140: 0.421895    1.099920    3.485749    0.277082    0.051599    0.022205    0.721520    
#> 141: 0.393670    1.077102    3.473927    0.298087    0.049019    0.021095    0.708574    
#> 142: 0.441827    1.071338    3.489982    0.301880    0.050473    0.020040    0.708334    
#> 143: 0.414703    1.084039    3.480724    0.286786    0.053092    0.019038    0.699811    
#> 144: 0.422971    1.082833    3.488614    0.272446    0.050438    0.019264    0.700657    
#> 145: 0.398386    1.097448    3.466985    0.258824    0.047916    0.019384    0.702075    
#> 146: 0.371203    1.107749    3.468361    0.245883    0.045520    0.022308    0.716574    
#> 147: 0.405300    1.078315    3.472682    0.233589    0.047139    0.025144    0.701966    
#> 148: 0.417321    1.087415    3.489017    0.266867    0.045154    0.024743    0.701741    
#> 149: 0.403467    1.078891    3.482589    0.263515    0.042896    0.027200    0.718525    
#> 150: 0.426392    1.079375    3.467204    0.250339    0.040752    0.025840    0.735626    
#> 151: 0.360938    1.103588    3.466461    0.237822    0.042181    0.024548    0.716344    
#> 152: 0.426218    1.086921    3.480538    0.293376    0.043980    0.022558    0.707436    
#> 153: 0.415869    1.091825    3.491573    0.280036    0.056273    0.021943    0.718901    
#> 154: 0.426809    1.109370    3.482338    0.252008    0.041619    0.024801    0.723830    
#> 155: 0.403183    1.091114    3.476436    0.253497    0.036194    0.021383    0.704994    
#> 156: 0.417201    1.092661    3.481630    0.272062    0.032180    0.026213    0.735283    
#> 157: 0.435525    1.085122    3.488197    0.266338    0.024820    0.028482    0.734173    
#> 158: 0.434735    1.106593    3.477093    0.288982    0.025841    0.024094    0.704073    
#> 159: 0.387266    1.116725    3.477684    0.266900    0.030027    0.029104    0.697241    
#> 160: 0.427522    1.085191    3.499820    0.262579    0.032687    0.023365    0.702227    
#> 161: 0.429913    1.068015    3.488990    0.288779    0.036555    0.024161    0.720319    
#> 162: 0.436197    1.084324    3.477534    0.285239    0.035562    0.019434    0.711987    
#> 163: 0.450305    1.061911    3.477204    0.327194    0.037987    0.021893    0.704601    
#> 164: 0.436351    1.085845    3.472904    0.324529    0.043997    0.018831    0.696678    
#> 165: 0.434060    1.069807    3.493253    0.274682    0.046397    0.017484    0.689413    
#> 166: 0.419492    1.095069    3.475548    0.283002    0.046855    0.020371    0.697914    
#> 167: 0.415427    1.108508    3.475962    0.314563    0.042804    0.027875    0.710284    
#> 168: 0.425919    1.118720    3.472229    0.351728    0.043140    0.027119    0.697126    
#> 169: 0.413512    1.133731    3.469666    0.306603    0.038728    0.025706    0.710280    
#> 170: 0.392918    1.097581    3.469957    0.312448    0.035413    0.025366    0.694188    
#> 171: 0.390823    1.098051    3.468766    0.301476    0.037998    0.023660    0.693488    
#> 172: 0.382704    1.126627    3.456464    0.244063    0.045382    0.023405    0.693090    
#> 173: 0.376785    1.132754    3.448113    0.270717    0.042253    0.021050    0.697906    
#> 174: 0.386255    1.121711    3.462990    0.254958    0.043858    0.017622    0.715888    
#> 175: 0.372297    1.107024    3.456263    0.256060    0.053509    0.016471    0.708393    
#> 176: 0.404729    1.123010    3.468785    0.213337    0.048362    0.020038    0.712962    
#> 177: 0.401571    1.105085    3.478753    0.232007    0.041843    0.013205    0.732305    
#> 178: 0.377741    1.091550    3.463891    0.207209    0.048177    0.014258    0.717967    
#> 179: 0.378541    1.121485    3.467441    0.219121    0.057548    0.015385    0.725057    
#> 180: 0.379821    1.115655    3.461077    0.215930    0.057427    0.017501    0.704501    
#> 181: 0.375325    1.101597    3.458329    0.211613    0.052907    0.018889    0.697434    
#> 182: 0.333579    1.129324    3.441101    0.243834    0.062307    0.017759    0.728324    
#> 183: 0.359357    1.139886    3.444691    0.204863    0.060487    0.019336    0.705282    
#> 184: 0.360385    1.116184    3.450212    0.239605    0.052677    0.019737    0.703054    
#> 185: 0.355406    1.111292    3.451845    0.231346    0.056086    0.018688    0.708401    
#> 186: 0.335619    1.145235    3.444998    0.253541    0.050814    0.018728    0.709794    
#> 187: 0.353566    1.108903    3.455631    0.252892    0.048364    0.016078    0.745494    
#> 188: 0.345629    1.124776    3.452174    0.217484    0.050612    0.020217    0.749502    
#> 189: 0.364706    1.125027    3.464011    0.181193    0.054218    0.018766    0.748338    
#> 190: 0.360572    1.103128    3.464134    0.226740    0.049176    0.018195    0.744926    
#> 191: 0.347654    1.107164    3.453569    0.172358    0.044549    0.017220    0.735395    
#> 192: 0.365769    1.096353    3.469855    0.228235    0.044462    0.023044    0.700494    
#> 193: 0.408915    1.108945    3.469789    0.260290    0.044315    0.023715    0.684857    
#> 194: 0.367207    1.102668    3.465903    0.257935    0.043271    0.024321    0.713719    
#> 195: 0.372101    1.093381    3.466118    0.262770    0.039959    0.025771    0.714762    
#> 196: 0.401089    1.092832    3.471541    0.271856    0.045878    0.025737    0.718293    
#> 197: 0.384704    1.109295    3.489413    0.254845    0.044860    0.024633    0.736372    
#> 198: 0.419271    1.098488    3.481509    0.263952    0.042294    0.026519    0.707573    
#> 199: 0.434992    1.090390    3.484804    0.294590    0.043314    0.024563    0.692233    
#> 200: 0.433825    1.086587    3.479600    0.342306    0.037598    0.026361    0.711527    
#> 201: 0.422908    1.074465    3.483856    0.359959    0.035192    0.026776    0.710150    
#> 202: 0.423567    1.077547    3.486595    0.343574    0.036293    0.026734    0.711446    
#> 203: 0.433666    1.078411    3.484385    0.344572    0.038299    0.026001    0.709973    
#> 204: 0.436484    1.073074    3.488220    0.333377    0.040433    0.026103    0.711870    
#> 205: 0.436540    1.078955    3.488182    0.326571    0.041423    0.026468    0.713250    
#> 206: 0.434421    1.082285    3.487641    0.322243    0.040612    0.026575    0.716531    
#> 207: 0.428660    1.083070    3.484036    0.325998    0.039947    0.026525    0.716365    
#> 208: 0.423594    1.082774    3.482686    0.323127    0.039514    0.026759    0.715493    
#> 209: 0.424449    1.082961    3.481631    0.322223    0.039797    0.026676    0.714862    
#> 210: 0.426780    1.082410    3.482042    0.321778    0.039921    0.026197    0.714034    
#> 211: 0.430531    1.083374    3.483472    0.317777    0.039840    0.025811    0.713171    
#> 212: 0.432106    1.082914    3.484101    0.312736    0.040407    0.025336    0.712827    
#> 213: 0.433146    1.080445    3.484464    0.308750    0.041360    0.025254    0.712991    
#> 214: 0.436387    1.079357    3.485192    0.307733    0.041699    0.025285    0.713478    
#> 215: 0.437842    1.078691    3.486388    0.302748    0.041926    0.025434    0.714799    
#> 216: 0.440791    1.077503    3.487157    0.299602    0.041599    0.025466    0.716137    
#> 217: 0.440665    1.078445    3.487497    0.296666    0.041714    0.025437    0.716011    
#> 218: 0.441328    1.079346    3.487159    0.298002    0.041580    0.025167    0.715651    
#> 219: 0.439692    1.079080    3.486473    0.298210    0.041004    0.025179    0.715554    
#> 220: 0.438298    1.079338    3.486303    0.301644    0.041031    0.025344    0.714713    
#> 221: 0.437362    1.078941    3.486218    0.302107    0.040867    0.025210    0.713831    
#> 222: 0.437376    1.077915    3.486175    0.302052    0.040351    0.025124    0.713940    
#> 223: 0.437909    1.078037    3.486348    0.301019    0.040204    0.025024    0.713456    
#> 224: 0.437760    1.079211    3.486018    0.301736    0.040244    0.024808    0.712666    
#> 225: 0.436376    1.078463    3.485880    0.299987    0.040386    0.024615    0.712478    
#> 226: 0.433835    1.077411    3.485000    0.299399    0.040477    0.024364    0.712909    
#> 227: 0.431894    1.077701    3.484805    0.298142    0.040723    0.024257    0.712361    
#> 228: 0.429911    1.079015    3.483959    0.297730    0.040976    0.024083    0.711983    
#> 229: 0.428474    1.079343    3.483491    0.297481    0.041194    0.023818    0.711173    
#> 230: 0.427728    1.079217    3.483086    0.297258    0.041297    0.023603    0.711487    
#> 231: 0.426846    1.079894    3.482662    0.298887    0.041490    0.023648    0.711244    
#> 232: 0.425743    1.080430    3.482571    0.298167    0.041576    0.023706    0.711248    
#> 233: 0.425464    1.079878    3.482819    0.297451    0.041489    0.023830    0.711441    
#> 234: 0.424615    1.079879    3.482933    0.297412    0.041638    0.023810    0.711353    
#> 235: 0.424481    1.079845    3.482869    0.296338    0.041696    0.023824    0.710953    
#> 236: 0.424183    1.080442    3.482367    0.295997    0.041616    0.023806    0.710853    
#> 237: 0.424830    1.080726    3.482358    0.295391    0.041623    0.023885    0.711022    
#> 238: 0.425145    1.081136    3.482396    0.295322    0.041594    0.024004    0.711156    
#> 239: 0.425658    1.081449    3.482380    0.295060    0.041523    0.023884    0.711359    
#> 240: 0.425494    1.081143    3.482346    0.295021    0.041589    0.023807    0.711555    
#> 241: 0.425326    1.080662    3.482609    0.295152    0.041599    0.023783    0.711435    
#> 242: 0.425139    1.080224    3.482339    0.295380    0.041536    0.023856    0.711491    
#> 243: 0.424526    1.080346    3.482230    0.295102    0.041498    0.023926    0.711798    
#> 244: 0.424608    1.079832    3.482670    0.295327    0.041372    0.024063    0.712075    
#> 245: 0.424109    1.079819    3.482574    0.295332    0.041365    0.024036    0.712242    
#> 246: 0.424311    1.079909    3.482514    0.295243    0.041549    0.024037    0.712270    
#> 247: 0.424077    1.080027    3.482341    0.294770    0.041641    0.023933    0.712421    
#> 248: 0.423509    1.080405    3.482213    0.294188    0.041835    0.023774    0.712157    
#> 249: 0.423419    1.080603    3.482240    0.293676    0.041781    0.023740    0.712227    
#> 250: 0.424005    1.080872    3.482317    0.292996    0.041697    0.023731    0.712412    
#> 251: 0.423879    1.081034    3.482545    0.292258    0.041516    0.023739    0.712547    
#> 252: 0.423953    1.080975    3.482918    0.291306    0.041360    0.023699    0.712688    
#> 253: 0.424219    1.081023    3.483041    0.291031    0.041294    0.023703    0.712624    
#> 254: 0.424889    1.081342    3.483182    0.290801    0.041214    0.023747    0.712357    
#> 255: 0.424785    1.081506    3.483201    0.290790    0.041143    0.023798    0.712297    
#> 256: 0.424825    1.081328    3.483148    0.289574    0.041083    0.023781    0.712579    
#> 257: 0.424770    1.080891    3.483134    0.288923    0.041250    0.023762    0.712687    
#> 258: 0.424746    1.080404    3.483099    0.287639    0.041416    0.023655    0.712786    
#> 259: 0.425275    1.080304    3.483214    0.286662    0.041587    0.023647    0.712925    
#> 260: 0.425570    1.080404    3.483399    0.285985    0.041610    0.023684    0.712681    
#> 261: 0.426066    1.080199    3.483592    0.285938    0.041638    0.023701    0.713075    
#> 262: 0.425467    1.080409    3.483487    0.284701    0.041648    0.023652    0.713287    
#> 263: 0.425112    1.080867    3.483361    0.283871    0.041627    0.023608    0.713707    
#> 264: 0.424627    1.081239    3.483160    0.283490    0.041894    0.023563    0.714113    
#> 265: 0.424495    1.081384    3.483058    0.283649    0.041995    0.023574    0.714226    
#> 266: 0.424911    1.081651    3.482998    0.283918    0.042085    0.023511    0.714260    
#> 267: 0.424898    1.081523    3.483099    0.284471    0.042066    0.023477    0.714210    
#> 268: 0.424216    1.081477    3.482826    0.284521    0.042086    0.023488    0.714068    
#> 269: 0.423942    1.081459    3.482656    0.284973    0.042150    0.023432    0.714030    
#> 270: 0.423603    1.081718    3.482366    0.284736    0.042118    0.023399    0.713711    
#> 271: 0.423125    1.081752    3.482109    0.285000    0.042035    0.023377    0.713612    
#> 272: 0.422746    1.081585    3.481965    0.284754    0.042022    0.023346    0.713821    
#> 273: 0.422419    1.081672    3.481905    0.284641    0.042226    0.023335    0.713745    
#> 274: 0.421772    1.081956    3.481827    0.283964    0.042298    0.023300    0.713609    
#> 275: 0.421251    1.082163    3.481547    0.283079    0.042546    0.023280    0.713435    
#> 276: 0.420664    1.082185    3.481527    0.282885    0.042610    0.023312    0.713385    
#> 277: 0.420332    1.082393    3.481461    0.283036    0.042645    0.023313    0.713221    
#> 278: 0.419629    1.082726    3.481178    0.283566    0.042629    0.023318    0.713091    
#> 279: 0.418834    1.083071    3.480771    0.283812    0.042615    0.023329    0.713112    
#> 280: 0.418406    1.083539    3.480561    0.283044    0.042681    0.023247    0.713078    
#> 281: 0.417538    1.083878    3.480447    0.282048    0.042798    0.023136    0.713269    
#> 282: 0.417454    1.084300    3.480370    0.281399    0.042968    0.023047    0.713396    
#> 283: 0.417440    1.084439    3.480395    0.280611    0.043166    0.022968    0.713637    
#> 284: 0.417266    1.084304    3.480444    0.279920    0.043276    0.022890    0.713505    
#> 285: 0.417306    1.084417    3.480395    0.279518    0.043337    0.022872    0.713440    
#> 286: 0.417230    1.084591    3.480352    0.279486    0.043507    0.022884    0.713665    
#> 287: 0.417043    1.084987    3.480256    0.279504    0.043580    0.022916    0.713679    
#> 288: 0.417387    1.084995    3.480292    0.279491    0.043715    0.022856    0.713779    
#> 289: 0.417967    1.084990    3.480417    0.279356    0.043886    0.022802    0.713712    
#> 290: 0.418297    1.084826    3.480585    0.278580    0.044063    0.022732    0.713711    
#> 291: 0.418436    1.084928    3.480645    0.277964    0.044184    0.022664    0.713603    
#> 292: 0.418318    1.085085    3.480617    0.277778    0.044267    0.022611    0.713483    
#> 293: 0.418478    1.085181    3.480618    0.277343    0.044330    0.022560    0.713329    
#> 294: 0.418456    1.085413    3.480545    0.276720    0.044466    0.022527    0.713197    
#> 295: 0.418492    1.085128    3.480612    0.276379    0.044530    0.022487    0.713047    
#> 296: 0.418687    1.084791    3.480729    0.276372    0.044510    0.022483    0.713073    
#> 297: 0.418966    1.084832    3.480785    0.276081    0.044560    0.022461    0.713098    
#> 298: 0.419276    1.084713    3.480792    0.276709    0.044647    0.022441    0.712986    
#> 299: 0.419134    1.084901    3.480679    0.276750    0.044724    0.022420    0.712805    
#> 300: 0.419096    1.084881    3.480670    0.276160    0.044804    0.022391    0.712729    
#> 301: 0.418974    1.084821    3.480508    0.276219    0.044786    0.022354    0.713027    
#> 302: 0.418964    1.084913    3.480344    0.276448    0.044689    0.022368    0.712971    
#> 303: 0.418815    1.085050    3.480159    0.276613    0.044615    0.022389    0.712813    
#> 304: 0.418899    1.085292    3.479978    0.276428    0.044627    0.022373    0.712812    
#> 305: 0.418660    1.085166    3.479842    0.276231    0.044613    0.022348    0.712629    
#> 306: 0.418235    1.085101    3.479619    0.276195    0.044563    0.022324    0.712598    
#> 307: 0.417844    1.085134    3.479426    0.275834    0.044567    0.022325    0.712869    
#> 308: 0.417493    1.085027    3.479335    0.275891    0.044571    0.022290    0.713132    
#> 309: 0.417494    1.084781    3.479326    0.275675    0.044546    0.022261    0.713218    
#> 310: 0.417826    1.084536    3.479301    0.275893    0.044500    0.022233    0.713329    
#> 311: 0.417860    1.084651    3.479270    0.275975    0.044493    0.022247    0.713252    
#> 312: 0.417448    1.084714    3.479063    0.275397    0.044481    0.022254    0.713256    
#> 313: 0.416939    1.084685    3.478843    0.274945    0.044430    0.022257    0.713391    
#> 314: 0.416434    1.084664    3.478634    0.274752    0.044399    0.022261    0.713361    
#> 315: 0.416017    1.084670    3.478486    0.275111    0.044390    0.022296    0.713194    
#> 316: 0.415965    1.084733    3.478393    0.275361    0.044411    0.022253    0.713227    
#> 317: 0.415971    1.084737    3.478334    0.275395    0.044491    0.022224    0.713286    
#> 318: 0.415889    1.084787    3.478240    0.275480    0.044581    0.022206    0.713167    
#> 319: 0.415927    1.084720    3.478253    0.275831    0.044637    0.022172    0.713155    
#> 320: 0.415556    1.084754    3.478085    0.275797    0.044685    0.022158    0.713246    
#> 321: 0.415107    1.085161    3.477899    0.275227    0.044832    0.022109    0.713460    
#> 322: 0.415227    1.085310    3.477772    0.275325    0.044827    0.022084    0.713475    
#> 323: 0.414717    1.085412    3.477650    0.275663    0.044878    0.022086    0.713528    
#> 324: 0.414590    1.085566    3.477624    0.275656    0.044849    0.022068    0.713651    
#> 325: 0.414525    1.085720    3.477523    0.275640    0.044814    0.022082    0.713596    
#> 326: 0.414318    1.085711    3.477394    0.275725    0.044795    0.022101    0.713497    
#> 327: 0.414191    1.085714    3.477288    0.276079    0.044743    0.022093    0.713401    
#> 328: 0.414350    1.085899    3.477143    0.276398    0.044731    0.022099    0.713357    
#> 329: 0.414356    1.085993    3.477088    0.276580    0.044699    0.022070    0.713225    
#> 330: 0.414133    1.085959    3.477076    0.276521    0.044708    0.022098    0.713116    
#> 331: 0.414056    1.086107    3.476997    0.276620    0.044681    0.022102    0.712984    
#> 332: 0.413851    1.086079    3.476966    0.276760    0.044628    0.022133    0.713000    
#> 333: 0.413537    1.086215    3.476790    0.276769    0.044645    0.022124    0.712926    
#> 334: 0.413043    1.086373    3.476493    0.276822    0.044622    0.022085    0.712919    
#> 335: 0.412802    1.086533    3.476275    0.277088    0.044666    0.022067    0.712998    
#> 336: 0.412511    1.086713    3.476148    0.277153    0.044673    0.022065    0.713082    
#> 337: 0.412327    1.086991    3.475961    0.277561    0.044688    0.022046    0.713018    
#> 338: 0.412430    1.087019    3.475951    0.277604    0.044695    0.021970    0.712951    
#> 339: 0.412250    1.087168    3.475841    0.277723    0.044692    0.021922    0.712836    
#> 340: 0.411965    1.087122    3.475799    0.277577    0.044720    0.021873    0.712779    
#> 341: 0.411861    1.087167    3.475808    0.277418    0.044703    0.021837    0.712803    
#> 342: 0.411549    1.087131    3.475698    0.277034    0.044676    0.021811    0.712732    
#> 343: 0.411218    1.087212    3.475663    0.276803    0.044713    0.021806    0.712665    
#> 344: 0.411270    1.087184    3.475718    0.276557    0.044691    0.021796    0.712759    
#> 345: 0.411289    1.087179    3.475775    0.276307    0.044766    0.021787    0.712724    
#> 346: 0.411262    1.087266    3.475695    0.276064    0.044825    0.021740    0.712677    
#> 347: 0.411354    1.087247    3.475622    0.275833    0.044811    0.021732    0.712739    
#> 348: 0.411028    1.087469    3.475511    0.275475    0.044780    0.021722    0.712804    
#> 349: 0.410891    1.087505    3.475458    0.275178    0.044785    0.021741    0.712692    
#> 350: 0.410515    1.087411    3.475371    0.275034    0.044798    0.021737    0.712601    
#> 351: 0.410361    1.087526    3.475277    0.275274    0.044843    0.021747    0.712429    
#> 352: 0.409932    1.087690    3.475213    0.275438    0.044842    0.021746    0.712572    
#> 353: 0.409897    1.087902    3.475156    0.275300    0.044964    0.021753    0.712654    
#> 354: 0.409994    1.088045    3.475084    0.275218    0.045042    0.021744    0.712676    
#> 355: 0.410362    1.087889    3.475109    0.274967    0.045140    0.021726    0.712652    
#> 356: 0.410561    1.087718    3.475180    0.275065    0.045189    0.021721    0.712733    
#> 357: 0.411042    1.087658    3.475256    0.275308    0.045150    0.021721    0.712677    
#> 358: 0.411168    1.087622    3.475348    0.275395    0.045100    0.021727    0.712669    
#> 359: 0.410926    1.087702    3.475299    0.275207    0.045114    0.021734    0.712488    
#> 360: 0.410711    1.087764    3.475196    0.274965    0.045085    0.021710    0.712444    
#> 361: 0.410468    1.087795    3.475086    0.274656    0.045131    0.021710    0.712271    
#> 362: 0.410385    1.087865    3.474975    0.274520    0.045157    0.021700    0.712059    
#> 363: 0.410477    1.087845    3.474986    0.274243    0.045138    0.021691    0.711929    
#> 364: 0.410516    1.087887    3.474962    0.274055    0.045072    0.021695    0.711902    
#> 365: 0.410611    1.087775    3.475036    0.273702    0.045062    0.021689    0.712006    
#> 366: 0.410952    1.087719    3.475084    0.273464    0.045080    0.021682    0.712130    
#> 367: 0.411045    1.087692    3.475132    0.273247    0.045048    0.021672    0.712185    
#> 368: 0.411223    1.087749    3.475089    0.273110    0.045074    0.021638    0.712138    
#> 369: 0.411097    1.087682    3.475068    0.272958    0.045074    0.021590    0.712219    
#> 370: 0.410912    1.087641    3.474983    0.272783    0.045204    0.021545    0.712304    
#> 371: 0.410822    1.087589    3.474916    0.272794    0.045266    0.021513    0.712315    
#> 372: 0.410853    1.087587    3.474920    0.272876    0.045329    0.021500    0.712282    
#> 373: 0.410853    1.087671    3.474920    0.272864    0.045394    0.021482    0.712336    
#> 374: 0.410842    1.087682    3.474952    0.272853    0.045413    0.021486    0.712331    
#> 375: 0.410756    1.087821    3.474954    0.272751    0.045448    0.021489    0.712306    
#> 376: 0.410727    1.087901    3.474949    0.272600    0.045459    0.021474    0.712291    
#> 377: 0.410724    1.088016    3.474932    0.272463    0.045500    0.021480    0.712341    
#> 378: 0.410584    1.088100    3.474830    0.272240    0.045489    0.021485    0.712308    
#> 379: 0.410412    1.088039    3.474811    0.271906    0.045483    0.021466    0.712269    
#> 380: 0.410253    1.087972    3.474812    0.271749    0.045455    0.021440    0.712292    
#> 381: 0.410357    1.087907    3.474804    0.271488    0.045420    0.021418    0.712275    
#> 382: 0.410410    1.087891    3.474809    0.270980    0.045391    0.021401    0.712272    
#> 383: 0.410529    1.087887    3.474834    0.270765    0.045378    0.021406    0.712186    
#> 384: 0.410290    1.087891    3.474792    0.270651    0.045425    0.021384    0.712154    
#> 385: 0.410268    1.087918    3.474788    0.270519    0.045470    0.021372    0.712116    
#> 386: 0.410314    1.087962    3.474823    0.270342    0.045623    0.021366    0.712091    
#> 387: 0.410527    1.087965    3.474939    0.270328    0.045690    0.021360    0.712093    
#> 388: 0.410622    1.087902    3.475023    0.270016    0.045797    0.021342    0.712117    
#> 389: 0.410768    1.087594    3.475063    0.269624    0.045863    0.021317    0.712302    
#> 390: 0.410654    1.087565    3.475058    0.269208    0.045867    0.021315    0.712412    
#> 391: 0.410750    1.087582    3.474989    0.269264    0.045895    0.021303    0.712400    
#> 392: 0.410738    1.087663    3.475016    0.269206    0.045943    0.021297    0.712366    
#> 393: 0.410709    1.087620    3.474994    0.269102    0.045969    0.021292    0.712343    
#> 394: 0.410766    1.087621    3.474972    0.269241    0.045963    0.021326    0.712329    
#> 395: 0.410931    1.087728    3.474945    0.269247    0.046000    0.021367    0.712272    
#> 396: 0.411093    1.087768    3.474952    0.269178    0.045973    0.021407    0.712220    
#> 397: 0.411147    1.087731    3.474989    0.269240    0.045989    0.021437    0.712251    
#> 398: 0.411229    1.087663    3.475070    0.269421    0.045935    0.021462    0.712302    
#> 399: 0.411353    1.087741    3.475168    0.269604    0.045938    0.021458    0.712348    
#> 400: 0.411533    1.087811    3.475205    0.269617    0.045910    0.021450    0.712374    
#> 401: 0.411631    1.087829    3.475225    0.269684    0.045879    0.021449    0.712416    
#> 402: 0.411642    1.087790    3.475261    0.269440    0.045897    0.021446    0.712455    
#> 403: 0.411880    1.087676    3.475334    0.269508    0.045906    0.021447    0.712384    
#> 404: 0.411909    1.087581    3.475303    0.269390    0.045940    0.021431    0.712324    
#> 405: 0.411936    1.087549    3.475326    0.269226    0.045923    0.021418    0.712376    
#> 406: 0.412074    1.087554    3.475312    0.269460    0.045965    0.021412    0.712401    
#> 407: 0.412138    1.087586    3.475395    0.269657    0.045921    0.021413    0.712346    
#> 408: 0.412323    1.087605    3.475451    0.269657    0.045875    0.021404    0.712425    
#> 409: 0.412333    1.087573    3.475440    0.269745    0.045849    0.021396    0.712464    
#> 410: 0.412314    1.087577    3.475404    0.269875    0.045880    0.021364    0.712556    
#> 411: 0.412292    1.087460    3.475372    0.269877    0.045901    0.021349    0.712652    
#> 412: 0.412269    1.087486    3.475357    0.269736    0.045848    0.021357    0.712693    
#> 413: 0.412264    1.087520    3.475318    0.269946    0.045841    0.021347    0.712720    
#> 414: 0.412275    1.087575    3.475328    0.270182    0.045857    0.021335    0.712703    
#> 415: 0.412479    1.087492    3.475357    0.270270    0.045887    0.021328    0.712695    
#> 416: 0.412506    1.087574    3.475351    0.270177    0.045895    0.021317    0.712629    
#> 417: 0.412500    1.087473    3.475356    0.269898    0.045910    0.021313    0.712634    
#> 418: 0.412338    1.087463    3.475363    0.269855    0.045871    0.021305    0.712631    
#> 419: 0.412410    1.087584    3.475365    0.269900    0.045853    0.021293    0.712664    
#> 420: 0.412521    1.087613    3.475390    0.269640    0.045808    0.021283    0.712679    
#> 421: 0.412523    1.087608    3.475477    0.269551    0.045764    0.021285    0.712716    
#> 422: 0.412627    1.087485    3.475525    0.269650    0.045770    0.021276    0.712744    
#> 423: 0.412974    1.087303    3.475587    0.269531    0.045813    0.021282    0.712780    
#> 424: 0.412957    1.087239    3.475559    0.269369    0.045873    0.021281    0.712789    
#> 425: 0.413178    1.087233    3.475601    0.269225    0.045957    0.021277    0.712832    
#> 426: 0.413281    1.087232    3.475667    0.269062    0.046005    0.021282    0.712816    
#> 427: 0.413284    1.087167    3.475753    0.268988    0.046005    0.021285    0.712922    
#> 428: 0.413235    1.087099    3.475790    0.269043    0.045973    0.021300    0.712943    
#> 429: 0.413292    1.087104    3.475832    0.268981    0.045947    0.021313    0.712908    
#> 430: 0.413357    1.087121    3.475858    0.269037    0.045939    0.021338    0.712840    
#> 431: 0.413371    1.087120    3.475852    0.268859    0.045936    0.021331    0.712845    
#> 432: 0.413391    1.087090    3.475883    0.268686    0.045968    0.021329    0.712804    
#> 433: 0.413453    1.087075    3.475940    0.268601    0.046023    0.021322    0.712779    
#> 434: 0.413302    1.086981    3.475914    0.268638    0.046064    0.021322    0.712736    
#> 435: 0.413296    1.086904    3.475905    0.268483    0.046112    0.021314    0.712688    
#> 436: 0.413270    1.086802    3.475966    0.268237    0.046132    0.021310    0.712669    
#> 437: 0.413319    1.086705    3.475990    0.268254    0.046131    0.021310    0.712670    
#> 438: 0.413242    1.086856    3.475970    0.268177    0.046139    0.021279    0.712678    
#> 439: 0.413170    1.086938    3.475942    0.268161    0.046125    0.021248    0.712687    
#> 440: 0.413128    1.086962    3.475959    0.267985    0.046126    0.021234    0.712663    
#> 441: 0.413135    1.086907    3.476013    0.267925    0.046143    0.021238    0.712598    
#> 442: 0.413082    1.086858    3.476068    0.267725    0.046115    0.021220    0.712561    
#> 443: 0.413062    1.086918    3.476028    0.267625    0.046070    0.021231    0.712507    
#> 444: 0.412915    1.087037    3.475904    0.267511    0.046041    0.021244    0.712448    
#> 445: 0.412732    1.087158    3.475820    0.267527    0.046062    0.021227    0.712470    
#> 446: 0.412382    1.087245    3.475751    0.267601    0.046059    0.021224    0.712438    
#> 447: 0.412355    1.087339    3.475710    0.267602    0.046065    0.021217    0.712411    
#> 448: 0.412246    1.087424    3.475666    0.267683    0.046021    0.021240    0.712329    
#> 449: 0.412273    1.087528    3.475727    0.267870    0.046029    0.021250    0.712300    
#> 450: 0.412250    1.087535    3.475704    0.267917    0.045997    0.021253    0.712328    
#> 451: 0.412257    1.087602    3.475645    0.267978    0.045980    0.021256    0.712344    
#> 452: 0.412171    1.087665    3.475581    0.267981    0.045991    0.021253    0.712323    
#> 453: 0.411966    1.087750    3.475525    0.267875    0.045974    0.021245    0.712304    
#> 454: 0.411845    1.087908    3.475462    0.267684    0.045979    0.021240    0.712303    
#> 455: 0.411768    1.088019    3.475399    0.267494    0.045992    0.021240    0.712373    
#> 456: 0.411628    1.088042    3.475346    0.267251    0.046034    0.021240    0.712403    
#> 457: 0.411558    1.088053    3.475373    0.267023    0.046055    0.021227    0.712334    
#> 458: 0.411538    1.088120    3.475415    0.266873    0.046074    0.021211    0.712342    
#> 459: 0.411412    1.088216    3.475400    0.266712    0.046072    0.021198    0.712413    
#> 460: 0.411248    1.088244    3.475293    0.266787    0.046066    0.021195    0.712414    
#> 461: 0.411080    1.088364    3.475234    0.266842    0.046034    0.021189    0.712466    
#> 462: 0.410896    1.088428    3.475206    0.266863    0.045994    0.021184    0.712496    
#> 463: 0.410933    1.088495    3.475255    0.266755    0.045977    0.021197    0.712466    
#> 464: 0.411025    1.088578    3.475258    0.266666    0.045955    0.021210    0.712410    
#> 465: 0.411056    1.088519    3.475258    0.266630    0.045915    0.021217    0.712372    
#> 466: 0.410926    1.088588    3.475173    0.266646    0.045888    0.021208    0.712321    
#> 467: 0.410797    1.088624    3.475158    0.266765    0.045873    0.021219    0.712249    
#> 468: 0.410867    1.088678    3.475174    0.266767    0.045862    0.021225    0.712235    
#> 469: 0.410700    1.088809    3.475113    0.266775    0.045873    0.021240    0.712251    
#> 470: 0.410488    1.088967    3.474995    0.266858    0.045891    0.021262    0.712266    
#> 471: 0.410239    1.089054    3.474924    0.266845    0.045905    0.021264    0.712194    
#> 472: 0.410144    1.089100    3.474885    0.266747    0.045908    0.021269    0.712171    
#> 473: 0.410052    1.089133    3.474891    0.266964    0.045910    0.021287    0.712103    
#> 474: 0.410092    1.089175    3.474874    0.267111    0.045928    0.021287    0.712152    
#> 475: 0.410067    1.089269    3.474871    0.267133    0.045954    0.021300    0.712151    
#> 476: 0.410016    1.089228    3.474855    0.267025    0.045974    0.021310    0.712211    
#> 477: 0.410025    1.089249    3.474866    0.267033    0.045970    0.021317    0.712129    
#> 478: 0.409964    1.089213    3.474859    0.267061    0.045984    0.021308    0.712138    
#> 479: 0.410093    1.089240    3.474887    0.267024    0.045997    0.021295    0.712169    
#> 480: 0.410166    1.089265    3.474883    0.267026    0.046003    0.021308    0.712174    
#> 481: 0.410096    1.089297    3.474854    0.267259    0.045994    0.021319    0.712174    
#> 482: 0.410170    1.089276    3.474804    0.267423    0.045978    0.021334    0.712183    
#> 483: 0.409978    1.089217    3.474791    0.267372    0.045947    0.021338    0.712221    
#> 484: 0.409961    1.089078    3.474805    0.267418    0.045920    0.021340    0.712247    
#> 485: 0.409987    1.089087    3.474833    0.267388    0.045935    0.021333    0.712286    
#> 486: 0.409907    1.089079    3.474838    0.267592    0.045945    0.021332    0.712268    
#> 487: 0.410078    1.089117    3.474912    0.267757    0.045938    0.021341    0.712225    
#> 488: 0.410114    1.089149    3.474953    0.267805    0.045904    0.021349    0.712162    
#> 489: 0.410209    1.089121    3.474960    0.267841    0.045877    0.021350    0.712147    
#> 490: 0.410329    1.089132    3.474993    0.267846    0.045862    0.021348    0.712127    
#> 491: 0.410404    1.089143    3.475043    0.267970    0.045838    0.021353    0.712144    
#> 492: 0.410407    1.089197    3.475068    0.268068    0.045831    0.021355    0.712159    
#> 493: 0.410453    1.089200    3.475111    0.267881    0.045837    0.021362    0.712177    
#> 494: 0.410577    1.089261    3.475106    0.267787    0.045843    0.021363    0.712142    
#> 495: 0.410591    1.089329    3.475103    0.267663    0.045844    0.021382    0.712079    
#> 496: 0.410673    1.089390    3.475098    0.267547    0.045832    0.021390    0.712107    
#> 497: 0.410729    1.089367    3.475104    0.267460    0.045828    0.021398    0.712079    
#> 498: 0.410721    1.089334    3.475091    0.267485    0.045807    0.021398    0.712039    
#> 499: 0.410724    1.089348    3.475055    0.267466    0.045791    0.021396    0.712022    
#> 500: 0.410764    1.089316    3.475032    0.267348    0.045789    0.021392    0.712049    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.245359    0.975557    3.446974    0.392401    0.090326    0.016800    1.615315    
#> 002: 0.156762    0.990437    3.484992    0.372781    0.085809    0.016189    1.052804    
#> 003: 0.165180    0.954789    3.490474    0.354142    0.081519    0.016177    0.763617    
#> 004: 0.110554    0.952657    3.473700    0.336435    0.091722    0.015368    0.700349    
#> 005: 0.123614    0.964700    3.455160    0.319613    0.102276    0.014600    0.668703    
#> 006: 0.056437    0.978363    3.446163    0.303633    0.097162    0.015958    0.626321    
#> 007: 0.067164    0.992015    3.442349    0.288451    0.104034    0.016983    0.627293    
#> 008: 0.035978    0.992281    3.427093    0.274029    0.109766    0.020974    0.625937    
#> 009: -0.006190   0.984662    3.414088    0.260327    0.112439    0.021313    0.626073    
#> 010: -0.006170   0.989192    3.412072    0.247311    0.106817    0.020247    0.628620    
#> 011: 0.010608    1.008894    3.409107    0.234945    0.108014    0.019851    0.630763    
#> 012: 0.029812    1.022001    3.409388    0.223198    0.102613    0.018859    0.625779    
#> 013: -0.005476   1.017089    3.401183    0.212038    0.097482    0.018324    0.634845    
#> 014: 0.010070    1.006306    3.405786    0.201436    0.097902    0.017408    0.638819    
#> 015: 0.009637    1.001558    3.408599    0.191364    0.093007    0.019209    0.625450    
#> 016: 0.006602    1.016889    3.414626    0.181796    0.093541    0.021303    0.628901    
#> 017: 0.025015    1.016260    3.417697    0.172706    0.092259    0.024507    0.599524    
#> 018: 0.022072    1.010898    3.404944    0.164071    0.087646    0.024079    0.612949    
#> 019: -0.000083   1.009226    3.418657    0.155867    0.083264    0.025249    0.605309    
#> 020: 0.027380    1.020081    3.411427    0.171523    0.091473    0.027522    0.608342    
#> 021: 0.023673    1.012330    3.414115    0.162947    0.086900    0.026146    0.603020    
#> 022: 0.021813    1.017937    3.424676    0.154800    0.082555    0.026679    0.598666    
#> 023: 0.074739    1.021521    3.434478    0.147060    0.078427    0.028737    0.627851    
#> 024: 0.105690    1.025407    3.443626    0.139707    0.089285    0.027301    0.639230    
#> 025: 0.086380    0.991822    3.435340    0.132721    0.084821    0.028909    0.628817    
#> 026: 0.043756    1.010843    3.431955    0.138308    0.082665    0.031469    0.625442    
#> 027: 0.045968    1.035820    3.425975    0.131393    0.086369    0.032433    0.614716    
#> 028: 0.066282    1.008079    3.437225    0.124823    0.082051    0.034799    0.609573    
#> 029: 0.033884    1.006988    3.414749    0.118582    0.077998    0.033059    0.622339    
#> 030: 0.026753    1.026898    3.420369    0.112653    0.097399    0.031406    0.621839    
#> 031: 0.032544    1.000880    3.421894    0.107020    0.097936    0.029836    0.611927    
#> 032: 0.038763    0.978277    3.442180    0.101669    0.093040    0.028344    0.612588    
#> 033: 0.026678    0.990421    3.436341    0.120245    0.091900    0.026927    0.622233    
#> 034: 0.065340    1.001886    3.438555    0.118398    0.099830    0.025581    0.609564    
#> 035: 0.052541    0.980381    3.430975    0.112478    0.102143    0.024302    0.604417    
#> 036: 0.080659    0.985993    3.440470    0.106855    0.097035    0.023928    0.604003    
#> 037: 0.060732    0.990688    3.432819    0.105399    0.096396    0.022732    0.607237    
#> 038: 0.050817    1.019663    3.423018    0.106737    0.094021    0.021595    0.618174    
#> 039: 0.070213    0.992853    3.434053    0.128428    0.089320    0.020794    0.592819    
#> 040: 0.044530    1.001535    3.433925    0.132361    0.084854    0.020959    0.623101    
#> 041: 0.000128    1.005330    3.422531    0.125743    0.084726    0.019911    0.626168    
#> 042: 0.023453    0.997821    3.414832    0.127018    0.082641    0.020384    0.612516    
#> 043: -0.001723   1.023784    3.408310    0.120667    0.088204    0.020940    0.614515    
#> 044: -0.014996   1.020831    3.400920    0.114634    0.092823    0.019893    0.617751    
#> 045: -0.019249   1.044305    3.384286    0.113532    0.097138    0.018912    0.630593    
#> 046: 0.007205    1.032678    3.388743    0.148012    0.092282    0.019085    0.643593    
#> 047: 0.022588    1.031207    3.398324    0.140612    0.087667    0.018131    0.630590    
#> 048: 0.014087    1.021695    3.405766    0.133581    0.095829    0.018787    0.626071    
#> 049: 0.009360    1.029932    3.407974    0.126902    0.107519    0.020840    0.621754    
#> 050: 0.039819    1.006893    3.417105    0.123330    0.102143    0.020161    0.639711    
#> 051: 0.007813    1.017281    3.403798    0.129319    0.097036    0.025998    0.646331    
#> 052: 0.026513    1.020734    3.422343    0.122853    0.092184    0.024698    0.616952    
#> 053: 0.047190    1.014177    3.414581    0.127647    0.100479    0.023708    0.598873    
#> 054: 0.012416    1.003042    3.421783    0.121265    0.095455    0.026075    0.624849    
#> 055: 0.030305    1.001451    3.431025    0.115202    0.090682    0.024771    0.630735    
#> 056: 0.073349    0.984623    3.440113    0.111626    0.086148    0.025337    0.619202    
#> 057: 0.099595    0.968628    3.459588    0.128251    0.081841    0.027546    0.632339    
#> 058: 0.067296    0.961650    3.445352    0.121838    0.077749    0.026169    0.623108    
#> 059: 0.075876    0.942717    3.454679    0.121907    0.073861    0.024861    0.637596    
#> 060: 0.081950    0.950634    3.459272    0.127861    0.072338    0.025650    0.631908    
#> 061: 0.089891    0.982714    3.454907    0.126957    0.080598    0.024368    0.649935    
#> 062: 0.090637    1.000381    3.452712    0.120609    0.087298    0.023149    0.655180    
#> 063: 0.111425    0.955456    3.458460    0.121466    0.089050    0.022357    0.637584    
#> 064: 0.089591    0.978703    3.452046    0.115393    0.084598    0.021239    0.626796    
#> 065: 0.110962    0.972593    3.440464    0.109623    0.084109    0.020177    0.627811    
#> 066: 0.110024    0.988302    3.456129    0.104142    0.083450    0.022763    0.611134    
#> 067: 0.092931    0.967008    3.442716    0.101017    0.084064    0.025023    0.602293    
#> 068: 0.073762    0.979214    3.449489    0.112047    0.099492    0.024958    0.599304    
#> 069: 0.051147    0.996887    3.438271    0.106445    0.096127    0.023710    0.625312    
#> 070: 0.072761    0.999560    3.441829    0.101123    0.092164    0.024701    0.617522    
#> 071: 0.055139    1.005175    3.434598    0.100313    0.109535    0.023466    0.615484    
#> 072: 0.019232    0.979336    3.435282    0.095297    0.104058    0.025707    0.631404    
#> 073: 0.058021    0.999596    3.454468    0.090532    0.098855    0.024422    0.639620    
#> 074: 0.048117    0.975011    3.442901    0.086006    0.093913    0.023201    0.632174    
#> 075: 0.081844    0.967489    3.468586    0.081705    0.090882    0.022041    0.633336    
#> 076: 0.057648    0.992129    3.453716    0.082385    0.102591    0.020938    0.633015    
#> 077: 0.076533    0.977641    3.443130    0.078266    0.097461    0.019892    0.637444    
#> 078: 0.059285    1.004022    3.424991    0.078447    0.092588    0.018897    0.631030    
#> 079: 0.065355    1.008444    3.434244    0.084637    0.087959    0.017952    0.658901    
#> 080: 0.063094    1.000020    3.438628    0.093443    0.083616    0.017055    0.660468    
#> 081: 0.067096    1.003109    3.433948    0.088771    0.085709    0.016982    0.628790    
#> 082: 0.049689    0.972686    3.437737    0.084332    0.081424    0.019439    0.626517    
#> 083: 0.062323    1.003601    3.436044    0.085351    0.081859    0.021223    0.622297    
#> 084: 0.041037    0.999205    3.428191    0.101255    0.084355    0.022284    0.604381    
#> 085: 0.043083    1.023564    3.441839    0.096192    0.099362    0.021170    0.627593    
#> 086: 0.023028    1.027999    3.422540    0.091911    0.097634    0.020111    0.607915    
#> 087: -0.004864   1.013285    3.404193    0.094795    0.101346    0.019106    0.615672    
#> 088: -0.030153   1.020095    3.408252    0.131106    0.096279    0.018150    0.635248    
#> 089: 0.008369    1.035067    3.406664    0.131121    0.104556    0.021085    0.619468    
#> 090: 0.001354    1.026742    3.414483    0.124565    0.099328    0.022268    0.619812    
#> 091: 0.002422    1.008786    3.404242    0.118337    0.094362    0.022227    0.621118    
#> 092: -0.005555   1.022352    3.400577    0.118169    0.089644    0.021438    0.622028    
#> 093: -0.017939   1.022262    3.398243    0.143279    0.089805    0.020366    0.633877    
#> 094: -0.010172   1.031554    3.388822    0.136115    0.085315    0.022961    0.620404    
#> 095: -0.000055   1.016935    3.404518    0.131966    0.084665    0.026704    0.626349    
#> 096: -0.006723   1.013312    3.415293    0.137145    0.089771    0.025369    0.614941    
#> 097: 0.022094    1.031455    3.412933    0.130287    0.085283    0.024936    0.617655    
#> 098: 0.005624    1.029792    3.416182    0.123773    0.081019    0.025592    0.615273    
#> 099: 0.016263    0.992479    3.417687    0.122623    0.083415    0.026359    0.601668    
#> 100: -0.002147   1.025978    3.408120    0.120059    0.088725    0.025041    0.598963    
#> 101: -0.013105   1.017350    3.390017    0.114555    0.084289    0.023789    0.596320    
#> 102: -0.035152   1.029925    3.385357    0.111476    0.092902    0.022600    0.615860    
#> 103: 0.000588    1.025015    3.406477    0.132036    0.088257    0.022939    0.603547    
#> 104: -0.013302   1.020761    3.414270    0.125434    0.083844    0.022981    0.615712    
#> 105: 0.012892    1.024438    3.419225    0.119163    0.096790    0.021832    0.622893    
#> 106: 0.022127    1.027182    3.406410    0.113204    0.091951    0.020740    0.603133    
#> 107: 0.016880    1.019857    3.416396    0.108718    0.087353    0.022144    0.620123    
#> 108: 0.024529    0.999217    3.418261    0.108061    0.092972    0.021037    0.633740    
#> 109: 0.015581    1.007237    3.416860    0.121712    0.088324    0.019985    0.617327    
#> 110: 0.039055    0.989483    3.414036    0.118903    0.083907    0.018985    0.615054    
#> 111: 0.041430    0.997640    3.423445    0.117153    0.079712    0.018704    0.614106    
#> 112: 0.018544    0.987330    3.414467    0.111295    0.078845    0.017768    0.627114    
#> 113: 0.035812    1.024445    3.422226    0.105730    0.074902    0.019002    0.618064    
#> 114: 0.031663    1.011837    3.417577    0.100444    0.077331    0.021855    0.615967    
#> 115: 0.044347    0.990583    3.417623    0.114559    0.078057    0.023069    0.625674    
#> 116: 0.002898    1.022697    3.404791    0.117452    0.078483    0.026571    0.618480    
#> 117: -0.008160   1.025443    3.408874    0.111580    0.079760    0.025242    0.620259    
#> 118: 0.003798    1.009446    3.412463    0.107721    0.093070    0.025334    0.608425    
#> 119: 0.006373    1.005271    3.411967    0.110219    0.088417    0.028023    0.598978    
#> 120: 0.002628    1.002717    3.409425    0.104708    0.085916    0.026622    0.614060    
#> 121: -0.003792   1.046312    3.401884    0.107058    0.108589    0.025291    0.619423    
#> 122: 0.019700    1.006523    3.421532    0.112022    0.103159    0.024027    0.601651    
#> 123: 0.051569    1.029108    3.419405    0.119516    0.098001    0.023398    0.600825    
#> 124: 0.039085    1.026330    3.421615    0.113540    0.093101    0.022394    0.603632    
#> 125: 0.062102    1.008046    3.430573    0.122377    0.088446    0.027092    0.597072    
#> 126: 0.015317    1.027099    3.410927    0.167634    0.092692    0.026374    0.614094    
#> 127: 0.054233    1.004678    3.417438    0.159654    0.088057    0.029298    0.609370    
#> 128: 0.011863    1.016258    3.428885    0.151672    0.084466    0.031462    0.605521    
#> 129: 0.026206    1.023673    3.418396    0.144088    0.081263    0.029889    0.608574    
#> 130: 0.041654    1.018022    3.405973    0.145451    0.088966    0.028395    0.607386    
#> 131: 0.020294    1.006335    3.403809    0.138178    0.097302    0.026975    0.624053    
#> 132: -0.005275   1.034494    3.391789    0.131269    0.092437    0.029830    0.637335    
#> 133: -0.004085   1.012927    3.400443    0.131361    0.087815    0.030259    0.629148    
#> 134: 0.025333    1.015684    3.423268    0.124793    0.083424    0.032035    0.617253    
#> 135: 0.016407    0.998080    3.426757    0.122486    0.079253    0.032262    0.616757    
#> 136: 0.027763    0.999065    3.416502    0.122711    0.075290    0.031778    0.597222    
#> 137: 0.055154    0.990618    3.435304    0.127342    0.071526    0.035490    0.593502    
#> 138: 0.031764    0.995521    3.425892    0.120975    0.067949    0.033715    0.597846    
#> 139: 0.016860    1.020400    3.427769    0.124115    0.074683    0.033184    0.603567    
#> 140: 0.057229    1.003324    3.432622    0.142215    0.076179    0.031525    0.609887    
#> 141: 0.059961    0.960949    3.443843    0.135104    0.072370    0.029949    0.628472    
#> 142: 0.070755    0.961274    3.455700    0.128349    0.068751    0.030822    0.632058    
#> 143: 0.045533    0.987943    3.438282    0.162193    0.065314    0.034916    0.617111    
#> 144: 0.086428    0.990591    3.449633    0.154083    0.067050    0.033561    0.601750    
#> 145: 0.054877    0.998233    3.432225    0.146379    0.067877    0.031883    0.601359    
#> 146: 0.038455    1.012090    3.430292    0.139060    0.071745    0.031454    0.603970    
#> 147: -0.010360   1.003066    3.418335    0.132107    0.080714    0.030150    0.597826    
#> 148: -0.001701   1.015131    3.419274    0.125502    0.086005    0.028642    0.608923    
#> 149: 0.000581    1.015331    3.404379    0.119227    0.081705    0.027241    0.604010    
#> 150: 0.007918    1.009270    3.401150    0.113265    0.077619    0.025879    0.614189    
#> 151: -0.007039   1.034983    3.414365    0.115592    0.073738    0.024585    0.615867    
#> 152: -0.008728   1.019907    3.414168    0.126197    0.074360    0.025951    0.612010    
#> 153: -0.007106   1.014718    3.425225    0.120172    0.085322    0.020901    0.618660    
#> 154: 0.027038    1.023683    3.418987    0.114600    0.074395    0.023691    0.634553    
#> 155: 0.023743    1.013507    3.415752    0.114873    0.064697    0.023682    0.618449    
#> 156: 0.029853    1.003503    3.423080    0.118186    0.055223    0.028522    0.645097    
#> 157: 0.039663    0.967982    3.440170    0.104683    0.057157    0.031268    0.644234    
#> 158: 0.064393    0.984942    3.433313    0.105681    0.083349    0.027289    0.625225    
#> 159: 0.020984    1.017569    3.428798    0.112200    0.085189    0.024565    0.623659    
#> 160: 0.062390    1.005538    3.435959    0.117083    0.093081    0.020764    0.622281    
#> 161: 0.052086    0.987370    3.435039    0.124788    0.074696    0.023656    0.613580    
#> 162: 0.038735    0.991194    3.416066    0.113130    0.085010    0.020385    0.628357    
#> 163: 0.054750    0.989608    3.424763    0.098163    0.070817    0.023523    0.621392    
#> 164: 0.048630    1.002396    3.426402    0.102788    0.070012    0.023404    0.600390    
#> 165: 0.077471    0.994061    3.431726    0.119317    0.077220    0.026120    0.603592    
#> 166: 0.068058    1.020463    3.422931    0.130119    0.083512    0.029760    0.614256    
#> 167: 0.055628    1.022225    3.440026    0.130509    0.072684    0.032961    0.603606    
#> 168: 0.042859    1.019989    3.430607    0.121412    0.078810    0.028479    0.612245    
#> 169: 0.016859    1.044782    3.412369    0.106981    0.077151    0.025945    0.624367    
#> 170: 0.022070    1.026392    3.419449    0.098687    0.073840    0.021075    0.617726    
#> 171: -0.000160   1.018056    3.418825    0.095075    0.079794    0.016956    0.603309    
#> 172: -0.016278   1.025430    3.415670    0.077995    0.081108    0.017503    0.612395    
#> 173: 0.010490    1.024556    3.398421    0.091327    0.081138    0.018961    0.614854    
#> 174: 0.009463    1.023262    3.415648    0.104016    0.091714    0.019216    0.608712    
#> 175: 0.009422    1.007302    3.409312    0.104174    0.084091    0.018947    0.614744    
#> 176: 0.013119    1.037037    3.417556    0.091675    0.091658    0.019189    0.608415    
#> 177: 0.023098    1.019752    3.429039    0.081538    0.092767    0.015696    0.622970    
#> 178: 0.041386    0.999179    3.426073    0.106162    0.084671    0.020492    0.592192    
#> 179: 0.051801    1.036852    3.423608    0.101671    0.087044    0.020020    0.615754    
#> 180: 0.045020    1.012747    3.428467    0.102843    0.085416    0.025653    0.620803    
#> 181: 0.009752    0.998483    3.415165    0.113862    0.086441    0.023330    0.613983    
#> 182: -0.006017   1.002731    3.405801    0.128988    0.077407    0.028533    0.618021    
#> 183: 0.002846    1.022890    3.403751    0.138992    0.089432    0.024236    0.610075    
#> 184: 0.024376    1.022991    3.409283    0.135347    0.083549    0.024432    0.609548    
#> 185: -0.010050   1.022884    3.399810    0.123136    0.079139    0.017956    0.630146    
#> 186: -0.022693   1.033273    3.395813    0.132319    0.084801    0.022301    0.628788    
#> 187: -0.016527   1.011304    3.414580    0.129129    0.077070    0.029325    0.639050    
#> 188: -0.027070   1.021143    3.411898    0.111797    0.075021    0.026836    0.649108    
#> 189: 0.006999    1.026538    3.415274    0.114277    0.091384    0.028169    0.628458    
#> 190: -0.015722   1.033386    3.419487    0.116169    0.069617    0.028086    0.620998    
#> 191: 0.003769    1.016135    3.414390    0.116714    0.065764    0.026748    0.622008    
#> 192: 0.013140    1.028503    3.409531    0.093001    0.075948    0.030989    0.618473    
#> 193: 0.008147    1.030601    3.417671    0.102054    0.069463    0.035548    0.614984    
#> 194: -0.005134   1.020182    3.405987    0.116947    0.087973    0.028478    0.625566    
#> 195: -0.034718   1.035239    3.393275    0.116354    0.078121    0.024225    0.613559    
#> 196: -0.030007   1.024737    3.403588    0.120627    0.080280    0.026222    0.616000    
#> 197: -0.005324   1.018632    3.418388    0.125830    0.080763    0.028743    0.613438    
#> 198: 0.046584    1.009774    3.419689    0.135817    0.068205    0.034285    0.599339    
#> 199: 0.026066    1.023509    3.410894    0.133443    0.079495    0.030045    0.607432    
#> 200: 0.039551    1.017886    3.425686    0.113018    0.071333    0.029038    0.621157    
#> 201: 0.031594    1.013575    3.430722    0.107775    0.072359    0.032106    0.625724    
#> 202: 0.030905    1.021117    3.427266    0.109598    0.077269    0.031754    0.625887    
#> 203: 0.040438    1.018211    3.427720    0.113222    0.081501    0.029912    0.625644    
#> 204: 0.047753    1.009020    3.432510    0.116119    0.081925    0.030052    0.624305    
#> 205: 0.051400    1.008736    3.433947    0.115239    0.082760    0.030031    0.626170    
#> 206: 0.051742    1.009594    3.435488    0.114369    0.081749    0.029502    0.627912    
#> 207: 0.052988    1.010543    3.434171    0.112818    0.080994    0.028459    0.629153    
#> 208: 0.052710    1.009678    3.434973    0.109336    0.080216    0.027877    0.628693    
#> 209: 0.055386    1.005479    3.435208    0.105966    0.079664    0.027399    0.628164    
#> 210: 0.056945    1.003643    3.435961    0.104583    0.079657    0.026848    0.625798    
#> 211: 0.056943    1.003375    3.436267    0.103413    0.079904    0.026513    0.623647    
#> 212: 0.058526    1.002870    3.436352    0.103677    0.079922    0.026179    0.622328    
#> 213: 0.060970    1.000460    3.438364    0.104384    0.080467    0.026712    0.622677    
#> 214: 0.064821    0.999113    3.439929    0.105257    0.081133    0.027088    0.622347    
#> 215: 0.068143    0.997282    3.441715    0.105934    0.080254    0.027409    0.622179    
#> 216: 0.070667    0.995088    3.442851    0.107315    0.079616    0.027591    0.622611    
#> 217: 0.071336    0.994328    3.443426    0.107526    0.079160    0.027452    0.621923    
#> 218: 0.072311    0.993872    3.443834    0.107056    0.079098    0.027521    0.620763    
#> 219: 0.070923    0.993669    3.442677    0.106260    0.079313    0.027471    0.620433    
#> 220: 0.069848    0.994035    3.442278    0.106209    0.079704    0.027546    0.619649    
#> 221: 0.069431    0.994511    3.442280    0.106595    0.079601    0.027598    0.619370    
#> 222: 0.068972    0.994564    3.442149    0.106276    0.078998    0.027671    0.619723    
#> 223: 0.069457    0.994476    3.442092    0.105276    0.078802    0.027598    0.619828    
#> 224: 0.070653    0.994746    3.442096    0.104867    0.078770    0.027382    0.619935    
#> 225: 0.070110    0.993546    3.442474    0.103794    0.078771    0.027364    0.620500    
#> 226: 0.069550    0.993355    3.441837    0.103886    0.078441    0.027197    0.620879    
#> 227: 0.067880    0.993296    3.441569    0.103366    0.078574    0.027173    0.621669    
#> 228: 0.066917    0.993454    3.440933    0.103241    0.078649    0.027090    0.621877    
#> 229: 0.065960    0.993066    3.440510    0.103366    0.078967    0.026829    0.621881    
#> 230: 0.065645    0.992658    3.440040    0.103256    0.078862    0.026703    0.622345    
#> 231: 0.065745    0.992650    3.440217    0.103331    0.078765    0.026627    0.622357    
#> 232: 0.064539    0.992515    3.440042    0.103499    0.078599    0.026594    0.622150    
#> 233: 0.063370    0.991551    3.440000    0.103813    0.078467    0.026719    0.621969    
#> 234: 0.062233    0.991706    3.439813    0.103590    0.078435    0.026767    0.622197    
#> 235: 0.061496    0.991864    3.439435    0.102793    0.078418    0.026703    0.622490    
#> 236: 0.060765    0.992390    3.438938    0.101955    0.078461    0.026580    0.623085    
#> 237: 0.060823    0.993090    3.438678    0.101506    0.078594    0.026573    0.623118    
#> 238: 0.060792    0.993165    3.438471    0.101195    0.079065    0.026689    0.623388    
#> 239: 0.060445    0.993706    3.438158    0.100994    0.079357    0.026735    0.623468    
#> 240: 0.060326    0.993633    3.438168    0.101370    0.079466    0.026729    0.623102    
#> 241: 0.060349    0.993033    3.438181    0.101369    0.079407    0.026731    0.622826    
#> 242: 0.059610    0.992811    3.437936    0.101246    0.079442    0.026620    0.622857    
#> 243: 0.058265    0.993425    3.437419    0.101381    0.079611    0.026547    0.622803    
#> 244: 0.057358    0.993703    3.437145    0.100977    0.079537    0.026564    0.622804    
#> 245: 0.057173    0.993324    3.437171    0.101121    0.079913    0.026486    0.622703    
#> 246: 0.056791    0.993210    3.437062    0.100781    0.079975    0.026405    0.622591    
#> 247: 0.056159    0.993379    3.437048    0.101170    0.080168    0.026369    0.622826    
#> 248: 0.055899    0.993993    3.436657    0.101119    0.080144    0.026319    0.623039    
#> 249: 0.055602    0.994386    3.436573    0.101324    0.080184    0.026312    0.623228    
#> 250: 0.055688    0.994564    3.436389    0.101655    0.080261    0.026303    0.623222    
#> 251: 0.055820    0.995206    3.436484    0.101851    0.079968    0.026272    0.623663    
#> 252: 0.055993    0.995545    3.436795    0.101792    0.080001    0.026244    0.623559    
#> 253: 0.056209    0.995708    3.436839    0.101841    0.080376    0.026181    0.623635    
#> 254: 0.056271    0.995942    3.436828    0.101649    0.080473    0.026150    0.623664    
#> 255: 0.055994    0.996121    3.436783    0.101654    0.080456    0.026139    0.623768    
#> 256: 0.056079    0.995975    3.436648    0.101468    0.080620    0.026077    0.623712    
#> 257: 0.055696    0.995652    3.436657    0.101290    0.080885    0.026072    0.623791    
#> 258: 0.055540    0.995301    3.436631    0.101196    0.080933    0.025982    0.623878    
#> 259: 0.055648    0.995114    3.436637    0.101035    0.081102    0.026016    0.624109    
#> 260: 0.055342    0.995399    3.436635    0.100986    0.081135    0.026095    0.623967    
#> 261: 0.055341    0.995191    3.436658    0.101183    0.081243    0.026134    0.624037    
#> 262: 0.055825    0.995376    3.436707    0.101818    0.081310    0.026161    0.624039    
#> 263: 0.055725    0.995576    3.436668    0.102042    0.081417    0.026171    0.624163    
#> 264: 0.055705    0.995636    3.436658    0.102168    0.081772    0.026226    0.624050    
#> 265: 0.055769    0.995830    3.436498    0.102241    0.081814    0.026256    0.623929    
#> 266: 0.055875    0.995897    3.436394    0.102381    0.081817    0.026287    0.623852    
#> 267: 0.055998    0.995792    3.436561    0.102446    0.081708    0.026330    0.623799    
#> 268: 0.055552    0.995628    3.436363    0.102665    0.081528    0.026346    0.623701    
#> 269: 0.055596    0.995775    3.436292    0.103024    0.081326    0.026331    0.623738    
#> 270: 0.055859    0.995914    3.436204    0.103080    0.081183    0.026326    0.623552    
#> 271: 0.055493    0.995806    3.435982    0.103080    0.081310    0.026306    0.623826    
#> 272: 0.055275    0.995622    3.435875    0.103153    0.081360    0.026339    0.624150    
#> 273: 0.055042    0.995975    3.435896    0.103123    0.081442    0.026361    0.624322    
#> 274: 0.054708    0.996033    3.435890    0.103013    0.081249    0.026374    0.624417    
#> 275: 0.054658    0.996117    3.435726    0.103018    0.081464    0.026369    0.624382    
#> 276: 0.054059    0.996499    3.435508    0.102912    0.081428    0.026395    0.624225    
#> 277: 0.053633    0.996788    3.435451    0.102870    0.081364    0.026421    0.624204    
#> 278: 0.053203    0.997179    3.435341    0.102568    0.081341    0.026416    0.624278    
#> 279: 0.052764    0.997538    3.435097    0.102523    0.081538    0.026349    0.624538    
#> 280: 0.052567    0.997783    3.434949    0.102551    0.081631    0.026235    0.624673    
#> 281: 0.052380    0.997972    3.434856    0.102832    0.081692    0.026167    0.624527    
#> 282: 0.052120    0.998314    3.434723    0.102938    0.081756    0.026127    0.624489    
#> 283: 0.052026    0.998693    3.434672    0.102939    0.081807    0.026112    0.624776    
#> 284: 0.051775    0.998753    3.434579    0.103021    0.081669    0.026099    0.624538    
#> 285: 0.051979    0.998795    3.434515    0.103010    0.081481    0.026096    0.624491    
#> 286: 0.052290    0.998771    3.434553    0.102956    0.081447    0.026080    0.624506    
#> 287: 0.052332    0.998780    3.434466    0.103116    0.081390    0.026095    0.624525    
#> 288: 0.052407    0.998816    3.434354    0.103119    0.081331    0.026091    0.624435    
#> 289: 0.052443    0.998990    3.434298    0.103230    0.081240    0.026142    0.624344    
#> 290: 0.052252    0.998912    3.434272    0.103273    0.081331    0.026166    0.624287    
#> 291: 0.051978    0.999123    3.434242    0.103402    0.081288    0.026197    0.624054    
#> 292: 0.051790    0.999329    3.434085    0.103753    0.081208    0.026168    0.623984    
#> 293: 0.051584    0.999606    3.433873    0.103881    0.081182    0.026098    0.623967    
#> 294: 0.051181    0.999937    3.433637    0.104066    0.081219    0.026036    0.623787    
#> 295: 0.050817    0.999993    3.433505    0.104223    0.081181    0.026006    0.623634    
#> 296: 0.050522    1.000133    3.433296    0.104135    0.081151    0.025953    0.623557    
#> 297: 0.050305    1.000349    3.433131    0.104315    0.081150    0.025915    0.623469    
#> 298: 0.050255    1.000578    3.432969    0.104528    0.081261    0.025866    0.623445    
#> 299: 0.050013    1.000855    3.432735    0.104712    0.081111    0.025869    0.623396    
#> 300: 0.049976    1.000873    3.432782    0.104691    0.081105    0.025856    0.623269    
#> 301: 0.050042    1.000917    3.432611    0.104619    0.081101    0.025806    0.623380    
#> 302: 0.049957    1.001014    3.432442    0.104464    0.081102    0.025766    0.623331    
#> 303: 0.049506    1.001273    3.432242    0.104508    0.081115    0.025741    0.623291    
#> 304: 0.049473    1.001622    3.431973    0.104657    0.081139    0.025681    0.623219    
#> 305: 0.049098    1.001587    3.431789    0.104787    0.081096    0.025648    0.623063    
#> 306: 0.048507    1.001621    3.431564    0.104989    0.081081    0.025689    0.622850    
#> 307: 0.048145    1.001843    3.431341    0.105145    0.081157    0.025730    0.622893    
#> 308: 0.047696    1.001927    3.431171    0.105231    0.081125    0.025748    0.622861    
#> 309: 0.047453    1.001793    3.431126    0.105299    0.081198    0.025713    0.622965    
#> 310: 0.047614    1.001667    3.431129    0.105158    0.081280    0.025648    0.623014    
#> 311: 0.047710    1.001643    3.431185    0.105316    0.081351    0.025600    0.622966    
#> 312: 0.047935    1.001544    3.431193    0.105315    0.081331    0.025535    0.622897    
#> 313: 0.047857    1.001281    3.431202    0.105185    0.081306    0.025483    0.623043    
#> 314: 0.047456    1.001392    3.431095    0.105027    0.081294    0.025460    0.623037    
#> 315: 0.047482    1.001496    3.431113    0.105023    0.081335    0.025445    0.622913    
#> 316: 0.047663    1.001577    3.431078    0.105060    0.081427    0.025388    0.622886    
#> 317: 0.047918    1.001371    3.431226    0.105111    0.081409    0.025360    0.622922    
#> 318: 0.048053    1.001412    3.431257    0.105000    0.081438    0.025346    0.622734    
#> 319: 0.048130    1.001293    3.431338    0.104999    0.081447    0.025309    0.622743    
#> 320: 0.048013    1.001133    3.431331    0.104999    0.081422    0.025284    0.622742    
#> 321: 0.047710    1.001100    3.431151    0.104955    0.081420    0.025201    0.622784    
#> 322: 0.047500    1.001165    3.430967    0.105065    0.081423    0.025167    0.622813    
#> 323: 0.047054    1.001129    3.430832    0.105273    0.081414    0.025121    0.622847    
#> 324: 0.047085    1.001184    3.430798    0.105389    0.081430    0.025073    0.622775    
#> 325: 0.046997    1.001398    3.430703    0.105581    0.081512    0.025051    0.622668    
#> 326: 0.047015    1.001297    3.430608    0.105606    0.081505    0.025041    0.622643    
#> 327: 0.046919    1.001304    3.430591    0.105648    0.081431    0.025042    0.622751    
#> 328: 0.047027    1.001418    3.430538    0.105687    0.081425    0.025054    0.622673    
#> 329: 0.047087    1.001493    3.430519    0.105657    0.081379    0.025015    0.622631    
#> 330: 0.047006    1.001440    3.430477    0.105792    0.081478    0.025016    0.622450    
#> 331: 0.047091    1.001508    3.430420    0.105910    0.081461    0.025016    0.622328    
#> 332: 0.047056    1.001579    3.430457    0.106067    0.081386    0.024991    0.622381    
#> 333: 0.046840    1.001690    3.430375    0.106145    0.081378    0.024977    0.622176    
#> 334: 0.046536    1.001731    3.430194    0.106169    0.081356    0.024993    0.622098    
#> 335: 0.046155    1.001802    3.430017    0.106304    0.081252    0.024999    0.621934    
#> 336: 0.045809    1.002046    3.429860    0.106336    0.081163    0.024985    0.622003    
#> 337: 0.045765    1.002398    3.429739    0.106459    0.081151    0.024976    0.621961    
#> 338: 0.045793    1.002580    3.429730    0.106607    0.081064    0.024968    0.621932    
#> 339: 0.045585    1.002741    3.429578    0.106730    0.081008    0.024966    0.621876    
#> 340: 0.045420    1.002553    3.429535    0.106790    0.081024    0.024923    0.621883    
#> 341: 0.045545    1.002548    3.429548    0.106823    0.080986    0.024878    0.621942    
#> 342: 0.045296    1.002425    3.429474    0.106879    0.080994    0.024809    0.621959    
#> 343: 0.044992    1.002489    3.429400    0.106884    0.081040    0.024778    0.621945    
#> 344: 0.044789    1.002595    3.429258    0.106871    0.081049    0.024743    0.621967    
#> 345: 0.044539    1.002740    3.429140    0.106881    0.081155    0.024718    0.621925    
#> 346: 0.044246    1.002897    3.428926    0.106990    0.081185    0.024676    0.621957    
#> 347: 0.044028    1.002919    3.428808    0.106969    0.081248    0.024635    0.622039    
#> 348: 0.043913    1.002973    3.428704    0.106996    0.081372    0.024586    0.622020    
#> 349: 0.043782    1.002850    3.428689    0.106910    0.081365    0.024587    0.621995    
#> 350: 0.043596    1.002787    3.428666    0.106727    0.081376    0.024564    0.622072    
#> 351: 0.043482    1.003062    3.428562    0.106574    0.081510    0.024510    0.622156    
#> 352: 0.043321    1.003264    3.428479    0.106599    0.081580    0.024461    0.622376    
#> 353: 0.043338    1.003482    3.428417    0.106726    0.081692    0.024456    0.622290    
#> 354: 0.043298    1.003561    3.428308    0.106869    0.081691    0.024487    0.622211    
#> 355: 0.043429    1.003473    3.428286    0.106967    0.081680    0.024499    0.622252    
#> 356: 0.043255    1.003445    3.428262    0.107058    0.081743    0.024478    0.622391    
#> 357: 0.043357    1.003466    3.428254    0.107099    0.081697    0.024482    0.622310    
#> 358: 0.043198    1.003492    3.428199    0.107006    0.081558    0.024489    0.622257    
#> 359: 0.043029    1.003541    3.428158    0.107008    0.081537    0.024499    0.622146    
#> 360: 0.042699    1.003640    3.427959    0.106991    0.081474    0.024494    0.622045    
#> 361: 0.042501    1.003707    3.427872    0.106951    0.081504    0.024499    0.621979    
#> 362: 0.042485    1.003816    3.427752    0.106923    0.081500    0.024489    0.621889    
#> 363: 0.042440    1.003766    3.427701    0.107035    0.081453    0.024496    0.621708    
#> 364: 0.042441    1.003751    3.427653    0.107123    0.081346    0.024506    0.621696    
#> 365: 0.042381    1.003579    3.427705    0.107158    0.081376    0.024525    0.621709    
#> 366: 0.042364    1.003533    3.427670    0.107240    0.081398    0.024552    0.621629    
#> 367: 0.042442    1.003450    3.427635    0.107109    0.081439    0.024532    0.621720    
#> 368: 0.042472    1.003520    3.427629    0.106974    0.081470    0.024531    0.621681    
#> 369: 0.042419    1.003579    3.427584    0.106972    0.081485    0.024531    0.621631    
#> 370: 0.042255    1.003662    3.427526    0.106895    0.081461    0.024520    0.621635    
#> 371: 0.042009    1.003807    3.427386    0.106906    0.081447    0.024510    0.621602    
#> 372: 0.041847    1.003968    3.427292    0.106922    0.081423    0.024529    0.621602    
#> 373: 0.041753    1.004095    3.427220    0.106951    0.081438    0.024529    0.621660    
#> 374: 0.041679    1.004226    3.427167    0.106841    0.081439    0.024532    0.621638    
#> 375: 0.041582    1.004288    3.427138    0.106830    0.081417    0.024534    0.621649    
#> 376: 0.041577    1.004366    3.427106    0.106804    0.081444    0.024550    0.621553    
#> 377: 0.041488    1.004440    3.427052    0.106729    0.081448    0.024555    0.621542    
#> 378: 0.041153    1.004496    3.426948    0.106748    0.081442    0.024574    0.621592    
#> 379: 0.040985    1.004446    3.426925    0.106788    0.081408    0.024591    0.621577    
#> 380: 0.040804    1.004531    3.426856    0.106712    0.081397    0.024598    0.621563    
#> 381: 0.040629    1.004565    3.426772    0.106619    0.081436    0.024583    0.621622    
#> 382: 0.040632    1.004572    3.426758    0.106547    0.081426    0.024576    0.621561    
#> 383: 0.040731    1.004574    3.426748    0.106642    0.081399    0.024590    0.621407    
#> 384: 0.040831    1.004505    3.426795    0.106706    0.081371    0.024608    0.621291    
#> 385: 0.040897    1.004601    3.426807    0.106737    0.081421    0.024622    0.621177    
#> 386: 0.040810    1.004800    3.426766    0.106757    0.081504    0.024624    0.621081    
#> 387: 0.040928    1.004855    3.426842    0.106797    0.081547    0.024605    0.620993    
#> 388: 0.040977    1.004816    3.426879    0.106785    0.081542    0.024597    0.620882    
#> 389: 0.040921    1.004668    3.426841    0.106666    0.081476    0.024583    0.620923    
#> 390: 0.040620    1.004812    3.426723    0.106638    0.081531    0.024565    0.620961    
#> 391: 0.040561    1.004880    3.426691    0.106596    0.081596    0.024537    0.620884    
#> 392: 0.040580    1.004829    3.426733    0.106524    0.081688    0.024515    0.620931    
#> 393: 0.040524    1.004746    3.426732    0.106572    0.081693    0.024494    0.620902    
#> 394: 0.040530    1.004780    3.426754    0.106566    0.081780    0.024492    0.620834    
#> 395: 0.040648    1.004823    3.426822    0.106637    0.081868    0.024484    0.620846    
#> 396: 0.040793    1.004788    3.426904    0.106754    0.081870    0.024495    0.620736    
#> 397: 0.040792    1.004684    3.426926    0.106804    0.081866    0.024479    0.620681    
#> 398: 0.040860    1.004569    3.426967    0.106777    0.081818    0.024470    0.620671    
#> 399: 0.040917    1.004490    3.427051    0.106862    0.081790    0.024466    0.620569    
#> 400: 0.041017    1.004425    3.427104    0.106865    0.081788    0.024430    0.620536    
#> 401: 0.041104    1.004432    3.427131    0.106842    0.081777    0.024416    0.620609    
#> 402: 0.041149    1.004502    3.427151    0.106841    0.081816    0.024413    0.620606    
#> 403: 0.041363    1.004476    3.427210    0.106762    0.081778    0.024411    0.620594    
#> 404: 0.041406    1.004542    3.427168    0.106684    0.081758    0.024389    0.620525    
#> 405: 0.041293    1.004617    3.427126    0.106638    0.081672    0.024391    0.620469    
#> 406: 0.041416    1.004599    3.427160    0.106576    0.081650    0.024396    0.620554    
#> 407: 0.041511    1.004538    3.427222    0.106598    0.081624    0.024397    0.620587    
#> 408: 0.041534    1.004495    3.427257    0.106542    0.081602    0.024383    0.620644    
#> 409: 0.041550    1.004376    3.427312    0.106537    0.081597    0.024372    0.620639    
#> 410: 0.041533    1.004342    3.427253    0.106519    0.081590    0.024351    0.620693    
#> 411: 0.041543    1.004193    3.427262    0.106533    0.081636    0.024328    0.620712    
#> 412: 0.041525    1.004190    3.427244    0.106479    0.081634    0.024326    0.620637    
#> 413: 0.041451    1.004225    3.427238    0.106491    0.081676    0.024316    0.620719    
#> 414: 0.041344    1.004259    3.427212    0.106509    0.081744    0.024303    0.620666    
#> 415: 0.041343    1.004202    3.427199    0.106562    0.081783    0.024318    0.620594    
#> 416: 0.041339    1.004235    3.427239    0.106653    0.081788    0.024341    0.620500    
#> 417: 0.041411    1.004175    3.427274    0.106662    0.081736    0.024350    0.620461    
#> 418: 0.041273    1.004183    3.427276    0.106625    0.081709    0.024354    0.620409    
#> 419: 0.041308    1.004219    3.427272    0.106536    0.081692    0.024370    0.620398    
#> 420: 0.041438    1.004249    3.427315    0.106557    0.081610    0.024407    0.620342    
#> 421: 0.041501    1.004172    3.427427    0.106488    0.081574    0.024436    0.620317    
#> 422: 0.041622    1.004068    3.427455    0.106552    0.081532    0.024443    0.620257    
#> 423: 0.041645    1.004064    3.427453    0.106465    0.081569    0.024435    0.620219    
#> 424: 0.041559    1.004129    3.427443    0.106379    0.081587    0.024436    0.620201    
#> 425: 0.041664    1.004192    3.427438    0.106317    0.081612    0.024449    0.620177    
#> 426: 0.041640    1.004299    3.427369    0.106305    0.081630    0.024437    0.620154    
#> 427: 0.041518    1.004308    3.427370    0.106275    0.081581    0.024434    0.620086    
#> 428: 0.041370    1.004353    3.427358    0.106313    0.081521    0.024415    0.620185    
#> 429: 0.041266    1.004352    3.427375    0.106314    0.081460    0.024413    0.620215    
#> 430: 0.041182    1.004308    3.427358    0.106352    0.081410    0.024415    0.620259    
#> 431: 0.040984    1.004316    3.427276    0.106405    0.081380    0.024400    0.620275    
#> 432: 0.040797    1.004409    3.427245    0.106528    0.081394    0.024407    0.620303    
#> 433: 0.040783    1.004464    3.427243    0.106493    0.081443    0.024389    0.620260    
#> 434: 0.040623    1.004408    3.427200    0.106514    0.081481    0.024376    0.620223    
#> 435: 0.040639    1.004395    3.427195    0.106487    0.081510    0.024353    0.620205    
#> 436: 0.040564    1.004302    3.427246    0.106476    0.081617    0.024340    0.620208    
#> 437: 0.040564    1.004165    3.427259    0.106466    0.081657    0.024328    0.620226    
#> 438: 0.040467    1.004283    3.427207    0.106423    0.081707    0.024309    0.620198    
#> 439: 0.040415    1.004371    3.427160    0.106408    0.081688    0.024302    0.620157    
#> 440: 0.040306    1.004417    3.427168    0.106353    0.081738    0.024303    0.620159    
#> 441: 0.040235    1.004471    3.427163    0.106337    0.081736    0.024328    0.620127    
#> 442: 0.040146    1.004570    3.427131    0.106394    0.081713    0.024339    0.620037    
#> 443: 0.040071    1.004633    3.427064    0.106411    0.081657    0.024367    0.620000    
#> 444: 0.040061    1.004723    3.426998    0.106472    0.081586    0.024390    0.620009    
#> 445: 0.039935    1.004848    3.426928    0.106636    0.081585    0.024384    0.620044    
#> 446: 0.039785    1.004884    3.426858    0.106722    0.081511    0.024377    0.620073    
#> 447: 0.039814    1.004884    3.426823    0.106727    0.081470    0.024364    0.620138    
#> 448: 0.039758    1.004851    3.426828    0.106716    0.081482    0.024375    0.620081    
#> 449: 0.039837    1.004917    3.426880    0.106817    0.081513    0.024390    0.620039    
#> 450: 0.039826    1.004931    3.426867    0.106814    0.081544    0.024400    0.620056    
#> 451: 0.039839    1.004971    3.426845    0.106881    0.081509    0.024409    0.620101    
#> 452: 0.039795    1.005007    3.426803    0.106943    0.081491    0.024407    0.620155    
#> 453: 0.039680    1.005052    3.426757    0.106947    0.081506    0.024415    0.620088    
#> 454: 0.039546    1.005269    3.426634    0.106941    0.081524    0.024407    0.620125    
#> 455: 0.039483    1.005351    3.426572    0.106946    0.081539    0.024406    0.620136    
#> 456: 0.039359    1.005418    3.426480    0.107035    0.081540    0.024400    0.620101    
#> 457: 0.039287    1.005436    3.426460    0.107020    0.081584    0.024392    0.620061    
#> 458: 0.039246    1.005582    3.426416    0.107000    0.081591    0.024389    0.620028    
#> 459: 0.039144    1.005667    3.426385    0.106939    0.081588    0.024377    0.620062    
#> 460: 0.039042    1.005677    3.426319    0.106932    0.081561    0.024373    0.620083    
#> 461: 0.038951    1.005687    3.426311    0.106971    0.081505    0.024377    0.620124    
#> 462: 0.038950    1.005740    3.426321    0.106978    0.081476    0.024381    0.620130    
#> 463: 0.038967    1.005814    3.426326    0.107056    0.081447    0.024396    0.620145    
#> 464: 0.039040    1.005899    3.426307    0.107084    0.081394    0.024413    0.620123    
#> 465: 0.039029    1.005792    3.426328    0.107009    0.081346    0.024414    0.620125    
#> 466: 0.039065    1.005826    3.426288    0.106899    0.081349    0.024402    0.620194    
#> 467: 0.039042    1.005846    3.426304    0.106870    0.081343    0.024393    0.620150    
#> 468: 0.039223    1.005826    3.426385    0.106867    0.081332    0.024394    0.620092    
#> 469: 0.039244    1.005824    3.426429    0.106921    0.081359    0.024393    0.620100    
#> 470: 0.039151    1.005845    3.426410    0.106900    0.081331    0.024385    0.620121    
#> 471: 0.038992    1.005861    3.426383    0.106879    0.081316    0.024365    0.620136    
#> 472: 0.038997    1.005840    3.426378    0.106876    0.081309    0.024348    0.620208    
#> 473: 0.038916    1.005842    3.426393    0.106802    0.081252    0.024352    0.620197    
#> 474: 0.038883    1.005786    3.426395    0.106669    0.081232    0.024354    0.620245    
#> 475: 0.038847    1.005790    3.426402    0.106600    0.081219    0.024369    0.620222    
#> 476: 0.038796    1.005752    3.426380    0.106626    0.081206    0.024370    0.620239    
#> 477: 0.038714    1.005814    3.426358    0.106616    0.081207    0.024374    0.620186    
#> 478: 0.038573    1.005877    3.426326    0.106627    0.081175    0.024359    0.620162    
#> 479: 0.038607    1.005909    3.426311    0.106640    0.081144    0.024342    0.620150    
#> 480: 0.038603    1.005927    3.426326    0.106649    0.081185    0.024355    0.620154    
#> 481: 0.038640    1.006012    3.426356    0.106652    0.081180    0.024364    0.620119    
#> 482: 0.038756    1.006003    3.426342    0.106636    0.081166    0.024370    0.620141    
#> 483: 0.038655    1.005982    3.426319    0.106668    0.081126    0.024384    0.620088    
#> 484: 0.038708    1.005898    3.426318    0.106716    0.081100    0.024388    0.620058    
#> 485: 0.038733    1.005875    3.426343    0.106799    0.081100    0.024389    0.620057    
#> 486: 0.038713    1.005885    3.426353    0.106731    0.081100    0.024383    0.620050    
#> 487: 0.038899    1.005890    3.426402    0.106652    0.081099    0.024401    0.620033    
#> 488: 0.038916    1.005836    3.426449    0.106623    0.081044    0.024418    0.620046    
#> 489: 0.039059    1.005777    3.426482    0.106625    0.081022    0.024421    0.620057    
#> 490: 0.039105    1.005755    3.426526    0.106613    0.081053    0.024410    0.620049    
#> 491: 0.039173    1.005777    3.426588    0.106567    0.081012    0.024424    0.620001    
#> 492: 0.039197    1.005804    3.426591    0.106503    0.080979    0.024432    0.619984    
#> 493: 0.039263    1.005815    3.426645    0.106470    0.080971    0.024437    0.619997    
#> 494: 0.039402    1.005796    3.426679    0.106427    0.081002    0.024428    0.619962    
#> 495: 0.039461    1.005716    3.426708    0.106425    0.081010    0.024422    0.619913    
#> 496: 0.039547    1.005667    3.426740    0.106365    0.081004    0.024396    0.619919    
#> 497: 0.039587    1.005654    3.426768    0.106263    0.081051    0.024380    0.619945    
#> 498: 0.039609    1.005635    3.426745    0.106258    0.081072    0.024368    0.619903    
#> 499: 0.039583    1.005714    3.426701    0.106279    0.081084    0.024355    0.619901    
#> 500: 0.039576    1.005749    3.426677    0.106305    0.081114    0.024333    0.619868    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.314903    0.958044    3.440426    0.392401    0.082317    0.016800    1.820066    
#> 002: 0.510612    0.992455    3.481892    0.372781    0.078201    0.015960    1.168627    
#> 003: 0.679353    0.963404    3.468158    0.354142    0.074291    0.015162    0.954314    
#> 004: 0.654676    0.961582    3.472781    0.449932    0.070576    0.014404    0.835451    
#> 005: 0.712298    0.965098    3.462462    0.522919    0.067047    0.013684    0.770815    
#> 006: 0.692664    0.972179    3.445604    0.565143    0.063695    0.013278    0.749158    
#> 007: 0.627705    1.008320    3.439596    0.600981    0.060510    0.013457    0.772298    
#> 008: 0.647401    0.981386    3.432510    0.625409    0.057485    0.015716    0.771058    
#> 009: 0.618871    0.979946    3.433131    0.635674    0.059373    0.014931    0.730878    
#> 010: 0.659476    0.979731    3.437649    0.720782    0.056405    0.014184    0.746320    
#> 011: 0.746706    0.982229    3.447062    0.689241    0.056408    0.013475    0.743143    
#> 012: 0.734532    0.975271    3.444098    0.717575    0.060208    0.012801    0.756137    
#> 013: 0.681631    0.975513    3.437574    0.750144    0.064027    0.012161    0.778246    
#> 014: 0.693677    0.976821    3.449161    0.712636    0.060826    0.014081    0.778958    
#> 015: 0.732814    0.974524    3.471019    0.677005    0.057785    0.015632    0.745212    
#> 016: 0.763748    0.979451    3.477711    0.668091    0.054895    0.024434    0.768277    
#> 017: 0.737019    0.999139    3.462150    0.753265    0.052151    0.023213    0.734128    
#> 018: 0.750293    0.988618    3.445720    0.739085    0.049543    0.022052    0.733512    
#> 019: 0.709944    0.986838    3.446096    0.844743    0.047066    0.020949    0.729471    
#> 020: 0.772968    0.984718    3.450729    0.817534    0.044713    0.019902    0.751167    
#> 021: 0.762314    0.972533    3.451266    0.801931    0.047052    0.018907    0.730875    
#> 022: 0.737901    0.973079    3.465878    0.761834    0.044699    0.017962    0.714597    
#> 023: 0.789496    0.970130    3.482022    0.723743    0.042464    0.017819    0.730026    
#> 024: 0.782830    0.991777    3.481074    0.687556    0.040341    0.016928    0.722036    
#> 025: 0.768869    0.971576    3.465965    0.660112    0.039822    0.019049    0.729716    
#> 026: 0.740494    0.989325    3.449994    0.734740    0.037831    0.018623    0.745800    
#> 027: 0.695464    0.995497    3.444886    0.698003    0.035939    0.020068    0.738125    
#> 028: 0.725217    1.004090    3.461970    0.677742    0.035998    0.020709    0.706869    
#> 029: 0.753720    0.991068    3.447156    0.675187    0.039116    0.019673    0.739051    
#> 030: 0.779915    1.012726    3.454409    0.775184    0.039783    0.018689    0.741548    
#> 031: 0.711885    0.993929    3.461126    0.736425    0.046488    0.017755    0.737131    
#> 032: 0.743647    1.009189    3.461013    0.701337    0.044164    0.016867    0.729111    
#> 033: 0.704437    1.011382    3.450251    0.666270    0.043389    0.016024    0.734947    
#> 034: 0.755095    1.024996    3.439812    0.755861    0.041220    0.016113    0.753849    
#> 035: 0.676483    1.004233    3.433063    0.718068    0.045859    0.015307    0.730518    
#> 036: 0.684056    1.015318    3.437715    0.682164    0.045693    0.017463    0.736162    
#> 037: 0.695861    1.021161    3.427163    0.749367    0.043408    0.016590    0.763047    
#> 038: 0.738608    1.006765    3.432984    0.924911    0.045691    0.015760    0.770431    
#> 039: 0.725406    0.992203    3.444337    0.878666    0.051489    0.017043    0.742135    
#> 040: 0.716277    0.994762    3.445863    0.852891    0.048914    0.016191    0.736212    
#> 041: 0.709138    0.969260    3.450164    0.810246    0.048043    0.021385    0.709425    
#> 042: 0.721385    0.987091    3.441279    0.769734    0.047236    0.020316    0.730403    
#> 043: 0.681975    0.997482    3.428882    0.731247    0.044874    0.019300    0.738213    
#> 044: 0.648860    1.011266    3.421993    0.694685    0.042630    0.018761    0.748905    
#> 045: 0.619652    1.016839    3.416720    0.659951    0.043002    0.017823    0.744815    
#> 046: 0.665613    1.007931    3.427362    0.694669    0.040852    0.016949    0.741268    
#> 047: 0.667592    1.007808    3.435278    0.659935    0.043792    0.019407    0.749205    
#> 048: 0.660982    1.000107    3.431980    0.701220    0.054966    0.020294    0.759532    
#> 049: 0.669764    0.993149    3.440857    0.699059    0.055671    0.019280    0.752810    
#> 050: 0.719241    0.978093    3.442385    0.719181    0.062704    0.018316    0.756276    
#> 051: 0.689883    0.990362    3.423170    0.758344    0.060690    0.018663    0.761521    
#> 052: 0.716399    0.991071    3.443825    0.795842    0.057656    0.018543    0.754196    
#> 053: 0.743899    0.991076    3.435998    0.919846    0.054773    0.017616    0.729232    
#> 054: 0.696574    0.998115    3.448293    0.873854    0.052034    0.020287    0.735997    
#> 055: 0.722107    1.002225    3.446621    0.830161    0.049432    0.019273    0.732238    
#> 056: 0.763814    0.987324    3.455068    0.788653    0.046961    0.019526    0.744606    
#> 057: 0.737080    0.999075    3.452348    0.749221    0.052588    0.018550    0.721445    
#> 058: 0.741891    1.007622    3.440204    0.852852    0.054321    0.017622    0.718506    
#> 059: 0.787809    0.953561    3.456657    0.958291    0.053634    0.016741    0.746098    
#> 060: 0.823058    0.965363    3.458435    0.958754    0.050953    0.018417    0.755289    
#> 061: 0.874471    0.967251    3.469499    1.011297    0.048405    0.023999    0.752379    
#> 062: 0.756299    0.984116    3.461267    0.960732    0.045985    0.022799    0.756687    
#> 063: 0.760670    0.976506    3.448104    0.912695    0.043686    0.021659    0.764499    
#> 064: 0.788671    0.987108    3.469138    0.927036    0.043948    0.020576    0.752596    
#> 065: 0.811549    0.979338    3.446839    0.941111    0.044950    0.019547    0.734221    
#> 066: 0.820300    0.982652    3.459562    0.894055    0.048217    0.018570    0.734414    
#> 067: 0.776768    0.973761    3.458615    0.849353    0.045806    0.017641    0.733837    
#> 068: 0.705629    0.971093    3.451822    0.806885    0.047317    0.016759    0.736331    
#> 069: 0.701467    0.983053    3.443112    0.766541    0.047914    0.015921    0.739653    
#> 070: 0.721588    0.998062    3.446036    0.848519    0.054561    0.016237    0.724579    
#> 071: 0.710539    1.029773    3.425032    0.806093    0.051833    0.015425    0.746108    
#> 072: 0.686385    1.005968    3.423532    0.765788    0.053775    0.014654    0.735867    
#> 073: 0.692445    1.009908    3.449615    0.727499    0.055515    0.013921    0.749788    
#> 074: 0.696227    0.987460    3.447399    0.691124    0.054399    0.013225    0.731702    
#> 075: 0.738842    0.976977    3.461848    0.787307    0.053514    0.012564    0.738374    
#> 076: 0.702984    0.976768    3.463948    0.747941    0.050839    0.013076    0.756192    
#> 077: 0.762947    0.981599    3.452161    0.746798    0.048297    0.013588    0.738724    
#> 078: 0.760052    0.990278    3.458919    0.709458    0.045882    0.012909    0.745408    
#> 079: 0.729404    0.998901    3.466128    0.701374    0.048757    0.015562    0.759371    
#> 080: 0.729446    0.989183    3.451337    0.733711    0.046319    0.018181    0.761741    
#> 081: 0.756872    0.982252    3.457522    0.728120    0.044003    0.018208    0.761850    
#> 082: 0.721445    0.968265    3.460424    0.784787    0.041803    0.017298    0.773072    
#> 083: 0.706900    0.977618    3.478131    0.745548    0.039713    0.016433    0.777777    
#> 084: 0.750361    0.985482    3.462025    0.721256    0.040589    0.019190    0.751385    
#> 085: 0.708058    1.000397    3.462355    0.685193    0.038733    0.020678    0.744348    
#> 086: 0.731844    0.992514    3.465671    0.665981    0.036796    0.021325    0.746660    
#> 087: 0.721515    0.981792    3.447629    0.667985    0.034956    0.022240    0.734790    
#> 088: 0.676281    0.973230    3.445132    0.759470    0.033208    0.021128    0.760842    
#> 089: 0.739045    1.004066    3.434459    0.839429    0.035585    0.020072    0.722885    
#> 090: 0.706063    1.006463    3.435797    0.797458    0.039117    0.019115    0.722131    
#> 091: 0.678390    0.992612    3.429124    0.757585    0.037161    0.018160    0.740457    
#> 092: 0.718037    1.015509    3.428580    0.807974    0.035303    0.019812    0.726405    
#> 093: 0.661008    1.002889    3.428911    0.767576    0.051533    0.018821    0.753827    
#> 094: 0.703835    1.010342    3.426048    0.741713    0.052427    0.017880    0.742212    
#> 095: 0.763523    1.001164    3.452302    0.927633    0.049806    0.016986    0.758354    
#> 096: 0.692448    1.019253    3.441851    0.881251    0.047315    0.016137    0.748796    
#> 097: 0.761278    1.025400    3.441801    0.837189    0.044949    0.016777    0.736406    
#> 098: 0.791447    1.013442    3.458864    0.795329    0.046202    0.019067    0.717454    
#> 099: 0.718314    0.993685    3.443879    0.760216    0.043892    0.018114    0.728955    
#> 100: 0.712672    0.991262    3.452281    0.786684    0.046108    0.017208    0.721971    
#> 101: 0.709239    0.975189    3.430045    0.786779    0.043802    0.016348    0.734787    
#> 102: 0.705736    0.963240    3.439381    0.747440    0.041612    0.015531    0.739255    
#> 103: 0.724790    0.980817    3.439935    0.807585    0.049502    0.014754    0.736453    
#> 104: 0.660444    0.990403    3.447890    0.767206    0.047027    0.014016    0.754139    
#> 105: 0.697632    0.992681    3.443318    0.897763    0.060466    0.013315    0.775454    
#> 106: 0.732367    1.004545    3.440842    0.852875    0.062218    0.012650    0.734961    
#> 107: 0.721855    1.005759    3.440229    0.905777    0.077352    0.012017    0.740672    
#> 108: 0.702425    0.984398    3.437007    0.860488    0.073485    0.011416    0.754303    
#> 109: 0.703442    0.982326    3.450858    0.817463    0.078287    0.010846    0.733765    
#> 110: 0.704955    0.973083    3.437453    0.776590    0.074373    0.010378    0.741481    
#> 111: 0.708081    0.993971    3.439239    0.737761    0.070905    0.009860    0.727092    
#> 112: 0.677700    0.983137    3.434088    0.700873    0.067360    0.009367    0.751638    
#> 113: 0.682316    1.013823    3.435905    0.691885    0.063992    0.009833    0.738854    
#> 114: 0.656374    1.023290    3.435242    0.657291    0.060792    0.010216    0.747641    
#> 115: 0.688181    0.986255    3.435407    0.675614    0.074881    0.010065    0.736356    
#> 116: 0.764740    0.996051    3.449366    0.759862    0.071137    0.012081    0.729055    
#> 117: 0.700213    1.012987    3.448676    0.721869    0.067580    0.011477    0.748962    
#> 118: 0.729732    0.993762    3.455391    0.685775    0.064201    0.010903    0.764893    
#> 119: 0.759213    0.997490    3.445208    0.856989    0.066965    0.010639    0.754788    
#> 120: 0.673847    0.977149    3.439787    0.828641    0.063616    0.010853    0.745518    
#> 121: 0.730807    1.020348    3.441126    0.787209    0.060436    0.012357    0.746625    
#> 122: 0.704161    0.996112    3.451618    0.747849    0.057414    0.011739    0.743996    
#> 123: 0.716614    1.009992    3.443781    0.710456    0.055852    0.011152    0.738986    
#> 124: 0.775135    1.024831    3.440983    0.869559    0.053060    0.010772    0.751482    
#> 125: 0.707474    1.040416    3.429466    0.826081    0.053388    0.011190    0.752491    
#> 126: 0.688985    1.021812    3.425916    0.850451    0.063052    0.010631    0.756945    
#> 127: 0.676469    0.993065    3.422149    0.807929    0.066091    0.010099    0.784244    
#> 128: 0.706913    1.004310    3.436005    0.767532    0.062787    0.009594    0.763719    
#> 129: 0.733508    1.013401    3.434059    0.931146    0.059647    0.009115    0.762514    
#> 130: 0.809888    1.017718    3.438886    1.005102    0.056665    0.008734    0.748350    
#> 131: 0.736626    1.009669    3.430703    0.954847    0.055813    0.008297    0.734388    
#> 132: 0.668389    1.020269    3.419016    0.907104    0.068210    0.007882    0.730982    
#> 133: 0.683207    1.004153    3.429574    0.861749    0.075481    0.007488    0.733431    
#> 134: 0.672423    0.980125    3.437893    0.818662    0.071707    0.009290    0.741336    
#> 135: 0.698277    0.980050    3.445170    0.777729    0.068122    0.008825    0.749109    
#> 136: 0.674041    0.979683    3.444671    0.738842    0.064716    0.009658    0.755104    
#> 137: 0.718850    0.992936    3.446828    0.717967    0.061480    0.011594    0.747786    
#> 138: 0.727438    1.001920    3.437824    0.830805    0.058406    0.011709    0.733633    
#> 139: 0.717418    1.007507    3.440437    0.921427    0.055486    0.012768    0.743335    
#> 140: 0.767777    0.999520    3.442646    0.954913    0.052711    0.013685    0.756900    
#> 141: 0.776380    0.990038    3.445649    1.014446    0.050076    0.013001    0.758090    
#> 142: 0.757027    0.963443    3.461405    0.963724    0.047621    0.012351    0.759393    
#> 143: 0.730862    0.989581    3.450721    0.915538    0.055291    0.012089    0.748327    
#> 144: 0.696886    1.017415    3.447432    0.869761    0.055598    0.011485    0.736741    
#> 145: 0.704121    1.010397    3.443217    0.826273    0.059005    0.010910    0.736529    
#> 146: 0.700132    1.014015    3.450968    0.784959    0.056054    0.011723    0.737382    
#> 147: 0.654708    0.977234    3.450466    0.745711    0.053252    0.014151    0.735348    
#> 148: 0.680206    0.990622    3.460593    0.708426    0.051755    0.013443    0.739454    
#> 149: 0.702283    0.966199    3.465407    0.673004    0.049168    0.013729    0.738418    
#> 150: 0.753802    0.969406    3.463488    0.639354    0.046709    0.014027    0.740803    
#> 151: 0.653584    0.993750    3.455140    0.607386    0.044622    0.014059    0.731912    
#> 152: 0.684013    0.991754    3.459356    0.645553    0.042293    0.013714    0.742526    
#> 153: 0.695850    1.000407    3.459737    0.683860    0.051659    0.012436    0.737384    
#> 154: 0.710639    0.998394    3.461404    0.690722    0.056541    0.012085    0.738426    
#> 155: 0.698752    0.979883    3.452123    0.812075    0.054840    0.009578    0.744961    
#> 156: 0.742529    0.978905    3.463397    0.808527    0.056501    0.009919    0.773854    
#> 157: 0.727137    0.976050    3.471773    0.628803    0.061348    0.009501    0.785655    
#> 158: 0.768755    0.999368    3.461219    0.691912    0.052617    0.009078    0.774016    
#> 159: 0.719663    1.001601    3.457608    0.698470    0.057415    0.007777    0.771809    
#> 160: 0.771291    0.977801    3.461222    0.783522    0.050867    0.008565    0.767511    
#> 161: 0.766457    1.006985    3.453707    0.833262    0.040331    0.011520    0.749838    
#> 162: 0.764987    1.021911    3.437320    0.862329    0.042469    0.012366    0.748263    
#> 163: 0.741492    1.003131    3.438717    0.907387    0.042225    0.011249    0.721149    
#> 164: 0.725448    1.011391    3.442028    0.777090    0.041442    0.013536    0.725797    
#> 165: 0.761318    0.998024    3.449375    0.926498    0.050984    0.012471    0.716866    
#> 166: 0.818781    1.030829    3.440830    0.970295    0.064847    0.011180    0.734498    
#> 167: 0.808330    1.038562    3.453545    0.924499    0.061961    0.008974    0.755485    
#> 168: 0.804538    1.017232    3.460669    0.850948    0.065572    0.008572    0.749009    
#> 169: 0.742939    1.031910    3.442129    0.842674    0.064490    0.010828    0.744209    
#> 170: 0.756657    1.004224    3.442623    0.825842    0.057690    0.010781    0.761548    
#> 171: 0.742156    1.018524    3.439109    0.872143    0.066040    0.008578    0.739922    
#> 172: 0.722947    1.038420    3.433436    0.859849    0.062038    0.007500    0.723566    
#> 173: 0.659314    1.036813    3.417912    0.669630    0.060124    0.006768    0.756441    
#> 174: 0.650844    1.028318    3.421783    0.589253    0.066310    0.005063    0.758756    
#> 175: 0.669508    1.026795    3.415817    0.758149    0.088505    0.005218    0.777675    
#> 176: 0.640546    1.036146    3.421975    0.641357    0.074301    0.003447    0.759852    
#> 177: 0.664894    1.011683    3.431229    0.730953    0.073506    0.003787    0.750612    
#> 178: 0.679433    1.008163    3.432528    0.700027    0.074966    0.003971    0.740034    
#> 179: 0.741009    1.015508    3.436270    0.760033    0.059083    0.004052    0.765489    
#> 180: 0.653016    1.019274    3.428067    0.593379    0.054773    0.005311    0.766986    
#> 181: 0.630268    1.009201    3.418306    0.614464    0.050937    0.005126    0.757540    
#> 182: 0.654109    1.022686    3.412265    0.707358    0.073998    0.005110    0.755183    
#> 183: 0.673180    1.033381    3.413137    0.672498    0.058555    0.004806    0.742368    
#> 184: 0.654366    1.016252    3.410530    0.782840    0.057941    0.004077    0.767979    
#> 185: 0.632093    1.040114    3.406209    0.625448    0.057237    0.004453    0.777327    
#> 186: 0.594975    1.045689    3.410851    0.669681    0.075208    0.003932    0.767549    
#> 187: 0.612099    1.010835    3.416306    0.640209    0.059001    0.003491    0.778151    
#> 188: 0.603446    1.028068    3.412939    0.709387    0.072401    0.004141    0.779935    
#> 189: 0.644374    1.051139    3.417247    0.685513    0.081416    0.004030    0.759616    
#> 190: 0.677828    1.036357    3.424777    0.677018    0.067280    0.004147    0.773290    
#> 191: 0.623179    1.042121    3.419400    0.571083    0.057097    0.004022    0.759800    
#> 192: 0.593943    1.034926    3.424225    0.524754    0.070091    0.004811    0.781911    
#> 193: 0.637151    1.035137    3.429274    0.605138    0.060302    0.003964    0.758649    
#> 194: 0.647841    1.015763    3.418872    0.692392    0.079906    0.003743    0.782431    
#> 195: 0.592561    1.029421    3.414971    0.621974    0.066820    0.002759    0.812096    
#> 196: 0.625336    1.025556    3.421256    0.714013    0.077921    0.002787    0.802450    
#> 197: 0.637056    1.016602    3.431963    0.741302    0.069911    0.002831    0.797246    
#> 198: 0.714999    0.997694    3.421463    0.809189    0.073503    0.003014    0.783454    
#> 199: 0.623102    0.977668    3.425880    0.706834    0.084963    0.002296    0.802579    
#> 200: 0.642126    1.020844    3.420458    0.638690    0.088270    0.001369    0.823178    
#> 201: 0.635860    1.009955    3.422682    0.650087    0.081063    0.001638    0.801015    
#> 202: 0.641358    1.012951    3.421938    0.679646    0.079602    0.001763    0.798211    
#> 203: 0.657002    1.016146    3.421578    0.712676    0.077835    0.001876    0.795323    
#> 204: 0.652426    1.015502    3.422780    0.703394    0.078459    0.001872    0.795696    
#> 205: 0.653576    1.020474    3.422551    0.704906    0.079050    0.001923    0.793578    
#> 206: 0.659772    1.024741    3.423023    0.736492    0.079331    0.001935    0.794265    
#> 207: 0.659122    1.023708    3.422520    0.728328    0.081335    0.001924    0.795553    
#> 208: 0.662060    1.023377    3.422372    0.716411    0.080474    0.001936    0.794845    
#> 209: 0.664969    1.021202    3.422616    0.714428    0.079393    0.001909    0.795298    
#> 210: 0.665032    1.020291    3.422622    0.713062    0.079211    0.001907    0.794295    
#> 211: 0.668173    1.019530    3.423329    0.716428    0.079049    0.001875    0.793220    
#> 212: 0.670905    1.017042    3.423896    0.711209    0.078836    0.001854    0.791043    
#> 213: 0.672372    1.013140    3.424566    0.706041    0.079660    0.001866    0.789888    
#> 214: 0.674121    1.011361    3.424581    0.709700    0.080244    0.001896    0.788121    
#> 215: 0.672486    1.012367    3.424582    0.705808    0.080571    0.001932    0.786334    
#> 216: 0.677126    1.011955    3.424635    0.712470    0.080928    0.001936    0.786122    
#> 217: 0.680430    1.013292    3.424425    0.720178    0.080603    0.001953    0.785215    
#> 218: 0.679561    1.015021    3.423567    0.721749    0.080422    0.001993    0.783349    
#> 219: 0.678771    1.014406    3.422490    0.727672    0.079348    0.002071    0.782237    
#> 220: 0.673773    1.015390    3.421870    0.722444    0.079152    0.002069    0.781639    
#> 221: 0.670799    1.015990    3.421370    0.723119    0.078487    0.002061    0.781146    
#> 222: 0.671075    1.015163    3.421255    0.728948    0.078042    0.002084    0.780513    
#> 223: 0.670895    1.014898    3.421181    0.729175    0.077643    0.002086    0.779757    
#> 224: 0.672766    1.015678    3.421308    0.732209    0.077963    0.002082    0.779353    
#> 225: 0.672112    1.014297    3.421499    0.731810    0.077536    0.002072    0.779181    
#> 226: 0.673090    1.013369    3.421696    0.736654    0.077182    0.002090    0.778837    
#> 227: 0.672589    1.013015    3.421980    0.734559    0.077308    0.002107    0.778446    
#> 228: 0.671613    1.013621    3.421732    0.731844    0.077576    0.002142    0.777845    
#> 229: 0.670403    1.013521    3.421591    0.730750    0.077409    0.002167    0.777011    
#> 230: 0.670192    1.013540    3.421364    0.728142    0.077228    0.002165    0.777026    
#> 231: 0.669208    1.013751    3.421208    0.726513    0.077081    0.002166    0.776823    
#> 232: 0.667294    1.014226    3.421198    0.725721    0.076878    0.002185    0.776802    
#> 233: 0.667279    1.014044    3.421243    0.727265    0.076857    0.002212    0.776825    
#> 234: 0.666390    1.014460    3.421301    0.725780    0.076884    0.002227    0.776043    
#> 235: 0.666139    1.013979    3.421097    0.726411    0.076912    0.002210    0.775666    
#> 236: 0.665091    1.014021    3.420959    0.722771    0.077122    0.002197    0.775519    
#> 237: 0.665993    1.013884    3.420865    0.724322    0.077381    0.002196    0.775632    
#> 238: 0.667465    1.013812    3.420885    0.728347    0.077581    0.002197    0.776118    
#> 239: 0.667991    1.013939    3.420965    0.730639    0.077843    0.002196    0.776308    
#> 240: 0.669966    1.013468    3.421049    0.735927    0.077925    0.002190    0.776357    
#> 241: 0.671252    1.012665    3.421283    0.739184    0.077723    0.002180    0.776421    
#> 242: 0.670687    1.012049    3.421320    0.740283    0.077610    0.002193    0.776703    
#> 243: 0.669819    1.012343    3.421289    0.738750    0.077674    0.002197    0.777109    
#> 244: 0.669112    1.012249    3.421343    0.736412    0.077366    0.002208    0.777334    
#> 245: 0.669184    1.012016    3.421409    0.735766    0.076925    0.002205    0.777901    
#> 246: 0.669538    1.011758    3.421519    0.734419    0.076248    0.002210    0.778302    
#> 247: 0.669842    1.011701    3.421640    0.735205    0.075915    0.002213    0.778131    
#> 248: 0.669245    1.011906    3.421659    0.734415    0.075697    0.002209    0.777926    
#> 249: 0.668463    1.012222    3.421711    0.733754    0.075931    0.002202    0.778030    
#> 250: 0.669401    1.012401    3.421718    0.735943    0.075941    0.002212    0.777917    
#> 251: 0.670306    1.012841    3.421791    0.738437    0.075932    0.002221    0.777748    
#> 252: 0.670813    1.013111    3.421863    0.738476    0.075859    0.002231    0.778124    
#> 253: 0.670606    1.013336    3.421954    0.738089    0.075819    0.002244    0.777831    
#> 254: 0.670453    1.014118    3.422158    0.737014    0.075732    0.002258    0.777697    
#> 255: 0.670191    1.014630    3.422440    0.735629    0.075675    0.002283    0.777645    
#> 256: 0.670156    1.014450    3.422496    0.734753    0.075338    0.002293    0.777563    
#> 257: 0.669655    1.014068    3.422514    0.733433    0.075018    0.002286    0.777641    
#> 258: 0.669313    1.013877    3.422400    0.731961    0.074850    0.002278    0.777501    
#> 259: 0.669071    1.013860    3.422351    0.731520    0.074813    0.002272    0.777538    
#> 260: 0.668293    1.014195    3.422408    0.729944    0.074687    0.002262    0.777729    
#> 261: 0.667534    1.014133    3.422437    0.728927    0.074523    0.002259    0.777595    
#> 262: 0.667811    1.014129    3.422491    0.728612    0.074664    0.002258    0.777661    
#> 263: 0.667757    1.014417    3.422547    0.727984    0.074684    0.002278    0.777740    
#> 264: 0.667670    1.014418    3.422607    0.728102    0.074613    0.002296    0.778008    
#> 265: 0.667889    1.014630    3.422533    0.729304    0.074705    0.002301    0.778102    
#> 266: 0.668320    1.014572    3.422534    0.731957    0.074712    0.002304    0.778090    
#> 267: 0.668524    1.014910    3.422514    0.733888    0.074689    0.002310    0.777988    
#> 268: 0.668806    1.014825    3.422434    0.734231    0.074577    0.002317    0.777871    
#> 269: 0.668974    1.014687    3.422450    0.734507    0.074419    0.002327    0.777628    
#> 270: 0.669363    1.014714    3.422308    0.736034    0.074331    0.002335    0.777202    
#> 271: 0.669140    1.014938    3.422124    0.736993    0.074305    0.002344    0.777388    
#> 272: 0.669093    1.014989    3.421924    0.736673    0.074261    0.002353    0.777732    
#> 273: 0.669007    1.015276    3.421844    0.736343    0.074448    0.002357    0.777760    
#> 274: 0.668521    1.015459    3.421959    0.733719    0.074332    0.002358    0.777847    
#> 275: 0.668688    1.015502    3.421934    0.734410    0.074208    0.002358    0.777585    
#> 276: 0.668870    1.015596    3.422110    0.734838    0.074180    0.002377    0.777264    
#> 277: 0.668688    1.015562    3.422296    0.734993    0.074179    0.002395    0.777039    
#> 278: 0.669037    1.015299    3.422439    0.735616    0.074251    0.002407    0.777049    
#> 279: 0.669908    1.014961    3.422507    0.738645    0.074279    0.002418    0.777149    
#> 280: 0.670281    1.015124    3.422586    0.739370    0.074184    0.002422    0.777189    
#> 281: 0.669931    1.015330    3.422599    0.739430    0.074035    0.002425    0.777201    
#> 282: 0.669706    1.015628    3.422639    0.739555    0.073947    0.002441    0.777269    
#> 283: 0.669816    1.015948    3.422708    0.739100    0.073729    0.002468    0.777372    
#> 284: 0.669350    1.015915    3.422682    0.738662    0.073430    0.002483    0.777418    
#> 285: 0.669493    1.015949    3.422646    0.739084    0.073261    0.002491    0.777495    
#> 286: 0.669693    1.016297    3.422554    0.739678    0.073115    0.002503    0.777569    
#> 287: 0.669008    1.016668    3.422463    0.738882    0.073049    0.002516    0.777519    
#> 288: 0.668852    1.016695    3.422395    0.737851    0.073056    0.002521    0.777511    
#> 289: 0.668900    1.016616    3.422319    0.738569    0.072970    0.002529    0.777421    
#> 290: 0.668655    1.016640    3.422214    0.737807    0.072955    0.002535    0.777536    
#> 291: 0.668913    1.016950    3.422208    0.739066    0.072901    0.002536    0.777534    
#> 292: 0.669023    1.017140    3.422211    0.737910    0.072840    0.002530    0.777572    
#> 293: 0.668755    1.017129    3.422169    0.737557    0.072800    0.002528    0.777537    
#> 294: 0.668998    1.017039    3.422175    0.737487    0.072765    0.002523    0.777617    
#> 295: 0.669059    1.016779    3.422127    0.738730    0.072665    0.002525    0.777294    
#> 296: 0.669031    1.016737    3.422136    0.738455    0.072465    0.002542    0.777135    
#> 297: 0.669103    1.016782    3.422128    0.738460    0.072281    0.002554    0.777008    
#> 298: 0.669151    1.016798    3.422117    0.737899    0.072128    0.002567    0.776797    
#> 299: 0.669462    1.016768    3.422122    0.738707    0.071995    0.002572    0.776546    
#> 300: 0.669664    1.016663    3.422192    0.738858    0.071965    0.002570    0.776339    
#> 301: 0.670036    1.016423    3.422229    0.738940    0.071870    0.002571    0.776324    
#> 302: 0.670119    1.016438    3.422222    0.739271    0.071761    0.002571    0.776198    
#> 303: 0.670330    1.016436    3.422253    0.739727    0.071646    0.002584    0.776035    
#> 304: 0.670358    1.016657    3.422268    0.740366    0.071653    0.002595    0.775925    
#> 305: 0.670216    1.016489    3.422313    0.740343    0.071622    0.002612    0.775700    
#> 306: 0.669528    1.016315    3.422278    0.739559    0.071675    0.002619    0.775569    
#> 307: 0.669183    1.016259    3.422241    0.738484    0.071797    0.002619    0.775574    
#> 308: 0.668728    1.016190    3.422248    0.738426    0.071980    0.002632    0.775715    
#> 309: 0.668620    1.015923    3.422223    0.739248    0.072020    0.002639    0.775876    
#> 310: 0.669102    1.015885    3.422152    0.739915    0.071968    0.002641    0.775724    
#> 311: 0.669019    1.015842    3.422107    0.739205    0.072003    0.002640    0.775684    
#> 312: 0.669047    1.015857    3.422039    0.740107    0.072062    0.002634    0.775728    
#> 313: 0.668633    1.015760    3.421990    0.739393    0.072059    0.002635    0.775593    
#> 314: 0.668418    1.015631    3.421929    0.738720    0.071998    0.002634    0.775447    
#> 315: 0.668141    1.015577    3.421932    0.738109    0.071950    0.002635    0.775346    
#> 316: 0.668313    1.015545    3.421934    0.738923    0.071859    0.002637    0.775258    
#> 317: 0.668323    1.015588    3.421958    0.738884    0.071860    0.002636    0.775380    
#> 318: 0.668177    1.015539    3.421913    0.738103    0.071801    0.002636    0.775118    
#> 319: 0.668064    1.015433    3.421921    0.737385    0.071854    0.002631    0.775004    
#> 320: 0.667758    1.015319    3.421848    0.737770    0.071813    0.002627    0.774935    
#> 321: 0.666940    1.015238    3.421715    0.737101    0.071803    0.002621    0.775037    
#> 322: 0.666936    1.015310    3.421578    0.737522    0.071781    0.002616    0.775032    
#> 323: 0.666542    1.015364    3.421485    0.737664    0.071815    0.002612    0.775024    
#> 324: 0.666193    1.015662    3.421438    0.736845    0.071966    0.002606    0.774898    
#> 325: 0.665911    1.015900    3.421382    0.736643    0.071882    0.002605    0.774852    
#> 326: 0.666094    1.015844    3.421295    0.736584    0.071910    0.002605    0.774630    
#> 327: 0.666482    1.015876    3.421285    0.737723    0.071972    0.002605    0.774560    
#> 328: 0.666493    1.015922    3.421272    0.737550    0.071940    0.002605    0.774453    
#> 329: 0.666418    1.015943    3.421276    0.737695    0.072005    0.002607    0.774425    
#> 330: 0.666400    1.016048    3.421306    0.738229    0.071990    0.002613    0.774323    
#> 331: 0.666593    1.016282    3.421328    0.738256    0.071948    0.002623    0.774303    
#> 332: 0.666664    1.016166    3.421373    0.738651    0.071817    0.002630    0.774352    
#> 333: 0.666815    1.016141    3.421374    0.738970    0.071790    0.002644    0.774314    
#> 334: 0.666734    1.016016    3.421368    0.739182    0.071742    0.002652    0.774349    
#> 335: 0.666708    1.016103    3.421298    0.739533    0.071699    0.002650    0.774361    
#> 336: 0.666431    1.016325    3.421250    0.739209    0.071793    0.002647    0.774354    
#> 337: 0.666869    1.016532    3.421236    0.740767    0.071759    0.002641    0.774438    
#> 338: 0.667138    1.016457    3.421297    0.741850    0.071740    0.002638    0.774498    
#> 339: 0.666905    1.016517    3.421331    0.741255    0.071678    0.002638    0.774431    
#> 340: 0.666658    1.016336    3.421416    0.740937    0.071649    0.002639    0.774490    
#> 341: 0.666647    1.016249    3.421501    0.740430    0.071606    0.002642    0.774566    
#> 342: 0.666215    1.016184    3.421502    0.740021    0.071631    0.002646    0.774492    
#> 343: 0.665945    1.016290    3.421545    0.739029    0.071728    0.002644    0.774382    
#> 344: 0.666138    1.016323    3.421568    0.739590    0.071754    0.002645    0.774434    
#> 345: 0.666166    1.016278    3.421585    0.738817    0.071658    0.002649    0.774483    
#> 346: 0.666151    1.016390    3.421567    0.738141    0.071535    0.002650    0.774461    
#> 347: 0.666113    1.016402    3.421481    0.738100    0.071476    0.002654    0.774446    
#> 348: 0.665769    1.016597    3.421396    0.738382    0.071482    0.002659    0.774500    
#> 349: 0.665930    1.016616    3.421309    0.740367    0.071411    0.002660    0.774486    
#> 350: 0.665799    1.016537    3.421254    0.740480    0.071365    0.002664    0.774530    
#> 351: 0.665946    1.016620    3.421218    0.740287    0.071318    0.002663    0.774656    
#> 352: 0.665840    1.016653    3.421191    0.740359    0.071294    0.002672    0.774654    
#> 353: 0.666022    1.016747    3.421181    0.740045    0.071198    0.002676    0.774535    
#> 354: 0.666091    1.016740    3.421118    0.740610    0.071111    0.002683    0.774422    
#> 355: 0.666287    1.016635    3.421086    0.741347    0.071078    0.002692    0.774301    
#> 356: 0.666099    1.016492    3.421105    0.740260    0.071097    0.002696    0.774366    
#> 357: 0.666347    1.016537    3.421172    0.740292    0.071012    0.002700    0.774262    
#> 358: 0.666150    1.016581    3.421252    0.739943    0.070980    0.002702    0.774305    
#> 359: 0.665838    1.016769    3.421261    0.739711    0.071019    0.002703    0.774170    
#> 360: 0.665519    1.016820    3.421203    0.739031    0.070960    0.002701    0.774103    
#> 361: 0.665191    1.016833    3.421163    0.738297    0.070833    0.002701    0.773977    
#> 362: 0.665195    1.016833    3.421111    0.737907    0.070723    0.002702    0.773838    
#> 363: 0.664994    1.016892    3.421042    0.737886    0.070643    0.002706    0.773718    
#> 364: 0.664889    1.016957    3.420920    0.738133    0.070585    0.002706    0.773659    
#> 365: 0.664673    1.016932    3.420861    0.738256    0.070611    0.002706    0.773676    
#> 366: 0.664604    1.017061    3.420776    0.737491    0.070558    0.002703    0.773716    
#> 367: 0.664410    1.017124    3.420711    0.737335    0.070562    0.002700    0.773651    
#> 368: 0.664543    1.017250    3.420653    0.737649    0.070473    0.002699    0.773660    
#> 369: 0.664636    1.017409    3.420627    0.739162    0.070421    0.002697    0.773689    
#> 370: 0.664738    1.017510    3.420604    0.740079    0.070417    0.002695    0.773647    
#> 371: 0.664510    1.017525    3.420512    0.740133    0.070397    0.002694    0.773613    
#> 372: 0.664321    1.017589    3.420446    0.739986    0.070416    0.002693    0.773599    
#> 373: 0.663901    1.017819    3.420350    0.739298    0.070441    0.002692    0.773577    
#> 374: 0.663625    1.017851    3.420272    0.738754    0.070466    0.002688    0.773593    
#> 375: 0.663318    1.017921    3.420214    0.738185    0.070577    0.002691    0.773568    
#> 376: 0.662951    1.017986    3.420140    0.737448    0.070679    0.002694    0.773582    
#> 377: 0.662685    1.018070    3.420088    0.736959    0.070788    0.002693    0.773641    
#> 378: 0.662396    1.018044    3.420047    0.736112    0.070754    0.002697    0.773677    
#> 379: 0.662095    1.017818    3.420047    0.735690    0.070720    0.002701    0.773631    
#> 380: 0.661888    1.017721    3.420008    0.735863    0.070643    0.002704    0.773574    
#> 381: 0.661707    1.017679    3.419977    0.735859    0.070582    0.002702    0.773651    
#> 382: 0.661537    1.017731    3.419953    0.735418    0.070480    0.002705    0.773530    
#> 383: 0.661498    1.017774    3.419933    0.735691    0.070419    0.002705    0.773529    
#> 384: 0.661076    1.017702    3.419968    0.735165    0.070400    0.002705    0.773521    
#> 385: 0.661189    1.017765    3.419977    0.735196    0.070360    0.002708    0.773420    
#> 386: 0.661216    1.017932    3.419995    0.734432    0.070304    0.002714    0.773400    
#> 387: 0.661109    1.018052    3.420012    0.733941    0.070219    0.002724    0.773392    
#> 388: 0.661363    1.018122    3.420053    0.734163    0.070182    0.002736    0.773347    
#> 389: 0.661574    1.017977    3.420104    0.734617    0.070127    0.002739    0.773384    
#> 390: 0.661428    1.017980    3.420107    0.734212    0.070021    0.002743    0.773395    
#> 391: 0.661471    1.017909    3.420138    0.734484    0.069978    0.002747    0.773330    
#> 392: 0.661641    1.017973    3.420180    0.735244    0.069912    0.002748    0.773304    
#> 393: 0.661704    1.017960    3.420194    0.735968    0.069894    0.002751    0.773215    
#> 394: 0.661813    1.017930    3.420217    0.736318    0.069924    0.002756    0.773114    
#> 395: 0.662095    1.018002    3.420259    0.737348    0.069915    0.002763    0.773073    
#> 396: 0.662413    1.017986    3.420318    0.738441    0.069976    0.002764    0.773016    
#> 397: 0.662543    1.017965    3.420386    0.738868    0.070003    0.002765    0.772945    
#> 398: 0.663022    1.017863    3.420456    0.739588    0.070004    0.002768    0.772852    
#> 399: 0.663559    1.017740    3.420559    0.740703    0.069960    0.002771    0.772835    
#> 400: 0.663952    1.017732    3.420641    0.741663    0.069952    0.002774    0.772830    
#> 401: 0.664025    1.017719    3.420649    0.742127    0.069954    0.002775    0.772800    
#> 402: 0.664035    1.017813    3.420649    0.741911    0.069872    0.002779    0.772790    
#> 403: 0.664255    1.017818    3.420660    0.741978    0.069829    0.002784    0.772803    
#> 404: 0.664185    1.017826    3.420649    0.741720    0.069721    0.002788    0.772810    
#> 405: 0.664010    1.017815    3.420659    0.741733    0.069695    0.002791    0.772818    
#> 406: 0.663947    1.017875    3.420679    0.741423    0.069709    0.002794    0.772846    
#> 407: 0.663892    1.017845    3.420716    0.741444    0.069705    0.002792    0.772883    
#> 408: 0.663788    1.017975    3.420709    0.740998    0.069777    0.002792    0.772960    
#> 409: 0.663491    1.018026    3.420678    0.740315    0.069717    0.002794    0.772970    
#> 410: 0.663201    1.018149    3.420607    0.739562    0.069665    0.002797    0.772969    
#> 411: 0.663304    1.018034    3.420555    0.740159    0.069638    0.002804    0.773004    
#> 412: 0.663326    1.018051    3.420520    0.739744    0.069565    0.002808    0.772999    
#> 413: 0.663433    1.018122    3.420472    0.739355    0.069566    0.002811    0.773048    
#> 414: 0.663444    1.018138    3.420450    0.740109    0.069526    0.002811    0.773021    
#> 415: 0.663729    1.018035    3.420452    0.740645    0.069511    0.002823    0.772941    
#> 416: 0.663959    1.018074    3.420463    0.740535    0.069483    0.002833    0.772877    
#> 417: 0.664137    1.017996    3.420485    0.740511    0.069447    0.002840    0.772836    
#> 418: 0.663980    1.017992    3.420480    0.740117    0.069496    0.002842    0.772798    
#> 419: 0.664057    1.018122    3.420480    0.740507    0.069517    0.002849    0.772699    
#> 420: 0.664209    1.018212    3.420492    0.741005    0.069527    0.002852    0.772638    
#> 421: 0.664064    1.018223    3.420512    0.740551    0.069540    0.002853    0.772595    
#> 422: 0.664258    1.018118    3.420526    0.741005    0.069562    0.002856    0.772539    
#> 423: 0.664409    1.018022    3.420563    0.741029    0.069566    0.002857    0.772554    
#> 424: 0.664352    1.017990    3.420585    0.740642    0.069609    0.002855    0.772527    
#> 425: 0.664518    1.018056    3.420597    0.740630    0.069635    0.002857    0.772464    
#> 426: 0.664857    1.018129    3.420625    0.741300    0.069677    0.002856    0.772444    
#> 427: 0.664891    1.018031    3.420658    0.740983    0.069683    0.002860    0.772373    
#> 428: 0.664731    1.018003    3.420680    0.740390    0.069670    0.002864    0.772349    
#> 429: 0.664713    1.018074    3.420706    0.740063    0.069636    0.002866    0.772377    
#> 430: 0.664774    1.018089    3.420708    0.739997    0.069666    0.002867    0.772377    
#> 431: 0.664680    1.018097    3.420674    0.739905    0.069671    0.002865    0.772295    
#> 432: 0.664534    1.018234    3.420657    0.739837    0.069640    0.002865    0.772284    
#> 433: 0.664592    1.018374    3.420652    0.739883    0.069596    0.002865    0.772266    
#> 434: 0.664542    1.018377    3.420665    0.739760    0.069564    0.002868    0.772213    
#> 435: 0.664620    1.018379    3.420680    0.739375    0.069545    0.002870    0.772172    
#> 436: 0.664754    1.018291    3.420701    0.739073    0.069504    0.002873    0.772214    
#> 437: 0.664770    1.018335    3.420695    0.739247    0.069409    0.002875    0.772267    
#> 438: 0.664776    1.018584    3.420691    0.739656    0.069384    0.002876    0.772235    
#> 439: 0.664839    1.018773    3.420647    0.740063    0.069371    0.002878    0.772105    
#> 440: 0.664754    1.018939    3.420641    0.739411    0.069336    0.002878    0.772115    
#> 441: 0.664815    1.018981    3.420645    0.739491    0.069387    0.002881    0.771985    
#> 442: 0.664771    1.019123    3.420643    0.739171    0.069403    0.002878    0.771982    
#> 443: 0.664838    1.019236    3.420634    0.739316    0.069421    0.002879    0.771864    
#> 444: 0.664531    1.019300    3.420632    0.738915    0.069442    0.002879    0.771791    
#> 445: 0.664514    1.019378    3.420606    0.739075    0.069435    0.002884    0.771761    
#> 446: 0.664470    1.019390    3.420571    0.738988    0.069391    0.002886    0.771738    
#> 447: 0.664762    1.019420    3.420590    0.739122    0.069387    0.002891    0.771690    
#> 448: 0.664562    1.019486    3.420597    0.738669    0.069348    0.002892    0.771627    
#> 449: 0.664563    1.019546    3.420676    0.738121    0.069363    0.002895    0.771573    
#> 450: 0.664621    1.019541    3.420705    0.737596    0.069329    0.002902    0.771563    
#> 451: 0.664887    1.019582    3.420696    0.737808    0.069347    0.002904    0.771542    
#> 452: 0.664923    1.019654    3.420667    0.737903    0.069341    0.002905    0.771526    
#> 453: 0.664741    1.019656    3.420648    0.737453    0.069332    0.002904    0.771524    
#> 454: 0.664616    1.019729    3.420618    0.737116    0.069373    0.002903    0.771421    
#> 455: 0.664735    1.019711    3.420576    0.737439    0.069376    0.002902    0.771355    
#> 456: 0.664753    1.019708    3.420556    0.737653    0.069399    0.002902    0.771355    
#> 457: 0.664897    1.019664    3.420562    0.738376    0.069393    0.002903    0.771273    
#> 458: 0.665045    1.019751    3.420576    0.739173    0.069402    0.002903    0.771229    
#> 459: 0.664772    1.019920    3.420583    0.739063    0.069399    0.002904    0.771320    
#> 460: 0.664531    1.020011    3.420557    0.738651    0.069401    0.002907    0.771333    
#> 461: 0.664463    1.020177    3.420543    0.738593    0.069404    0.002911    0.771289    
#> 462: 0.664463    1.020306    3.420540    0.738468    0.069436    0.002911    0.771283    
#> 463: 0.664471    1.020360    3.420525    0.738199    0.069424    0.002911    0.771283    
#> 464: 0.664451    1.020346    3.420530    0.737868    0.069454    0.002911    0.771240    
#> 465: 0.664399    1.020192    3.420528    0.737559    0.069473    0.002910    0.771238    
#> 466: 0.664458    1.020234    3.420508    0.737593    0.069424    0.002910    0.771292    
#> 467: 0.664438    1.020196    3.420502    0.737412    0.069419    0.002913    0.771158    
#> 468: 0.664610    1.020166    3.420516    0.737440    0.069396    0.002917    0.771117    
#> 469: 0.664764    1.020247    3.420530    0.737748    0.069375    0.002921    0.771130    
#> 470: 0.664595    1.020245    3.420530    0.737676    0.069403    0.002926    0.771114    
#> 471: 0.664384    1.020191    3.420514    0.737514    0.069406    0.002927    0.771178    
#> 472: 0.664370    1.020138    3.420534    0.737117    0.069405    0.002930    0.771178    
#> 473: 0.664217    1.020081    3.420545    0.736625    0.069364    0.002931    0.771125    
#> 474: 0.664225    1.020030    3.420567    0.736448    0.069401    0.002932    0.771196    
#> 475: 0.664205    1.020108    3.420587    0.736030    0.069375    0.002936    0.771170    
#> 476: 0.664475    1.020074    3.420598    0.736271    0.069376    0.002936    0.771209    
#> 477: 0.664582    1.020016    3.420620    0.736308    0.069385    0.002937    0.771222    
#> 478: 0.664618    1.019907    3.420666    0.736329    0.069380    0.002940    0.771248    
#> 479: 0.664853    1.019932    3.420702    0.736957    0.069421    0.002942    0.771304    
#> 480: 0.664940    1.019902    3.420722    0.737493    0.069459    0.002943    0.771419    
#> 481: 0.664949    1.019893    3.420717    0.737574    0.069426    0.002943    0.771486    
#> 482: 0.665071    1.019907    3.420691    0.737751    0.069391    0.002946    0.771506    
#> 483: 0.665048    1.019882    3.420652    0.738151    0.069377    0.002947    0.771578    
#> 484: 0.665128    1.019783    3.420657    0.738647    0.069303    0.002945    0.771624    
#> 485: 0.665307    1.019753    3.420682    0.738998    0.069297    0.002944    0.771660    
#> 486: 0.665494    1.019706    3.420722    0.738680    0.069270    0.002942    0.771643    
#> 487: 0.665746    1.019724    3.420779    0.738609    0.069253    0.002940    0.771629    
#> 488: 0.665835    1.019616    3.420829    0.738671    0.069276    0.002937    0.771629    
#> 489: 0.666062    1.019481    3.420880    0.739023    0.069307    0.002938    0.771680    
#> 490: 0.666354    1.019456    3.420953    0.739579    0.069320    0.002940    0.771751    
#> 491: 0.666427    1.019472    3.420995    0.739459    0.069360    0.002938    0.771790    
#> 492: 0.666371    1.019514    3.421005    0.739470    0.069398    0.002935    0.771879    
#> 493: 0.666150    1.019461    3.421028    0.738887    0.069436    0.002937    0.771873    
#> 494: 0.666181    1.019462    3.421045    0.738694    0.069457    0.002937    0.771812    
#> 495: 0.666507    1.019406    3.421089    0.739612    0.069450    0.002939    0.771787    
#> 496: 0.666726    1.019430    3.421081    0.739929    0.069445    0.002939    0.771746    
#> 497: 0.666627    1.019445    3.421079    0.739982    0.069417    0.002938    0.771791    
#> 498: 0.666505    1.019458    3.421074    0.739801    0.069409    0.002937    0.771775    
#> 499: 0.666629    1.019521    3.421051    0.740011    0.069432    0.002936    0.771747    
#> 500: 0.666728    1.019472    3.421047    0.740231    0.069476    0.002936    0.771707    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.307931    0.966708    3.441481    0.392401    0.077294    0.016800    1.697515    
#> 002: 0.275358    1.019952    3.457732    0.372781    0.073429    0.015960    1.190800    
#> 003: 0.393126    0.986078    3.466036    0.354142    0.073338    0.015162    0.899233    
#> 004: 0.378514    0.967869    3.479677    0.336435    0.078832    0.014565    0.814244    
#> 005: 0.405434    0.981621    3.464445    0.319613    0.104183    0.013836    0.739011    
#> 006: 0.416333    0.977674    3.462670    0.303633    0.098974    0.013145    0.701785    
#> 007: 0.365853    1.001040    3.461219    0.288451    0.094025    0.012487    0.677313    
#> 008: 0.420019    1.011126    3.466014    0.274029    0.092966    0.011863    0.673074    
#> 009: 0.369423    0.997594    3.465063    0.260327    0.088318    0.011270    0.686856    
#> 010: 0.382819    0.994732    3.462765    0.257654    0.083902    0.015679    0.681198    
#> 011: 0.451733    0.998255    3.468849    0.307070    0.084138    0.016489    0.678476    
#> 012: 0.474506    1.002985    3.464856    0.291717    0.091568    0.015664    0.656234    
#> 013: 0.391633    0.993518    3.459167    0.277131    0.086990    0.016062    0.665675    
#> 014: 0.433693    1.002811    3.470246    0.263275    0.082640    0.023513    0.667020    
#> 015: 0.426225    0.998632    3.473358    0.265927    0.081372    0.022338    0.650524    
#> 016: 0.424914    1.007018    3.468142    0.281163    0.083666    0.021221    0.660396    
#> 017: 0.430764    1.011041    3.472563    0.310389    0.079483    0.022836    0.649751    
#> 018: 0.427986    1.024631    3.460275    0.333999    0.086919    0.023668    0.656999    
#> 019: 0.385824    1.009541    3.455386    0.317299    0.082573    0.022485    0.663093    
#> 020: 0.426603    1.003509    3.467449    0.301434    0.078445    0.026971    0.665183    
#> 021: 0.437419    0.984515    3.481684    0.286363    0.074523    0.025622    0.659072    
#> 022: 0.433291    0.982931    3.496740    0.272045    0.070796    0.025736    0.650448    
#> 023: 0.524803    0.998181    3.508066    0.294564    0.070566    0.029196    0.669732    
#> 024: 0.524620    1.000258    3.506657    0.286251    0.070417    0.027736    0.667679    
#> 025: 0.495311    0.985909    3.491861    0.271939    0.068983    0.026349    0.662374    
#> 026: 0.415879    1.014330    3.464585    0.258342    0.065534    0.025032    0.674109    
#> 027: 0.393243    1.032625    3.456771    0.279412    0.063998    0.023780    0.678220    
#> 028: 0.432130    1.021163    3.469953    0.271638    0.066488    0.025517    0.671139    
#> 029: 0.455608    1.010379    3.467146    0.339910    0.077824    0.030731    0.679465    
#> 030: 0.463648    1.018350    3.470244    0.322915    0.081619    0.029194    0.665873    
#> 031: 0.425976    0.995136    3.485271    0.343446    0.077538    0.027734    0.666726    
#> 032: 0.448593    0.979358    3.494010    0.326274    0.073662    0.028714    0.663183    
#> 033: 0.414432    0.997080    3.478079    0.309960    0.074541    0.027278    0.681681    
#> 034: 0.431492    0.997777    3.485057    0.294462    0.070814    0.025914    0.674542    
#> 035: 0.431057    0.981640    3.476899    0.289307    0.067273    0.024667    0.658316    
#> 036: 0.431532    1.012109    3.466636    0.274842    0.063910    0.023434    0.688161    
#> 037: 0.399693    1.009769    3.471505    0.261099    0.060714    0.022262    0.696288    
#> 038: 0.461681    1.009607    3.468538    0.325689    0.063536    0.025099    0.674142    
#> 039: 0.442640    1.000771    3.472510    0.329089    0.069149    0.023844    0.643881    
#> 040: 0.440670    1.027824    3.464699    0.369234    0.086536    0.022652    0.668629    
#> 041: 0.422686    0.999029    3.460440    0.377211    0.082209    0.021519    0.679913    
#> 042: 0.422678    0.997563    3.464919    0.358350    0.078099    0.022044    0.651085    
#> 043: 0.391137    1.024216    3.451691    0.340433    0.089668    0.020942    0.662557    
#> 044: 0.366037    1.038436    3.452100    0.323411    0.089102    0.019895    0.660713    
#> 045: 0.352590    1.064434    3.434318    0.307241    0.097313    0.018900    0.659852    
#> 046: 0.391680    1.009158    3.450962    0.323557    0.092447    0.017955    0.659522    
#> 047: 0.379773    1.038029    3.451158    0.307379    0.087825    0.017057    0.651027    
#> 048: 0.386185    1.013495    3.446988    0.313137    0.083434    0.017404    0.663984    
#> 049: 0.394155    1.035797    3.459836    0.325764    0.079815    0.019561    0.656365    
#> 050: 0.493043    0.993036    3.486089    0.339194    0.086001    0.023858    0.661962    
#> 051: 0.477462    1.004903    3.474233    0.322234    0.082157    0.022665    0.670908    
#> 052: 0.489400    0.999035    3.489611    0.346476    0.078915    0.021532    0.651273    
#> 053: 0.457329    0.979019    3.477230    0.332851    0.074970    0.021601    0.663022    
#> 054: 0.403872    0.998580    3.480767    0.316208    0.071221    0.022472    0.685780    
#> 055: 0.401545    0.997782    3.465244    0.330095    0.073694    0.021349    0.686705    
#> 056: 0.418769    0.996952    3.464545    0.313590    0.084120    0.020281    0.665666    
#> 057: 0.429446    1.014457    3.466486    0.300021    0.084337    0.019267    0.697322    
#> 058: 0.421584    1.011774    3.460580    0.285020    0.087367    0.018304    0.684415    
#> 059: 0.407824    0.979147    3.468334    0.314475    0.082998    0.018273    0.692261    
#> 060: 0.395359    0.976533    3.469437    0.298752    0.078848    0.027083    0.684310    
#> 061: 0.478100    0.974303    3.496086    0.283814    0.074906    0.032395    0.702369    
#> 062: 0.475637    0.984641    3.489569    0.356357    0.071161    0.034046    0.713992    
#> 063: 0.512202    0.962114    3.496238    0.356445    0.067603    0.033609    0.698750    
#> 064: 0.487590    0.957432    3.500697    0.338623    0.064223    0.031928    0.672668    
#> 065: 0.505449    0.966886    3.490612    0.321692    0.061011    0.030332    0.677875    
#> 066: 0.523987    0.973842    3.497615    0.305607    0.064209    0.028815    0.669858    
#> 067: 0.496115    0.981462    3.495144    0.290327    0.081180    0.027375    0.657488    
#> 068: 0.440258    0.997534    3.486877    0.275811    0.077121    0.026006    0.672505    
#> 069: 0.421227    1.008120    3.461491    0.285199    0.073265    0.024706    0.672723    
#> 070: 0.447046    1.010163    3.477963    0.320959    0.069602    0.023470    0.683702    
#> 071: 0.408983    1.034685    3.448368    0.377246    0.076788    0.023222    0.672344    
#> 072: 0.409396    1.017099    3.453950    0.389941    0.072949    0.022061    0.664150    
#> 073: 0.451160    1.022057    3.474503    0.405056    0.069301    0.020958    0.660021    
#> 074: 0.472743    0.993112    3.474731    0.384803    0.068858    0.024029    0.658366    
#> 075: 0.481554    0.993111    3.507422    0.365563    0.076542    0.026913    0.667127    
#> 076: 0.499293    0.990970    3.508904    0.361181    0.072715    0.026480    0.672501    
#> 077: 0.496522    0.989916    3.493302    0.343122    0.073329    0.025156    0.664648    
#> 078: 0.451996    0.987446    3.489544    0.325966    0.069662    0.023898    0.664773    
#> 079: 0.452070    0.995989    3.481669    0.309667    0.066179    0.024107    0.681739    
#> 080: 0.486996    0.986986    3.494171    0.333191    0.062870    0.024909    0.690813    
#> 081: 0.490004    1.003813    3.490020    0.343358    0.060168    0.026979    0.664459    
#> 082: 0.444676    0.981665    3.484418    0.326190    0.064267    0.030919    0.656106    
#> 083: 0.454681    0.998285    3.488493    0.309881    0.061054    0.033688    0.672184    
#> 084: 0.423331    1.003830    3.474526    0.294387    0.064366    0.032004    0.644142    
#> 085: 0.447224    0.995440    3.488439    0.279667    0.061147    0.030403    0.657244    
#> 086: 0.425149    1.013168    3.482784    0.265684    0.059231    0.028883    0.644704    
#> 087: 0.425135    1.006696    3.471099    0.276483    0.065304    0.027439    0.654660    
#> 088: 0.351895    0.989677    3.469756    0.262659    0.062039    0.027477    0.669611    
#> 089: 0.409085    1.005838    3.464156    0.275491    0.058937    0.030435    0.662653    
#> 090: 0.381497    1.002862    3.466248    0.274098    0.066728    0.028914    0.672251    
#> 091: 0.413677    0.988043    3.459610    0.261853    0.063391    0.027468    0.667822    
#> 092: 0.389094    1.024434    3.454225    0.265723    0.064586    0.026094    0.658938    
#> 093: 0.388299    1.012209    3.466643    0.262951    0.072650    0.024790    0.678255    
#> 094: 0.418710    1.010162    3.460329    0.274256    0.069018    0.023550    0.674368    
#> 095: 0.436522    1.008621    3.468728    0.260543    0.066941    0.022373    0.668675    
#> 096: 0.395225    1.007313    3.476819    0.247516    0.064684    0.021254    0.669294    
#> 097: 0.444359    1.021543    3.468496    0.303230    0.072529    0.022228    0.647406    
#> 098: 0.437530    1.042518    3.470301    0.288069    0.074141    0.021117    0.665218    
#> 099: 0.404043    1.001330    3.461359    0.293193    0.070434    0.023032    0.659385    
#> 100: 0.399937    1.021184    3.463936    0.318333    0.066913    0.022864    0.662112    
#> 101: 0.388020    1.006141    3.454978    0.302416    0.063567    0.024635    0.661505    
#> 102: 0.413344    0.996880    3.462574    0.287295    0.073080    0.023403    0.656622    
#> 103: 0.439671    1.013248    3.470784    0.358715    0.069426    0.025198    0.646374    
#> 104: 0.423270    1.022266    3.472345    0.397948    0.065955    0.027039    0.667329    
#> 105: 0.450828    1.010374    3.467105    0.378051    0.069850    0.025687    0.679913    
#> 106: 0.441080    1.010275    3.454742    0.359148    0.079216    0.024403    0.676413    
#> 107: 0.438753    1.025982    3.469834    0.341191    0.090007    0.023183    0.654753    
#> 108: 0.433693    1.011791    3.474734    0.324131    0.086953    0.022023    0.667884    
#> 109: 0.450938    1.007577    3.482163    0.370288    0.091645    0.020922    0.662615    
#> 110: 0.426380    0.995800    3.457778    0.351773    0.087063    0.019876    0.657714    
#> 111: 0.400784    1.020505    3.452967    0.334185    0.082709    0.018882    0.644792    
#> 112: 0.408166    1.013351    3.448299    0.317475    0.078574    0.018996    0.669189    
#> 113: 0.384855    1.040107    3.450487    0.335181    0.078540    0.019064    0.670943    
#> 114: 0.410644    1.021951    3.459247    0.340067    0.087072    0.023625    0.650453    
#> 115: 0.422493    0.986940    3.460894    0.329375    0.082718    0.023157    0.661067    
#> 116: 0.438801    1.003887    3.463580    0.312906    0.081613    0.021999    0.674052    
#> 117: 0.427381    1.024903    3.477017    0.342644    0.077532    0.020899    0.671307    
#> 118: 0.442058    0.997691    3.469891    0.331881    0.076408    0.020982    0.665534    
#> 119: 0.431547    1.006321    3.472349    0.333944    0.072588    0.027135    0.657745    
#> 120: 0.430306    0.994025    3.478567    0.320129    0.068959    0.028560    0.651461    
#> 121: 0.452134    1.026240    3.485637    0.346609    0.065511    0.027132    0.656294    
#> 122: 0.441124    0.998162    3.487764    0.329279    0.062235    0.027813    0.664535    
#> 123: 0.461329    1.034271    3.472176    0.312815    0.064398    0.027936    0.663194    
#> 124: 0.430447    1.049056    3.467016    0.297174    0.065177    0.026540    0.677677    
#> 125: 0.435185    1.027070    3.464077    0.282315    0.061919    0.025213    0.669027    
#> 126: 0.409648    1.036358    3.445288    0.273071    0.075117    0.023952    0.678853    
#> 127: 0.438103    1.025545    3.453279    0.301427    0.077229    0.024009    0.685892    
#> 128: 0.441017    1.004795    3.490602    0.286356    0.076747    0.023115    0.684435    
#> 129: 0.453191    0.997553    3.490472    0.272038    0.080044    0.025339    0.696838    
#> 130: 0.483972    1.001254    3.487041    0.258436    0.076042    0.032949    0.669018    
#> 131: 0.455440    0.976239    3.480539    0.274048    0.072240    0.031302    0.672624    
#> 132: 0.424240    1.001080    3.460269    0.260346    0.068628    0.029737    0.680245    
#> 133: 0.441811    0.988104    3.463704    0.366039    0.065197    0.028250    0.663917    
#> 134: 0.447224    0.968737    3.487654    0.372696    0.061937    0.029659    0.661926    
#> 135: 0.443222    0.970689    3.482852    0.354062    0.058840    0.031624    0.665420    
#> 136: 0.466672    0.979500    3.491045    0.380756    0.055898    0.030454    0.670145    
#> 137: 0.481249    0.979818    3.492416    0.361718    0.053103    0.029793    0.689635    
#> 138: 0.477311    0.990475    3.485684    0.396887    0.051100    0.028304    0.659732    
#> 139: 0.460118    1.008445    3.485046    0.387359    0.048545    0.026999    0.648649    
#> 140: 0.468588    1.003501    3.483536    0.373358    0.050589    0.031961    0.651888    
#> 141: 0.464978    0.987369    3.486117    0.369290    0.051155    0.030363    0.655611    
#> 142: 0.466940    0.967435    3.491404    0.350825    0.057849    0.029685    0.657802    
#> 143: 0.431611    1.002327    3.481277    0.333284    0.071005    0.029490    0.672126    
#> 144: 0.490095    0.990318    3.500632    0.316620    0.067454    0.028016    0.646573    
#> 145: 0.443480    1.003627    3.469103    0.300789    0.077388    0.026615    0.648763    
#> 146: 0.419688    1.017807    3.482332    0.285749    0.073519    0.025932    0.661756    
#> 147: 0.398947    1.009585    3.455570    0.271462    0.069843    0.024636    0.676075    
#> 148: 0.390274    1.022546    3.465045    0.258024    0.082980    0.023995    0.665600    
#> 149: 0.405521    1.016247    3.458611    0.360305    0.078831    0.025870    0.662251    
#> 150: 0.466535    1.004121    3.451470    0.360270    0.080752    0.024577    0.686413    
#> 151: 0.383686    1.034484    3.452587    0.342256    0.081150    0.023348    0.663230    
#> 152: 0.387214    1.028560    3.459009    0.296415    0.088365    0.022956    0.654242    
#> 153: 0.410801    1.030050    3.474573    0.290512    0.091972    0.027275    0.664809    
#> 154: 0.440074    1.020078    3.473766    0.302088    0.068831    0.027460    0.672136    
#> 155: 0.442743    0.990964    3.470610    0.256047    0.072235    0.023980    0.668795    
#> 156: 0.430726    1.004059    3.460028    0.291019    0.079553    0.024208    0.678291    
#> 157: 0.428045    1.006726    3.466963    0.345596    0.070698    0.026774    0.685369    
#> 158: 0.467279    1.020250    3.471794    0.305269    0.071318    0.030418    0.663154    
#> 159: 0.426791    1.014013    3.484349    0.281201    0.067419    0.030262    0.651703    
#> 160: 0.475450    0.986266    3.489885    0.274071    0.064234    0.030089    0.657809    
#> 161: 0.466122    0.994725    3.486337    0.285904    0.058064    0.032712    0.656785    
#> 162: 0.448337    1.000565    3.476742    0.317282    0.063969    0.030385    0.652743    
#> 163: 0.481487    0.987709    3.481193    0.376584    0.054552    0.029012    0.662769    
#> 164: 0.477593    0.990730    3.481658    0.415082    0.053935    0.031952    0.671681    
#> 165: 0.517643    0.967030    3.482764    0.372157    0.055786    0.029416    0.673895    
#> 166: 0.512377    1.002934    3.476006    0.480674    0.055975    0.027667    0.682934    
#> 167: 0.474691    1.013093    3.483697    0.382256    0.066012    0.028741    0.695795    
#> 168: 0.474832    1.001968    3.494486    0.375216    0.057227    0.032457    0.670545    
#> 169: 0.500904    1.021958    3.484078    0.398448    0.063685    0.025500    0.668468    
#> 170: 0.475233    1.004658    3.480477    0.422762    0.062271    0.023712    0.650852    
#> 171: 0.441491    1.004558    3.470747    0.395376    0.070370    0.022084    0.632510    
#> 172: 0.375520    1.036287    3.455894    0.324317    0.064909    0.019758    0.649874    
#> 173: 0.392764    1.053053    3.433019    0.350512    0.068778    0.019514    0.659911    
#> 174: 0.420225    1.042113    3.443281    0.397001    0.076305    0.019906    0.652868    
#> 175: 0.392236    1.025507    3.442750    0.350230    0.082860    0.023090    0.651737    
#> 176: 0.445923    1.024036    3.477440    0.348441    0.069051    0.024979    0.633151    
#> 177: 0.477632    1.005985    3.481096    0.354911    0.064222    0.028295    0.641944    
#> 178: 0.445292    0.986526    3.478153    0.317769    0.063511    0.021197    0.661542    
#> 179: 0.492412    1.021099    3.473572    0.426960    0.049280    0.017466    0.684249    
#> 180: 0.479605    0.999997    3.473576    0.446551    0.062154    0.019608    0.665818    
#> 181: 0.436750    0.995287    3.461950    0.366073    0.061103    0.019389    0.671044    
#> 182: 0.432875    0.997681    3.460401    0.367919    0.073877    0.014946    0.696401    
#> 183: 0.445549    1.021868    3.462674    0.315204    0.086794    0.012600    0.684745    
#> 184: 0.430505    1.002095    3.465016    0.351413    0.080392    0.014575    0.688236    
#> 185: 0.411901    1.020497    3.462514    0.311892    0.084951    0.012095    0.681555    
#> 186: 0.390756    1.049782    3.463013    0.317060    0.085984    0.012289    0.676458    
#> 187: 0.424873    1.017347    3.476497    0.352698    0.077063    0.014710    0.665673    
#> 188: 0.398788    1.030996    3.460872    0.336273    0.079507    0.013666    0.673257    
#> 189: 0.397369    1.030525    3.469046    0.327293    0.084691    0.013904    0.664920    
#> 190: 0.413607    1.021839    3.462016    0.381198    0.074963    0.015239    0.650143    
#> 191: 0.406366    1.034944    3.450045    0.306772    0.073560    0.016533    0.642215    
#> 192: 0.398296    1.035007    3.456027    0.296702    0.086272    0.017989    0.649316    
#> 193: 0.425529    1.035247    3.464206    0.301735    0.084582    0.019930    0.655958    
#> 194: 0.410492    1.026691    3.451180    0.373905    0.062782    0.018314    0.676916    
#> 195: 0.370233    1.026609    3.443659    0.355111    0.065557    0.020174    0.682038    
#> 196: 0.390328    1.027973    3.462616    0.353182    0.070720    0.019774    0.678591    
#> 197: 0.394726    1.027098    3.476607    0.324624    0.063213    0.023452    0.668757    
#> 198: 0.427246    1.020019    3.461649    0.269712    0.061175    0.023519    0.657681    
#> 199: 0.426405    0.990996    3.473906    0.281810    0.060089    0.023359    0.673366    
#> 200: 0.442247    0.989607    3.472277    0.336189    0.070916    0.020598    0.691667    
#> 201: 0.450948    0.985751    3.479190    0.339923    0.066370    0.022453    0.679790    
#> 202: 0.452310    0.993866    3.478672    0.333699    0.067119    0.023752    0.681614    
#> 203: 0.459057    0.992922    3.481295    0.313717    0.068160    0.024840    0.678320    
#> 204: 0.459155    0.986256    3.486008    0.306141    0.069026    0.025231    0.677470    
#> 205: 0.454145    0.987959    3.487011    0.303629    0.068708    0.026025    0.678696    
#> 206: 0.457394    0.992420    3.488130    0.308018    0.067584    0.025934    0.677541    
#> 207: 0.456760    0.994099    3.486440    0.306772    0.068614    0.025631    0.675784    
#> 208: 0.450543    0.996610    3.484717    0.305405    0.068973    0.026123    0.675278    
#> 209: 0.450103    0.995578    3.482834    0.304648    0.069944    0.026393    0.676406    
#> 210: 0.449280    0.993964    3.482332    0.305997    0.070027    0.026425    0.675381    
#> 211: 0.447343    0.995664    3.481766    0.302909    0.068677    0.026280    0.675647    
#> 212: 0.447156    0.996836    3.481425    0.300372    0.068594    0.026409    0.674527    
#> 213: 0.445215    0.995065    3.481457    0.296979    0.069379    0.026148    0.674541    
#> 214: 0.446134    0.993994    3.481541    0.295354    0.070051    0.025892    0.675727    
#> 215: 0.444626    0.993620    3.481659    0.294641    0.069761    0.025999    0.676489    
#> 216: 0.443820    0.992892    3.480978    0.294663    0.069256    0.025958    0.677481    
#> 217: 0.443199    0.994039    3.480888    0.293642    0.068811    0.026219    0.676844    
#> 218: 0.443596    0.995172    3.480290    0.295596    0.068460    0.026309    0.675677    
#> 219: 0.443937    0.995206    3.479858    0.299960    0.067846    0.026639    0.674180    
#> 220: 0.443179    0.995603    3.479302    0.302352    0.067906    0.026662    0.673033    
#> 221: 0.443412    0.995644    3.478785    0.305054    0.067877    0.026739    0.672119    
#> 222: 0.444357    0.995737    3.478303    0.309268    0.067383    0.026726    0.671561    
#> 223: 0.446283    0.995013    3.478418    0.310781    0.067272    0.026816    0.671039    
#> 224: 0.447832    0.995682    3.478391    0.312546    0.067626    0.026891    0.670515    
#> 225: 0.447310    0.994730    3.478674    0.314135    0.067907    0.027006    0.670025    
#> 226: 0.446577    0.993676    3.478178    0.313249    0.067831    0.027052    0.669944    
#> 227: 0.444910    0.994173    3.477820    0.314111    0.067632    0.027049    0.670222    
#> 228: 0.443738    0.995121    3.477141    0.314849    0.067430    0.026989    0.669755    
#> 229: 0.442236    0.995560    3.476289    0.314979    0.067022    0.026835    0.669053    
#> 230: 0.441823    0.995689    3.475761    0.315173    0.066770    0.026750    0.668823    
#> 231: 0.441571    0.995950    3.476032    0.314969    0.066722    0.026600    0.668837    
#> 232: 0.441517    0.996050    3.476369    0.313051    0.066952    0.026545    0.668409    
#> 233: 0.442134    0.995547    3.476686    0.311239    0.067244    0.026703    0.668188    
#> 234: 0.441245    0.995866    3.476461    0.311365    0.067100    0.026740    0.668143    
#> 235: 0.440731    0.995846    3.476201    0.312161    0.067596    0.026661    0.667911    
#> 236: 0.440836    0.995695    3.476018    0.310673    0.067570    0.026741    0.668077    
#> 237: 0.441724    0.995448    3.476219    0.310076    0.067453    0.026928    0.668482    
#> 238: 0.443045    0.995314    3.476290    0.310741    0.067167    0.027093    0.668969    
#> 239: 0.443186    0.995856    3.476312    0.310922    0.067034    0.027117    0.668903    
#> 240: 0.443732    0.995781    3.476677    0.310677    0.066767    0.027020    0.668814    
#> 241: 0.444027    0.995291    3.476831    0.310148    0.066654    0.026978    0.668708    
#> 242: 0.443836    0.995142    3.476796    0.308773    0.067028    0.026921    0.668946    
#> 243: 0.443599    0.995186    3.476966    0.307923    0.067160    0.026831    0.669000    
#> 244: 0.443718    0.995085    3.477155    0.308504    0.067338    0.026826    0.668876    
#> 245: 0.443318    0.994921    3.476930    0.308371    0.067463    0.026890    0.668872    
#> 246: 0.443062    0.995119    3.476537    0.309232    0.067710    0.026889    0.668690    
#> 247: 0.442509    0.995374    3.476672    0.308815    0.067986    0.026840    0.668396    
#> 248: 0.442415    0.995934    3.476476    0.308692    0.068096    0.026813    0.668024    
#> 249: 0.442454    0.996064    3.476668    0.308655    0.068490    0.026779    0.667927    
#> 250: 0.443376    0.996360    3.476871    0.309431    0.068694    0.026650    0.668084    
#> 251: 0.443722    0.996722    3.477130    0.310431    0.068925    0.026521    0.668256    
#> 252: 0.444615    0.996705    3.477552    0.310138    0.068922    0.026531    0.668220    
#> 253: 0.444925    0.996909    3.477556    0.310195    0.068910    0.026500    0.668204    
#> 254: 0.444763    0.997419    3.477554    0.310521    0.068625    0.026539    0.667891    
#> 255: 0.444431    0.997789    3.477415    0.309712    0.068523    0.026557    0.667740    
#> 256: 0.444130    0.997906    3.477254    0.309709    0.068371    0.026616    0.667394    
#> 257: 0.443518    0.997837    3.477019    0.311032    0.068163    0.026662    0.667444    
#> 258: 0.442446    0.997791    3.476894    0.309863    0.068118    0.026625    0.667596    
#> 259: 0.441509    0.997924    3.476612    0.309566    0.068046    0.026578    0.667787    
#> 260: 0.441692    0.998151    3.476797    0.310541    0.068016    0.026579    0.667523    
#> 261: 0.442058    0.998032    3.476836    0.311555    0.068042    0.026641    0.667244    
#> 262: 0.442208    0.998138    3.476971    0.311517    0.068118    0.026666    0.667032    
#> 263: 0.441792    0.998367    3.476966    0.311660    0.068116    0.026706    0.667085    
#> 264: 0.441554    0.998452    3.476971    0.311652    0.068211    0.026681    0.667130    
#> 265: 0.441668    0.998493    3.477031    0.311509    0.068370    0.026694    0.667200    
#> 266: 0.441704    0.998678    3.477124    0.311241    0.068482    0.026778    0.667243    
#> 267: 0.441598    0.998580    3.477349    0.310357    0.068366    0.026804    0.667657    
#> 268: 0.441772    0.998190    3.477432    0.310418    0.068327    0.026752    0.667905    
#> 269: 0.442625    0.997851    3.477648    0.310760    0.068362    0.026747    0.668013    
#> 270: 0.442849    0.997813    3.477667    0.311047    0.068294    0.026680    0.667892    
#> 271: 0.442886    0.997677    3.477561    0.311725    0.068321    0.026564    0.668053    
#> 272: 0.443101    0.997441    3.477576    0.312733    0.068162    0.026516    0.668458    
#> 273: 0.442752    0.997713    3.477434    0.313056    0.068166    0.026472    0.668707    
#> 274: 0.442634    0.998016    3.477453    0.313353    0.068180    0.026497    0.668816    
#> 275: 0.442329    0.998026    3.477274    0.312882    0.068095    0.026511    0.669002    
#> 276: 0.441848    0.998331    3.477218    0.312445    0.067958    0.026549    0.669144    
#> 277: 0.441357    0.998612    3.477142    0.312686    0.067988    0.026549    0.669281    
#> 278: 0.441020    0.998527    3.477087    0.312517    0.067968    0.026542    0.669170    
#> 279: 0.440617    0.998413    3.477042    0.312543    0.067963    0.026575    0.669191    
#> 280: 0.440343    0.998572    3.476898    0.312086    0.068001    0.026597    0.669164    
#> 281: 0.440079    0.998671    3.476950    0.311649    0.067961    0.026594    0.669061    
#> 282: 0.440133    0.998948    3.477029    0.311124    0.067941    0.026544    0.669079    
#> 283: 0.439940    0.999253    3.476836    0.310571    0.067920    0.026518    0.669250    
#> 284: 0.439862    0.999401    3.476659    0.310231    0.068035    0.026476    0.669238    
#> 285: 0.439578    0.999609    3.476401    0.310217    0.068169    0.026455    0.669211    
#> 286: 0.439190    0.999569    3.476226    0.309682    0.068197    0.026445    0.669507    
#> 287: 0.438667    0.999989    3.476018    0.309783    0.068301    0.026398    0.669674    
#> 288: 0.438448    1.000130    3.475847    0.310384    0.068374    0.026313    0.669917    
#> 289: 0.438594    1.000381    3.475716    0.310567    0.068480    0.026246    0.670061    
#> 290: 0.438546    1.000358    3.475692    0.310303    0.068586    0.026224    0.670129    
#> 291: 0.438342    1.000470    3.475765    0.310174    0.068634    0.026199    0.669884    
#> 292: 0.438388    1.000552    3.475849    0.310308    0.068574    0.026198    0.669724    
#> 293: 0.438701    1.000506    3.475924    0.309927    0.068531    0.026169    0.669714    
#> 294: 0.438681    1.000568    3.475837    0.309461    0.068530    0.026141    0.669813    
#> 295: 0.438381    1.000270    3.475763    0.309541    0.068542    0.026071    0.669758    
#> 296: 0.438479    1.000077    3.475775    0.309977    0.068542    0.026017    0.669649    
#> 297: 0.438674    1.000013    3.475791    0.309910    0.068549    0.026040    0.669633    
#> 298: 0.439115    0.999912    3.475898    0.310241    0.068538    0.026054    0.669485    
#> 299: 0.439133    1.000033    3.475890    0.310393    0.068590    0.026010    0.669388    
#> 300: 0.439327    1.000101    3.475972    0.309940    0.068690    0.026018    0.669357    
#> 301: 0.439383    1.000003    3.475939    0.309829    0.068783    0.026025    0.669433    
#> 302: 0.439862    1.000052    3.475861    0.310035    0.068848    0.025971    0.669504    
#> 303: 0.439906    1.000171    3.475866    0.309618    0.069082    0.025910    0.669322    
#> 304: 0.440210    1.000257    3.475892    0.309509    0.069293    0.025888    0.669391    
#> 305: 0.440139    1.000201    3.475828    0.309417    0.069347    0.025859    0.669405    
#> 306: 0.439730    1.000302    3.475636    0.309272    0.069374    0.025833    0.669412    
#> 307: 0.439534    1.000491    3.475491    0.309091    0.069453    0.025801    0.669673    
#> 308: 0.439100    1.000581    3.475338    0.309208    0.069548    0.025809    0.669987    
#> 309: 0.439085    1.000383    3.475327    0.309246    0.069613    0.025787    0.670083    
#> 310: 0.439351    1.000205    3.475273    0.309839    0.069599    0.025743    0.670338    
#> 311: 0.439163    1.000181    3.475240    0.309934    0.069583    0.025680    0.670303    
#> 312: 0.438948    1.000103    3.475134    0.310094    0.069572    0.025642    0.670318    
#> 313: 0.438917    1.000009    3.475164    0.310112    0.069596    0.025644    0.670286    
#> 314: 0.438378    0.999990    3.475025    0.310163    0.069579    0.025634    0.670259    
#> 315: 0.438169    1.000019    3.474987    0.310307    0.069572    0.025581    0.670175    
#> 316: 0.438035    1.000081    3.474944    0.310287    0.069442    0.025548    0.670106    
#> 317: 0.438057    1.000155    3.474907    0.310262    0.069366    0.025531    0.670259    
#> 318: 0.438217    1.000229    3.474752    0.310832    0.069399    0.025484    0.670226    
#> 319: 0.438350    1.000249    3.474776    0.310949    0.069341    0.025474    0.670295    
#> 320: 0.437993    1.000211    3.474705    0.311104    0.069304    0.025460    0.670422    
#> 321: 0.437546    1.000309    3.474560    0.311055    0.069195    0.025452    0.670479    
#> 322: 0.437491    1.000434    3.474424    0.311372    0.069134    0.025447    0.670502    
#> 323: 0.437196    1.000601    3.474251    0.311556    0.069034    0.025427    0.670545    
#> 324: 0.437225    1.000732    3.474284    0.311454    0.069046    0.025435    0.670420    
#> 325: 0.437092    1.000898    3.474209    0.311252    0.069000    0.025399    0.670340    
#> 326: 0.436823    1.000963    3.474105    0.311292    0.069013    0.025350    0.670156    
#> 327: 0.437002    1.000978    3.474174    0.311209    0.068967    0.025306    0.670131    
#> 328: 0.437050    1.001051    3.474166    0.310927    0.068988    0.025274    0.669955    
#> 329: 0.437217    1.001019    3.474250    0.310848    0.069055    0.025260    0.669834    
#> 330: 0.437199    1.001033    3.474280    0.310476    0.069096    0.025219    0.669884    
#> 331: 0.436999    1.001182    3.474317    0.310006    0.069232    0.025160    0.669875    
#> 332: 0.436826    1.001301    3.474289    0.309513    0.069376    0.025092    0.669966    
#> 333: 0.436558    1.001394    3.474101    0.309215    0.069498    0.025021    0.670034    
#> 334: 0.436380    1.001320    3.473943    0.309093    0.069637    0.024963    0.670069    
#> 335: 0.436366    1.001389    3.473899    0.308546    0.069789    0.024916    0.670061    
#> 336: 0.436226    1.001560    3.473859    0.308069    0.069912    0.024890    0.670046    
#> 337: 0.436140    1.001923    3.473851    0.307771    0.069996    0.024887    0.670047    
#> 338: 0.436169    1.001911    3.473951    0.307645    0.070023    0.024901    0.670068    
#> 339: 0.436053    1.001903    3.473879    0.307748    0.070039    0.024901    0.669966    
#> 340: 0.436091    1.001665    3.473878    0.307834    0.070027    0.024907    0.669882    
#> 341: 0.436216    1.001730    3.473854    0.307952    0.070079    0.024902    0.669874    
#> 342: 0.436123    1.001566    3.473918    0.307733    0.070126    0.024869    0.669903    
#> 343: 0.435876    1.001560    3.473866    0.307633    0.070170    0.024872    0.669902    
#> 344: 0.435813    1.001536    3.473930    0.307562    0.070213    0.024890    0.669887    
#> 345: 0.435963    1.001488    3.473948    0.307410    0.070122    0.024911    0.669888    
#> 346: 0.435929    1.001533    3.473920    0.306995    0.070040    0.024908    0.669842    
#> 347: 0.436093    1.001458    3.473920    0.306871    0.069911    0.024930    0.669874    
#> 348: 0.436080    1.001572    3.473915    0.307105    0.069826    0.024956    0.669855    
#> 349: 0.436039    1.001510    3.473925    0.307018    0.069732    0.024975    0.669829    
#> 350: 0.436034    1.001308    3.473951    0.307220    0.069693    0.024995    0.669733    
#> 351: 0.436192    1.001458    3.473978    0.307117    0.069658    0.025028    0.669714    
#> 352: 0.435981    1.001618    3.473988    0.306998    0.069610    0.025087    0.669865    
#> 353: 0.435819    1.001793    3.473836    0.306891    0.069654    0.025114    0.669937    
#> 354: 0.435624    1.001798    3.473748    0.306606    0.069749    0.025151    0.669994    
#> 355: 0.435747    1.001647    3.473730    0.306680    0.069819    0.025215    0.669961    
#> 356: 0.435663    1.001509    3.473774    0.306379    0.069752    0.025220    0.670180    
#> 357: 0.435872    1.001520    3.473779    0.306598    0.069687    0.025190    0.670171    
#> 358: 0.435877    1.001611    3.473787    0.306973    0.069762    0.025171    0.670101    
#> 359: 0.435791    1.001605    3.473803    0.306855    0.069768    0.025166    0.670035    
#> 360: 0.435540    1.001566    3.473744    0.306373    0.069694    0.025157    0.670015    
#> 361: 0.435182    1.001636    3.473578    0.306110    0.069667    0.025127    0.670033    
#> 362: 0.435070    1.001688    3.473423    0.306170    0.069679    0.025104    0.669875    
#> 363: 0.434706    1.001747    3.473369    0.305751    0.069693    0.025083    0.669760    
#> 364: 0.434672    1.001789    3.473335    0.305522    0.069738    0.025062    0.669782    
#> 365: 0.434528    1.001842    3.473252    0.305441    0.069926    0.025053    0.669799    
#> 366: 0.434259    1.001952    3.473101    0.305630    0.070019    0.025013    0.669844    
#> 367: 0.434324    1.001936    3.473055    0.306016    0.070062    0.024981    0.669842    
#> 368: 0.434452    1.002059    3.472953    0.306243    0.069972    0.024959    0.669892    
#> 369: 0.434397    1.002047    3.472911    0.306248    0.069910    0.024947    0.669928    
#> 370: 0.434255    1.002137    3.472799    0.306299    0.069939    0.024961    0.669951    
#> 371: 0.434047    1.002217    3.472649    0.306338    0.069977    0.024970    0.669900    
#> 372: 0.433924    1.002355    3.472520    0.306551    0.070036    0.024955    0.669969    
#> 373: 0.433832    1.002496    3.472462    0.306837    0.070091    0.024941    0.670011    
#> 374: 0.433773    1.002530    3.472416    0.307460    0.070112    0.024906    0.669961    
#> 375: 0.433602    1.002610    3.472399    0.307792    0.070133    0.024881    0.669905    
#> 376: 0.433546    1.002764    3.472363    0.307605    0.070099    0.024883    0.669953    
#> 377: 0.433497    1.002854    3.472307    0.307492    0.070088    0.024885    0.669976    
#> 378: 0.433308    1.002816    3.472285    0.307437    0.070013    0.024887    0.669982    
#> 379: 0.433151    1.002734    3.472293    0.307333    0.069929    0.024901    0.669874    
#> 380: 0.433095    1.002626    3.472330    0.307143    0.069841    0.024920    0.669884    
#> 381: 0.432855    1.002606    3.472292    0.306977    0.069826    0.024931    0.669875    
#> 382: 0.432693    1.002583    3.472213    0.307144    0.069726    0.024931    0.669850    
#> 383: 0.432613    1.002676    3.472123    0.307026    0.069698    0.024912    0.669929    
#> 384: 0.432471    1.002649    3.472074    0.307027    0.069671    0.024924    0.669940    
#> 385: 0.432509    1.002685    3.472049    0.306996    0.069635    0.024922    0.669931    
#> 386: 0.432450    1.002779    3.472075    0.307035    0.069636    0.024912    0.669947    
#> 387: 0.432513    1.002858    3.472124    0.307099    0.069588    0.024918    0.669929    
#> 388: 0.432720    1.002829    3.472162    0.307159    0.069581    0.024911    0.670015    
#> 389: 0.432684    1.002636    3.472162    0.307268    0.069602    0.024897    0.670115    
#> 390: 0.432566    1.002730    3.472101    0.307253    0.069648    0.024886    0.670136    
#> 391: 0.432746    1.002771    3.472086    0.307380    0.069703    0.024864    0.670085    
#> 392: 0.432812    1.002734    3.472097    0.307587    0.069736    0.024840    0.670157    
#> 393: 0.432673    1.002651    3.472046    0.307393    0.069848    0.024810    0.670250    
#> 394: 0.432645    1.002652    3.472002    0.307620    0.069874    0.024793    0.670246    
#> 395: 0.432733    1.002701    3.471995    0.307493    0.069893    0.024782    0.670248    
#> 396: 0.432728    1.002801    3.472010    0.307433    0.069935    0.024780    0.670168    
#> 397: 0.432639    1.002861    3.472001    0.307472    0.069961    0.024776    0.670202    
#> 398: 0.432600    1.002811    3.472040    0.307443    0.069980    0.024754    0.670311    
#> 399: 0.432748    1.002766    3.472113    0.307525    0.069957    0.024741    0.670304    
#> 400: 0.432806    1.002835    3.472154    0.307255    0.070010    0.024722    0.670347    
#> 401: 0.432791    1.002862    3.472103    0.307200    0.070083    0.024689    0.670430    
#> 402: 0.432749    1.002983    3.472094    0.306899    0.070146    0.024644    0.670454    
#> 403: 0.432964    1.003015    3.472091    0.306896    0.070173    0.024586    0.670454    
#> 404: 0.432957    1.003017    3.472040    0.306972    0.070155    0.024547    0.670397    
#> 405: 0.432927    1.003054    3.472034    0.307030    0.070191    0.024525    0.670419    
#> 406: 0.432976    1.003122    3.472013    0.307012    0.070154    0.024532    0.670512    
#> 407: 0.432975    1.003140    3.472037    0.306865    0.070095    0.024556    0.670603    
#> 408: 0.432977    1.003297    3.472021    0.306866    0.070173    0.024555    0.670759    
#> 409: 0.432884    1.003306    3.471924    0.306706    0.070167    0.024570    0.670780    
#> 410: 0.432849    1.003336    3.471857    0.306804    0.070153    0.024582    0.670806    
#> 411: 0.432754    1.003220    3.471842    0.306945    0.070121    0.024579    0.670940    
#> 412: 0.432604    1.003326    3.471809    0.307130    0.070090    0.024572    0.670970    
#> 413: 0.432483    1.003363    3.471763    0.307473    0.070083    0.024559    0.671007    
#> 414: 0.432482    1.003320    3.471798    0.307573    0.070068    0.024560    0.670915    
#> 415: 0.432574    1.003229    3.471820    0.307781    0.070099    0.024553    0.670808    
#> 416: 0.432848    1.003229    3.471876    0.308106    0.070097    0.024533    0.670749    
#> 417: 0.432987    1.003244    3.471906    0.308229    0.070080    0.024530    0.670700    
#> 418: 0.432879    1.003215    3.471940    0.308089    0.070007    0.024539    0.670641    
#> 419: 0.432936    1.003261    3.471932    0.308006    0.069940    0.024550    0.670732    
#> 420: 0.433060    1.003222    3.471986    0.307872    0.069909    0.024549    0.670663    
#> 421: 0.432968    1.003161    3.472057    0.307815    0.069836    0.024544    0.670694    
#> 422: 0.433124    1.003025    3.472141    0.307623    0.069772    0.024541    0.670681    
#> 423: 0.433401    1.002819    3.472247    0.307656    0.069725    0.024556    0.670708    
#> 424: 0.433382    1.002674    3.472248    0.307489    0.069657    0.024541    0.670777    
#> 425: 0.433502    1.002681    3.472254    0.307438    0.069642    0.024555    0.670838    
#> 426: 0.433540    1.002740    3.472280    0.307382    0.069690    0.024552    0.670753    
#> 427: 0.433500    1.002707    3.472335    0.307306    0.069699    0.024552    0.670718    
#> 428: 0.433284    1.002738    3.472308    0.307127    0.069679    0.024544    0.670710    
#> 429: 0.433317    1.002765    3.472324    0.307046    0.069704    0.024517    0.670740    
#> 430: 0.433425    1.002799    3.472321    0.307399    0.069699    0.024505    0.670718    
#> 431: 0.433371    1.002766    3.472274    0.307414    0.069657    0.024496    0.670640    
#> 432: 0.433216    1.002727    3.472264    0.307452    0.069601    0.024507    0.670618    
#> 433: 0.433147    1.002750    3.472286    0.307433    0.069610    0.024523    0.670569    
#> 434: 0.432971    1.002583    3.472285    0.307210    0.069583    0.024544    0.670588    
#> 435: 0.432881    1.002578    3.472284    0.307031    0.069516    0.024564    0.670555    
#> 436: 0.432767    1.002480    3.472343    0.306755    0.069462    0.024557    0.670586    
#> 437: 0.432780    1.002329    3.472412    0.306627    0.069405    0.024570    0.670579    
#> 438: 0.432739    1.002402    3.472424    0.306717    0.069390    0.024557    0.670515    
#> 439: 0.432759    1.002427    3.472452    0.306605    0.069361    0.024565    0.670446    
#> 440: 0.432678    1.002489    3.472504    0.306341    0.069333    0.024541    0.670487    
#> 441: 0.432706    1.002414    3.472560    0.306011    0.069292    0.024546    0.670449    
#> 442: 0.432676    1.002349    3.472634    0.305817    0.069238    0.024565    0.670394    
#> 443: 0.432633    1.002406    3.472601    0.305943    0.069250    0.024560    0.670401    
#> 444: 0.432427    1.002541    3.472476    0.305845    0.069244    0.024557    0.670392    
#> 445: 0.432293    1.002706    3.472414    0.305780    0.069282    0.024566    0.670381    
#> 446: 0.432147    1.002816    3.472334    0.305786    0.069316    0.024567    0.670312    
#> 447: 0.432172    1.002964    3.472268    0.305937    0.069409    0.024550    0.670310    
#> 448: 0.431969    1.003051    3.472178    0.306186    0.069434    0.024535    0.670254    
#> 449: 0.431946    1.003163    3.472176    0.306547    0.069483    0.024525    0.670256    
#> 450: 0.431998    1.003203    3.472149    0.306918    0.069526    0.024501    0.670210    
#> 451: 0.432076    1.003253    3.472128    0.307147    0.069565    0.024478    0.670189    
#> 452: 0.432081    1.003298    3.472124    0.307118    0.069555    0.024454    0.670150    
#> 453: 0.431996    1.003333    3.472096    0.307026    0.069515    0.024431    0.670078    
#> 454: 0.431833    1.003443    3.472016    0.306984    0.069500    0.024413    0.670012    
#> 455: 0.431732    1.003488    3.471963    0.306731    0.069555    0.024397    0.669956    
#> 456: 0.431547    1.003475    3.471937    0.306390    0.069614    0.024379    0.669971    
#> 457: 0.431588    1.003462    3.471959    0.306327    0.069652    0.024371    0.669911    
#> 458: 0.431656    1.003549    3.471969    0.306433    0.069715    0.024358    0.669799    
#> 459: 0.431539    1.003725    3.471958    0.306522    0.069807    0.024341    0.669826    
#> 460: 0.431415    1.003775    3.471908    0.306539    0.069806    0.024340    0.669781    
#> 461: 0.431331    1.003867    3.471869    0.306598    0.069859    0.024334    0.669742    
#> 462: 0.431270    1.003967    3.471858    0.306777    0.069893    0.024320    0.669701    
#> 463: 0.431234    1.004098    3.471840    0.307052    0.069936    0.024293    0.669728    
#> 464: 0.431313    1.004170    3.471838    0.307156    0.069991    0.024279    0.669676    
#> 465: 0.431384    1.004057    3.471843    0.307261    0.070045    0.024256    0.669662    
#> 466: 0.431617    1.004039    3.471867    0.307570    0.070075    0.024237    0.669643    
#> 467: 0.431601    1.004021    3.471902    0.307655    0.070089    0.024226    0.669611    
#> 468: 0.431772    1.004059    3.471948    0.307690    0.070064    0.024211    0.669627    
#> 469: 0.431768    1.004155    3.471952    0.307609    0.070076    0.024201    0.669688    
#> 470: 0.431663    1.004170    3.471943    0.307545    0.070073    0.024178    0.669680    
#> 471: 0.431661    1.004107    3.471990    0.307330    0.070094    0.024159    0.669671    
#> 472: 0.431752    1.004094    3.472030    0.307160    0.070108    0.024140    0.669711    
#> 473: 0.431717    1.004148    3.472012    0.307253    0.070119    0.024125    0.669588    
#> 474: 0.431671    1.004196    3.472011    0.307356    0.070075    0.024129    0.669561    
#> 475: 0.431666    1.004314    3.471981    0.307226    0.070067    0.024129    0.669544    
#> 476: 0.431547    1.004365    3.471933    0.307037    0.070045    0.024132    0.669552    
#> 477: 0.431413    1.004440    3.471888    0.306907    0.070108    0.024131    0.669501    
#> 478: 0.431393    1.004446    3.471904    0.306873    0.070210    0.024126    0.669476    
#> 479: 0.431482    1.004472    3.471927    0.306910    0.070286    0.024136    0.669479    
#> 480: 0.431521    1.004477    3.471929    0.306857    0.070289    0.024166    0.669492    
#> 481: 0.431597    1.004489    3.471912    0.306872    0.070256    0.024185    0.669467    
#> 482: 0.431625    1.004495    3.471875    0.306821    0.070219    0.024198    0.669551    
#> 483: 0.431493    1.004514    3.471833    0.306764    0.070215    0.024204    0.669509    
#> 484: 0.431413    1.004427    3.471828    0.306709    0.070196    0.024211    0.669510    
#> 485: 0.431455    1.004439    3.471835    0.306612    0.070174    0.024234    0.669491    
#> 486: 0.431514    1.004515    3.471868    0.306703    0.070152    0.024240    0.669470    
#> 487: 0.431622    1.004612    3.471887    0.306666    0.070149    0.024242    0.669444    
#> 488: 0.431631    1.004594    3.471897    0.306606    0.070169    0.024251    0.669381    
#> 489: 0.431740    1.004590    3.471874    0.306555    0.070191    0.024271    0.669369    
#> 490: 0.431905    1.004614    3.471913    0.306680    0.070258    0.024272    0.669311    
#> 491: 0.431929    1.004713    3.471913    0.306700    0.070287    0.024262    0.669277    
#> 492: 0.431987    1.004804    3.471913    0.306773    0.070289    0.024259    0.669312    
#> 493: 0.431905    1.004884    3.471873    0.306821    0.070295    0.024244    0.669293    
#> 494: 0.431954    1.004948    3.471848    0.306751    0.070292    0.024230    0.669347    
#> 495: 0.431981    1.004986    3.471803    0.306708    0.070322    0.024214    0.669321    
#> 496: 0.432062    1.005034    3.471762    0.306775    0.070317    0.024206    0.669361    
#> 497: 0.432020    1.005029    3.471718    0.307057    0.070312    0.024196    0.669478    
#> 498: 0.432063    1.004992    3.471704    0.307349    0.070345    0.024192    0.669494    
#> 499: 0.432215    1.004978    3.471709    0.307454    0.070332    0.024193    0.669522    
#> 500: 0.432326    1.004939    3.471742    0.307568    0.070359    0.024179    0.669477    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.369997    0.974987    3.444553    0.392401    0.081808    0.016800    1.869884    
#> 002: 0.690578    1.041252    3.462081    0.372781    0.077717    0.016241    1.295325    
#> 003: 0.940630    1.027051    3.480967    0.354142    0.073831    0.015429    0.919432    
#> 004: 0.966005    1.042164    3.477884    0.466269    0.070140    0.014657    0.821963    
#> 005: 1.141785    1.036584    3.476077    0.671288    0.066633    0.013925    0.758760    
#> 006: 1.149132    1.047387    3.473047    0.637723    0.063301    0.013228    0.706148    
#> 007: 1.092403    1.052030    3.473414    0.665507    0.060136    0.014137    0.709614    
#> 008: 1.072091    1.042345    3.459385    0.636284    0.057129    0.013430    0.716799    
#> 009: 1.066140    1.047930    3.455849    0.735140    0.054273    0.013090    0.712014    
#> 010: 1.021744    1.035022    3.458610    0.698383    0.051559    0.012468    0.721481    
#> 011: 1.129903    1.022589    3.476302    0.764022    0.068363    0.012585    0.690825    
#> 012: 1.125894    1.023211    3.472907    0.792201    0.064945    0.012907    0.685959    
#> 013: 1.178245    1.013709    3.476262    0.922109    0.061698    0.013633    0.695610    
#> 014: 1.193596    1.003419    3.479193    0.891022    0.058613    0.012952    0.716869    
#> 015: 1.245780    1.033438    3.487272    1.042272    0.055682    0.012304    0.697873    
#> 016: 1.236913    1.040016    3.489961    0.990159    0.053715    0.011689    0.699773    
#> 017: 1.218975    1.045730    3.488238    0.940651    0.051767    0.012534    0.679847    
#> 018: 1.221299    1.026505    3.475200    0.938534    0.056753    0.013027    0.681909    
#> 019: 1.132887    1.021666    3.477889    0.891608    0.053916    0.013682    0.670207    
#> 020: 1.179262    1.021472    3.482458    0.847027    0.055761    0.014954    0.674974    
#> 021: 1.205721    1.008006    3.491946    0.829186    0.052973    0.015862    0.669057    
#> 022: 1.159700    1.002356    3.498705    0.787726    0.050324    0.015069    0.673968    
#> 023: 1.234331    1.023002    3.499040    0.845251    0.047808    0.017756    0.688701    
#> 024: 1.244852    1.052104    3.486928    0.867742    0.045417    0.016868    0.665322    
#> 025: 1.191559    1.028363    3.479218    0.958149    0.043146    0.016025    0.687886    
#> 026: 1.175564    1.052252    3.473083    0.910242    0.048190    0.015223    0.680791    
#> 027: 1.183144    1.070476    3.472219    0.864730    0.049309    0.014462    0.687840    
#> 028: 1.225365    1.041514    3.479070    0.977273    0.046844    0.015155    0.676635    
#> 029: 1.135028    1.034870    3.476212    0.928410    0.053111    0.015697    0.683293    
#> 030: 1.193084    1.034419    3.470751    0.941316    0.050455    0.017042    0.682785    
#> 031: 1.225507    1.014848    3.478930    1.129470    0.047932    0.016432    0.669359    
#> 032: 1.148362    1.030790    3.479526    1.072997    0.046729    0.017196    0.673571    
#> 033: 1.061283    1.049730    3.470381    1.019347    0.044649    0.016337    0.677589    
#> 034: 1.100304    1.048193    3.472358    0.968380    0.042416    0.016210    0.686706    
#> 035: 1.035324    1.021005    3.463095    0.919961    0.045044    0.015400    0.686470    
#> 036: 1.101664    1.050872    3.464506    0.873963    0.049529    0.014630    0.695830    
#> 037: 1.107739    1.056827    3.472939    0.830264    0.048432    0.013898    0.709828    
#> 038: 1.169597    1.050228    3.465889    0.851214    0.053233    0.013203    0.700932    
#> 039: 1.150137    1.052192    3.471795    0.808654    0.053295    0.012543    0.694222    
#> 040: 1.146836    1.055905    3.479448    0.768221    0.050630    0.011916    0.699630    
#> 041: 1.145634    1.035695    3.474752    0.901059    0.048099    0.011320    0.672219    
#> 042: 1.166679    1.031346    3.469973    0.957686    0.045694    0.010776    0.677978    
#> 043: 1.141748    1.044950    3.467942    0.909801    0.043409    0.010502    0.671043    
#> 044: 1.211777    1.060112    3.470703    1.038187    0.047154    0.010914    0.675216    
#> 045: 1.175960    1.064983    3.469818    0.986277    0.052879    0.010580    0.666923    
#> 046: 1.174287    1.051210    3.474555    0.936963    0.050235    0.010051    0.673064    
#> 047: 1.215999    1.063565    3.463235    1.021108    0.047724    0.009549    0.685673    
#> 048: 1.145448    1.051711    3.458463    0.970052    0.052711    0.009071    0.692576    
#> 049: 1.198894    1.029151    3.479443    1.108871    0.060931    0.010136    0.704261    
#> 050: 1.271781    0.994265    3.492609    1.053427    0.059067    0.012337    0.715893    
#> 051: 1.242599    1.023647    3.482694    1.058024    0.056114    0.011720    0.722766    
#> 052: 1.187855    1.037166    3.483517    1.005123    0.053817    0.011134    0.704700    
#> 053: 1.201593    1.019820    3.489689    0.954867    0.051126    0.010577    0.692732    
#> 054: 1.162837    1.015994    3.491820    0.907123    0.058353    0.011793    0.709461    
#> 055: 1.201414    1.023462    3.486958    0.917250    0.064602    0.011204    0.709060    
#> 056: 1.157709    1.016014    3.481082    0.871388    0.061372    0.010644    0.734635    
#> 057: 1.213378    1.036327    3.485603    0.911902    0.058303    0.010111    0.732374    
#> 058: 1.179023    1.028668    3.475967    0.866307    0.055388    0.009606    0.722517    
#> 059: 1.149453    0.989885    3.486124    0.822992    0.060637    0.009126    0.749816    
#> 060: 1.112441    1.008507    3.491940    0.781842    0.057605    0.013736    0.733265    
#> 061: 1.165093    1.003696    3.498699    0.742750    0.054725    0.013366    0.730432    
#> 062: 1.115236    1.029481    3.484258    0.705613    0.063590    0.012697    0.724514    
#> 063: 1.141840    0.998514    3.485641    0.680607    0.060410    0.012697    0.703311    
#> 064: 1.127969    1.028080    3.483144    0.723295    0.057390    0.012063    0.706142    
#> 065: 1.175322    1.027912    3.474142    0.823222    0.054520    0.011459    0.691437    
#> 066: 1.168305    1.038479    3.479445    0.782061    0.060186    0.011703    0.691537    
#> 067: 1.126184    1.026100    3.475995    0.742958    0.057177    0.012659    0.678153    
#> 068: 1.091526    1.032415    3.479893    0.705810    0.054318    0.012026    0.696502    
#> 069: 1.133072    1.037686    3.480931    0.670519    0.052876    0.011425    0.699247    
#> 070: 1.113818    1.021877    3.487660    0.636993    0.054204    0.010853    0.696616    
#> 071: 1.084788    1.063843    3.463119    0.659441    0.063645    0.010311    0.696564    
#> 072: 1.069421    1.042462    3.460327    0.626469    0.060463    0.009795    0.681227    
#> 073: 1.120342    1.061193    3.480631    0.777546    0.057440    0.009305    0.693456    
#> 074: 1.155240    1.039530    3.475733    0.772545    0.057259    0.009195    0.685053    
#> 075: 1.155581    1.031955    3.494642    0.890659    0.060540    0.009327    0.699664    
#> 076: 1.224752    1.043044    3.500064    0.858921    0.058551    0.008861    0.698796    
#> 077: 1.228996    1.028805    3.491139    0.901179    0.060498    0.008657    0.680641    
#> 078: 1.223812    1.016679    3.485899    0.856120    0.061365    0.008225    0.681961    
#> 079: 1.228760    1.050412    3.481392    0.957662    0.058297    0.007813    0.703923    
#> 080: 1.210611    1.030222    3.471327    0.909779    0.066351    0.007423    0.723543    
#> 081: 1.166424    1.048796    3.472342    0.898443    0.065517    0.007348    0.697004    
#> 082: 1.165530    1.040759    3.479481    0.854295    0.062241    0.009245    0.695975    
#> 083: 1.163393    1.052345    3.479250    0.964234    0.059129    0.008782    0.695158    
#> 084: 1.169712    1.041840    3.482608    0.916022    0.062028    0.008809    0.702819    
#> 085: 1.107910    1.041864    3.487995    0.870221    0.058926    0.009037    0.703253    
#> 086: 1.190455    1.041715    3.490381    0.826710    0.059550    0.012622    0.686669    
#> 087: 1.222114    1.044933    3.477807    1.052628    0.056573    0.011991    0.677806    
#> 088: 1.136129    1.028293    3.479151    0.999997    0.053744    0.011821    0.687188    
#> 089: 1.141630    1.037373    3.471489    0.949997    0.053091    0.015878    0.675069    
#> 090: 1.094509    1.037719    3.466896    0.902497    0.054212    0.015084    0.674401    
#> 091: 1.093307    1.028688    3.459833    0.857372    0.051501    0.014329    0.682292    
#> 092: 1.135809    1.058214    3.465177    0.814504    0.048926    0.016564    0.694159    
#> 093: 1.110037    1.039435    3.470045    0.773778    0.047102    0.015736    0.705943    
#> 094: 1.130260    1.043217    3.454816    0.769752    0.048017    0.014949    0.707079    
#> 095: 1.044614    1.060168    3.467685    0.731264    0.056216    0.014201    0.702262    
#> 096: 1.082024    1.059416    3.464394    0.694701    0.053405    0.013491    0.698940    
#> 097: 1.136160    1.062536    3.464062    0.760442    0.050735    0.013305    0.695444    
#> 098: 1.082309    1.071124    3.470722    0.722419    0.048198    0.012640    0.711000    
#> 099: 1.074135    1.047286    3.471946    0.686298    0.050273    0.013979    0.703436    
#> 100: 1.055315    1.049322    3.468492    0.651984    0.047760    0.013280    0.678387    
#> 101: 1.042689    1.050011    3.450542    0.619384    0.053493    0.012616    0.675193    
#> 102: 1.061174    1.035167    3.453333    0.662727    0.056718    0.013593    0.677243    
#> 103: 1.110713    1.052642    3.472655    0.673699    0.053882    0.012914    0.674402    
#> 104: 1.107358    1.063271    3.474530    0.645357    0.051188    0.012268    0.693441    
#> 105: 1.061985    1.047198    3.472883    0.613089    0.055220    0.011655    0.692061    
#> 106: 1.125922    1.042586    3.466490    0.669055    0.056371    0.011072    0.691466    
#> 107: 1.132526    1.044071    3.472972    0.707680    0.053740    0.010518    0.701020    
#> 108: 1.099527    1.041266    3.474156    0.697549    0.055310    0.011021    0.705023    
#> 109: 1.003339    1.050803    3.472324    0.662672    0.052623    0.010541    0.691642    
#> 110: 1.084445    1.049050    3.463702    0.635418    0.049992    0.010014    0.689299    
#> 111: 1.083717    1.059050    3.461544    0.612353    0.051211    0.009513    0.681033    
#> 112: 1.089184    1.035180    3.456823    0.710430    0.056182    0.009037    0.685950    
#> 113: 1.109713    1.063019    3.458362    0.734630    0.053373    0.009329    0.685229    
#> 114: 1.118064    1.052984    3.464287    0.697899    0.057011    0.009226    0.687175    
#> 115: 1.155356    1.034127    3.453744    0.873534    0.054496    0.009771    0.713243    
#> 116: 1.177882    1.045830    3.469070    0.829857    0.051771    0.010550    0.704746    
#> 117: 1.147476    1.070294    3.469272    0.815485    0.052455    0.010206    0.690981    
#> 118: 1.151674    1.068096    3.469817    0.774711    0.056616    0.009696    0.680259    
#> 119: 1.140685    1.045926    3.474589    0.891616    0.053916    0.010321    0.698440    
#> 120: 1.172428    1.035340    3.473595    0.959167    0.051220    0.009805    0.692051    
#> 121: 1.197326    1.057343    3.482599    0.911209    0.048659    0.010309    0.699787    
#> 122: 1.171719    1.045521    3.485685    0.865648    0.056385    0.011491    0.709879    
#> 123: 1.291241    1.043755    3.479905    1.033006    0.053566    0.013610    0.685777    
#> 124: 1.227677    1.064006    3.474443    1.023051    0.050888    0.013212    0.689884    
#> 125: 1.191724    1.056769    3.471780    0.971898    0.053304    0.014277    0.681560    
#> 126: 1.120650    1.074918    3.459586    0.923304    0.056012    0.013924    0.701754    
#> 127: 1.109870    1.069625    3.458910    0.877138    0.053212    0.013228    0.689530    
#> 128: 1.081065    1.031875    3.478761    0.833281    0.054071    0.012566    0.708622    
#> 129: 1.222534    1.047919    3.485404    0.907449    0.067471    0.011938    0.686697    
#> 130: 1.181212    1.048456    3.478375    0.862077    0.064097    0.012887    0.679879    
#> 131: 1.186796    1.053266    3.463717    0.932629    0.075298    0.014242    0.681351    
#> 132: 1.163903    1.044487    3.459471    0.918293    0.077404    0.013530    0.686477    
#> 133: 1.066032    1.043951    3.466134    0.872379    0.073534    0.012853    0.693627    
#> 134: 1.127227    1.050261    3.467792    0.858868    0.069857    0.012211    0.684872    
#> 135: 1.180098    1.028051    3.475907    0.833698    0.066364    0.011600    0.687869    
#> 136: 1.141703    1.029348    3.477464    0.792013    0.063046    0.012200    0.693389    
#> 137: 1.200422    1.013750    3.489858    0.865303    0.059894    0.015103    0.695999    
#> 138: 1.156873    1.034118    3.493199    0.822038    0.056899    0.014348    0.691835    
#> 139: 1.242471    1.048126    3.489894    0.986635    0.054054    0.013631    0.690448    
#> 140: 1.172996    1.048907    3.489715    0.937303    0.051351    0.012949    0.700697    
#> 141: 1.149809    1.011053    3.492821    0.890438    0.048784    0.012302    0.698100    
#> 142: 1.252474    1.005541    3.500466    0.912450    0.046344    0.011687    0.700162    
#> 143: 1.152762    1.022220    3.492496    0.866828    0.046324    0.012065    0.707080    
#> 144: 1.194825    1.036947    3.500589    0.823486    0.044810    0.011462    0.709729    
#> 145: 1.150828    1.039096    3.474446    0.800192    0.052273    0.010889    0.690973    
#> 146: 1.176400    1.045240    3.493190    0.846594    0.049660    0.015395    0.707088    
#> 147: 1.191727    1.037515    3.476204    0.838321    0.047177    0.014625    0.683605    
#> 148: 1.144774    1.048057    3.486889    0.796405    0.046223    0.013894    0.692436    
#> 149: 1.156785    1.041083    3.477041    0.793561    0.045345    0.015072    0.700718    
#> 150: 1.184016    1.030379    3.471523    0.830908    0.047769    0.014318    0.704614    
#> 151: 1.245456    1.074415    3.475053    1.129064    0.051667    0.013603    0.670393    
#> 152: 1.229963    1.050443    3.485317    1.091836    0.049374    0.011984    0.677016    
#> 153: 1.208368    1.057142    3.488700    1.006968    0.056910    0.012117    0.679837    
#> 154: 1.224281    1.040334    3.488369    0.889404    0.052407    0.013141    0.681956    
#> 155: 1.168991    1.029113    3.479123    0.879044    0.045192    0.013382    0.676301    
#> 156: 1.193110    1.029505    3.489359    0.864050    0.046869    0.014712    0.680052    
#> 157: 1.170474    1.029799    3.499062    0.717434    0.045061    0.016243    0.701875    
#> 158: 1.207458    1.047662    3.488902    0.730551    0.048915    0.014276    0.690471    
#> 159: 1.094209    1.035667    3.497674    0.510201    0.048352    0.013816    0.700226    
#> 160: 1.164334    1.014431    3.496493    0.538790    0.057454    0.011071    0.713543    
#> 161: 1.131939    1.017664    3.498488    0.622625    0.053575    0.015596    0.698262    
#> 162: 1.148270    1.037585    3.489149    0.678462    0.051853    0.015871    0.697289    
#> 163: 1.159524    1.013884    3.488752    0.617394    0.045435    0.015085    0.691528    
#> 164: 1.116393    1.034629    3.485195    0.534207    0.051678    0.014320    0.698081    
#> 165: 1.123424    1.017609    3.483998    0.643059    0.045779    0.014859    0.684000    
#> 166: 1.137653    1.057038    3.485059    0.625639    0.041437    0.012320    0.703060    
#> 167: 1.136741    1.064842    3.489552    0.612060    0.042722    0.016080    0.715528    
#> 168: 1.175842    1.075222    3.475413    0.766974    0.041932    0.015319    0.706027    
#> 169: 1.107594    1.097996    3.465936    0.624393    0.040063    0.014871    0.706436    
#> 170: 1.053779    1.055338    3.465245    0.542636    0.041178    0.014862    0.692383    
#> 171: 1.066569    1.047432    3.468479    0.611191    0.041060    0.011475    0.683475    
#> 172: 1.098821    1.066876    3.466145    0.713658    0.035768    0.012263    0.676947    
#> 173: 1.124960    1.070714    3.462782    0.720628    0.044685    0.012038    0.701875    
#> 174: 1.110209    1.085716    3.462777    0.712223    0.039346    0.011179    0.688581    
#> 175: 1.138098    1.084327    3.456823    0.870210    0.055216    0.013669    0.691508    
#> 176: 1.076351    1.084095    3.464752    0.718325    0.048314    0.013078    0.677472    
#> 177: 1.053993    1.069669    3.465244    0.695002    0.048713    0.012737    0.693840    
#> 178: 1.052563    1.057635    3.467714    0.571737    0.055959    0.012724    0.698352    
#> 179: 1.094119    1.066782    3.464999    0.668031    0.055162    0.010293    0.706665    
#> 180: 1.128933    1.038785    3.475277    0.683408    0.049602    0.011073    0.702368    
#> 181: 1.095084    1.018154    3.469141    0.638511    0.049398    0.011088    0.697628    
#> 182: 1.097358    1.044641    3.455521    0.752170    0.058249    0.008484    0.705829    
#> 183: 1.068854    1.050842    3.460777    0.557120    0.055566    0.008179    0.708949    
#> 184: 1.090974    1.039567    3.463553    0.639301    0.045067    0.008640    0.698322    
#> 185: 1.074226    1.062774    3.464616    0.611983    0.046057    0.008615    0.711131    
#> 186: 1.031721    1.064625    3.469659    0.551268    0.059993    0.009052    0.713307    
#> 187: 1.068898    1.029346    3.479630    0.511596    0.046490    0.011679    0.707075    
#> 188: 1.045158    1.059656    3.471015    0.492658    0.046662    0.010449    0.724815    
#> 189: 1.117160    1.054454    3.481651    0.572322    0.050294    0.008931    0.716079    
#> 190: 1.094986    1.043520    3.481563    0.506525    0.050526    0.008950    0.705601    
#> 191: 1.095609    1.048814    3.477240    0.561842    0.045649    0.008723    0.688554    
#> 192: 1.090003    1.046679    3.481793    0.639023    0.051149    0.009237    0.689381    
#> 193: 1.141976    1.046640    3.487015    0.650859    0.055859    0.009767    0.676429    
#> 194: 1.078843    1.051883    3.476870    0.485119    0.059950    0.010586    0.707989    
#> 195: 1.043016    1.057461    3.468476    0.494092    0.054336    0.010496    0.707212    
#> 196: 1.085718    1.045521    3.483947    0.510353    0.063849    0.011747    0.715201    
#> 197: 1.089405    1.044874    3.504535    0.538523    0.048326    0.013126    0.718195    
#> 198: 1.132635    1.028876    3.491254    0.587239    0.037594    0.012311    0.707072    
#> 199: 1.089419    1.019953    3.486783    0.512968    0.045346    0.011714    0.692415    
#> 200: 1.050073    1.042198    3.476336    0.563401    0.047994    0.012019    0.705925    
#> 201: 1.083050    1.028012    3.485668    0.622825    0.045147    0.012049    0.703961    
#> 202: 1.109920    1.027766    3.483632    0.704381    0.046321    0.011699    0.700812    
#> 203: 1.141197    1.025712    3.481888    0.771497    0.049153    0.011679    0.698375    
#> 204: 1.152364    1.021687    3.482906    0.795725    0.048397    0.011568    0.701937    
#> 205: 1.175399    1.027171    3.482013    0.854294    0.049173    0.011993    0.700833    
#> 206: 1.179198    1.031511    3.482282    0.863631    0.049281    0.011653    0.699295    
#> 207: 1.168936    1.034082    3.481384    0.848008    0.048637    0.011398    0.698653    
#> 208: 1.168330    1.035855    3.481193    0.841084    0.048707    0.011357    0.695668    
#> 209: 1.171827    1.033781    3.480605    0.843156    0.048666    0.011314    0.694728    
#> 210: 1.171049    1.034984    3.480417    0.841616    0.048417    0.011226    0.693507    
#> 211: 1.174711    1.036138    3.481026    0.848263    0.048633    0.011128    0.692025    
#> 212: 1.172706    1.036103    3.480752    0.847581    0.048841    0.011201    0.690785    
#> 213: 1.173537    1.034917    3.480330    0.843380    0.048700    0.011299    0.691558    
#> 214: 1.172970    1.034373    3.480694    0.836168    0.048768    0.011551    0.690778    
#> 215: 1.171256    1.034924    3.481256    0.829868    0.048467    0.011821    0.689994    
#> 216: 1.173229    1.033997    3.481504    0.830459    0.048395    0.011827    0.691224    
#> 217: 1.175718    1.034685    3.481579    0.831715    0.047834    0.011856    0.691180    
#> 218: 1.175437    1.035717    3.481058    0.827117    0.047415    0.011798    0.691334    
#> 219: 1.174883    1.035694    3.480501    0.826615    0.047197    0.012004    0.692037    
#> 220: 1.175716    1.036068    3.480338    0.834391    0.046656    0.012140    0.692429    
#> 221: 1.174684    1.036514    3.480120    0.831842    0.046450    0.012148    0.692534    
#> 222: 1.171485    1.036463    3.479824    0.823937    0.046323    0.012266    0.692938    
#> 223: 1.175210    1.036884    3.480280    0.830329    0.046261    0.012425    0.692135    
#> 224: 1.179230    1.038069    3.480735    0.836530    0.046287    0.012492    0.691476    
#> 225: 1.179259    1.037243    3.480801    0.837958    0.046274    0.012557    0.691802    
#> 226: 1.177462    1.036117    3.480671    0.828390    0.046301    0.012502    0.691622    
#> 227: 1.174015    1.036129    3.480744    0.818973    0.046405    0.012415    0.691820    
#> 228: 1.171958    1.037256    3.480275    0.812508    0.046480    0.012445    0.691897    
#> 229: 1.169196    1.036932    3.480128    0.806808    0.046630    0.012401    0.691550    
#> 230: 1.169782    1.036654    3.479971    0.805192    0.046510    0.012432    0.691583    
#> 231: 1.170198    1.036876    3.480275    0.807725    0.046514    0.012455    0.691254    
#> 232: 1.168803    1.036171    3.480696    0.804598    0.046678    0.012458    0.691395    
#> 233: 1.167273    1.035485    3.480944    0.803454    0.046457    0.012566    0.691564    
#> 234: 1.166678    1.035018    3.480983    0.803167    0.046231    0.012620    0.691593    
#> 235: 1.166253    1.034501    3.480892    0.801518    0.046161    0.012614    0.691517    
#> 236: 1.167904    1.034765    3.480723    0.807070    0.045985    0.012654    0.691588    
#> 237: 1.170738    1.034884    3.480793    0.816535    0.045933    0.012738    0.691925    
#> 238: 1.173087    1.034690    3.480868    0.824620    0.046016    0.012894    0.692217    
#> 239: 1.174696    1.034984    3.480816    0.830722    0.045958    0.013106    0.692262    
#> 240: 1.177497    1.034675    3.481032    0.836960    0.045956    0.013182    0.691963    
#> 241: 1.178909    1.034116    3.481283    0.837747    0.045917    0.013274    0.691836    
#> 242: 1.180038    1.033826    3.481089    0.843568    0.045800    0.013330    0.692389    
#> 243: 1.178584    1.034058    3.481113    0.842863    0.045658    0.013409    0.692776    
#> 244: 1.177038    1.034223    3.481005    0.842480    0.045740    0.013462    0.693333    
#> 245: 1.177119    1.033891    3.481007    0.843189    0.046072    0.013459    0.693353    
#> 246: 1.177416    1.033595    3.481263    0.841047    0.046253    0.013519    0.693604    
#> 247: 1.177491    1.033616    3.481512    0.840881    0.046396    0.013580    0.693545    
#> 248: 1.176490    1.033655    3.481601    0.837298    0.046457    0.013605    0.693288    
#> 249: 1.174256    1.033878    3.481400    0.834869    0.046432    0.013618    0.693200    
#> 250: 1.174808    1.034421    3.481404    0.835940    0.046448    0.013644    0.693302    
#> 251: 1.174698    1.034978    3.481601    0.834412    0.046435    0.013661    0.693515    
#> 252: 1.175095    1.035074    3.481883    0.833659    0.046468    0.013673    0.693164    
#> 253: 1.174291    1.035266    3.482003    0.833785    0.046517    0.013708    0.693161    
#> 254: 1.173973    1.035845    3.482161    0.834032    0.046589    0.013761    0.693248    
#> 255: 1.174566    1.035959    3.482339    0.835492    0.046502    0.013816    0.693354    
#> 256: 1.174977    1.035679    3.482380    0.836595    0.046322    0.013848    0.693343    
#> 257: 1.174317    1.035343    3.482376    0.834049    0.046151    0.013873    0.693515    
#> 258: 1.173936    1.034884    3.482396    0.833481    0.045986    0.013843    0.693760    
#> 259: 1.173462    1.034634    3.482369    0.831492    0.046129    0.013825    0.693658    
#> 260: 1.172611    1.034704    3.482442    0.827316    0.046136    0.013806    0.693422    
#> 261: 1.172434    1.034647    3.482606    0.825879    0.046142    0.013829    0.693235    
#> 262: 1.173474    1.034582    3.482751    0.826789    0.046169    0.013836    0.692940    
#> 263: 1.172935    1.034678    3.482849    0.825040    0.046040    0.013839    0.692781    
#> 264: 1.172261    1.034782    3.482807    0.824327    0.045960    0.013798    0.692929    
#> 265: 1.172554    1.034652    3.482849    0.823708    0.045978    0.013757    0.692899    
#> 266: 1.173727    1.034860    3.482914    0.825253    0.046012    0.013717    0.692805    
#> 267: 1.173719    1.034977    3.482995    0.825878    0.045921    0.013690    0.692773    
#> 268: 1.173359    1.034693    3.482876    0.824723    0.045944    0.013707    0.692614    
#> 269: 1.174750    1.034376    3.482914    0.825851    0.046002    0.013701    0.692549    
#> 270: 1.175754    1.034397    3.482861    0.829538    0.046045    0.013671    0.692111    
#> 271: 1.176511    1.034526    3.482777    0.831181    0.046023    0.013642    0.692146    
#> 272: 1.177275    1.034501    3.482834    0.831442    0.046030    0.013668    0.692325    
#> 273: 1.177277    1.034573    3.482874    0.831447    0.046111    0.013672    0.692561    
#> 274: 1.176823    1.034922    3.482998    0.829229    0.046089    0.013692    0.692660    
#> 275: 1.176706    1.035064    3.482910    0.828548    0.046090    0.013712    0.692605    
#> 276: 1.176626    1.035378    3.482921    0.828688    0.046020    0.013718    0.692681    
#> 277: 1.176793    1.035666    3.482987    0.830368    0.045958    0.013699    0.692797    
#> 278: 1.176726    1.035862    3.483013    0.829951    0.046045    0.013668    0.692972    
#> 279: 1.176138    1.035633    3.483060    0.829305    0.046207    0.013666    0.693055    
#> 280: 1.175587    1.035808    3.483050    0.827905    0.046448    0.013641    0.692888    
#> 281: 1.174749    1.035782    3.483079    0.827123    0.046443    0.013628    0.693124    
#> 282: 1.174836    1.035956    3.483142    0.828167    0.046588    0.013633    0.693131    
#> 283: 1.174559    1.036131    3.483219    0.828201    0.046655    0.013630    0.693564    
#> 284: 1.173806    1.035984    3.483136    0.826641    0.046685    0.013651    0.693620    
#> 285: 1.174105    1.035881    3.483039    0.827166    0.046788    0.013665    0.693604    
#> 286: 1.174633    1.035881    3.482946    0.828756    0.046851    0.013658    0.693587    
#> 287: 1.174891    1.035980    3.482779    0.830124    0.046841    0.013689    0.693518    
#> 288: 1.175646    1.035869    3.482690    0.832376    0.046888    0.013680    0.693695    
#> 289: 1.176678    1.035808    3.482682    0.835733    0.046974    0.013666    0.693638    
#> 290: 1.176885    1.035749    3.482668    0.836390    0.046972    0.013673    0.693591    
#> 291: 1.177024    1.036021    3.482727    0.836259    0.046972    0.013637    0.693439    
#> 292: 1.176352    1.036024    3.482720    0.834597    0.046975    0.013594    0.693447    
#> 293: 1.175815    1.036012    3.482751    0.833534    0.046989    0.013564    0.693384    
#> 294: 1.175035    1.035995    3.482733    0.831753    0.047061    0.013554    0.693305    
#> 295: 1.175403    1.035640    3.482700    0.831885    0.047049    0.013549    0.693112    
#> 296: 1.175929    1.035491    3.482593    0.832816    0.046929    0.013551    0.693199    
#> 297: 1.175875    1.035595    3.482585    0.832584    0.046905    0.013584    0.693042    
#> 298: 1.175765    1.035656    3.482500    0.832196    0.046916    0.013583    0.692952    
#> 299: 1.175831    1.035925    3.482376    0.832310    0.046948    0.013572    0.692848    
#> 300: 1.175184    1.035742    3.482362    0.830950    0.047109    0.013560    0.692753    
#> 301: 1.175047    1.035532    3.482241    0.830393    0.047189    0.013510    0.692800    
#> 302: 1.175038    1.035472    3.482138    0.830242    0.047190    0.013479    0.692689    
#> 303: 1.174533    1.035689    3.482011    0.829669    0.047217    0.013459    0.692449    
#> 304: 1.174202    1.036093    3.481788    0.829578    0.047190    0.013434    0.692430    
#> 305: 1.172938    1.036062    3.481602    0.828634    0.047271    0.013414    0.692348    
#> 306: 1.172425    1.035953    3.481445    0.827638    0.047263    0.013388    0.692336    
#> 307: 1.172259    1.035926    3.481298    0.828058    0.047462    0.013356    0.692299    
#> 308: 1.171588    1.035942    3.481141    0.828025    0.047641    0.013337    0.692593    
#> 309: 1.171448    1.035872    3.481065    0.829217    0.047672    0.013319    0.692804    
#> 310: 1.171665    1.035745    3.480904    0.830180    0.047710    0.013291    0.692984    
#> 311: 1.171482    1.035788    3.480774    0.830484    0.047718    0.013273    0.692875    
#> 312: 1.170920    1.035722    3.480648    0.830260    0.047714    0.013264    0.692748    
#> 313: 1.170789    1.035432    3.480535    0.830764    0.047685    0.013251    0.692798    
#> 314: 1.170368    1.035290    3.480498    0.830401    0.047690    0.013252    0.692720    
#> 315: 1.169671    1.035278    3.480495    0.829377    0.047644    0.013249    0.692703    
#> 316: 1.169320    1.035268    3.480431    0.828498    0.047650    0.013225    0.692714    
#> 317: 1.169434    1.035224    3.480393    0.827558    0.047663    0.013250    0.692727    
#> 318: 1.169468    1.035197    3.480362    0.827421    0.047603    0.013240    0.692666    
#> 319: 1.169608    1.035006    3.480386    0.827878    0.047620    0.013247    0.692761    
#> 320: 1.169193    1.034935    3.480296    0.828541    0.047562    0.013223    0.692828    
#> 321: 1.168968    1.034944    3.480187    0.829357    0.047577    0.013209    0.693003    
#> 322: 1.168137    1.035091    3.480000    0.827760    0.047525    0.013169    0.693203    
#> 323: 1.166954    1.035191    3.479807    0.826365    0.047517    0.013139    0.693360    
#> 324: 1.166296    1.035473    3.479702    0.825259    0.047552    0.013104    0.693306    
#> 325: 1.166124    1.035764    3.479620    0.824919    0.047587    0.013109    0.693195    
#> 326: 1.165960    1.035751    3.479469    0.825428    0.047592    0.013103    0.693182    
#> 327: 1.166032    1.035830    3.479440    0.825870    0.047606    0.013089    0.693218    
#> 328: 1.165756    1.035878    3.479356    0.825036    0.047594    0.013078    0.693180    
#> 329: 1.165430    1.035968    3.479336    0.823831    0.047577    0.013088    0.693096    
#> 330: 1.165201    1.036069    3.479312    0.823493    0.047550    0.013099    0.693005    
#> 331: 1.165056    1.036324    3.479215    0.823249    0.047508    0.013099    0.692943    
#> 332: 1.164690    1.036359    3.479186    0.822607    0.047440    0.013082    0.693135    
#> 333: 1.164554    1.036252    3.479131    0.822114    0.047475    0.013071    0.693237    
#> 334: 1.164385    1.036215    3.478999    0.821677    0.047533    0.013071    0.693232    
#> 335: 1.163226    1.036261    3.478830    0.820049    0.047602    0.013057    0.693166    
#> 336: 1.162311    1.036445    3.478650    0.819754    0.047717    0.013041    0.693164    
#> 337: 1.162155    1.036825    3.478494    0.820816    0.047784    0.013028    0.693195    
#> 338: 1.162463    1.037132    3.478447    0.821784    0.047807    0.013019    0.693186    
#> 339: 1.161952    1.037323    3.478411    0.820709    0.047766    0.013033    0.693096    
#> 340: 1.161774    1.037124    3.478512    0.819328    0.047761    0.013047    0.693182    
#> 341: 1.161761    1.037061    3.478590    0.818087    0.047815    0.013066    0.693105    
#> 342: 1.161372    1.036786    3.478606    0.817134    0.047839    0.013068    0.693072    
#> 343: 1.161072    1.036703    3.478672    0.816382    0.047833    0.013075    0.693018    
#> 344: 1.161161    1.036547    3.478774    0.816244    0.047708    0.013095    0.693174    
#> 345: 1.161069    1.036562    3.478821    0.815736    0.047716    0.013118    0.693175    
#> 346: 1.160788    1.036576    3.478790    0.814561    0.047703    0.013105    0.693013    
#> 347: 1.161204    1.036390    3.478783    0.816049    0.047731    0.013118    0.692952    
#> 348: 1.161112    1.036412    3.478738    0.816370    0.047778    0.013132    0.693044    
#> 349: 1.160875    1.036439    3.478681    0.816884    0.047775    0.013157    0.693042    
#> 350: 1.160587    1.036414    3.478602    0.816958    0.047806    0.013159    0.693067    
#> 351: 1.160312    1.036649    3.478489    0.817385    0.047897    0.013153    0.693080    
#> 352: 1.159841    1.036702    3.478472    0.817035    0.047937    0.013167    0.693218    
#> 353: 1.159887    1.036795    3.478472    0.816468    0.047979    0.013175    0.693235    
#> 354: 1.160202    1.036745    3.478427    0.816970    0.047979    0.013185    0.693066    
#> 355: 1.160524    1.036556    3.478424    0.816607    0.047969    0.013197    0.692923    
#> 356: 1.160549    1.036449    3.478448    0.816145    0.047922    0.013208    0.693052    
#> 357: 1.160504    1.036462    3.478434    0.815418    0.047847    0.013198    0.693073    
#> 358: 1.160456    1.036576    3.478414    0.815175    0.047824    0.013208    0.693027    
#> 359: 1.160349    1.036559    3.478399    0.815227    0.047801    0.013232    0.692900    
#> 360: 1.160261    1.036441    3.478384    0.814998    0.047758    0.013259    0.692814    
#> 361: 1.160257    1.036379    3.478405    0.814912    0.047755    0.013285    0.692776    
#> 362: 1.160488    1.036454    3.478333    0.815169    0.047783    0.013289    0.692644    
#> 363: 1.160723    1.036429    3.478359    0.815725    0.047758    0.013298    0.692542    
#> 364: 1.161056    1.036467    3.478363    0.816111    0.047713    0.013318    0.692434    
#> 365: 1.161190    1.036482    3.478367    0.816705    0.047681    0.013340    0.692442    
#> 366: 1.161074    1.036586    3.478281    0.817419    0.047740    0.013346    0.692439    
#> 367: 1.160852    1.036681    3.478191    0.817358    0.047801    0.013337    0.692394    
#> 368: 1.160710    1.036861    3.478097    0.817600    0.047786    0.013316    0.692348    
#> 369: 1.160268    1.036890    3.478070    0.817153    0.047830    0.013306    0.692361    
#> 370: 1.159999    1.037012    3.478041    0.816395    0.047871    0.013305    0.692397    
#> 371: 1.159847    1.037064    3.477956    0.815960    0.047893    0.013295    0.692337    
#> 372: 1.159501    1.037112    3.477895    0.815945    0.047894    0.013282    0.692319    
#> 373: 1.159140    1.037240    3.477799    0.816078    0.047946    0.013267    0.692355    
#> 374: 1.158915    1.037266    3.477752    0.815689    0.048017    0.013223    0.692440    
#> 375: 1.158528    1.037247    3.477729    0.814893    0.048060    0.013193    0.692512    
#> 376: 1.159035    1.037322    3.477720    0.815908    0.048091    0.013179    0.692475    
#> 377: 1.159100    1.037396    3.477755    0.815735    0.048105    0.013172    0.692579    
#> 378: 1.158865    1.037305    3.477745    0.814754    0.048124    0.013179    0.692638    
#> 379: 1.158295    1.037162    3.477771    0.813309    0.048151    0.013175    0.692689    
#> 380: 1.158108    1.037021    3.477804    0.812498    0.048167    0.013168    0.692637    
#> 381: 1.157806    1.036923    3.477784    0.811906    0.048142    0.013174    0.692580    
#> 382: 1.157790    1.036838    3.477837    0.811638    0.048158    0.013186    0.692443    
#> 383: 1.157700    1.036819    3.477797    0.811154    0.048106    0.013197    0.692420    
#> 384: 1.157845    1.036756    3.477833    0.811584    0.048098    0.013208    0.692351    
#> 385: 1.157928    1.036674    3.477871    0.811658    0.048093    0.013218    0.692332    
#> 386: 1.158245    1.036737    3.477948    0.811727    0.048123    0.013221    0.692289    
#> 387: 1.158264    1.036706    3.478058    0.811012    0.048158    0.013221    0.692286    
#> 388: 1.158439    1.036703    3.478096    0.811189    0.048157    0.013212    0.692305    
#> 389: 1.158787    1.036489    3.478156    0.811487    0.048133    0.013204    0.692405    
#> 390: 1.158679    1.036464    3.478167    0.811609    0.048073    0.013208    0.692386    
#> 391: 1.158642    1.036436    3.478154    0.811564    0.048015    0.013219    0.692280    
#> 392: 1.158299    1.036467    3.478133    0.810636    0.047964    0.013221    0.692254    
#> 393: 1.158002    1.036404    3.478081    0.809836    0.047946    0.013223    0.692193    
#> 394: 1.157845    1.036426    3.478078    0.809213    0.047954    0.013233    0.692108    
#> 395: 1.157931    1.036544    3.478103    0.808945    0.047935    0.013248    0.692058    
#> 396: 1.157628    1.036698    3.478077    0.808356    0.047894    0.013255    0.692001    
#> 397: 1.157667    1.036716    3.478050    0.809337    0.047855    0.013255    0.692005    
#> 398: 1.158248    1.036734    3.478042    0.811465    0.047824    0.013249    0.692020    
#> 399: 1.158426    1.036753    3.478097    0.811512    0.047792    0.013251    0.692015    
#> 400: 1.158770    1.036705    3.478185    0.811564    0.047754    0.013253    0.691973    
#> 401: 1.159025    1.036765    3.478201    0.811541    0.047744    0.013253    0.692013    
#> 402: 1.159250    1.036871    3.478206    0.811580    0.047725    0.013257    0.692048    
#> 403: 1.159482    1.036863    3.478201    0.811662    0.047776    0.013246    0.692085    
#> 404: 1.159695    1.036881    3.478161    0.811807    0.047775    0.013248    0.692062    
#> 405: 1.159722    1.036870    3.478188    0.811727    0.047753    0.013246    0.692052    
#> 406: 1.159830    1.036937    3.478158    0.811895    0.047729    0.013256    0.692059    
#> 407: 1.159907    1.037005    3.478176    0.812037    0.047761    0.013258    0.692008    
#> 408: 1.159952    1.037065    3.478145    0.812039    0.047808    0.013244    0.692049    
#> 409: 1.159847    1.037106    3.478053    0.812253    0.047797    0.013244    0.692011    
#> 410: 1.159659    1.037181    3.477951    0.812602    0.047806    0.013263    0.692001    
#> 411: 1.159863    1.037054    3.477941    0.813082    0.047795    0.013274    0.692096    
#> 412: 1.159532    1.037164    3.477898    0.812374    0.047799    0.013277    0.692156    
#> 413: 1.159369    1.037228    3.477860    0.811975    0.047779    0.013270    0.692191    
#> 414: 1.158875    1.037195    3.477855    0.811238    0.047744    0.013269    0.692239    
#> 415: 1.158720    1.037143    3.477871    0.810536    0.047708    0.013275    0.692256    
#> 416: 1.158603    1.037174    3.477900    0.809892    0.047696    0.013271    0.692208    
#> 417: 1.158598    1.037186    3.477883    0.809991    0.047682    0.013283    0.692193    
#> 418: 1.158426    1.037298    3.477830    0.810272    0.047726    0.013285    0.692217    
#> 419: 1.158434    1.037371    3.477801    0.810323    0.047760    0.013283    0.692186    
#> 420: 1.158482    1.037433    3.477815    0.809956    0.047763    0.013272    0.692085    
#> 421: 1.158427    1.037485    3.477864    0.809882    0.047755    0.013265    0.692042    
#> 422: 1.158616    1.037476    3.477845    0.810393    0.047745    0.013262    0.692035    
#> 423: 1.158660    1.037426    3.477864    0.810610    0.047733    0.013269    0.692020    
#> 424: 1.158712    1.037380    3.477810    0.810922    0.047738    0.013271    0.692000    
#> 425: 1.158986    1.037432    3.477746    0.812003    0.047713    0.013284    0.692027    
#> 426: 1.159137    1.037503    3.477750    0.812944    0.047719    0.013283    0.692030    
#> 427: 1.159016    1.037496    3.477741    0.813037    0.047749    0.013287    0.691994    
#> 428: 1.158977    1.037552    3.477747    0.812916    0.047787    0.013291    0.691997    
#> 429: 1.158953    1.037531    3.477764    0.812781    0.047775    0.013291    0.691951    
#> 430: 1.158958    1.037644    3.477776    0.812560    0.047753    0.013297    0.692000    
#> 431: 1.158776    1.037683    3.477752    0.811928    0.047749    0.013299    0.691973    
#> 432: 1.158899    1.037768    3.477735    0.812604    0.047721    0.013304    0.691926    
#> 433: 1.159032    1.037845    3.477776    0.813147    0.047705    0.013300    0.691957    
#> 434: 1.158937    1.037810    3.477759    0.813222    0.047696    0.013304    0.691887    
#> 435: 1.158999    1.037861    3.477734    0.813195    0.047697    0.013306    0.691872    
#> 436: 1.159039    1.037847    3.477764    0.813034    0.047666    0.013315    0.691877    
#> 437: 1.158957    1.037832    3.477758    0.812547    0.047641    0.013323    0.691857    
#> 438: 1.158905    1.038005    3.477709    0.812540    0.047704    0.013302    0.691804    
#> 439: 1.159168    1.038083    3.477707    0.812882    0.047717    0.013295    0.691766    
#> 440: 1.159235    1.038115    3.477757    0.812580    0.047738    0.013290    0.691704    
#> 441: 1.159199    1.038016    3.477820    0.811763    0.047754    0.013288    0.691686    
#> 442: 1.159131    1.037938    3.477909    0.811005    0.047769    0.013291    0.691671    
#> 443: 1.159148    1.037996    3.477904    0.810366    0.047770    0.013279    0.691706    
#> 444: 1.158957    1.038043    3.477874    0.809694    0.047761    0.013272    0.691718    
#> 445: 1.158598    1.038138    3.477817    0.809072    0.047823    0.013262    0.691769    
#> 446: 1.158317    1.038230    3.477757    0.808853    0.047873    0.013253    0.691745    
#> 447: 1.158134    1.038265    3.477727    0.808589    0.047928    0.013240    0.691757    
#> 448: 1.157863    1.038370    3.477674    0.808736    0.047910    0.013230    0.691762    
#> 449: 1.157699    1.038532    3.477682    0.808423    0.047923    0.013215    0.691838    
#> 450: 1.157780    1.038601    3.477650    0.808568    0.047945    0.013201    0.691893    
#> 451: 1.157774    1.038724    3.477613    0.808526    0.047951    0.013203    0.691960    
#> 452: 1.157811    1.038774    3.477622    0.808536    0.047956    0.013203    0.692007    
#> 453: 1.157850    1.038861    3.477612    0.808249    0.047939    0.013191    0.692025    
#> 454: 1.157773    1.038974    3.477597    0.808175    0.047918    0.013181    0.691951    
#> 455: 1.157686    1.038985    3.477557    0.808233    0.047916    0.013179    0.691948    
#> 456: 1.157537    1.039001    3.477516    0.807962    0.047904    0.013176    0.691999    
#> 457: 1.157428    1.039008    3.477539    0.807396    0.047915    0.013170    0.691947    
#> 458: 1.157343    1.039110    3.477585    0.806878    0.047909    0.013169    0.691962    
#> 459: 1.157022    1.039203    3.477614    0.806311    0.047903    0.013172    0.691987    
#> 460: 1.157054    1.039233    3.477614    0.806075    0.047875    0.013175    0.692052    
#> 461: 1.156991    1.039296    3.477625    0.805634    0.047843    0.013174    0.692112    
#> 462: 1.156773    1.039411    3.477624    0.805326    0.047874    0.013171    0.692163    
#> 463: 1.156686    1.039455    3.477631    0.805476    0.047890    0.013171    0.692193    
#> 464: 1.156603    1.039562    3.477577    0.805564    0.047917    0.013167    0.692166    
#> 465: 1.156658    1.039449    3.477545    0.805784    0.047925    0.013164    0.692153    
#> 466: 1.156553    1.039499    3.477517    0.805440    0.047916    0.013158    0.692176    
#> 467: 1.156666    1.039499    3.477541    0.805919    0.047938    0.013150    0.692175    
#> 468: 1.156934    1.039488    3.477600    0.806424    0.047910    0.013148    0.692186    
#> 469: 1.157222    1.039510    3.477675    0.806504    0.047912    0.013151    0.692272    
#> 470: 1.157621    1.039489    3.477701    0.807484    0.047919    0.013143    0.692267    
#> 471: 1.157783    1.039493    3.477719    0.807828    0.047886    0.013132    0.692321    
#> 472: 1.157902    1.039466    3.477723    0.808268    0.047860    0.013124    0.692344    
#> 473: 1.157824    1.039498    3.477717    0.808054    0.047821    0.013138    0.692329    
#> 474: 1.157855    1.039440    3.477698    0.808483    0.047809    0.013154    0.692343    
#> 475: 1.157774    1.039532    3.477657    0.808467    0.047781    0.013175    0.692355    
#> 476: 1.157709    1.039486    3.477619    0.808472    0.047756    0.013183    0.692457    
#> 477: 1.157613    1.039427    3.477619    0.808256    0.047760    0.013193    0.692440    
#> 478: 1.157594    1.039414    3.477609    0.808572    0.047793    0.013196    0.692459    
#> 479: 1.157707    1.039510    3.477591    0.808953    0.047781    0.013200    0.692453    
#> 480: 1.158065    1.039521    3.477565    0.810027    0.047754    0.013216    0.692483    
#> 481: 1.158162    1.039547    3.477538    0.810613    0.047736    0.013220    0.692446    
#> 482: 1.158178    1.039588    3.477465    0.811269    0.047709    0.013232    0.692492    
#> 483: 1.157862    1.039635    3.477424    0.810981    0.047673    0.013238    0.692510    
#> 484: 1.157926    1.039561    3.477446    0.811089    0.047659    0.013239    0.692517    
#> 485: 1.157794    1.039572    3.477444    0.810774    0.047630    0.013245    0.692524    
#> 486: 1.157744    1.039628    3.477489    0.810376    0.047607    0.013253    0.692489    
#> 487: 1.158020    1.039669    3.477525    0.810557    0.047601    0.013262    0.692416    
#> 488: 1.158028    1.039632    3.477544    0.810420    0.047553    0.013284    0.692396    
#> 489: 1.158253    1.039548    3.477544    0.810890    0.047522    0.013304    0.692403    
#> 490: 1.158234    1.039558    3.477540    0.810790    0.047494    0.013312    0.692400    
#> 491: 1.158229    1.039644    3.477575    0.810536    0.047474    0.013324    0.692399    
#> 492: 1.158062    1.039747    3.477575    0.810436    0.047436    0.013334    0.692524    
#> 493: 1.157674    1.039764    3.477543    0.809982    0.047394    0.013346    0.692573    
#> 494: 1.157630    1.039799    3.477508    0.809911    0.047353    0.013346    0.692536    
#> 495: 1.157917    1.039846    3.477507    0.810532    0.047318    0.013348    0.692563    
#> 496: 1.158262    1.039911    3.477511    0.811400    0.047310    0.013348    0.692586    
#> 497: 1.158036    1.039884    3.477492    0.811253    0.047320    0.013344    0.692620    
#> 498: 1.157893    1.039873    3.477463    0.811252    0.047309    0.013340    0.692620    
#> 499: 1.157830    1.039998    3.477410    0.811310    0.047327    0.013333    0.692590    
#> 500: 1.157777    1.039985    3.477380    0.811158    0.047357    0.013326    0.692560    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.317104    0.975025    3.445083    0.392401    0.077588    0.016800    1.895157    
#> 002: 0.353967    1.055996    3.460743    0.372781    0.073708    0.017472    1.310108    
#> 003: 0.494762    0.999043    3.467416    0.354142    0.086970    0.017695    0.928638    
#> 004: 0.450892    0.978961    3.475913    0.364967    0.128860    0.016810    0.739284    
#> 005: 0.524900    0.956930    3.474734    0.365424    0.141301    0.015969    0.687181    
#> 006: 0.525984    0.970447    3.479054    0.393262    0.134236    0.015982    0.641925    
#> 007: 0.510261    0.986502    3.477520    0.403461    0.127524    0.015183    0.674356    
#> 008: 0.500364    0.969491    3.480645    0.383288    0.156374    0.014912    0.673649    
#> 009: 0.470199    0.944574    3.465680    0.364124    0.160761    0.014167    0.679834    
#> 010: 0.472603    0.947576    3.471947    0.374084    0.199243    0.016925    0.669122    
#> 011: 0.577230    0.947518    3.487006    0.355380    0.189281    0.018414    0.669057    
#> 012: 0.598501    0.954832    3.487880    0.427226    0.179817    0.017517    0.657719    
#> 013: 0.523395    0.966825    3.479242    0.405865    0.170826    0.016860    0.656746    
#> 014: 0.574121    0.948639    3.490305    0.476242    0.187087    0.016017    0.644045    
#> 015: 0.601350    0.945698    3.499847    0.482081    0.177732    0.017650    0.631845    
#> 016: 0.590663    0.965526    3.494440    0.457977    0.173289    0.017113    0.650953    
#> 017: 0.567343    0.981946    3.490980    0.458609    0.168161    0.016257    0.636731    
#> 018: 0.534170    0.977198    3.481956    0.435679    0.164064    0.015444    0.649581    
#> 019: 0.511964    0.988090    3.473208    0.413895    0.155861    0.014672    0.653870    
#> 020: 0.555459    0.977392    3.486103    0.393200    0.148067    0.014605    0.644133    
#> 021: 0.541370    0.955570    3.495869    0.404951    0.140664    0.013875    0.640424    
#> 022: 0.546095    0.954935    3.502607    0.403735    0.153050    0.015117    0.634861    
#> 023: 0.625351    0.980475    3.506005    0.426013    0.161619    0.015343    0.653044    
#> 024: 0.597744    0.973601    3.508949    0.404713    0.153538    0.017536    0.643262    
#> 025: 0.602208    0.931954    3.503347    0.411778    0.168368    0.016659    0.644130    
#> 026: 0.578436    0.976757    3.483633    0.416686    0.168725    0.015826    0.653787    
#> 027: 0.561694    1.007695    3.479942    0.441041    0.193046    0.015035    0.657128    
#> 028: 0.554612    0.982143    3.490311    0.418989    0.183394    0.014283    0.648358    
#> 029: 0.594408    0.962546    3.488573    0.398040    0.174224    0.013682    0.675337    
#> 030: 0.569878    0.961512    3.487529    0.387852    0.165513    0.013612    0.656326    
#> 031: 0.555838    0.947926    3.502729    0.368459    0.157238    0.014209    0.675040    
#> 032: 0.548425    0.941499    3.509582    0.388367    0.149376    0.016299    0.654750    
#> 033: 0.574500    0.946818    3.506585    0.452700    0.168885    0.017180    0.655268    
#> 034: 0.605188    0.932927    3.520863    0.498892    0.168669    0.016321    0.664362    
#> 035: 0.602740    0.916401    3.515884    0.473947    0.160236    0.015856    0.652703    
#> 036: 0.620246    0.943697    3.516815    0.450250    0.153090    0.018161    0.661189    
#> 037: 0.574833    0.946627    3.518635    0.427738    0.177006    0.017253    0.676959    
#> 038: 0.643264    0.950664    3.509639    0.538141    0.168156    0.016391    0.667017    
#> 039: 0.618957    0.940188    3.511070    0.511234    0.186146    0.015571    0.642948    
#> 040: 0.561538    0.974407    3.512930    0.485673    0.176838    0.014792    0.677148    
#> 041: 0.557295    0.953867    3.504200    0.461389    0.167996    0.014053    0.657284    
#> 042: 0.581941    0.934848    3.502513    0.459801    0.177759    0.013350    0.644349    
#> 043: 0.554117    0.964424    3.482131    0.436811    0.193481    0.012683    0.656267    
#> 044: 0.533564    0.977048    3.476878    0.426933    0.183807    0.012049    0.667577    
#> 045: 0.496962    0.980984    3.467888    0.405587    0.192470    0.011446    0.658878    
#> 046: 0.495111    0.977788    3.470249    0.385307    0.182847    0.010874    0.651773    
#> 047: 0.536712    0.973208    3.469039    0.412566    0.173704    0.010330    0.659390    
#> 048: 0.562001    0.981900    3.479026    0.461730    0.183013    0.009814    0.656602    
#> 049: 0.541584    0.977198    3.477161    0.438644    0.173863    0.011731    0.648979    
#> 050: 0.557300    0.921423    3.481215    0.456028    0.180845    0.013778    0.674582    
#> 051: 0.588763    0.954641    3.479063    0.533007    0.206579    0.013090    0.662112    
#> 052: 0.620359    0.958316    3.486964    0.568059    0.196250    0.012435    0.655987    
#> 053: 0.564781    0.965840    3.482938    0.567304    0.186437    0.011813    0.653254    
#> 054: 0.538640    0.949009    3.494614    0.538939    0.177116    0.011223    0.670435    
#> 055: 0.551078    0.964179    3.492410    0.511992    0.168260    0.011536    0.654047    
#> 056: 0.596096    0.955314    3.494795    0.514388    0.168266    0.013230    0.663074    
#> 057: 0.609903    0.942516    3.490689    0.548851    0.159853    0.012568    0.667169    
#> 058: 0.590167    0.973501    3.482390    0.527875    0.151860    0.011940    0.662790    
#> 059: 0.572322    0.924653    3.494491    0.502919    0.157519    0.012301    0.654602    
#> 060: 0.560796    0.953087    3.488313    0.547557    0.159090    0.014379    0.657948    
#> 061: 0.596818    0.954831    3.488703    0.534310    0.160142    0.013660    0.672617    
#> 062: 0.553532    0.956809    3.490827    0.507595    0.157345    0.014929    0.673663    
#> 063: 0.598670    0.927359    3.490057    0.527854    0.168440    0.018215    0.670773    
#> 064: 0.578890    0.945029    3.492235    0.521993    0.163165    0.018273    0.652216    
#> 065: 0.583071    0.945175    3.480225    0.514501    0.155006    0.017657    0.641359    
#> 066: 0.558459    0.960989    3.483618    0.488776    0.147256    0.019101    0.640485    
#> 067: 0.538603    0.960810    3.474640    0.503261    0.160312    0.021183    0.633118    
#> 068: 0.515422    0.971553    3.481403    0.478098    0.174734    0.020692    0.643302    
#> 069: 0.524204    0.960718    3.484632    0.483817    0.180805    0.019658    0.660876    
#> 070: 0.530866    0.971477    3.492215    0.461288    0.171765    0.020883    0.672967    
#> 071: 0.486899    0.980513    3.467256    0.438224    0.163177    0.019839    0.664188    
#> 072: 0.488739    0.980235    3.471147    0.416313    0.155018    0.018847    0.654593    
#> 073: 0.522460    0.986089    3.489985    0.395497    0.158105    0.017905    0.638395    
#> 074: 0.576375    0.954567    3.491870    0.489983    0.150200    0.017010    0.633065    
#> 075: 0.582719    0.927337    3.512805    0.465483    0.145018    0.016159    0.646238    
#> 076: 0.590279    0.950788    3.524278    0.442209    0.149320    0.016709    0.656581    
#> 077: 0.643851    0.930550    3.519323    0.436195    0.174283    0.015873    0.665630    
#> 078: 0.631470    0.923785    3.516115    0.440476    0.168677    0.015080    0.633461    
#> 079: 0.598822    0.947478    3.507437    0.477214    0.173515    0.014326    0.658456    
#> 080: 0.594588    0.940604    3.506879    0.521566    0.165381    0.014637    0.660096    
#> 081: 0.615448    0.946743    3.507666    0.510701    0.159640    0.015869    0.639925    
#> 082: 0.601819    0.945241    3.514375    0.485166    0.151658    0.015075    0.659688    
#> 083: 0.592541    0.974689    3.506826    0.460908    0.166970    0.014322    0.652834    
#> 084: 0.593711    0.957178    3.505093    0.437862    0.166454    0.013606    0.665300    
#> 085: 0.604449    0.961950    3.511383    0.415969    0.161496    0.014503    0.653445    
#> 086: 0.589080    0.964483    3.508912    0.395171    0.153421    0.013778    0.649281    
#> 087: 0.574761    0.964787    3.492229    0.376922    0.145750    0.014736    0.643366    
#> 088: 0.518361    0.958062    3.495338    0.429675    0.145984    0.014009    0.657924    
#> 089: 0.541128    0.980361    3.483132    0.408191    0.173884    0.014008    0.654942    
#> 090: 0.519085    0.966311    3.480337    0.432634    0.170446    0.013934    0.657755    
#> 091: 0.534263    0.965415    3.471445    0.461385    0.161924    0.015524    0.639790    
#> 092: 0.544033    0.986636    3.477091    0.520906    0.167951    0.015317    0.629540    
#> 093: 0.498654    0.965109    3.480388    0.494860    0.159553    0.015339    0.658867    
#> 094: 0.530923    0.974912    3.477836    0.470117    0.151575    0.017519    0.653827    
#> 095: 0.521218    0.997828    3.479622    0.446611    0.150044    0.019669    0.650270    
#> 096: 0.491675    0.992114    3.475290    0.466047    0.170383    0.018685    0.654663    
#> 097: 0.521542    0.984754    3.479574    0.442744    0.168498    0.017751    0.648761    
#> 098: 0.580344    0.994703    3.486209    0.442871    0.163660    0.016863    0.640531    
#> 099: 0.550359    0.957088    3.483824    0.525019    0.155477    0.016020    0.641458    
#> 100: 0.526083    0.986744    3.479677    0.498768    0.147703    0.015219    0.632362    
#> 101: 0.493251    0.955224    3.463415    0.494983    0.153330    0.014458    0.638556    
#> 102: 0.503579    0.974293    3.460144    0.470234    0.167333    0.014748    0.653499    
#> 103: 0.561066    0.948394    3.477752    0.486246    0.165139    0.014065    0.652180    
#> 104: 0.532372    0.962989    3.491590    0.461933    0.163521    0.015428    0.646622    
#> 105: 0.570163    0.952195    3.483839    0.526822    0.155345    0.014657    0.668116    
#> 106: 0.576106    0.940415    3.492155    0.528361    0.167974    0.013924    0.649941    
#> 107: 0.601357    0.966602    3.496467    0.564429    0.184635    0.015576    0.660854    
#> 108: 0.583837    0.970374    3.484275    0.536229    0.175404    0.014860    0.660489    
#> 109: 0.562315    0.963033    3.495115    0.509418    0.194791    0.014117    0.658815    
#> 110: 0.546158    0.960686    3.484591    0.495028    0.185052    0.013411    0.647405    
#> 111: 0.578321    0.953556    3.496957    0.470276    0.175799    0.012741    0.626762    
#> 112: 0.579596    0.940463    3.489271    0.457690    0.167009    0.012104    0.642617    
#> 113: 0.549792    0.987020    3.484997    0.471640    0.174946    0.011499    0.619429    
#> 114: 0.561896    0.970935    3.483173    0.470301    0.190267    0.012486    0.640321    
#> 115: 0.558646    0.951199    3.486640    0.446786    0.180754    0.011862    0.654781    
#> 116: 0.586910    0.959792    3.491267    0.432481    0.201765    0.014494    0.644582    
#> 117: 0.538719    0.973832    3.490657    0.414348    0.191677    0.013769    0.650581    
#> 118: 0.599870    0.971409    3.496713    0.491552    0.183417    0.013081    0.641186    
#> 119: 0.619315    0.954830    3.490704    0.639368    0.187374    0.015593    0.647866    
#> 120: 0.578522    0.959938    3.477673    0.607400    0.178005    0.014813    0.655868    
#> 121: 0.587630    0.998443    3.473969    0.577030    0.169105    0.015433    0.653661    
#> 122: 0.556417    0.945294    3.491375    0.548178    0.161584    0.015165    0.643824    
#> 123: 0.595052    0.984654    3.490607    0.520769    0.153505    0.015399    0.637427    
#> 124: 0.584477    0.988807    3.483006    0.504688    0.168605    0.015684    0.640347    
#> 125: 0.577193    0.992037    3.474840    0.480794    0.160175    0.016806    0.632522    
#> 126: 0.506495    0.997494    3.460321    0.475906    0.170179    0.015966    0.632903    
#> 127: 0.527529    0.965972    3.471820    0.452111    0.161670    0.015168    0.644089    
#> 128: 0.549028    0.955427    3.486588    0.488548    0.172671    0.016411    0.641296    
#> 129: 0.554060    0.987406    3.480292    0.532333    0.190175    0.015591    0.635596    
#> 130: 0.587509    0.993677    3.479087    0.505717    0.180667    0.014811    0.648329    
#> 131: 0.567655    0.972340    3.470929    0.488806    0.181303    0.016053    0.649499    
#> 132: 0.540264    0.972546    3.473276    0.464365    0.174413    0.015251    0.654606    
#> 133: 0.523528    0.954746    3.475093    0.475002    0.179959    0.014980    0.647941    
#> 134: 0.581524    0.927852    3.492838    0.481603    0.170961    0.018777    0.651785    
#> 135: 0.584268    0.937158    3.502678    0.457523    0.162413    0.018712    0.647464    
#> 136: 0.596770    0.924162    3.502811    0.473166    0.156746    0.017776    0.645155    
#> 137: 0.596501    0.958578    3.499440    0.451114    0.154829    0.016888    0.644988    
#> 138: 0.585166    0.966288    3.497824    0.428558    0.168794    0.016043    0.644384    
#> 139: 0.541292    0.955578    3.503804    0.407130    0.160354    0.015241    0.636015    
#> 140: 0.555617    0.969239    3.496819    0.453657    0.152337    0.019149    0.633212    
#> 141: 0.586000    0.950540    3.504838    0.464099    0.166865    0.020003    0.622944    
#> 142: 0.605919    0.945096    3.515748    0.450176    0.185162    0.019213    0.633785    
#> 143: 0.564464    0.983147    3.506442    0.476679    0.175904    0.018253    0.651625    
#> 144: 0.605928    0.951849    3.518491    0.452845    0.171911    0.017340    0.641263    
#> 145: 0.619408    0.967366    3.507229    0.430203    0.164426    0.016799    0.627999    
#> 146: 0.574270    0.955496    3.510398    0.408693    0.159874    0.018188    0.647856    
#> 147: 0.566750    0.936284    3.504318    0.393069    0.163894    0.017436    0.644167    
#> 148: 0.579665    0.944695    3.514142    0.412611    0.164385    0.019133    0.642249    
#> 149: 0.576014    0.936053    3.513757    0.419240    0.156165    0.024534    0.633352    
#> 150: 0.621765    0.936476    3.505740    0.436204    0.148357    0.023307    0.646163    
#> 151: 0.574105    0.961341    3.493929    0.414394    0.140939    0.022142    0.640690    
#> 152: 0.542882    0.973378    3.495552    0.472285    0.141837    0.023081    0.637415    
#> 153: 0.526734    0.977614    3.496260    0.479401    0.137534    0.020397    0.638500    
#> 154: 0.576680    0.979634    3.495043    0.456056    0.161933    0.018406    0.647566    
#> 155: 0.536692    0.973427    3.487349    0.436981    0.161495    0.016221    0.634787    
#> 156: 0.565038    0.964148    3.501512    0.398328    0.157689    0.018036    0.637722    
#> 157: 0.573379    0.955423    3.513519    0.356309    0.164987    0.018045    0.634041    
#> 158: 0.616585    0.979839    3.506334    0.396302    0.158131    0.014412    0.640551    
#> 159: 0.584437    0.987393    3.508022    0.393163    0.147139    0.015888    0.653229    
#> 160: 0.589052    0.934727    3.512995    0.420815    0.152575    0.015528    0.654062    
#> 161: 0.578490    0.953590    3.507797    0.357419    0.144945    0.015741    0.648454    
#> 162: 0.545780    0.947732    3.499102    0.347765    0.155916    0.013726    0.663245    
#> 163: 0.564760    0.955113    3.494167    0.431728    0.183977    0.013724    0.650162    
#> 164: 0.565194    0.947320    3.489428    0.455277    0.161570    0.012336    0.641259    
#> 165: 0.581041    0.942335    3.493136    0.392785    0.155195    0.012417    0.656641    
#> 166: 0.599126    0.994355    3.492122    0.432088    0.161097    0.015285    0.649038    
#> 167: 0.598596    0.973555    3.496216    0.463836    0.161021    0.017621    0.649075    
#> 168: 0.582318    0.968589    3.494335    0.469446    0.138945    0.014854    0.636943    
#> 169: 0.566527    1.002993    3.485855    0.446288    0.149506    0.013979    0.642415    
#> 170: 0.571176    0.967368    3.490039    0.394171    0.151661    0.015158    0.641591    
#> 171: 0.540847    0.969410    3.492884    0.391529    0.159570    0.015845    0.632402    
#> 172: 0.554288    0.993318    3.491251    0.438944    0.168404    0.015226    0.631651    
#> 173: 0.564985    0.988343    3.476753    0.372017    0.148660    0.012751    0.637943    
#> 174: 0.551212    0.973875    3.484488    0.373494    0.156967    0.011536    0.644928    
#> 175: 0.511352    0.953973    3.473233    0.445777    0.154840    0.014089    0.649480    
#> 176: 0.473680    1.015154    3.478108    0.320945    0.165949    0.013663    0.661107    
#> 177: 0.563087    0.983954    3.492984    0.415157    0.160482    0.012061    0.661467    
#> 178: 0.553533    0.952449    3.484912    0.437794    0.181909    0.011318    0.657181    
#> 179: 0.542046    1.017960    3.481164    0.462808    0.143930    0.012924    0.676043    
#> 180: 0.524968    0.992027    3.481079    0.353120    0.166228    0.014234    0.658393    
#> 181: 0.523865    0.993942    3.463460    0.387026    0.134820    0.014727    0.653760    
#> 182: 0.484911    0.985646    3.455736    0.327089    0.158721    0.015125    0.670110    
#> 183: 0.499003    1.023892    3.460821    0.341827    0.162229    0.012323    0.674684    
#> 184: 0.526041    0.992193    3.468384    0.390118    0.182514    0.012380    0.660057    
#> 185: 0.480699    0.994543    3.453343    0.456831    0.186328    0.011790    0.648449    
#> 186: 0.489705    1.009622    3.455364    0.475486    0.183094    0.012011    0.649410    
#> 187: 0.514237    0.996679    3.458724    0.529283    0.177351    0.009712    0.634610    
#> 188: 0.507075    0.980184    3.463205    0.565367    0.171787    0.008402    0.658776    
#> 189: 0.507021    0.975169    3.485202    0.468553    0.176710    0.006973    0.676331    
#> 190: 0.520946    0.971103    3.483156    0.440664    0.179986    0.006177    0.668795    
#> 191: 0.508630    0.977206    3.474568    0.388360    0.203146    0.006064    0.671189    
#> 192: 0.510182    0.996691    3.481844    0.408192    0.192934    0.007023    0.653912    
#> 193: 0.578346    0.985405    3.484411    0.454960    0.192905    0.009287    0.634266    
#> 194: 0.540513    0.960021    3.477238    0.443847    0.159950    0.010355    0.649064    
#> 195: 0.486604    0.957604    3.477332    0.435679    0.163895    0.010662    0.650168    
#> 196: 0.548370    0.964367    3.486705    0.441224    0.153091    0.011156    0.649525    
#> 197: 0.526131    0.965894    3.497501    0.351645    0.158354    0.012732    0.671886    
#> 198: 0.598135    0.936054    3.497627    0.466643    0.167763    0.015332    0.639875    
#> 199: 0.548072    0.966431    3.496717    0.396246    0.173094    0.018196    0.639847    
#> 200: 0.572737    0.964271    3.494136    0.437777    0.151846    0.015779    0.667381    
#> 201: 0.559410    0.959220    3.494854    0.452851    0.155237    0.017599    0.658076    
#> 202: 0.554272    0.962703    3.494150    0.455709    0.159867    0.017556    0.655247    
#> 203: 0.563996    0.961603    3.492031    0.456057    0.165285    0.017677    0.654525    
#> 204: 0.561513    0.954119    3.495603    0.438338    0.172016    0.017929    0.657854    
#> 205: 0.566914    0.959096    3.497080    0.434171    0.175157    0.018082    0.656711    
#> 206: 0.575485    0.959986    3.499047    0.443869    0.171480    0.018231    0.657404    
#> 207: 0.572885    0.958557    3.498792    0.440319    0.169773    0.018392    0.656415    
#> 208: 0.571156    0.958678    3.499315    0.428739    0.168109    0.018681    0.655965    
#> 209: 0.574372    0.957653    3.498229    0.434577    0.166166    0.018414    0.654481    
#> 210: 0.574023    0.955989    3.497801    0.432334    0.165086    0.018134    0.653238    
#> 211: 0.575728    0.956939    3.498210    0.433085    0.164832    0.017997    0.651320    
#> 212: 0.575916    0.956086    3.498079    0.433138    0.166274    0.017812    0.651189    
#> 213: 0.575364    0.957191    3.497824    0.429080    0.169497    0.017635    0.651463    
#> 214: 0.574888    0.956450    3.497960    0.426355    0.169458    0.017596    0.650940    
#> 215: 0.573577    0.956367    3.498314    0.421119    0.170098    0.017724    0.650929    
#> 216: 0.577753    0.954689    3.498824    0.422910    0.169126    0.017887    0.651860    
#> 217: 0.580181    0.955031    3.499332    0.427117    0.168846    0.017946    0.651126    
#> 218: 0.581901    0.955764    3.499217    0.427865    0.168874    0.017876    0.650756    
#> 219: 0.581819    0.956013    3.499024    0.426757    0.168081    0.017940    0.650701    
#> 220: 0.580657    0.957069    3.498595    0.427272    0.167396    0.018278    0.650458    
#> 221: 0.578703    0.958122    3.498196    0.427435    0.166310    0.018473    0.650109    
#> 222: 0.579130    0.957892    3.497743    0.430991    0.164580    0.018662    0.650149    
#> 223: 0.579875    0.957078    3.497494    0.434548    0.163083    0.018738    0.650210    
#> 224: 0.581333    0.957340    3.497782    0.438009    0.163270    0.018675    0.650530    
#> 225: 0.581677    0.955923    3.498023    0.439525    0.163220    0.018727    0.650110    
#> 226: 0.580629    0.955329    3.497782    0.441443    0.163287    0.018710    0.649611    
#> 227: 0.580474    0.955708    3.498037    0.441760    0.162992    0.018717    0.649314    
#> 228: 0.579320    0.955702    3.497623    0.441970    0.163099    0.018742    0.649490    
#> 229: 0.579594    0.955378    3.497417    0.443013    0.162745    0.018697    0.649585    
#> 230: 0.580033    0.955071    3.497325    0.443548    0.162773    0.018686    0.649667    
#> 231: 0.579827    0.955228    3.497551    0.441975    0.163335    0.018644    0.649286    
#> 232: 0.579705    0.955632    3.497781    0.442078    0.163610    0.018542    0.648666    
#> 233: 0.579084    0.955161    3.498011    0.440726    0.163553    0.018551    0.648604    
#> 234: 0.578792    0.955023    3.498023    0.439438    0.163051    0.018478    0.648453    
#> 235: 0.579123    0.955115    3.497994    0.438861    0.163611    0.018385    0.648384    
#> 236: 0.578728    0.955389    3.497906    0.436223    0.163898    0.018317    0.648621    
#> 237: 0.578889    0.955346    3.497927    0.433778    0.163482    0.018280    0.649690    
#> 238: 0.578640    0.954846    3.498211    0.431396    0.162841    0.018446    0.650326    
#> 239: 0.578491    0.954827    3.498201    0.430134    0.162526    0.018450    0.650354    
#> 240: 0.578921    0.953873    3.498551    0.429144    0.162437    0.018422    0.650331    
#> 241: 0.580046    0.952523    3.498986    0.429822    0.162171    0.018468    0.650585    
#> 242: 0.579392    0.951782    3.499082    0.428401    0.162129    0.018458    0.651189    
#> 243: 0.578799    0.952227    3.499039    0.428142    0.161926    0.018582    0.651322    
#> 244: 0.578223    0.952638    3.499179    0.426400    0.161712    0.018654    0.651493    
#> 245: 0.578176    0.951767    3.499486    0.424899    0.161284    0.018728    0.651891    
#> 246: 0.578502    0.951464    3.499637    0.424298    0.160960    0.018860    0.651971    
#> 247: 0.579117    0.951518    3.499964    0.424148    0.160139    0.018970    0.652150    
#> 248: 0.579398    0.951856    3.500150    0.424281    0.159932    0.019009    0.651804    
#> 249: 0.578741    0.952463    3.500025    0.424433    0.159770    0.019108    0.651387    
#> 250: 0.578585    0.952872    3.499847    0.424749    0.159075    0.019205    0.651456    
#> 251: 0.578939    0.953582    3.499813    0.425424    0.158615    0.019243    0.651405    
#> 252: 0.579320    0.953923    3.499906    0.426799    0.158171    0.019246    0.651115    
#> 253: 0.578553    0.954073    3.499890    0.427242    0.157613    0.019244    0.651334    
#> 254: 0.578123    0.954750    3.499720    0.427306    0.156927    0.019359    0.651371    
#> 255: 0.577761    0.955083    3.499507    0.426500    0.156345    0.019453    0.651348    
#> 256: 0.577281    0.955153    3.499322    0.426010    0.155927    0.019525    0.651173    
#> 257: 0.576409    0.955035    3.499108    0.426040    0.155682    0.019604    0.651005    
#> 258: 0.575864    0.954919    3.498938    0.427340    0.155535    0.019529    0.651102    
#> 259: 0.575339    0.955095    3.498719    0.427805    0.155490    0.019505    0.651055    
#> 260: 0.574477    0.955337    3.498641    0.427333    0.155520    0.019489    0.650826    
#> 261: 0.574454    0.955529    3.498636    0.426291    0.155443    0.019448    0.650612    
#> 262: 0.574313    0.955860    3.498686    0.425365    0.155533    0.019408    0.650545    
#> 263: 0.574158    0.956066    3.498674    0.425277    0.155245    0.019350    0.650661    
#> 264: 0.574191    0.955908    3.498627    0.425925    0.154986    0.019300    0.650716    
#> 265: 0.574655    0.956068    3.498819    0.426061    0.154714    0.019307    0.650746    
#> 266: 0.575035    0.956022    3.498845    0.426988    0.154741    0.019317    0.650743    
#> 267: 0.575137    0.956010    3.499042    0.428260    0.154680    0.019289    0.650937    
#> 268: 0.575872    0.955679    3.499122    0.429015    0.154748    0.019314    0.651054    
#> 269: 0.576811    0.955589    3.499165    0.429760    0.154702    0.019312    0.651065    
#> 270: 0.577412    0.955714    3.499091    0.430633    0.154605    0.019302    0.650843    
#> 271: 0.577560    0.955989    3.498943    0.430977    0.154524    0.019286    0.650813    
#> 272: 0.577652    0.955919    3.498889    0.430574    0.154301    0.019327    0.650930    
#> 273: 0.577362    0.956211    3.498726    0.430587    0.154156    0.019364    0.651004    
#> 274: 0.576746    0.956463    3.498611    0.430352    0.154141    0.019330    0.651162    
#> 275: 0.576151    0.956503    3.498381    0.429453    0.154266    0.019283    0.651112    
#> 276: 0.576022    0.956849    3.498427    0.429190    0.154236    0.019267    0.651007    
#> 277: 0.575999    0.957203    3.498537    0.429206    0.154003    0.019251    0.650874    
#> 278: 0.575902    0.957428    3.498642    0.429903    0.153781    0.019222    0.650957    
#> 279: 0.576164    0.957117    3.498686    0.431017    0.153615    0.019205    0.651339    
#> 280: 0.576088    0.956915    3.498753    0.431037    0.153777    0.019138    0.651359    
#> 281: 0.576050    0.957004    3.498826    0.431309    0.153843    0.019068    0.651205    
#> 282: 0.576340    0.957147    3.498864    0.431921    0.153833    0.019032    0.651132    
#> 283: 0.576296    0.957239    3.498794    0.432648    0.154115    0.019022    0.651392    
#> 284: 0.575925    0.957222    3.498650    0.432855    0.154047    0.019002    0.651465    
#> 285: 0.576146    0.957252    3.498604    0.432347    0.154134    0.019014    0.651570    
#> 286: 0.576396    0.957247    3.498616    0.431858    0.154010    0.019058    0.651717    
#> 287: 0.576456    0.957440    3.498490    0.432279    0.153871    0.019072    0.651664    
#> 288: 0.576426    0.957283    3.498544    0.431673    0.153642    0.019081    0.651829    
#> 289: 0.576357    0.957337    3.498531    0.430942    0.153446    0.019115    0.651935    
#> 290: 0.576599    0.957287    3.498507    0.430740    0.153441    0.019134    0.651971    
#> 291: 0.576883    0.957414    3.498636    0.431124    0.153538    0.019138    0.651672    
#> 292: 0.576743    0.957483    3.498620    0.431720    0.153597    0.019125    0.651580    
#> 293: 0.576906    0.957488    3.498657    0.431633    0.153446    0.019105    0.651576    
#> 294: 0.576671    0.957443    3.498641    0.431625    0.153276    0.019121    0.651390    
#> 295: 0.576519    0.957303    3.498516    0.431346    0.153312    0.019070    0.651313    
#> 296: 0.576256    0.957573    3.498364    0.430640    0.153489    0.019011    0.651347    
#> 297: 0.576252    0.957975    3.498185    0.430159    0.153733    0.018967    0.651498    
#> 298: 0.576244    0.958174    3.498098    0.430058    0.153853    0.018929    0.651398    
#> 299: 0.576107    0.958471    3.497989    0.429990    0.153788    0.018899    0.651242    
#> 300: 0.575826    0.958458    3.497928    0.429733    0.153780    0.018901    0.651033    
#> 301: 0.575833    0.958565    3.497835    0.429375    0.153627    0.018876    0.650878    
#> 302: 0.576217    0.958747    3.497752    0.429923    0.153494    0.018862    0.650765    
#> 303: 0.576396    0.958966    3.497691    0.430396    0.153475    0.018867    0.650594    
#> 304: 0.576097    0.959193    3.497479    0.431432    0.153393    0.018859    0.650526    
#> 305: 0.575634    0.959052    3.497287    0.432109    0.153268    0.018834    0.650434    
#> 306: 0.575102    0.959021    3.497113    0.432166    0.153241    0.018827    0.650326    
#> 307: 0.574751    0.959183    3.496935    0.431945    0.153264    0.018805    0.650385    
#> 308: 0.574313    0.959150    3.496791    0.431972    0.153266    0.018732    0.650520    
#> 309: 0.574169    0.959055    3.496677    0.432236    0.153317    0.018692    0.650618    
#> 310: 0.574153    0.958927    3.496598    0.432478    0.153135    0.018649    0.650677    
#> 311: 0.574173    0.958920    3.496642    0.433342    0.153138    0.018621    0.650758    
#> 312: 0.574010    0.958770    3.496647    0.433752    0.153186    0.018609    0.650774    
#> 313: 0.573844    0.958447    3.496665    0.433752    0.153201    0.018597    0.650899    
#> 314: 0.573528    0.958553    3.496585    0.433707    0.153143    0.018604    0.650917    
#> 315: 0.573208    0.958838    3.496522    0.433922    0.153138    0.018587    0.650843    
#> 316: 0.573024    0.959102    3.496447    0.433768    0.153098    0.018535    0.650788    
#> 317: 0.572741    0.959197    3.496479    0.433035    0.153157    0.018515    0.650895    
#> 318: 0.572508    0.959193    3.496418    0.432484    0.153282    0.018517    0.650842    
#> 319: 0.572421    0.959275    3.496360    0.432068    0.153206    0.018508    0.650867    
#> 320: 0.572032    0.959270    3.496255    0.432072    0.153267    0.018503    0.651109    
#> 321: 0.571578    0.959380    3.496127    0.431776    0.153439    0.018484    0.651149    
#> 322: 0.571519    0.959463    3.495942    0.431951    0.153290    0.018450    0.651171    
#> 323: 0.571067    0.959570    3.495822    0.432019    0.153219    0.018415    0.651080    
#> 324: 0.570886    0.959688    3.495759    0.432272    0.153090    0.018387    0.650830    
#> 325: 0.571062    0.959882    3.495662    0.432459    0.153075    0.018368    0.650679    
#> 326: 0.570943    0.959811    3.495574    0.432534    0.152937    0.018359    0.650598    
#> 327: 0.571048    0.959885    3.495532    0.433376    0.152811    0.018351    0.650507    
#> 328: 0.571240    0.960080    3.495498    0.433628    0.152730    0.018354    0.650346    
#> 329: 0.571439    0.960129    3.495492    0.433925    0.152638    0.018355    0.650199    
#> 330: 0.571110    0.960040    3.495477    0.433813    0.152600    0.018357    0.650180    
#> 331: 0.570935    0.960153    3.495438    0.433706    0.152687    0.018331    0.650136    
#> 332: 0.571026    0.960266    3.495470    0.433887    0.152911    0.018324    0.650131    
#> 333: 0.570842    0.960298    3.495320    0.434492    0.152985    0.018297    0.650095    
#> 334: 0.570325    0.960173    3.495130    0.434414    0.153003    0.018287    0.650146    
#> 335: 0.569883    0.960230    3.494944    0.434898    0.153039    0.018283    0.650131    
#> 336: 0.569189    0.960303    3.494767    0.434863    0.153041    0.018273    0.650181    
#> 337: 0.568698    0.960687    3.494579    0.435285    0.153094    0.018263    0.650140    
#> 338: 0.568337    0.960888    3.494426    0.435690    0.153169    0.018241    0.650137    
#> 339: 0.567963    0.961012    3.494264    0.435829    0.153333    0.018201    0.650094    
#> 340: 0.567593    0.960849    3.494131    0.436203    0.153441    0.018169    0.650034    
#> 341: 0.567484    0.960832    3.494165    0.436242    0.153593    0.018143    0.649968    
#> 342: 0.567301    0.960552    3.494142    0.436025    0.153580    0.018117    0.649977    
#> 343: 0.566802    0.960501    3.494088    0.436016    0.153651    0.018101    0.650076    
#> 344: 0.566690    0.960441    3.494096    0.435828    0.153645    0.018077    0.650139    
#> 345: 0.566618    0.960459    3.494169    0.435692    0.153540    0.018078    0.650278    
#> 346: 0.566530    0.960467    3.494112    0.435498    0.153571    0.018055    0.650286    
#> 347: 0.566619    0.960306    3.494057    0.435059    0.153617    0.018045    0.650340    
#> 348: 0.566574    0.960299    3.493964    0.435073    0.153604    0.018044    0.650360    
#> 349: 0.566481    0.960114    3.493920    0.435168    0.153635    0.018060    0.650283    
#> 350: 0.566280    0.960063    3.493822    0.435333    0.153746    0.018078    0.650289    
#> 351: 0.566137    0.960195    3.493722    0.435652    0.153740    0.018108    0.650221    
#> 352: 0.565830    0.960406    3.493615    0.435831    0.153650    0.018126    0.650313    
#> 353: 0.565813    0.960643    3.493607    0.435842    0.153747    0.018107    0.650223    
#> 354: 0.565738    0.960702    3.493513    0.436294    0.153933    0.018063    0.650131    
#> 355: 0.565896    0.960507    3.493471    0.436304    0.154080    0.018033    0.650120    
#> 356: 0.565693    0.960482    3.493444    0.435806    0.154015    0.018001    0.650229    
#> 357: 0.565785    0.960687    3.493433    0.435816    0.154028    0.017970    0.650317    
#> 358: 0.565770    0.960760    3.493438    0.435612    0.154013    0.017952    0.650249    
#> 359: 0.565588    0.960826    3.493359    0.435139    0.154049    0.017948    0.650238    
#> 360: 0.565470    0.960831    3.493278    0.434800    0.153949    0.017947    0.650154    
#> 361: 0.565331    0.960830    3.493233    0.434384    0.153908    0.017974    0.650013    
#> 362: 0.565270    0.960724    3.493201    0.434405    0.153933    0.017977    0.649852    
#> 363: 0.565094    0.960698    3.493160    0.434607    0.153900    0.017979    0.649652    
#> 364: 0.565161    0.960701    3.493116    0.434826    0.153891    0.017970    0.649687    
#> 365: 0.565202    0.960571    3.493183    0.434792    0.153804    0.017982    0.649678    
#> 366: 0.565154    0.960504    3.493197    0.434198    0.153621    0.017980    0.649763    
#> 367: 0.565356    0.960458    3.493238    0.434237    0.153425    0.017971    0.649740    
#> 368: 0.565532    0.960639    3.493195    0.434736    0.153423    0.017961    0.649647    
#> 369: 0.565642    0.960650    3.493206    0.435370    0.153384    0.017950    0.649669    
#> 370: 0.565563    0.960748    3.493169    0.435662    0.153432    0.017928    0.649684    
#> 371: 0.565501    0.960874    3.493037    0.435652    0.153477    0.017899    0.649703    
#> 372: 0.565257    0.961044    3.492908    0.435568    0.153426    0.017888    0.649721    
#> 373: 0.564660    0.961199    3.492729    0.435427    0.153387    0.017868    0.649782    
#> 374: 0.564482    0.961207    3.492633    0.435300    0.153362    0.017852    0.649737    
#> 375: 0.564349    0.961327    3.492606    0.435281    0.153321    0.017842    0.649705    
#> 376: 0.564260    0.961362    3.492550    0.434948    0.153272    0.017834    0.649636    
#> 377: 0.564102    0.961538    3.492487    0.434670    0.153343    0.017823    0.649564    
#> 378: 0.563861    0.961687    3.492418    0.434533    0.153263    0.017822    0.649471    
#> 379: 0.563543    0.961683    3.492323    0.434664    0.153139    0.017814    0.649403    
#> 380: 0.563365    0.961684    3.492255    0.434663    0.153069    0.017810    0.649303    
#> 381: 0.563194    0.961756    3.492187    0.435121    0.152983    0.017797    0.649255    
#> 382: 0.563026    0.961882    3.492157    0.434897    0.152895    0.017781    0.649147    
#> 383: 0.562846    0.962061    3.492147    0.434543    0.152872    0.017779    0.649120    
#> 384: 0.562702    0.962101    3.492140    0.434205    0.152908    0.017769    0.649234    
#> 385: 0.562798    0.962063    3.492156    0.434354    0.153067    0.017747    0.649228    
#> 386: 0.562867    0.962131    3.492168    0.434293    0.153288    0.017729    0.649160    
#> 387: 0.562903    0.962323    3.492174    0.434052    0.153279    0.017704    0.649172    
#> 388: 0.562989    0.962398    3.492176    0.434042    0.153414    0.017673    0.649116    
#> 389: 0.562923    0.962358    3.492129    0.434028    0.153495    0.017643    0.649145    
#> 390: 0.562714    0.962447    3.492064    0.434143    0.153516    0.017632    0.649182    
#> 391: 0.562685    0.962541    3.492002    0.434268    0.153580    0.017621    0.649087    
#> 392: 0.562528    0.962672    3.491923    0.434622    0.153657    0.017613    0.649093    
#> 393: 0.562238    0.962700    3.491812    0.434881    0.153754    0.017592    0.649119    
#> 394: 0.562249    0.962733    3.491802    0.434943    0.153780    0.017599    0.649196    
#> 395: 0.562509    0.962791    3.491831    0.434733    0.153826    0.017604    0.649205    
#> 396: 0.562687    0.962810    3.491827    0.434812    0.153796    0.017608    0.649173    
#> 397: 0.562642    0.962674    3.491826    0.435047    0.153834    0.017605    0.649211    
#> 398: 0.562660    0.962700    3.491804    0.435188    0.153827    0.017590    0.649243    
#> 399: 0.562657    0.962623    3.491864    0.435402    0.153844    0.017584    0.649216    
#> 400: 0.562754    0.962619    3.491906    0.435466    0.153789    0.017573    0.649233    
#> 401: 0.562743    0.962653    3.491912    0.435343    0.153807    0.017567    0.649300    
#> 402: 0.562702    0.962783    3.491878    0.435231    0.153804    0.017556    0.649330    
#> 403: 0.562945    0.962836    3.491850    0.435510    0.153728    0.017538    0.649329    
#> 404: 0.562992    0.962870    3.491793    0.435723    0.153680    0.017523    0.649253    
#> 405: 0.563063    0.962890    3.491821    0.435920    0.153689    0.017521    0.649226    
#> 406: 0.563206    0.962967    3.491801    0.436075    0.153835    0.017517    0.649241    
#> 407: 0.563185    0.962993    3.491803    0.436321    0.153918    0.017518    0.649164    
#> 408: 0.563295    0.963047    3.491766    0.436466    0.154011    0.017499    0.649092    
#> 409: 0.563199    0.962998    3.491714    0.436496    0.154056    0.017478    0.649008    
#> 410: 0.563159    0.963110    3.491637    0.436788    0.154138    0.017458    0.648977    
#> 411: 0.563133    0.963065    3.491612    0.437106    0.154110    0.017442    0.648955    
#> 412: 0.563069    0.963147    3.491591    0.436983    0.154027    0.017437    0.648971    
#> 413: 0.562912    0.963209    3.491550    0.436744    0.154058    0.017412    0.649050    
#> 414: 0.562811    0.963273    3.491518    0.436963    0.154139    0.017389    0.648961    
#> 415: 0.562917    0.963412    3.491453    0.436964    0.154223    0.017360    0.649009    
#> 416: 0.562824    0.963529    3.491401    0.436834    0.154233    0.017335    0.649038    
#> 417: 0.562868    0.963547    3.491354    0.437171    0.154181    0.017314    0.649072    
#> 418: 0.562663    0.963609    3.491312    0.437417    0.154139    0.017310    0.648983    
#> 419: 0.562591    0.963681    3.491248    0.437631    0.154105    0.017299    0.649004    
#> 420: 0.562706    0.963652    3.491248    0.437655    0.153975    0.017302    0.648929    
#> 421: 0.562684    0.963588    3.491303    0.437458    0.153896    0.017313    0.648957    
#> 422: 0.562903    0.963424    3.491346    0.437536    0.153946    0.017319    0.648954    
#> 423: 0.563185    0.963364    3.491389    0.437380    0.154020    0.017324    0.648885    
#> 424: 0.563104    0.963366    3.491371    0.436971    0.154009    0.017325    0.648875    
#> 425: 0.563191    0.963455    3.491350    0.436940    0.154058    0.017335    0.648874    
#> 426: 0.563423    0.963551    3.491393    0.437325    0.154036    0.017343    0.648816    
#> 427: 0.563382    0.963544    3.491423    0.437495    0.154038    0.017337    0.648785    
#> 428: 0.563344    0.963559    3.491424    0.437438    0.154007    0.017339    0.648743    
#> 429: 0.563280    0.963567    3.491442    0.437570    0.153945    0.017345    0.648696    
#> 430: 0.563167    0.963661    3.491403    0.437447    0.153904    0.017352    0.648718    
#> 431: 0.563052    0.963679    3.491369    0.437179    0.153850    0.017348    0.648690    
#> 432: 0.562833    0.963763    3.491330    0.437103    0.153789    0.017343    0.648642    
#> 433: 0.562761    0.963859    3.491314    0.437003    0.153849    0.017341    0.648596    
#> 434: 0.562608    0.963833    3.491267    0.436982    0.153974    0.017322    0.648550    
#> 435: 0.562616    0.963875    3.491247    0.436841    0.153977    0.017314    0.648496    
#> 436: 0.562600    0.963793    3.491320    0.436729    0.153975    0.017315    0.648523    
#> 437: 0.562538    0.963598    3.491352    0.436637    0.153983    0.017317    0.648547    
#> 438: 0.562422    0.963654    3.491333    0.436658    0.153856    0.017296    0.648564    
#> 439: 0.562389    0.963765    3.491304    0.436729    0.153892    0.017284    0.648499    
#> 440: 0.562285    0.963813    3.491307    0.436424    0.153918    0.017272    0.648493    
#> 441: 0.562431    0.963746    3.491312    0.436429    0.153924    0.017264    0.648455    
#> 442: 0.562325    0.963830    3.491316    0.436441    0.153861    0.017272    0.648389    
#> 443: 0.562376    0.963948    3.491269    0.436625    0.153754    0.017280    0.648350    
#> 444: 0.562135    0.964101    3.491158    0.436380    0.153603    0.017288    0.648359    
#> 445: 0.561896    0.964188    3.491079    0.436626    0.153500    0.017286    0.648379    
#> 446: 0.561581    0.964345    3.490997    0.436757    0.153440    0.017277    0.648354    
#> 447: 0.561670    0.964386    3.490988    0.436848    0.153439    0.017265    0.648309    
#> 448: 0.561687    0.964340    3.491020    0.436868    0.153387    0.017265    0.648237    
#> 449: 0.561793    0.964369    3.491119    0.436685    0.153381    0.017260    0.648240    
#> 450: 0.561895    0.964294    3.491125    0.436809    0.153393    0.017243    0.648335    
#> 451: 0.562064    0.964224    3.491110    0.437350    0.153395    0.017230    0.648389    
#> 452: 0.562095    0.964269    3.491086    0.437741    0.153404    0.017219    0.648398    
#> 453: 0.561987    0.964280    3.491027    0.437837    0.153388    0.017196    0.648365    
#> 454: 0.561826    0.964447    3.490961    0.437990    0.153402    0.017184    0.648359    
#> 455: 0.561915    0.964570    3.490922    0.438348    0.153484    0.017169    0.648328    
#> 456: 0.561803    0.964613    3.490866    0.438513    0.153601    0.017156    0.648257    
#> 457: 0.561807    0.964648    3.490881    0.438625    0.153632    0.017148    0.648179    
#> 458: 0.561847    0.964804    3.490922    0.438684    0.153628    0.017137    0.648097    
#> 459: 0.561785    0.964952    3.490902    0.438594    0.153639    0.017126    0.648061    
#> 460: 0.561626    0.965038    3.490816    0.438408    0.153692    0.017111    0.648108    
#> 461: 0.561495    0.965089    3.490779    0.438655    0.153620    0.017106    0.648163    
#> 462: 0.561420    0.965104    3.490804    0.438611    0.153599    0.017100    0.648196    
#> 463: 0.561395    0.965111    3.490855    0.438327    0.153587    0.017104    0.648144    
#> 464: 0.561448    0.965094    3.490891    0.438018    0.153584    0.017111    0.648075    
#> 465: 0.561499    0.965046    3.490933    0.437728    0.153621    0.017114    0.648012    
#> 466: 0.561589    0.965114    3.490907    0.437595    0.153618    0.017117    0.647975    
#> 467: 0.561532    0.965076    3.490908    0.437317    0.153591    0.017124    0.647917    
#> 468: 0.561689    0.965119    3.490921    0.437510    0.153575    0.017115    0.647921    
#> 469: 0.561695    0.965247    3.490933    0.437683    0.153561    0.017114    0.647945    
#> 470: 0.561692    0.965336    3.490883    0.437868    0.153483    0.017117    0.647989    
#> 471: 0.561721    0.965333    3.490889    0.438144    0.153508    0.017109    0.648017    
#> 472: 0.561757    0.965260    3.490882    0.438227    0.153469    0.017092    0.648031    
#> 473: 0.561751    0.965202    3.490903    0.438089    0.153487    0.017097    0.647971    
#> 474: 0.561780    0.965217    3.490923    0.438033    0.153494    0.017100    0.647956    
#> 475: 0.561834    0.965257    3.490964    0.437792    0.153476    0.017114    0.647945    
#> 476: 0.561928    0.965184    3.490996    0.438012    0.153501    0.017114    0.647972    
#> 477: 0.561952    0.965073    3.491046    0.438174    0.153516    0.017121    0.647894    
#> 478: 0.561929    0.965097    3.491054    0.438276    0.153598    0.017118    0.647911    
#> 479: 0.561999    0.965165    3.491058    0.438298    0.153599    0.017107    0.647925    
#> 480: 0.561988    0.965104    3.491071    0.438029    0.153563    0.017124    0.647897    
#> 481: 0.562045    0.965071    3.491096    0.437836    0.153539    0.017133    0.647870    
#> 482: 0.562160    0.965003    3.491103    0.437925    0.153496    0.017139    0.647870    
#> 483: 0.562155    0.964854    3.491127    0.438198    0.153440    0.017148    0.647831    
#> 484: 0.562332    0.964764    3.491186    0.438414    0.153444    0.017162    0.647820    
#> 485: 0.562470    0.964726    3.491218    0.438786    0.153377    0.017173    0.647801    
#> 486: 0.562525    0.964729    3.491268    0.438718    0.153301    0.017180    0.647736    
#> 487: 0.562795    0.964673    3.491371    0.438752    0.153209    0.017199    0.647709    
#> 488: 0.562914    0.964623    3.491494    0.438688    0.153218    0.017217    0.647750    
#> 489: 0.563084    0.964576    3.491561    0.438484    0.153156    0.017242    0.647800    
#> 490: 0.563196    0.964549    3.491581    0.438571    0.153156    0.017240    0.647772    
#> 491: 0.563344    0.964571    3.491663    0.438651    0.153152    0.017250    0.647675    
#> 492: 0.563441    0.964622    3.491688    0.438860    0.153201    0.017255    0.647654    
#> 493: 0.563411    0.964704    3.491688    0.438727    0.153212    0.017252    0.647645    
#> 494: 0.563455    0.964757    3.491669    0.438644    0.153248    0.017247    0.647600    
#> 495: 0.563493    0.964772    3.491700    0.438544    0.153266    0.017245    0.647612    
#> 496: 0.563564    0.964854    3.491677    0.438469    0.153272    0.017243    0.647629    
#> 497: 0.563559    0.964847    3.491678    0.438582    0.153240    0.017247    0.647656    
#> 498: 0.563590    0.964818    3.491683    0.438654    0.153249    0.017243    0.647582    
#> 499: 0.563709    0.964783    3.491684    0.438865    0.153249    0.017227    0.647524    
#> 500: 0.563821    0.964733    3.491681    0.438932    0.153282    0.017217    0.647488    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.286905    0.971172    3.437842    0.392401    0.081111    0.016800    1.686151    
#> 002: 0.316611    0.952474    3.454955    0.372781    0.077055    0.015960    1.108915    
#> 003: 0.399960    0.914416    3.443526    0.366450    0.076520    0.015162    0.904402    
#> 004: 0.385736    0.899274    3.451029    0.396063    0.072694    0.014404    0.864027    
#> 005: 0.433676    0.919244    3.439729    0.399525    0.081267    0.013684    0.791663    
#> 006: 0.441651    0.946859    3.431763    0.422356    0.091547    0.013000    0.764176    
#> 007: 0.405293    0.955619    3.427302    0.565055    0.086969    0.012350    0.769553    
#> 008: 0.392059    0.920927    3.420810    0.536802    0.082621    0.011882    0.767608    
#> 009: 0.379160    0.915206    3.417708    0.510468    0.080617    0.011695    0.765045    
#> 010: 0.397798    0.917002    3.417882    0.680016    0.077996    0.014595    0.753624    
#> 011: 0.416860    0.921690    3.421494    0.646015    0.075329    0.015815    0.771212    
#> 012: 0.430802    0.931909    3.417200    0.702134    0.078783    0.015024    0.762657    
#> 013: 0.360317    0.945751    3.405713    0.667028    0.074844    0.014273    0.786107    
#> 014: 0.445103    0.934680    3.427594    0.633676    0.102869    0.013559    0.779936    
#> 015: 0.466000    0.960485    3.443529    0.601992    0.097726    0.012881    0.739460    
#> 016: 0.474091    0.942456    3.449023    0.585357    0.098187    0.012237    0.753044    
#> 017: 0.455957    0.947051    3.444886    0.626255    0.095868    0.011625    0.749627    
#> 018: 0.489754    0.949237    3.426405    0.594942    0.095409    0.011044    0.768996    
#> 019: 0.473797    0.947473    3.428498    0.677687    0.090639    0.010492    0.758619    
#> 020: 0.470945    0.939604    3.439631    0.643803    0.086107    0.009967    0.751273    
#> 021: 0.472420    0.925728    3.449723    0.611613    0.082742    0.012853    0.724731    
#> 022: 0.415585    0.912781    3.456209    0.581032    0.094618    0.012210    0.739535    
#> 023: 0.533386    0.931603    3.455861    0.651691    0.093657    0.011600    0.756272    
#> 024: 0.529709    0.955395    3.449207    0.713982    0.088974    0.011259    0.748525    
#> 025: 0.505880    0.926908    3.439466    0.794073    0.084525    0.010696    0.742938    
#> 026: 0.467587    0.959593    3.431742    0.754370    0.080299    0.010287    0.770338    
#> 027: 0.460626    0.959970    3.433286    0.716651    0.088008    0.010941    0.768079    
#> 028: 0.462779    0.957569    3.422563    0.796566    0.083607    0.011984    0.748105    
#> 029: 0.483483    0.969191    3.416757    0.856668    0.087453    0.013036    0.769533    
#> 030: 0.518378    0.986241    3.420175    0.949343    0.083081    0.014234    0.767850    
#> 031: 0.478883    0.961016    3.427668    0.963077    0.078927    0.014250    0.740171    
#> 032: 0.444236    0.936528    3.431117    0.914923    0.074980    0.014307    0.725685    
#> 033: 0.442919    0.944260    3.427431    0.869177    0.081739    0.013592    0.716992    
#> 034: 0.487085    0.945414    3.430555    0.825718    0.083040    0.012912    0.737307    
#> 035: 0.421407    0.923728    3.427444    0.784432    0.078888    0.012267    0.743324    
#> 036: 0.462199    0.942965    3.427102    0.745211    0.101792    0.012209    0.742039    
#> 037: 0.456933    0.951872    3.430787    0.707950    0.104780    0.014632    0.758342    
#> 038: 0.498125    0.946028    3.435753    0.672553    0.099541    0.016270    0.749243    
#> 039: 0.475095    0.929620    3.440956    0.638925    0.100636    0.015710    0.746945    
#> 040: 0.474844    0.950189    3.439999    0.681654    0.095604    0.014925    0.757606    
#> 041: 0.486237    0.931331    3.444919    0.747974    0.090824    0.014179    0.737857    
#> 042: 0.546652    0.922353    3.449218    0.863677    0.086283    0.013470    0.729886    
#> 043: 0.459208    0.940314    3.434198    0.820493    0.081969    0.012796    0.728409    
#> 044: 0.491349    0.942732    3.437946    0.779469    0.077870    0.012156    0.733633    
#> 045: 0.523523    0.977424    3.425835    0.850976    0.079009    0.011549    0.731084    
#> 046: 0.493491    0.951116    3.425443    0.808427    0.092056    0.011456    0.719721    
#> 047: 0.484240    0.948837    3.422216    0.814923    0.089415    0.012161    0.730475    
#> 048: 0.431667    0.963851    3.412668    0.774177    0.089321    0.011964    0.729334    
#> 049: 0.417963    0.962992    3.419456    0.735468    0.098038    0.011365    0.744019    
#> 050: 0.490032    0.901763    3.430637    0.768051    0.093136    0.010797    0.765877    
#> 051: 0.442380    0.923211    3.425631    0.736428    0.118869    0.010257    0.745670    
#> 052: 0.484318    0.935155    3.438909    0.699607    0.112925    0.009744    0.728695    
#> 053: 0.401864    0.940129    3.438093    0.664626    0.125971    0.009257    0.750784    
#> 054: 0.386430    0.929013    3.427672    0.631395    0.119673    0.008794    0.754816    
#> 055: 0.401438    0.936936    3.425280    0.599825    0.113689    0.008355    0.768400    
#> 056: 0.424345    0.907219    3.438340    0.569834    0.108005    0.008068    0.792184    
#> 057: 0.470487    0.909305    3.451718    0.541342    0.102604    0.009132    0.789398    
#> 058: 0.442970    0.925048    3.441585    0.514275    0.097474    0.009587    0.773718    
#> 059: 0.419876    0.896791    3.440737    0.560816    0.099258    0.010074    0.784169    
#> 060: 0.434368    0.895942    3.445191    0.532775    0.125798    0.009570    0.778629    
#> 061: 0.464194    0.921000    3.446705    0.506136    0.119508    0.009091    0.787970    
#> 062: 0.444753    0.927640    3.447458    0.616996    0.113533    0.011418    0.797955    
#> 063: 0.487851    0.882250    3.450055    0.593091    0.107856    0.010847    0.789492    
#> 064: 0.459973    0.912274    3.445109    0.599872    0.102463    0.010331    0.747611    
#> 065: 0.508588    0.904097    3.440735    0.600396    0.097340    0.009814    0.751149    
#> 066: 0.501491    0.938560    3.446006    0.607006    0.092473    0.009324    0.756041    
#> 067: 0.461318    0.914706    3.440848    0.583116    0.087849    0.008858    0.756265    
#> 068: 0.420044    0.938701    3.446441    0.594051    0.102807    0.008415    0.764569    
#> 069: 0.463511    0.929093    3.440555    0.564349    0.105692    0.008582    0.764033    
#> 070: 0.447223    0.915353    3.452814    0.536131    0.100408    0.010684    0.755617    
#> 071: 0.412062    0.942409    3.431673    0.509325    0.095387    0.010150    0.780785    
#> 072: 0.399913    0.901736    3.433248    0.483858    0.090618    0.009642    0.773995    
#> 073: 0.484355    0.908164    3.445094    0.647167    0.124138    0.009160    0.762988    
#> 074: 0.469051    0.904184    3.449728    0.614809    0.117931    0.008702    0.744436    
#> 075: 0.453274    0.905352    3.459703    0.598690    0.112035    0.008460    0.752891    
#> 076: 0.517878    0.932378    3.474154    0.568755    0.106433    0.010773    0.752134    
#> 077: 0.539599    0.913951    3.453316    0.540317    0.101111    0.011016    0.764561    
#> 078: 0.495083    0.922772    3.452711    0.685565    0.096056    0.011896    0.754237    
#> 079: 0.514936    0.947647    3.454602    0.689622    0.124789    0.013073    0.750935    
#> 080: 0.489537    0.925251    3.454447    0.655141    0.118549    0.015799    0.758434    
#> 081: 0.485246    0.937554    3.444959    0.622384    0.112622    0.015727    0.738792    
#> 082: 0.461217    0.919779    3.454387    0.591265    0.106991    0.015682    0.762950    
#> 083: 0.494097    0.938865    3.459580    0.618673    0.101641    0.014898    0.763066    
#> 084: 0.451047    0.944424    3.438117    0.587739    0.098153    0.014153    0.748659    
#> 085: 0.446766    0.950206    3.448296    0.558352    0.093245    0.013446    0.744697    
#> 086: 0.459909    0.949931    3.445793    0.530435    0.092731    0.014182    0.749806    
#> 087: 0.455364    0.939128    3.437533    0.503913    0.093932    0.013857    0.755953    
#> 088: 0.397336    0.926648    3.437321    0.478717    0.099000    0.013164    0.759573    
#> 089: 0.389787    0.938828    3.425614    0.454782    0.094050    0.014490    0.757021    
#> 090: 0.367954    0.946666    3.420143    0.432042    0.090540    0.013766    0.778143    
#> 091: 0.375886    0.931334    3.408678    0.410440    0.100144    0.013078    0.774867    
#> 092: 0.383953    0.967702    3.411663    0.463350    0.102020    0.012424    0.773445    
#> 093: 0.359767    0.951998    3.411791    0.480317    0.096919    0.014803    0.766189    
#> 094: 0.399663    0.963781    3.411654    0.515406    0.095589    0.014063    0.771097    
#> 095: 0.396593    0.960139    3.432245    0.516831    0.090810    0.017343    0.743239    
#> 096: 0.381835    0.958992    3.431132    0.528261    0.112351    0.016476    0.736735    
#> 097: 0.421909    0.983399    3.417613    0.518042    0.106733    0.015652    0.743664    
#> 098: 0.451361    0.967081    3.433521    0.534815    0.101397    0.014870    0.751955    
#> 099: 0.458233    0.939734    3.428049    0.632815    0.120772    0.014126    0.746388    
#> 100: 0.470593    0.924177    3.433533    0.607100    0.114734    0.013420    0.750677    
#> 101: 0.394452    0.927292    3.422338    0.576745    0.108997    0.012749    0.743985    
#> 102: 0.393880    0.928547    3.406701    0.547908    0.103547    0.012111    0.752006    
#> 103: 0.426808    0.947895    3.419833    0.539021    0.100695    0.011506    0.737932    
#> 104: 0.443459    0.975088    3.428377    0.596924    0.105802    0.010931    0.730118    
#> 105: 0.453417    0.960148    3.423238    0.683961    0.100512    0.010384    0.738754    
#> 106: 0.466977    0.947476    3.423595    0.649763    0.095486    0.009865    0.739980    
#> 107: 0.492841    0.959093    3.426467    0.748405    0.090712    0.009372    0.739947    
#> 108: 0.467466    0.951675    3.418113    0.771352    0.086176    0.008903    0.767865    
#> 109: 0.445643    0.954509    3.426759    0.732784    0.099868    0.008458    0.756155    
#> 110: 0.454517    0.943975    3.423257    0.696145    0.097372    0.008260    0.733264    
#> 111: 0.409045    0.956045    3.429211    0.661338    0.094017    0.007847    0.739490    
#> 112: 0.399589    0.926934    3.417995    0.628271    0.089316    0.007455    0.757573    
#> 113: 0.376552    0.966938    3.419093    0.596857    0.094389    0.007082    0.735946    
#> 114: 0.448192    0.951957    3.421210    0.663980    0.100144    0.006728    0.741178    
#> 115: 0.475185    0.936500    3.417116    0.778686    0.096232    0.007136    0.741002    
#> 116: 0.484143    0.938547    3.428827    0.739752    0.094024    0.009384    0.737271    
#> 117: 0.451065    0.957175    3.440378    0.702764    0.089323    0.009124    0.759514    
#> 118: 0.476895    0.937287    3.438865    0.667626    0.085567    0.009076    0.749734    
#> 119: 0.466517    0.945674    3.442405    0.634245    0.082062    0.011428    0.763318    
#> 120: 0.458823    0.925487    3.433158    0.617659    0.077959    0.012436    0.750484    
#> 121: 0.481386    0.970482    3.432054    0.590915    0.087550    0.011814    0.774079    
#> 122: 0.439284    0.941316    3.441759    0.561369    0.096275    0.011224    0.783112    
#> 123: 0.478529    0.966979    3.439823    0.533301    0.091461    0.010662    0.789058    
#> 124: 0.460798    0.990688    3.428345    0.625459    0.091554    0.010129    0.752930    
#> 125: 0.443018    0.980113    3.412785    0.714042    0.099851    0.009623    0.748601    
#> 126: 0.433193    0.986679    3.398648    0.678340    0.097917    0.009142    0.759570    
#> 127: 0.446854    0.951147    3.404257    0.778448    0.098064    0.008685    0.765610    
#> 128: 0.429089    0.942396    3.407049    0.795022    0.112498    0.008250    0.755711    
#> 129: 0.439478    0.945916    3.413491    0.755271    0.114086    0.007838    0.769437    
#> 130: 0.422780    0.966050    3.413576    0.717507    0.126642    0.007446    0.759277    
#> 131: 0.413224    0.947191    3.409620    0.681632    0.120310    0.007074    0.755715    
#> 132: 0.380312    0.961112    3.393901    0.647550    0.114294    0.006720    0.788173    
#> 133: 0.341984    0.936106    3.399568    0.615173    0.108580    0.006384    0.766024    
#> 134: 0.410164    0.950632    3.402003    0.663160    0.103151    0.006065    0.743563    
#> 135: 0.435657    0.950018    3.413537    0.630002    0.114570    0.005762    0.755093    
#> 136: 0.394021    0.939076    3.409698    0.612017    0.108842    0.005473    0.752680    
#> 137: 0.477143    0.945848    3.417335    0.616381    0.124635    0.005200    0.781431    
#> 138: 0.447736    0.965135    3.417837    0.635038    0.118403    0.004940    0.759378    
#> 139: 0.438816    0.945842    3.429429    0.603286    0.122498    0.004693    0.781676    
#> 140: 0.431193    0.923130    3.436899    0.573122    0.128419    0.005019    0.777905    
#> 141: 0.439938    0.931272    3.440690    0.544466    0.131100    0.004769    0.758802    
#> 142: 0.467841    0.908593    3.443763    0.573413    0.129143    0.004530    0.756105    
#> 143: 0.451097    0.940715    3.451615    0.562934    0.122686    0.004304    0.757651    
#> 144: 0.499405    0.927147    3.458168    0.539314    0.116551    0.004088    0.768520    
#> 145: 0.446705    0.936801    3.445525    0.537115    0.110724    0.003884    0.751737    
#> 146: 0.437621    0.931401    3.446619    0.595901    0.122006    0.003690    0.758654    
#> 147: 0.403328    0.912471    3.441622    0.566106    0.115950    0.003505    0.746497    
#> 148: 0.418265    0.939906    3.446426    0.537800    0.110153    0.003854    0.740759    
#> 149: 0.428860    0.933570    3.434631    0.510910    0.104645    0.004838    0.766587    
#> 150: 0.461964    0.931887    3.432057    0.485365    0.099413    0.005287    0.771807    
#> 151: 0.410964    0.967007    3.420175    0.519732    0.107782    0.005195    0.758653    
#> 152: 0.374559    0.951124    3.415557    0.607375    0.100942    0.004519    0.767660    
#> 153: 0.395495    0.954950    3.414113    0.575731    0.081682    0.004985    0.769216    
#> 154: 0.401738    0.957894    3.420144    0.503530    0.097947    0.005712    0.766442    
#> 155: 0.402525    0.936023    3.425912    0.453487    0.085762    0.005960    0.744380    
#> 156: 0.444898    0.934327    3.447201    0.479000    0.106787    0.006364    0.760080    
#> 157: 0.477686    0.904736    3.457654    0.608063    0.110320    0.006023    0.775068    
#> 158: 0.500539    0.939716    3.457606    0.572751    0.088062    0.006290    0.771592    
#> 159: 0.439118    0.937458    3.456289    0.578360    0.107297    0.006405    0.777199    
#> 160: 0.489472    0.888189    3.455928    0.597458    0.093227    0.007402    0.760394    
#> 161: 0.462330    0.923163    3.441848    0.665218    0.093859    0.007668    0.751619    
#> 162: 0.422808    0.947529    3.426862    0.565827    0.101471    0.006389    0.762260    
#> 163: 0.430801    0.937506    3.423125    0.526144    0.140716    0.006731    0.748659    
#> 164: 0.451598    0.939558    3.425793    0.558333    0.111099    0.006915    0.746049    
#> 165: 0.433142    0.929384    3.427762    0.599698    0.100034    0.006932    0.736316    
#> 166: 0.456954    0.956855    3.422232    0.599095    0.099940    0.006962    0.730803    
#> 167: 0.438507    0.961184    3.431906    0.580116    0.096464    0.008372    0.742094    
#> 168: 0.478959    0.968815    3.436757    0.675395    0.100210    0.007504    0.741282    
#> 169: 0.441986    0.981636    3.425510    0.533836    0.099331    0.006443    0.758715    
#> 170: 0.440085    0.959288    3.424614    0.617899    0.099292    0.008413    0.750756    
#> 171: 0.400243    0.958434    3.419986    0.491081    0.085466    0.008701    0.745078    
#> 172: 0.377677    0.960893    3.426706    0.481695    0.108111    0.007153    0.738335    
#> 173: 0.410512    0.957443    3.411870    0.619151    0.095789    0.007892    0.728890    
#> 174: 0.429242    0.961786    3.416844    0.603808    0.086283    0.008938    0.734995    
#> 175: 0.399237    0.966677    3.408344    0.521993    0.091027    0.008756    0.750779    
#> 176: 0.421592    0.982675    3.417185    0.541150    0.094490    0.008448    0.730767    
#> 177: 0.409251    0.957203    3.421069    0.534822    0.068990    0.010313    0.739957    
#> 178: 0.411162    0.943853    3.422042    0.503035    0.089668    0.008153    0.754833    
#> 179: 0.495986    0.981718    3.428761    0.653652    0.087882    0.010468    0.752212    
#> 180: 0.414131    0.964694    3.431236    0.518289    0.096495    0.008676    0.746523    
#> 181: 0.406088    0.963354    3.410520    0.526420    0.077279    0.008328    0.771165    
#> 182: 0.355540    0.974453    3.403578    0.559700    0.075905    0.009223    0.791135    
#> 183: 0.416043    0.981573    3.412962    0.558413    0.077728    0.009448    0.761290    
#> 184: 0.396482    0.945521    3.422652    0.506095    0.087967    0.008911    0.734401    
#> 185: 0.411244    0.964243    3.424765    0.512347    0.106532    0.010032    0.740113    
#> 186: 0.409991    0.964218    3.429439    0.532795    0.096525    0.010917    0.752058    
#> 187: 0.426668    0.950256    3.440578    0.578911    0.090226    0.009676    0.745262    
#> 188: 0.375878    0.955600    3.432871    0.446595    0.107905    0.008851    0.758523    
#> 189: 0.416050    0.951666    3.436001    0.559967    0.088369    0.010351    0.778509    
#> 190: 0.391467    0.934847    3.441015    0.462858    0.073105    0.011605    0.747589    
#> 191: 0.414055    0.954260    3.427481    0.570991    0.074048    0.011508    0.735875    
#> 192: 0.417142    0.964886    3.433204    0.648605    0.073360    0.011171    0.739330    
#> 193: 0.507011    0.965090    3.431121    0.799369    0.084979    0.007541    0.730295    
#> 194: 0.458139    0.958469    3.423451    0.705986    0.074460    0.010659    0.752693    
#> 195: 0.372939    0.959469    3.416176    0.611981    0.073685    0.014728    0.737587    
#> 196: 0.416438    0.961172    3.417229    0.606604    0.091436    0.011426    0.761077    
#> 197: 0.387865    0.947712    3.441123    0.549216    0.100979    0.011350    0.761826    
#> 198: 0.461085    0.927438    3.428827    0.685514    0.106894    0.010893    0.743465    
#> 199: 0.408799    0.929572    3.427387    0.622020    0.089231    0.012433    0.738429    
#> 200: 0.391782    0.941789    3.424792    0.664086    0.088280    0.010582    0.756622    
#> 201: 0.402719    0.938164    3.424830    0.676273    0.092533    0.010492    0.760360    
#> 202: 0.423471    0.936748    3.425916    0.748941    0.094564    0.010308    0.756039    
#> 203: 0.442885    0.936582    3.424671    0.791725    0.094883    0.010573    0.751509    
#> 204: 0.453229    0.929036    3.426640    0.823710    0.100456    0.010256    0.751187    
#> 205: 0.466298    0.934264    3.427822    0.842126    0.101966    0.010239    0.754177    
#> 206: 0.466180    0.939837    3.427353    0.849833    0.101296    0.010242    0.753739    
#> 207: 0.469538    0.942921    3.425187    0.870218    0.101706    0.010050    0.754709    
#> 208: 0.468965    0.945304    3.423803    0.866285    0.102000    0.009878    0.753210    
#> 209: 0.471659    0.944984    3.423673    0.864162    0.100857    0.009739    0.751731    
#> 210: 0.471460    0.943121    3.424540    0.853575    0.101060    0.009546    0.751013    
#> 211: 0.471980    0.943727    3.425406    0.836912    0.101715    0.009433    0.749266    
#> 212: 0.472115    0.942096    3.426096    0.818350    0.102236    0.009262    0.748479    
#> 213: 0.471282    0.939554    3.426094    0.802157    0.103668    0.009104    0.749630    
#> 214: 0.470112    0.938540    3.425940    0.791033    0.102783    0.008850    0.749971    
#> 215: 0.467575    0.939609    3.425656    0.779478    0.102783    0.008702    0.749172    
#> 216: 0.467087    0.938928    3.425430    0.767509    0.102753    0.008793    0.748609    
#> 217: 0.464257    0.940950    3.424868    0.759309    0.103207    0.008852    0.746908    
#> 218: 0.462450    0.942492    3.424039    0.752449    0.104722    0.008808    0.746190    
#> 219: 0.458288    0.943921    3.422718    0.747126    0.104982    0.008802    0.746207    
#> 220: 0.453228    0.945280    3.421857    0.748147    0.105277    0.008749    0.746387    
#> 221: 0.449814    0.946181    3.420839    0.746280    0.106189    0.008677    0.746044    
#> 222: 0.448145    0.947136    3.419980    0.741994    0.106603    0.008664    0.745869    
#> 223: 0.449943    0.947317    3.419594    0.745305    0.106970    0.008638    0.745333    
#> 224: 0.452311    0.947689    3.419728    0.746468    0.106266    0.008554    0.745661    
#> 225: 0.452333    0.946300    3.420133    0.748233    0.105750    0.008587    0.745942    
#> 226: 0.452013    0.945250    3.420143    0.744628    0.106208    0.008558    0.746298    
#> 227: 0.451755    0.945130    3.420477    0.738036    0.105908    0.008509    0.746921    
#> 228: 0.449384    0.945917    3.420206    0.734277    0.105534    0.008501    0.746951    
#> 229: 0.448113    0.945705    3.419978    0.728606    0.105267    0.008488    0.747034    
#> 230: 0.447371    0.945876    3.419728    0.723671    0.105068    0.008488    0.747111    
#> 231: 0.445270    0.947003    3.419617    0.719793    0.105073    0.008465    0.747359    
#> 232: 0.442810    0.947269    3.419721    0.716124    0.104575    0.008581    0.747663    
#> 233: 0.442326    0.946682    3.419782    0.718896    0.104603    0.008721    0.748226    
#> 234: 0.441527    0.946555    3.419922    0.716986    0.104270    0.008807    0.748172    
#> 235: 0.441622    0.946579    3.420039    0.712483    0.104311    0.008870    0.748083    
#> 236: 0.442371    0.946501    3.419952    0.712684    0.103908    0.008877    0.748168    
#> 237: 0.442609    0.946224    3.419904    0.709723    0.103294    0.008897    0.748955    
#> 238: 0.442515    0.945846    3.419973    0.709062    0.102639    0.008978    0.749189    
#> 239: 0.442266    0.946254    3.420024    0.706040    0.102201    0.009036    0.749429    
#> 240: 0.442072    0.946078    3.420094    0.704570    0.101806    0.008996    0.749523    
#> 241: 0.442700    0.945455    3.420294    0.705567    0.101617    0.008977    0.749041    
#> 242: 0.441881    0.945377    3.420039    0.703631    0.101370    0.008973    0.749535    
#> 243: 0.440616    0.945944    3.419925    0.700044    0.101629    0.008979    0.750161    
#> 244: 0.440742    0.945726    3.420067    0.700409    0.101108    0.009008    0.750479    
#> 245: 0.441391    0.945251    3.420303    0.700048    0.100746    0.009043    0.751088    
#> 246: 0.442185    0.944834    3.420589    0.699912    0.100654    0.009087    0.751733    
#> 247: 0.442542    0.944763    3.421069    0.697138    0.100916    0.009158    0.752137    
#> 248: 0.442607    0.944608    3.421424    0.693806    0.100728    0.009182    0.752145    
#> 249: 0.442534    0.944062    3.421978    0.690266    0.100596    0.009186    0.752465    
#> 250: 0.444201    0.944195    3.422464    0.687994    0.100408    0.009237    0.752621    
#> 251: 0.445117    0.944326    3.423120    0.686014    0.100205    0.009249    0.752897    
#> 252: 0.445670    0.944043    3.423732    0.684312    0.100031    0.009251    0.753193    
#> 253: 0.446409    0.943707    3.424038    0.683476    0.099771    0.009242    0.753264    
#> 254: 0.446946    0.943817    3.424339    0.684394    0.099434    0.009219    0.753305    
#> 255: 0.447631    0.944276    3.424576    0.687216    0.099250    0.009222    0.753324    
#> 256: 0.448479    0.944065    3.424737    0.685633    0.099130    0.009259    0.753397    
#> 257: 0.448395    0.943501    3.425052    0.684107    0.099294    0.009310    0.753321    
#> 258: 0.448148    0.943025    3.425296    0.682806    0.099236    0.009341    0.753149    
#> 259: 0.448573    0.942672    3.425472    0.681602    0.098932    0.009376    0.752908    
#> 260: 0.448655    0.942746    3.425693    0.679344    0.098695    0.009404    0.752677    
#> 261: 0.449135    0.942522    3.425914    0.679177    0.098420    0.009427    0.752818    
#> 262: 0.449368    0.942722    3.426017    0.678559    0.098048    0.009427    0.753043    
#> 263: 0.448469    0.943214    3.425950    0.676255    0.098057    0.009426    0.753219    
#> 264: 0.447687    0.943549    3.425820    0.674899    0.098095    0.009423    0.753350    
#> 265: 0.447699    0.943692    3.425700    0.675522    0.097896    0.009438    0.753587    
#> 266: 0.447924    0.943848    3.425722    0.676221    0.097813    0.009462    0.753632    
#> 267: 0.447823    0.943920    3.425776    0.678608    0.097907    0.009460    0.753844    
#> 268: 0.447289    0.943872    3.425610    0.678594    0.097956    0.009416    0.753587    
#> 269: 0.447117    0.944013    3.425489    0.677728    0.097933    0.009410    0.753388    
#> 270: 0.446946    0.944613    3.425242    0.676661    0.097856    0.009406    0.753137    
#> 271: 0.446175    0.945129    3.424910    0.675793    0.097851    0.009408    0.753238    
#> 272: 0.445689    0.945200    3.424705    0.673605    0.097875    0.009434    0.753361    
#> 273: 0.445839    0.945365    3.424645    0.673852    0.097694    0.009426    0.753497    
#> 274: 0.445825    0.945608    3.424695    0.672123    0.097906    0.009434    0.753505    
#> 275: 0.445478    0.945640    3.424606    0.670419    0.097933    0.009443    0.753621    
#> 276: 0.445576    0.945477    3.424787    0.671623    0.097772    0.009489    0.753598    
#> 277: 0.445669    0.945407    3.425072    0.671781    0.097513    0.009547    0.753613    
#> 278: 0.445843    0.945357    3.425333    0.670851    0.097281    0.009571    0.753637    
#> 279: 0.445442    0.945037    3.425416    0.668925    0.097069    0.009597    0.754049    
#> 280: 0.445424    0.945029    3.425592    0.668111    0.096923    0.009609    0.753987    
#> 281: 0.445204    0.945156    3.425779    0.666665    0.096982    0.009603    0.753805    
#> 282: 0.445134    0.945345    3.425873    0.665721    0.097035    0.009606    0.753758    
#> 283: 0.445472    0.945351    3.425975    0.664712    0.097398    0.009601    0.754103    
#> 284: 0.445495    0.945046    3.425973    0.663973    0.097503    0.009604    0.754260    
#> 285: 0.445375    0.944847    3.425849    0.662853    0.097446    0.009618    0.754398    
#> 286: 0.445183    0.945149    3.425722    0.662470    0.097400    0.009664    0.754471    
#> 287: 0.444856    0.945337    3.425593    0.661721    0.097134    0.009685    0.754492    
#> 288: 0.444566    0.945477    3.425465    0.660571    0.097000    0.009712    0.754455    
#> 289: 0.444318    0.945544    3.425263    0.660641    0.096913    0.009729    0.754394    
#> 290: 0.444091    0.945680    3.425070    0.660284    0.097071    0.009736    0.754482    
#> 291: 0.443949    0.945984    3.424891    0.660389    0.097100    0.009735    0.754282    
#> 292: 0.443159    0.946085    3.424698    0.659961    0.097164    0.009705    0.754364    
#> 293: 0.442693    0.946344    3.424515    0.659583    0.097110    0.009687    0.754236    
#> 294: 0.442097    0.946570    3.424259    0.659051    0.097092    0.009681    0.754174    
#> 295: 0.441575    0.946415    3.424138    0.658977    0.097081    0.009694    0.754033    
#> 296: 0.441617    0.946322    3.424125    0.659347    0.097188    0.009732    0.754039    
#> 297: 0.441610    0.946316    3.424142    0.658975    0.097319    0.009775    0.754017    
#> 298: 0.441750    0.946331    3.424101    0.659945    0.097353    0.009796    0.753962    
#> 299: 0.441311    0.946454    3.423955    0.659635    0.097337    0.009788    0.753925    
#> 300: 0.441416    0.946402    3.423966    0.659960    0.097147    0.009801    0.753865    
#> 301: 0.441732    0.946348    3.423924    0.661070    0.096948    0.009800    0.753948    
#> 302: 0.442153    0.946386    3.423933    0.660451    0.096851    0.009816    0.753882    
#> 303: 0.442010    0.946479    3.423870    0.659520    0.096670    0.009813    0.753676    
#> 304: 0.442342    0.946723    3.423823    0.660057    0.096532    0.009802    0.753484    
#> 305: 0.442274    0.946580    3.423847    0.659429    0.096433    0.009802    0.753401    
#> 306: 0.442084    0.946439    3.423759    0.659216    0.096281    0.009800    0.753287    
#> 307: 0.442071    0.946307    3.423737    0.659830    0.095992    0.009814    0.753255    
#> 308: 0.441637    0.946192    3.423651    0.660283    0.095743    0.009805    0.753372    
#> 309: 0.441627    0.946155    3.423604    0.660146    0.095533    0.009816    0.753624    
#> 310: 0.441456    0.946323    3.423450    0.659556    0.095389    0.009824    0.753746    
#> 311: 0.441483    0.946430    3.423394    0.659483    0.095124    0.009845    0.753645    
#> 312: 0.441129    0.946334    3.423367    0.659600    0.095054    0.009850    0.753750    
#> 313: 0.440807    0.946005    3.423338    0.659255    0.095093    0.009849    0.753867    
#> 314: 0.440564    0.946026    3.423332    0.659442    0.095022    0.009844    0.753772    
#> 315: 0.440141    0.946200    3.423295    0.658142    0.094999    0.009855    0.753630    
#> 316: 0.439873    0.946260    3.423323    0.657147    0.094962    0.009867    0.753605    
#> 317: 0.439655    0.946178    3.423384    0.655946    0.095070    0.009852    0.753661    
#> 318: 0.439555    0.946166    3.423341    0.655019    0.095109    0.009828    0.753664    
#> 319: 0.439780    0.945927    3.423414    0.655554    0.095123    0.009829    0.753701    
#> 320: 0.439703    0.945739    3.423381    0.655257    0.095118    0.009806    0.753933    
#> 321: 0.439259    0.945838    3.423225    0.653865    0.095143    0.009800    0.753920    
#> 322: 0.438979    0.945879    3.423025    0.652830    0.095114    0.009790    0.753928    
#> 323: 0.438228    0.945938    3.422891    0.651507    0.095045    0.009809    0.753987    
#> 324: 0.437826    0.946143    3.422844    0.650830    0.095017    0.009807    0.753866    
#> 325: 0.437367    0.946514    3.422694    0.649990    0.094984    0.009793    0.753733    
#> 326: 0.437112    0.946450    3.422619    0.649649    0.094966    0.009782    0.753597    
#> 327: 0.436894    0.946520    3.422615    0.648959    0.094874    0.009762    0.753539    
#> 328: 0.436768    0.946732    3.422606    0.648494    0.094824    0.009739    0.753474    
#> 329: 0.436729    0.946610    3.422662    0.648014    0.094850    0.009719    0.753419    
#> 330: 0.436542    0.946578    3.422685    0.647517    0.094757    0.009710    0.753408    
#> 331: 0.436688    0.946676    3.422724    0.647181    0.094738    0.009690    0.753307    
#> 332: 0.436847    0.946726    3.422782    0.646907    0.094834    0.009697    0.753244    
#> 333: 0.436664    0.946771    3.422768    0.645661    0.094846    0.009682    0.753242    
#> 334: 0.436526    0.946607    3.422744    0.644813    0.094881    0.009659    0.753301    
#> 335: 0.436105    0.946764    3.422624    0.643884    0.094821    0.009649    0.753291    
#> 336: 0.435547    0.946993    3.422504    0.643662    0.094718    0.009656    0.753205    
#> 337: 0.435165    0.947410    3.422386    0.643375    0.094699    0.009647    0.753295    
#> 338: 0.434866    0.947444    3.422443    0.643081    0.094736    0.009643    0.753473    
#> 339: 0.434526    0.947562    3.422444    0.643099    0.094776    0.009646    0.753492    
#> 340: 0.434378    0.947260    3.422477    0.642134    0.094767    0.009659    0.753720    
#> 341: 0.434358    0.947249    3.422514    0.641845    0.094830    0.009665    0.753861    
#> 342: 0.434280    0.947174    3.422525    0.641351    0.094805    0.009684    0.753768    
#> 343: 0.434171    0.947186    3.422630    0.640257    0.094763    0.009697    0.753711    
#> 344: 0.434371    0.947149    3.422724    0.639773    0.094788    0.009737    0.753662    
#> 345: 0.434342    0.947202    3.422785    0.639104    0.094828    0.009762    0.753574    
#> 346: 0.434210    0.947245    3.422742    0.638629    0.094851    0.009770    0.753474    
#> 347: 0.434572    0.947173    3.422635    0.639503    0.094890    0.009775    0.753543    
#> 348: 0.434349    0.947302    3.422520    0.639634    0.094930    0.009785    0.753510    
#> 349: 0.434142    0.947246    3.422435    0.640063    0.094944    0.009795    0.753363    
#> 350: 0.434004    0.947114    3.422367    0.640438    0.094946    0.009784    0.753274    
#> 351: 0.434025    0.947309    3.422306    0.640739    0.094911    0.009780    0.753376    
#> 352: 0.433756    0.947479    3.422294    0.640592    0.094900    0.009767    0.753467    
#> 353: 0.433578    0.947726    3.422260    0.639440    0.094959    0.009764    0.753524    
#> 354: 0.433335    0.947877    3.422138    0.639071    0.095050    0.009737    0.753527    
#> 355: 0.433403    0.947805    3.422011    0.638895    0.095169    0.009720    0.753450    
#> 356: 0.433508    0.947739    3.421990    0.638802    0.095165    0.009710    0.753540    
#> 357: 0.433712    0.947881    3.421966    0.638600    0.095123    0.009704    0.753618    
#> 358: 0.433626    0.947980    3.421982    0.638194    0.095170    0.009690    0.753593    
#> 359: 0.433689    0.948235    3.421957    0.637923    0.095139    0.009686    0.753511    
#> 360: 0.433642    0.948405    3.421855    0.637920    0.095046    0.009690    0.753400    
#> 361: 0.433468    0.948481    3.421773    0.637501    0.095027    0.009680    0.753270    
#> 362: 0.433357    0.948529    3.421707    0.636953    0.094955    0.009661    0.753198    
#> 363: 0.433185    0.948630    3.421674    0.636901    0.094951    0.009648    0.753130    
#> 364: 0.433020    0.948748    3.421608    0.636528    0.094977    0.009644    0.753059    
#> 365: 0.432992    0.948736    3.421656    0.636277    0.094979    0.009655    0.753124    
#> 366: 0.432865    0.948740    3.421603    0.635728    0.094886    0.009654    0.753168    
#> 367: 0.432931    0.948725    3.421617    0.635382    0.094827    0.009650    0.753118    
#> 368: 0.433019    0.948802    3.421570    0.634343    0.094895    0.009656    0.753133    
#> 369: 0.432645    0.948845    3.421563    0.633536    0.094860    0.009671    0.753195    
#> 370: 0.432449    0.948926    3.421533    0.632705    0.094842    0.009667    0.753191    
#> 371: 0.432406    0.948998    3.421444    0.632433    0.094809    0.009653    0.753232    
#> 372: 0.432248    0.949143    3.421422    0.632911    0.094770    0.009644    0.753135    
#> 373: 0.431924    0.949337    3.421336    0.633091    0.094722    0.009642    0.753038    
#> 374: 0.431996    0.949347    3.421283    0.632761    0.094660    0.009638    0.752960    
#> 375: 0.431858    0.949378    3.421260    0.632336    0.094648    0.009635    0.752920    
#> 376: 0.431950    0.949464    3.421246    0.632843    0.094594    0.009633    0.752860    
#> 377: 0.432070    0.949505    3.421236    0.633342    0.094610    0.009636    0.752856    
#> 378: 0.431810    0.949581    3.421198    0.633224    0.094519    0.009640    0.752889    
#> 379: 0.431507    0.949529    3.421160    0.633099    0.094478    0.009640    0.752877    
#> 380: 0.431392    0.949582    3.421156    0.632805    0.094488    0.009635    0.752929    
#> 381: 0.431020    0.949683    3.421119    0.632153    0.094486    0.009635    0.752982    
#> 382: 0.430950    0.949817    3.421115    0.632074    0.094414    0.009643    0.752972    
#> 383: 0.430822    0.949958    3.421079    0.632012    0.094490    0.009634    0.752884    
#> 384: 0.430642    0.949920    3.421069    0.632207    0.094501    0.009621    0.752854    
#> 385: 0.430592    0.949997    3.421020    0.632540    0.094571    0.009606    0.752825    
#> 386: 0.430877    0.950125    3.421053    0.633638    0.094765    0.009597    0.752776    
#> 387: 0.430951    0.950287    3.421107    0.633335    0.094857    0.009586    0.752834    
#> 388: 0.430938    0.950413    3.421140    0.632926    0.094926    0.009581    0.752912    
#> 389: 0.430987    0.950289    3.421171    0.632487    0.095006    0.009577    0.753071    
#> 390: 0.430793    0.950272    3.421159    0.631870    0.095040    0.009581    0.753185    
#> 391: 0.430555    0.950228    3.421137    0.631118    0.095030    0.009573    0.753198    
#> 392: 0.430368    0.950272    3.421144    0.631176    0.095057    0.009568    0.753164    
#> 393: 0.430256    0.950256    3.421095    0.631120    0.095048    0.009570    0.753091    
#> 394: 0.429958    0.950279    3.421024    0.630591    0.095019    0.009567    0.753167    
#> 395: 0.429784    0.950400    3.420990    0.630272    0.095125    0.009573    0.753053    
#> 396: 0.429603    0.950521    3.420978    0.630036    0.095187    0.009579    0.752980    
#> 397: 0.429595    0.950437    3.420978    0.630108    0.095243    0.009581    0.752935    
#> 398: 0.429550    0.950276    3.421017    0.629952    0.095251    0.009600    0.753010    
#> 399: 0.429519    0.950214    3.421090    0.630007    0.095265    0.009614    0.752967    
#> 400: 0.429449    0.950305    3.421153    0.629368    0.095230    0.009612    0.753064    
#> 401: 0.429545    0.950377    3.421171    0.629416    0.095249    0.009616    0.753215    
#> 402: 0.429577    0.950534    3.421180    0.629328    0.095321    0.009615    0.753237    
#> 403: 0.429786    0.950554    3.421215    0.629475    0.095307    0.009606    0.753187    
#> 404: 0.429742    0.950644    3.421147    0.629300    0.095378    0.009593    0.753180    
#> 405: 0.429619    0.950750    3.421135    0.629199    0.095411    0.009586    0.753210    
#> 406: 0.429618    0.950870    3.421098    0.629207    0.095479    0.009585    0.753252    
#> 407: 0.429684    0.950957    3.421111    0.629323    0.095517    0.009572    0.753320    
#> 408: 0.429803    0.951055    3.421150    0.628891    0.095504    0.009561    0.753396    
#> 409: 0.429924    0.950986    3.421160    0.628656    0.095437    0.009540    0.753334    
#> 410: 0.429906    0.951033    3.421110    0.628563    0.095519    0.009534    0.753282    
#> 411: 0.429955    0.950853    3.421097    0.628668    0.095532    0.009519    0.753325    
#> 412: 0.429979    0.950892    3.421075    0.628525    0.095505    0.009506    0.753328    
#> 413: 0.429925    0.950955    3.421024    0.628345    0.095492    0.009490    0.753406    
#> 414: 0.429864    0.950928    3.421034    0.628559    0.095519    0.009482    0.753358    
#> 415: 0.429945    0.951003    3.420982    0.628530    0.095511    0.009464    0.753331    
#> 416: 0.429850    0.951113    3.420950    0.628374    0.095564    0.009449    0.753296    
#> 417: 0.429720    0.951240    3.420874    0.628560    0.095539    0.009442    0.753230    
#> 418: 0.429511    0.951344    3.420770    0.628599    0.095528    0.009438    0.753125    
#> 419: 0.429410    0.951482    3.420699    0.628961    0.095521    0.009443    0.753001    
#> 420: 0.429301    0.951601    3.420668    0.628563    0.095469    0.009443    0.752940    
#> 421: 0.429189    0.951648    3.420700    0.628304    0.095449    0.009451    0.752896    
#> 422: 0.429302    0.951524    3.420740    0.628158    0.095434    0.009462    0.752916    
#> 423: 0.429486    0.951411    3.420778    0.627866    0.095420    0.009471    0.753044    
#> 424: 0.429450    0.951374    3.420755    0.627754    0.095386    0.009469    0.753020    
#> 425: 0.429455    0.951383    3.420730    0.627938    0.095366    0.009466    0.753073    
#> 426: 0.429321    0.951417    3.420732    0.627915    0.095346    0.009463    0.753137    
#> 427: 0.429124    0.951358    3.420756    0.627589    0.095256    0.009460    0.753232    
#> 428: 0.428939    0.951462    3.420716    0.627158    0.095264    0.009456    0.753289    
#> 429: 0.428745    0.951517    3.420700    0.626680    0.095246    0.009455    0.753421    
#> 430: 0.428516    0.951576    3.420640    0.626171    0.095282    0.009448    0.753450    
#> 431: 0.428476    0.951620    3.420596    0.625833    0.095294    0.009449    0.753417    
#> 432: 0.428236    0.951743    3.420579    0.625326    0.095308    0.009463    0.753367    
#> 433: 0.428109    0.951890    3.420564    0.625068    0.095367    0.009469    0.753326    
#> 434: 0.427765    0.951883    3.420563    0.624534    0.095380    0.009471    0.753362    
#> 435: 0.427930    0.951874    3.420566    0.624518    0.095362    0.009474    0.753399    
#> 436: 0.428071    0.951803    3.420642    0.624220    0.095354    0.009473    0.753419    
#> 437: 0.428182    0.951726    3.420681    0.623952    0.095425    0.009474    0.753343    
#> 438: 0.428219    0.951708    3.420734    0.623655    0.095310    0.009481    0.753224    
#> 439: 0.428306    0.951811    3.420751    0.623648    0.095276    0.009483    0.753114    
#> 440: 0.428461    0.951825    3.420810    0.623473    0.095219    0.009481    0.753017    
#> 441: 0.428597    0.951712    3.420855    0.623734    0.095230    0.009476    0.752904    
#> 442: 0.428645    0.951685    3.420907    0.623701    0.095201    0.009469    0.752844    
#> 443: 0.428653    0.951742    3.420892    0.623615    0.095145    0.009466    0.752864    
#> 444: 0.428669    0.951817    3.420850    0.624256    0.095157    0.009464    0.752841    
#> 445: 0.428528    0.951863    3.420789    0.624422    0.095099    0.009467    0.752843    
#> 446: 0.428237    0.951955    3.420719    0.624263    0.095106    0.009470    0.752865    
#> 447: 0.428140    0.952042    3.420658    0.624082    0.095039    0.009467    0.752948    
#> 448: 0.428038    0.952125    3.420655    0.623935    0.095054    0.009462    0.753001    
#> 449: 0.428244    0.952203    3.420769    0.624048    0.095100    0.009463    0.753037    
#> 450: 0.428345    0.952139    3.420829    0.624123    0.095096    0.009459    0.753074    
#> 451: 0.428418    0.952123    3.420819    0.624573    0.095085    0.009454    0.753066    
#> 452: 0.428548    0.952203    3.420757    0.625312    0.095086    0.009453    0.753031    
#> 453: 0.428598    0.952306    3.420708    0.626108    0.095055    0.009452    0.752958    
#> 454: 0.428496    0.952460    3.420649    0.626250    0.095062    0.009440    0.752932    
#> 455: 0.428399    0.952568    3.420588    0.626069    0.095033    0.009435    0.752943    
#> 456: 0.428137    0.952601    3.420539    0.625820    0.095057    0.009429    0.753016    
#> 457: 0.427930    0.952630    3.420504    0.625639    0.095062    0.009420    0.752969    
#> 458: 0.427838    0.952765    3.420513    0.625289    0.095017    0.009417    0.752910    
#> 459: 0.427721    0.952902    3.420505    0.625258    0.095015    0.009427    0.752907    
#> 460: 0.427488    0.952978    3.420461    0.625097    0.095055    0.009431    0.752817    
#> 461: 0.427407    0.953058    3.420472    0.624687    0.095060    0.009427    0.752843    
#> 462: 0.427414    0.953123    3.420515    0.624485    0.095063    0.009424    0.752814    
#> 463: 0.427396    0.953170    3.420541    0.624050    0.095078    0.009424    0.752758    
#> 464: 0.427629    0.953132    3.420585    0.624084    0.095043    0.009420    0.752703    
#> 465: 0.427736    0.952952    3.420635    0.623925    0.095042    0.009419    0.752636    
#> 466: 0.427798    0.952994    3.420628    0.623743    0.095057    0.009418    0.752585    
#> 467: 0.427795    0.952907    3.420609    0.623860    0.094991    0.009412    0.752585    
#> 468: 0.427954    0.952941    3.420627    0.623956    0.095019    0.009404    0.752637    
#> 469: 0.428187    0.952969    3.420681    0.624072    0.095036    0.009400    0.752709    
#> 470: 0.428189    0.953002    3.420659    0.624482    0.095068    0.009399    0.752678    
#> 471: 0.428157    0.952905    3.420650    0.624316    0.095096    0.009398    0.752699    
#> 472: 0.428139    0.952858    3.420670    0.624499    0.095142    0.009397    0.752648    
#> 473: 0.427937    0.952891    3.420651    0.624379    0.095159    0.009394    0.752591    
#> 474: 0.427831    0.952852    3.420663    0.624152    0.095203    0.009394    0.752633    
#> 475: 0.427917    0.952929    3.420664    0.623990    0.095201    0.009383    0.752666    
#> 476: 0.427944    0.952925    3.420672    0.623788    0.095199    0.009378    0.752688    
#> 477: 0.428043    0.952885    3.420712    0.623713    0.095149    0.009367    0.752689    
#> 478: 0.428144    0.952819    3.420723    0.623868    0.095118    0.009363    0.752703    
#> 479: 0.428314    0.952857    3.420736    0.624209    0.095169    0.009357    0.752712    
#> 480: 0.428275    0.952836    3.420724    0.624167    0.095168    0.009355    0.752772    
#> 481: 0.428303    0.952846    3.420700    0.624773    0.095194    0.009342    0.752777    
#> 482: 0.428435    0.952871    3.420657    0.625383    0.095210    0.009332    0.752842    
#> 483: 0.428507    0.952883    3.420643    0.625734    0.095208    0.009322    0.752804    
#> 484: 0.428560    0.952827    3.420653    0.625924    0.095238    0.009318    0.752797    
#> 485: 0.428595    0.952899    3.420641    0.626288    0.095307    0.009308    0.752808    
#> 486: 0.428874    0.952944    3.420662    0.626977    0.095319    0.009298    0.752767    
#> 487: 0.429180    0.952918    3.420728    0.627624    0.095265    0.009294    0.752687    
#> 488: 0.429297    0.952930    3.420789    0.627992    0.095324    0.009291    0.752611    
#> 489: 0.429492    0.952864    3.420816    0.628396    0.095379    0.009292    0.752606    
#> 490: 0.429642    0.952900    3.420839    0.628307    0.095386    0.009286    0.752552    
#> 491: 0.429725    0.952977    3.420878    0.628313    0.095429    0.009282    0.752524    
#> 492: 0.429759    0.953113    3.420868    0.628354    0.095487    0.009282    0.752528    
#> 493: 0.429652    0.953151    3.420874    0.628153    0.095526    0.009281    0.752514    
#> 494: 0.429764    0.953167    3.420867    0.628009    0.095530    0.009276    0.752461    
#> 495: 0.429922    0.953165    3.420900    0.628024    0.095500    0.009270    0.752459    
#> 496: 0.429889    0.953204    3.420869    0.627751    0.095479    0.009273    0.752459    
#> 497: 0.429789    0.953176    3.420878    0.627394    0.095416    0.009276    0.752461    
#> 498: 0.429979    0.953152    3.420889    0.627528    0.095371    0.009269    0.752425    
#> 499: 0.429983    0.953218    3.420857    0.627470    0.095310    0.009266    0.752453    
#> 500: 0.430090    0.953196    3.420832    0.627860    0.095253    0.009266    0.752428    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.331834    0.973109    3.439835    0.392401    0.077078    0.016800    1.789678    
#> 002: 0.537585    1.060540    3.434541    0.372781    0.073224    0.016601    1.217449    
#> 003: 0.695757    1.006450    3.444709    0.354142    0.069563    0.015771    0.976624    
#> 004: 0.684195    1.018963    3.457737    0.336435    0.066085    0.014983    0.917039    
#> 005: 0.790602    1.026244    3.455592    0.319613    0.062781    0.014234    0.858162    
#> 006: 0.794271    1.029196    3.450420    0.303633    0.059642    0.013522    0.830294    
#> 007: 0.739093    1.025528    3.446166    0.288451    0.056660    0.012846    0.859768    
#> 008: 0.723486    1.012028    3.450501    0.274029    0.053827    0.013761    0.848244    
#> 009: 0.662981    0.997728    3.448152    0.280827    0.051135    0.013073    0.859166    
#> 010: 0.732249    0.978746    3.447187    0.336432    0.048579    0.012419    0.852932    
#> 011: 0.828759    0.989892    3.466141    0.366526    0.046150    0.011798    0.862068    
#> 012: 0.809019    0.981471    3.462621    0.348200    0.043842    0.011703    0.837724    
#> 013: 0.739504    0.986366    3.444603    0.330790    0.041650    0.012376    0.860208    
#> 014: 0.798876    0.969179    3.464321    0.331383    0.039568    0.014980    0.877770    
#> 015: 0.817844    0.974474    3.489068    0.314813    0.037589    0.014231    0.840428    
#> 016: 0.830992    1.008660    3.482250    0.316844    0.035710    0.013519    0.839982    
#> 017: 0.734885    1.011184    3.464467    0.301002    0.033924    0.012844    0.831650    
#> 018: 0.786516    1.013251    3.451534    0.358542    0.032228    0.012201    0.854593    
#> 019: 0.752963    1.007137    3.462554    0.340615    0.030617    0.011591    0.846135    
#> 020: 0.782770    1.026185    3.456432    0.341929    0.029086    0.011012    0.845643    
#> 021: 0.734332    1.020599    3.457591    0.324833    0.027632    0.010461    0.830279    
#> 022: 0.770936    1.013283    3.467772    0.317926    0.026250    0.009938    0.806951    
#> 023: 0.848396    1.019434    3.472184    0.313162    0.024937    0.009899    0.817858    
#> 024: 0.859360    1.039312    3.475871    0.297504    0.023691    0.011266    0.823850    
#> 025: 0.796628    1.008629    3.455220    0.321022    0.022506    0.013378    0.845340    
#> 026: 0.752048    1.040394    3.445642    0.304971    0.021381    0.012709    0.853645    
#> 027: 0.737811    1.060380    3.446954    0.299874    0.020312    0.012073    0.864375    
#> 028: 0.815622    1.057372    3.455361    0.324397    0.019296    0.011470    0.829592    
#> 029: 0.844669    1.026421    3.455922    0.349764    0.019465    0.013636    0.844200    
#> 030: 0.820714    1.039409    3.451597    0.336260    0.018492    0.012954    0.833802    
#> 031: 0.773133    1.022804    3.466061    0.319447    0.017568    0.012842    0.838551    
#> 032: 0.757873    1.016972    3.462425    0.393440    0.016689    0.012200    0.837554    
#> 033: 0.752090    1.033262    3.444415    0.373768    0.015855    0.011590    0.832902    
#> 034: 0.796148    1.041921    3.452211    0.370719    0.015062    0.011054    0.826040    
#> 035: 0.777267    1.032473    3.444284    0.352183    0.014309    0.011013    0.837350    
#> 036: 0.766539    1.021797    3.451895    0.334574    0.015333    0.010818    0.842025    
#> 037: 0.784688    1.031444    3.452324    0.394012    0.014667    0.010277    0.841481    
#> 038: 0.821695    1.022841    3.447921    0.416977    0.014522    0.009763    0.855101    
#> 039: 0.819835    1.011589    3.466684    0.396128    0.014950    0.009275    0.833761    
#> 040: 0.775255    1.004882    3.474411    0.394446    0.015824    0.008811    0.839974    
#> 041: 0.789451    0.985688    3.466372    0.374724    0.015033    0.009328    0.844186    
#> 042: 0.861817    0.983995    3.471288    0.355987    0.014281    0.011002    0.831498    
#> 043: 0.758469    0.986449    3.466387    0.338188    0.013651    0.011700    0.832832    
#> 044: 0.781095    0.992170    3.467955    0.321279    0.012969    0.011115    0.871808    
#> 045: 0.780062    1.007152    3.455055    0.305215    0.014777    0.010560    0.869864    
#> 046: 0.772558    1.003360    3.448863    0.309502    0.014038    0.010032    0.876452    
#> 047: 0.793375    1.015884    3.447261    0.302693    0.013336    0.011385    0.854880    
#> 048: 0.793212    1.009601    3.456104    0.354790    0.014799    0.011133    0.834519    
#> 049: 0.720461    1.011289    3.457004    0.340334    0.015441    0.010577    0.867109    
#> 050: 0.797705    0.985553    3.460373    0.323318    0.016282    0.010048    0.841640    
#> 051: 0.797119    1.003585    3.463575    0.378408    0.016798    0.013104    0.837247    
#> 052: 0.815771    1.021586    3.464345    0.387991    0.016693    0.012448    0.813591    
#> 053: 0.830077    1.022439    3.467556    0.368591    0.017737    0.011826    0.827092    
#> 054: 0.770393    1.025152    3.463169    0.350161    0.017447    0.011235    0.850009    
#> 055: 0.794781    1.025410    3.456655    0.332653    0.019850    0.010673    0.850709    
#> 056: 0.808893    1.023277    3.459991    0.316021    0.018869    0.010139    0.860621    
#> 057: 0.763962    1.011532    3.469821    0.300220    0.017925    0.009750    0.860623    
#> 058: 0.775965    1.009080    3.457342    0.294366    0.017029    0.010576    0.845977    
#> 059: 0.788939    0.976707    3.465668    0.329486    0.016178    0.012032    0.852338    
#> 060: 0.820301    0.980463    3.484389    0.338702    0.017229    0.015185    0.850676    
#> 061: 0.836118    0.983464    3.473655    0.401062    0.016368    0.014426    0.861731    
#> 062: 0.782580    1.001371    3.469857    0.381009    0.015782    0.013705    0.867692    
#> 063: 0.813804    0.988110    3.481047    0.361959    0.014993    0.013019    0.854555    
#> 064: 0.846910    0.992156    3.484176    0.343861    0.014244    0.014355    0.837735    
#> 065: 0.831294    0.989573    3.466893    0.335559    0.013531    0.015060    0.825990    
#> 066: 0.855903    0.977153    3.473993    0.354445    0.012855    0.014307    0.846464    
#> 067: 0.813747    0.980950    3.472312    0.336723    0.012212    0.014524    0.840738    
#> 068: 0.742807    0.989325    3.468775    0.319887    0.011601    0.013798    0.848415    
#> 069: 0.789686    1.004301    3.455546    0.369018    0.011021    0.013108    0.870252    
#> 070: 0.827585    1.009793    3.474112    0.433086    0.010470    0.012453    0.843561    
#> 071: 0.815192    1.017658    3.460227    0.411432    0.010268    0.011830    0.832482    
#> 072: 0.757236    0.996687    3.460199    0.390860    0.010091    0.011238    0.880255    
#> 073: 0.780817    1.011901    3.472154    0.371317    0.009586    0.010676    0.855093    
#> 074: 0.765277    0.994885    3.479024    0.352751    0.009107    0.011387    0.836824    
#> 075: 0.802486    0.995614    3.481804    0.358620    0.008652    0.010817    0.866827    
#> 076: 0.810316    1.008106    3.484037    0.340689    0.008324    0.012220    0.867430    
#> 077: 0.877771    0.990271    3.485506    0.323655    0.007907    0.011609    0.875063    
#> 078: 0.877801    0.993281    3.491254    0.307472    0.007512    0.012760    0.851596    
#> 079: 0.856181    1.002642    3.484799    0.314302    0.007137    0.013911    0.863092    
#> 080: 0.827640    0.999886    3.469812    0.320847    0.007316    0.013216    0.880142    
#> 081: 0.797148    0.997442    3.465081    0.318268    0.006950    0.012555    0.845612    
#> 082: 0.795243    0.993118    3.474100    0.337399    0.006602    0.011927    0.850373    
#> 083: 0.823567    0.988712    3.485304    0.320529    0.006782    0.011331    0.871064    
#> 084: 0.827283    1.003108    3.472252    0.320998    0.008012    0.010764    0.847799    
#> 085: 0.790830    1.010777    3.473530    0.304948    0.009460    0.010226    0.847190    
#> 086: 0.747820    1.012504    3.464770    0.289700    0.008987    0.011391    0.828401    
#> 087: 0.761695    1.000935    3.453283    0.294906    0.008826    0.011377    0.838471    
#> 088: 0.721250    1.000955    3.450358    0.341451    0.009374    0.012194    0.856602    
#> 089: 0.771210    1.012422    3.440962    0.348847    0.008906    0.012872    0.840267    
#> 090: 0.721251    1.021556    3.442793    0.331405    0.008460    0.013034    0.831061    
#> 091: 0.705136    1.014884    3.425522    0.344423    0.008037    0.014228    0.830884    
#> 092: 0.721727    1.029757    3.432132    0.378471    0.007635    0.014387    0.833691    
#> 093: 0.700621    1.041754    3.434016    0.359547    0.007312    0.013668    0.850294    
#> 094: 0.688116    1.049067    3.421658    0.363401    0.006946    0.018581    0.839861    
#> 095: 0.757011    1.051257    3.440031    0.442483    0.008106    0.020894    0.824316    
#> 096: 0.699316    1.069322    3.430597    0.420359    0.009113    0.019849    0.823916    
#> 097: 0.690244    1.075729    3.426790    0.399341    0.008951    0.018856    0.818634    
#> 098: 0.741987    1.072028    3.439189    0.379374    0.008503    0.017914    0.849827    
#> 099: 0.726265    1.057211    3.425951    0.360405    0.008078    0.017018    0.842727    
#> 100: 0.730853    1.058468    3.432485    0.360954    0.007748    0.016167    0.842697    
#> 101: 0.692219    1.039022    3.421932    0.342906    0.007384    0.015359    0.839010    
#> 102: 0.709365    1.031300    3.422275    0.325761    0.007015    0.014591    0.842200    
#> 103: 0.762757    1.037754    3.437669    0.353027    0.006664    0.013861    0.825383    
#> 104: 0.733108    1.035880    3.443913    0.384358    0.006437    0.013168    0.852352    
#> 105: 0.784205    1.039772    3.440119    0.386713    0.006828    0.012510    0.820811    
#> 106: 0.787550    1.034597    3.448397    0.367377    0.007583    0.012833    0.816504    
#> 107: 0.803902    1.034178    3.452912    0.419684    0.007651    0.014298    0.840977    
#> 108: 0.796905    1.025835    3.445054    0.398700    0.007269    0.015835    0.845455    
#> 109: 0.760452    1.026477    3.460377    0.385372    0.006905    0.015043    0.836292    
#> 110: 0.779419    1.032402    3.437777    0.366103    0.006560    0.014291    0.827867    
#> 111: 0.755292    1.040692    3.444366    0.347798    0.006232    0.015024    0.826148    
#> 112: 0.768062    1.027224    3.444471    0.351440    0.005920    0.017489    0.824359    
#> 113: 0.793680    1.039922    3.459495    0.333868    0.006433    0.016720    0.811263    
#> 114: 0.769219    1.046015    3.455158    0.317175    0.007624    0.015884    0.836280    
#> 115: 0.778462    1.031780    3.443264    0.301316    0.007242    0.015090    0.869662    
#> 116: 0.763442    1.035679    3.454916    0.341248    0.009075    0.014336    0.851701    
#> 117: 0.748627    1.047129    3.459699    0.324186    0.008621    0.013619    0.834507    
#> 118: 0.776589    1.040002    3.455479    0.321054    0.009233    0.012938    0.829991    
#> 119: 0.819926    1.023568    3.457035    0.381586    0.009404    0.012291    0.845435    
#> 120: 0.787725    1.011661    3.457207    0.380217    0.008934    0.011676    0.824944    
#> 121: 0.798065    1.028235    3.453804    0.361206    0.009715    0.012714    0.842065    
#> 122: 0.788887    1.003002    3.471749    0.343146    0.009229    0.012079    0.857066    
#> 123: 0.861328    1.017869    3.468240    0.364392    0.011286    0.011475    0.841722    
#> 124: 0.827682    1.033855    3.458926    0.440005    0.010722    0.012004    0.850640    
#> 125: 0.811066    1.041156    3.453665    0.418005    0.010882    0.016577    0.838474    
#> 126: 0.785010    1.035131    3.449073    0.420566    0.010376    0.015748    0.850401    
#> 127: 0.793811    1.024451    3.445027    0.399538    0.009857    0.014961    0.854692    
#> 128: 0.816814    1.022712    3.461980    0.379561    0.011331    0.014213    0.833804    
#> 129: 0.838928    1.032880    3.465997    0.402600    0.012309    0.013502    0.815461    
#> 130: 0.828154    1.038116    3.457109    0.420984    0.011693    0.012827    0.809599    
#> 131: 0.809244    1.036595    3.445585    0.409292    0.012548    0.012186    0.815836    
#> 132: 0.744605    1.029884    3.434862    0.388827    0.011921    0.012535    0.825886    
#> 133: 0.781230    1.019305    3.449152    0.369386    0.011325    0.012169    0.834786    
#> 134: 0.787699    1.001663    3.469003    0.350917    0.010759    0.011560    0.838864    
#> 135: 0.757537    1.007463    3.457111    0.342389    0.012665    0.010982    0.837634    
#> 136: 0.789165    1.001721    3.464549    0.336570    0.015910    0.010433    0.807511    
#> 137: 0.785960    1.011835    3.466155    0.323566    0.016152    0.010026    0.821193    
#> 138: 0.795522    1.001667    3.463582    0.310504    0.016021    0.009525    0.821763    
#> 139: 0.797683    0.999336    3.470882    0.294979    0.016266    0.009049    0.846653    
#> 140: 0.849229    1.013571    3.482389    0.315986    0.017473    0.010963    0.868673    
#> 141: 0.805561    0.993674    3.480647    0.330994    0.019941    0.010415    0.854204    
#> 142: 0.816012    0.982609    3.492057    0.314445    0.019157    0.009895    0.855779    
#> 143: 0.792007    0.996656    3.484976    0.298722    0.018199    0.010699    0.837630    
#> 144: 0.840628    1.020941    3.486117    0.283786    0.017406    0.010715    0.822467    
#> 145: 0.790359    1.023307    3.464879    0.310140    0.017925    0.010179    0.811115    
#> 146: 0.780464    1.022544    3.466678    0.342546    0.017029    0.009670    0.837746    
#> 147: 0.753081    1.021515    3.453766    0.325419    0.016178    0.009996    0.843031    
#> 148: 0.737163    1.035179    3.463877    0.309148    0.016580    0.010645    0.847403    
#> 149: 0.752032    1.014654    3.459201    0.293690    0.015751    0.010630    0.879003    
#> 150: 0.816816    1.003563    3.461513    0.379579    0.014964    0.010098    0.854333    
#> 151: 0.745333    1.018892    3.451592    0.397728    0.014215    0.009593    0.859870    
#> 152: 0.776701    1.008961    3.457633    0.359539    0.013468    0.007726    0.849419    
#> 153: 0.770121    1.034251    3.454534    0.419575    0.017387    0.007012    0.846736    
#> 154: 0.829487    1.052941    3.455799    0.387196    0.014541    0.007112    0.870076    
#> 155: 0.753540    1.040273    3.457046    0.421724    0.016759    0.007256    0.851299    
#> 156: 0.775100    1.026716    3.467118    0.394596    0.017474    0.008018    0.844609    
#> 157: 0.797161    1.025580    3.470148    0.291605    0.013264    0.010447    0.835172    
#> 158: 0.816343    1.028526    3.459171    0.379706    0.013987    0.009343    0.829775    
#> 159: 0.750322    1.051847    3.456751    0.294010    0.015938    0.009843    0.836688    
#> 160: 0.802327    1.030226    3.459703    0.378023    0.017110    0.010825    0.834038    
#> 161: 0.773739    1.015462    3.456191    0.291134    0.022334    0.012364    0.840374    
#> 162: 0.745023    1.026285    3.439903    0.303336    0.019697    0.011081    0.838946    
#> 163: 0.770139    1.025365    3.442347    0.369844    0.017526    0.011479    0.827076    
#> 164: 0.838501    1.030628    3.457041    0.361366    0.017369    0.009552    0.830135    
#> 165: 0.825521    1.029078    3.469138    0.300989    0.016430    0.011023    0.821518    
#> 166: 0.805702    1.039008    3.459862    0.370461    0.013384    0.009486    0.844978    
#> 167: 0.854773    1.044999    3.472893    0.366416    0.013092    0.008506    0.851337    
#> 168: 0.856481    1.040555    3.482343    0.350450    0.009903    0.006867    0.846469    
#> 169: 0.802853    1.048516    3.459385    0.340526    0.010420    0.008176    0.853494    
#> 170: 0.808412    1.035548    3.465050    0.349653    0.010808    0.009066    0.829384    
#> 171: 0.758276    1.031825    3.454277    0.361667    0.007133    0.007695    0.838627    
#> 172: 0.791334    1.037484    3.449313    0.401498    0.004807    0.007188    0.834190    
#> 173: 0.753707    1.045234    3.439640    0.316606    0.004110    0.008344    0.843830    
#> 174: 0.762274    1.043373    3.440538    0.320213    0.003984    0.009711    0.857735    
#> 175: 0.760338    1.038748    3.432579    0.384254    0.003375    0.011070    0.864155    
#> 176: 0.729589    1.047257    3.445093    0.293167    0.002771    0.010877    0.848475    
#> 177: 0.744393    1.046535    3.451895    0.315387    0.002179    0.011533    0.855314    
#> 178: 0.772928    1.044064    3.442186    0.355947    0.002894    0.009371    0.840715    
#> 179: 0.769364    1.044463    3.453707    0.292004    0.003785    0.010170    0.870671    
#> 180: 0.705611    1.034803    3.444210    0.268306    0.004631    0.012503    0.867274    
#> 181: 0.687188    1.016812    3.419351    0.279983    0.004447    0.014692    0.845706    
#> 182: 0.714101    1.018723    3.419648    0.268853    0.005675    0.013508    0.856839    
#> 183: 0.748712    1.022664    3.431741    0.304991    0.006935    0.013804    0.851942    
#> 184: 0.759655    1.011344    3.440349    0.363262    0.007563    0.011625    0.844199    
#> 185: 0.729123    1.030206    3.445166    0.277407    0.008815    0.008475    0.839195    
#> 186: 0.759712    1.036567    3.444581    0.310288    0.010079    0.010057    0.832747    
#> 187: 0.755155    1.032780    3.451369    0.297584    0.009499    0.009277    0.853707    
#> 188: 0.729865    1.049344    3.441312    0.307727    0.010202    0.010534    0.866507    
#> 189: 0.772365    1.043360    3.457105    0.273837    0.010705    0.008887    0.874188    
#> 190: 0.723243    1.046790    3.460121    0.227211    0.008016    0.009356    0.886257    
#> 191: 0.704555    1.040301    3.442487    0.205877    0.006202    0.009922    0.881825    
#> 192: 0.723704    1.052449    3.445806    0.227611    0.005549    0.011406    0.869256    
#> 193: 0.758768    1.049064    3.439053    0.283645    0.003881    0.010504    0.856996    
#> 194: 0.743544    1.040230    3.427099    0.341471    0.003397    0.012906    0.851873    
#> 195: 0.738074    1.046554    3.443093    0.317629    0.004259    0.015102    0.839317    
#> 196: 0.767136    1.038131    3.451440    0.328276    0.006351    0.015549    0.823783    
#> 197: 0.748001    1.053111    3.462321    0.356419    0.007423    0.015417    0.841360    
#> 198: 0.819584    1.038826    3.452446    0.437143    0.006261    0.016452    0.818521    
#> 199: 0.737590    1.034184    3.443539    0.380811    0.005775    0.018938    0.807817    
#> 200: 0.751152    1.038550    3.444474    0.293989    0.006070    0.016356    0.837958    
#> 201: 0.726875    1.031325    3.447760    0.285605    0.005709    0.017271    0.840695    
#> 202: 0.735097    1.033816    3.449761    0.297105    0.005846    0.017868    0.840022    
#> 203: 0.763271    1.033424    3.451984    0.316035    0.006140    0.017712    0.834220    
#> 204: 0.779623    1.028660    3.455571    0.329814    0.006373    0.018174    0.831249    
#> 205: 0.781735    1.027520    3.456638    0.335771    0.006451    0.018278    0.832780    
#> 206: 0.781422    1.028478    3.457682    0.352747    0.006301    0.018173    0.836163    
#> 207: 0.777534    1.027430    3.456635    0.344417    0.006062    0.017616    0.837030    
#> 208: 0.776870    1.025872    3.457096    0.340219    0.006082    0.017121    0.838429    
#> 209: 0.782768    1.024237    3.456800    0.346777    0.006119    0.016565    0.836963    
#> 210: 0.783477    1.023333    3.456213    0.347877    0.006038    0.016318    0.836472    
#> 211: 0.784844    1.023320    3.456761    0.349399    0.006005    0.015959    0.835367    
#> 212: 0.784451    1.024127    3.456689    0.345909    0.005895    0.016040    0.835645    
#> 213: 0.785812    1.022176    3.457085    0.344593    0.005938    0.015932    0.836682    
#> 214: 0.787292    1.021614    3.457864    0.346752    0.005921    0.015868    0.837534    
#> 215: 0.787418    1.021581    3.458158    0.344523    0.005847    0.015624    0.838683    
#> 216: 0.790243    1.020726    3.457931    0.348642    0.005773    0.015586    0.839828    
#> 217: 0.790242    1.020490    3.457964    0.354550    0.005649    0.015581    0.839450    
#> 218: 0.790708    1.021211    3.457451    0.361498    0.005630    0.015665    0.839611    
#> 219: 0.790070    1.021711    3.456048    0.364499    0.005647    0.015531    0.839854    
#> 220: 0.788557    1.022361    3.455461    0.364343    0.005661    0.015256    0.839952    
#> 221: 0.784639    1.022396    3.454670    0.363473    0.005645    0.015110    0.839273    
#> 222: 0.783540    1.022577    3.453946    0.366036    0.005641    0.015029    0.839843    
#> 223: 0.782868    1.023015    3.453291    0.365804    0.005597    0.014970    0.839663    
#> 224: 0.783703    1.023199    3.453330    0.367398    0.005506    0.014894    0.839127    
#> 225: 0.783017    1.022998    3.453812    0.365804    0.005460    0.014706    0.839586    
#> 226: 0.784303    1.022096    3.454067    0.369034    0.005438    0.014647    0.839585    
#> 227: 0.784108    1.021575    3.454366    0.369921    0.005430    0.014576    0.839122    
#> 228: 0.782555    1.021761    3.453783    0.369556    0.005425    0.014458    0.839759    
#> 229: 0.782749    1.021345    3.453747    0.372113    0.005406    0.014494    0.839102    
#> 230: 0.784541    1.021041    3.453898    0.373904    0.005413    0.014490    0.838960    
#> 231: 0.786015    1.020793    3.454555    0.376573    0.005482    0.014432    0.838753    
#> 232: 0.785726    1.020525    3.454972    0.377972    0.005566    0.014392    0.838366    
#> 233: 0.786692    1.019907    3.455191    0.380231    0.005613    0.014376    0.838173    
#> 234: 0.786908    1.019686    3.455279    0.378583    0.005651    0.014294    0.838219    
#> 235: 0.786964    1.019661    3.455006    0.378230    0.005670    0.014216    0.837941    
#> 236: 0.786749    1.019713    3.454819    0.376813    0.005695    0.014142    0.838227    
#> 237: 0.787580    1.019472    3.454831    0.377352    0.005670    0.014164    0.838528    
#> 238: 0.788426    1.019303    3.454956    0.378325    0.005694    0.014206    0.838992    
#> 239: 0.789080    1.019511    3.454936    0.379986    0.005690    0.014171    0.839128    
#> 240: 0.788987    1.019415    3.455203    0.378686    0.005677    0.014076    0.839123    
#> 241: 0.789517    1.019279    3.455420    0.378652    0.005676    0.014052    0.839122    
#> 242: 0.788735    1.019380    3.455399    0.378285    0.005733    0.014065    0.839564    
#> 243: 0.788179    1.019661    3.455528    0.377109    0.005795    0.014083    0.839966    
#> 244: 0.787453    1.019682    3.455569    0.375861    0.005762    0.014145    0.841120    
#> 245: 0.787729    1.019447    3.455426    0.375646    0.005727    0.014094    0.841766    
#> 246: 0.787121    1.019347    3.455185    0.375796    0.005746    0.014078    0.842821    
#> 247: 0.787002    1.019371    3.455301    0.375385    0.005769    0.014058    0.843026    
#> 248: 0.787181    1.019443    3.455444    0.374986    0.005777    0.014044    0.842732    
#> 249: 0.786381    1.019344    3.455662    0.373210    0.005829    0.013992    0.842935    
#> 250: 0.787041    1.019313    3.455839    0.374625    0.005825    0.014040    0.842628    
#> 251: 0.787103    1.019419    3.455984    0.374840    0.005826    0.014008    0.842096    
#> 252: 0.787846    1.019501    3.456456    0.374569    0.005834    0.014008    0.842085    
#> 253: 0.788666    1.019485    3.456807    0.374867    0.005817    0.014128    0.842128    
#> 254: 0.789185    1.019649    3.457068    0.374162    0.005784    0.014217    0.842768    
#> 255: 0.790070    1.019764    3.457250    0.374025    0.005741    0.014257    0.843261    
#> 256: 0.790841    1.019660    3.457213    0.374887    0.005715    0.014328    0.843321    
#> 257: 0.791530    1.019496    3.457218    0.374405    0.005688    0.014323    0.843239    
#> 258: 0.792098    1.019269    3.457310    0.373806    0.005664    0.014298    0.843067    
#> 259: 0.791849    1.019221    3.457269    0.373063    0.005669    0.014279    0.843085    
#> 260: 0.791673    1.019354    3.457305    0.373108    0.005681    0.014255    0.842973    
#> 261: 0.791597    1.019254    3.457398    0.372227    0.005685    0.014216    0.842982    
#> 262: 0.791140    1.019225    3.457407    0.370906    0.005665    0.014163    0.842838    
#> 263: 0.791005    1.019272    3.457337    0.371184    0.005628    0.014160    0.842831    
#> 264: 0.790824    1.019335    3.457248    0.371790    0.005632    0.014189    0.843005    
#> 265: 0.791029    1.019333    3.457322    0.372143    0.005615    0.014244    0.843003    
#> 266: 0.791763    1.019400    3.457338    0.372987    0.005607    0.014213    0.843015    
#> 267: 0.791798    1.019367    3.457475    0.373208    0.005591    0.014201    0.843295    
#> 268: 0.792191    1.019204    3.457409    0.372770    0.005598    0.014165    0.843475    
#> 269: 0.792699    1.019080    3.457601    0.372675    0.005603    0.014170    0.843492    
#> 270: 0.793882    1.018848    3.457607    0.373642    0.005599    0.014142    0.843321    
#> 271: 0.793913    1.018750    3.457446    0.374507    0.005586    0.014154    0.843335    
#> 272: 0.794203    1.018729    3.457300    0.374291    0.005590    0.014149    0.843575    
#> 273: 0.793455    1.018802    3.457222    0.374286    0.005575    0.014141    0.843677    
#> 274: 0.793055    1.018860    3.457222    0.373413    0.005561    0.014113    0.843526    
#> 275: 0.792675    1.018845    3.457083    0.373124    0.005534    0.014071    0.843309    
#> 276: 0.793046    1.018891    3.457232    0.372707    0.005512    0.014105    0.843513    
#> 277: 0.792911    1.018949    3.457356    0.372482    0.005493    0.014106    0.843605    
#> 278: 0.793081    1.018940    3.457604    0.372297    0.005504    0.014115    0.843508    
#> 279: 0.792953    1.018840    3.457739    0.372870    0.005512    0.014117    0.843593    
#> 280: 0.792997    1.018995    3.457892    0.372245    0.005517    0.014105    0.843445    
#> 281: 0.793079    1.019149    3.458011    0.372314    0.005506    0.014079    0.843346    
#> 282: 0.793434    1.019451    3.458096    0.373595    0.005510    0.014051    0.843582    
#> 283: 0.793979    1.019621    3.458243    0.374527    0.005542    0.014032    0.843983    
#> 284: 0.794433    1.019684    3.458475    0.374639    0.005555    0.014011    0.844088    
#> 285: 0.794428    1.019803    3.458368    0.375394    0.005564    0.013982    0.844367    
#> 286: 0.794586    1.019891    3.458256    0.375562    0.005583    0.013982    0.844631    
#> 287: 0.794227    1.019974    3.458154    0.375640    0.005577    0.013999    0.844732    
#> 288: 0.793974    1.019957    3.458212    0.374890    0.005591    0.014028    0.844790    
#> 289: 0.794328    1.019900    3.458269    0.374512    0.005586    0.014026    0.844709    
#> 290: 0.794363    1.019930    3.458238    0.374354    0.005580    0.014081    0.844855    
#> 291: 0.794489    1.020067    3.458381    0.374641    0.005570    0.014098    0.844634    
#> 292: 0.794293    1.020221    3.458330    0.374821    0.005563    0.014084    0.844620    
#> 293: 0.794129    1.020251    3.458249    0.375019    0.005549    0.014088    0.844429    
#> 294: 0.794077    1.020255    3.458156    0.375374    0.005540    0.014083    0.844245    
#> 295: 0.794053    1.020193    3.458065    0.375770    0.005533    0.014056    0.843986    
#> 296: 0.793928    1.020087    3.458108    0.375201    0.005532    0.014085    0.844096    
#> 297: 0.793930    1.020058    3.458279    0.374845    0.005530    0.014102    0.844037    
#> 298: 0.794340    1.019858    3.458396    0.374136    0.005530    0.014119    0.843805    
#> 299: 0.794576    1.019790    3.458328    0.373638    0.005527    0.014112    0.843677    
#> 300: 0.795041    1.019751    3.458396    0.373660    0.005535    0.014123    0.843373    
#> 301: 0.794907    1.019561    3.458369    0.373409    0.005535    0.014104    0.843361    
#> 302: 0.794934    1.019392    3.458325    0.373555    0.005539    0.014091    0.843264    
#> 303: 0.795100    1.019337    3.458311    0.374257    0.005545    0.014077    0.843162    
#> 304: 0.795423    1.019483    3.458221    0.375550    0.005555    0.014077    0.842882    
#> 305: 0.795656    1.019448    3.458192    0.375984    0.005548    0.014073    0.842698    
#> 306: 0.795391    1.019444    3.458167    0.375810    0.005533    0.014080    0.842570    
#> 307: 0.795191    1.019320    3.458028    0.374808    0.005522    0.014049    0.842780    
#> 308: 0.795002    1.019181    3.458071    0.375073    0.005516    0.014019    0.842902    
#> 309: 0.795279    1.019037    3.458044    0.375034    0.005515    0.014001    0.842922    
#> 310: 0.795388    1.018841    3.457973    0.374998    0.005515    0.013971    0.843107    
#> 311: 0.795620    1.018714    3.458037    0.375029    0.005518    0.013963    0.843188    
#> 312: 0.795844    1.018471    3.457935    0.375653    0.005528    0.013980    0.843214    
#> 313: 0.795959    1.018291    3.457879    0.375886    0.005538    0.013991    0.843218    
#> 314: 0.795519    1.018253    3.457779    0.375533    0.005534    0.014003    0.843281    
#> 315: 0.795180    1.018202    3.457748    0.375539    0.005518    0.014027    0.843354    
#> 316: 0.795619    1.018175    3.457796    0.376417    0.005509    0.014027    0.843347    
#> 317: 0.795949    1.018161    3.457910    0.376216    0.005520    0.014018    0.843427    
#> 318: 0.796125    1.018122    3.457909    0.375835    0.005518    0.014015    0.843361    
#> 319: 0.796211    1.018032    3.457934    0.375405    0.005510    0.014018    0.843319    
#> 320: 0.796041    1.017964    3.457957    0.375898    0.005508    0.014015    0.843382    
#> 321: 0.795583    1.017914    3.457887    0.375835    0.005512    0.014014    0.843402    
#> 322: 0.795794    1.017897    3.457751    0.376081    0.005504    0.013977    0.843422    
#> 323: 0.795340    1.017869    3.457724    0.375973    0.005499    0.013959    0.843521    
#> 324: 0.795058    1.017892    3.457680    0.375766    0.005487    0.013932    0.843513    
#> 325: 0.794967    1.017869    3.457632    0.375578    0.005482    0.013946    0.843442    
#> 326: 0.794725    1.017763    3.457560    0.375062    0.005481    0.013941    0.843457    
#> 327: 0.794870    1.017882    3.457494    0.375593    0.005486    0.013945    0.843320    
#> 328: 0.794977    1.017995    3.457440    0.375866    0.005491    0.013959    0.843278    
#> 329: 0.794958    1.017948    3.457440    0.376242    0.005484    0.013979    0.843068    
#> 330: 0.794923    1.017947    3.457495    0.376111    0.005494    0.014035    0.842909    
#> 331: 0.795132    1.018078    3.457575    0.375459    0.005515    0.014050    0.842893    
#> 332: 0.795330    1.018112    3.457726    0.375207    0.005529    0.014083    0.842873    
#> 333: 0.795301    1.018159    3.457659    0.375186    0.005542    0.014085    0.842910    
#> 334: 0.795137    1.018146    3.457546    0.375125    0.005544    0.014063    0.842828    
#> 335: 0.795185    1.018131    3.457523    0.375152    0.005558    0.014067    0.842719    
#> 336: 0.794954    1.018223    3.457481    0.374853    0.005568    0.014074    0.842818    
#> 337: 0.795166    1.018269    3.457406    0.374994    0.005565    0.014061    0.842795    
#> 338: 0.795196    1.018322    3.457442    0.375171    0.005563    0.014065    0.842695    
#> 339: 0.795062    1.018436    3.457416    0.375087    0.005561    0.014050    0.842569    
#> 340: 0.794905    1.018438    3.457443    0.374874    0.005554    0.014036    0.842558    
#> 341: 0.795052    1.018555    3.457508    0.374446    0.005559    0.014033    0.842583    
#> 342: 0.794844    1.018545    3.457480    0.373814    0.005556    0.014047    0.842602    
#> 343: 0.794583    1.018563    3.457498    0.373593    0.005557    0.014049    0.842510    
#> 344: 0.794818    1.018591    3.457512    0.373739    0.005563    0.014033    0.842530    
#> 345: 0.794561    1.018628    3.457474    0.373607    0.005566    0.014028    0.842389    
#> 346: 0.794617    1.018684    3.457463    0.373589    0.005573    0.014025    0.842287    
#> 347: 0.794633    1.018620    3.457420    0.373539    0.005574    0.014037    0.842323    
#> 348: 0.794341    1.018667    3.457331    0.373453    0.005585    0.014074    0.842259    
#> 349: 0.794429    1.018697    3.457316    0.373713    0.005587    0.014084    0.842223    
#> 350: 0.793966    1.018763    3.457207    0.373666    0.005581    0.014079    0.842180    
#> 351: 0.793941    1.018920    3.457090    0.373557    0.005582    0.014063    0.842180    
#> 352: 0.793819    1.019012    3.457107    0.373618    0.005589    0.014052    0.842273    
#> 353: 0.793935    1.019085    3.457077    0.373755    0.005597    0.014045    0.842244    
#> 354: 0.793805    1.019150    3.456949    0.373394    0.005618    0.014025    0.842354    
#> 355: 0.793986    1.019191    3.456892    0.373720    0.005637    0.014032    0.842454    
#> 356: 0.793712    1.019234    3.456930    0.373043    0.005656    0.014031    0.842456    
#> 357: 0.793563    1.019266    3.456927    0.372407    0.005658    0.014025    0.842429    
#> 358: 0.793320    1.019382    3.456910    0.371972    0.005680    0.014003    0.842354    
#> 359: 0.792976    1.019482    3.456863    0.371796    0.005696    0.014009    0.842234    
#> 360: 0.792768    1.019488    3.456757    0.371930    0.005702    0.014009    0.842132    
#> 361: 0.792742    1.019485    3.456701    0.371801    0.005707    0.013994    0.842007    
#> 362: 0.792705    1.019469    3.456687    0.371481    0.005709    0.013978    0.841951    
#> 363: 0.792816    1.019346    3.456689    0.371468    0.005709    0.013988    0.841851    
#> 364: 0.792913    1.019350    3.456691    0.371859    0.005705    0.013998    0.841775    
#> 365: 0.792928    1.019330    3.456725    0.371903    0.005709    0.013996    0.841756    
#> 366: 0.792879    1.019330    3.456609    0.371608    0.005692    0.013988    0.841906    
#> 367: 0.792646    1.019310    3.456606    0.371249    0.005682    0.013987    0.842092    
#> 368: 0.792747    1.019356    3.456535    0.371426    0.005676    0.014014    0.842153    
#> 369: 0.792665    1.019369    3.456527    0.371742    0.005675    0.014012    0.842229    
#> 370: 0.792565    1.019418    3.456549    0.371831    0.005682    0.013992    0.842221    
#> 371: 0.792361    1.019509    3.456421    0.371864    0.005679    0.013959    0.842245    
#> 372: 0.792338    1.019587    3.456333    0.371974    0.005675    0.013940    0.842266    
#> 373: 0.791920    1.019718    3.456218    0.371823    0.005675    0.013932    0.842224    
#> 374: 0.791683    1.019753    3.456128    0.371613    0.005674    0.013928    0.842170    
#> 375: 0.791550    1.019761    3.456105    0.371509    0.005673    0.013922    0.842097    
#> 376: 0.791676    1.019761    3.456135    0.371363    0.005672    0.013927    0.842091    
#> 377: 0.791762    1.019790    3.456144    0.371420    0.005673    0.013966    0.841997    
#> 378: 0.791624    1.019762    3.456052    0.371129    0.005676    0.013988    0.842106    
#> 379: 0.791470    1.019700    3.456065    0.370797    0.005676    0.013997    0.842131    
#> 380: 0.791144    1.019634    3.456015    0.370650    0.005680    0.013983    0.842052    
#> 381: 0.790879    1.019588    3.455934    0.371225    0.005680    0.013976    0.842045    
#> 382: 0.790594    1.019545    3.455880    0.371171    0.005684    0.013968    0.842070    
#> 383: 0.790719    1.019459    3.455931    0.371037    0.005693    0.013956    0.842087    
#> 384: 0.790487    1.019453    3.455974    0.370798    0.005688    0.013945    0.842141    
#> 385: 0.790542    1.019484    3.455946    0.371116    0.005684    0.013931    0.842134    
#> 386: 0.790638    1.019550    3.455988    0.371180    0.005680    0.013942    0.842056    
#> 387: 0.791102    1.019587    3.456084    0.371304    0.005675    0.013949    0.842087    
#> 388: 0.791160    1.019579    3.456120    0.371184    0.005662    0.013951    0.842157    
#> 389: 0.791322    1.019469    3.456138    0.371322    0.005656    0.013953    0.842171    
#> 390: 0.791089    1.019410    3.456069    0.371087    0.005646    0.013960    0.842273    
#> 391: 0.791202    1.019359    3.456088    0.371012    0.005636    0.013952    0.842299    
#> 392: 0.791373    1.019320    3.456175    0.371041    0.005634    0.013959    0.842217    
#> 393: 0.791584    1.019312    3.456203    0.371211    0.005643    0.013950    0.842172    
#> 394: 0.791760    1.019305    3.456217    0.371445    0.005639    0.013946    0.842190    
#> 395: 0.792278    1.019301    3.456218    0.372347    0.005643    0.013939    0.842129    
#> 396: 0.792597    1.019378    3.456270    0.372781    0.005654    0.013929    0.842024    
#> 397: 0.792865    1.019319    3.456387    0.372682    0.005660    0.013921    0.842073    
#> 398: 0.793261    1.019238    3.456558    0.372430    0.005662    0.013919    0.842202    
#> 399: 0.793413    1.019213    3.456732    0.372197    0.005673    0.013903    0.842305    
#> 400: 0.793581    1.019231    3.456810    0.372055    0.005663    0.013885    0.842507    
#> 401: 0.793574    1.019279    3.456824    0.371574    0.005667    0.013859    0.842600    
#> 402: 0.793555    1.019335    3.456835    0.371340    0.005668    0.013839    0.842622    
#> 403: 0.793714    1.019351    3.456854    0.371273    0.005675    0.013826    0.842632    
#> 404: 0.793728    1.019361    3.456788    0.371011    0.005684    0.013821    0.842526    
#> 405: 0.793712    1.019365    3.456819    0.370866    0.005688    0.013820    0.842513    
#> 406: 0.793561    1.019342    3.456824    0.370482    0.005698    0.013812    0.842566    
#> 407: 0.793551    1.019321    3.456860    0.370265    0.005700    0.013829    0.842511    
#> 408: 0.793402    1.019369    3.456846    0.369934    0.005690    0.013826    0.842555    
#> 409: 0.793365    1.019331    3.456842    0.369554    0.005682    0.013831    0.842474    
#> 410: 0.793208    1.019305    3.456736    0.369464    0.005676    0.013817    0.842464    
#> 411: 0.793350    1.019184    3.456685    0.369633    0.005680    0.013814    0.842463    
#> 412: 0.793227    1.019124    3.456637    0.369116    0.005676    0.013812    0.842483    
#> 413: 0.793004    1.019106    3.456572    0.368818    0.005677    0.013807    0.842466    
#> 414: 0.792887    1.019079    3.456533    0.369501    0.005676    0.013795    0.842384    
#> 415: 0.793178    1.019040    3.456580    0.369798    0.005674    0.013794    0.842445    
#> 416: 0.793244    1.019046    3.456586    0.369554    0.005669    0.013788    0.842410    
#> 417: 0.793427    1.019021    3.456626    0.369887    0.005668    0.013797    0.842324    
#> 418: 0.793594    1.019036    3.456715    0.370070    0.005674    0.013808    0.842235    
#> 419: 0.793753    1.019084    3.456713    0.370307    0.005685    0.013828    0.842134    
#> 420: 0.793752    1.019127    3.456671    0.370302    0.005691    0.013836    0.842035    
#> 421: 0.793655    1.019147    3.456671    0.370377    0.005689    0.013844    0.841977    
#> 422: 0.793842    1.019118    3.456670    0.370719    0.005696    0.013850    0.842009    
#> 423: 0.793982    1.019106    3.456679    0.370797    0.005698    0.013847    0.842046    
#> 424: 0.793870    1.019129    3.456605    0.370883    0.005700    0.013842    0.841953    
#> 425: 0.793864    1.019164    3.456585    0.370952    0.005713    0.013846    0.841945    
#> 426: 0.793885    1.019195    3.456578    0.370995    0.005718    0.013832    0.841876    
#> 427: 0.793959    1.019187    3.456626    0.371226    0.005716    0.013831    0.841840    
#> 428: 0.793916    1.019164    3.456659    0.370770    0.005706    0.013819    0.841940    
#> 429: 0.793975    1.019163    3.456660    0.370614    0.005699    0.013798    0.841991    
#> 430: 0.793953    1.019179    3.456678    0.370444    0.005692    0.013790    0.842053    
#> 431: 0.793859    1.019216    3.456618    0.370400    0.005686    0.013782    0.842073    
#> 432: 0.793773    1.019274    3.456610    0.370438    0.005692    0.013785    0.842033    
#> 433: 0.793814    1.019308    3.456622    0.370262    0.005700    0.013785    0.842031    
#> 434: 0.793814    1.019333    3.456678    0.369957    0.005707    0.013788    0.842022    
#> 435: 0.793828    1.019378    3.456700    0.369851    0.005710    0.013798    0.841978    
#> 436: 0.793877    1.019355    3.456746    0.369915    0.005712    0.013799    0.841993    
#> 437: 0.793891    1.019373    3.456753    0.369779    0.005708    0.013811    0.842070    
#> 438: 0.793871    1.019413    3.456780    0.369744    0.005708    0.013810    0.842086    
#> 439: 0.793788    1.019428    3.456787    0.369941    0.005704    0.013810    0.842060    
#> 440: 0.793711    1.019490    3.456761    0.369801    0.005707    0.013820    0.842106    
#> 441: 0.793728    1.019507    3.456773    0.370087    0.005712    0.013824    0.842057    
#> 442: 0.793514    1.019528    3.456780    0.369903    0.005709    0.013818    0.842057    
#> 443: 0.793436    1.019546    3.456730    0.369895    0.005708    0.013818    0.842017    
#> 444: 0.793314    1.019600    3.456666    0.369763    0.005708    0.013832    0.842003    
#> 445: 0.793182    1.019641    3.456599    0.369969    0.005710    0.013841    0.841998    
#> 446: 0.793097    1.019689    3.456565    0.370054    0.005720    0.013829    0.841952    
#> 447: 0.793299    1.019730    3.456583    0.370074    0.005732    0.013818    0.841919    
#> 448: 0.793290    1.019712    3.456640    0.369807    0.005738    0.013817    0.841951    
#> 449: 0.793344    1.019752    3.456773    0.369379    0.005750    0.013813    0.842019    
#> 450: 0.793456    1.019799    3.456812    0.368936    0.005762    0.013812    0.842098    
#> 451: 0.793543    1.019867    3.456847    0.368722    0.005776    0.013806    0.842143    
#> 452: 0.793562    1.019900    3.456879    0.368389    0.005782    0.013797    0.842095    
#> 453: 0.793508    1.019975    3.456889    0.368109    0.005784    0.013794    0.841998    
#> 454: 0.793393    1.020055    3.456892    0.367800    0.005787    0.013775    0.841925    
#> 455: 0.793359    1.020147    3.456897    0.367649    0.005789    0.013766    0.841882    
#> 456: 0.793377    1.020155    3.456890    0.367866    0.005786    0.013758    0.841877    
#> 457: 0.793479    1.020149    3.456925    0.368124    0.005776    0.013753    0.841911    
#> 458: 0.793596    1.020181    3.457025    0.368440    0.005772    0.013751    0.841915    
#> 459: 0.793271    1.020206    3.457008    0.368454    0.005773    0.013749    0.841867    
#> 460: 0.792982    1.020181    3.456960    0.368216    0.005775    0.013739    0.841887    
#> 461: 0.792633    1.020207    3.456933    0.367906    0.005780    0.013725    0.841940    
#> 462: 0.792503    1.020260    3.456957    0.367810    0.005788    0.013734    0.842054    
#> 463: 0.792460    1.020329    3.456999    0.367670    0.005790    0.013732    0.842106    
#> 464: 0.792457    1.020324    3.456993    0.367395    0.005785    0.013728    0.842055    
#> 465: 0.792386    1.020290    3.456996    0.367066    0.005783    0.013718    0.842046    
#> 466: 0.792438    1.020299    3.456951    0.366974    0.005779    0.013715    0.842136    
#> 467: 0.792263    1.020308    3.456941    0.366825    0.005776    0.013715    0.842081    
#> 468: 0.792374    1.020310    3.456961    0.366739    0.005768    0.013713    0.842173    
#> 469: 0.792423    1.020354    3.457005    0.366811    0.005764    0.013707    0.842289    
#> 470: 0.792445    1.020372    3.456980    0.366776    0.005764    0.013698    0.842332    
#> 471: 0.792333    1.020357    3.456965    0.366761    0.005760    0.013691    0.842313    
#> 472: 0.792375    1.020317    3.456969    0.366699    0.005760    0.013695    0.842342    
#> 473: 0.792243    1.020288    3.456980    0.366556    0.005759    0.013684    0.842405    
#> 474: 0.792180    1.020238    3.456993    0.366387    0.005753    0.013666    0.842533    
#> 475: 0.792255    1.020268    3.457004    0.366229    0.005749    0.013658    0.842586    
#> 476: 0.792221    1.020262    3.456984    0.366409    0.005753    0.013650    0.842618    
#> 477: 0.792041    1.020251    3.456938    0.366059    0.005757    0.013646    0.842596    
#> 478: 0.791868    1.020217    3.456925    0.365746    0.005754    0.013644    0.842673    
#> 479: 0.791845    1.020214    3.456884    0.365744    0.005758    0.013632    0.842711    
#> 480: 0.791763    1.020189    3.456896    0.365596    0.005764    0.013632    0.842796    
#> 481: 0.791761    1.020161    3.456902    0.365615    0.005768    0.013637    0.842842    
#> 482: 0.791837    1.020163    3.456872    0.365434    0.005766    0.013637    0.842914    
#> 483: 0.791705    1.020142    3.456868    0.365453    0.005766    0.013640    0.842928    
#> 484: 0.791634    1.020068    3.456865    0.365507    0.005765    0.013633    0.842917    
#> 485: 0.791645    1.020082    3.456900    0.365491    0.005759    0.013629    0.842926    
#> 486: 0.791540    1.020117    3.456902    0.365497    0.005758    0.013621    0.842917    
#> 487: 0.791777    1.020154    3.456956    0.365505    0.005761    0.013623    0.842880    
#> 488: 0.791875    1.020157    3.457007    0.365497    0.005764    0.013615    0.842937    
#> 489: 0.792005    1.020155    3.456997    0.365768    0.005768    0.013603    0.842937    
#> 490: 0.792171    1.020167    3.457023    0.366122    0.005775    0.013591    0.842966    
#> 491: 0.792247    1.020173    3.457096    0.365990    0.005783    0.013601    0.842960    
#> 492: 0.792270    1.020181    3.457093    0.366035    0.005788    0.013612    0.842963    
#> 493: 0.792303    1.020210    3.457147    0.365726    0.005802    0.013614    0.842986    
#> 494: 0.792338    1.020284    3.457183    0.365592    0.005812    0.013614    0.843000    
#> 495: 0.792442    1.020350    3.457200    0.365916    0.005815    0.013613    0.842959    
#> 496: 0.792482    1.020389    3.457134    0.365845    0.005812    0.013607    0.842974    
#> 497: 0.792407    1.020368    3.457127    0.365900    0.005814    0.013619    0.843020    
#> 498: 0.792431    1.020345    3.457121    0.365833    0.005823    0.013616    0.842991    
#> 499: 0.792536    1.020374    3.457088    0.365928    0.005828    0.013611    0.842940    
#> 500: 0.792491    1.020415    3.457017    0.366070    0.005832    0.013607    0.842839    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.344457    0.970133    3.443991    0.392401    0.081047    0.016800    1.713748    
#> 002: 0.521271    0.996986    3.465222    0.372781    0.076995    0.015960    1.132068    
#> 003: 0.698835    0.996110    3.478525    0.354142    0.073145    0.015162    0.965811    
#> 004: 0.683957    1.033719    3.493325    0.336435    0.069488    0.014404    0.835302    
#> 005: 0.756663    1.048275    3.491228    0.319613    0.066013    0.013684    0.778284    
#> 006: 0.799369    1.036775    3.487569    0.352429    0.062713    0.013000    0.719285    
#> 007: 0.736228    1.062361    3.484168    0.334808    0.059577    0.012350    0.711787    
#> 008: 0.742930    1.057296    3.489309    0.318067    0.057131    0.011732    0.704680    
#> 009: 0.710704    1.033097    3.484796    0.351963    0.054275    0.011146    0.674539    
#> 010: 0.711384    1.040740    3.481419    0.346167    0.051561    0.010588    0.694358    
#> 011: 0.784329    1.056594    3.480203    0.409072    0.064473    0.010059    0.693399    
#> 012: 0.793468    1.061401    3.473426    0.388618    0.061249    0.009556    0.677754    
#> 013: 0.750629    1.059308    3.473579    0.409891    0.059222    0.010131    0.673123    
#> 014: 0.808691    1.054521    3.485136    0.434283    0.056261    0.010057    0.673807    
#> 015: 0.814696    1.051581    3.498686    0.412569    0.053448    0.010712    0.661941    
#> 016: 0.819898    1.056142    3.508809    0.395211    0.052932    0.012606    0.664479    
#> 017: 0.796782    1.053763    3.505254    0.465928    0.050285    0.012059    0.659671    
#> 018: 0.841732    1.050579    3.489735    0.490404    0.065306    0.012361    0.650784    
#> 019: 0.804624    1.055452    3.489558    0.465884    0.063862    0.011743    0.657362    
#> 020: 0.780477    1.065103    3.494292    0.442590    0.060669    0.011155    0.672199    
#> 021: 0.806922    1.058978    3.498178    0.420460    0.057635    0.010598    0.651047    
#> 022: 0.791654    1.053248    3.500518    0.399437    0.054753    0.010174    0.650846    
#> 023: 0.879943    1.057361    3.504190    0.463485    0.052016    0.011360    0.670066    
#> 024: 0.816931    1.069150    3.508038    0.441958    0.049415    0.010792    0.655352    
#> 025: 0.820649    1.049206    3.508472    0.419860    0.048300    0.010640    0.664868    
#> 026: 0.798164    1.071147    3.486289    0.430222    0.045885    0.010224    0.656040    
#> 027: 0.774393    1.079652    3.479242    0.422616    0.043591    0.009781    0.673193    
#> 028: 0.806357    1.069958    3.483871    0.421181    0.046448    0.009631    0.644536    
#> 029: 0.837714    1.062786    3.483042    0.483719    0.059737    0.011068    0.667171    
#> 030: 0.786019    1.070780    3.481446    0.459533    0.056750    0.012081    0.672984    
#> 031: 0.806738    1.063419    3.491302    0.520239    0.053913    0.011620    0.668798    
#> 032: 0.776378    1.035874    3.489597    0.498350    0.056391    0.011039    0.675657    
#> 033: 0.752248    1.067804    3.480730    0.473433    0.062519    0.010487    0.676431    
#> 034: 0.798185    1.079882    3.484916    0.459295    0.059393    0.009962    0.674061    
#> 035: 0.784029    1.059072    3.482842    0.493921    0.056423    0.009464    0.660358    
#> 036: 0.779689    1.073287    3.483382    0.469225    0.063134    0.008991    0.647185    
#> 037: 0.803140    1.075190    3.485374    0.454900    0.066394    0.008883    0.672942    
#> 038: 0.813738    1.062135    3.478515    0.462865    0.064730    0.010249    0.674455    
#> 039: 0.795101    1.050281    3.487381    0.487295    0.061494    0.011018    0.646037    
#> 040: 0.834956    1.064005    3.492796    0.555168    0.058419    0.010494    0.665530    
#> 041: 0.790851    1.063108    3.489572    0.527409    0.055726    0.010798    0.657494    
#> 042: 0.807049    1.054879    3.486848    0.501039    0.052940    0.011004    0.645396    
#> 043: 0.785680    1.061551    3.482265    0.524702    0.050293    0.010454    0.668029    
#> 044: 0.729833    1.070733    3.480324    0.498466    0.048571    0.009932    0.662169    
#> 045: 0.759494    1.085374    3.476117    0.473543    0.047778    0.009793    0.655681    
#> 046: 0.770638    1.062085    3.482382    0.479000    0.045389    0.010185    0.650520    
#> 047: 0.765963    1.066073    3.479532    0.455050    0.045556    0.011844    0.657006    
#> 048: 0.759150    1.053077    3.477913    0.432298    0.048340    0.012756    0.686361    
#> 049: 0.778776    1.063008    3.487435    0.439938    0.049488    0.012358    0.671403    
#> 050: 0.845063    1.040066    3.497900    0.417941    0.052220    0.014614    0.674285    
#> 051: 0.834164    1.057573    3.490846    0.408191    0.049609    0.015717    0.667514    
#> 052: 0.849552    1.060979    3.504047    0.516081    0.047128    0.016610    0.663158    
#> 053: 0.850536    1.052457    3.500816    0.515187    0.049486    0.015779    0.663255    
#> 054: 0.785831    1.064541    3.493640    0.489427    0.055888    0.014990    0.649699    
#> 055: 0.797220    1.066621    3.488058    0.471306    0.056449    0.014301    0.645619    
#> 056: 0.805194    1.046698    3.488494    0.485291    0.063768    0.013586    0.654088    
#> 057: 0.795445    1.057426    3.499037    0.461027    0.063243    0.012907    0.669621    
#> 058: 0.834371    1.048403    3.489301    0.447195    0.065637    0.012261    0.674124    
#> 059: 0.842828    1.026516    3.500233    0.508515    0.062355    0.012939    0.672631    
#> 060: 0.847994    1.004413    3.508603    0.515255    0.059238    0.018001    0.687019    
#> 061: 0.885180    1.009348    3.524849    0.489492    0.056276    0.018143    0.695429    
#> 062: 0.867143    1.044604    3.526360    0.470602    0.070231    0.021331    0.688562    
#> 063: 0.940118    1.023899    3.523872    0.599434    0.066719    0.022208    0.697189    
#> 064: 0.918056    1.013834    3.518940    0.608333    0.063383    0.021098    0.705646    
#> 065: 0.893468    1.016227    3.506015    0.577916    0.060214    0.020043    0.680739    
#> 066: 0.888942    1.052801    3.511603    0.648885    0.057203    0.021217    0.647567    
#> 067: 0.880462    1.048186    3.500355    0.616441    0.054343    0.020156    0.646765    
#> 068: 0.788503    1.056045    3.497892    0.585619    0.051626    0.019148    0.654553    
#> 069: 0.751037    1.050512    3.476295    0.556338    0.049045    0.018191    0.673258    
#> 070: 0.789568    1.044944    3.489253    0.557202    0.057605    0.017281    0.662213    
#> 071: 0.782904    1.076737    3.475926    0.529342    0.055819    0.016417    0.679650    
#> 072: 0.757208    1.051900    3.485678    0.502875    0.058830    0.015596    0.666643    
#> 073: 0.795382    1.079996    3.499223    0.477731    0.057944    0.014816    0.669952    
#> 074: 0.780593    1.061730    3.492935    0.453844    0.061870    0.014325    0.671102    
#> 075: 0.803743    1.066115    3.504639    0.431152    0.058776    0.013655    0.666614    
#> 076: 0.817805    1.057213    3.504492    0.496416    0.055837    0.014941    0.650019    
#> 077: 0.851444    1.046485    3.505452    0.498095    0.053045    0.015461    0.655557    
#> 078: 0.812294    1.047535    3.505632    0.473190    0.050393    0.016302    0.658810    
#> 079: 0.826992    1.057744    3.499221    0.498960    0.054513    0.017305    0.645883    
#> 080: 0.862664    1.045340    3.493583    0.548188    0.059640    0.016440    0.667651    
#> 081: 0.825387    1.060576    3.491796    0.520779    0.056658    0.017290    0.667369    
#> 082: 0.775131    1.050102    3.488538    0.494740    0.053825    0.016425    0.677470    
#> 083: 0.808740    1.057518    3.499376    0.470003    0.051134    0.015604    0.662642    
#> 084: 0.818364    1.062486    3.493278    0.446503    0.051454    0.014824    0.656456    
#> 085: 0.794719    1.067902    3.505722    0.424177    0.048882    0.016235    0.651160    
#> 086: 0.827331    1.037267    3.509096    0.402969    0.046438    0.018985    0.642329    
#> 087: 0.783865    1.039988    3.497386    0.382820    0.044116    0.018036    0.648061    
#> 088: 0.714873    1.041190    3.496264    0.363679    0.041910    0.017134    0.661340    
#> 089: 0.770813    1.055700    3.479661    0.413075    0.046051    0.017467    0.664631    
#> 090: 0.735253    1.066011    3.481743    0.450369    0.053104    0.016594    0.658467    
#> 091: 0.711393    1.051559    3.464782    0.427850    0.050449    0.015764    0.661362    
#> 092: 0.736252    1.076271    3.466469    0.430848    0.047927    0.014976    0.648984    
#> 093: 0.731523    1.065287    3.471174    0.409306    0.048557    0.014227    0.654779    
#> 094: 0.780826    1.076874    3.473332    0.480535    0.047381    0.013516    0.660668    
#> 095: 0.767683    1.081925    3.479306    0.456508    0.051746    0.012840    0.659883    
#> 096: 0.678884    1.076902    3.472484    0.433683    0.049158    0.012198    0.672730    
#> 097: 0.761953    1.070418    3.473433    0.411999    0.046700    0.011588    0.662434    
#> 098: 0.735207    1.086347    3.487542    0.391399    0.047769    0.011009    0.675942    
#> 099: 0.738369    1.055418    3.470326    0.409516    0.055612    0.010458    0.667434    
#> 100: 0.762823    1.055057    3.473537    0.429955    0.058817    0.009935    0.657004    
#> 101: 0.761672    1.061104    3.465404    0.426628    0.059205    0.009439    0.657837    
#> 102: 0.742249    1.074017    3.457907    0.405297    0.056245    0.010171    0.665025    
#> 103: 0.782704    1.071152    3.468928    0.474460    0.053432    0.009662    0.654761    
#> 104: 0.793785    1.069428    3.485160    0.483149    0.057497    0.009179    0.656801    
#> 105: 0.789412    1.057299    3.484866    0.458992    0.068584    0.008720    0.657764    
#> 106: 0.815470    1.058616    3.489389    0.438332    0.065155    0.008284    0.650497    
#> 107: 0.800336    1.073661    3.486079    0.457186    0.061897    0.007870    0.658313    
#> 108: 0.799707    1.067214    3.479667    0.450123    0.061540    0.007477    0.663720    
#> 109: 0.826882    1.067553    3.487807    0.506206    0.060478    0.007269    0.675551    
#> 110: 0.825450    1.075725    3.471440    0.598783    0.060396    0.007118    0.671295    
#> 111: 0.825930    1.073252    3.482163    0.568844    0.061558    0.007529    0.650446    
#> 112: 0.750850    1.057510    3.471493    0.540401    0.062989    0.007921    0.667140    
#> 113: 0.743921    1.087720    3.467797    0.513381    0.067630    0.007525    0.657303    
#> 114: 0.790419    1.086124    3.468499    0.524729    0.064248    0.007149    0.677505    
#> 115: 0.794106    1.049080    3.473475    0.498493    0.066233    0.006791    0.676382    
#> 116: 0.781883    1.082366    3.473107    0.473568    0.062921    0.007281    0.679545    
#> 117: 0.762050    1.091264    3.478433    0.480130    0.059775    0.007126    0.676937    
#> 118: 0.786970    1.067487    3.480261    0.456123    0.056787    0.007243    0.675564    
#> 119: 0.797628    1.070310    3.482071    0.441426    0.062332    0.008115    0.674879    
#> 120: 0.719009    1.052355    3.481402    0.419355    0.059216    0.009950    0.667258    
#> 121: 0.779658    1.081126    3.484487    0.439906    0.056255    0.010569    0.666506    
#> 122: 0.779607    1.050483    3.497289    0.417911    0.055869    0.013113    0.652331    
#> 123: 0.802720    1.075814    3.495864    0.397015    0.053075    0.012458    0.654756    
#> 124: 0.798906    1.085593    3.486145    0.377164    0.050421    0.013190    0.652160    
#> 125: 0.843406    1.075311    3.489875    0.432354    0.047900    0.012530    0.648893    
#> 126: 0.822001    1.086428    3.485113    0.410737    0.045505    0.014686    0.662557    
#> 127: 0.822799    1.084680    3.479217    0.468617    0.043230    0.014506    0.664003    
#> 128: 0.795016    1.074806    3.491725    0.445186    0.059874    0.015554    0.642723    
#> 129: 0.853731    1.054152    3.505514    0.485758    0.056880    0.015891    0.658820    
#> 130: 0.824714    1.086446    3.494803    0.461470    0.054036    0.017599    0.664870    
#> 131: 0.791409    1.062344    3.488901    0.438397    0.055196    0.016719    0.657984    
#> 132: 0.785948    1.068646    3.479834    0.416477    0.053616    0.015883    0.661791    
#> 133: 0.835285    1.050178    3.486623    0.612927    0.058145    0.015089    0.645562    
#> 134: 0.816696    1.045088    3.493509    0.631912    0.062782    0.014334    0.649393    
#> 135: 0.829859    1.029836    3.496629    0.600316    0.063246    0.013618    0.659725    
#> 136: 0.879452    1.050761    3.495624    0.685671    0.060084    0.012937    0.638822    
#> 137: 0.892076    1.037586    3.497637    0.651387    0.057080    0.012290    0.667958    
#> 138: 0.854713    1.052913    3.503359    0.618818    0.054226    0.013492    0.647480    
#> 139: 0.828097    1.055825    3.504748    0.587877    0.051515    0.012919    0.665184    
#> 140: 0.875932    1.044565    3.506222    0.559037    0.056268    0.012273    0.672947    
#> 141: 0.854737    1.042334    3.507022    0.544779    0.053455    0.011660    0.667664    
#> 142: 0.858371    1.022198    3.510963    0.533390    0.050782    0.011143    0.663091    
#> 143: 0.829138    1.048269    3.505432    0.517259    0.048243    0.012066    0.676109    
#> 144: 0.898967    1.044649    3.519882    0.491396    0.045831    0.011463    0.667150    
#> 145: 0.844675    1.047540    3.501522    0.466826    0.052124    0.010890    0.665971    
#> 146: 0.819339    1.049644    3.515955    0.443485    0.049518    0.011064    0.675331    
#> 147: 0.790408    1.034444    3.507680    0.421311    0.047042    0.010511    0.666018    
#> 148: 0.798933    1.033439    3.513021    0.471031    0.044690    0.009985    0.663594    
#> 149: 0.817213    1.030690    3.508237    0.468228    0.047763    0.010170    0.659752    
#> 150: 0.841587    1.041279    3.501880    0.471497    0.050588    0.010591    0.679361    
#> 151: 0.798291    1.069794    3.496577    0.463203    0.051896    0.010278    0.664243    
#> 152: 0.808874    1.046907    3.508815    0.500489    0.041814    0.010772    0.667045    
#> 153: 0.812680    1.053405    3.500708    0.456079    0.052773    0.012878    0.661349    
#> 154: 0.886830    1.053844    3.508987    0.548919    0.051449    0.015549    0.664235    
#> 155: 0.819800    1.043615    3.494898    0.473716    0.063721    0.015176    0.649891    
#> 156: 0.807525    1.061757    3.502637    0.423813    0.065517    0.010688    0.668684    
#> 157: 0.862081    1.052168    3.507486    0.500899    0.067950    0.010578    0.663752    
#> 158: 0.832590    1.062025    3.497632    0.447250    0.060690    0.010998    0.659969    
#> 159: 0.770863    1.073991    3.494453    0.401163    0.063062    0.009519    0.645469    
#> 160: 0.813921    1.037571    3.496682    0.468926    0.071765    0.009906    0.641822    
#> 161: 0.790955    1.061566    3.486728    0.514657    0.056791    0.010284    0.658299    
#> 162: 0.809374    1.072913    3.476413    0.546028    0.056301    0.012022    0.656443    
#> 163: 0.818619    1.066194    3.479311    0.506925    0.063442    0.009997    0.650971    
#> 164: 0.807616    1.068652    3.483145    0.557246    0.062860    0.010825    0.643050    
#> 165: 0.794090    1.057552    3.486956    0.490584    0.054997    0.011453    0.640868    
#> 166: 0.837655    1.086518    3.483829    0.714592    0.051210    0.011485    0.662109    
#> 167: 0.868171    1.101529    3.491715    0.745448    0.047918    0.011019    0.670621    
#> 168: 0.905525    1.092656    3.500564    0.634326    0.049186    0.012710    0.665875    
#> 169: 0.869978    1.100543    3.482127    0.629340    0.053527    0.011706    0.661480    
#> 170: 0.862048    1.081094    3.478519    0.707747    0.061780    0.011652    0.668286    
#> 171: 0.761986    1.074156    3.473591    0.519559    0.052767    0.011981    0.650785    
#> 172: 0.759223    1.086716    3.471361    0.489028    0.048689    0.011422    0.646918    
#> 173: 0.767296    1.113351    3.464753    0.470892    0.049488    0.012353    0.655038    
#> 174: 0.803822    1.085713    3.480210    0.495730    0.045649    0.014332    0.648199    
#> 175: 0.791613    1.084552    3.471979    0.475192    0.056210    0.013179    0.652329    
#> 176: 0.756188    1.078394    3.486449    0.403602    0.058302    0.010720    0.662572    
#> 177: 0.804363    1.081083    3.491492    0.458133    0.053025    0.012787    0.649053    
#> 178: 0.796802    1.069688    3.494422    0.462242    0.053860    0.014652    0.652166    
#> 179: 0.853169    1.064988    3.497999    0.445537    0.056451    0.013826    0.673736    
#> 180: 0.831478    1.050070    3.498795    0.520778    0.044762    0.012583    0.651137    
#> 181: 0.788122    1.038200    3.478798    0.473823    0.040266    0.013796    0.653843    
#> 182: 0.734000    1.044237    3.471042    0.460543    0.042930    0.012641    0.681795    
#> 183: 0.769395    1.069812    3.464756    0.494437    0.044183    0.012757    0.656192    
#> 184: 0.758333    1.063267    3.470056    0.525365    0.035746    0.012177    0.650619    
#> 185: 0.768232    1.082441    3.466835    0.527514    0.042420    0.014868    0.660854    
#> 186: 0.777210    1.106872    3.473669    0.526974    0.051734    0.018377    0.675905    
#> 187: 0.759929    1.102389    3.481121    0.543759    0.050987    0.016640    0.660017    
#> 188: 0.760061    1.106194    3.482772    0.476576    0.045829    0.014589    0.676104    
#> 189: 0.751837    1.095460    3.483268    0.487028    0.042661    0.014926    0.684413    
#> 190: 0.781974    1.077657    3.492911    0.523808    0.039094    0.016235    0.663039    
#> 191: 0.736876    1.087482    3.472855    0.408677    0.032798    0.015175    0.647771    
#> 192: 0.742553    1.082374    3.473197    0.394434    0.038133    0.014265    0.660459    
#> 193: 0.785418    1.101380    3.479620    0.417391    0.040984    0.015680    0.674248    
#> 194: 0.767757    1.089656    3.472718    0.431800    0.051881    0.014348    0.680478    
#> 195: 0.745963    1.064333    3.475377    0.446347    0.041471    0.014442    0.681312    
#> 196: 0.817633    1.061526    3.489953    0.498035    0.043819    0.014469    0.667805    
#> 197: 0.750185    1.063190    3.496031    0.414714    0.042635    0.016898    0.684922    
#> 198: 0.810631    1.069327    3.492091    0.348546    0.039744    0.017686    0.669616    
#> 199: 0.762427    1.059105    3.491831    0.423875    0.056247    0.016010    0.655187    
#> 200: 0.854890    1.044483    3.500805    0.508440    0.064345    0.016073    0.657921    
#> 201: 0.827502    1.047692    3.497334    0.481775    0.057951    0.016363    0.658853    
#> 202: 0.812259    1.047951    3.497031    0.475807    0.053800    0.017648    0.661958    
#> 203: 0.811182    1.045146    3.496439    0.458278    0.050041    0.018645    0.664355    
#> 204: 0.817037    1.042557    3.499827    0.451620    0.047074    0.018458    0.668632    
#> 205: 0.817192    1.045347    3.501701    0.439057    0.045113    0.018871    0.672951    
#> 206: 0.814066    1.049190    3.501126    0.432305    0.044502    0.018327    0.673587    
#> 207: 0.808090    1.051441    3.498755    0.427989    0.043870    0.017749    0.671200    
#> 208: 0.806299    1.052574    3.497828    0.424344    0.043257    0.017440    0.669150    
#> 209: 0.805160    1.050604    3.496607    0.427770    0.042651    0.017284    0.667908    
#> 210: 0.805732    1.049709    3.497428    0.429614    0.042578    0.017112    0.667520    
#> 211: 0.806809    1.049548    3.498422    0.423842    0.043374    0.016868    0.666563    
#> 212: 0.808124    1.049752    3.498553    0.421896    0.043242    0.016871    0.666042    
#> 213: 0.810456    1.047969    3.499185    0.422992    0.042619    0.016675    0.667802    
#> 214: 0.813521    1.047529    3.499805    0.426466    0.042323    0.016551    0.668863    
#> 215: 0.813136    1.047630    3.500551    0.426237    0.041834    0.016593    0.669506    
#> 216: 0.814276    1.047086    3.500595    0.424450    0.041843    0.016495    0.671101    
#> 217: 0.810344    1.047541    3.500005    0.419857    0.041535    0.016404    0.670755    
#> 218: 0.808488    1.048733    3.498569    0.423148    0.041315    0.016490    0.669846    
#> 219: 0.805725    1.049157    3.497069    0.425829    0.041053    0.016531    0.669413    
#> 220: 0.801648    1.049638    3.496441    0.427270    0.040511    0.016571    0.669364    
#> 221: 0.802596    1.049698    3.496300    0.432494    0.040369    0.016485    0.668288    
#> 222: 0.804254    1.049787    3.495844    0.439409    0.040692    0.016405    0.667215    
#> 223: 0.805170    1.050289    3.495748    0.439972    0.040809    0.016471    0.666340    
#> 224: 0.807364    1.051139    3.495946    0.440821    0.040965    0.016527    0.665853    
#> 225: 0.806570    1.050154    3.496463    0.443455    0.040970    0.016538    0.665818    
#> 226: 0.807591    1.048784    3.496501    0.445666    0.040965    0.016479    0.666105    
#> 227: 0.807627    1.048074    3.496750    0.446953    0.041098    0.016442    0.665799    
#> 228: 0.809498    1.048890    3.496374    0.451784    0.041365    0.016397    0.665475    
#> 229: 0.809149    1.048890    3.496116    0.454268    0.041746    0.016372    0.664909    
#> 230: 0.808976    1.048538    3.495727    0.455236    0.041885    0.016308    0.664841    
#> 231: 0.808807    1.049075    3.495662    0.455718    0.042210    0.016233    0.664219    
#> 232: 0.807402    1.049469    3.495820    0.453713    0.042523    0.016159    0.664155    
#> 233: 0.806742    1.049119    3.496046    0.452534    0.042748    0.016067    0.664549    
#> 234: 0.806557    1.049197    3.496023    0.451676    0.042866    0.016024    0.664540    
#> 235: 0.806239    1.049473    3.495870    0.451062    0.042937    0.015979    0.664548    
#> 236: 0.805988    1.050160    3.495675    0.448534    0.043110    0.015942    0.664520    
#> 237: 0.806317    1.050627    3.495422    0.448788    0.043291    0.015973    0.664543    
#> 238: 0.805934    1.050965    3.495304    0.446805    0.043529    0.015878    0.665122    
#> 239: 0.804565    1.051638    3.494936    0.445748    0.043822    0.015835    0.665038    
#> 240: 0.803047    1.051747    3.494707    0.444993    0.043912    0.015742    0.664911    
#> 241: 0.802113    1.051349    3.494467    0.445049    0.044089    0.015652    0.664574    
#> 242: 0.802172    1.051202    3.494083    0.444770    0.044159    0.015583    0.664620    
#> 243: 0.801136    1.051466    3.493935    0.444815    0.044212    0.015477    0.664956    
#> 244: 0.800723    1.051534    3.493913    0.446313    0.044220    0.015430    0.665223    
#> 245: 0.801302    1.051160    3.494074    0.447241    0.044437    0.015436    0.665225    
#> 246: 0.801385    1.051030    3.493929    0.448332    0.044446    0.015452    0.665323    
#> 247: 0.801644    1.050645    3.494189    0.447052    0.044525    0.015436    0.665027    
#> 248: 0.801403    1.050810    3.494262    0.446690    0.044505    0.015361    0.664649    
#> 249: 0.801339    1.051171    3.494195    0.446972    0.044637    0.015301    0.664467    
#> 250: 0.802011    1.051677    3.494294    0.446161    0.044822    0.015286    0.664496    
#> 251: 0.803052    1.051981    3.494587    0.446596    0.045005    0.015261    0.664405    
#> 252: 0.803764    1.052303    3.494974    0.445614    0.045239    0.015287    0.664438    
#> 253: 0.803956    1.052419    3.495239    0.445591    0.045356    0.015346    0.664349    
#> 254: 0.804094    1.052904    3.495278    0.445206    0.045522    0.015374    0.664482    
#> 255: 0.803690    1.053077    3.495288    0.444723    0.045473    0.015383    0.664671    
#> 256: 0.803831    1.052981    3.495259    0.445420    0.045373    0.015336    0.664856    
#> 257: 0.804169    1.052778    3.495046    0.447571    0.045341    0.015253    0.664988    
#> 258: 0.803511    1.052428    3.495101    0.446336    0.045343    0.015202    0.665143    
#> 259: 0.803040    1.052124    3.495062    0.446483    0.045401    0.015204    0.665290    
#> 260: 0.803048    1.052104    3.494971    0.448690    0.045456    0.015180    0.664980    
#> 261: 0.803341    1.051874    3.495032    0.450144    0.045558    0.015160    0.664822    
#> 262: 0.803594    1.052080    3.495071    0.450070    0.045609    0.015080    0.664882    
#> 263: 0.803854    1.052217    3.495065    0.450749    0.045751    0.015063    0.665084    
#> 264: 0.803663    1.052324    3.494909    0.452098    0.045659    0.015031    0.665261    
#> 265: 0.803095    1.052406    3.494791    0.451024    0.045680    0.015000    0.665599    
#> 266: 0.802315    1.052589    3.494720    0.450402    0.045628    0.014989    0.665874    
#> 267: 0.801273    1.053045    3.494712    0.449088    0.045674    0.014995    0.666085    
#> 268: 0.800887    1.053088    3.494473    0.448230    0.045717    0.014963    0.666106    
#> 269: 0.801653    1.053080    3.494444    0.448742    0.045829    0.014971    0.666077    
#> 270: 0.802103    1.053250    3.494440    0.449283    0.045902    0.014938    0.666031    
#> 271: 0.802842    1.053106    3.494506    0.450293    0.045815    0.014890    0.666137    
#> 272: 0.803536    1.052635    3.494627    0.451974    0.045708    0.014844    0.666645    
#> 273: 0.803821    1.052711    3.494712    0.452200    0.045749    0.014798    0.667075    
#> 274: 0.804332    1.052778    3.494856    0.452355    0.045689    0.014760    0.667197    
#> 275: 0.804329    1.052807    3.494856    0.452012    0.045561    0.014726    0.667296    
#> 276: 0.804256    1.052753    3.495091    0.451616    0.045570    0.014696    0.667469    
#> 277: 0.804229    1.052738    3.495313    0.451909    0.045550    0.014665    0.667609    
#> 278: 0.804424    1.052893    3.495409    0.453146    0.045588    0.014603    0.667779    
#> 279: 0.805115    1.052681    3.495621    0.454092    0.045703    0.014579    0.667978    
#> 280: 0.805380    1.052678    3.495665    0.454008    0.045860    0.014563    0.667835    
#> 281: 0.805352    1.052719    3.495747    0.453585    0.045838    0.014545    0.667700    
#> 282: 0.805158    1.052767    3.495842    0.452779    0.045886    0.014533    0.667734    
#> 283: 0.805384    1.052856    3.495945    0.452529    0.045900    0.014545    0.667963    
#> 284: 0.805646    1.052799    3.495998    0.452400    0.045808    0.014535    0.668040    
#> 285: 0.805642    1.052970    3.495876    0.452600    0.045865    0.014507    0.667985    
#> 286: 0.805421    1.053070    3.495745    0.452548    0.046095    0.014468    0.667937    
#> 287: 0.804946    1.053436    3.495464    0.453286    0.046059    0.014447    0.667998    
#> 288: 0.804850    1.053529    3.495317    0.453326    0.046284    0.014411    0.667916    
#> 289: 0.805264    1.053576    3.495333    0.453085    0.046337    0.014382    0.667836    
#> 290: 0.805429    1.053508    3.495303    0.452545    0.046397    0.014393    0.667979    
#> 291: 0.805308    1.053540    3.495432    0.451957    0.046391    0.014399    0.667858    
#> 292: 0.805234    1.053446    3.495486    0.451982    0.046366    0.014401    0.667699    
#> 293: 0.804774    1.053490    3.495330    0.451663    0.046359    0.014408    0.667543    
#> 294: 0.804679    1.053555    3.495265    0.451545    0.046413    0.014400    0.667344    
#> 295: 0.804619    1.053291    3.495206    0.452490    0.046422    0.014407    0.667224    
#> 296: 0.805054    1.053166    3.495183    0.453155    0.046317    0.014466    0.667410    
#> 297: 0.805140    1.053139    3.495157    0.453429    0.046211    0.014526    0.667281    
#> 298: 0.805678    1.053130    3.495214    0.454930    0.046106    0.014559    0.667108    
#> 299: 0.806287    1.053173    3.495284    0.456169    0.046049    0.014563    0.666969    
#> 300: 0.806690    1.052975    3.495458    0.455836    0.046068    0.014536    0.666839    
#> 301: 0.807151    1.052743    3.495530    0.455513    0.046056    0.014530    0.667039    
#> 302: 0.807305    1.052765    3.495548    0.455741    0.046076    0.014512    0.666969    
#> 303: 0.807660    1.052824    3.495650    0.455562    0.046076    0.014517    0.666727    
#> 304: 0.807661    1.052998    3.495635    0.455603    0.046063    0.014522    0.666730    
#> 305: 0.807557    1.052869    3.495672    0.455586    0.046137    0.014520    0.666495    
#> 306: 0.807468    1.052765    3.495589    0.455611    0.046155    0.014485    0.666439    
#> 307: 0.807250    1.052803    3.495402    0.455813    0.046278    0.014455    0.666544    
#> 308: 0.806798    1.052805    3.495266    0.455799    0.046429    0.014461    0.666506    
#> 309: 0.806453    1.052824    3.495138    0.455631    0.046437    0.014475    0.666651    
#> 310: 0.806604    1.052774    3.495047    0.456570    0.046460    0.014498    0.666542    
#> 311: 0.806629    1.052753    3.494932    0.457104    0.046475    0.014508    0.666461    
#> 312: 0.806193    1.052735    3.494770    0.456993    0.046520    0.014507    0.666609    
#> 313: 0.805858    1.052550    3.494713    0.456781    0.046520    0.014528    0.666798    
#> 314: 0.805411    1.052615    3.494648    0.456264    0.046553    0.014517    0.666773    
#> 315: 0.805174    1.052767    3.494590    0.456611    0.046645    0.014519    0.666719    
#> 316: 0.805156    1.052844    3.494578    0.457164    0.046704    0.014514    0.666684    
#> 317: 0.805246    1.052933    3.494593    0.457124    0.046724    0.014505    0.666648    
#> 318: 0.805260    1.053095    3.494452    0.457402    0.046642    0.014491    0.666715    
#> 319: 0.805317    1.053141    3.494479    0.457076    0.046600    0.014502    0.666727    
#> 320: 0.804784    1.053206    3.494301    0.457140    0.046601    0.014495    0.666793    
#> 321: 0.804188    1.053363    3.494074    0.457092    0.046626    0.014498    0.666799    
#> 322: 0.804033    1.053530    3.493919    0.456738    0.046731    0.014498    0.666752    
#> 323: 0.803608    1.053577    3.493850    0.456843    0.046739    0.014521    0.666583    
#> 324: 0.803388    1.053804    3.493795    0.456396    0.046726    0.014512    0.666440    
#> 325: 0.803252    1.054074    3.493678    0.456065    0.046721    0.014495    0.666369    
#> 326: 0.803085    1.054055    3.493591    0.455982    0.046720    0.014489    0.666187    
#> 327: 0.802911    1.054153    3.493561    0.455787    0.046837    0.014486    0.666135    
#> 328: 0.802821    1.054196    3.493512    0.455508    0.046801    0.014463    0.666153    
#> 329: 0.803081    1.054333    3.493546    0.455710    0.046867    0.014452    0.666058    
#> 330: 0.802900    1.054289    3.493588    0.455396    0.046819    0.014430    0.666062    
#> 331: 0.802931    1.054491    3.493607    0.454578    0.046802    0.014400    0.666023    
#> 332: 0.802882    1.054468    3.493673    0.454084    0.046733    0.014386    0.666096    
#> 333: 0.802514    1.054496    3.493595    0.453343    0.046731    0.014367    0.666012    
#> 334: 0.802208    1.054530    3.493436    0.453141    0.046711    0.014345    0.665846    
#> 335: 0.801988    1.054595    3.493379    0.452178    0.046678    0.014335    0.665790    
#> 336: 0.801558    1.054757    3.493302    0.451429    0.046682    0.014335    0.665687    
#> 337: 0.801223    1.055026    3.493175    0.451300    0.046666    0.014324    0.665662    
#> 338: 0.801137    1.055215    3.493154    0.450985    0.046697    0.014317    0.665587    
#> 339: 0.800896    1.055301    3.493139    0.450951    0.046710    0.014314    0.665561    
#> 340: 0.800900    1.055153    3.493094    0.451035    0.046790    0.014301    0.665509    
#> 341: 0.801111    1.055101    3.493119    0.451457    0.046920    0.014301    0.665368    
#> 342: 0.800834    1.055042    3.493072    0.451067    0.046964    0.014299    0.665194    
#> 343: 0.800455    1.055054    3.493002    0.451153    0.047071    0.014269    0.664991    
#> 344: 0.800605    1.055102    3.493020    0.451603    0.047084    0.014259    0.664907    
#> 345: 0.800694    1.055157    3.493033    0.451793    0.047098    0.014253    0.664819    
#> 346: 0.800782    1.055268    3.492966    0.451827    0.047110    0.014233    0.664743    
#> 347: 0.800857    1.055178    3.492855    0.451998    0.047178    0.014236    0.664767    
#> 348: 0.800736    1.055198    3.492799    0.452870    0.047244    0.014224    0.664673    
#> 349: 0.800716    1.055247    3.492725    0.453273    0.047223    0.014209    0.664676    
#> 350: 0.800742    1.055153    3.492648    0.453680    0.047211    0.014188    0.664759    
#> 351: 0.800713    1.055204    3.492593    0.453171    0.047236    0.014167    0.664777    
#> 352: 0.800271    1.055300    3.492571    0.452760    0.047299    0.014175    0.664864    
#> 353: 0.800321    1.055400    3.492577    0.452125    0.047228    0.014179    0.664840    
#> 354: 0.800275    1.055342    3.492552    0.451372    0.047132    0.014195    0.664808    
#> 355: 0.800711    1.055241    3.492605    0.451232    0.047091    0.014206    0.664810    
#> 356: 0.800560    1.055225    3.492648    0.450699    0.047123    0.014212    0.664914    
#> 357: 0.800770    1.055269    3.492725    0.451106    0.047098    0.014202    0.664866    
#> 358: 0.800946    1.055334    3.492789    0.451403    0.047136    0.014192    0.664817    
#> 359: 0.800796    1.055446    3.492773    0.450950    0.047167    0.014177    0.664865    
#> 360: 0.800621    1.055416    3.492681    0.450290    0.047215    0.014160    0.664882    
#> 361: 0.800523    1.055436    3.492638    0.450138    0.047203    0.014137    0.664961    
#> 362: 0.800651    1.055446    3.492613    0.450334    0.047215    0.014128    0.664856    
#> 363: 0.800799    1.055441    3.492628    0.449767    0.047180    0.014123    0.664887    
#> 364: 0.800818    1.055570    3.492650    0.449205    0.047233    0.014128    0.664953    
#> 365: 0.800761    1.055579    3.492686    0.448984    0.047244    0.014136    0.665035    
#> 366: 0.800620    1.055650    3.492590    0.449229    0.047272    0.014124    0.665085    
#> 367: 0.800610    1.055760    3.492547    0.449502    0.047325    0.014118    0.665064    
#> 368: 0.800759    1.055829    3.492480    0.449857    0.047263    0.014118    0.665027    
#> 369: 0.800676    1.055851    3.492472    0.449847    0.047291    0.014110    0.665035    
#> 370: 0.800547    1.055898    3.492484    0.449740    0.047323    0.014142    0.664988    
#> 371: 0.800340    1.055914    3.492488    0.449430    0.047326    0.014144    0.664921    
#> 372: 0.800267    1.056018    3.492441    0.449345    0.047339    0.014132    0.664936    
#> 373: 0.800146    1.056123    3.492365    0.449646    0.047332    0.014115    0.664905    
#> 374: 0.800021    1.056225    3.492218    0.450419    0.047357    0.014110    0.664773    
#> 375: 0.800006    1.056362    3.492141    0.451070    0.047443    0.014103    0.664731    
#> 376: 0.799929    1.056505    3.492108    0.450840    0.047512    0.014091    0.664630    
#> 377: 0.799649    1.056603    3.492104    0.450570    0.047564    0.014071    0.664617    
#> 378: 0.799416    1.056678    3.492055    0.450417    0.047573    0.014052    0.664540    
#> 379: 0.799244    1.056584    3.492054    0.450010    0.047574    0.014025    0.664478    
#> 380: 0.799037    1.056541    3.492016    0.449387    0.047575    0.014001    0.664494    
#> 381: 0.798842    1.056507    3.492046    0.448836    0.047574    0.013981    0.664504    
#> 382: 0.798688    1.056511    3.492068    0.448515    0.047589    0.013977    0.664423    
#> 383: 0.798869    1.056498    3.492095    0.448264    0.047588    0.013961    0.664452    
#> 384: 0.798694    1.056455    3.492152    0.447991    0.047565    0.013955    0.664452    
#> 385: 0.798595    1.056344    3.492148    0.447963    0.047600    0.013951    0.664459    
#> 386: 0.798568    1.056476    3.492190    0.448051    0.047610    0.013954    0.664519    
#> 387: 0.798892    1.056546    3.492292    0.448509    0.047615    0.013967    0.664533    
#> 388: 0.798943    1.056542    3.492376    0.448433    0.047590    0.013974    0.664574    
#> 389: 0.798906    1.056402    3.492440    0.448216    0.047551    0.013991    0.664502    
#> 390: 0.798807    1.056412    3.492426    0.447964    0.047487    0.013993    0.664527    
#> 391: 0.798951    1.056394    3.492419    0.447868    0.047449    0.013989    0.664495    
#> 392: 0.798945    1.056364    3.492473    0.447553    0.047396    0.013979    0.664550    
#> 393: 0.798867    1.056284    3.492476    0.447012    0.047366    0.013981    0.664527    
#> 394: 0.799006    1.056239    3.492443    0.447255    0.047372    0.013979    0.664528    
#> 395: 0.799164    1.056306    3.492478    0.447296    0.047340    0.013998    0.664578    
#> 396: 0.799122    1.056377    3.492474    0.447301    0.047315    0.013999    0.664641    
#> 397: 0.799155    1.056345    3.492470    0.447199    0.047299    0.014014    0.664741    
#> 398: 0.799229    1.056332    3.492423    0.447122    0.047271    0.014017    0.664784    
#> 399: 0.799345    1.056413    3.492447    0.447205    0.047263    0.014010    0.664866    
#> 400: 0.799426    1.056511    3.492436    0.447228    0.047244    0.013998    0.664899    
#> 401: 0.799518    1.056609    3.492419    0.447596    0.047304    0.013974    0.664994    
#> 402: 0.799282    1.056683    3.492360    0.447223    0.047320    0.013949    0.665025    
#> 403: 0.799356    1.056684    3.492346    0.447537    0.047374    0.013917    0.664987    
#> 404: 0.799485    1.056722    3.492273    0.448285    0.047316    0.013894    0.664952    
#> 405: 0.799412    1.056722    3.492247    0.448858    0.047273    0.013872    0.665010    
#> 406: 0.799417    1.056785    3.492219    0.449173    0.047250    0.013871    0.665057    
#> 407: 0.799370    1.056924    3.492203    0.448957    0.047296    0.013866    0.664999    
#> 408: 0.799274    1.057099    3.492177    0.448617    0.047311    0.013849    0.665094    
#> 409: 0.799046    1.057157    3.492076    0.448354    0.047279    0.013838    0.665052    
#> 410: 0.798790    1.057223    3.491960    0.448154    0.047269    0.013838    0.665040    
#> 411: 0.798621    1.057118    3.491914    0.448038    0.047249    0.013825    0.665076    
#> 412: 0.798564    1.057156    3.491863    0.448229    0.047257    0.013809    0.665094    
#> 413: 0.798713    1.057133    3.491847    0.448745    0.047257    0.013799    0.665040    
#> 414: 0.798655    1.057099    3.491872    0.449184    0.047207    0.013786    0.665057    
#> 415: 0.798930    1.057086    3.491880    0.449794    0.047163    0.013793    0.664992    
#> 416: 0.799101    1.057152    3.491860    0.450375    0.047170    0.013801    0.664905    
#> 417: 0.799021    1.057175    3.491835    0.450319    0.047157    0.013810    0.664843    
#> 418: 0.798819    1.057222    3.491839    0.450022    0.047214    0.013805    0.664833    
#> 419: 0.798707    1.057337    3.491784    0.450274    0.047273    0.013795    0.664774    
#> 420: 0.798898    1.057349    3.491768    0.450525    0.047337    0.013774    0.664662    
#> 421: 0.798716    1.057324    3.491779    0.450370    0.047378    0.013747    0.664649    
#> 422: 0.798881    1.057234    3.491808    0.450142    0.047378    0.013725    0.664711    
#> 423: 0.799001    1.057131    3.491841    0.450029    0.047395    0.013723    0.664756    
#> 424: 0.798829    1.057123    3.491761    0.449732    0.047431    0.013711    0.664709    
#> 425: 0.798841    1.057171    3.491732    0.449557    0.047417    0.013705    0.664728    
#> 426: 0.798855    1.057201    3.491752    0.449411    0.047418    0.013694    0.664654    
#> 427: 0.798719    1.057192    3.491791    0.449313    0.047385    0.013696    0.664592    
#> 428: 0.798542    1.057225    3.491792    0.449121    0.047392    0.013707    0.664511    
#> 429: 0.798460    1.057194    3.491789    0.449010    0.047407    0.013693    0.664470    
#> 430: 0.798398    1.057203    3.491804    0.449180    0.047370    0.013696    0.664491    
#> 431: 0.798347    1.057187    3.491757    0.449174    0.047375    0.013691    0.664424    
#> 432: 0.798321    1.057250    3.491775    0.449038    0.047369    0.013703    0.664461    
#> 433: 0.798417    1.057282    3.491859    0.448857    0.047316    0.013705    0.664535    
#> 434: 0.798216    1.057204    3.491855    0.448582    0.047269    0.013710    0.664485    
#> 435: 0.798259    1.057179    3.491847    0.448317    0.047235    0.013715    0.664454    
#> 436: 0.798200    1.057180    3.491899    0.447675    0.047219    0.013706    0.664484    
#> 437: 0.798185    1.057165    3.491908    0.447508    0.047214    0.013697    0.664506    
#> 438: 0.798158    1.057292    3.491871    0.447743    0.047195    0.013686    0.664426    
#> 439: 0.798272    1.057357    3.491880    0.447925    0.047210    0.013679    0.664360    
#> 440: 0.798175    1.057392    3.491912    0.447886    0.047245    0.013675    0.664398    
#> 441: 0.798005    1.057409    3.491905    0.447676    0.047278    0.013666    0.664396    
#> 442: 0.797753    1.057452    3.491890    0.447598    0.047328    0.013666    0.664342    
#> 443: 0.797636    1.057541    3.491813    0.447612    0.047350    0.013651    0.664356    
#> 444: 0.797373    1.057537    3.491729    0.447374    0.047386    0.013640    0.664346    
#> 445: 0.797168    1.057568    3.491665    0.447192    0.047459    0.013628    0.664456    
#> 446: 0.796874    1.057641    3.491604    0.447222    0.047552    0.013613    0.664492    
#> 447: 0.797010    1.057723    3.491610    0.447579    0.047621    0.013616    0.664508    
#> 448: 0.797102    1.057761    3.491649    0.447842    0.047624    0.013610    0.664513    
#> 449: 0.797133    1.057861    3.491729    0.448047    0.047629    0.013616    0.664565    
#> 450: 0.797161    1.057902    3.491689    0.448165    0.047628    0.013618    0.664576    
#> 451: 0.797277    1.057912    3.491659    0.448341    0.047673    0.013616    0.664605    
#> 452: 0.797309    1.057990    3.491611    0.448509    0.047674    0.013604    0.664566    
#> 453: 0.797161    1.058024    3.491548    0.448628    0.047669    0.013587    0.664520    
#> 454: 0.797124    1.058128    3.491523    0.448531    0.047693    0.013573    0.664460    
#> 455: 0.797124    1.058138    3.491542    0.448346    0.047709    0.013563    0.664421    
#> 456: 0.797020    1.058166    3.491538    0.448395    0.047717    0.013555    0.664385    
#> 457: 0.797002    1.058181    3.491557    0.448422    0.047725    0.013544    0.664323    
#> 458: 0.796952    1.058324    3.491578    0.448464    0.047738    0.013539    0.664309    
#> 459: 0.796935    1.058473    3.491561    0.448673    0.047740    0.013529    0.664353    
#> 460: 0.796820    1.058548    3.491509    0.448775    0.047722    0.013550    0.664340    
#> 461: 0.796690    1.058634    3.491513    0.448600    0.047744    0.013557    0.664384    
#> 462: 0.796631    1.058718    3.491492    0.448715    0.047772    0.013549    0.664329    
#> 463: 0.796642    1.058770    3.491449    0.448898    0.047803    0.013539    0.664323    
#> 464: 0.796765    1.058807    3.491427    0.449069    0.047847    0.013525    0.664203    
#> 465: 0.796870    1.058781    3.491413    0.449248    0.047861    0.013503    0.664138    
#> 466: 0.797000    1.058814    3.491359    0.449589    0.047871    0.013488    0.664093    
#> 467: 0.796764    1.058837    3.491316    0.449881    0.047933    0.013471    0.664033    
#> 468: 0.797001    1.058864    3.491342    0.450293    0.047951    0.013466    0.664036    
#> 469: 0.797159    1.058999    3.491372    0.450333    0.047970    0.013458    0.664057    
#> 470: 0.797046    1.059035    3.491339    0.450115    0.048019    0.013457    0.664050    
#> 471: 0.796865    1.059055    3.491298    0.449933    0.048015    0.013459    0.664073    
#> 472: 0.796897    1.059063    3.491304    0.449841    0.048016    0.013459    0.664110    
#> 473: 0.796896    1.059082    3.491282    0.449836    0.048008    0.013448    0.664103    
#> 474: 0.796883    1.059072    3.491231    0.449816    0.048012    0.013434    0.664162    
#> 475: 0.796934    1.059253    3.491209    0.449755    0.048007    0.013420    0.664219    
#> 476: 0.796899    1.059328    3.491153    0.449705    0.048030    0.013405    0.664261    
#> 477: 0.796936    1.059327    3.491189    0.449813    0.048048    0.013393    0.664221    
#> 478: 0.796985    1.059326    3.491229    0.449765    0.048083    0.013385    0.664255    
#> 479: 0.797047    1.059353    3.491245    0.449653    0.048103    0.013373    0.664306    
#> 480: 0.797057    1.059360    3.491244    0.449520    0.048111    0.013357    0.664418    
#> 481: 0.797016    1.059400    3.491254    0.449373    0.048144    0.013344    0.664432    
#> 482: 0.797032    1.059405    3.491210    0.449450    0.048154    0.013334    0.664491    
#> 483: 0.796954    1.059420    3.491200    0.449418    0.048180    0.013328    0.664482    
#> 484: 0.796882    1.059326    3.491205    0.449266    0.048168    0.013323    0.664439    
#> 485: 0.796813    1.059295    3.491227    0.449076    0.048148    0.013315    0.664444    
#> 486: 0.796848    1.059306    3.491242    0.449033    0.048134    0.013309    0.664432    
#> 487: 0.796938    1.059328    3.491309    0.448837    0.048107    0.013310    0.664368    
#> 488: 0.796920    1.059254    3.491350    0.448650    0.048106    0.013300    0.664377    
#> 489: 0.796951    1.059180    3.491358    0.448416    0.048142    0.013298    0.664405    
#> 490: 0.797070    1.059192    3.491381    0.448440    0.048157    0.013302    0.664383    
#> 491: 0.797161    1.059236    3.491404    0.448581    0.048191    0.013295    0.664339    
#> 492: 0.797121    1.059280    3.491393    0.448604    0.048163    0.013285    0.664400    
#> 493: 0.797123    1.059285    3.491401    0.448468    0.048157    0.013276    0.664429    
#> 494: 0.797383    1.059295    3.491388    0.448612    0.048145    0.013265    0.664421    
#> 495: 0.797496    1.059299    3.491376    0.448607    0.048119    0.013262    0.664406    
#> 496: 0.797595    1.059288    3.491331    0.448822    0.048103    0.013266    0.664416    
#> 497: 0.797597    1.059245    3.491293    0.449268    0.048109    0.013265    0.664398    
#> 498: 0.797597    1.059241    3.491257    0.449550    0.048118    0.013261    0.664337    
#> 499: 0.797673    1.059340    3.491205    0.449769    0.048148    0.013252    0.664317    
#> 500: 0.797671    1.059300    3.491184    0.449975    0.048149    0.013252    0.664333    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.319084    0.973163    3.453535    0.392401    0.079171    0.016800    1.815211    
#> 002: 0.422084    1.052776    3.485583    0.372781    0.075212    0.015960    1.154579    
#> 003: 0.574986    1.057240    3.506722    0.354142    0.078313    0.015162    0.868606    
#> 004: 0.610703    1.089723    3.505391    0.430911    0.076799    0.014404    0.724725    
#> 005: 0.726838    1.090834    3.504827    0.537808    0.072960    0.013684    0.617009    
#> 006: 0.685924    1.107542    3.510528    0.510918    0.089716    0.013000    0.545642    
#> 007: 0.673859    1.099981    3.515159    0.563759    0.086707    0.012350    0.527334    
#> 008: 0.702713    1.102705    3.514477    0.636794    0.085613    0.013807    0.527719    
#> 009: 0.702149    1.078605    3.515846    0.615802    0.081333    0.013117    0.517003    
#> 010: 0.677214    1.083806    3.518607    0.585012    0.083247    0.012461    0.511480    
#> 011: 0.735674    1.083472    3.523811    0.555761    0.095035    0.012942    0.514744    
#> 012: 0.753971    1.075734    3.523257    0.581274    0.090283    0.013723    0.504859    
#> 013: 0.726353    1.099445    3.514052    0.588967    0.092202    0.014148    0.510953    
#> 014: 0.738501    1.100582    3.515604    0.677798    0.088565    0.013441    0.506043    
#> 015: 0.753197    1.087928    3.525367    0.643908    0.097377    0.014905    0.484624    
#> 016: 0.757221    1.082425    3.534113    0.646551    0.093788    0.014518    0.495180    
#> 017: 0.752086    1.090744    3.533353    0.614223    0.095906    0.015662    0.482084    
#> 018: 0.747281    1.078476    3.531093    0.583512    0.096308    0.016866    0.487481    
#> 019: 0.761059    1.085534    3.543996    0.554337    0.091607    0.018106    0.473540    
#> 020: 0.809406    1.080207    3.543129    0.602452    0.087027    0.017201    0.485110    
#> 021: 0.799675    1.069377    3.552762    0.604422    0.082675    0.019281    0.473154    
#> 022: 0.807527    1.071088    3.561544    0.672338    0.078542    0.018317    0.471439    
#> 023: 0.839058    1.077741    3.552268    0.658085    0.083907    0.019949    0.484158    
#> 024: 0.833910    1.089571    3.556709    0.625181    0.083377    0.020845    0.469441    
#> 025: 0.795362    1.062144    3.550111    0.593922    0.081955    0.022078    0.480561    
#> 026: 0.774871    1.082419    3.538773    0.564226    0.085485    0.021089    0.489386    
#> 027: 0.785457    1.081516    3.547036    0.547495    0.081211    0.021574    0.486627    
#> 028: 0.757467    1.090924    3.537545    0.616262    0.082343    0.020496    0.486016    
#> 029: 0.765173    1.097911    3.536074    0.608250    0.085330    0.021559    0.482609    
#> 030: 0.748622    1.104263    3.526407    0.577838    0.081063    0.020481    0.483741    
#> 031: 0.733783    1.082844    3.534228    0.634230    0.081710    0.022248    0.486824    
#> 032: 0.764631    1.075455    3.533889    0.682514    0.080466    0.021135    0.478612    
#> 033: 0.757860    1.073386    3.541462    0.649211    0.076893    0.020078    0.480059    
#> 034: 0.821172    1.079757    3.542196    0.636033    0.073048    0.019075    0.491799    
#> 035: 0.802442    1.064811    3.547237    0.625589    0.078128    0.018121    0.483976    
#> 036: 0.776020    1.080641    3.546331    0.594309    0.098469    0.017215    0.487898    
#> 037: 0.772120    1.067082    3.552230    0.564594    0.093545    0.019492    0.490295    
#> 038: 0.770386    1.054836    3.551919    0.536364    0.088868    0.019961    0.497570    
#> 039: 0.790133    1.060148    3.557598    0.557821    0.084425    0.019721    0.488584    
#> 040: 0.808835    1.085025    3.554656    0.560822    0.082500    0.018735    0.490504    
#> 041: 0.753754    1.086331    3.544113    0.532781    0.078375    0.017798    0.485221    
#> 042: 0.785758    1.088713    3.539798    0.576799    0.079030    0.018421    0.478776    
#> 043: 0.778159    1.096866    3.528423    0.686202    0.075930    0.018726    0.492682    
#> 044: 0.758339    1.090667    3.533481    0.651892    0.073758    0.019640    0.484293    
#> 045: 0.737880    1.094385    3.534318    0.619297    0.084078    0.018658    0.477264    
#> 046: 0.780506    1.068669    3.541730    0.588332    0.086164    0.017725    0.467429    
#> 047: 0.774213    1.092030    3.533436    0.570564    0.091320    0.016839    0.473838    
#> 048: 0.766164    1.097763    3.534171    0.542035    0.097775    0.015997    0.484755    
#> 049: 0.784831    1.093986    3.540667    0.612345    0.092886    0.016200    0.489979    
#> 050: 0.793419    1.058320    3.545057    0.633786    0.096331    0.017425    0.499910    
#> 051: 0.771208    1.069332    3.535726    0.605240    0.094739    0.018726    0.489945    
#> 052: 0.772292    1.074895    3.547941    0.574978    0.090002    0.017789    0.481071    
#> 053: 0.772948    1.071176    3.538878    0.571626    0.085502    0.017489    0.485987    
#> 054: 0.765551    1.073893    3.541890    0.543045    0.095992    0.016615    0.499350    
#> 055: 0.784632    1.069618    3.553290    0.550344    0.095416    0.019208    0.490147    
#> 056: 0.831074    1.042474    3.553784    0.701499    0.090645    0.019052    0.491430    
#> 057: 0.810434    1.050166    3.559738    0.678332    0.091132    0.018474    0.481905    
#> 058: 0.815444    1.055322    3.545307    0.644416    0.086576    0.017550    0.481111    
#> 059: 0.782210    1.035622    3.546661    0.649562    0.089810    0.016942    0.498207    
#> 060: 0.791206    1.055525    3.544014    0.653644    0.087409    0.016410    0.510709    
#> 061: 0.772649    1.069273    3.539977    0.620962    0.094589    0.015590    0.513900    
#> 062: 0.844212    1.069418    3.551115    0.706601    0.120291    0.014810    0.501021    
#> 063: 0.855123    1.048829    3.546227    0.684306    0.114276    0.016028    0.503682    
#> 064: 0.813149    1.078815    3.543472    0.650091    0.108562    0.016087    0.512730    
#> 065: 0.825871    1.085721    3.537958    0.637591    0.103134    0.015282    0.488287    
#> 066: 0.787299    1.082520    3.541825    0.704634    0.097977    0.015222    0.491170    
#> 067: 0.779732    1.073309    3.534430    0.704166    0.093079    0.017022    0.482801    
#> 068: 0.772724    1.096644    3.535602    0.732274    0.091564    0.016171    0.486213    
#> 069: 0.810844    1.097124    3.525180    0.777039    0.086986    0.016274    0.490471    
#> 070: 0.787746    1.096905    3.529847    0.880386    0.094055    0.015849    0.492751    
#> 071: 0.789334    1.107128    3.520005    0.892423    0.100498    0.016865    0.494716    
#> 072: 0.738773    1.069761    3.532024    0.847802    0.095473    0.016022    0.485026    
#> 073: 0.717304    1.084072    3.541771    0.805412    0.090699    0.017947    0.500089    
#> 074: 0.725445    1.061502    3.530187    0.765141    0.086164    0.019851    0.499890    
#> 075: 0.764952    1.041218    3.552918    0.726884    0.087747    0.020857    0.498480    
#> 076: 0.838041    1.070490    3.565473    0.690540    0.092750    0.021483    0.491273    
#> 077: 0.858607    1.061028    3.562700    0.656013    0.088112    0.022989    0.488325    
#> 078: 0.864676    1.076049    3.557973    0.752461    0.083707    0.022210    0.465687    
#> 079: 0.796782    1.080766    3.554837    0.714838    0.084173    0.021680    0.473893    
#> 080: 0.793577    1.068294    3.552126    0.679096    0.080816    0.021029    0.490146    
#> 081: 0.778354    1.070251    3.545526    0.645141    0.079795    0.022638    0.485594    
#> 082: 0.793166    1.066917    3.550218    0.612884    0.077464    0.022665    0.490217    
#> 083: 0.790468    1.101485    3.543220    0.682638    0.084112    0.021532    0.493096    
#> 084: 0.802123    1.085458    3.546253    0.711544    0.081956    0.020455    0.484884    
#> 085: 0.810269    1.095230    3.553602    0.732651    0.085342    0.019433    0.489898    
#> 086: 0.817196    1.091211    3.550000    0.730552    0.086281    0.020602    0.481812    
#> 087: 0.789673    1.086045    3.537488    0.720383    0.081967    0.021717    0.479363    
#> 088: 0.766567    1.072996    3.548568    0.684364    0.077868    0.022034    0.482196    
#> 089: 0.766957    1.074851    3.538163    0.666316    0.073975    0.021799    0.474986    
#> 090: 0.753606    1.072446    3.544243    0.633000    0.074517    0.020709    0.483291    
#> 091: 0.746266    1.071036    3.528014    0.601350    0.072595    0.019674    0.486258    
#> 092: 0.729223    1.088945    3.526554    0.571283    0.075756    0.018690    0.489567    
#> 093: 0.719694    1.075364    3.534208    0.542718    0.077410    0.019726    0.497244    
#> 094: 0.754564    1.082123    3.535386    0.517488    0.080105    0.019858    0.492903    
#> 095: 0.777099    1.081452    3.547574    0.513584    0.082311    0.020477    0.481549    
#> 096: 0.742819    1.073804    3.540780    0.525369    0.078196    0.021717    0.485155    
#> 097: 0.765103    1.070986    3.535304    0.566199    0.074286    0.021023    0.488152    
#> 098: 0.762898    1.086163    3.532481    0.590233    0.079575    0.020279    0.470036    
#> 099: 0.768330    1.065419    3.534234    0.593354    0.075596    0.019265    0.477171    
#> 100: 0.779412    1.072857    3.542709    0.645031    0.088188    0.020256    0.473965    
#> 101: 0.774769    1.074187    3.533100    0.660371    0.088413    0.019243    0.472695    
#> 102: 0.779947    1.078206    3.532649    0.668584    0.090816    0.018281    0.486294    
#> 103: 0.787986    1.071902    3.536989    0.748667    0.086275    0.017367    0.484396    
#> 104: 0.763691    1.074641    3.542515    0.711233    0.085940    0.016498    0.489116    
#> 105: 0.800718    1.079672    3.541744    0.686863    0.096995    0.015673    0.492583    
#> 106: 0.787380    1.068366    3.541014    0.652520    0.101882    0.014890    0.494251    
#> 107: 0.768981    1.085704    3.542016    0.619894    0.096788    0.014711    0.488649    
#> 108: 0.777208    1.073062    3.543536    0.615581    0.091949    0.015045    0.488229    
#> 109: 0.783422    1.079000    3.548613    0.584802    0.087351    0.015126    0.489238    
#> 110: 0.774601    1.070261    3.537916    0.555562    0.099633    0.014705    0.486295    
#> 111: 0.763683    1.068622    3.547359    0.539012    0.102726    0.015327    0.481324    
#> 112: 0.773011    1.070109    3.536887    0.567275    0.108494    0.014561    0.491024    
#> 113: 0.773595    1.095593    3.540120    0.654205    0.103069    0.013843    0.469463    
#> 114: 0.807408    1.081977    3.540468    0.726866    0.113221    0.013151    0.478530    
#> 115: 0.810585    1.059382    3.538521    0.734229    0.107560    0.012493    0.491152    
#> 116: 0.771897    1.083999    3.539181    0.697517    0.102182    0.016240    0.482329    
#> 117: 0.781096    1.091835    3.547669    0.662641    0.097073    0.015831    0.480754    
#> 118: 0.787053    1.082001    3.546773    0.715642    0.092219    0.017080    0.470695    
#> 119: 0.774075    1.088424    3.536960    0.687152    0.095436    0.018920    0.471641    
#> 120: 0.716887    1.076260    3.531609    0.652795    0.090665    0.017974    0.474667    
#> 121: 0.741598    1.104949    3.528488    0.620155    0.086131    0.017075    0.478838    
#> 122: 0.756282    1.079248    3.536310    0.602398    0.092587    0.018756    0.471281    
#> 123: 0.765844    1.102789    3.534754    0.596131    0.087957    0.018180    0.478096    
#> 124: 0.739431    1.118827    3.519002    0.566324    0.083559    0.017271    0.486359    
#> 125: 0.750207    1.119837    3.517971    0.609373    0.080502    0.019074    0.473935    
#> 126: 0.706262    1.114431    3.518616    0.578904    0.076477    0.018671    0.485251    
#> 127: 0.745248    1.093572    3.526893    0.571693    0.074644    0.017737    0.482274    
#> 128: 0.766547    1.079702    3.536683    0.642643    0.077044    0.017880    0.485727    
#> 129: 0.772004    1.101598    3.535610    0.610511    0.087305    0.017232    0.482324    
#> 130: 0.785963    1.095299    3.533955    0.579986    0.089773    0.019427    0.482492    
#> 131: 0.742665    1.095706    3.527806    0.559977    0.099890    0.020708    0.496174    
#> 132: 0.732039    1.092599    3.526644    0.536272    0.099271    0.019672    0.501456    
#> 133: 0.803489    1.082803    3.540439    0.740889    0.099552    0.018689    0.496062    
#> 134: 0.786172    1.057683    3.551579    0.760890    0.094574    0.017786    0.507190    
#> 135: 0.809117    1.056846    3.550536    0.722845    0.095337    0.018056    0.493236    
#> 136: 0.822378    1.071102    3.550305    0.704204    0.090570    0.017153    0.496451    
#> 137: 0.831795    1.045122    3.561078    0.668994    0.086041    0.020483    0.504916    
#> 138: 0.802311    1.066948    3.549526    0.635544    0.081739    0.019459    0.495497    
#> 139: 0.784915    1.067264    3.552718    0.603767    0.082200    0.018486    0.492487    
#> 140: 0.822790    1.067514    3.550835    0.677551    0.091650    0.017562    0.493602    
#> 141: 0.801865    1.054141    3.552578    0.643673    0.097893    0.016684    0.492066    
#> 142: 0.824659    1.055705    3.559602    0.642337    0.106018    0.015850    0.494567    
#> 143: 0.796864    1.061850    3.559838    0.672220    0.108210    0.017329    0.497279    
#> 144: 0.821190    1.067218    3.555708    0.638609    0.102799    0.017481    0.472980    
#> 145: 0.783209    1.078844    3.543741    0.614075    0.097659    0.017426    0.477497    
#> 146: 0.779974    1.084806    3.546676    0.589262    0.092776    0.016555    0.481941    
#> 147: 0.769859    1.075900    3.539272    0.621053    0.088138    0.017899    0.487578    
#> 148: 0.792127    1.080929    3.551501    0.695901    0.085100    0.017004    0.493616    
#> 149: 0.805611    1.046672    3.550566    0.661106    0.090255    0.016264    0.488788    
#> 150: 0.791080    1.047035    3.542319    0.628051    0.088267    0.017346    0.505319    
#> 151: 0.764090    1.075803    3.540553    0.596648    0.083854    0.016479    0.481443    
#> 152: 0.743644    1.079421    3.539697    0.579096    0.092851    0.016649    0.473269    
#> 153: 0.747378    1.091205    3.545026    0.538858    0.092147    0.017811    0.493473    
#> 154: 0.782400    1.093264    3.538398    0.527838    0.093305    0.018495    0.494787    
#> 155: 0.744967    1.084403    3.539603    0.514671    0.089998    0.019130    0.485531    
#> 156: 0.767151    1.085110    3.543045    0.500811    0.104730    0.020032    0.496401    
#> 157: 0.798505    1.070960    3.549724    0.597111    0.090183    0.018252    0.488920    
#> 158: 0.825049    1.080591    3.555540    0.586028    0.091581    0.018508    0.488774    
#> 159: 0.784466    1.066245    3.555628    0.559600    0.081735    0.017871    0.491634    
#> 160: 0.811572    1.043419    3.562898    0.570608    0.079012    0.018973    0.479323    
#> 161: 0.806434    1.065977    3.556094    0.555150    0.087430    0.019921    0.489845    
#> 162: 0.756761    1.063926    3.554755    0.472873    0.092003    0.019453    0.504005    
#> 163: 0.760232    1.060601    3.549357    0.486323    0.078239    0.019800    0.513025    
#> 164: 0.765654    1.063926    3.542215    0.577281    0.080997    0.016797    0.482979    
#> 165: 0.781523    1.054709    3.545136    0.614841    0.079948    0.017597    0.482481    
#> 166: 0.832196    1.080234    3.543782    0.694331    0.082395    0.014206    0.485770    
#> 167: 0.797960    1.081368    3.548516    0.682062    0.080835    0.016730    0.494021    
#> 168: 0.804652    1.076193    3.553037    0.634668    0.083253    0.020162    0.490104    
#> 169: 0.778632    1.100928    3.542805    0.562676    0.088846    0.018710    0.487331    
#> 170: 0.805839    1.098722    3.543443    0.596571    0.084573    0.019515    0.479224    
#> 171: 0.766404    1.082664    3.544317    0.537072    0.080484    0.019654    0.484049    
#> 172: 0.746827    1.090911    3.541183    0.571142    0.076963    0.019084    0.479534    
#> 173: 0.770706    1.093357    3.540374    0.527176    0.080699    0.021792    0.465082    
#> 174: 0.742056    1.085425    3.545843    0.511599    0.074592    0.021490    0.478136    
#> 175: 0.728255    1.068744    3.539026    0.524499    0.074914    0.021949    0.483391    
#> 176: 0.737417    1.093312    3.552162    0.440403    0.073221    0.024148    0.488536    
#> 177: 0.754679    1.085047    3.543445    0.504572    0.067264    0.025650    0.498194    
#> 178: 0.802945    1.064186    3.554625    0.528571    0.074780    0.024341    0.483095    
#> 179: 0.786353    1.091895    3.551803    0.503020    0.085546    0.022456    0.485015    
#> 180: 0.752031    1.086057    3.548874    0.466719    0.082364    0.021341    0.487701    
#> 181: 0.778228    1.096664    3.542569    0.525374    0.087178    0.023974    0.487614    
#> 182: 0.749559    1.092568    3.535532    0.522472    0.085507    0.025085    0.489072    
#> 183: 0.740701    1.100713    3.534906    0.517261    0.066580    0.027763    0.505224    
#> 184: 0.734722    1.095550    3.539563    0.562632    0.064939    0.024738    0.493339    
#> 185: 0.729337    1.090604    3.530876    0.541087    0.069727    0.024105    0.491532    
#> 186: 0.743381    1.101720    3.533899    0.544734    0.087004    0.024277    0.491104    
#> 187: 0.739261    1.089813    3.534783    0.557293    0.073359    0.019124    0.473704    
#> 188: 0.726662    1.076374    3.539472    0.477326    0.081607    0.018043    0.491056    
#> 189: 0.751276    1.093148    3.549484    0.542479    0.082427    0.015789    0.490726    
#> 190: 0.766255    1.089692    3.540410    0.574447    0.085680    0.015115    0.477698    
#> 191: 0.774295    1.086155    3.535471    0.584229    0.088522    0.015163    0.474907    
#> 192: 0.790227    1.088163    3.535306    0.637833    0.091121    0.011712    0.488930    
#> 193: 0.800128    1.090519    3.540102    0.623110    0.099270    0.012338    0.484364    
#> 194: 0.756008    1.072668    3.529789    0.597927    0.096612    0.012397    0.485475    
#> 195: 0.727554    1.087673    3.526674    0.621462    0.097693    0.011282    0.493205    
#> 196: 0.744644    1.074407    3.534105    0.595651    0.100348    0.012217    0.490800    
#> 197: 0.723744    1.080234    3.542328    0.562472    0.093349    0.013910    0.511057    
#> 198: 0.749761    1.069055    3.533368    0.584921    0.083900    0.015195    0.478351    
#> 199: 0.736376    1.067143    3.533721    0.505608    0.078995    0.016992    0.480168    
#> 200: 0.742809    1.086085    3.530789    0.586581    0.084897    0.017883    0.484524    
#> 201: 0.742797    1.083427    3.536259    0.578319    0.080228    0.017729    0.482926    
#> 202: 0.751617    1.084443    3.538550    0.581124    0.081114    0.018347    0.481753    
#> 203: 0.771558    1.082915    3.540075    0.582153    0.082971    0.018807    0.482720    
#> 204: 0.783359    1.077688    3.544949    0.603786    0.080815    0.019185    0.485550    
#> 205: 0.785815    1.080411    3.545990    0.598641    0.082125    0.019315    0.487323    
#> 206: 0.783449    1.085520    3.544389    0.596222    0.083534    0.019145    0.486154    
#> 207: 0.783481    1.087382    3.543278    0.592784    0.083414    0.018994    0.484730    
#> 208: 0.782354    1.087162    3.542566    0.585184    0.083295    0.018928    0.483603    
#> 209: 0.782103    1.085066    3.542224    0.583574    0.083267    0.019185    0.482483    
#> 210: 0.781808    1.083089    3.542960    0.584162    0.082589    0.018845    0.482496    
#> 211: 0.784910    1.082806    3.544650    0.581469    0.082645    0.018635    0.481820    
#> 212: 0.787087    1.081359    3.545870    0.576814    0.081843    0.018553    0.481817    
#> 213: 0.791575    1.078253    3.547463    0.578449    0.081025    0.018594    0.483262    
#> 214: 0.793965    1.076632    3.548721    0.576157    0.080703    0.018796    0.483528    
#> 215: 0.794572    1.075115    3.549933    0.573362    0.080023    0.019106    0.483831    
#> 216: 0.798516    1.073876    3.551109    0.572240    0.079847    0.019222    0.485853    
#> 217: 0.798518    1.073392    3.551789    0.567700    0.079396    0.019315    0.486878    
#> 218: 0.798820    1.072597    3.551715    0.566077    0.079171    0.019254    0.487751    
#> 219: 0.794315    1.072549    3.550630    0.564108    0.079312    0.019046    0.488041    
#> 220: 0.791233    1.072841    3.549686    0.565104    0.079384    0.018759    0.488754    
#> 221: 0.788074    1.073626    3.548955    0.562354    0.079527    0.018535    0.488534    
#> 222: 0.786399    1.073576    3.548485    0.560390    0.080145    0.018410    0.488443    
#> 223: 0.785974    1.073282    3.548261    0.559973    0.080630    0.018445    0.488108    
#> 224: 0.787330    1.073838    3.548159    0.561254    0.081010    0.018499    0.487689    
#> 225: 0.786552    1.072623    3.548536    0.560488    0.080780    0.018405    0.487914    
#> 226: 0.785930    1.071560    3.548427    0.557005    0.080649    0.018372    0.488214    
#> 227: 0.785931    1.070940    3.548510    0.555664    0.080660    0.018335    0.487972    
#> 228: 0.785378    1.071063    3.548074    0.557145    0.080731    0.018342    0.487889    
#> 229: 0.785085    1.070992    3.548031    0.557724    0.080814    0.018322    0.488129    
#> 230: 0.785676    1.070927    3.548043    0.558205    0.080949    0.018326    0.488126    
#> 231: 0.785854    1.071491    3.548113    0.559219    0.081105    0.018393    0.488098    
#> 232: 0.784398    1.071470    3.548010    0.560042    0.081397    0.018309    0.488129    
#> 233: 0.782405    1.070949    3.547960    0.558305    0.081607    0.018227    0.488481    
#> 234: 0.781502    1.070863    3.547760    0.558213    0.081874    0.018186    0.488707    
#> 235: 0.781048    1.071037    3.547814    0.556567    0.081671    0.018152    0.488752    
#> 236: 0.780895    1.071273    3.547839    0.556503    0.081776    0.018118    0.488946    
#> 237: 0.781115    1.071210    3.547762    0.556630    0.081913    0.018085    0.489293    
#> 238: 0.781364    1.071153    3.547728    0.557023    0.081925    0.018021    0.489686    
#> 239: 0.781602    1.071482    3.547603    0.557664    0.082003    0.018009    0.490109    
#> 240: 0.782231    1.071022    3.547741    0.559105    0.082035    0.018008    0.490129    
#> 241: 0.782911    1.070085    3.547924    0.559913    0.081890    0.018046    0.490143    
#> 242: 0.783054    1.069288    3.547987    0.559410    0.081781    0.018088    0.490175    
#> 243: 0.782752    1.069602    3.547964    0.559790    0.081818    0.018022    0.490233    
#> 244: 0.783083    1.069843    3.548010    0.561408    0.081889    0.017986    0.489796    
#> 245: 0.782856    1.069537    3.548013    0.560738    0.081960    0.017918    0.489917    
#> 246: 0.782669    1.069282    3.548312    0.560092    0.081943    0.018001    0.489939    
#> 247: 0.782957    1.069101    3.548364    0.560217    0.081934    0.018046    0.490071    
#> 248: 0.782638    1.069406    3.548383    0.559418    0.081917    0.018054    0.489934    
#> 249: 0.782400    1.069513    3.548214    0.561067    0.081924    0.018014    0.489843    
#> 250: 0.782596    1.069841    3.548317    0.560682    0.082009    0.018073    0.489829    
#> 251: 0.783044    1.070335    3.548434    0.560797    0.082307    0.018008    0.489846    
#> 252: 0.782944    1.071136    3.548534    0.560021    0.082522    0.017995    0.489677    
#> 253: 0.782783    1.071531    3.548371    0.559773    0.082645    0.018018    0.489505    
#> 254: 0.782435    1.071981    3.548237    0.559443    0.082697    0.018005    0.489272    
#> 255: 0.782271    1.072318    3.548171    0.558380    0.082781    0.017997    0.489128    
#> 256: 0.781835    1.072348    3.548207    0.557551    0.082779    0.018041    0.489139    
#> 257: 0.781935    1.072135    3.548194    0.557840    0.082848    0.017994    0.489318    
#> 258: 0.782177    1.071989    3.548207    0.557941    0.082822    0.017927    0.489496    
#> 259: 0.782719    1.072099    3.548158    0.559502    0.082981    0.017878    0.489742    
#> 260: 0.782633    1.072168    3.548105    0.559166    0.083105    0.017857    0.489728    
#> 261: 0.782540    1.072100    3.548108    0.557725    0.083197    0.017854    0.489742    
#> 262: 0.782325    1.072350    3.547986    0.557049    0.083286    0.017802    0.489627    
#> 263: 0.781739    1.072371    3.547929    0.556747    0.083269    0.017827    0.489728    
#> 264: 0.781685    1.072365    3.547899    0.557117    0.083014    0.017852    0.489903    
#> 265: 0.781538    1.072467    3.547931    0.557463    0.082954    0.017837    0.490008    
#> 266: 0.781464    1.072677    3.547981    0.556956    0.082804    0.017849    0.490108    
#> 267: 0.781369    1.072569    3.548106    0.557027    0.082721    0.017826    0.490013    
#> 268: 0.781630    1.072098    3.548049    0.558370    0.082821    0.017802    0.489956    
#> 269: 0.782585    1.071907    3.548080    0.562131    0.083095    0.017806    0.489979    
#> 270: 0.782951    1.071892    3.548058    0.564733    0.083236    0.017791    0.489830    
#> 271: 0.783135    1.071931    3.548147    0.565087    0.083311    0.017813    0.489682    
#> 272: 0.783604    1.071748    3.548164    0.566271    0.083169    0.017827    0.489738    
#> 273: 0.783398    1.071840    3.548272    0.566726    0.083133    0.017876    0.489825    
#> 274: 0.783158    1.071865    3.548447    0.565686    0.083172    0.017879    0.489987    
#> 275: 0.783373    1.071863    3.548398    0.565739    0.083256    0.017866    0.489953    
#> 276: 0.782872    1.072061    3.548349    0.565138    0.083288    0.017810    0.489877    
#> 277: 0.782849    1.072317    3.548425    0.565485    0.083255    0.017754    0.489879    
#> 278: 0.782702    1.072593    3.548429    0.566197    0.083317    0.017717    0.489863    
#> 279: 0.782773    1.072526    3.548417    0.566789    0.083459    0.017712    0.489837    
#> 280: 0.782566    1.072657    3.548340    0.566281    0.083541    0.017713    0.489672    
#> 281: 0.781900    1.072927    3.548298    0.565468    0.083567    0.017729    0.489683    
#> 282: 0.781599    1.073240    3.548226    0.565081    0.083528    0.017747    0.489550    
#> 283: 0.781663    1.073345    3.548196    0.566401    0.083382    0.017765    0.489603    
#> 284: 0.781866    1.073221    3.548215    0.567815    0.083350    0.017802    0.489692    
#> 285: 0.782106    1.073241    3.548087    0.569238    0.083389    0.017842    0.489723    
#> 286: 0.782240    1.073174    3.547966    0.569812    0.083597    0.017879    0.489730    
#> 287: 0.782134    1.073332    3.547811    0.571250    0.083793    0.017834    0.489731    
#> 288: 0.782029    1.073439    3.547725    0.571307    0.083947    0.017822    0.489916    
#> 289: 0.781981    1.073361    3.547648    0.571001    0.084069    0.017809    0.489920    
#> 290: 0.781994    1.073228    3.547631    0.570654    0.084130    0.017811    0.490055    
#> 291: 0.781975    1.073434    3.547723    0.569766    0.084109    0.017868    0.489980    
#> 292: 0.782114    1.073396    3.547738    0.569237    0.084172    0.017902    0.489974    
#> 293: 0.782229    1.073564    3.547704    0.569593    0.084201    0.017928    0.489924    
#> 294: 0.781916    1.073701    3.547634    0.569409    0.084243    0.017918    0.489912    
#> 295: 0.782048    1.073509    3.547607    0.569897    0.084256    0.017907    0.489792    
#> 296: 0.782020    1.073502    3.547593    0.569907    0.084166    0.017914    0.489744    
#> 297: 0.782098    1.073534    3.547638    0.570249    0.084062    0.017943    0.489823    
#> 298: 0.782327    1.073482    3.547618    0.571331    0.083927    0.017964    0.489683    
#> 299: 0.782196    1.073635    3.547523    0.571872    0.083940    0.017946    0.489615    
#> 300: 0.781984    1.073552    3.547553    0.571745    0.083911    0.017940    0.489566    
#> 301: 0.782154    1.073442    3.547543    0.571720    0.083878    0.017924    0.489614    
#> 302: 0.782366    1.073486    3.547478    0.572120    0.083835    0.017928    0.489527    
#> 303: 0.782298    1.073603    3.547447    0.571514    0.083777    0.017950    0.489406    
#> 304: 0.782254    1.073897    3.547360    0.571521    0.083651    0.017939    0.489464    
#> 305: 0.782088    1.073890    3.547295    0.571445    0.083732    0.017923    0.489313    
#> 306: 0.781754    1.073939    3.547190    0.571450    0.083756    0.017886    0.489238    
#> 307: 0.781243    1.074049    3.546940    0.571552    0.083788    0.017876    0.489197    
#> 308: 0.780756    1.074104    3.546758    0.571597    0.083858    0.017859    0.489171    
#> 309: 0.780139    1.074080    3.546632    0.571621    0.083821    0.017832    0.489243    
#> 310: 0.779867    1.074229    3.546368    0.571772    0.083898    0.017808    0.489290    
#> 311: 0.779649    1.074315    3.546250    0.572039    0.084046    0.017784    0.489210    
#> 312: 0.779195    1.074457    3.546119    0.571889    0.084132    0.017770    0.489318    
#> 313: 0.778802    1.074412    3.545950    0.571746    0.084169    0.017743    0.489504    
#> 314: 0.778266    1.074643    3.545804    0.571738    0.084142    0.017722    0.489658    
#> 315: 0.778115    1.074915    3.545637    0.571910    0.084124    0.017696    0.489748    
#> 316: 0.778000    1.075078    3.545502    0.571718    0.084147    0.017683    0.489806    
#> 317: 0.778142    1.075216    3.545421    0.572718    0.084178    0.017690    0.489914    
#> 318: 0.778096    1.075444    3.545271    0.572670    0.084206    0.017695    0.490012    
#> 319: 0.778186    1.075527    3.545172    0.573430    0.084195    0.017692    0.490031    
#> 320: 0.777937    1.075634    3.545077    0.573482    0.084234    0.017701    0.490148    
#> 321: 0.777683    1.075784    3.544958    0.573499    0.084244    0.017727    0.490321    
#> 322: 0.777226    1.075843    3.544758    0.573372    0.084272    0.017704    0.490422    
#> 323: 0.776655    1.075970    3.544533    0.573296    0.084372    0.017681    0.490420    
#> 324: 0.776289    1.076167    3.544397    0.573212    0.084523    0.017662    0.490284    
#> 325: 0.776364    1.076320    3.544341    0.573938    0.084595    0.017661    0.490129    
#> 326: 0.776412    1.076381    3.544274    0.574445    0.084617    0.017645    0.490044    
#> 327: 0.776637    1.076517    3.544291    0.575132    0.084747    0.017654    0.489960    
#> 328: 0.777076    1.076586    3.544297    0.576500    0.084777    0.017639    0.489795    
#> 329: 0.777453    1.076618    3.544362    0.577500    0.084811    0.017653    0.489704    
#> 330: 0.777557    1.076687    3.544345    0.578116    0.084790    0.017670    0.489607    
#> 331: 0.777969    1.076849    3.544323    0.579750    0.084775    0.017663    0.489555    
#> 332: 0.778168    1.076835    3.544295    0.580338    0.084667    0.017672    0.489569    
#> 333: 0.777788    1.076839    3.544179    0.580202    0.084561    0.017658    0.489617    
#> 334: 0.777343    1.076735    3.544016    0.580688    0.084468    0.017639    0.489712    
#> 335: 0.777055    1.076854    3.543946    0.581049    0.084476    0.017631    0.489679    
#> 336: 0.776486    1.077073    3.543810    0.580529    0.084532    0.017620    0.489681    
#> 337: 0.776043    1.077315    3.543686    0.580749    0.084592    0.017609    0.489633    
#> 338: 0.775980    1.077388    3.543677    0.581173    0.084643    0.017599    0.489612    
#> 339: 0.776059    1.077464    3.543664    0.581573    0.084667    0.017596    0.489668    
#> 340: 0.775994    1.077207    3.543667    0.581657    0.084793    0.017589    0.489676    
#> 341: 0.776099    1.077053    3.543701    0.582202    0.084940    0.017580    0.489598    
#> 342: 0.775939    1.076786    3.543685    0.582343    0.084940    0.017586    0.489564    
#> 343: 0.775850    1.076688    3.543717    0.582531    0.084945    0.017593    0.489501    
#> 344: 0.775989    1.076586    3.543713    0.582818    0.084950    0.017594    0.489430    
#> 345: 0.776029    1.076550    3.543713    0.583224    0.084949    0.017605    0.489408    
#> 346: 0.775972    1.076645    3.543612    0.583594    0.084929    0.017604    0.489369    
#> 347: 0.775734    1.076661    3.543519    0.583588    0.084977    0.017615    0.489286    
#> 348: 0.775722    1.076684    3.543442    0.584246    0.084945    0.017619    0.489254    
#> 349: 0.775676    1.076642    3.543415    0.584655    0.084922    0.017620    0.489246    
#> 350: 0.775510    1.076643    3.543349    0.585060    0.084904    0.017618    0.489260    
#> 351: 0.775365    1.076822    3.543221    0.585510    0.084956    0.017617    0.489251    
#> 352: 0.775111    1.077106    3.543158    0.585219    0.084973    0.017610    0.489352    
#> 353: 0.774905    1.077327    3.543048    0.585296    0.085014    0.017604    0.489310    
#> 354: 0.774425    1.077369    3.542885    0.585226    0.084991    0.017610    0.489357    
#> 355: 0.774422    1.077412    3.542765    0.585263    0.085005    0.017600    0.489407    
#> 356: 0.774219    1.077463    3.542726    0.585170    0.085075    0.017602    0.489431    
#> 357: 0.774459    1.077562    3.542724    0.585917    0.085117    0.017588    0.489440    
#> 358: 0.774488    1.077681    3.542684    0.586371    0.085183    0.017590    0.489398    
#> 359: 0.774258    1.077963    3.542607    0.585941    0.085256    0.017598    0.489411    
#> 360: 0.774140    1.078026    3.542519    0.585682    0.085322    0.017608    0.489427    
#> 361: 0.774152    1.078003    3.542483    0.585594    0.085306    0.017618    0.489419    
#> 362: 0.774118    1.077887    3.542453    0.585836    0.085285    0.017626    0.489315    
#> 363: 0.774231    1.077757    3.542479    0.585541    0.085196    0.017642    0.489239    
#> 364: 0.774266    1.077712    3.542512    0.585233    0.085152    0.017670    0.489200    
#> 365: 0.774226    1.077639    3.542568    0.584766    0.085042    0.017709    0.489157    
#> 366: 0.774237    1.077572    3.542565    0.584353    0.085065    0.017725    0.489219    
#> 367: 0.774225    1.077661    3.542550    0.583862    0.085067    0.017733    0.489247    
#> 368: 0.774102    1.077753    3.542543    0.583317    0.085032    0.017723    0.489215    
#> 369: 0.773861    1.077759    3.542486    0.582862    0.085027    0.017707    0.489170    
#> 370: 0.773639    1.077875    3.542425    0.582291    0.085030    0.017717    0.489164    
#> 371: 0.773430    1.077949    3.542324    0.581913    0.085045    0.017698    0.489169    
#> 372: 0.773306    1.078028    3.542257    0.581862    0.085050    0.017689    0.489229    
#> 373: 0.773105    1.078187    3.542190    0.582181    0.085120    0.017676    0.489277    
#> 374: 0.773018    1.078144    3.542177    0.581827    0.085115    0.017676    0.489322    
#> 375: 0.773027    1.078175    3.542155    0.582150    0.085155    0.017673    0.489342    
#> 376: 0.773124    1.078209    3.542123    0.582767    0.085158    0.017679    0.489306    
#> 377: 0.773112    1.078270    3.542049    0.583182    0.085185    0.017700    0.489271    
#> 378: 0.773071    1.078338    3.541947    0.584022    0.085217    0.017711    0.489303    
#> 379: 0.772794    1.078287    3.541844    0.584036    0.085250    0.017718    0.489349    
#> 380: 0.772341    1.078285    3.541746    0.583802    0.085308    0.017725    0.489362    
#> 381: 0.772015    1.078321    3.541653    0.584094    0.085329    0.017729    0.489351    
#> 382: 0.771731    1.078431    3.541582    0.584164    0.085392    0.017728    0.489286    
#> 383: 0.771695    1.078454    3.541554    0.584575    0.085405    0.017734    0.489260    
#> 384: 0.771504    1.078474    3.541524    0.584649    0.085411    0.017746    0.489238    
#> 385: 0.771411    1.078435    3.541511    0.584961    0.085419    0.017757    0.489207    
#> 386: 0.771468    1.078509    3.541511    0.584711    0.085410    0.017767    0.489143    
#> 387: 0.771416    1.078615    3.541539    0.584798    0.085417    0.017781    0.489123    
#> 388: 0.771482    1.078690    3.541528    0.584636    0.085392    0.017791    0.489109    
#> 389: 0.771300    1.078589    3.541525    0.584271    0.085386    0.017809    0.489135    
#> 390: 0.771260    1.078672    3.541502    0.584275    0.085341    0.017825    0.489103    
#> 391: 0.771315    1.078727    3.541465    0.584524    0.085320    0.017830    0.489090    
#> 392: 0.771272    1.078765    3.541427    0.584751    0.085282    0.017832    0.489132    
#> 393: 0.771216    1.078663    3.541380    0.584863    0.085252    0.017821    0.489114    
#> 394: 0.771435    1.078606    3.541388    0.585140    0.085209    0.017814    0.489159    
#> 395: 0.771852    1.078625    3.541451    0.585743    0.085123    0.017813    0.489138    
#> 396: 0.772039    1.078572    3.541524    0.585887    0.085034    0.017825    0.489183    
#> 397: 0.772209    1.078514    3.541601    0.585948    0.084965    0.017855    0.489197    
#> 398: 0.772376    1.078414    3.541633    0.586073    0.084944    0.017851    0.489208    
#> 399: 0.772462    1.078296    3.541690    0.586012    0.084971    0.017847    0.489226    
#> 400: 0.772535    1.078235    3.541743    0.585568    0.085017    0.017848    0.489280    
#> 401: 0.772557    1.078212    3.541746    0.585369    0.085045    0.017863    0.489306    
#> 402: 0.772657    1.078241    3.541791    0.585235    0.085026    0.017869    0.489360    
#> 403: 0.772947    1.078173    3.541820    0.585675    0.085069    0.017871    0.489342    
#> 404: 0.773051    1.078167    3.541771    0.586068    0.085083    0.017876    0.489246    
#> 405: 0.772972    1.078231    3.541722    0.586535    0.085080    0.017880    0.489207    
#> 406: 0.772804    1.078287    3.541646    0.586448    0.085062    0.017906    0.489199    
#> 407: 0.772740    1.078323    3.541621    0.586733    0.085020    0.017917    0.489183    
#> 408: 0.772782    1.078380    3.541607    0.586793    0.085012    0.017927    0.489154    
#> 409: 0.772645    1.078425    3.541571    0.586838    0.084995    0.017932    0.489088    
#> 410: 0.772564    1.078542    3.541558    0.586643    0.085014    0.017929    0.489120    
#> 411: 0.772470    1.078435    3.541579    0.586472    0.085005    0.017934    0.489085    
#> 412: 0.772401    1.078501    3.541580    0.586526    0.085016    0.017936    0.489124    
#> 413: 0.772343    1.078598    3.541540    0.586754    0.084987    0.017935    0.489167    
#> 414: 0.772095    1.078678    3.541499    0.586555    0.084910    0.017941    0.489194    
#> 415: 0.772059    1.078670    3.541456    0.586559    0.084849    0.017957    0.489243    
#> 416: 0.772066    1.078762    3.541467    0.586663    0.084831    0.017961    0.489274    
#> 417: 0.771923    1.078757    3.541463    0.586312    0.084862    0.017968    0.489293    
#> 418: 0.771818    1.078799    3.541485    0.586226    0.084902    0.017973    0.489238    
#> 419: 0.771829    1.078874    3.541483    0.586295    0.084944    0.017966    0.489189    
#> 420: 0.771881    1.078884    3.541483    0.586145    0.084981    0.017955    0.489149    
#> 421: 0.771692    1.078912    3.541520    0.585808    0.084986    0.017957    0.489181    
#> 422: 0.771827    1.078908    3.541519    0.585798    0.084974    0.017966    0.489191    
#> 423: 0.771842    1.078881    3.541510    0.585980    0.084982    0.017968    0.489192    
#> 424: 0.771596    1.078898    3.541458    0.585843    0.085001    0.017974    0.489167    
#> 425: 0.771385    1.078975    3.541417    0.585360    0.084984    0.017982    0.489160    
#> 426: 0.771291    1.079058    3.541382    0.585515    0.084952    0.017979    0.489189    
#> 427: 0.771169    1.079113    3.541393    0.585334    0.084911    0.017982    0.489177    
#> 428: 0.771187    1.079180    3.541405    0.585636    0.084939    0.017990    0.489122    
#> 429: 0.771121    1.079266    3.541374    0.585614    0.084962    0.017984    0.489111    
#> 430: 0.771154    1.079324    3.541354    0.585647    0.084966    0.017990    0.489080    
#> 431: 0.771331    1.079326    3.541364    0.585777    0.084985    0.018000    0.489029    
#> 432: 0.771480    1.079344    3.541379    0.586028    0.084992    0.018018    0.488978    
#> 433: 0.771562    1.079358    3.541407    0.585960    0.084986    0.018041    0.488986    
#> 434: 0.771553    1.079250    3.541437    0.585936    0.084991    0.018047    0.489004    
#> 435: 0.771638    1.079217    3.541456    0.585724    0.084977    0.018051    0.489004    
#> 436: 0.771609    1.079132    3.541523    0.585315    0.084971    0.018040    0.489080    
#> 437: 0.771694    1.078985    3.541550    0.585360    0.084998    0.018029    0.489127    
#> 438: 0.771706    1.079019    3.541544    0.585432    0.085018    0.018015    0.489165    
#> 439: 0.771827    1.079111    3.541543    0.585527    0.084998    0.018003    0.489177    
#> 440: 0.771854    1.079156    3.541558    0.585326    0.085011    0.018000    0.489198    
#> 441: 0.771905    1.079138    3.541601    0.585043    0.085013    0.017995    0.489223    
#> 442: 0.771849    1.079181    3.541600    0.584986    0.085025    0.017992    0.489198    
#> 443: 0.771831    1.079248    3.541563    0.584968    0.085023    0.017977    0.489195    
#> 444: 0.771767    1.079332    3.541536    0.584753    0.085028    0.017971    0.489208    
#> 445: 0.771636    1.079402    3.541499    0.584551    0.085069    0.017970    0.489188    
#> 446: 0.771479    1.079480    3.541469    0.584385    0.085101    0.017970    0.489111    
#> 447: 0.771437    1.079487    3.541470    0.584312    0.085099    0.017967    0.489073    
#> 448: 0.771440    1.079409    3.541454    0.584405    0.085077    0.017967    0.489046    
#> 449: 0.771460    1.079452    3.541520    0.584428    0.085033    0.017972    0.489046    
#> 450: 0.771514    1.079404    3.541541    0.584341    0.084978    0.017974    0.489093    
#> 451: 0.771564    1.079353    3.541553    0.584488    0.084954    0.017968    0.489102    
#> 452: 0.771653    1.079307    3.541602    0.584509    0.084969    0.017966    0.489098    
#> 453: 0.771657    1.079272    3.541620    0.584298    0.084966    0.017963    0.489060    
#> 454: 0.771975    1.079341    3.541662    0.584709    0.084931    0.017956    0.489061    
#> 455: 0.772226    1.079339    3.541719    0.584940    0.084941    0.017951    0.489010    
#> 456: 0.772419    1.079209    3.541765    0.585263    0.084892    0.017955    0.489026    
#> 457: 0.772511    1.079142    3.541821    0.585373    0.084858    0.017945    0.489009    
#> 458: 0.772559    1.079161    3.541878    0.585120    0.084836    0.017947    0.488983    
#> 459: 0.772369    1.079142    3.541891    0.584685    0.084815    0.017949    0.488971    
#> 460: 0.772227    1.079071    3.541876    0.584425    0.084819    0.017940    0.488946    
#> 461: 0.772133    1.079084    3.541858    0.584440    0.084858    0.017931    0.488895    
#> 462: 0.771974    1.079139    3.541842    0.584421    0.084935    0.017920    0.488871    
#> 463: 0.771989    1.079219    3.541866    0.584516    0.084952    0.017913    0.488865    
#> 464: 0.772177    1.079228    3.541857    0.585055    0.084986    0.017904    0.488816    
#> 465: 0.772336    1.079111    3.541880    0.585661    0.084959    0.017892    0.488814    
#> 466: 0.772447    1.079087    3.541850    0.585820    0.084971    0.017879    0.488879    
#> 467: 0.772514    1.079067    3.541862    0.586157    0.084953    0.017868    0.488860    
#> 468: 0.772765    1.079069    3.541911    0.586780    0.084956    0.017854    0.488839    
#> 469: 0.772876    1.079092    3.541941    0.586872    0.084934    0.017853    0.488852    
#> 470: 0.772870    1.079102    3.541912    0.586977    0.084945    0.017857    0.488889    
#> 471: 0.772926    1.079074    3.541952    0.586943    0.084940    0.017840    0.488957    
#> 472: 0.772923    1.079048    3.541967    0.587046    0.084936    0.017831    0.488961    
#> 473: 0.772795    1.079055    3.541950    0.586913    0.084955    0.017823    0.488915    
#> 474: 0.772697    1.079065    3.541917    0.586844    0.084982    0.017812    0.488905    
#> 475: 0.772713    1.079139    3.541901    0.586874    0.085020    0.017798    0.488939    
#> 476: 0.772653    1.079111    3.541890    0.586669    0.085091    0.017781    0.488932    
#> 477: 0.772612    1.079113    3.541904    0.586729    0.085168    0.017762    0.488870    
#> 478: 0.772501    1.079087    3.541897    0.586775    0.085196    0.017753    0.488859    
#> 479: 0.772620    1.079101    3.541918    0.586969    0.085208    0.017747    0.488854    
#> 480: 0.772593    1.079144    3.541861    0.587232    0.085213    0.017735    0.488851    
#> 481: 0.772576    1.079195    3.541827    0.587307    0.085208    0.017728    0.488845    
#> 482: 0.772650    1.079228    3.541785    0.587491    0.085178    0.017718    0.488839    
#> 483: 0.772575    1.079194    3.541788    0.587456    0.085198    0.017702    0.488826    
#> 484: 0.772431    1.079072    3.541804    0.587059    0.085232    0.017684    0.488870    
#> 485: 0.772372    1.079043    3.541815    0.586885    0.085260    0.017676    0.488930    
#> 486: 0.772352    1.079063    3.541848    0.586597    0.085289    0.017666    0.488924    
#> 487: 0.772468    1.079035    3.541898    0.586620    0.085308    0.017657    0.488909    
#> 488: 0.772478    1.079017    3.541938    0.586394    0.085341    0.017651    0.488932    
#> 489: 0.772572    1.078977    3.541969    0.586220    0.085324    0.017655    0.488961    
#> 490: 0.772617    1.078953    3.542021    0.585846    0.085314    0.017652    0.488961    
#> 491: 0.772781    1.079017    3.542078    0.585932    0.085322    0.017648    0.488912    
#> 492: 0.772803    1.079034    3.542086    0.585827    0.085317    0.017644    0.488928    
#> 493: 0.772833    1.079053    3.542116    0.585858    0.085300    0.017644    0.488863    
#> 494: 0.772973    1.079087    3.542108    0.585680    0.085265    0.017631    0.488856    
#> 495: 0.772977    1.079080    3.542098    0.585515    0.085259    0.017631    0.488824    
#> 496: 0.773045    1.079167    3.542101    0.585334    0.085262    0.017634    0.488819    
#> 497: 0.773072    1.079227    3.542134    0.585073    0.085286    0.017638    0.488826    
#> 498: 0.773115    1.079192    3.542136    0.585223    0.085282    0.017630    0.488826    
#> 499: 0.773151    1.079151    3.542128    0.585234    0.085308    0.017618    0.488803    
#> 500: 0.773092    1.079152    3.542100    0.585024    0.085365    0.017602    0.488757    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.272812    0.969976    3.448235    0.392401    0.083216    0.016800    1.571644    
#> 002: 0.276370    1.030393    3.487184    0.372781    0.079055    0.015960    1.058807    
#> 003: 0.357541    0.979844    3.500134    0.354142    0.080507    0.015162    0.829813    
#> 004: 0.330413    0.992098    3.497516    0.336435    0.076482    0.014404    0.757484    
#> 005: 0.397603    1.008203    3.479617    0.319613    0.072658    0.013684    0.726212    
#> 006: 0.338117    1.018641    3.463851    0.303633    0.079702    0.013000    0.686881    
#> 007: 0.277139    1.020966    3.460495    0.288451    0.088462    0.013441    0.689552    
#> 008: 0.277854    1.007400    3.454111    0.274029    0.084038    0.018428    0.676471    
#> 009: 0.248556    0.994172    3.446621    0.260327    0.084053    0.017507    0.664190    
#> 010: 0.282345    0.999925    3.460604    0.247311    0.079850    0.019528    0.675070    
#> 011: 0.312912    1.020479    3.457137    0.261952    0.076420    0.020073    0.692625    
#> 012: 0.276701    1.010957    3.445397    0.250579    0.072599    0.020174    0.684440    
#> 013: 0.234637    1.027922    3.434474    0.252925    0.070365    0.023499    0.693610    
#> 014: 0.302870    1.019808    3.451623    0.240279    0.080583    0.022324    0.681892    
#> 015: 0.325749    1.015452    3.466722    0.228265    0.077833    0.021208    0.667168    
#> 016: 0.327850    1.011781    3.477307    0.216852    0.082281    0.020147    0.655781    
#> 017: 0.319176    1.005651    3.475308    0.218693    0.089900    0.019140    0.657805    
#> 018: 0.320088    1.028021    3.461724    0.207758    0.106388    0.018183    0.668509    
#> 019: 0.282546    1.011089    3.457989    0.209845    0.101068    0.017274    0.668291    
#> 020: 0.314275    0.991856    3.466517    0.199639    0.096015    0.016410    0.667991    
#> 021: 0.335004    0.994345    3.484242    0.189657    0.091214    0.015590    0.676749    
#> 022: 0.306399    1.014223    3.483774    0.196265    0.086653    0.014810    0.669500    
#> 023: 0.392404    0.999447    3.498307    0.211699    0.082321    0.014503    0.706366    
#> 024: 0.404323    1.011739    3.499423    0.232187    0.078205    0.014091    0.699592    
#> 025: 0.365088    0.975744    3.497715    0.220577    0.074294    0.014941    0.688697    
#> 026: 0.330005    1.005659    3.478076    0.209548    0.071679    0.014194    0.677896    
#> 027: 0.307621    1.007341    3.479745    0.202329    0.081328    0.014457    0.680937    
#> 028: 0.356295    0.975131    3.489274    0.199061    0.085620    0.013734    0.663192    
#> 029: 0.361734    0.995979    3.484317    0.189108    0.094150    0.013283    0.673905    
#> 030: 0.354336    1.004229    3.484085    0.229446    0.089442    0.014945    0.670536    
#> 031: 0.330509    0.990790    3.483018    0.217973    0.103822    0.014198    0.666028    
#> 032: 0.313304    0.980059    3.479997    0.207075    0.099360    0.013488    0.667887    
#> 033: 0.316459    1.013059    3.479947    0.196721    0.100051    0.012813    0.681682    
#> 034: 0.361130    1.014164    3.479101    0.216636    0.095048    0.014547    0.678601    
#> 035: 0.305778    0.980934    3.476021    0.205804    0.090296    0.013819    0.659673    
#> 036: 0.300067    0.980381    3.474496    0.195514    0.103984    0.013128    0.673872    
#> 037: 0.325807    1.004720    3.467347    0.195635    0.098785    0.012472    0.679053    
#> 038: 0.321257    1.007772    3.463769    0.236759    0.101023    0.013825    0.685444    
#> 039: 0.333580    0.986371    3.479032    0.224921    0.096610    0.016154    0.679511    
#> 040: 0.350366    0.998786    3.479203    0.258759    0.091780    0.015347    0.695975    
#> 041: 0.302711    0.981094    3.463711    0.245821    0.095161    0.015230    0.670027    
#> 042: 0.306319    0.997116    3.464973    0.233530    0.090403    0.014680    0.658570    
#> 043: 0.291454    1.008330    3.455827    0.221853    0.085883    0.015874    0.665093    
#> 044: 0.277986    1.024985    3.459704    0.210761    0.089823    0.016961    0.663804    
#> 045: 0.261143    1.036030    3.448320    0.200222    0.085332    0.017346    0.686747    
#> 046: 0.303184    1.009100    3.460588    0.235346    0.089592    0.017337    0.684551    
#> 047: 0.290341    1.015929    3.462577    0.223579    0.085112    0.018043    0.674548    
#> 048: 0.304215    1.017419    3.457419    0.217157    0.094193    0.017140    0.677824    
#> 049: 0.291571    1.031195    3.470253    0.206299    0.096781    0.016906    0.689313    
#> 050: 0.371847    0.997912    3.471397    0.206186    0.091942    0.018068    0.709610    
#> 051: 0.352823    0.998782    3.470997    0.216611    0.087345    0.019305    0.681146    
#> 052: 0.328116    0.991460    3.486691    0.210825    0.086852    0.018340    0.666183    
#> 053: 0.339992    0.991479    3.467557    0.250754    0.101750    0.017423    0.671285    
#> 054: 0.304329    1.009445    3.471088    0.238216    0.103465    0.016552    0.678034    
#> 055: 0.299606    1.003279    3.466151    0.226305    0.098291    0.015724    0.681714    
#> 056: 0.330715    0.982314    3.476507    0.214990    0.100608    0.014938    0.673571    
#> 057: 0.323314    0.982508    3.486822    0.204240    0.095578    0.015810    0.675376    
#> 058: 0.328218    0.983292    3.470972    0.209016    0.090799    0.015343    0.694166    
#> 059: 0.338700    0.962402    3.484363    0.211001    0.086259    0.015696    0.686011    
#> 060: 0.319201    0.972154    3.479703    0.209417    0.099420    0.014912    0.683710    
#> 061: 0.353505    0.995445    3.482841    0.227005    0.104612    0.014669    0.695035    
#> 062: 0.348997    1.005285    3.489199    0.215655    0.112372    0.013936    0.700075    
#> 063: 0.371690    0.979529    3.488984    0.222823    0.106753    0.013239    0.701964    
#> 064: 0.329916    0.992193    3.478375    0.212543    0.101416    0.012577    0.669340    
#> 065: 0.352518    0.991297    3.468431    0.208945    0.096345    0.011948    0.664811    
#> 066: 0.338985    1.008062    3.479441    0.198498    0.094198    0.012320    0.648742    
#> 067: 0.325003    0.974546    3.471602    0.206627    0.089688    0.011872    0.652237    
#> 068: 0.300808    1.000623    3.483797    0.196296    0.103069    0.013081    0.682666    
#> 069: 0.302065    1.004134    3.468312    0.186481    0.097915    0.012657    0.693297    
#> 070: 0.308423    0.993523    3.479889    0.188204    0.093292    0.013263    0.687011    
#> 071: 0.299394    1.017805    3.457993    0.200678    0.096877    0.012600    0.706444    
#> 072: 0.271210    0.993263    3.458923    0.203165    0.092033    0.012677    0.684980    
#> 073: 0.316771    1.012663    3.468087    0.205576    0.099369    0.013670    0.677465    
#> 074: 0.291508    0.993001    3.461254    0.195297    0.100639    0.013421    0.674785    
#> 075: 0.333055    0.997956    3.488352    0.208505    0.095607    0.012912    0.670803    
#> 076: 0.325224    1.006604    3.489174    0.198080    0.090827    0.014119    0.693775    
#> 077: 0.385656    0.987204    3.491090    0.198292    0.086286    0.016164    0.686454    
#> 078: 0.363111    0.986590    3.495016    0.190344    0.081971    0.015356    0.666759    
#> 079: 0.383909    0.995687    3.496687    0.211651    0.087168    0.014588    0.679425    
#> 080: 0.360044    0.992393    3.489815    0.215246    0.097459    0.013859    0.683901    
#> 081: 0.338834    1.009500    3.483792    0.218098    0.092586    0.013166    0.669611    
#> 082: 0.341917    0.993140    3.489642    0.227489    0.102342    0.012507    0.674746    
#> 083: 0.325018    1.024995    3.481067    0.219517    0.097225    0.012894    0.663957    
#> 084: 0.323778    1.018026    3.468144    0.208541    0.097010    0.012703    0.654934    
#> 085: 0.283114    1.027276    3.459863    0.198114    0.092159    0.012068    0.690372    
#> 086: 0.283200    1.028574    3.449708    0.223616    0.094387    0.012171    0.658940    
#> 087: 0.279727    1.028043    3.449013    0.212435    0.097744    0.012267    0.675385    
#> 088: 0.245771    1.021442    3.456159    0.218882    0.095546    0.011654    0.706177    
#> 089: 0.261946    1.029210    3.443247    0.207938    0.112134    0.011071    0.690248    
#> 090: 0.247585    1.021600    3.447673    0.202437    0.112235    0.010518    0.696331    
#> 091: 0.267535    1.015248    3.440615    0.192315    0.106845    0.009992    0.691459    
#> 092: 0.281156    1.042049    3.442695    0.193103    0.101503    0.009492    0.687879    
#> 093: 0.282243    1.010476    3.453655    0.189557    0.101936    0.009653    0.681697    
#> 094: 0.288652    1.015783    3.452762    0.180251    0.099060    0.009170    0.687484    
#> 095: 0.302152    1.028931    3.468910    0.192648    0.111199    0.008711    0.688635    
#> 096: 0.278633    1.007736    3.472409    0.201569    0.107338    0.009087    0.660660    
#> 097: 0.314815    1.036418    3.469231    0.191490    0.101972    0.009311    0.663165    
#> 098: 0.300518    1.038212    3.466625    0.189778    0.102250    0.010386    0.659520    
#> 099: 0.278712    1.005633    3.454232    0.180289    0.113633    0.009867    0.671617    
#> 100: 0.264549    1.014738    3.456977    0.187288    0.113530    0.009761    0.664036    
#> 101: 0.245694    1.017012    3.439793    0.211877    0.107853    0.009273    0.655062    
#> 102: 0.253472    1.035675    3.428282    0.222964    0.102461    0.008809    0.668061    
#> 103: 0.276332    1.021079    3.443320    0.211816    0.097338    0.008686    0.669707    
#> 104: 0.272388    1.020566    3.452621    0.217780    0.104456    0.008773    0.682416    
#> 105: 0.297139    1.022621    3.454563    0.206891    0.107189    0.009295    0.678895    
#> 106: 0.311953    1.015611    3.459681    0.214943    0.106479    0.011291    0.670288    
#> 107: 0.328998    1.033401    3.458981    0.213019    0.101155    0.010727    0.668731    
#> 108: 0.298770    1.006395    3.457980    0.202368    0.096097    0.010190    0.681977    
#> 109: 0.306908    1.012753    3.466555    0.199606    0.091292    0.009681    0.685740    
#> 110: 0.294335    1.012526    3.446305    0.189626    0.086969    0.009197    0.690028    
#> 111: 0.286942    1.017455    3.464013    0.187250    0.082621    0.008737    0.680000    
#> 112: 0.311713    0.997897    3.459269    0.177888    0.082717    0.008300    0.697407    
#> 113: 0.292019    1.023281    3.456679    0.168993    0.090037    0.008477    0.682175    
#> 114: 0.268490    1.032656    3.463387    0.160544    0.085535    0.008054    0.692667    
#> 115: 0.326980    1.006384    3.464083    0.187800    0.081259    0.008920    0.701803    
#> 116: 0.317441    1.008784    3.469029    0.197815    0.107157    0.010899    0.681142    
#> 117: 0.323358    0.984506    3.473722    0.199271    0.101799    0.011558    0.674767    
#> 118: 0.317731    0.977449    3.483251    0.189307    0.096709    0.011788    0.681306    
#> 119: 0.308493    1.003618    3.475119    0.213739    0.091874    0.011199    0.674237    
#> 120: 0.273303    1.016292    3.448453    0.214518    0.087280    0.012447    0.673371    
#> 121: 0.302107    1.046124    3.455766    0.209818    0.093404    0.013010    0.683474    
#> 122: 0.315642    1.016615    3.472203    0.205444    0.095614    0.014238    0.680354    
#> 123: 0.334214    1.024785    3.468669    0.217835    0.090833    0.013636    0.669366    
#> 124: 0.302445    1.060019    3.455831    0.249206    0.086291    0.014408    0.656914    
#> 125: 0.300003    1.046365    3.450586    0.236746    0.081977    0.013911    0.670388    
#> 126: 0.269609    1.057733    3.435001    0.224909    0.077878    0.020875    0.674864    
#> 127: 0.276472    1.038991    3.438867    0.243197    0.073984    0.019832    0.685048    
#> 128: 0.239146    1.025643    3.445482    0.231037    0.074165    0.018840    0.664090    
#> 129: 0.262574    1.038875    3.443409    0.219486    0.077086    0.017898    0.662753    
#> 130: 0.315290    1.044301    3.455899    0.252304    0.090661    0.017003    0.649251    
#> 131: 0.295727    1.011940    3.450862    0.249879    0.103874    0.016153    0.667138    
#> 132: 0.255873    1.033168    3.432749    0.237385    0.098680    0.015345    0.677165    
#> 133: 0.254925    1.017990    3.452077    0.233950    0.093746    0.014578    0.668018    
#> 134: 0.309899    1.010577    3.467380    0.222252    0.113977    0.013849    0.681054    
#> 135: 0.309741    1.010296    3.464528    0.229974    0.108278    0.013157    0.669795    
#> 136: 0.316906    0.989320    3.470296    0.252260    0.109464    0.012499    0.666936    
#> 137: 0.348485    0.998814    3.473315    0.273189    0.103991    0.011874    0.678689    
#> 138: 0.341107    1.005186    3.469964    0.282667    0.098791    0.012557    0.660146    
#> 139: 0.348975    1.015099    3.478033    0.268534    0.093852    0.014530    0.666690    
#> 140: 0.344286    1.020247    3.478928    0.262376    0.089351    0.013803    0.678047    
#> 141: 0.303424    0.990995    3.473099    0.249257    0.084884    0.013113    0.678682    
#> 142: 0.353964    0.987407    3.491420    0.259537    0.092433    0.012793    0.683450    
#> 143: 0.316058    1.010942    3.490364    0.246560    0.087811    0.012153    0.676569    
#> 144: 0.359062    0.999477    3.493174    0.234232    0.083421    0.011546    0.666541    
#> 145: 0.321497    1.006277    3.472573    0.224158    0.079250    0.010968    0.668095    
#> 146: 0.303926    1.019618    3.468843    0.232422    0.081680    0.010681    0.670754    
#> 147: 0.246505    0.999038    3.457267    0.220801    0.091763    0.010799    0.654110    
#> 148: 0.283105    1.007400    3.469141    0.209761    0.090030    0.010259    0.681161    
#> 149: 0.298336    1.010624    3.464785    0.199273    0.089797    0.009746    0.692676    
#> 150: 0.292850    1.004123    3.452104    0.193693    0.102695    0.009259    0.700645    
#> 151: 0.254349    1.043400    3.441781    0.184008    0.112094    0.008796    0.693532    
#> 152: 0.270116    1.021365    3.458708    0.187729    0.082476    0.008689    0.673150    
#> 153: 0.276643    1.000693    3.464513    0.196741    0.084933    0.009730    0.688828    
#> 154: 0.322631    1.008210    3.478337    0.197615    0.087171    0.011424    0.695663    
#> 155: 0.320770    0.999411    3.478281    0.202840    0.105118    0.011505    0.683447    
#> 156: 0.313605    1.015459    3.480691    0.201967    0.106048    0.013452    0.670760    
#> 157: 0.341810    1.008902    3.484164    0.150457    0.110246    0.013159    0.691022    
#> 158: 0.350889    1.014760    3.479803    0.174822    0.107265    0.012161    0.678810    
#> 159: 0.317344    1.005724    3.484669    0.188645    0.107563    0.010278    0.668604    
#> 160: 0.357780    0.962147    3.497221    0.176939    0.110150    0.011629    0.680889    
#> 161: 0.364391    0.984030    3.493227    0.201372    0.096885    0.010533    0.691875    
#> 162: 0.347987    1.002650    3.476935    0.194430    0.090890    0.008444    0.695765    
#> 163: 0.340414    1.005745    3.470033    0.207527    0.123843    0.009028    0.676430    
#> 164: 0.284671    1.022136    3.462306    0.171887    0.112466    0.010492    0.682796    
#> 165: 0.332471    0.986797    3.487247    0.232873    0.104193    0.014228    0.671060    
#> 166: 0.335378    1.028381    3.480832    0.216988    0.098990    0.012049    0.681913    
#> 167: 0.358203    1.014538    3.494652    0.214688    0.099006    0.014784    0.681121    
#> 168: 0.378446    1.015257    3.490026    0.241331    0.094673    0.015342    0.683517    
#> 169: 0.348678    1.042599    3.476391    0.244789    0.095094    0.014479    0.678486    
#> 170: 0.330447    1.008346    3.478276    0.217284    0.090455    0.014743    0.651734    
#> 171: 0.312035    0.997719    3.472813    0.227888    0.084238    0.012073    0.649867    
#> 172: 0.311828    1.015578    3.469503    0.210148    0.090697    0.011688    0.660956    
#> 173: 0.319526    1.032016    3.459520    0.200774    0.088981    0.014053    0.668988    
#> 174: 0.284314    1.018096    3.454969    0.191322    0.082659    0.018698    0.668563    
#> 175: 0.275291    1.023574    3.452369    0.187006    0.096219    0.013298    0.667047    
#> 176: 0.284632    1.043440    3.463782    0.186937    0.093943    0.012184    0.669002    
#> 177: 0.309817    1.007155    3.474774    0.166867    0.088175    0.010360    0.676189    
#> 178: 0.333077    0.993551    3.475406    0.192774    0.085384    0.011725    0.680155    
#> 179: 0.349241    1.011501    3.471264    0.260100    0.091569    0.011962    0.686026    
#> 180: 0.329624    1.009929    3.474452    0.223888    0.076262    0.010267    0.673693    
#> 181: 0.336843    1.008038    3.462457    0.184032    0.077078    0.010848    0.678068    
#> 182: 0.302655    1.004168    3.461512    0.213185    0.074297    0.012329    0.676329    
#> 183: 0.311526    1.015559    3.468086    0.162534    0.074947    0.015166    0.665656    
#> 184: 0.341670    0.987670    3.474438    0.164192    0.089079    0.011252    0.676831    
#> 185: 0.308836    1.025391    3.472572    0.149439    0.101692    0.008859    0.676210    
#> 186: 0.328657    1.027637    3.474129    0.167038    0.089958    0.008776    0.673917    
#> 187: 0.308667    1.005937    3.478096    0.172872    0.106145    0.009298    0.659359    
#> 188: 0.285659    1.014559    3.470563    0.166162    0.103729    0.007009    0.682267    
#> 189: 0.329619    1.024856    3.477799    0.159295    0.095175    0.007168    0.707073    
#> 190: 0.307011    1.017036    3.477453    0.201172    0.092041    0.008485    0.672813    
#> 191: 0.301386    1.027113    3.459935    0.174137    0.094011    0.009645    0.676339    
#> 192: 0.296390    1.030378    3.475918    0.195764    0.082422    0.010918    0.677386    
#> 193: 0.339323    1.018701    3.474296    0.173563    0.093713    0.009172    0.663006    
#> 194: 0.290818    1.005130    3.465558    0.196189    0.105512    0.009798    0.691802    
#> 195: 0.244534    1.025111    3.454642    0.167914    0.096509    0.009418    0.678544    
#> 196: 0.272686    1.019117    3.461454    0.160719    0.087975    0.010221    0.693254    
#> 197: 0.253480    1.011115    3.478062    0.159461    0.094810    0.010454    0.705402    
#> 198: 0.325693    0.990941    3.476123    0.144676    0.094470    0.012638    0.673291    
#> 199: 0.297173    1.004007    3.469897    0.175896    0.100445    0.010822    0.670877    
#> 200: 0.304354    1.005889    3.470902    0.181765    0.117270    0.009314    0.678782    
#> 201: 0.303653    1.001217    3.473607    0.195440    0.109002    0.010219    0.672478    
#> 202: 0.302560    1.007554    3.473638    0.202550    0.105960    0.010681    0.671379    
#> 203: 0.313775    1.008772    3.470885    0.200835    0.103415    0.010861    0.673590    
#> 204: 0.319902    1.000361    3.472909    0.206505    0.099734    0.011283    0.677439    
#> 205: 0.318010    1.002570    3.473453    0.200687    0.095463    0.011377    0.683561    
#> 206: 0.317673    1.007483    3.473588    0.200621    0.094313    0.011581    0.685915    
#> 207: 0.316444    1.005684    3.471850    0.207555    0.094318    0.011631    0.686451    
#> 208: 0.318329    1.006116    3.472215    0.210814    0.094602    0.011471    0.685520    
#> 209: 0.319251    1.004137    3.471330    0.209300    0.095193    0.011526    0.684007    
#> 210: 0.320393    1.003457    3.471623    0.209211    0.095315    0.011420    0.682553    
#> 211: 0.322494    1.005126    3.472328    0.207086    0.095194    0.011494    0.680731    
#> 212: 0.323910    1.005226    3.472881    0.206295    0.094450    0.011524    0.680705    
#> 213: 0.326641    1.003826    3.473393    0.206032    0.094607    0.011822    0.680461    
#> 214: 0.327214    1.003850    3.473475    0.205309    0.094267    0.012006    0.679307    
#> 215: 0.326980    1.004552    3.473477    0.204880    0.093738    0.012143    0.678885    
#> 216: 0.328255    1.004362    3.473758    0.205153    0.094313    0.012066    0.678552    
#> 217: 0.327495    1.005390    3.473710    0.205968    0.094218    0.011969    0.677550    
#> 218: 0.326388    1.005552    3.473143    0.206371    0.094549    0.011988    0.676576    
#> 219: 0.325345    1.005035    3.472005    0.208036    0.094647    0.011975    0.675758    
#> 220: 0.323543    1.005674    3.471283    0.210189    0.094090    0.011983    0.674954    
#> 221: 0.322243    1.006858    3.470385    0.212520    0.093911    0.011900    0.674203    
#> 222: 0.322209    1.006435    3.469904    0.214066    0.093977    0.011909    0.674353    
#> 223: 0.323525    1.006475    3.469381    0.214689    0.093683    0.011818    0.674387    
#> 224: 0.324799    1.006911    3.469421    0.214269    0.093088    0.011783    0.675030    
#> 225: 0.325457    1.004937    3.469963    0.213646    0.092709    0.011744    0.675626    
#> 226: 0.325511    1.004401    3.469878    0.213201    0.093205    0.011666    0.675922    
#> 227: 0.325247    1.004656    3.469835    0.211343    0.093143    0.011601    0.676175    
#> 228: 0.324687    1.005738    3.469120    0.211400    0.093371    0.011493    0.675838    
#> 229: 0.323314    1.005377    3.468732    0.210215    0.093266    0.011461    0.675474    
#> 230: 0.323436    1.004871    3.468566    0.210234    0.092859    0.011424    0.675614    
#> 231: 0.322661    1.005746    3.468633    0.209664    0.093189    0.011415    0.675546    
#> 232: 0.321180    1.006299    3.468811    0.209251    0.093201    0.011406    0.675482    
#> 233: 0.320040    1.005795    3.468821    0.208455    0.093504    0.011412    0.675669    
#> 234: 0.319342    1.005652    3.468766    0.207892    0.093332    0.011443    0.675934    
#> 235: 0.319267    1.005436    3.468617    0.207592    0.093033    0.011485    0.676174    
#> 236: 0.319307    1.005915    3.468455    0.207444    0.093446    0.011476    0.676506    
#> 237: 0.319596    1.005847    3.468338    0.207941    0.093416    0.011463    0.677026    
#> 238: 0.320063    1.005840    3.468298    0.209133    0.093742    0.011458    0.677472    
#> 239: 0.318715    1.006229    3.468064    0.209823    0.093998    0.011508    0.677099    
#> 240: 0.318018    1.006135    3.467999    0.209984    0.093957    0.011539    0.676855    
#> 241: 0.317853    1.005406    3.468023    0.208851    0.093971    0.011528    0.676551    
#> 242: 0.317080    1.004995    3.467707    0.208467    0.093697    0.011533    0.676659    
#> 243: 0.316374    1.005497    3.467628    0.208131    0.093682    0.011511    0.677092    
#> 244: 0.315145    1.005519    3.467622    0.207522    0.093826    0.011467    0.677577    
#> 245: 0.314525    1.005198    3.467603    0.208492    0.094259    0.011435    0.678254    
#> 246: 0.313851    1.005317    3.467365    0.208758    0.094249    0.011426    0.678609    
#> 247: 0.314061    1.004858    3.467606    0.208252    0.094367    0.011376    0.678928    
#> 248: 0.313716    1.005177    3.467549    0.207513    0.094547    0.011319    0.678859    
#> 249: 0.313554    1.005404    3.467601    0.207392    0.094697    0.011255    0.678801    
#> 250: 0.314040    1.005579    3.467809    0.207339    0.094764    0.011229    0.678540    
#> 251: 0.314580    1.006069    3.468088    0.207099    0.094664    0.011213    0.678501    
#> 252: 0.314874    1.006595    3.468197    0.207240    0.094714    0.011164    0.678318    
#> 253: 0.314733    1.006858    3.468204    0.207079    0.094707    0.011155    0.678222    
#> 254: 0.314875    1.007294    3.468359    0.206715    0.094757    0.011107    0.678369    
#> 255: 0.314838    1.007775    3.468447    0.206256    0.094679    0.011089    0.678898    
#> 256: 0.315086    1.007563    3.468361    0.206334    0.094878    0.011083    0.679068    
#> 257: 0.315448    1.007223    3.468552    0.206434    0.095067    0.011089    0.679201    
#> 258: 0.315416    1.006749    3.468688    0.205758    0.095081    0.011070    0.679338    
#> 259: 0.315481    1.006906    3.468730    0.204965    0.094985    0.011096    0.679508    
#> 260: 0.315295    1.006996    3.468733    0.204613    0.094994    0.011129    0.679272    
#> 261: 0.315360    1.007107    3.468804    0.204941    0.095018    0.011177    0.679299    
#> 262: 0.315186    1.007503    3.468600    0.205324    0.094803    0.011224    0.679257    
#> 263: 0.314752    1.007580    3.468530    0.205431    0.094784    0.011282    0.679294    
#> 264: 0.314335    1.007756    3.468444    0.205541    0.094593    0.011307    0.679433    
#> 265: 0.314531    1.007721    3.468605    0.205489    0.094164    0.011388    0.679236    
#> 266: 0.314789    1.007825    3.468749    0.205264    0.093859    0.011461    0.679173    
#> 267: 0.314950    1.007720    3.468929    0.205437    0.093722    0.011531    0.678952    
#> 268: 0.315120    1.007467    3.469054    0.205816    0.093759    0.011559    0.678750    
#> 269: 0.315954    1.007293    3.469328    0.205666    0.093897    0.011579    0.678779    
#> 270: 0.316864    1.007074    3.469492    0.205821    0.093827    0.011579    0.678701    
#> 271: 0.316959    1.006900    3.469507    0.206108    0.093766    0.011614    0.679022    
#> 272: 0.317053    1.006829    3.469479    0.206101    0.093572    0.011650    0.679300    
#> 273: 0.317201    1.007165    3.469470    0.206122    0.093376    0.011664    0.679664    
#> 274: 0.316914    1.007394    3.469590    0.206324    0.093302    0.011713    0.679554    
#> 275: 0.316750    1.007721    3.469460    0.206667    0.093116    0.011745    0.679472    
#> 276: 0.316742    1.007613    3.469717    0.206799    0.092947    0.011802    0.679433    
#> 277: 0.316449    1.007730    3.469796    0.206431    0.092888    0.011838    0.679228    
#> 278: 0.316522    1.007732    3.469885    0.206195    0.092902    0.011874    0.679136    
#> 279: 0.316774    1.007607    3.469989    0.206513    0.093066    0.011895    0.679212    
#> 280: 0.316744    1.007676    3.470002    0.206397    0.093150    0.011890    0.678933    
#> 281: 0.316514    1.007903    3.469981    0.206016    0.093134    0.011899    0.678825    
#> 282: 0.316356    1.008017    3.470009    0.205341    0.093232    0.011918    0.678768    
#> 283: 0.316339    1.008168    3.470100    0.205554    0.093379    0.011956    0.678981    
#> 284: 0.315791    1.008019    3.470016    0.205784    0.093366    0.011972    0.678999    
#> 285: 0.315657    1.007995    3.469860    0.205773    0.093494    0.011982    0.678931    
#> 286: 0.315448    1.008276    3.469655    0.205712    0.093609    0.011967    0.678673    
#> 287: 0.315135    1.008526    3.469493    0.205571    0.093699    0.011935    0.678744    
#> 288: 0.315409    1.008511    3.469489    0.205303    0.093809    0.011934    0.678916    
#> 289: 0.315746    1.008381    3.469541    0.205138    0.093808    0.011958    0.678995    
#> 290: 0.315968    1.008224    3.469608    0.204785    0.093992    0.011968    0.679063    
#> 291: 0.316293    1.008314    3.469789    0.204598    0.093898    0.012005    0.678933    
#> 292: 0.316482    1.008069    3.469992    0.204542    0.093840    0.012033    0.678925    
#> 293: 0.316565    1.007938    3.470096    0.204209    0.093808    0.012042    0.678784    
#> 294: 0.316481    1.007891    3.470128    0.204141    0.093851    0.012028    0.678650    
#> 295: 0.316450    1.007575    3.470147    0.204101    0.093796    0.012009    0.678456    
#> 296: 0.316424    1.007626    3.470162    0.203887    0.093714    0.012034    0.678488    
#> 297: 0.316466    1.007843    3.470102    0.203853    0.093539    0.012039    0.678439    
#> 298: 0.316513    1.007782    3.470127    0.203768    0.093401    0.012027    0.678394    
#> 299: 0.316336    1.007851    3.470098    0.203706    0.093294    0.012037    0.678341    
#> 300: 0.316320    1.007680    3.470173    0.203558    0.093260    0.012046    0.678222    
#> 301: 0.316242    1.007445    3.470107    0.203573    0.093269    0.012038    0.678160    
#> 302: 0.316204    1.007474    3.470052    0.203419    0.093372    0.012042    0.678085    
#> 303: 0.315962    1.007556    3.469896    0.203056    0.093339    0.012045    0.677953    
#> 304: 0.315860    1.007851    3.469745    0.203126    0.093331    0.012034    0.678029    
#> 305: 0.315751    1.007585    3.469671    0.203005    0.093402    0.011997    0.678081    
#> 306: 0.315445    1.007485    3.469559    0.202891    0.093345    0.011974    0.678129    
#> 307: 0.315338    1.007439    3.469470    0.203044    0.093418    0.011940    0.678283    
#> 308: 0.315030    1.007332    3.469427    0.202787    0.093405    0.011930    0.678396    
#> 309: 0.315001    1.007004    3.469410    0.202918    0.093382    0.011944    0.678467    
#> 310: 0.314894    1.006880    3.469367    0.203231    0.093330    0.011966    0.678503    
#> 311: 0.314447    1.006827    3.469303    0.203196    0.093223    0.011979    0.678525    
#> 312: 0.314316    1.006749    3.469167    0.203110    0.093107    0.012003    0.678601    
#> 313: 0.314033    1.006604    3.468959    0.202892    0.093001    0.012016    0.678714    
#> 314: 0.313695    1.006803    3.468809    0.202816    0.092972    0.012029    0.678651    
#> 315: 0.313286    1.007092    3.468673    0.202894    0.092947    0.012022    0.678611    
#> 316: 0.313157    1.007398    3.468572    0.202558    0.093060    0.012029    0.678563    
#> 317: 0.313145    1.007391    3.468602    0.202746    0.093077    0.012035    0.678637    
#> 318: 0.312887    1.007617    3.468402    0.202925    0.092955    0.012035    0.678484    
#> 319: 0.312519    1.007637    3.468245    0.202838    0.092881    0.012041    0.678374    
#> 320: 0.312138    1.007686    3.468147    0.202608    0.093034    0.012048    0.678439    
#> 321: 0.312057    1.007804    3.468045    0.202553    0.093104    0.012028    0.678505    
#> 322: 0.311738    1.007799    3.467891    0.202469    0.093264    0.012024    0.678510    
#> 323: 0.311168    1.007883    3.467764    0.202445    0.093300    0.012022    0.678463    
#> 324: 0.310951    1.008131    3.467760    0.202435    0.093205    0.012019    0.678258    
#> 325: 0.310839    1.008321    3.467644    0.202312    0.093168    0.012004    0.678146    
#> 326: 0.310676    1.008190    3.467569    0.202401    0.093148    0.011989    0.678107    
#> 327: 0.310775    1.008247    3.467546    0.202467    0.093229    0.011973    0.678218    
#> 328: 0.310772    1.008269    3.467481    0.202371    0.093238    0.011932    0.678143    
#> 329: 0.310786    1.008267    3.467468    0.202048    0.093399    0.011886    0.678277    
#> 330: 0.310686    1.008312    3.467465    0.201855    0.093299    0.011870    0.678277    
#> 331: 0.310897    1.008339    3.467482    0.201837    0.093272    0.011850    0.678292    
#> 332: 0.310864    1.008373    3.467529    0.201783    0.093315    0.011847    0.678327    
#> 333: 0.310640    1.008390    3.467415    0.201826    0.093251    0.011837    0.678335    
#> 334: 0.310449    1.008169    3.467298    0.201910    0.093258    0.011822    0.678336    
#> 335: 0.310065    1.008275    3.467124    0.202041    0.093194    0.011809    0.678258    
#> 336: 0.309512    1.008410    3.466936    0.202269    0.093149    0.011812    0.678189    
#> 337: 0.309158    1.008707    3.466702    0.202548    0.093139    0.011810    0.678236    
#> 338: 0.308820    1.008830    3.466582    0.202834    0.093185    0.011797    0.678236    
#> 339: 0.308454    1.009049    3.466418    0.202892    0.093319    0.011779    0.678194    
#> 340: 0.308294    1.009021    3.466332    0.203099    0.093478    0.011754    0.678237    
#> 341: 0.308106    1.008978    3.466285    0.203245    0.093677    0.011733    0.678199    
#> 342: 0.307757    1.008831    3.466172    0.203308    0.093834    0.011714    0.678181    
#> 343: 0.307631    1.008877    3.466188    0.203056    0.093833    0.011691    0.678217    
#> 344: 0.307714    1.008905    3.466236    0.202792    0.093865    0.011686    0.678260    
#> 345: 0.307708    1.008785    3.466263    0.202748    0.093956    0.011698    0.678203    
#> 346: 0.307739    1.008749    3.466199    0.202758    0.094003    0.011696    0.678115    
#> 347: 0.307772    1.008685    3.466108    0.202970    0.094080    0.011704    0.678165    
#> 348: 0.307464    1.008716    3.466033    0.202848    0.094159    0.011702    0.678137    
#> 349: 0.307169    1.008645    3.465969    0.202997    0.094165    0.011717    0.678132    
#> 350: 0.306905    1.008609    3.465890    0.202965    0.094252    0.011712    0.678095    
#> 351: 0.306820    1.008787    3.465820    0.202974    0.094326    0.011703    0.678005    
#> 352: 0.306503    1.008979    3.465714    0.203252    0.094418    0.011684    0.678055    
#> 353: 0.306451    1.009137    3.465637    0.203383    0.094396    0.011680    0.678023    
#> 354: 0.306371    1.009316    3.465467    0.203775    0.094321    0.011699    0.677935    
#> 355: 0.306516    1.009252    3.465373    0.204030    0.094276    0.011690    0.677819    
#> 356: 0.306519    1.009282    3.465368    0.204235    0.094305    0.011679    0.677848    
#> 357: 0.306527    1.009397    3.465380    0.204193    0.094346    0.011688    0.677832    
#> 358: 0.306674    1.009431    3.465469    0.204238    0.094251    0.011695    0.677780    
#> 359: 0.306777    1.009542    3.465499    0.204374    0.094136    0.011715    0.677738    
#> 360: 0.306749    1.009564    3.465421    0.204203    0.094173    0.011733    0.677568    
#> 361: 0.306588    1.009625    3.465336    0.203991    0.094133    0.011735    0.677491    
#> 362: 0.306565    1.009646    3.465254    0.203836    0.094108    0.011728    0.677352    
#> 363: 0.306467    1.009641    3.465211    0.203746    0.094103    0.011713    0.677182    
#> 364: 0.306553    1.009742    3.465199    0.203819    0.094130    0.011711    0.677159    
#> 365: 0.306367    1.009752    3.465186    0.203733    0.094178    0.011739    0.677199    
#> 366: 0.306387    1.009724    3.465119    0.203764    0.094131    0.011776    0.677210    
#> 367: 0.306385    1.009742    3.465112    0.203793    0.094081    0.011790    0.677245    
#> 368: 0.306503    1.009793    3.465115    0.203930    0.094026    0.011813    0.677154    
#> 369: 0.306401    1.009764    3.465084    0.204147    0.093987    0.011827    0.677134    
#> 370: 0.306335    1.009843    3.465027    0.204340    0.093909    0.011833    0.677053    
#> 371: 0.306228    1.010066    3.464894    0.204444    0.093862    0.011833    0.677082    
#> 372: 0.306113    1.010229    3.464806    0.204694    0.093861    0.011838    0.677038    
#> 373: 0.305861    1.010467    3.464705    0.204865    0.093811    0.011849    0.677003    
#> 374: 0.305820    1.010568    3.464690    0.204845    0.093697    0.011872    0.676955    
#> 375: 0.305821    1.010597    3.464671    0.204831    0.093575    0.011870    0.677013    
#> 376: 0.305859    1.010601    3.464669    0.204838    0.093558    0.011894    0.676969    
#> 377: 0.305753    1.010714    3.464649    0.204693    0.093531    0.011901    0.676923    
#> 378: 0.305579    1.010713    3.464607    0.204319    0.093554    0.011896    0.676996    
#> 379: 0.305525    1.010616    3.464644    0.204144    0.093572    0.011892    0.677017    
#> 380: 0.305317    1.010667    3.464634    0.204043    0.093628    0.011891    0.677017    
#> 381: 0.305068    1.010768    3.464591    0.203941    0.093646    0.011885    0.677040    
#> 382: 0.305054    1.010824    3.464556    0.204064    0.093642    0.011886    0.676974    
#> 383: 0.305112    1.010835    3.464535    0.204319    0.093678    0.011883    0.676833    
#> 384: 0.304992    1.010748    3.464534    0.204490    0.093608    0.011884    0.676780    
#> 385: 0.305019    1.010725    3.464569    0.204607    0.093595    0.011892    0.676698    
#> 386: 0.305205    1.010860    3.464613    0.204755    0.093581    0.011900    0.676633    
#> 387: 0.305419    1.010968    3.464701    0.204686    0.093555    0.011907    0.676546    
#> 388: 0.305655    1.010968    3.464796    0.204753    0.093489    0.011912    0.676594    
#> 389: 0.305844    1.010784    3.464843    0.204831    0.093402    0.011918    0.676645    
#> 390: 0.305706    1.010920    3.464789    0.204896    0.093375    0.011909    0.676684    
#> 391: 0.305616    1.010919    3.464757    0.205078    0.093314    0.011912    0.676695    
#> 392: 0.305695    1.010946    3.464792    0.205175    0.093275    0.011912    0.676655    
#> 393: 0.305565    1.010895    3.464766    0.205302    0.093224    0.011918    0.676577    
#> 394: 0.305680    1.010877    3.464796    0.205344    0.093192    0.011918    0.676482    
#> 395: 0.305876    1.010956    3.464852    0.205179    0.093233    0.011919    0.676498    
#> 396: 0.306017    1.011009    3.464889    0.205164    0.093226    0.011919    0.676442    
#> 397: 0.306129    1.010910    3.464949    0.205265    0.093228    0.011927    0.676385    
#> 398: 0.306335    1.010815    3.465014    0.205387    0.093183    0.011940    0.676381    
#> 399: 0.306501    1.010815    3.465055    0.205285    0.093199    0.011945    0.676327    
#> 400: 0.306589    1.010868    3.465089    0.205292    0.093246    0.011939    0.676258    
#> 401: 0.306651    1.010911    3.465121    0.205280    0.093282    0.011943    0.676243    
#> 402: 0.306690    1.010946    3.465120    0.205323    0.093325    0.011937    0.676264    
#> 403: 0.306807    1.010914    3.465131    0.205287    0.093353    0.011936    0.676218    
#> 404: 0.306894    1.011000    3.465109    0.205129    0.093348    0.011918    0.676150    
#> 405: 0.306844    1.011051    3.465118    0.205058    0.093357    0.011909    0.676153    
#> 406: 0.306812    1.011031    3.465133    0.205044    0.093393    0.011906    0.676241    
#> 407: 0.306918    1.010998    3.465188    0.205085    0.093545    0.011890    0.676218    
#> 408: 0.307008    1.010986    3.465244    0.205002    0.093608    0.011879    0.676286    
#> 409: 0.306854    1.010961    3.465167    0.204967    0.093554    0.011859    0.676212    
#> 410: 0.306743    1.010952    3.465067    0.204897    0.093611    0.011844    0.676227    
#> 411: 0.306811    1.010740    3.465072    0.204830    0.093571    0.011846    0.676354    
#> 412: 0.306783    1.010774    3.465018    0.204894    0.093595    0.011846    0.676314    
#> 413: 0.306681    1.010797    3.464945    0.205000    0.093566    0.011835    0.676373    
#> 414: 0.306452    1.010779    3.464910    0.205036    0.093566    0.011824    0.676357    
#> 415: 0.306351    1.010741    3.464848    0.205115    0.093601    0.011819    0.676365    
#> 416: 0.306280    1.010803    3.464809    0.205220    0.093653    0.011821    0.676339    
#> 417: 0.306262    1.010841    3.464805    0.205155    0.093672    0.011813    0.676351    
#> 418: 0.306140    1.010935    3.464795    0.205130    0.093658    0.011801    0.676327    
#> 419: 0.306156    1.011024    3.464826    0.205161    0.093700    0.011788    0.676285    
#> 420: 0.306283    1.011097    3.464842    0.205122    0.093771    0.011780    0.676264    
#> 421: 0.306289    1.011142    3.464886    0.205135    0.093820    0.011772    0.676276    
#> 422: 0.306449    1.010998    3.464939    0.205200    0.093877    0.011750    0.676369    
#> 423: 0.306698    1.010895    3.465004    0.205161    0.093984    0.011738    0.676500    
#> 424: 0.306756    1.010813    3.465028    0.205114    0.094010    0.011733    0.676514    
#> 425: 0.306986    1.010765    3.465057    0.205221    0.093965    0.011741    0.676589    
#> 426: 0.307242    1.010790    3.465141    0.205256    0.093909    0.011737    0.676546    
#> 427: 0.307312    1.010697    3.465208    0.205187    0.093812    0.011727    0.676578    
#> 428: 0.307240    1.010704    3.465240    0.205237    0.093884    0.011713    0.676628    
#> 429: 0.307309    1.010710    3.465286    0.205230    0.093942    0.011696    0.676615    
#> 430: 0.307270    1.010737    3.465266    0.205263    0.093973    0.011687    0.676637    
#> 431: 0.307062    1.010727    3.465206    0.205366    0.093984    0.011688    0.676644    
#> 432: 0.306904    1.010771    3.465188    0.205415    0.094024    0.011694    0.676593    
#> 433: 0.306928    1.010890    3.465199    0.205507    0.093932    0.011689    0.676605    
#> 434: 0.306913    1.010851    3.465197    0.205630    0.093911    0.011687    0.676534    
#> 435: 0.306881    1.010872    3.465180    0.205646    0.093896    0.011682    0.676496    
#> 436: 0.306882    1.010792    3.465232    0.205552    0.093915    0.011682    0.676529    
#> 437: 0.306893    1.010692    3.465236    0.205576    0.093978    0.011674    0.676573    
#> 438: 0.306951    1.010773    3.465265    0.205608    0.093943    0.011665    0.676648    
#> 439: 0.307033    1.010872    3.465268    0.205688    0.093951    0.011652    0.676654    
#> 440: 0.307055    1.010934    3.465304    0.205580    0.093984    0.011636    0.676645    
#> 441: 0.307033    1.010939    3.465315    0.205460    0.093993    0.011626    0.676653    
#> 442: 0.306997    1.010981    3.465350    0.205402    0.094046    0.011627    0.676562    
#> 443: 0.307038    1.011042    3.465333    0.205421    0.093993    0.011635    0.676598    
#> 444: 0.307024    1.011138    3.465276    0.205404    0.093973    0.011643    0.676549    
#> 445: 0.306908    1.011179    3.465200    0.205415    0.093935    0.011644    0.676493    
#> 446: 0.306708    1.011265    3.465140    0.205394    0.093930    0.011636    0.676487    
#> 447: 0.306774    1.011308    3.465081    0.205377    0.093867    0.011640    0.676466    
#> 448: 0.306604    1.011368    3.465021    0.205397    0.093835    0.011641    0.676383    
#> 449: 0.306644    1.011444    3.465064    0.205461    0.093809    0.011640    0.676390    
#> 450: 0.306589    1.011437    3.465065    0.205472    0.093819    0.011641    0.676358    
#> 451: 0.306687    1.011409    3.465067    0.205491    0.093851    0.011638    0.676389    
#> 452: 0.306718    1.011465    3.465033    0.205504    0.093858    0.011642    0.676353    
#> 453: 0.306693    1.011415    3.465014    0.205451    0.093811    0.011648    0.676286    
#> 454: 0.306604    1.011539    3.464984    0.205479    0.093780    0.011644    0.676300    
#> 455: 0.306520    1.011641    3.464937    0.205496    0.093813    0.011634    0.676312    
#> 456: 0.306337    1.011659    3.464904    0.205565    0.093843    0.011632    0.676380    
#> 457: 0.306345    1.011615    3.464935    0.205525    0.093894    0.011628    0.676309    
#> 458: 0.306263    1.011749    3.464939    0.205543    0.093890    0.011635    0.676338    
#> 459: 0.306137    1.011878    3.464935    0.205506    0.093864    0.011642    0.676354    
#> 460: 0.306073    1.011918    3.464903    0.205598    0.093826    0.011659    0.676293    
#> 461: 0.305994    1.011971    3.464907    0.205792    0.093799    0.011665    0.676290    
#> 462: 0.305967    1.012029    3.464957    0.205838    0.093767    0.011667    0.676267    
#> 463: 0.306047    1.012033    3.465010    0.205795    0.093768    0.011666    0.676237    
#> 464: 0.306163    1.012023    3.465043    0.205721    0.093759    0.011657    0.676184    
#> 465: 0.306172    1.011877    3.465082    0.205639    0.093736    0.011649    0.676170    
#> 466: 0.306115    1.011862    3.465065    0.205614    0.093752    0.011640    0.676128    
#> 467: 0.306001    1.011808    3.465061    0.205460    0.093770    0.011621    0.676099    
#> 468: 0.306101    1.011810    3.465087    0.205444    0.093742    0.011620    0.676113    
#> 469: 0.306213    1.011832    3.465119    0.205570    0.093743    0.011615    0.676138    
#> 470: 0.306214    1.011862    3.465098    0.205694    0.093738    0.011615    0.676120    
#> 471: 0.306139    1.011825    3.465076    0.205686    0.093687    0.011610    0.676073    
#> 472: 0.306119    1.011818    3.465072    0.205700    0.093720    0.011604    0.676060    
#> 473: 0.306034    1.011863    3.465039    0.205730    0.093744    0.011605    0.675990    
#> 474: 0.305998    1.011870    3.465027    0.205862    0.093764    0.011615    0.676020    
#> 475: 0.306037    1.011837    3.465029    0.205945    0.093698    0.011628    0.676011    
#> 476: 0.306023    1.011800    3.465027    0.206192    0.093666    0.011646    0.676038    
#> 477: 0.305954    1.011766    3.465051    0.206262    0.093633    0.011651    0.675974    
#> 478: 0.305925    1.011766    3.465054    0.206391    0.093608    0.011657    0.675981    
#> 479: 0.305920    1.011783    3.465058    0.206475    0.093541    0.011659    0.675956    
#> 480: 0.305930    1.011774    3.465085    0.206536    0.093481    0.011659    0.675985    
#> 481: 0.305933    1.011765    3.465076    0.206488    0.093479    0.011647    0.675999    
#> 482: 0.306070    1.011789    3.465071    0.206599    0.093516    0.011646    0.676017    
#> 483: 0.306115    1.011759    3.465067    0.206691    0.093552    0.011642    0.675989    
#> 484: 0.306187    1.011645    3.465105    0.206898    0.093566    0.011637    0.676020    
#> 485: 0.306199    1.011684    3.465118    0.206996    0.093537    0.011633    0.676101    
#> 486: 0.306321    1.011645    3.465171    0.207057    0.093501    0.011631    0.676126    
#> 487: 0.306519    1.011624    3.465221    0.207189    0.093484    0.011631    0.676050    
#> 488: 0.306542    1.011635    3.465249    0.207192    0.093507    0.011628    0.676046    
#> 489: 0.306643    1.011626    3.465238    0.207264    0.093529    0.011627    0.676007    
#> 490: 0.306698    1.011645    3.465245    0.207212    0.093501    0.011633    0.676011    
#> 491: 0.306716    1.011742    3.465263    0.207181    0.093470    0.011640    0.676008    
#> 492: 0.306789    1.011830    3.465261    0.207176    0.093492    0.011646    0.676073    
#> 493: 0.306744    1.011891    3.465264    0.207178    0.093476    0.011665    0.676072    
#> 494: 0.306751    1.011947    3.465210    0.207138    0.093439    0.011682    0.676093    
#> 495: 0.306748    1.011994    3.465181    0.207140    0.093407    0.011694    0.676050    
#> 496: 0.306731    1.012122    3.465117    0.207154    0.093337    0.011703    0.676055    
#> 497: 0.306551    1.012168    3.465068    0.207099    0.093354    0.011719    0.676051    
#> 498: 0.306525    1.012156    3.465034    0.207011    0.093312    0.011723    0.676007    
#> 499: 0.306487    1.012188    3.465004    0.207040    0.093324    0.011730    0.675929    
#> 500: 0.306537    1.012181    3.464972    0.207013    0.093270    0.011742    0.675906    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.230564    0.988659    3.443882    0.392401    0.078598    0.016800    1.730971    
#> 002: 0.081458    1.088728    3.502356    0.372781    0.074668    0.018454    1.082825    
#> 003: 0.164113    1.117795    3.546109    0.354142    0.070935    0.019093    0.865505    
#> 004: 0.155073    1.159696    3.555590    0.336435    0.067388    0.018138    0.777352    
#> 005: 0.192940    1.180098    3.539567    0.319613    0.064019    0.018071    0.716143    
#> 006: 0.197504    1.193966    3.542374    0.303633    0.060818    0.019221    0.683048    
#> 007: 0.180866    1.201880    3.533759    0.288451    0.057777    0.020080    0.691649    
#> 008: 0.159559    1.199591    3.534793    0.298505    0.054888    0.021791    0.682896    
#> 009: 0.185572    1.163039    3.546020    0.283580    0.052144    0.023216    0.692777    
#> 010: 0.160490    1.164473    3.544793    0.269401    0.049536    0.022055    0.696536    
#> 011: 0.250360    1.178342    3.549157    0.283497    0.047060    0.020952    0.712633    
#> 012: 0.253453    1.173253    3.540990    0.269322    0.044707    0.019905    0.697959    
#> 013: 0.220247    1.163628    3.547970    0.255856    0.042471    0.018955    0.699027    
#> 014: 0.246893    1.167542    3.560737    0.243063    0.040348    0.018542    0.717670    
#> 015: 0.259799    1.168203    3.571366    0.230910    0.038330    0.019266    0.695450    
#> 016: 0.250939    1.171719    3.579437    0.227370    0.036414    0.025278    0.691030    
#> 017: 0.288791    1.171533    3.586289    0.246468    0.034593    0.028079    0.687502    
#> 018: 0.271240    1.167432    3.566107    0.270049    0.035623    0.026675    0.708051    
#> 019: 0.212808    1.172022    3.552880    0.256547    0.035905    0.026617    0.690945    
#> 020: 0.246100    1.159750    3.576618    0.243719    0.041638    0.026449    0.711195    
#> 021: 0.257660    1.165101    3.574007    0.254312    0.039556    0.025127    0.687639    
#> 022: 0.253584    1.155995    3.582052    0.253241    0.037578    0.025087    0.679007    
#> 023: 0.301182    1.167633    3.583484    0.297915    0.035700    0.023832    0.695480    
#> 024: 0.294853    1.189926    3.585454    0.292189    0.033915    0.022641    0.680556    
#> 025: 0.272457    1.169339    3.571390    0.283843    0.032219    0.023014    0.682043    
#> 026: 0.245970    1.173697    3.556474    0.269651    0.031493    0.025893    0.695532    
#> 027: 0.231357    1.180652    3.565311    0.282810    0.031726    0.025662    0.698130    
#> 028: 0.283017    1.177132    3.578734    0.268670    0.031216    0.025162    0.685165    
#> 029: 0.279957    1.168563    3.554100    0.316095    0.029655    0.023904    0.710577    
#> 030: 0.245250    1.178365    3.558325    0.300290    0.035318    0.022708    0.700233    
#> 031: 0.238266    1.161372    3.584157    0.305855    0.033552    0.021573    0.704835    
#> 032: 0.264991    1.163938    3.588159    0.303373    0.035256    0.021874    0.688420    
#> 033: 0.231080    1.188888    3.556752    0.288205    0.047861    0.020780    0.700391    
#> 034: 0.255020    1.206586    3.560325    0.273794    0.055253    0.019741    0.692881    
#> 035: 0.211157    1.172222    3.548484    0.270739    0.052490    0.018754    0.666244    
#> 036: 0.220940    1.201282    3.549147    0.282545    0.049866    0.018666    0.691863    
#> 037: 0.223416    1.190054    3.563074    0.268417    0.048486    0.017732    0.702743    
#> 038: 0.251331    1.179260    3.549610    0.275612    0.048502    0.016846    0.686567    
#> 039: 0.248247    1.171811    3.560041    0.263807    0.047281    0.016007    0.674724    
#> 040: 0.206859    1.184658    3.548695    0.342584    0.044917    0.015537    0.681697    
#> 041: 0.203974    1.181983    3.543452    0.332395    0.042671    0.014760    0.670403    
#> 042: 0.239864    1.177993    3.550508    0.315775    0.045821    0.014022    0.691092    
#> 043: 0.187087    1.205806    3.527240    0.299987    0.052746    0.013321    0.688832    
#> 044: 0.170336    1.229121    3.523085    0.284987    0.050108    0.013475    0.700747    
#> 045: 0.161150    1.232957    3.517598    0.334806    0.061319    0.012801    0.675543    
#> 046: 0.161450    1.208504    3.523013    0.318066    0.058253    0.012748    0.688444    
#> 047: 0.176455    1.207275    3.519075    0.302162    0.055341    0.012110    0.678864    
#> 048: 0.154157    1.210488    3.516509    0.287054    0.052574    0.012538    0.695185    
#> 049: 0.160535    1.207754    3.529011    0.272702    0.049945    0.012032    0.705730    
#> 050: 0.253723    1.203115    3.534422    0.264232    0.047448    0.013714    0.715932    
#> 051: 0.222851    1.222963    3.534732    0.280365    0.045075    0.017743    0.709433    
#> 052: 0.244583    1.208996    3.553176    0.313236    0.042822    0.022184    0.688207    
#> 053: 0.247346    1.189978    3.546218    0.308179    0.040681    0.028149    0.683399    
#> 054: 0.200722    1.181164    3.549656    0.292770    0.038646    0.029586    0.692776    
#> 055: 0.221046    1.178738    3.554342    0.294727    0.037154    0.028107    0.697045    
#> 056: 0.236226    1.198030    3.555861    0.279991    0.036948    0.026701    0.694728    
#> 057: 0.250933    1.181884    3.572977    0.265991    0.035101    0.030512    0.713970    
#> 058: 0.232943    1.163297    3.565272    0.252691    0.033346    0.028986    0.717259    
#> 059: 0.234060    1.149934    3.571824    0.257194    0.031679    0.027537    0.704771    
#> 060: 0.256874    1.150097    3.581601    0.247866    0.032237    0.027905    0.699889    
#> 061: 0.283878    1.141971    3.593518    0.260644    0.030625    0.029814    0.712906    
#> 062: 0.250204    1.159225    3.572983    0.271127    0.036503    0.029942    0.711911    
#> 063: 0.311132    1.150806    3.573198    0.273342    0.034678    0.030499    0.719067    
#> 064: 0.237891    1.159710    3.578951    0.259675    0.039007    0.028974    0.710240    
#> 065: 0.262155    1.136717    3.566304    0.246691    0.037057    0.030508    0.695806    
#> 066: 0.254275    1.152231    3.575362    0.250196    0.035204    0.028982    0.676725    
#> 067: 0.216969    1.165286    3.568837    0.237687    0.033444    0.033206    0.687833    
#> 068: 0.170604    1.164963    3.557235    0.234061    0.031772    0.031546    0.714290    
#> 069: 0.181886    1.183985    3.546665    0.222358    0.030183    0.029969    0.728853    
#> 070: 0.181983    1.190991    3.553350    0.246334    0.039742    0.028470    0.701372    
#> 071: 0.188843    1.197785    3.525975    0.263612    0.037755    0.027047    0.705886    
#> 072: 0.165615    1.161941    3.536247    0.304795    0.040096    0.025694    0.703291    
#> 073: 0.219055    1.171354    3.554736    0.291283    0.044408    0.024410    0.681108    
#> 074: 0.215632    1.179013    3.556811    0.276719    0.045921    0.023189    0.676357    
#> 075: 0.251212    1.154035    3.598523    0.262883    0.045384    0.022030    0.695737    
#> 076: 0.273965    1.148061    3.590598    0.276622    0.043115    0.020928    0.707323    
#> 077: 0.292559    1.137785    3.583668    0.266203    0.044526    0.020856    0.700393    
#> 078: 0.311258    1.138442    3.594151    0.252893    0.042300    0.022168    0.681970    
#> 079: 0.292438    1.150866    3.592314    0.240248    0.040185    0.028517    0.698687    
#> 080: 0.281917    1.146997    3.577940    0.298613    0.041884    0.027091    0.697814    
#> 081: 0.260178    1.169208    3.560198    0.283682    0.039790    0.025737    0.689922    
#> 082: 0.261948    1.169229    3.568372    0.293501    0.037801    0.024450    0.697661    
#> 083: 0.279133    1.188668    3.566915    0.278826    0.035911    0.023227    0.698750    
#> 084: 0.247851    1.186841    3.564128    0.264885    0.034115    0.025671    0.672434    
#> 085: 0.244866    1.182014    3.564211    0.251641    0.038296    0.024388    0.695008    
#> 086: 0.223054    1.173819    3.558591    0.239059    0.036381    0.023168    0.691250    
#> 087: 0.187446    1.155740    3.553785    0.227106    0.034562    0.022010    0.697546    
#> 088: 0.169992    1.167748    3.553548    0.215750    0.037605    0.020909    0.701427    
#> 089: 0.192409    1.204546    3.532075    0.208799    0.044935    0.019864    0.684953    
#> 090: 0.147676    1.200114    3.539566    0.231131    0.050549    0.018871    0.675133    
#> 091: 0.164403    1.173598    3.534234    0.219574    0.048021    0.019399    0.685339    
#> 092: 0.136745    1.201713    3.521348    0.236437    0.045620    0.018429    0.694351    
#> 093: 0.155019    1.214437    3.522646    0.250156    0.050812    0.017508    0.685701    
#> 094: 0.181593    1.205591    3.534178    0.260860    0.048272    0.016633    0.679196    
#> 095: 0.203279    1.200202    3.542087    0.248956    0.045858    0.022913    0.689944    
#> 096: 0.144227    1.212271    3.533280    0.236508    0.043565    0.021767    0.689947    
#> 097: 0.180894    1.223478    3.526409    0.297542    0.041387    0.020679    0.686141    
#> 098: 0.212698    1.223102    3.546610    0.284719    0.039318    0.021916    0.693931    
#> 099: 0.168304    1.207106    3.523092    0.308143    0.037352    0.020821    0.693829    
#> 100: 0.208901    1.199173    3.540449    0.324860    0.035484    0.023486    0.682159    
#> 101: 0.190300    1.188589    3.524230    0.308617    0.033710    0.022312    0.686422    
#> 102: 0.186222    1.185800    3.524487    0.293186    0.039346    0.021196    0.685297    
#> 103: 0.248736    1.175393    3.546445    0.338281    0.039941    0.023432    0.687804    
#> 104: 0.212948    1.183353    3.560736    0.390620    0.040914    0.024210    0.687020    
#> 105: 0.226832    1.176478    3.546756    0.371089    0.044397    0.022999    0.690932    
#> 106: 0.219796    1.182252    3.545819    0.352535    0.042177    0.021849    0.691408    
#> 107: 0.213513    1.188152    3.546230    0.334908    0.040068    0.020757    0.683901    
#> 108: 0.216418    1.189421    3.542476    0.318163    0.038065    0.019719    0.701806    
#> 109: 0.195921    1.178336    3.551012    0.308183    0.036162    0.020489    0.697710    
#> 110: 0.195939    1.190167    3.528229    0.308534    0.037353    0.019464    0.686413    
#> 111: 0.200085    1.194801    3.536694    0.318464    0.035486    0.018491    0.682880    
#> 112: 0.215620    1.174501    3.536896    0.302540    0.041882    0.020707    0.701252    
#> 113: 0.204727    1.199592    3.542234    0.287413    0.041124    0.023516    0.681420    
#> 114: 0.231428    1.187559    3.560205    0.273043    0.039068    0.022340    0.701345    
#> 115: 0.247648    1.152308    3.553385    0.273694    0.037115    0.025295    0.706410    
#> 116: 0.253379    1.175943    3.569591    0.260010    0.039702    0.025709    0.696950    
#> 117: 0.244991    1.176777    3.569802    0.306697    0.037717    0.025216    0.675478    
#> 118: 0.259634    1.168759    3.571413    0.291362    0.036609    0.025906    0.686341    
#> 119: 0.287549    1.155655    3.584182    0.284589    0.034778    0.027780    0.683233    
#> 120: 0.239470    1.157872    3.566369    0.285771    0.033039    0.029576    0.686022    
#> 121: 0.272803    1.169785    3.558120    0.296391    0.033876    0.028098    0.690957    
#> 122: 0.271925    1.129296    3.588026    0.281571    0.032183    0.031914    0.705933    
#> 123: 0.306931    1.153077    3.587586    0.267493    0.030573    0.031868    0.695653    
#> 124: 0.270903    1.185022    3.569495    0.254118    0.029110    0.033598    0.682822    
#> 125: 0.283416    1.180272    3.568396    0.255899    0.028750    0.031918    0.695617    
#> 126: 0.258811    1.185119    3.566563    0.297635    0.029318    0.032022    0.704329    
#> 127: 0.253602    1.175743    3.553460    0.321262    0.029227    0.031099    0.688696    
#> 128: 0.222930    1.176586    3.563686    0.305199    0.035021    0.029544    0.682800    
#> 129: 0.270167    1.190944    3.568077    0.289939    0.044728    0.029346    0.685567    
#> 130: 0.306119    1.205006    3.569030    0.290752    0.042491    0.027878    0.671470    
#> 131: 0.246190    1.173688    3.557187    0.304426    0.040367    0.026485    0.684649    
#> 132: 0.185075    1.177349    3.538354    0.289205    0.038348    0.025160    0.680802    
#> 133: 0.228342    1.186289    3.553647    0.338905    0.040289    0.023902    0.685998    
#> 134: 0.230920    1.171516    3.555608    0.353455    0.038274    0.022707    0.677606    
#> 135: 0.233153    1.171612    3.557394    0.335782    0.044316    0.021572    0.681020    
#> 136: 0.255244    1.155278    3.553464    0.405441    0.042100    0.024202    0.675490    
#> 137: 0.269849    1.166084    3.554882    0.387843    0.039995    0.027633    0.683958    
#> 138: 0.225075    1.177132    3.551688    0.368451    0.049449    0.026251    0.688971    
#> 139: 0.222460    1.195015    3.541787    0.353700    0.046977    0.024938    0.684905    
#> 140: 0.234801    1.185174    3.562277    0.336015    0.049970    0.027801    0.697251    
#> 141: 0.270235    1.144098    3.582267    0.319214    0.050111    0.028527    0.681770    
#> 142: 0.276776    1.134560    3.591669    0.303254    0.047605    0.027101    0.712102    
#> 143: 0.252463    1.160652    3.585015    0.288091    0.045225    0.028304    0.711891    
#> 144: 0.284063    1.174938    3.589722    0.273686    0.042964    0.026889    0.683615    
#> 145: 0.240238    1.192227    3.556849    0.260002    0.043944    0.025544    0.671867    
#> 146: 0.214870    1.193686    3.559749    0.251341    0.044850    0.024267    0.684189    
#> 147: 0.180469    1.188882    3.540841    0.242128    0.042608    0.023888    0.681291    
#> 148: 0.208888    1.218150    3.558438    0.230914    0.044175    0.022987    0.675746    
#> 149: 0.207254    1.200715    3.555936    0.297421    0.043354    0.021838    0.679454    
#> 150: 0.238052    1.184204    3.548665    0.287675    0.041186    0.022161    0.688717    
#> 151: 0.185048    1.193326    3.543596    0.280690    0.039127    0.021621    0.679076    
#> 152: 0.151139    1.194973    3.542023    0.300728    0.040628    0.025334    0.695437    
#> 153: 0.169299    1.212049    3.539678    0.285032    0.046315    0.021671    0.709527    
#> 154: 0.241606    1.208367    3.552222    0.266249    0.041244    0.023955    0.710534    
#> 155: 0.188232    1.189507    3.539165    0.282323    0.046502    0.015414    0.709922    
#> 156: 0.222959    1.197437    3.546856    0.293867    0.054329    0.016860    0.691404    
#> 157: 0.271459    1.171278    3.558405    0.347132    0.058268    0.020412    0.703400    
#> 158: 0.258655    1.185695    3.556453    0.266119    0.043639    0.022253    0.684843    
#> 159: 0.217414    1.198358    3.563616    0.273060    0.043070    0.020152    0.696799    
#> 160: 0.220500    1.164196    3.567603    0.265870    0.046809    0.014995    0.697155    
#> 161: 0.212877    1.165716    3.552372    0.296415    0.050687    0.016223    0.674599    
#> 162: 0.171551    1.184241    3.531496    0.330757    0.053650    0.015294    0.678725    
#> 163: 0.223128    1.203663    3.529977    0.381604    0.055535    0.017057    0.667670    
#> 164: 0.253094    1.191619    3.540698    0.396494    0.049153    0.018209    0.674559    
#> 165: 0.251494    1.179882    3.547611    0.352781    0.043459    0.017110    0.683332    
#> 166: 0.280569    1.200787    3.554778    0.501232    0.046233    0.018431    0.673657    
#> 167: 0.266673    1.209694    3.561105    0.403241    0.038453    0.017162    0.693936    
#> 168: 0.265162    1.221011    3.551181    0.423306    0.042807    0.014991    0.680039    
#> 169: 0.287497    1.217219    3.544922    0.410774    0.038916    0.016305    0.685697    
#> 170: 0.266492    1.185231    3.553650    0.399090    0.036061    0.018749    0.692182    
#> 171: 0.186809    1.219980    3.532207    0.366287    0.036005    0.015655    0.681400    
#> 172: 0.179785    1.228970    3.532296    0.268284    0.042418    0.016330    0.682752    
#> 173: 0.185341    1.225306    3.524358    0.294719    0.035479    0.022708    0.694234    
#> 174: 0.214077    1.223567    3.529964    0.371251    0.039451    0.023017    0.687469    
#> 175: 0.218679    1.219163    3.530469    0.294695    0.042477    0.025103    0.686774    
#> 176: 0.223671    1.208131    3.554886    0.312232    0.031757    0.021650    0.687595    
#> 177: 0.233115    1.203946    3.552881    0.312774    0.035016    0.025315    0.677138    
#> 178: 0.252718    1.181019    3.554405    0.278076    0.035228    0.020683    0.670129    
#> 179: 0.276865    1.189599    3.552739    0.329563    0.034421    0.017160    0.696458    
#> 180: 0.246159    1.176444    3.558508    0.374772    0.041734    0.018260    0.679832    
#> 181: 0.216950    1.161292    3.541082    0.298626    0.043528    0.017778    0.686396    
#> 182: 0.173455    1.176326    3.529009    0.290420    0.035753    0.021445    0.700234    
#> 183: 0.210115    1.201467    3.541817    0.275204    0.034623    0.022696    0.704197    
#> 184: 0.228455    1.163891    3.554280    0.299997    0.032628    0.026555    0.695096    
#> 185: 0.217150    1.175022    3.553361    0.248964    0.026601    0.029063    0.703398    
#> 186: 0.226406    1.202656    3.562679    0.264474    0.032685    0.028843    0.698920    
#> 187: 0.245494    1.178055    3.560931    0.324571    0.034047    0.019874    0.690206    
#> 188: 0.229194    1.197288    3.563763    0.298453    0.042708    0.020417    0.696183    
#> 189: 0.245266    1.204948    3.563138    0.245752    0.045570    0.017819    0.693086    
#> 190: 0.222997    1.202846    3.565387    0.246258    0.045383    0.020129    0.671687    
#> 191: 0.207466    1.202318    3.549459    0.228839    0.041362    0.019247    0.676425    
#> 192: 0.185557    1.200964    3.542897    0.232235    0.040967    0.016429    0.686533    
#> 193: 0.219296    1.215990    3.542171    0.264260    0.030411    0.017872    0.678546    
#> 194: 0.170928    1.191681    3.530880    0.309828    0.037957    0.018513    0.683664    
#> 195: 0.138368    1.196788    3.523346    0.289572    0.043748    0.016566    0.696126    
#> 196: 0.166910    1.190928    3.534916    0.297434    0.046245    0.019526    0.709072    
#> 197: 0.177642    1.210580    3.552189    0.285702    0.050998    0.021771    0.700651    
#> 198: 0.207023    1.197644    3.541535    0.246267    0.040758    0.018995    0.678678    
#> 199: 0.191457    1.202021    3.539761    0.275707    0.044063    0.019320    0.665837    
#> 200: 0.202659    1.197304    3.535465    0.306188    0.040063    0.015560    0.674774    
#> 201: 0.196929    1.186075    3.542626    0.313686    0.039374    0.017352    0.671651    
#> 202: 0.205661    1.189887    3.544010    0.314639    0.040266    0.017906    0.675866    
#> 203: 0.217886    1.190054    3.543923    0.293967    0.039658    0.017917    0.683066    
#> 204: 0.218597    1.185470    3.545633    0.286502    0.041595    0.018280    0.683747    
#> 205: 0.211787    1.188142    3.545513    0.279953    0.041979    0.018395    0.683777    
#> 206: 0.211382    1.191573    3.545047    0.286275    0.042687    0.017967    0.685616    
#> 207: 0.208421    1.192477    3.542841    0.284018    0.041900    0.017716    0.686504    
#> 208: 0.205645    1.191648    3.542769    0.286163    0.041674    0.017328    0.687011    
#> 209: 0.207091    1.189653    3.542598    0.285994    0.042536    0.016844    0.687339    
#> 210: 0.210533    1.188306    3.543991    0.284982    0.042797    0.016929    0.686012    
#> 211: 0.212411    1.188965    3.545418    0.281075    0.042731    0.016956    0.685103    
#> 212: 0.217043    1.188629    3.546772    0.278650    0.043024    0.017136    0.684850    
#> 213: 0.218881    1.185763    3.547504    0.275957    0.043073    0.017429    0.686116    
#> 214: 0.221565    1.184303    3.548588    0.275593    0.042753    0.017612    0.687113    
#> 215: 0.222047    1.183755    3.549458    0.275079    0.043004    0.017730    0.687600    
#> 216: 0.223558    1.182859    3.549415    0.275567    0.043513    0.017749    0.688927    
#> 217: 0.224721    1.183414    3.549738    0.274941    0.044063    0.017969    0.688201    
#> 218: 0.224924    1.184168    3.549216    0.273584    0.043990    0.018002    0.688397    
#> 219: 0.224502    1.184209    3.548215    0.275617    0.044257    0.017825    0.688421    
#> 220: 0.222611    1.184380    3.548073    0.273949    0.044183    0.017537    0.689640    
#> 221: 0.222718    1.183836    3.547787    0.277965    0.044552    0.017460    0.689340    
#> 222: 0.222651    1.183178    3.547225    0.280324    0.045061    0.017321    0.689561    
#> 223: 0.224522    1.182895    3.547532    0.281112    0.045415    0.017255    0.689281    
#> 224: 0.226234    1.183122    3.548108    0.282391    0.045416    0.017277    0.689110    
#> 225: 0.226715    1.181625    3.548644    0.284784    0.045470    0.017325    0.689338    
#> 226: 0.226525    1.180851    3.548277    0.286963    0.045512    0.017297    0.689289    
#> 227: 0.226338    1.180918    3.548938    0.287699    0.045095    0.017378    0.688909    
#> 228: 0.227360    1.181580    3.548799    0.290078    0.044921    0.017557    0.688890    
#> 229: 0.227382    1.181621    3.548619    0.290595    0.044709    0.017609    0.688787    
#> 230: 0.227429    1.181456    3.548584    0.290742    0.044635    0.017590    0.688468    
#> 231: 0.226886    1.182257    3.548483    0.291585    0.044833    0.017618    0.688340    
#> 232: 0.225608    1.182680    3.548446    0.291931    0.044871    0.017708    0.688107    
#> 233: 0.225148    1.182330    3.548360    0.291400    0.044811    0.017693    0.688662    
#> 234: 0.223433    1.182635    3.548273    0.291431    0.044744    0.017802    0.688527    
#> 235: 0.223380    1.182547    3.548013    0.290846    0.044773    0.017797    0.688182    
#> 236: 0.222782    1.182850    3.547712    0.288725    0.044798    0.017703    0.688247    
#> 237: 0.223325    1.182772    3.547803    0.288768    0.044756    0.017735    0.688817    
#> 238: 0.222300    1.182951    3.547437    0.290158    0.044769    0.017706    0.689091    
#> 239: 0.221162    1.183608    3.546859    0.290887    0.044761    0.017644    0.689376    
#> 240: 0.220351    1.183685    3.546597    0.290021    0.044749    0.017580    0.689737    
#> 241: 0.219940    1.183517    3.546696    0.289748    0.044600    0.017556    0.689886    
#> 242: 0.219362    1.183492    3.546244    0.289296    0.044654    0.017572    0.690329    
#> 243: 0.218506    1.183881    3.546220    0.287925    0.044591    0.017680    0.690880    
#> 244: 0.217923    1.183719    3.546282    0.288456    0.044576    0.017793    0.691047    
#> 245: 0.218434    1.183452    3.546456    0.288490    0.044568    0.017871    0.691320    
#> 246: 0.218746    1.183497    3.546789    0.288356    0.044659    0.017946    0.691574    
#> 247: 0.219014    1.183453    3.547201    0.287113    0.044520    0.017951    0.691977    
#> 248: 0.219295    1.183543    3.547452    0.286217    0.044535    0.017908    0.691493    
#> 249: 0.219273    1.183516    3.547555    0.286053    0.044725    0.017951    0.691349    
#> 250: 0.219359    1.183458    3.547874    0.285145    0.044647    0.018062    0.691076    
#> 251: 0.220230    1.183701    3.548379    0.285371    0.044567    0.018048    0.690976    
#> 252: 0.221058    1.183834    3.548941    0.285237    0.044613    0.018064    0.690821    
#> 253: 0.221365    1.183969    3.549231    0.285165    0.044645    0.018073    0.690731    
#> 254: 0.221553    1.184409    3.549394    0.285356    0.044601    0.018069    0.690816    
#> 255: 0.221078    1.184594    3.549463    0.284448    0.044553    0.018183    0.690813    
#> 256: 0.221819    1.184499    3.549549    0.284102    0.044502    0.018235    0.690934    
#> 257: 0.222188    1.183907    3.549670    0.284692    0.044378    0.018288    0.690874    
#> 258: 0.222225    1.183534    3.549709    0.284161    0.044298    0.018361    0.690700    
#> 259: 0.221978    1.183276    3.549586    0.283657    0.044252    0.018441    0.690678    
#> 260: 0.221936    1.183346    3.549594    0.284725    0.044376    0.018420    0.690708    
#> 261: 0.221967    1.183377    3.549698    0.287024    0.044324    0.018423    0.690799    
#> 262: 0.222299    1.183342    3.549720    0.287172    0.044470    0.018459    0.690510    
#> 263: 0.221896    1.183450    3.549827    0.287214    0.044547    0.018480    0.690718    
#> 264: 0.221828    1.183458    3.549792    0.287792    0.044821    0.018481    0.690986    
#> 265: 0.221827    1.183582    3.549808    0.288205    0.045040    0.018482    0.691136    
#> 266: 0.221631    1.184079    3.549614    0.287883    0.045228    0.018501    0.691017    
#> 267: 0.221204    1.184185    3.549605    0.287417    0.045335    0.018531    0.691064    
#> 268: 0.220973    1.184203    3.549375    0.287207    0.045369    0.018517    0.691322    
#> 269: 0.221244    1.184305    3.549207    0.287617    0.045257    0.018541    0.691259    
#> 270: 0.221194    1.184488    3.548873    0.288133    0.045241    0.018501    0.691322    
#> 271: 0.220954    1.184639    3.548664    0.288722    0.045318    0.018514    0.691294    
#> 272: 0.221252    1.184398    3.548776    0.289377    0.045373    0.018536    0.691532    
#> 273: 0.221337    1.184732    3.548817    0.289487    0.045318    0.018541    0.691500    
#> 274: 0.221593    1.184965    3.548878    0.290095    0.045242    0.018540    0.691184    
#> 275: 0.221919    1.184976    3.548982    0.290168    0.045113    0.018530    0.691176    
#> 276: 0.222097    1.184748    3.549332    0.290223    0.045092    0.018526    0.691366    
#> 277: 0.222389    1.184828    3.549514    0.290028    0.045127    0.018510    0.691068    
#> 278: 0.222220    1.184756    3.549493    0.289724    0.045258    0.018452    0.690924    
#> 279: 0.222001    1.184696    3.549456    0.289515    0.045463    0.018442    0.690805    
#> 280: 0.221781    1.184908    3.549430    0.289151    0.045506    0.018387    0.690754    
#> 281: 0.221618    1.184960    3.549426    0.288392    0.045478    0.018429    0.690678    
#> 282: 0.221710    1.185073    3.549530    0.287240    0.045373    0.018430    0.690832    
#> 283: 0.221704    1.185245    3.549655    0.286719    0.045375    0.018435    0.691306    
#> 284: 0.221415    1.185286    3.549588    0.286339    0.045304    0.018420    0.691295    
#> 285: 0.221205    1.185543    3.549238    0.286620    0.045259    0.018447    0.691256    
#> 286: 0.220995    1.185863    3.549039    0.286488    0.045323    0.018451    0.691290    
#> 287: 0.220714    1.186132    3.548887    0.286132    0.045371    0.018450    0.691297    
#> 288: 0.220694    1.186194    3.548727    0.286552    0.045319    0.018444    0.691428    
#> 289: 0.220721    1.186482    3.548541    0.286950    0.045278    0.018406    0.691356    
#> 290: 0.220597    1.186580    3.548506    0.287365    0.045188    0.018379    0.691435    
#> 291: 0.221189    1.186774    3.548806    0.287384    0.045232    0.018458    0.691351    
#> 292: 0.221347    1.186665    3.548820    0.287555    0.045176    0.018485    0.691253    
#> 293: 0.221456    1.186658    3.548769    0.287039    0.045144    0.018504    0.691116    
#> 294: 0.221506    1.186705    3.548796    0.286175    0.045103    0.018543    0.691257    
#> 295: 0.221516    1.186352    3.548820    0.286146    0.045032    0.018578    0.691184    
#> 296: 0.221628    1.186038    3.548993    0.286465    0.044993    0.018672    0.691263    
#> 297: 0.221640    1.186050    3.548879    0.286289    0.044994    0.018736    0.691281    
#> 298: 0.221699    1.186039    3.548825    0.286706    0.044970    0.018735    0.691275    
#> 299: 0.221614    1.186009    3.548758    0.286893    0.044861    0.018718    0.691298    
#> 300: 0.221678    1.186012    3.548839    0.287065    0.044901    0.018732    0.691259    
#> 301: 0.221364    1.185938    3.548721    0.287334    0.045000    0.018732    0.691437    
#> 302: 0.221256    1.186096    3.548694    0.287359    0.045005    0.018708    0.691451    
#> 303: 0.221119    1.186325    3.548608    0.286998    0.045074    0.018713    0.691389    
#> 304: 0.220997    1.186603    3.548443    0.286925    0.045117    0.018749    0.691291    
#> 305: 0.220662    1.186678    3.548297    0.286605    0.045083    0.018790    0.691295    
#> 306: 0.220037    1.186697    3.548076    0.286184    0.045037    0.018848    0.691235    
#> 307: 0.219740    1.186707    3.547916    0.285943    0.045099    0.018854    0.691234    
#> 308: 0.219237    1.186667    3.547774    0.285811    0.045232    0.018811    0.691392    
#> 309: 0.218878    1.186532    3.547706    0.285978    0.045223    0.018788    0.691601    
#> 310: 0.218833    1.186596    3.547558    0.286942    0.045201    0.018779    0.691756    
#> 311: 0.218836    1.186882    3.547487    0.286893    0.045162    0.018784    0.691861    
#> 312: 0.218641    1.186988    3.547416    0.287152    0.045109    0.018835    0.691822    
#> 313: 0.218696    1.186854    3.547384    0.287240    0.045132    0.018840    0.691804    
#> 314: 0.218448    1.186797    3.547364    0.287123    0.045134    0.018869    0.691740    
#> 315: 0.218244    1.186846    3.547394    0.287223    0.045075    0.018892    0.691655    
#> 316: 0.218460    1.186892    3.547476    0.286920    0.044998    0.018913    0.691650    
#> 317: 0.218687    1.186807    3.547711    0.287029    0.044972    0.018948    0.691777    
#> 318: 0.219071    1.186587    3.547761    0.287608    0.044939    0.018945    0.691763    
#> 319: 0.219223    1.186443    3.547784    0.287918    0.044931    0.018955    0.691828    
#> 320: 0.219033    1.186398    3.547657    0.288230    0.044931    0.018952    0.691885    
#> 321: 0.218646    1.186466    3.547460    0.288366    0.044967    0.018922    0.691828    
#> 322: 0.218510    1.186620    3.547254    0.288643    0.044907    0.018928    0.691780    
#> 323: 0.217951    1.186696    3.547100    0.288904    0.044849    0.018894    0.691789    
#> 324: 0.217735    1.186764    3.547015    0.289086    0.044873    0.018888    0.691653    
#> 325: 0.217404    1.186949    3.546901    0.288968    0.044903    0.018910    0.691579    
#> 326: 0.217172    1.186933    3.546779    0.288774    0.044872    0.018934    0.691558    
#> 327: 0.217009    1.187145    3.546705    0.288674    0.044972    0.018902    0.691552    
#> 328: 0.216767    1.187316    3.546527    0.288375    0.044980    0.018882    0.691573    
#> 329: 0.217007    1.187365    3.546625    0.288288    0.044894    0.018890    0.691477    
#> 330: 0.217020    1.187455    3.546750    0.287973    0.044824    0.018933    0.691434    
#> 331: 0.217118    1.187596    3.546840    0.287554    0.044813    0.018958    0.691397    
#> 332: 0.217209    1.187476    3.546939    0.287211    0.044762    0.018989    0.691571    
#> 333: 0.217267    1.187490    3.546906    0.287242    0.044751    0.019037    0.691654    
#> 334: 0.217031    1.187389    3.546752    0.287496    0.044772    0.019055    0.691701    
#> 335: 0.216461    1.187521    3.546585    0.287549    0.044782    0.019050    0.691709    
#> 336: 0.215982    1.187666    3.546453    0.287530    0.044793    0.019023    0.691810    
#> 337: 0.215707    1.187925    3.546318    0.287443    0.044764    0.019039    0.691977    
#> 338: 0.215619    1.187895    3.546325    0.287321    0.044662    0.019034    0.692142    
#> 339: 0.215233    1.187896    3.546241    0.287729    0.044697    0.019038    0.692135    
#> 340: 0.215171    1.187766    3.546267    0.288002    0.044722    0.019071    0.692135    
#> 341: 0.215532    1.187879    3.546348    0.288134    0.044747    0.019100    0.692096    
#> 342: 0.215427    1.187850    3.546373    0.287914    0.044754    0.019106    0.692061    
#> 343: 0.215188    1.187913    3.546386    0.287570    0.044792    0.019108    0.691958    
#> 344: 0.215160    1.187782    3.546402    0.287256    0.044764    0.019106    0.691926    
#> 345: 0.215155    1.187783    3.546439    0.287285    0.044722    0.019111    0.691948    
#> 346: 0.215022    1.187973    3.546301    0.287192    0.044720    0.019122    0.691890    
#> 347: 0.214916    1.187981    3.546101    0.287529    0.044643    0.019142    0.691945    
#> 348: 0.214651    1.188162    3.545895    0.288079    0.044703    0.019171    0.691842    
#> 349: 0.214475    1.188167    3.545755    0.288241    0.044737    0.019174    0.691754    
#> 350: 0.214267    1.188092    3.545687    0.288823    0.044715    0.019187    0.691747    
#> 351: 0.214172    1.188227    3.545626    0.288535    0.044697    0.019185    0.691815    
#> 352: 0.213925    1.188327    3.545627    0.288178    0.044664    0.019224    0.691977    
#> 353: 0.213935    1.188435    3.545618    0.287821    0.044596    0.019295    0.692077    
#> 354: 0.213820    1.188500    3.545478    0.287436    0.044517    0.019328    0.692135    
#> 355: 0.213917    1.188419    3.545413    0.287416    0.044478    0.019355    0.692047    
#> 356: 0.213788    1.188462    3.545395    0.287163    0.044451    0.019386    0.692234    
#> 357: 0.213848    1.188573    3.545369    0.287470    0.044396    0.019386    0.692202    
#> 358: 0.213868    1.188622    3.545435    0.287549    0.044462    0.019385    0.692097    
#> 359: 0.213783    1.188628    3.545492    0.287628    0.044428    0.019396    0.692073    
#> 360: 0.213694    1.188651    3.545420    0.287426    0.044379    0.019367    0.692036    
#> 361: 0.213471    1.188652    3.545364    0.287122    0.044316    0.019377    0.691975    
#> 362: 0.213721    1.188545    3.545347    0.287095    0.044304    0.019372    0.691942    
#> 363: 0.213709    1.188409    3.545373    0.286575    0.044295    0.019376    0.691892    
#> 364: 0.213890    1.188365    3.545437    0.286334    0.044304    0.019386    0.691942    
#> 365: 0.214018    1.188195    3.545582    0.286176    0.044254    0.019408    0.692030    
#> 366: 0.214181    1.188093    3.545598    0.286241    0.044198    0.019417    0.692063    
#> 367: 0.214345    1.188072    3.545621    0.286849    0.044153    0.019423    0.692003    
#> 368: 0.214475    1.188149    3.545594    0.287083    0.044104    0.019443    0.691898    
#> 369: 0.214411    1.188236    3.545517    0.287108    0.044086    0.019451    0.691773    
#> 370: 0.214199    1.188365    3.545392    0.287012    0.044113    0.019448    0.691805    
#> 371: 0.213891    1.188442    3.545256    0.287052    0.044136    0.019453    0.691791    
#> 372: 0.213885    1.188579    3.545176    0.287245    0.044112    0.019466    0.691820    
#> 373: 0.213628    1.188796    3.545004    0.287402    0.044066    0.019484    0.691837    
#> 374: 0.213506    1.188850    3.544926    0.287737    0.044016    0.019497    0.691758    
#> 375: 0.213397    1.188843    3.544928    0.287921    0.044053    0.019496    0.691755    
#> 376: 0.213320    1.188929    3.544922    0.288136    0.044044    0.019504    0.691634    
#> 377: 0.213355    1.188952    3.545027    0.287837    0.043970    0.019538    0.691680    
#> 378: 0.213298    1.188943    3.544986    0.287670    0.043881    0.019553    0.691713    
#> 379: 0.213277    1.188797    3.545008    0.287607    0.043801    0.019586    0.691708    
#> 380: 0.213213    1.188683    3.545059    0.287585    0.043744    0.019623    0.691652    
#> 381: 0.213070    1.188635    3.545028    0.287564    0.043753    0.019637    0.691648    
#> 382: 0.213063    1.188561    3.544990    0.287758    0.043716    0.019619    0.691552    
#> 383: 0.213188    1.188502    3.545018    0.287695    0.043693    0.019622    0.691468    
#> 384: 0.212999    1.188425    3.545013    0.287791    0.043702    0.019623    0.691484    
#> 385: 0.212887    1.188314    3.545089    0.287611    0.043661    0.019651    0.691575    
#> 386: 0.213138    1.188255    3.545180    0.287543    0.043608    0.019698    0.691597    
#> 387: 0.213397    1.188193    3.545337    0.287355    0.043573    0.019739    0.691631    
#> 388: 0.213523    1.188139    3.545482    0.287058    0.043536    0.019778    0.691545    
#> 389: 0.213541    1.187886    3.545531    0.287049    0.043541    0.019805    0.691544    
#> 390: 0.213430    1.187891    3.545474    0.287109    0.043514    0.019812    0.691587    
#> 391: 0.213442    1.187882    3.545434    0.287197    0.043545    0.019804    0.691553    
#> 392: 0.213565    1.187918    3.545515    0.287367    0.043546    0.019822    0.691552    
#> 393: 0.213392    1.187893    3.545425    0.287358    0.043556    0.019835    0.691489    
#> 394: 0.213353    1.187911    3.545362    0.287609    0.043528    0.019829    0.691511    
#> 395: 0.213435    1.187965    3.545355    0.287425    0.043512    0.019831    0.691511    
#> 396: 0.213577    1.187885    3.545414    0.287227    0.043518    0.019842    0.691510    
#> 397: 0.213553    1.187817    3.545466    0.286911    0.043528    0.019834    0.691584    
#> 398: 0.213656    1.187777    3.545521    0.286634    0.043504    0.019821    0.691668    
#> 399: 0.213812    1.187830    3.545592    0.286621    0.043486    0.019799    0.691702    
#> 400: 0.213931    1.187924    3.545624    0.286489    0.043484    0.019806    0.691695    
#> 401: 0.213942    1.187983    3.545666    0.286621    0.043469    0.019823    0.691746    
#> 402: 0.213865    1.188049    3.545702    0.286269    0.043381    0.019860    0.691824    
#> 403: 0.214082    1.188014    3.545751    0.286346    0.043334    0.019875    0.691858    
#> 404: 0.214338    1.188055    3.545731    0.286533    0.043298    0.019903    0.691844    
#> 405: 0.214450    1.188029    3.545748    0.286665    0.043274    0.019913    0.691888    
#> 406: 0.214496    1.188004    3.545745    0.286550    0.043278    0.019914    0.692016    
#> 407: 0.214571    1.188038    3.545804    0.286503    0.043313    0.019913    0.691996    
#> 408: 0.214881    1.188074    3.545964    0.286262    0.043385    0.019931    0.692085    
#> 409: 0.214936    1.188048    3.545980    0.286037    0.043434    0.019954    0.692067    
#> 410: 0.214932    1.188043    3.545894    0.285963    0.043470    0.019935    0.692148    
#> 411: 0.214982    1.187817    3.545936    0.285691    0.043454    0.019936    0.692188    
#> 412: 0.215145    1.187840    3.545924    0.285674    0.043467    0.019922    0.692156    
#> 413: 0.215230    1.187827    3.545926    0.286102    0.043473    0.019905    0.692225    
#> 414: 0.215221    1.187881    3.545949    0.286240    0.043456    0.019880    0.692197    
#> 415: 0.215423    1.187863    3.545920    0.286597    0.043411    0.019868    0.692159    
#> 416: 0.215505    1.187899    3.545942    0.286826    0.043421    0.019863    0.692111    
#> 417: 0.215614    1.187851    3.545979    0.286922    0.043388    0.019853    0.692031    
#> 418: 0.215381    1.187886    3.545998    0.286800    0.043356    0.019843    0.691977    
#> 419: 0.215426    1.188030    3.546011    0.286985    0.043385    0.019849    0.691855    
#> 420: 0.215409    1.188108    3.546015    0.287039    0.043369    0.019841    0.691749    
#> 421: 0.215532    1.188069    3.546138    0.287039    0.043326    0.019849    0.691648    
#> 422: 0.215909    1.187916    3.546275    0.286723    0.043258    0.019867    0.691626    
#> 423: 0.216231    1.187735    3.546396    0.286520    0.043224    0.019881    0.691611    
#> 424: 0.216450    1.187643    3.546450    0.286389    0.043153    0.019902    0.691572    
#> 425: 0.216715    1.187560    3.546563    0.286325    0.043080    0.019941    0.691549    
#> 426: 0.216797    1.187583    3.546630    0.286244    0.043093    0.019946    0.691507    
#> 427: 0.216743    1.187580    3.546651    0.286165    0.043113    0.019942    0.691506    
#> 428: 0.216789    1.187573    3.546695    0.286119    0.043089    0.019937    0.691547    
#> 429: 0.216775    1.187537    3.546698    0.286274    0.043056    0.019939    0.691556    
#> 430: 0.216696    1.187609    3.546662    0.286436    0.043021    0.019932    0.691554    
#> 431: 0.216648    1.187659    3.546603    0.286335    0.043003    0.019908    0.691507    
#> 432: 0.216570    1.187728    3.546610    0.286183    0.042990    0.019900    0.691478    
#> 433: 0.216494    1.187869    3.546586    0.286261    0.042974    0.019883    0.691497    
#> 434: 0.216418    1.187767    3.546631    0.286080    0.042955    0.019881    0.691457    
#> 435: 0.216479    1.187727    3.546656    0.285961    0.042940    0.019884    0.691348    
#> 436: 0.216511    1.187701    3.546701    0.285724    0.042955    0.019874    0.691349    
#> 437: 0.216506    1.187737    3.546728    0.285614    0.042958    0.019859    0.691316    
#> 438: 0.216493    1.187898    3.546741    0.285605    0.042975    0.019851    0.691244    
#> 439: 0.216528    1.187991    3.546719    0.285652    0.042980    0.019840    0.691159    
#> 440: 0.216471    1.188029    3.546771    0.285549    0.042961    0.019845    0.691140    
#> 441: 0.216513    1.187990    3.546810    0.285299    0.042923    0.019852    0.691119    
#> 442: 0.216412    1.187999    3.546825    0.285133    0.042905    0.019847    0.691067    
#> 443: 0.216412    1.188067    3.546778    0.285206    0.042898    0.019852    0.691020    
#> 444: 0.216376    1.188090    3.546714    0.285346    0.042860    0.019873    0.690972    
#> 445: 0.216184    1.188120    3.546610    0.285330    0.042826    0.019894    0.691032    
#> 446: 0.215837    1.188232    3.546512    0.285249    0.042814    0.019892    0.691090    
#> 447: 0.215843    1.188340    3.546460    0.285238    0.042844    0.019898    0.691081    
#> 448: 0.215810    1.188361    3.546465    0.285179    0.042840    0.019908    0.691075    
#> 449: 0.215887    1.188450    3.546561    0.285360    0.042839    0.019922    0.691097    
#> 450: 0.215785    1.188538    3.546532    0.285544    0.042841    0.019946    0.691072    
#> 451: 0.215905    1.188555    3.546572    0.285532    0.042815    0.019962    0.691091    
#> 452: 0.215927    1.188655    3.546556    0.285563    0.042790    0.019975    0.691060    
#> 453: 0.215945    1.188698    3.546537    0.285661    0.042754    0.020005    0.691018    
#> 454: 0.215879    1.188746    3.546543    0.285536    0.042732    0.020033    0.690999    
#> 455: 0.215923    1.188789    3.546545    0.285353    0.042701    0.020050    0.691027    
#> 456: 0.215789    1.188766    3.546534    0.285126    0.042664    0.020055    0.691020    
#> 457: 0.215705    1.188839    3.546535    0.285047    0.042640    0.020064    0.690935    
#> 458: 0.215684    1.189008    3.546535    0.285032    0.042660    0.020056    0.690853    
#> 459: 0.215476    1.189140    3.546525    0.285172    0.042674    0.020046    0.690825    
#> 460: 0.215312    1.189216    3.546444    0.285211    0.042649    0.020036    0.690822    
#> 461: 0.215190    1.189344    3.546380    0.285250    0.042615    0.020029    0.690865    
#> 462: 0.214944    1.189473    3.546338    0.285452    0.042641    0.020015    0.690833    
#> 463: 0.214787    1.189571    3.546269    0.285669    0.042688    0.020010    0.690783    
#> 464: 0.214714    1.189672    3.546194    0.285777    0.042712    0.020012    0.690729    
#> 465: 0.214697    1.189577    3.546180    0.285854    0.042691    0.020005    0.690655    
#> 466: 0.214737    1.189589    3.546147    0.285874    0.042654    0.020000    0.690656    
#> 467: 0.214577    1.189590    3.546142    0.285794    0.042603    0.020003    0.690595    
#> 468: 0.214708    1.189562    3.546195    0.285829    0.042574    0.020007    0.690597    
#> 469: 0.214833    1.189666    3.546234    0.285752    0.042557    0.020021    0.690665    
#> 470: 0.214788    1.189692    3.546246    0.285634    0.042539    0.020028    0.690699    
#> 471: 0.214681    1.189670    3.546207    0.285344    0.042504    0.020031    0.690759    
#> 472: 0.214614    1.189682    3.546218    0.285118    0.042506    0.020029    0.690847    
#> 473: 0.214385    1.189701    3.546171    0.285249    0.042468    0.020011    0.690867    
#> 474: 0.214359    1.189674    3.546153    0.285296    0.042470    0.020010    0.690915    
#> 475: 0.214344    1.189805    3.546131    0.285192    0.042475    0.019997    0.690913    
#> 476: 0.214351    1.189756    3.546138    0.285007    0.042479    0.019983    0.690921    
#> 477: 0.214299    1.189682    3.546192    0.284787    0.042507    0.019981    0.690817    
#> 478: 0.214213    1.189653    3.546187    0.284694    0.042515    0.019984    0.690820    
#> 479: 0.214175    1.189683    3.546198    0.284630    0.042522    0.019974    0.690869    
#> 480: 0.214135    1.189695    3.546204    0.284462    0.042574    0.019959    0.690860    
#> 481: 0.214152    1.189743    3.546206    0.284369    0.042588    0.019933    0.690878    
#> 482: 0.214264    1.189813    3.546177    0.284330    0.042604    0.019939    0.690869    
#> 483: 0.214194    1.189867    3.546163    0.284213    0.042624    0.019938    0.690820    
#> 484: 0.214114    1.189816    3.546154    0.284180    0.042621    0.019943    0.690787    
#> 485: 0.214093    1.189888    3.546154    0.284030    0.042596    0.019962    0.690769    
#> 486: 0.214073    1.189970    3.546140    0.284081    0.042565    0.019953    0.690739    
#> 487: 0.214155    1.190034    3.546192    0.284024    0.042565    0.019945    0.690751    
#> 488: 0.214185    1.190026    3.546206    0.283972    0.042565    0.019935    0.690770    
#> 489: 0.214271    1.189944    3.546229    0.283952    0.042578    0.019936    0.690814    
#> 490: 0.214364    1.189919    3.546274    0.284009    0.042569    0.019938    0.690770    
#> 491: 0.214415    1.189943    3.546347    0.283960    0.042552    0.019959    0.690727    
#> 492: 0.214501    1.189967    3.546368    0.283925    0.042558    0.019972    0.690721    
#> 493: 0.214578    1.189972    3.546436    0.283930    0.042552    0.019990    0.690687    
#> 494: 0.214777    1.189984    3.546452    0.283837    0.042545    0.020003    0.690658    
#> 495: 0.214949    1.189986    3.546505    0.283753    0.042516    0.020001    0.690634    
#> 496: 0.214976    1.189989    3.546478    0.283733    0.042519    0.019996    0.690679    
#> 497: 0.214924    1.189929    3.546473    0.283830    0.042479    0.020012    0.690707    
#> 498: 0.214950    1.189906    3.546468    0.283781    0.042494    0.020024    0.690655    
#> 499: 0.214978    1.189968    3.546462    0.283690    0.042484    0.020027    0.690627    
#> 500: 0.214992    1.189938    3.546450    0.283597    0.042500    0.020014    0.690558    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.267440    0.952642    3.449680    0.392401    0.074825    0.016800    1.477972    
#> 002: 0.313945    0.970744    3.469198    0.372781    0.071084    0.015960    1.057472    
#> 003: 0.443274    0.881495    3.487480    0.354142    0.067530    0.015162    0.858347    
#> 004: 0.365035    0.883318    3.474488    0.336435    0.064182    0.014404    0.824295    
#> 005: 0.410550    0.890999    3.456905    0.319613    0.060973    0.013684    0.780279    
#> 006: 0.362335    0.907964    3.444056    0.303633    0.057924    0.013000    0.751623    
#> 007: 0.330321    0.915744    3.434146    0.288451    0.055028    0.014435    0.755494    
#> 008: 0.283629    0.921454    3.416866    0.274029    0.052276    0.014702    0.743032    
#> 009: 0.254312    0.912181    3.409844    0.260327    0.049663    0.017085    0.738959    
#> 010: 0.265188    0.926830    3.411115    0.247311    0.047179    0.016231    0.740432    
#> 011: 0.283505    0.944344    3.412340    0.234945    0.044820    0.015419    0.750058    
#> 012: 0.282455    0.941808    3.403525    0.223198    0.042579    0.014648    0.722928    
#> 013: 0.242269    0.949234    3.391096    0.212038    0.047347    0.013916    0.722705    
#> 014: 0.264484    0.962543    3.392831    0.201436    0.044980    0.013220    0.752904    
#> 015: 0.250929    0.959772    3.402303    0.191364    0.042731    0.012559    0.744918    
#> 016: 0.265491    0.960932    3.410532    0.181796    0.040594    0.011931    0.769779    
#> 017: 0.290065    0.938893    3.421720    0.172706    0.038564    0.012020    0.749696    
#> 018: 0.315056    0.933707    3.413485    0.192084    0.036636    0.011419    0.751357    
#> 019: 0.274810    0.931326    3.413937    0.186900    0.041297    0.011690    0.720669    
#> 020: 0.288944    0.928903    3.411450    0.221894    0.052540    0.011105    0.729251    
#> 021: 0.294583    0.919792    3.420437    0.210799    0.051475    0.010550    0.728165    
#> 022: 0.259408    0.926734    3.421211    0.200259    0.054778    0.010023    0.713551    
#> 023: 0.332456    0.931121    3.427338    0.190246    0.052039    0.009522    0.752232    
#> 024: 0.353431    0.943847    3.427271    0.187066    0.049437    0.010157    0.749988    
#> 025: 0.315754    0.924278    3.418765    0.199405    0.046965    0.010481    0.729744    
#> 026: 0.290067    0.953287    3.412391    0.216841    0.044617    0.009957    0.722223    
#> 027: 0.297001    0.948292    3.416454    0.205999    0.046334    0.011125    0.729441    
#> 028: 0.303798    0.940339    3.411931    0.205735    0.044017    0.010569    0.719335    
#> 029: 0.317557    0.948311    3.407438    0.195448    0.050246    0.012228    0.745492    
#> 030: 0.274241    0.966488    3.390745    0.197442    0.049182    0.011617    0.729457    
#> 031: 0.272047    0.958896    3.403327    0.187570    0.050652    0.011036    0.736954    
#> 032: 0.244892    0.963395    3.398974    0.178192    0.048119    0.011184    0.720125    
#> 033: 0.206210    0.977402    3.380833    0.185136    0.045713    0.012192    0.719901    
#> 034: 0.239641    0.982659    3.396264    0.200769    0.043427    0.012431    0.711465    
#> 035: 0.226083    0.959100    3.390312    0.190731    0.041256    0.012368    0.714276    
#> 036: 0.234903    0.976702    3.391638    0.181194    0.043719    0.014860    0.714032    
#> 037: 0.241504    0.981647    3.395001    0.179577    0.048526    0.014301    0.726498    
#> 038: 0.260318    0.969106    3.391857    0.170598    0.046768    0.013586    0.734422    
#> 039: 0.296338    0.952757    3.412573    0.174785    0.044849    0.014804    0.714438    
#> 040: 0.276011    0.950971    3.417450    0.195650    0.042606    0.014215    0.730554    
#> 041: 0.250112    0.940612    3.417957    0.185867    0.040476    0.015153    0.735805    
#> 042: 0.309156    0.912844    3.420295    0.205094    0.038452    0.014396    0.700501    
#> 043: 0.284178    0.932363    3.408489    0.194839    0.036529    0.014072    0.706059    
#> 044: 0.276162    0.946477    3.409900    0.186950    0.034703    0.013369    0.718605    
#> 045: 0.267102    0.963039    3.398171    0.195083    0.032968    0.012700    0.720835    
#> 046: 0.283224    0.958533    3.401291    0.192201    0.040743    0.012065    0.719288    
#> 047: 0.261287    0.948074    3.399852    0.182591    0.038706    0.012570    0.719955    
#> 048: 0.272418    0.939069    3.402324    0.173462    0.038670    0.012349    0.728408    
#> 049: 0.227014    0.955601    3.398483    0.164789    0.048289    0.013773    0.737246    
#> 050: 0.297595    0.925759    3.413709    0.182689    0.047919    0.013084    0.757785    
#> 051: 0.268656    0.967430    3.398850    0.173554    0.048285    0.014287    0.750550    
#> 052: 0.245265    0.966514    3.401380    0.164876    0.045871    0.013572    0.740288    
#> 053: 0.293403    0.954939    3.401679    0.160907    0.043577    0.013989    0.732685    
#> 054: 0.236039    0.951085    3.397420    0.169312    0.044377    0.014958    0.736997    
#> 055: 0.261746    0.969044    3.390598    0.169731    0.042158    0.016949    0.742211    
#> 056: 0.247379    0.948943    3.398574    0.174770    0.040050    0.016102    0.728033    
#> 057: 0.268799    0.941025    3.406199    0.166032    0.038381    0.015297    0.730105    
#> 058: 0.276370    0.927592    3.401262    0.201592    0.040187    0.014532    0.741771    
#> 059: 0.296126    0.897226    3.421992    0.230289    0.041164    0.013805    0.750762    
#> 060: 0.299320    0.928028    3.425056    0.218774    0.039849    0.013115    0.762239    
#> 061: 0.308889    0.934674    3.418953    0.215577    0.037857    0.014072    0.756639    
#> 062: 0.267271    0.966707    3.413431    0.204798    0.046980    0.014136    0.761142    
#> 063: 0.301121    0.942033    3.412941    0.194558    0.048941    0.013429    0.738295    
#> 064: 0.288220    0.939074    3.425712    0.184830    0.046494    0.013599    0.751391    
#> 065: 0.307626    0.934385    3.402567    0.175589    0.044169    0.012919    0.744039    
#> 066: 0.289827    0.936967    3.409846    0.170013    0.041961    0.012523    0.724204    
#> 067: 0.280511    0.952631    3.398574    0.164920    0.042510    0.011896    0.723058    
#> 068: 0.244774    0.948133    3.404782    0.163372    0.040384    0.012446    0.731419    
#> 069: 0.227333    0.960062    3.394482    0.212717    0.038365    0.011824    0.731054    
#> 070: 0.247796    0.957079    3.404712    0.202356    0.036447    0.013821    0.746505    
#> 071: 0.232261    0.992687    3.386016    0.192238    0.034712    0.015007    0.754177    
#> 072: 0.182109    0.951702    3.387808    0.182627    0.032977    0.014534    0.746531    
#> 073: 0.241669    0.960110    3.398667    0.180728    0.031328    0.013808    0.735257    
#> 074: 0.250680    0.959190    3.395301    0.181434    0.032150    0.013241    0.746084    
#> 075: 0.279933    0.964018    3.414721    0.223460    0.033167    0.012579    0.742717    
#> 076: 0.277655    0.958406    3.422631    0.213816    0.041348    0.012610    0.724722    
#> 077: 0.318068    0.928201    3.414563    0.203125    0.039281    0.013767    0.714435    
#> 078: 0.280241    0.931702    3.412856    0.192969    0.037317    0.013079    0.716423    
#> 079: 0.277927    0.938962    3.410214    0.210015    0.037207    0.012425    0.728435    
#> 080: 0.306483    0.938532    3.411785    0.199515    0.036002    0.011804    0.758674    
#> 081: 0.281089    0.939255    3.410598    0.189539    0.034775    0.012908    0.741610    
#> 082: 0.267115    0.924277    3.417951    0.204294    0.038909    0.012956    0.748100    
#> 083: 0.250496    0.939297    3.411118    0.194079    0.036963    0.012308    0.734525    
#> 084: 0.283319    0.945873    3.408577    0.198499    0.038233    0.012953    0.726075    
#> 085: 0.276866    0.929135    3.415755    0.188574    0.036322    0.012699    0.756824    
#> 086: 0.289360    0.925696    3.413192    0.186940    0.034506    0.013032    0.723040    
#> 087: 0.267042    0.935978    3.402464    0.191542    0.038299    0.014031    0.717398    
#> 088: 0.220781    0.931965    3.407212    0.199446    0.040110    0.013330    0.727916    
#> 089: 0.271615    0.950880    3.398005    0.189473    0.043506    0.012663    0.723482    
#> 090: 0.267138    0.944607    3.409184    0.180000    0.042081    0.012517    0.717660    
#> 091: 0.228205    0.933039    3.389682    0.171000    0.042880    0.012477    0.720628    
#> 092: 0.222376    0.954233    3.384199    0.191703    0.042101    0.013354    0.727449    
#> 093: 0.237234    0.943347    3.395722    0.187061    0.039996    0.015181    0.746531    
#> 094: 0.213489    0.959015    3.387445    0.177708    0.051124    0.014422    0.748324    
#> 095: 0.242924    0.958799    3.407186    0.171041    0.051001    0.013701    0.738602    
#> 096: 0.228157    0.958660    3.401613    0.196458    0.055960    0.013016    0.739133    
#> 097: 0.298753    0.966484    3.413513    0.218118    0.053162    0.012365    0.724976    
#> 098: 0.285905    0.973767    3.418248    0.207992    0.050504    0.011844    0.717337    
#> 099: 0.250409    0.938353    3.398562    0.197593    0.048771    0.011252    0.723244    
#> 100: 0.256486    0.955388    3.400037    0.187713    0.052062    0.010689    0.709536    
#> 101: 0.243898    0.934142    3.391874    0.178327    0.049459    0.010155    0.724045    
#> 102: 0.232225    0.956969    3.376230    0.181828    0.046986    0.011917    0.722558    
#> 103: 0.278756    0.963351    3.398352    0.190391    0.044636    0.012812    0.721616    
#> 104: 0.256191    0.964216    3.401324    0.195552    0.042405    0.013261    0.730905    
#> 105: 0.273075    0.952802    3.405966    0.185774    0.040284    0.013742    0.732784    
#> 106: 0.280219    0.962315    3.401291    0.215529    0.038270    0.015848    0.733375    
#> 107: 0.315587    0.955198    3.414964    0.224222    0.038413    0.016869    0.740741    
#> 108: 0.271657    0.945560    3.412366    0.213011    0.038163    0.016025    0.751952    
#> 109: 0.273244    0.934280    3.427566    0.202360    0.036255    0.015224    0.763919    
#> 110: 0.281855    0.959983    3.399299    0.211334    0.035020    0.015349    0.720938    
#> 111: 0.280021    0.958251    3.409414    0.210380    0.033269    0.016927    0.719863    
#> 112: 0.274196    0.930057    3.396227    0.199861    0.032826    0.017165    0.739600    
#> 113: 0.273888    0.937388    3.403009    0.194888    0.031184    0.016307    0.719045    
#> 114: 0.275404    0.947639    3.413095    0.219687    0.036067    0.015524    0.729217    
#> 115: 0.306968    0.923805    3.411798    0.234377    0.034263    0.016964    0.766335    
#> 116: 0.311449    0.938575    3.413301    0.222658    0.032550    0.019440    0.743985    
#> 117: 0.257096    0.968366    3.405277    0.211525    0.030923    0.018468    0.736088    
#> 118: 0.263504    0.963263    3.403804    0.200949    0.035421    0.017545    0.730044    
#> 119: 0.291767    0.942663    3.413720    0.197275    0.033650    0.016668    0.733682    
#> 120: 0.278114    0.944429    3.399869    0.192110    0.033883    0.015834    0.733545    
#> 121: 0.258632    0.977176    3.405782    0.183433    0.047362    0.015043    0.739849    
#> 122: 0.242503    0.955164    3.408179    0.174261    0.044993    0.014291    0.737664    
#> 123: 0.284543    0.979420    3.403722    0.173370    0.042744    0.013576    0.744104    
#> 124: 0.298678    0.968019    3.404155    0.186188    0.040969    0.012897    0.743516    
#> 125: 0.316160    0.968574    3.404702    0.186325    0.044568    0.012554    0.734846    
#> 126: 0.271202    0.966170    3.391747    0.230989    0.044637    0.012317    0.732888    
#> 127: 0.298316    0.967363    3.397855    0.219439    0.051749    0.012318    0.727347    
#> 128: 0.257925    0.953836    3.408604    0.208467    0.055964    0.013446    0.723611    
#> 129: 0.300853    0.948301    3.419886    0.198044    0.053166    0.012774    0.727881    
#> 130: 0.319258    0.967944    3.417696    0.188142    0.050508    0.012492    0.721959    
#> 131: 0.288043    0.953386    3.398542    0.181710    0.060380    0.011867    0.721859    
#> 132: 0.247041    0.967522    3.388426    0.172625    0.057361    0.011335    0.730072    
#> 133: 0.251840    0.963662    3.392680    0.180417    0.054493    0.012389    0.736737    
#> 134: 0.238320    0.944778    3.403504    0.171396    0.051768    0.016280    0.733347    
#> 135: 0.242295    0.933748    3.407812    0.162826    0.049180    0.015466    0.726290    
#> 136: 0.281425    0.931390    3.417779    0.154685    0.046721    0.014692    0.722561    
#> 137: 0.306945    0.934942    3.415390    0.178221    0.045845    0.013958    0.718894    
#> 138: 0.290370    0.943086    3.408756    0.177548    0.046628    0.014769    0.720037    
#> 139: 0.299786    0.944452    3.426697    0.176726    0.047602    0.014338    0.730056    
#> 140: 0.313448    0.937358    3.436569    0.167890    0.045222    0.013621    0.737716    
#> 141: 0.310665    0.892243    3.440211    0.159496    0.042961    0.014612    0.748777    
#> 142: 0.328277    0.905201    3.449651    0.156719    0.040813    0.013881    0.745324    
#> 143: 0.283975    0.932010    3.432462    0.170533    0.038773    0.015943    0.743501    
#> 144: 0.290397    0.945183    3.424314    0.173855    0.036834    0.015146    0.739990    
#> 145: 0.242353    0.958950    3.394262    0.165162    0.034992    0.014389    0.737350    
#> 146: 0.228875    0.961243    3.404463    0.199604    0.035085    0.013669    0.724184    
#> 147: 0.222035    0.961150    3.389226    0.189624    0.042058    0.012986    0.724412    
#> 148: 0.224246    0.976188    3.393466    0.180143    0.039955    0.012337    0.739926    
#> 149: 0.241505    0.955360    3.391798    0.171136    0.038412    0.011720    0.745382    
#> 150: 0.252984    0.955693    3.394243    0.162934    0.043582    0.011134    0.738248    
#> 151: 0.203385    0.979275    3.389571    0.154788    0.041403    0.010680    0.738141    
#> 152: 0.234899    0.968386    3.390486    0.151876    0.030227    0.008961    0.759160    
#> 153: 0.222867    0.984985    3.390750    0.149540    0.028756    0.011468    0.762340    
#> 154: 0.259143    0.975089    3.400876    0.139488    0.029243    0.012669    0.766438    
#> 155: 0.245893    0.939923    3.401253    0.165576    0.025647    0.015292    0.754061    
#> 156: 0.254334    0.953933    3.401308    0.167401    0.022040    0.019589    0.751848    
#> 157: 0.270395    0.951799    3.411012    0.162529    0.024461    0.019727    0.746825    
#> 158: 0.316876    0.954163    3.420252    0.173787    0.021163    0.018526    0.748634    
#> 159: 0.294334    0.965864    3.428102    0.168554    0.026020    0.019962    0.735439    
#> 160: 0.309819    0.940680    3.425311    0.167014    0.025412    0.019282    0.727222    
#> 161: 0.276952    0.948320    3.411836    0.170458    0.024703    0.019352    0.724574    
#> 162: 0.289279    0.959909    3.397811    0.183995    0.021372    0.019646    0.719744    
#> 163: 0.292744    0.948443    3.397991    0.185210    0.020337    0.019226    0.728767    
#> 164: 0.316102    0.974988    3.411781    0.162290    0.021363    0.021206    0.744624    
#> 165: 0.281116    0.965247    3.405800    0.187830    0.023509    0.022999    0.713989    
#> 166: 0.269920    0.984410    3.400881    0.175354    0.020783    0.023468    0.733269    
#> 167: 0.285455    0.987014    3.414955    0.188346    0.022617    0.023595    0.735434    
#> 168: 0.320174    0.993952    3.412287    0.195399    0.026240    0.019014    0.747802    
#> 169: 0.295888    0.992494    3.405119    0.205468    0.025091    0.022555    0.738318    
#> 170: 0.292503    0.948867    3.409428    0.191979    0.029302    0.018319    0.718071    
#> 171: 0.269629    0.965590    3.407847    0.201832    0.023250    0.017753    0.715001    
#> 172: 0.255328    0.981895    3.401157    0.181908    0.030021    0.014927    0.718283    
#> 173: 0.251620    0.986961    3.384665    0.154594    0.030031    0.014262    0.734843    
#> 174: 0.282637    0.989404    3.400660    0.186886    0.030616    0.013716    0.732947    
#> 175: 0.255991    0.984026    3.385524    0.178305    0.030149    0.015492    0.753755    
#> 176: 0.231251    0.992792    3.382505    0.185255    0.028313    0.012808    0.735585    
#> 177: 0.249978    0.980282    3.391682    0.187954    0.030260    0.012757    0.742369    
#> 178: 0.248615    0.976723    3.387557    0.186298    0.036731    0.014960    0.728641    
#> 179: 0.293014    0.972417    3.397369    0.181097    0.047982    0.018095    0.730587    
#> 180: 0.255993    0.972783    3.389656    0.175319    0.047113    0.014354    0.712957    
#> 181: 0.255334    0.966127    3.374075    0.183166    0.046495    0.013149    0.721340    
#> 182: 0.215193    0.975578    3.376084    0.203039    0.038337    0.014465    0.731780    
#> 183: 0.246185    0.987776    3.385571    0.201090    0.044853    0.016287    0.708177    
#> 184: 0.244998    0.964589    3.389141    0.209189    0.040068    0.014521    0.702808    
#> 185: 0.236848    0.978429    3.389878    0.204504    0.039735    0.015323    0.710959    
#> 186: 0.227102    0.997223    3.384968    0.199898    0.050373    0.014019    0.725098    
#> 187: 0.262081    0.954712    3.394717    0.174512    0.044033    0.013695    0.737246    
#> 188: 0.243929    0.966260    3.398043    0.165421    0.041366    0.016177    0.746337    
#> 189: 0.269575    0.983274    3.398711    0.161292    0.043054    0.013963    0.743466    
#> 190: 0.256422    0.953604    3.416225    0.193927    0.037608    0.016657    0.728661    
#> 191: 0.244273    0.967101    3.396888    0.166558    0.034738    0.012691    0.715035    
#> 192: 0.231290    0.969369    3.399853    0.151775    0.030308    0.013780    0.722631    
#> 193: 0.275394    0.967051    3.406995    0.165781    0.038571    0.013905    0.705958    
#> 194: 0.256450    0.958613    3.394682    0.131248    0.034942    0.012652    0.767906    
#> 195: 0.208306    0.970538    3.381141    0.129636    0.033524    0.012983    0.749359    
#> 196: 0.235158    0.973637    3.393448    0.136737    0.036484    0.013744    0.746264    
#> 197: 0.208169    0.971836    3.404212    0.140932    0.033041    0.012889    0.750641    
#> 198: 0.253707    0.955371    3.394900    0.141151    0.031681    0.012943    0.732707    
#> 199: 0.254349    0.953052    3.393149    0.179807    0.036129    0.009236    0.737104    
#> 200: 0.256393    0.963168    3.394357    0.180254    0.039462    0.011325    0.755471    
#> 201: 0.240808    0.955288    3.398207    0.171232    0.037899    0.013009    0.752239    
#> 202: 0.242947    0.955723    3.398435    0.171070    0.036846    0.013373    0.753424    
#> 203: 0.252424    0.955487    3.396700    0.174865    0.037880    0.012999    0.747472    
#> 204: 0.259186    0.954421    3.398768    0.179426    0.038830    0.013185    0.745092    
#> 205: 0.258968    0.958550    3.399689    0.188739    0.038339    0.013698    0.745700    
#> 206: 0.258285    0.961334    3.399931    0.194290    0.037575    0.013931    0.746620    
#> 207: 0.258807    0.960186    3.399515    0.204214    0.036036    0.014713    0.746147    
#> 208: 0.257557    0.959569    3.399903    0.203771    0.034843    0.014722    0.745957    
#> 209: 0.262631    0.956779    3.400643    0.201404    0.034572    0.014783    0.743179    
#> 210: 0.266685    0.955640    3.401764    0.202346    0.034118    0.014530    0.741119    
#> 211: 0.270180    0.956413    3.402543    0.205303    0.034822    0.014416    0.739712    
#> 212: 0.273064    0.956357    3.402966    0.203414    0.034898    0.014298    0.739658    
#> 213: 0.273587    0.953754    3.403205    0.203203    0.034897    0.014499    0.740628    
#> 214: 0.273894    0.953342    3.402504    0.202524    0.035352    0.014595    0.741514    
#> 215: 0.273304    0.954179    3.402508    0.200043    0.035205    0.014673    0.742618    
#> 216: 0.274086    0.953078    3.402676    0.196543    0.035452    0.014693    0.743964    
#> 217: 0.274064    0.953149    3.402882    0.193257    0.035857    0.014421    0.743535    
#> 218: 0.275349    0.953878    3.402681    0.189889    0.036271    0.014370    0.743348    
#> 219: 0.272853    0.954670    3.401319    0.187499    0.036040    0.014321    0.743931    
#> 220: 0.271937    0.955647    3.400912    0.186871    0.036147    0.014512    0.743167    
#> 221: 0.270834    0.956093    3.400645    0.186421    0.036240    0.014424    0.742318    
#> 222: 0.270970    0.956122    3.400543    0.186500    0.036184    0.014589    0.741718    
#> 223: 0.272477    0.955990    3.400763    0.185760    0.036176    0.014673    0.741495    
#> 224: 0.273399    0.956370    3.401266    0.185155    0.036095    0.014677    0.741162    
#> 225: 0.272676    0.955335    3.401750    0.184147    0.035953    0.014745    0.741347    
#> 226: 0.272409    0.954311    3.401714    0.182877    0.035942    0.014786    0.741675    
#> 227: 0.271293    0.954057    3.401862    0.182354    0.035999    0.014839    0.741004    
#> 228: 0.269752    0.954667    3.401347    0.181680    0.035758    0.014889    0.740737    
#> 229: 0.268798    0.954920    3.401077    0.179902    0.035621    0.014871    0.740069    
#> 230: 0.268028    0.954534    3.400904    0.178860    0.035475    0.014872    0.740079    
#> 231: 0.267897    0.954624    3.401061    0.178526    0.035272    0.014988    0.740036    
#> 232: 0.267702    0.954368    3.401618    0.177476    0.035075    0.015003    0.740125    
#> 233: 0.267905    0.953618    3.402050    0.176733    0.034838    0.015053    0.740200    
#> 234: 0.268346    0.953282    3.402412    0.177032    0.034777    0.015159    0.740184    
#> 235: 0.268094    0.952697    3.402226    0.176818    0.034503    0.015261    0.739872    
#> 236: 0.268221    0.952559    3.402276    0.176576    0.034314    0.015377    0.740384    
#> 237: 0.269777    0.952131    3.402680    0.176182    0.034083    0.015394    0.741263    
#> 238: 0.270348    0.952102    3.402974    0.176447    0.033887    0.015379    0.741634    
#> 239: 0.270465    0.952618    3.403176    0.175978    0.033900    0.015369    0.741483    
#> 240: 0.270877    0.952501    3.403414    0.176360    0.033967    0.015384    0.741075    
#> 241: 0.271818    0.952272    3.403701    0.176708    0.034277    0.015288    0.740807    
#> 242: 0.271850    0.952009    3.403625    0.176587    0.034516    0.015213    0.740861    
#> 243: 0.271285    0.952290    3.403795    0.176339    0.034732    0.015184    0.740713    
#> 244: 0.271202    0.951920    3.404103    0.175795    0.034651    0.015154    0.740571    
#> 245: 0.270943    0.951625    3.404163    0.175486    0.034762    0.015086    0.740556    
#> 246: 0.270738    0.951548    3.404286    0.174967    0.034838    0.015061    0.740701    
#> 247: 0.270725    0.951502    3.404512    0.174471    0.035021    0.015006    0.740419    
#> 248: 0.270480    0.951642    3.404463    0.174066    0.034892    0.014917    0.740589    
#> 249: 0.270692    0.951875    3.404617    0.174113    0.034865    0.014826    0.740932    
#> 250: 0.271055    0.952002    3.404797    0.174068    0.035022    0.014834    0.741057    
#> 251: 0.271188    0.952013    3.405028    0.173600    0.035118    0.014795    0.741133    
#> 252: 0.271491    0.952117    3.405415    0.173643    0.035183    0.014737    0.741267    
#> 253: 0.271566    0.952274    3.405654    0.173693    0.035174    0.014738    0.741243    
#> 254: 0.271957    0.952559    3.406048    0.173248    0.035130    0.014701    0.741260    
#> 255: 0.272217    0.952614    3.406379    0.173052    0.035130    0.014685    0.741308    
#> 256: 0.272893    0.952141    3.406527    0.172660    0.035138    0.014611    0.741518    
#> 257: 0.273289    0.951863    3.406704    0.172192    0.035336    0.014564    0.741646    
#> 258: 0.273311    0.951480    3.406584    0.172131    0.035358    0.014518    0.741653    
#> 259: 0.273255    0.951311    3.406540    0.172117    0.035427    0.014506    0.741666    
#> 260: 0.272973    0.951380    3.406586    0.171790    0.035507    0.014462    0.741445    
#> 261: 0.273333    0.951324    3.406709    0.171664    0.035627    0.014407    0.741484    
#> 262: 0.273819    0.951596    3.406835    0.171856    0.035627    0.014339    0.741748    
#> 263: 0.273730    0.951672    3.406975    0.171507    0.035618    0.014300    0.741852    
#> 264: 0.273348    0.951771    3.406856    0.171505    0.035765    0.014323    0.741788    
#> 265: 0.273427    0.951934    3.406821    0.171547    0.035856    0.014324    0.741669    
#> 266: 0.274040    0.952128    3.406824    0.171770    0.035795    0.014313    0.741743    
#> 267: 0.274067    0.952233    3.406845    0.172141    0.035774    0.014319    0.741539    
#> 268: 0.274098    0.952266    3.406820    0.172360    0.035747    0.014306    0.741261    
#> 269: 0.274132    0.952042    3.406783    0.172200    0.035758    0.014314    0.741165    
#> 270: 0.274398    0.952115    3.406632    0.171930    0.035690    0.014283    0.741108    
#> 271: 0.274266    0.952179    3.406391    0.171945    0.035666    0.014281    0.741522    
#> 272: 0.274232    0.951965    3.406350    0.171750    0.035650    0.014300    0.741689    
#> 273: 0.274391    0.952026    3.406458    0.171937    0.035798    0.014314    0.741548    
#> 274: 0.274129    0.952082    3.406612    0.171736    0.035813    0.014296    0.741304    
#> 275: 0.274535    0.952003    3.406810    0.171608    0.035918    0.014288    0.741025    
#> 276: 0.274796    0.951864    3.407152    0.171703    0.035967    0.014315    0.741076    
#> 277: 0.275001    0.952005    3.407348    0.171578    0.035858    0.014334    0.740805    
#> 278: 0.275080    0.952042    3.407562    0.171581    0.035872    0.014331    0.740714    
#> 279: 0.275180    0.951929    3.407694    0.171417    0.035836    0.014327    0.740848    
#> 280: 0.275202    0.952030    3.407755    0.171269    0.035818    0.014295    0.740815    
#> 281: 0.275010    0.952260    3.407740    0.171215    0.035944    0.014272    0.740638    
#> 282: 0.274879    0.952598    3.407675    0.171470    0.036125    0.014261    0.740865    
#> 283: 0.275073    0.952741    3.407741    0.171604    0.036299    0.014273    0.741021    
#> 284: 0.275093    0.952653    3.407777    0.171785    0.036387    0.014246    0.740943    
#> 285: 0.275155    0.952592    3.407716    0.171473    0.036384    0.014231    0.740926    
#> 286: 0.275381    0.952699    3.407738    0.171387    0.036606    0.014221    0.740743    
#> 287: 0.275466    0.952817    3.407733    0.171333    0.036682    0.014212    0.740716    
#> 288: 0.275978    0.952826    3.407696    0.171693    0.036764    0.014188    0.740754    
#> 289: 0.276335    0.952632    3.407746    0.171859    0.036799    0.014172    0.740706    
#> 290: 0.276309    0.952487    3.407833    0.171405    0.036772    0.014121    0.741007    
#> 291: 0.276543    0.952824    3.407895    0.171170    0.036782    0.014103    0.741048    
#> 292: 0.276354    0.952933    3.407864    0.171058    0.036820    0.014053    0.741072    
#> 293: 0.276034    0.952962    3.407812    0.170927    0.036813    0.013999    0.741018    
#> 294: 0.275829    0.953020    3.407706    0.171085    0.036860    0.013955    0.740924    
#> 295: 0.275694    0.952657    3.407735    0.170838    0.036861    0.013947    0.740838    
#> 296: 0.275729    0.952424    3.407778    0.170897    0.036809    0.013968    0.740966    
#> 297: 0.275706    0.952399    3.407812    0.171153    0.036723    0.013980    0.740986    
#> 298: 0.275629    0.952371    3.407768    0.171091    0.036723    0.013955    0.740812    
#> 299: 0.275591    0.952620    3.407669    0.171067    0.036710    0.013936    0.740628    
#> 300: 0.275637    0.952490    3.407744    0.170947    0.036696    0.013917    0.740712    
#> 301: 0.275781    0.952318    3.407718    0.170854    0.036717    0.013882    0.740745    
#> 302: 0.275790    0.952442    3.407661    0.170598    0.036819    0.013854    0.740694    
#> 303: 0.275607    0.952593    3.407658    0.170646    0.036754    0.013864    0.740564    
#> 304: 0.275206    0.952823    3.407483    0.170502    0.036704    0.013857    0.740538    
#> 305: 0.274971    0.952605    3.407381    0.170541    0.036689    0.013856    0.740445    
#> 306: 0.274555    0.952647    3.407192    0.170526    0.036691    0.013866    0.740516    
#> 307: 0.274325    0.952641    3.407127    0.170721    0.036687    0.013860    0.740618    
#> 308: 0.274078    0.952538    3.407116    0.170920    0.036639    0.013891    0.740729    
#> 309: 0.274014    0.952434    3.407032    0.171285    0.036678    0.013891    0.740784    
#> 310: 0.274070    0.952349    3.406850    0.171663    0.036707    0.013930    0.740885    
#> 311: 0.274085    0.952422    3.406869    0.171699    0.036699    0.013916    0.740924    
#> 312: 0.273772    0.952306    3.406762    0.171653    0.036724    0.013879    0.740941    
#> 313: 0.273488    0.952057    3.406759    0.171593    0.036720    0.013830    0.741172    
#> 314: 0.273202    0.951849    3.406776    0.171785    0.036707    0.013798    0.741201    
#> 315: 0.273017    0.951755    3.406745    0.171829    0.036695    0.013784    0.741156    
#> 316: 0.273201    0.951692    3.406817    0.172108    0.036695    0.013774    0.741141    
#> 317: 0.273579    0.951644    3.406945    0.172206    0.036706    0.013771    0.741282    
#> 318: 0.273883    0.951722    3.406952    0.172165    0.036688    0.013762    0.741190    
#> 319: 0.273932    0.951489    3.407038    0.172285    0.036608    0.013764    0.741161    
#> 320: 0.273482    0.951474    3.406843    0.172181    0.036584    0.013777    0.741070    
#> 321: 0.272800    0.951622    3.406572    0.172287    0.036588    0.013768    0.741034    
#> 322: 0.272392    0.951711    3.406355    0.172311    0.036564    0.013764    0.740840    
#> 323: 0.271874    0.951737    3.406229    0.172343    0.036541    0.013776    0.740735    
#> 324: 0.271695    0.951895    3.406140    0.172284    0.036498    0.013756    0.740741    
#> 325: 0.271552    0.952178    3.406076    0.172217    0.036507    0.013756    0.740674    
#> 326: 0.271568    0.952222    3.405978    0.172459    0.036530    0.013744    0.740619    
#> 327: 0.271649    0.952353    3.405943    0.172483    0.036509    0.013735    0.740702    
#> 328: 0.271541    0.952448    3.405817    0.172619    0.036475    0.013745    0.740748    
#> 329: 0.271706    0.952475    3.405864    0.172745    0.036434    0.013746    0.740699    
#> 330: 0.271445    0.952526    3.405852    0.172797    0.036439    0.013749    0.740629    
#> 331: 0.271497    0.952743    3.405845    0.172971    0.036441    0.013749    0.740475    
#> 332: 0.271532    0.952693    3.405951    0.173286    0.036360    0.013802    0.740258    
#> 333: 0.271489    0.952684    3.405926    0.173528    0.036301    0.013841    0.740149    
#> 334: 0.271373    0.952622    3.405844    0.173574    0.036248    0.013828    0.740155    
#> 335: 0.271260    0.952625    3.405672    0.173690    0.036191    0.013808    0.740139    
#> 336: 0.270880    0.952912    3.405491    0.173952    0.036219    0.013807    0.740118    
#> 337: 0.270679    0.953156    3.405314    0.174225    0.036255    0.013817    0.740057    
#> 338: 0.270737    0.953231    3.405271    0.174305    0.036280    0.013798    0.739972    
#> 339: 0.270489    0.953329    3.405176    0.174238    0.036291    0.013777    0.739851    
#> 340: 0.270339    0.953228    3.405168    0.174186    0.036339    0.013781    0.739765    
#> 341: 0.270275    0.953172    3.405234    0.173828    0.036367    0.013780    0.739843    
#> 342: 0.270234    0.952977    3.405316    0.173697    0.036355    0.013796    0.739766    
#> 343: 0.270084    0.952957    3.405339    0.173499    0.036391    0.013794    0.739703    
#> 344: 0.270327    0.952839    3.405425    0.173582    0.036380    0.013805    0.739711    
#> 345: 0.270314    0.952740    3.405433    0.173515    0.036381    0.013793    0.739757    
#> 346: 0.270208    0.952772    3.405314    0.173492    0.036361    0.013777    0.739720    
#> 347: 0.269976    0.952746    3.405154    0.173548    0.036385    0.013787    0.739653    
#> 348: 0.269837    0.952866    3.405086    0.173601    0.036366    0.013777    0.739619    
#> 349: 0.269716    0.952898    3.405014    0.173713    0.036340    0.013771    0.739510    
#> 350: 0.269277    0.952806    3.404923    0.173877    0.036337    0.013768    0.739462    
#> 351: 0.269178    0.952899    3.404805    0.174196    0.036313    0.013767    0.739329    
#> 352: 0.268894    0.952990    3.404764    0.174413    0.036290    0.013769    0.739432    
#> 353: 0.268730    0.953192    3.404681    0.174335    0.036334    0.013774    0.739379    
#> 354: 0.268667    0.953328    3.404546    0.174347    0.036359    0.013785    0.739324    
#> 355: 0.268919    0.953255    3.404539    0.174260    0.036337    0.013792    0.739258    
#> 356: 0.269067    0.953112    3.404643    0.174599    0.036363    0.013796    0.739272    
#> 357: 0.269356    0.953120    3.404640    0.174757    0.036369    0.013830    0.739177    
#> 358: 0.269523    0.953191    3.404684    0.174774    0.036346    0.013843    0.739142    
#> 359: 0.269522    0.953284    3.404695    0.174798    0.036285    0.013841    0.739061    
#> 360: 0.269265    0.953285    3.404577    0.174884    0.036237    0.013835    0.739009    
#> 361: 0.269008    0.953367    3.404510    0.174994    0.036292    0.013828    0.738858    
#> 362: 0.268967    0.953455    3.404424    0.174837    0.036296    0.013806    0.738665    
#> 363: 0.269150    0.953409    3.404465    0.174895    0.036218    0.013790    0.738635    
#> 364: 0.269261    0.953376    3.404483    0.174817    0.036174    0.013783    0.738714    
#> 365: 0.269337    0.953206    3.404553    0.174657    0.036171    0.013772    0.738860    
#> 366: 0.269329    0.953246    3.404486    0.174658    0.036163    0.013767    0.738895    
#> 367: 0.269299    0.953216    3.404448    0.174508    0.036195    0.013762    0.738921    
#> 368: 0.269456    0.953234    3.404406    0.174701    0.036222    0.013761    0.738774    
#> 369: 0.269414    0.953212    3.404379    0.174911    0.036241    0.013747    0.738783    
#> 370: 0.269220    0.953288    3.404323    0.174928    0.036269    0.013747    0.738756    
#> 371: 0.268922    0.953365    3.404143    0.174873    0.036244    0.013728    0.738690    
#> 372: 0.268854    0.953391    3.404085    0.174946    0.036241    0.013720    0.738574    
#> 373: 0.268630    0.953503    3.404030    0.174855    0.036261    0.013721    0.738557    
#> 374: 0.268649    0.953543    3.404042    0.174776    0.036243    0.013706    0.738499    
#> 375: 0.268617    0.953520    3.404079    0.174649    0.036211    0.013698    0.738466    
#> 376: 0.268567    0.953579    3.404076    0.174366    0.036229    0.013699    0.738390    
#> 377: 0.268487    0.953642    3.404075    0.174153    0.036219    0.013691    0.738414    
#> 378: 0.268441    0.953648    3.404027    0.173973    0.036204    0.013687    0.738448    
#> 379: 0.268353    0.953577    3.404015    0.173855    0.036231    0.013689    0.738397    
#> 380: 0.268247    0.953565    3.403977    0.173849    0.036252    0.013667    0.738341    
#> 381: 0.268232    0.953527    3.403985    0.173697    0.036307    0.013642    0.738433    
#> 382: 0.268334    0.953517    3.403987    0.173694    0.036293    0.013631    0.738430    
#> 383: 0.268432    0.953556    3.403983    0.173697    0.036319    0.013620    0.738369    
#> 384: 0.268289    0.953561    3.403964    0.173740    0.036292    0.013602    0.738425    
#> 385: 0.268236    0.953627    3.403962    0.173653    0.036317    0.013601    0.738397    
#> 386: 0.268201    0.953725    3.404028    0.173514    0.036399    0.013586    0.738357    
#> 387: 0.268422    0.953732    3.404116    0.173348    0.036481    0.013577    0.738366    
#> 388: 0.268440    0.953710    3.404156    0.173461    0.036568    0.013568    0.738302    
#> 389: 0.268402    0.953527    3.404109    0.173477    0.036629    0.013555    0.738386    
#> 390: 0.268299    0.953545    3.404071    0.173576    0.036691    0.013541    0.738346    
#> 391: 0.268373    0.953552    3.404075    0.173598    0.036732    0.013533    0.738266    
#> 392: 0.268541    0.953495    3.404167    0.173658    0.036720    0.013531    0.738259    
#> 393: 0.268649    0.953372    3.404175    0.173797    0.036676    0.013529    0.738267    
#> 394: 0.268730    0.953335    3.404170    0.173986    0.036659    0.013536    0.738190    
#> 395: 0.268939    0.953403    3.404175    0.174079    0.036698    0.013549    0.738124    
#> 396: 0.269107    0.953447    3.404204    0.174182    0.036670    0.013565    0.738058    
#> 397: 0.269268    0.953442    3.404247    0.174424    0.036688    0.013584    0.737952    
#> 398: 0.269372    0.953385    3.404274    0.174804    0.036681    0.013616    0.737927    
#> 399: 0.269516    0.953435    3.404343    0.175083    0.036705    0.013639    0.737792    
#> 400: 0.269526    0.953456    3.404388    0.175190    0.036707    0.013640    0.737667    
#> 401: 0.269568    0.953536    3.404362    0.175192    0.036703    0.013634    0.737690    
#> 402: 0.269599    0.953571    3.404368    0.175308    0.036711    0.013639    0.737671    
#> 403: 0.269816    0.953568    3.404379    0.175395    0.036718    0.013651    0.737545    
#> 404: 0.269915    0.953636    3.404357    0.175371    0.036732    0.013638    0.737483    
#> 405: 0.269984    0.953603    3.404385    0.175176    0.036748    0.013627    0.737510    
#> 406: 0.270070    0.953553    3.404399    0.175136    0.036756    0.013618    0.737588    
#> 407: 0.270032    0.953534    3.404413    0.175050    0.036746    0.013610    0.737657    
#> 408: 0.270088    0.953599    3.404415    0.175060    0.036724    0.013599    0.737845    
#> 409: 0.269928    0.953646    3.404339    0.175109    0.036680    0.013607    0.737789    
#> 410: 0.269739    0.953739    3.404211    0.175135    0.036641    0.013612    0.737759    
#> 411: 0.269636    0.953699    3.404099    0.175112    0.036662    0.013608    0.737792    
#> 412: 0.269630    0.953759    3.404039    0.175033    0.036636    0.013606    0.737796    
#> 413: 0.269580    0.953815    3.403974    0.175076    0.036638    0.013605    0.737775    
#> 414: 0.269395    0.953788    3.404001    0.175008    0.036615    0.013604    0.737752    
#> 415: 0.269493    0.953748    3.404000    0.175041    0.036614    0.013603    0.737766    
#> 416: 0.269679    0.953823    3.404041    0.175128    0.036599    0.013615    0.737739    
#> 417: 0.269747    0.953803    3.404093    0.175109    0.036597    0.013632    0.737686    
#> 418: 0.269623    0.953813    3.404131    0.175001    0.036604    0.013625    0.737658    
#> 419: 0.269598    0.953906    3.404123    0.175099    0.036612    0.013635    0.737639    
#> 420: 0.269611    0.953954    3.404111    0.174899    0.036621    0.013638    0.737620    
#> 421: 0.269493    0.954010    3.404120    0.174754    0.036629    0.013627    0.737551    
#> 422: 0.269651    0.953924    3.404143    0.174694    0.036613    0.013621    0.737523    
#> 423: 0.269870    0.953867    3.404201    0.174546    0.036624    0.013608    0.737662    
#> 424: 0.269870    0.953819    3.404221    0.174366    0.036676    0.013596    0.737641    
#> 425: 0.270067    0.953880    3.404267    0.174275    0.036738    0.013585    0.737684    
#> 426: 0.270225    0.954015    3.404298    0.174185    0.036763    0.013576    0.737655    
#> 427: 0.270061    0.953965    3.404333    0.174070    0.036750    0.013567    0.737621    
#> 428: 0.269834    0.953972    3.404313    0.174034    0.036720    0.013563    0.737681    
#> 429: 0.269747    0.954032    3.404296    0.173970    0.036702    0.013564    0.737727    
#> 430: 0.269574    0.954106    3.404252    0.173908    0.036677    0.013560    0.737682    
#> 431: 0.269352    0.954116    3.404201    0.173819    0.036695    0.013552    0.737626    
#> 432: 0.269299    0.954195    3.404210    0.173812    0.036724    0.013556    0.737623    
#> 433: 0.269215    0.954294    3.404200    0.173908    0.036757    0.013546    0.737624    
#> 434: 0.269112    0.954218    3.404215    0.174046    0.036752    0.013551    0.737543    
#> 435: 0.269174    0.954212    3.404230    0.174045    0.036757    0.013543    0.737487    
#> 436: 0.269179    0.954195    3.404269    0.174045    0.036813    0.013539    0.737392    
#> 437: 0.269285    0.954177    3.404279    0.174015    0.036838    0.013529    0.737348    
#> 438: 0.269445    0.954251    3.404329    0.174022    0.036840    0.013525    0.737261    
#> 439: 0.269597    0.954334    3.404388    0.174020    0.036883    0.013521    0.737166    
#> 440: 0.269690    0.954361    3.404470    0.173977    0.036887    0.013524    0.737054    
#> 441: 0.269677    0.954310    3.404494    0.173911    0.036905    0.013524    0.736978    
#> 442: 0.269643    0.954334    3.404525    0.173803    0.036916    0.013512    0.736941    
#> 443: 0.269580    0.954368    3.404508    0.173790    0.036896    0.013510    0.736936    
#> 444: 0.269560    0.954359    3.404472    0.173878    0.036908    0.013512    0.736897    
#> 445: 0.269487    0.954383    3.404432    0.173929    0.036912    0.013510    0.736883    
#> 446: 0.269252    0.954429    3.404336    0.174034    0.036922    0.013504    0.736846    
#> 447: 0.269281    0.954460    3.404312    0.174017    0.036915    0.013511    0.736833    
#> 448: 0.269189    0.954518    3.404281    0.174081    0.036915    0.013522    0.736808    
#> 449: 0.269195    0.954557    3.404323    0.174152    0.036897    0.013538    0.736773    
#> 450: 0.269193    0.954596    3.404313    0.174247    0.036884    0.013562    0.736680    
#> 451: 0.269260    0.954630    3.404303    0.174403    0.036847    0.013581    0.736633    
#> 452: 0.269273    0.954630    3.404304    0.174485    0.036831    0.013591    0.736592    
#> 453: 0.269191    0.954632    3.404308    0.174431    0.036840    0.013584    0.736490    
#> 454: 0.269167    0.954656    3.404296    0.174525    0.036873    0.013579    0.736348    
#> 455: 0.269183    0.954626    3.404299    0.174688    0.036864    0.013575    0.736389    
#> 456: 0.269138    0.954570    3.404291    0.174764    0.036871    0.013573    0.736389    
#> 457: 0.269131    0.954556    3.404315    0.174707    0.036863    0.013576    0.736306    
#> 458: 0.269192    0.954595    3.404382    0.174654    0.036825    0.013582    0.736242    
#> 459: 0.269187    0.954686    3.404400    0.174628    0.036765    0.013597    0.736224    
#> 460: 0.269103    0.954667    3.404352    0.174631    0.036726    0.013610    0.736161    
#> 461: 0.268976    0.954663    3.404346    0.174674    0.036706    0.013625    0.736173    
#> 462: 0.268854    0.954682    3.404368    0.174747    0.036652    0.013640    0.736175    
#> 463: 0.268834    0.954752    3.404379    0.174832    0.036649    0.013657    0.736151    
#> 464: 0.268885    0.954808    3.404352    0.174796    0.036612    0.013673    0.736161    
#> 465: 0.268920    0.954687    3.404351    0.174738    0.036592    0.013676    0.736184    
#> 466: 0.268982    0.954724    3.404300    0.174887    0.036575    0.013694    0.736132    
#> 467: 0.268788    0.954742    3.404274    0.175031    0.036568    0.013713    0.736022    
#> 468: 0.268866    0.954798    3.404294    0.175168    0.036574    0.013719    0.735991    
#> 469: 0.268897    0.954896    3.404319    0.175194    0.036614    0.013716    0.736029    
#> 470: 0.268755    0.954947    3.404292    0.175201    0.036629    0.013719    0.735984    
#> 471: 0.268544    0.954950    3.404256    0.175261    0.036632    0.013717    0.735978    
#> 472: 0.268411    0.954951    3.404239    0.175234    0.036630    0.013709    0.735998    
#> 473: 0.268214    0.955018    3.404181    0.175234    0.036628    0.013705    0.736018    
#> 474: 0.268098    0.954980    3.404154    0.175206    0.036619    0.013705    0.736135    
#> 475: 0.268102    0.955088    3.404101    0.175098    0.036609    0.013697    0.736155    
#> 476: 0.268136    0.955138    3.404084    0.175017    0.036597    0.013693    0.736205    
#> 477: 0.268052    0.955183    3.404071    0.174982    0.036582    0.013682    0.736155    
#> 478: 0.267895    0.955214    3.404027    0.174982    0.036559    0.013681    0.736115    
#> 479: 0.267927    0.955311    3.403999    0.175055    0.036573    0.013683    0.736160    
#> 480: 0.268001    0.955348    3.403985    0.175143    0.036580    0.013682    0.736165    
#> 481: 0.267904    0.955395    3.403944    0.175157    0.036599    0.013675    0.736144    
#> 482: 0.267988    0.955421    3.403909    0.175086    0.036602    0.013669    0.736155    
#> 483: 0.267819    0.955418    3.403885    0.175037    0.036626    0.013659    0.736144    
#> 484: 0.267673    0.955333    3.403877    0.175016    0.036634    0.013652    0.736170    
#> 485: 0.267642    0.955372    3.403879    0.175087    0.036656    0.013646    0.736146    
#> 486: 0.267740    0.955375    3.403910    0.175134    0.036666    0.013647    0.736076    
#> 487: 0.267845    0.955397    3.403963    0.175165    0.036675    0.013646    0.735975    
#> 488: 0.267805    0.955402    3.403970    0.175262    0.036685    0.013643    0.735861    
#> 489: 0.267888    0.955403    3.403961    0.175226    0.036667    0.013638    0.735865    
#> 490: 0.267971    0.955378    3.404013    0.175214    0.036683    0.013626    0.735884    
#> 491: 0.267995    0.955424    3.404057    0.175294    0.036719    0.013620    0.735863    
#> 492: 0.268002    0.955459    3.404073    0.175300    0.036722    0.013618    0.735834    
#> 493: 0.267990    0.955412    3.404089    0.175207    0.036736    0.013610    0.735842    
#> 494: 0.268085    0.955395    3.404096    0.175170    0.036765    0.013605    0.735795    
#> 495: 0.268141    0.955429    3.404103    0.175212    0.036754    0.013598    0.735788    
#> 496: 0.268240    0.955503    3.404066    0.175297    0.036731    0.013600    0.735805    
#> 497: 0.268254    0.955486    3.404079    0.175257    0.036702    0.013607    0.735884    
#> 498: 0.268308    0.955485    3.404053    0.175255    0.036705    0.013605    0.735863    
#> 499: 0.268308    0.955524    3.404002    0.175249    0.036706    0.013597    0.735873    
#> 500: 0.268274    0.955456    3.403984    0.175186    0.036706    0.013599    0.735904    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.304752    0.966574    3.445322    0.392401    0.089895    0.016800    1.543718    
#> 002: 0.525547    0.968810    3.480625    0.372781    0.085400    0.015960    1.043411    
#> 003: 0.648820    0.969880    3.480343    0.354142    0.081130    0.015162    0.726089    
#> 004: 0.675794    0.979980    3.490564    0.336435    0.077074    0.014404    0.648590    
#> 005: 0.711395    0.984315    3.483413    0.332937    0.073220    0.013684    0.641544    
#> 006: 0.677493    0.973381    3.474419    0.316291    0.071843    0.013000    0.608539    
#> 007: 0.631863    0.985506    3.469316    0.314522    0.073053    0.012350    0.626763    
#> 008: 0.633987    0.977500    3.463696    0.335519    0.069709    0.012137    0.623294    
#> 009: 0.597179    0.978589    3.458529    0.318743    0.090914    0.011530    0.622072    
#> 010: 0.634564    0.971776    3.454732    0.397254    0.086369    0.010977    0.618347    
#> 011: 0.692610    0.979240    3.468634    0.429090    0.082050    0.011077    0.620997    
#> 012: 0.678447    0.969015    3.465033    0.415360    0.077948    0.013550    0.600351    
#> 013: 0.634751    0.995845    3.454459    0.410455    0.075624    0.013865    0.604433    
#> 014: 0.668859    0.989430    3.461175    0.395838    0.077931    0.014207    0.618420    
#> 015: 0.658557    0.998972    3.462970    0.394989    0.076311    0.013497    0.615634    
#> 016: 0.654202    1.000855    3.465719    0.398240    0.072495    0.013343    0.645917    
#> 017: 0.661520    1.003261    3.470891    0.378328    0.068871    0.012676    0.617288    
#> 018: 0.684576    1.000756    3.466627    0.365334    0.080559    0.012042    0.603824    
#> 019: 0.624540    0.985302    3.459833    0.347067    0.076800    0.011440    0.605237    
#> 020: 0.676986    0.993505    3.470743    0.367716    0.072960    0.012872    0.601732    
#> 021: 0.692093    0.981300    3.485486    0.377653    0.069312    0.012229    0.594177    
#> 022: 0.720912    0.967005    3.491442    0.395524    0.065846    0.013021    0.587031    
#> 023: 0.778951    0.972309    3.497247    0.425843    0.063698    0.013786    0.624384    
#> 024: 0.785073    0.979931    3.494328    0.444008    0.060856    0.013878    0.624511    
#> 025: 0.727083    0.941852    3.491202    0.421808    0.069046    0.013184    0.621359    
#> 026: 0.674701    0.985891    3.481685    0.400718    0.074368    0.014047    0.614583    
#> 027: 0.671039    0.989152    3.473662    0.384543    0.070650    0.013429    0.621103    
#> 028: 0.719153    0.983057    3.484800    0.433765    0.067117    0.012998    0.593017    
#> 029: 0.718567    0.984648    3.470166    0.463460    0.068173    0.012348    0.615236    
#> 030: 0.722837    0.991586    3.469609    0.542164    0.078521    0.011730    0.594355    
#> 031: 0.679153    0.976048    3.471988    0.515055    0.076820    0.013748    0.595687    
#> 032: 0.664124    0.968021    3.472421    0.489303    0.072979    0.013061    0.587295    
#> 033: 0.658324    0.980735    3.470592    0.464837    0.069330    0.012408    0.588984    
#> 034: 0.706185    0.990292    3.471795    0.442891    0.070274    0.011787    0.588239    
#> 035: 0.681638    0.976213    3.469738    0.426785    0.069471    0.011198    0.581363    
#> 036: 0.679767    0.985827    3.474155    0.405446    0.065997    0.010638    0.606208    
#> 037: 0.690610    0.997886    3.476309    0.385174    0.062697    0.010106    0.635614    
#> 038: 0.675495    0.993149    3.468250    0.365915    0.059562    0.010734    0.620767    
#> 039: 0.699453    0.996645    3.475233    0.385974    0.056584    0.010572    0.606280    
#> 040: 0.674708    1.011910    3.477606    0.390979    0.066174    0.010931    0.618540    
#> 041: 0.632631    0.988351    3.467480    0.432199    0.065940    0.011298    0.620564    
#> 042: 0.683023    0.995896    3.464064    0.458072    0.076074    0.011699    0.605727    
#> 043: 0.652031    1.003688    3.449006    0.440332    0.074453    0.011114    0.600273    
#> 044: 0.650192    1.012168    3.451498    0.418315    0.070731    0.011792    0.603869    
#> 045: 0.630988    1.024355    3.449792    0.397399    0.068114    0.011896    0.617058    
#> 046: 0.644385    0.995364    3.452548    0.419847    0.064708    0.011301    0.617383    
#> 047: 0.651912    1.007910    3.449771    0.455743    0.069619    0.010736    0.617617    
#> 048: 0.640130    1.004113    3.453495    0.432955    0.069515    0.010714    0.612260    
#> 049: 0.620718    0.994920    3.453816    0.411308    0.078298    0.010679    0.612576    
#> 050: 0.695705    0.975297    3.465969    0.426949    0.075526    0.012395    0.620937    
#> 051: 0.653858    1.001780    3.458891    0.405602    0.071750    0.014029    0.633478    
#> 052: 0.654113    1.006089    3.470026    0.385322    0.068687    0.013327    0.620072    
#> 053: 0.659876    0.993122    3.469242    0.366056    0.085322    0.012661    0.610594    
#> 054: 0.624518    0.978681    3.468930    0.347753    0.081055    0.012076    0.627702    
#> 055: 0.657445    0.982450    3.469271    0.347926    0.077761    0.011473    0.615438    
#> 056: 0.710121    0.976140    3.472118    0.403779    0.076456    0.010899    0.613681    
#> 057: 0.693116    0.978413    3.473512    0.406978    0.072634    0.011868    0.616775    
#> 058: 0.673941    0.988771    3.466220    0.386629    0.069002    0.011275    0.618650    
#> 059: 0.645231    0.940614    3.481678    0.403065    0.065552    0.013855    0.642562    
#> 060: 0.664947    0.935966    3.487920    0.382912    0.073488    0.013163    0.646144    
#> 061: 0.729774    0.957305    3.482436    0.375641    0.082819    0.012775    0.636490    
#> 062: 0.726324    0.972072    3.492438    0.356859    0.078678    0.012137    0.653653    
#> 063: 0.721215    0.947664    3.495331    0.339016    0.087291    0.011530    0.641146    
#> 064: 0.674805    0.963098    3.484867    0.322065    0.082926    0.010953    0.630911    
#> 065: 0.705808    0.961883    3.472918    0.309813    0.078780    0.010406    0.620714    
#> 066: 0.716933    0.973953    3.479828    0.369777    0.077501    0.009885    0.611816    
#> 067: 0.681166    0.966806    3.469999    0.410608    0.073626    0.012111    0.608297    
#> 068: 0.659276    0.995844    3.474354    0.390077    0.076433    0.011550    0.627677    
#> 069: 0.644574    0.993502    3.452432    0.495944    0.073836    0.010973    0.646784    
#> 070: 0.670957    0.997355    3.471004    0.471146    0.070144    0.010949    0.628362    
#> 071: 0.655192    1.002904    3.462288    0.447589    0.069212    0.010401    0.631061    
#> 072: 0.656285    0.983763    3.460736    0.425210    0.066615    0.009881    0.615871    
#> 073: 0.688978    0.981584    3.477506    0.432895    0.063284    0.010375    0.622469    
#> 074: 0.686946    0.969059    3.480840    0.411250    0.064025    0.010939    0.604795    
#> 075: 0.707173    0.963995    3.488283    0.390688    0.062538    0.010625    0.608854    
#> 076: 0.692022    0.986639    3.486214    0.371153    0.068046    0.010094    0.616454    
#> 077: 0.738603    0.969652    3.481203    0.356736    0.064644    0.009589    0.614292    
#> 078: 0.714516    0.968990    3.489122    0.381895    0.070655    0.010729    0.600620    
#> 079: 0.720871    0.986574    3.491061    0.415866    0.067122    0.011472    0.624745    
#> 080: 0.725382    0.961360    3.488586    0.402901    0.071942    0.010899    0.642962    
#> 081: 0.696049    0.966965    3.481432    0.392302    0.069172    0.010354    0.625885    
#> 082: 0.720528    0.968069    3.490145    0.416436    0.065713    0.010385    0.630550    
#> 083: 0.705831    1.006357    3.484296    0.395614    0.065667    0.010217    0.620673    
#> 084: 0.704459    0.991666    3.476467    0.479124    0.062384    0.010197    0.624080    
#> 085: 0.680920    0.995580    3.489497    0.455168    0.065910    0.011375    0.616212    
#> 086: 0.688318    0.983411    3.482930    0.432409    0.062614    0.010806    0.621847    
#> 087: 0.701195    0.978093    3.477372    0.410789    0.071530    0.010266    0.609075    
#> 088: 0.661217    0.969419    3.471351    0.390249    0.070574    0.009753    0.622953    
#> 089: 0.658500    0.970682    3.462391    0.370737    0.081272    0.009265    0.630848    
#> 090: 0.654143    0.981440    3.457598    0.379668    0.077209    0.008802    0.643877    
#> 091: 0.620063    0.987640    3.445452    0.384239    0.073348    0.009155    0.614290    
#> 092: 0.619989    1.009297    3.440822    0.392445    0.074439    0.009747    0.610765    
#> 093: 0.606212    0.989124    3.447350    0.372822    0.080862    0.010151    0.629437    
#> 094: 0.638219    1.009253    3.455052    0.355178    0.081037    0.010880    0.623523    
#> 095: 0.639661    1.004552    3.460998    0.337419    0.087055    0.011003    0.626508    
#> 096: 0.634353    1.002803    3.461813    0.383423    0.085637    0.010560    0.608828    
#> 097: 0.661074    1.023085    3.453865    0.421071    0.081355    0.010032    0.600143    
#> 098: 0.662112    1.023224    3.458982    0.405472    0.077288    0.010592    0.605991    
#> 099: 0.645179    0.998907    3.451562    0.385199    0.073423    0.010062    0.625507    
#> 100: 0.627491    1.009726    3.453465    0.365939    0.069752    0.009559    0.599657    
#> 101: 0.612558    1.004711    3.440715    0.347642    0.066264    0.009829    0.608515    
#> 102: 0.638072    1.008265    3.443544    0.360609    0.062951    0.009411    0.607715    
#> 103: 0.644466    1.000795    3.456605    0.347480    0.068680    0.008941    0.610652    
#> 104: 0.647010    0.993669    3.475534    0.380935    0.068161    0.009345    0.616228    
#> 105: 0.676885    0.975196    3.470959    0.366802    0.077386    0.009274    0.625188    
#> 106: 0.711182    0.974295    3.473983    0.408389    0.075574    0.008811    0.628692    
#> 107: 0.713068    0.982366    3.479473    0.387969    0.076870    0.009285    0.634211    
#> 108: 0.671545    0.978240    3.471798    0.368571    0.089171    0.009434    0.635918    
#> 109: 0.686708    0.974328    3.478983    0.384543    0.084712    0.008963    0.620828    
#> 110: 0.679690    0.959195    3.468865    0.376034    0.082125    0.008515    0.630529    
#> 111: 0.680984    0.970224    3.468745    0.357232    0.080509    0.008089    0.621434    
#> 112: 0.647839    0.963361    3.463457    0.339371    0.076484    0.007684    0.641779    
#> 113: 0.634616    0.987416    3.465848    0.346055    0.072660    0.007300    0.625172    
#> 114: 0.685207    0.982475    3.473761    0.328752    0.070293    0.007114    0.634774    
#> 115: 0.714562    0.969490    3.470228    0.387463    0.082603    0.006758    0.635349    
#> 116: 0.704632    0.969875    3.478000    0.389570    0.078473    0.007186    0.621309    
#> 117: 0.640085    1.010158    3.470260    0.370092    0.080589    0.008720    0.629478    
#> 118: 0.674316    0.985705    3.475432    0.351587    0.076559    0.008284    0.622188    
#> 119: 0.702220    0.986472    3.472217    0.379827    0.072731    0.009299    0.642761    
#> 120: 0.650173    0.977245    3.471270    0.362683    0.069095    0.008834    0.627083    
#> 121: 0.694510    1.012173    3.478543    0.344926    0.082921    0.010093    0.616608    
#> 122: 0.691204    0.973735    3.484084    0.353503    0.078775    0.011347    0.607350    
#> 123: 0.744156    0.999594    3.484586    0.385866    0.074836    0.010779    0.619602    
#> 124: 0.702082    1.002809    3.476257    0.366573    0.071094    0.012349    0.611542    
#> 125: 0.696116    0.961577    3.480882    0.348244    0.067540    0.012865    0.638007    
#> 126: 0.689556    0.991303    3.472595    0.337003    0.068041    0.012222    0.628815    
#> 127: 0.692599    0.994546    3.464759    0.384860    0.079044    0.011611    0.613575    
#> 128: 0.692594    0.996735    3.471452    0.450630    0.075091    0.011698    0.610262    
#> 129: 0.695119    0.995631    3.475186    0.428099    0.072214    0.012219    0.605975    
#> 130: 0.728343    0.999936    3.473252    0.424089    0.068603    0.013659    0.611316    
#> 131: 0.662685    0.959184    3.465127    0.402884    0.065173    0.016131    0.611243    
#> 132: 0.650648    0.976735    3.452891    0.382740    0.071161    0.015324    0.630010    
#> 133: 0.609191    0.990578    3.457205    0.373172    0.076799    0.014558    0.625849    
#> 134: 0.669999    0.987480    3.471825    0.417455    0.072959    0.013830    0.624450    
#> 135: 0.661685    0.985293    3.467366    0.399187    0.069311    0.013139    0.613784    
#> 136: 0.661935    0.975189    3.468810    0.406357    0.065846    0.012482    0.602057    
#> 137: 0.692257    0.976546    3.467254    0.473708    0.062554    0.011858    0.610040    
#> 138: 0.673291    0.997216    3.470493    0.450022    0.059426    0.011461    0.610860    
#> 139: 0.649356    0.992458    3.479930    0.427521    0.056455    0.013580    0.631692    
#> 140: 0.729333    1.000408    3.484168    0.452539    0.053632    0.014890    0.629638    
#> 141: 0.672050    0.970944    3.477035    0.429912    0.060908    0.014146    0.643146    
#> 142: 0.682903    0.957690    3.485272    0.408416    0.070418    0.013438    0.630907    
#> 143: 0.654002    0.973062    3.481597    0.387996    0.073102    0.012767    0.635879    
#> 144: 0.726973    0.979116    3.489342    0.421091    0.072116    0.012128    0.593975    
#> 145: 0.682047    0.978727    3.470007    0.400037    0.068510    0.011632    0.605849    
#> 146: 0.674426    0.986393    3.480189    0.444406    0.069190    0.012230    0.608339    
#> 147: 0.623618    0.983510    3.462803    0.422185    0.066676    0.014379    0.595649    
#> 148: 0.627650    0.992321    3.469039    0.401076    0.063342    0.013660    0.602609    
#> 149: 0.624246    0.974715    3.473110    0.381022    0.073380    0.012977    0.609942    
#> 150: 0.641925    0.984020    3.458369    0.373836    0.082139    0.012328    0.624884    
#> 151: 0.611673    1.013633    3.452048    0.355145    0.080284    0.011712    0.610816    
#> 152: 0.614451    1.003492    3.461313    0.365110    0.073828    0.011108    0.611073    
#> 153: 0.622592    0.994655    3.467860    0.322472    0.077494    0.008658    0.629476    
#> 154: 0.662250    0.997131    3.466685    0.344321    0.068084    0.009363    0.627883    
#> 155: 0.634765    0.976844    3.463447    0.344905    0.064662    0.007983    0.624021    
#> 156: 0.657999    0.974392    3.475095    0.328274    0.063897    0.007326    0.628233    
#> 157: 0.670376    0.970888    3.482661    0.321037    0.072733    0.008305    0.633873    
#> 158: 0.689083    0.984600    3.476019    0.340203    0.081511    0.006698    0.609380    
#> 159: 0.658273    0.987057    3.477171    0.362193    0.073296    0.006052    0.609488    
#> 160: 0.685230    0.957379    3.484916    0.355653    0.088584    0.006530    0.619199    
#> 161: 0.702522    0.974095    3.476718    0.380454    0.085016    0.007302    0.623819    
#> 162: 0.681708    0.979147    3.473346    0.363559    0.064568    0.007274    0.639050    
#> 163: 0.680735    0.970797    3.470462    0.395428    0.069663    0.007490    0.628339    
#> 164: 0.664358    1.001049    3.470551    0.344809    0.059944    0.007811    0.631352    
#> 165: 0.677159    0.989025    3.475778    0.349382    0.067291    0.009942    0.623925    
#> 166: 0.706848    1.003669    3.475536    0.337678    0.078557    0.008656    0.628586    
#> 167: 0.678991    1.000661    3.479352    0.305552    0.075094    0.007484    0.637751    
#> 168: 0.681732    1.013875    3.470982    0.389047    0.067062    0.009831    0.630826    
#> 169: 0.679642    1.031962    3.464170    0.384171    0.072749    0.009324    0.642030    
#> 170: 0.685927    0.999740    3.471573    0.423295    0.071124    0.009379    0.625518    
#> 171: 0.651627    1.007024    3.468661    0.368295    0.078513    0.009384    0.612797    
#> 172: 0.621811    1.001080    3.464604    0.319028    0.071635    0.009107    0.611510    
#> 173: 0.626559    1.012584    3.452988    0.311704    0.066219    0.009212    0.610816    
#> 174: 0.634566    1.000318    3.457607    0.347739    0.074427    0.007498    0.608806    
#> 175: 0.629846    0.998206    3.452173    0.386456    0.078580    0.009129    0.626705    
#> 176: 0.679284    1.017658    3.462585    0.495299    0.064003    0.009120    0.607797    
#> 177: 0.652025    0.993160    3.465534    0.390648    0.075598    0.007756    0.614552    
#> 178: 0.666144    0.994922    3.468572    0.361690    0.067697    0.008946    0.607088    
#> 179: 0.673800    0.997166    3.463495    0.378452    0.057205    0.009732    0.618038    
#> 180: 0.667891    0.987479    3.468808    0.406306    0.059968    0.009922    0.612428    
#> 181: 0.657965    0.994543    3.447613    0.401869    0.064598    0.008033    0.628296    
#> 182: 0.649123    1.017981    3.443141    0.383105    0.064981    0.009497    0.641383    
#> 183: 0.660638    1.024846    3.451907    0.382332    0.065057    0.009523    0.649829    
#> 184: 0.655835    0.998666    3.455219    0.334603    0.064915    0.008138    0.629335    
#> 185: 0.614558    1.012022    3.450722    0.320617    0.073421    0.008131    0.622218    
#> 186: 0.610689    1.020844    3.460788    0.313062    0.077727    0.008744    0.627714    
#> 187: 0.660500    0.985344    3.472504    0.340709    0.069957    0.008972    0.608673    
#> 188: 0.639010    1.014907    3.463388    0.355054    0.067433    0.009088    0.622835    
#> 189: 0.673832    1.008877    3.469891    0.424269    0.068557    0.012503    0.611663    
#> 190: 0.693622    0.997534    3.470290    0.521614    0.065665    0.012994    0.598568    
#> 191: 0.654785    1.000622    3.460527    0.394561    0.058055    0.010777    0.607645    
#> 192: 0.634918    1.002558    3.460017    0.409539    0.059325    0.010095    0.602940    
#> 193: 0.682270    1.026359    3.465194    0.364285    0.057593    0.008869    0.613795    
#> 194: 0.646456    0.999757    3.463757    0.329345    0.074861    0.010056    0.625831    
#> 195: 0.625198    0.999309    3.461720    0.300479    0.067718    0.007049    0.637576    
#> 196: 0.639763    0.974111    3.473203    0.278372    0.072979    0.006309    0.648583    
#> 197: 0.619273    0.975561    3.484033    0.256251    0.065792    0.008178    0.650537    
#> 198: 0.662319    0.969629    3.478322    0.249179    0.062103    0.008635    0.655825    
#> 199: 0.639803    0.965653    3.474042    0.300764    0.071317    0.006980    0.630665    
#> 200: 0.680435    0.956242    3.482499    0.343063    0.085298    0.007224    0.638722    
#> 201: 0.677737    0.962658    3.484784    0.351336    0.083751    0.007983    0.629944    
#> 202: 0.680013    0.968063    3.482989    0.349571    0.084411    0.008026    0.632197    
#> 203: 0.687880    0.966425    3.481222    0.342343    0.085593    0.007891    0.632234    
#> 204: 0.689355    0.966970    3.481119    0.350856    0.085736    0.007884    0.631594    
#> 205: 0.692622    0.972619    3.481218    0.356413    0.085576    0.007948    0.632282    
#> 206: 0.693215    0.976552    3.482026    0.360546    0.083692    0.008113    0.632637    
#> 207: 0.692068    0.978188    3.480662    0.370658    0.081607    0.008159    0.631087    
#> 208: 0.692517    0.978367    3.479598    0.379429    0.080195    0.008184    0.628413    
#> 209: 0.694887    0.976348    3.478780    0.380171    0.077379    0.008505    0.628427    
#> 210: 0.696903    0.975855    3.478324    0.381242    0.076980    0.008718    0.625974    
#> 211: 0.695847    0.978315    3.478182    0.380809    0.075247    0.008863    0.625485    
#> 212: 0.696221    0.979221    3.477698    0.382687    0.074653    0.008963    0.625970    
#> 213: 0.697984    0.978631    3.477729    0.390964    0.074481    0.009213    0.626350    
#> 214: 0.700754    0.978351    3.478041    0.395020    0.073976    0.009417    0.625400    
#> 215: 0.700418    0.978959    3.477990    0.398894    0.073428    0.009485    0.624340    
#> 216: 0.699868    0.978965    3.478074    0.397001    0.073594    0.009394    0.625747    
#> 217: 0.697579    0.980270    3.477633    0.392573    0.073176    0.009257    0.626132    
#> 218: 0.695299    0.981036    3.476990    0.388805    0.073394    0.009210    0.625935    
#> 219: 0.694441    0.980939    3.476096    0.388348    0.073253    0.009177    0.626067    
#> 220: 0.693489    0.981328    3.475972    0.392378    0.073165    0.009166    0.625973    
#> 221: 0.691472    0.981910    3.475499    0.393495    0.073063    0.009100    0.625125    
#> 222: 0.689760    0.982601    3.474746    0.395041    0.072938    0.009081    0.624827    
#> 223: 0.689611    0.982722    3.474412    0.395228    0.072728    0.009053    0.624021    
#> 224: 0.690360    0.983352    3.474430    0.393509    0.072122    0.009061    0.623804    
#> 225: 0.689437    0.982210    3.474615    0.392008    0.071971    0.009037    0.623858    
#> 226: 0.688959    0.980704    3.474393    0.388427    0.071904    0.008971    0.624128    
#> 227: 0.689333    0.980187    3.474870    0.385312    0.071802    0.008867    0.624331    
#> 228: 0.689124    0.980578    3.474753    0.382023    0.072039    0.008777    0.624164    
#> 229: 0.688081    0.980170    3.474711    0.379675    0.072304    0.008717    0.623762    
#> 230: 0.688687    0.979922    3.474675    0.377516    0.072288    0.008657    0.623585    
#> 231: 0.688271    0.980204    3.474717    0.377807    0.072174    0.008585    0.623570    
#> 232: 0.688050    0.979323    3.475179    0.377155    0.072041    0.008540    0.624226    
#> 233: 0.687914    0.978215    3.475449    0.374990    0.071808    0.008532    0.624502    
#> 234: 0.688201    0.977733    3.475744    0.376237    0.071850    0.008514    0.623955    
#> 235: 0.688826    0.977669    3.475791    0.376502    0.071806    0.008475    0.624079    
#> 236: 0.688553    0.978240    3.475737    0.375442    0.071808    0.008465    0.624496    
#> 237: 0.688777    0.978111    3.475831    0.375759    0.072100    0.008503    0.624947    
#> 238: 0.689768    0.978078    3.475960    0.376810    0.072461    0.008554    0.625436    
#> 239: 0.689548    0.978381    3.475945    0.376784    0.072387    0.008620    0.625270    
#> 240: 0.689837    0.978184    3.476228    0.376325    0.072447    0.008657    0.624687    
#> 241: 0.690788    0.977467    3.476517    0.376209    0.072111    0.008674    0.624529    
#> 242: 0.690887    0.976705    3.476574    0.376724    0.072255    0.008696    0.625191    
#> 243: 0.690332    0.976752    3.476530    0.375910    0.072163    0.008723    0.625545    
#> 244: 0.689424    0.976856    3.476576    0.376533    0.072208    0.008738    0.625837    
#> 245: 0.689127    0.976381    3.476594    0.377116    0.072213    0.008733    0.626028    
#> 246: 0.688757    0.976247    3.476579    0.376969    0.072203    0.008800    0.625809    
#> 247: 0.688035    0.976134    3.476561    0.376732    0.072095    0.008842    0.626017    
#> 248: 0.687195    0.976696    3.476340    0.376723    0.072128    0.008893    0.625588    
#> 249: 0.686412    0.977107    3.476133    0.377871    0.071999    0.008994    0.625127    
#> 250: 0.685739    0.977747    3.475895    0.377908    0.071894    0.009077    0.624938    
#> 251: 0.685259    0.978538    3.475763    0.378046    0.071705    0.009128    0.624922    
#> 252: 0.685568    0.978920    3.475816    0.378348    0.071743    0.009179    0.625051    
#> 253: 0.685385    0.979470    3.475734    0.379206    0.072058    0.009197    0.625141    
#> 254: 0.685815    0.979751    3.475810    0.379993    0.072196    0.009235    0.625231    
#> 255: 0.685418    0.980186    3.475839    0.379940    0.072365    0.009284    0.625100    
#> 256: 0.685334    0.980261    3.475763    0.379772    0.072616    0.009325    0.624995    
#> 257: 0.684992    0.980210    3.475688    0.379012    0.072706    0.009378    0.624849    
#> 258: 0.684356    0.980063    3.475581    0.377972    0.072701    0.009378    0.624861    
#> 259: 0.684127    0.980098    3.475531    0.377778    0.072716    0.009345    0.624646    
#> 260: 0.683605    0.980511    3.475511    0.376816    0.072795    0.009305    0.624423    
#> 261: 0.683166    0.980551    3.475627    0.376238    0.072840    0.009280    0.624283    
#> 262: 0.683092    0.980750    3.475741    0.375506    0.072823    0.009258    0.624069    
#> 263: 0.682946    0.981185    3.475640    0.375416    0.073015    0.009288    0.624098    
#> 264: 0.682415    0.981430    3.475629    0.375214    0.073314    0.009288    0.624294    
#> 265: 0.681986    0.981557    3.475473    0.374471    0.073457    0.009327    0.624141    
#> 266: 0.681242    0.981833    3.475275    0.373455    0.073456    0.009365    0.624240    
#> 267: 0.681039    0.982081    3.475281    0.374661    0.073488    0.009383    0.624256    
#> 268: 0.681253    0.981804    3.475232    0.376122    0.073593    0.009388    0.623962    
#> 269: 0.681930    0.981474    3.475304    0.376298    0.073686    0.009418    0.623909    
#> 270: 0.682005    0.981433    3.475263    0.376524    0.073728    0.009418    0.623636    
#> 271: 0.681966    0.981396    3.475125    0.376590    0.073881    0.009419    0.623665    
#> 272: 0.681770    0.981368    3.474983    0.377016    0.073986    0.009400    0.623791    
#> 273: 0.681505    0.981758    3.474960    0.377297    0.074101    0.009420    0.623926    
#> 274: 0.681341    0.981976    3.474999    0.377592    0.074220    0.009409    0.624048    
#> 275: 0.680978    0.982181    3.474837    0.377438    0.074458    0.009409    0.624091    
#> 276: 0.680757    0.982460    3.474918    0.377545    0.074460    0.009414    0.624028    
#> 277: 0.680673    0.982611    3.475051    0.377806    0.074520    0.009411    0.624024    
#> 278: 0.680852    0.982583    3.475146    0.378264    0.074607    0.009405    0.624040    
#> 279: 0.680820    0.982646    3.475180    0.378819    0.074683    0.009433    0.624186    
#> 280: 0.681005    0.982809    3.475165    0.379016    0.074704    0.009442    0.624111    
#> 281: 0.680762    0.982997    3.475204    0.378450    0.074711    0.009446    0.624237    
#> 282: 0.680988    0.983094    3.475284    0.377851    0.074696    0.009458    0.624272    
#> 283: 0.681193    0.983115    3.475358    0.378285    0.074576    0.009497    0.624650    
#> 284: 0.681235    0.982974    3.475412    0.378119    0.074465    0.009526    0.624763    
#> 285: 0.681319    0.983062    3.475390    0.377880    0.074476    0.009559    0.624848    
#> 286: 0.681388    0.983150    3.475321    0.378483    0.074252    0.009576    0.624913    
#> 287: 0.681109    0.983396    3.475222    0.378171    0.074259    0.009568    0.624767    
#> 288: 0.681472    0.983396    3.475203    0.378114    0.074114    0.009569    0.624835    
#> 289: 0.681840    0.983347    3.475219    0.377638    0.074120    0.009557    0.624823    
#> 290: 0.681776    0.983425    3.475157    0.377297    0.074257    0.009537    0.624898    
#> 291: 0.682058    0.983635    3.475218    0.376871    0.074227    0.009524    0.624689    
#> 292: 0.681819    0.983703    3.475183    0.376030    0.074136    0.009515    0.624659    
#> 293: 0.681616    0.983620    3.475070    0.376018    0.074084    0.009525    0.624493    
#> 294: 0.681540    0.983687    3.474936    0.376370    0.073942    0.009530    0.624366    
#> 295: 0.681536    0.983413    3.474886    0.376388    0.073893    0.009509    0.624217    
#> 296: 0.681497    0.983304    3.474819    0.376421    0.073873    0.009494    0.624192    
#> 297: 0.681602    0.983558    3.474708    0.376915    0.073835    0.009477    0.624235    
#> 298: 0.681174    0.983734    3.474577    0.377064    0.073840    0.009470    0.623975    
#> 299: 0.680852    0.983885    3.474455    0.376835    0.073717    0.009488    0.623667    
#> 300: 0.680687    0.983759    3.474437    0.376658    0.073593    0.009498    0.623475    
#> 301: 0.680711    0.983658    3.474343    0.376141    0.073524    0.009504    0.623513    
#> 302: 0.680586    0.983782    3.474321    0.375734    0.073474    0.009492    0.623401    
#> 303: 0.680364    0.983946    3.474247    0.375380    0.073449    0.009481    0.623245    
#> 304: 0.680310    0.984232    3.474125    0.375428    0.073530    0.009473    0.623189    
#> 305: 0.680004    0.983994    3.474074    0.375394    0.073474    0.009462    0.623051    
#> 306: 0.679411    0.983925    3.473925    0.374838    0.073561    0.009476    0.622923    
#> 307: 0.678981    0.983995    3.473778    0.374792    0.073612    0.009503    0.622887    
#> 308: 0.678261    0.984079    3.473606    0.374448    0.073588    0.009509    0.622846    
#> 309: 0.678075    0.984051    3.473487    0.374505    0.073587    0.009529    0.622868    
#> 310: 0.678029    0.984163    3.473290    0.374685    0.073479    0.009523    0.622882    
#> 311: 0.677677    0.984230    3.473206    0.374521    0.073402    0.009521    0.622942    
#> 312: 0.676988    0.984340    3.473017    0.373586    0.073355    0.009524    0.623022    
#> 313: 0.676504    0.984413    3.472879    0.373286    0.073336    0.009526    0.623068    
#> 314: 0.676144    0.984752    3.472758    0.373377    0.073397    0.009529    0.623012    
#> 315: 0.675739    0.985066    3.472699    0.373273    0.073436    0.009527    0.623010    
#> 316: 0.675700    0.985127    3.472613    0.373509    0.073495    0.009516    0.622859    
#> 317: 0.675750    0.985180    3.472602    0.373812    0.073536    0.009514    0.622715    
#> 318: 0.675709    0.985262    3.472509    0.374019    0.073620    0.009512    0.622607    
#> 319: 0.675719    0.985266    3.472567    0.374328    0.073707    0.009530    0.622559    
#> 320: 0.675195    0.985293    3.472502    0.373818    0.073812    0.009556    0.622501    
#> 321: 0.674842    0.985408    3.472334    0.373497    0.073731    0.009566    0.622626    
#> 322: 0.674852    0.985515    3.472178    0.373380    0.073724    0.009564    0.622479    
#> 323: 0.674591    0.985574    3.472071    0.373367    0.073695    0.009558    0.622429    
#> 324: 0.674432    0.985770    3.472029    0.373924    0.073723    0.009557    0.622275    
#> 325: 0.674468    0.986087    3.471959    0.374261    0.073650    0.009553    0.622161    
#> 326: 0.674569    0.986081    3.471902    0.374772    0.073573    0.009560    0.622055    
#> 327: 0.674767    0.986279    3.471907    0.375046    0.073482    0.009583    0.621977    
#> 328: 0.674916    0.986498    3.471914    0.375477    0.073458    0.009595    0.621851    
#> 329: 0.675018    0.986481    3.471946    0.375431    0.073468    0.009605    0.621747    
#> 330: 0.675009    0.986434    3.471929    0.375641    0.073470    0.009613    0.621624    
#> 331: 0.675228    0.986522    3.471979    0.375889    0.073445    0.009615    0.621455    
#> 332: 0.675438    0.986525    3.472054    0.375911    0.073436    0.009606    0.621496    
#> 333: 0.675407    0.986566    3.471984    0.375911    0.073349    0.009596    0.621507    
#> 334: 0.675256    0.986419    3.471916    0.375785    0.073254    0.009601    0.621523    
#> 335: 0.675024    0.986523    3.471818    0.375658    0.073205    0.009614    0.621423    
#> 336: 0.674608    0.986844    3.471698    0.375705    0.073174    0.009638    0.621368    
#> 337: 0.674267    0.987155    3.471586    0.375852    0.073196    0.009665    0.621306    
#> 338: 0.674229    0.987324    3.471552    0.375790    0.073149    0.009670    0.621253    
#> 339: 0.673895    0.987508    3.471462    0.375523    0.073141    0.009673    0.621153    
#> 340: 0.673978    0.987351    3.471456    0.375840    0.073136    0.009675    0.621071    
#> 341: 0.674269    0.987331    3.471468    0.376286    0.073168    0.009682    0.621045    
#> 342: 0.674239    0.987186    3.471486    0.376519    0.073214    0.009677    0.621060    
#> 343: 0.673803    0.987186    3.471435    0.376819    0.073228    0.009673    0.621051    
#> 344: 0.673937    0.987260    3.471396    0.377346    0.073298    0.009671    0.621061    
#> 345: 0.673928    0.987294    3.471414    0.377432    0.073391    0.009669    0.621126    
#> 346: 0.673800    0.987345    3.471343    0.377392    0.073386    0.009662    0.621072    
#> 347: 0.673749    0.987399    3.471227    0.377497    0.073306    0.009669    0.621038    
#> 348: 0.673430    0.987500    3.471118    0.377376    0.073282    0.009668    0.621018    
#> 349: 0.673233    0.987612    3.471022    0.377445    0.073252    0.009676    0.621034    
#> 350: 0.673000    0.987647    3.470945    0.377558    0.073237    0.009680    0.621055    
#> 351: 0.673025    0.987755    3.470850    0.378038    0.073272    0.009683    0.621030    
#> 352: 0.672761    0.987847    3.470807    0.378206    0.073290    0.009694    0.621055    
#> 353: 0.672584    0.988053    3.470759    0.378269    0.073331    0.009711    0.621044    
#> 354: 0.672667    0.988130    3.470680    0.378216    0.073266    0.009733    0.620947    
#> 355: 0.672988    0.988004    3.470697    0.378031    0.073229    0.009730    0.621046    
#> 356: 0.672982    0.987937    3.470717    0.378427    0.073324    0.009719    0.621112    
#> 357: 0.673060    0.987978    3.470702    0.378380    0.073354    0.009712    0.621053    
#> 358: 0.673212    0.988058    3.470683    0.378698    0.073335    0.009716    0.620962    
#> 359: 0.673270    0.988305    3.470621    0.378876    0.073398    0.009721    0.620890    
#> 360: 0.673114    0.988330    3.470521    0.378683    0.073390    0.009732    0.620822    
#> 361: 0.672942    0.988418    3.470445    0.378920    0.073365    0.009736    0.620760    
#> 362: 0.672987    0.988448    3.470373    0.378837    0.073343    0.009733    0.620660    
#> 363: 0.672834    0.988340    3.470368    0.378708    0.073414    0.009733    0.620552    
#> 364: 0.672856    0.988341    3.470384    0.378456    0.073380    0.009731    0.620504    
#> 365: 0.672899    0.988213    3.470454    0.378491    0.073373    0.009746    0.620378    
#> 366: 0.672938    0.988136    3.470438    0.378367    0.073333    0.009754    0.620333    
#> 367: 0.672987    0.988173    3.470417    0.378329    0.073369    0.009747    0.620247    
#> 368: 0.673300    0.988267    3.470426    0.378882    0.073289    0.009740    0.620170    
#> 369: 0.673303    0.988205    3.470469    0.378897    0.073217    0.009731    0.620292    
#> 370: 0.673337    0.988193    3.470518    0.378577    0.073123    0.009734    0.620318    
#> 371: 0.673474    0.988173    3.470517    0.378286    0.073085    0.009738    0.620304    
#> 372: 0.673535    0.988237    3.470502    0.378418    0.073115    0.009745    0.620191    
#> 373: 0.673301    0.988325    3.470420    0.378501    0.073108    0.009751    0.620143    
#> 374: 0.673228    0.988348    3.470360    0.378478    0.073082    0.009761    0.620092    
#> 375: 0.673008    0.988467    3.470272    0.378402    0.073032    0.009764    0.620112    
#> 376: 0.672906    0.988575    3.470202    0.377975    0.073055    0.009754    0.620112    
#> 377: 0.672630    0.988651    3.470160    0.377830    0.073122    0.009748    0.620074    
#> 378: 0.672415    0.988631    3.470086    0.377613    0.073126    0.009745    0.620051    
#> 379: 0.672014    0.988500    3.470060    0.377396    0.073098    0.009746    0.620082    
#> 380: 0.671838    0.988513    3.470014    0.377135    0.073129    0.009760    0.620002    
#> 381: 0.671552    0.988558    3.469933    0.377123    0.073194    0.009751    0.619986    
#> 382: 0.671460    0.988505    3.469935    0.377221    0.073178    0.009745    0.619922    
#> 383: 0.671598    0.988481    3.469958    0.377285    0.073178    0.009745    0.619866    
#> 384: 0.671531    0.988456    3.469993    0.377078    0.073202    0.009751    0.619863    
#> 385: 0.671580    0.988456    3.470024    0.377015    0.073190    0.009755    0.619853    
#> 386: 0.671791    0.988533    3.470099    0.376862    0.073144    0.009753    0.619912    
#> 387: 0.671960    0.988588    3.470181    0.376801    0.073092    0.009762    0.619885    
#> 388: 0.672064    0.988431    3.470278    0.376908    0.073080    0.009762    0.619863    
#> 389: 0.672340    0.988168    3.470383    0.376908    0.073029    0.009757    0.619938    
#> 390: 0.672456    0.988162    3.470411    0.376881    0.073038    0.009742    0.619966    
#> 391: 0.672519    0.988074    3.470440    0.376930    0.073014    0.009751    0.619899    
#> 392: 0.672516    0.988043    3.470475    0.376856    0.073037    0.009751    0.619870    
#> 393: 0.672512    0.987895    3.470497    0.376762    0.073085    0.009742    0.619894    
#> 394: 0.672642    0.987823    3.470529    0.376854    0.073104    0.009737    0.619839    
#> 395: 0.672914    0.987862    3.470552    0.377274    0.073080    0.009728    0.619834    
#> 396: 0.673079    0.987941    3.470546    0.377677    0.073049    0.009726    0.619741    
#> 397: 0.673097    0.987893    3.470569    0.377726    0.073005    0.009725    0.619688    
#> 398: 0.673202    0.987839    3.470594    0.377845    0.072968    0.009726    0.619735    
#> 399: 0.673212    0.987748    3.470654    0.377748    0.072916    0.009727    0.619793    
#> 400: 0.673335    0.987782    3.470713    0.377543    0.072945    0.009730    0.619825    
#> 401: 0.673497    0.987845    3.470772    0.377714    0.072957    0.009740    0.619863    
#> 402: 0.673566    0.987842    3.470797    0.377698    0.073010    0.009760    0.619877    
#> 403: 0.673845    0.987777    3.470836    0.377891    0.073014    0.009777    0.619884    
#> 404: 0.673881    0.987731    3.470807    0.377918    0.073011    0.009802    0.619824    
#> 405: 0.673779    0.987762    3.470805    0.378010    0.072985    0.009828    0.619813    
#> 406: 0.673783    0.987867    3.470767    0.378252    0.072963    0.009852    0.619838    
#> 407: 0.673825    0.987928    3.470749    0.378573    0.072969    0.009865    0.619832    
#> 408: 0.673750    0.987990    3.470715    0.378315    0.072965    0.009874    0.619766    
#> 409: 0.673578    0.987913    3.470665    0.378188    0.072899    0.009886    0.619770    
#> 410: 0.673346    0.987939    3.470566    0.378180    0.072868    0.009891    0.619817    
#> 411: 0.673202    0.987856    3.470512    0.377808    0.072863    0.009887    0.619883    
#> 412: 0.673138    0.987963    3.470450    0.377925    0.072913    0.009888    0.619889    
#> 413: 0.673058    0.988071    3.470343    0.378308    0.072959    0.009889    0.619892    
#> 414: 0.672686    0.988149    3.470279    0.378127    0.072990    0.009890    0.619846    
#> 415: 0.672551    0.988210    3.470197    0.378079    0.073024    0.009897    0.619818    
#> 416: 0.672544    0.988303    3.470148    0.378432    0.073021    0.009902    0.619722    
#> 417: 0.672369    0.988306    3.470089    0.378616    0.073007    0.009900    0.619722    
#> 418: 0.672155    0.988371    3.470061    0.378763    0.073030    0.009897    0.619666    
#> 419: 0.672174    0.988469    3.470041    0.378787    0.073001    0.009890    0.619711    
#> 420: 0.672193    0.988543    3.470018    0.378688    0.073024    0.009885    0.619723    
#> 421: 0.672193    0.988536    3.470063    0.378581    0.073044    0.009887    0.619638    
#> 422: 0.672351    0.988488    3.470087    0.378590    0.073031    0.009900    0.619614    
#> 423: 0.672552    0.988413    3.470128    0.378590    0.073056    0.009904    0.619608    
#> 424: 0.672541    0.988313    3.470121    0.378426    0.073054    0.009898    0.619627    
#> 425: 0.672620    0.988392    3.470083    0.378670    0.073012    0.009897    0.619661    
#> 426: 0.672660    0.988522    3.470037    0.378994    0.072986    0.009891    0.619694    
#> 427: 0.672581    0.988552    3.470018    0.379021    0.072985    0.009886    0.619633    
#> 428: 0.672458    0.988637    3.469994    0.379066    0.073023    0.009881    0.619676    
#> 429: 0.672406    0.988669    3.469970    0.378905    0.073067    0.009869    0.619697    
#> 430: 0.672346    0.988762    3.469938    0.378756    0.073109    0.009872    0.619681    
#> 431: 0.672293    0.988735    3.469912    0.378727    0.073105    0.009871    0.619651    
#> 432: 0.672267    0.988755    3.469928    0.378874    0.073098    0.009871    0.619584    
#> 433: 0.672314    0.988816    3.469934    0.379128    0.073066    0.009876    0.619613    
#> 434: 0.672146    0.988802    3.469918    0.379279    0.073038    0.009872    0.619623    
#> 435: 0.672195    0.988803    3.469883    0.379424    0.073025    0.009867    0.619578    
#> 436: 0.672159    0.988723    3.469885    0.379376    0.072953    0.009857    0.619643    
#> 437: 0.672069    0.988718    3.469842    0.379222    0.072926    0.009857    0.619620    
#> 438: 0.672014    0.988838    3.469822    0.379196    0.072922    0.009851    0.619574    
#> 439: 0.671997    0.988906    3.469812    0.379107    0.072879    0.009843    0.619576    
#> 440: 0.671876    0.988962    3.469798    0.379189    0.072865    0.009836    0.619531    
#> 441: 0.671831    0.988918    3.469796    0.379258    0.072875    0.009833    0.619448    
#> 442: 0.671722    0.988913    3.469793    0.379022    0.072879    0.009834    0.619353    
#> 443: 0.671605    0.988974    3.469762    0.378826    0.072839    0.009837    0.619333    
#> 444: 0.671391    0.989025    3.469685    0.378776    0.072813    0.009844    0.619283    
#> 445: 0.671219    0.989100    3.469606    0.378738    0.072780    0.009851    0.619328    
#> 446: 0.670972    0.989208    3.469548    0.378578    0.072733    0.009848    0.619332    
#> 447: 0.670841    0.989268    3.469517    0.378612    0.072704    0.009847    0.619312    
#> 448: 0.670668    0.989251    3.469529    0.378531    0.072707    0.009853    0.619234    
#> 449: 0.670690    0.989251    3.469589    0.378550    0.072668    0.009849    0.619259    
#> 450: 0.670669    0.989231    3.469573    0.378728    0.072653    0.009849    0.619303    
#> 451: 0.670761    0.989263    3.469555    0.379043    0.072673    0.009842    0.619359    
#> 452: 0.670707    0.989303    3.469528    0.379119    0.072703    0.009847    0.619334    
#> 453: 0.670672    0.989323    3.469522    0.378897    0.072717    0.009849    0.619313    
#> 454: 0.670684    0.989403    3.469497    0.379058    0.072704    0.009852    0.619254    
#> 455: 0.670734    0.989476    3.469489    0.379303    0.072718    0.009855    0.619200    
#> 456: 0.670701    0.989489    3.469453    0.379300    0.072701    0.009866    0.619147    
#> 457: 0.670551    0.989454    3.469447    0.379197    0.072717    0.009861    0.619080    
#> 458: 0.670433    0.989537    3.469449    0.379140    0.072719    0.009857    0.619017    
#> 459: 0.670109    0.989682    3.469407    0.378943    0.072737    0.009844    0.619008    
#> 460: 0.669920    0.989785    3.469342    0.378758    0.072734    0.009838    0.619000    
#> 461: 0.669799    0.989889    3.469332    0.378668    0.072749    0.009836    0.619004    
#> 462: 0.669650    0.989937    3.469333    0.378617    0.072690    0.009834    0.619047    
#> 463: 0.669655    0.989979    3.469356    0.378492    0.072641    0.009826    0.619085    
#> 464: 0.669771    0.989991    3.469373    0.378480    0.072612    0.009824    0.619048    
#> 465: 0.669781    0.989887    3.469394    0.378357    0.072600    0.009821    0.619055    
#> 466: 0.669912    0.989898    3.469405    0.378267    0.072571    0.009808    0.619052    
#> 467: 0.669853    0.989873    3.469422    0.378325    0.072539    0.009800    0.618966    
#> 468: 0.669993    0.989849    3.469470    0.378491    0.072507    0.009797    0.618940    
#> 469: 0.670106    0.989882    3.469530    0.378480    0.072472    0.009804    0.618928    
#> 470: 0.670134    0.989883    3.469522    0.378659    0.072410    0.009809    0.618898    
#> 471: 0.670098    0.989898    3.469486    0.378488    0.072375    0.009802    0.618903    
#> 472: 0.670000    0.989886    3.469476    0.378535    0.072342    0.009799    0.618898    
#> 473: 0.669855    0.989901    3.469452    0.378480    0.072307    0.009803    0.618912    
#> 474: 0.669779    0.989886    3.469433    0.378513    0.072270    0.009813    0.618954    
#> 475: 0.669808    0.989983    3.469415    0.378329    0.072276    0.009822    0.619039    
#> 476: 0.669794    0.989970    3.469391    0.378270    0.072239    0.009826    0.619138    
#> 477: 0.669810    0.989954    3.469429    0.378190    0.072224    0.009833    0.619103    
#> 478: 0.669782    0.989918    3.469447    0.378133    0.072182    0.009834    0.619097    
#> 479: 0.669837    0.989946    3.469470    0.378071    0.072137    0.009833    0.619094    
#> 480: 0.669850    0.989958    3.469489    0.378224    0.072102    0.009833    0.619142    
#> 481: 0.669926    0.989992    3.469520    0.378225    0.072085    0.009832    0.619119    
#> 482: 0.670071    0.989992    3.469488    0.378374    0.072076    0.009828    0.619105    
#> 483: 0.669966    0.989962    3.469475    0.378192    0.072057    0.009822    0.619088    
#> 484: 0.669907    0.989879    3.469465    0.378078    0.072075    0.009822    0.619113    
#> 485: 0.669939    0.989893    3.469465    0.377994    0.072112    0.009827    0.619105    
#> 486: 0.670010    0.989944    3.469494    0.377885    0.072096    0.009826    0.619120    
#> 487: 0.670205    0.990003    3.469554    0.377828    0.072073    0.009824    0.619093    
#> 488: 0.670273    0.989983    3.469607    0.377762    0.072058    0.009820    0.619116    
#> 489: 0.670324    0.989962    3.469640    0.377682    0.072067    0.009818    0.619103    
#> 490: 0.670355    0.989954    3.469662    0.377576    0.072056    0.009815    0.619116    
#> 491: 0.670432    0.990006    3.469730    0.377424    0.072023    0.009818    0.619106    
#> 492: 0.670389    0.990040    3.469719    0.377259    0.071999    0.009818    0.619138    
#> 493: 0.670278    0.990063    3.469698    0.377431    0.072018    0.009828    0.619128    
#> 494: 0.670352    0.990134    3.469654    0.377468    0.071981    0.009837    0.619106    
#> 495: 0.670438    0.990115    3.469685    0.377339    0.071964    0.009846    0.619056    
#> 496: 0.670662    0.990126    3.469701    0.377518    0.071930    0.009846    0.619051    
#> 497: 0.670567    0.990146    3.469695    0.377438    0.071954    0.009845    0.619031    
#> 498: 0.670460    0.990151    3.469661    0.377355    0.071926    0.009843    0.619021    
#> 499: 0.670355    0.990210    3.469624    0.377346    0.071952    0.009838    0.618994    
#> 500: 0.670342    0.990173    3.469606    0.377321    0.071962    0.009830    0.618974    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.306005    0.983632    3.452080    0.392401    0.079373    0.016800    1.767513    
#> 002: 0.290132    1.067053    3.485944    0.372781    0.075404    0.017543    1.117407    
#> 003: 0.437335    1.043990    3.535351    0.354142    0.071634    0.017282    0.869255    
#> 004: 0.410086    1.066817    3.544757    0.336435    0.068052    0.017391    0.766277    
#> 005: 0.473866    1.076665    3.538147    0.319613    0.064650    0.018041    0.720759    
#> 006: 0.424477    1.083198    3.525887    0.303633    0.077920    0.021434    0.662908    
#> 007: 0.379610    1.112796    3.516228    0.288451    0.074024    0.025060    0.664657    
#> 008: 0.376197    1.109424    3.516653    0.274029    0.070323    0.030732    0.662740    
#> 009: 0.357974    1.114767    3.498237    0.260327    0.076696    0.029195    0.657356    
#> 010: 0.349546    1.113193    3.502133    0.247311    0.072861    0.027735    0.679519    
#> 011: 0.404467    1.125503    3.506447    0.234945    0.069218    0.026349    0.687936    
#> 012: 0.382447    1.112495    3.493688    0.223198    0.065757    0.025031    0.654857    
#> 013: 0.336125    1.118064    3.492406    0.212038    0.070152    0.023780    0.663247    
#> 014: 0.380931    1.115271    3.504859    0.229515    0.080004    0.022591    0.672585    
#> 015: 0.426662    1.119861    3.521450    0.236756    0.076004    0.025957    0.651891    
#> 016: 0.391999    1.125483    3.516971    0.224918    0.072204    0.029066    0.660785    
#> 017: 0.425515    1.122062    3.529310    0.213673    0.074366    0.027613    0.641686    
#> 018: 0.433616    1.108740    3.509496    0.252151    0.070648    0.028283    0.646678    
#> 019: 0.367247    1.109842    3.508647    0.256476    0.072211    0.026869    0.637074    
#> 020: 0.412660    1.115080    3.518237    0.243652    0.068600    0.027220    0.647582    
#> 021: 0.430156    1.101712    3.528047    0.231470    0.065170    0.029530    0.634102    
#> 022: 0.430400    1.100382    3.533765    0.219896    0.061912    0.030616    0.658709    
#> 023: 0.473148    1.098722    3.536742    0.208901    0.066034    0.029085    0.681305    
#> 024: 0.470637    1.123073    3.531302    0.198456    0.062732    0.027631    0.683302    
#> 025: 0.442891    1.110233    3.534592    0.188533    0.070187    0.026249    0.673060    
#> 026: 0.410080    1.139574    3.513386    0.196281    0.074710    0.025317    0.660152    
#> 027: 0.381669    1.130279    3.515474    0.186467    0.070975    0.024683    0.684112    
#> 028: 0.432581    1.113395    3.531549    0.191286    0.070598    0.023640    0.651468    
#> 029: 0.398541    1.107801    3.511423    0.181721    0.074502    0.022558    0.681672    
#> 030: 0.413475    1.116648    3.515082    0.172635    0.070777    0.022018    0.669700    
#> 031: 0.392540    1.100859    3.520910    0.164004    0.071471    0.023233    0.670850    
#> 032: 0.415956    1.066285    3.547773    0.158677    0.067897    0.022071    0.673125    
#> 033: 0.409042    1.078279    3.537016    0.171234    0.072971    0.023699    0.670840    
#> 034: 0.464084    1.086108    3.534875    0.178310    0.070888    0.022514    0.668698    
#> 035: 0.410136    1.071364    3.517169    0.169394    0.073266    0.021388    0.656568    
#> 036: 0.389355    1.110119    3.525620    0.160925    0.073828    0.021577    0.641429    
#> 037: 0.393879    1.114545    3.511234    0.152878    0.070136    0.022735    0.665669    
#> 038: 0.431251    1.118932    3.515576    0.159708    0.066629    0.024396    0.657213    
#> 039: 0.441053    1.096674    3.529385    0.181492    0.063586    0.023961    0.647108    
#> 040: 0.396360    1.108734    3.538038    0.172418    0.060407    0.022763    0.666346    
#> 041: 0.399094    1.105142    3.531803    0.163797    0.061376    0.027471    0.657158    
#> 042: 0.426924    1.091290    3.526879    0.155607    0.058307    0.027253    0.651038    
#> 043: 0.408537    1.106072    3.517677    0.147827    0.055392    0.027687    0.661242    
#> 044: 0.365274    1.115795    3.512163    0.140435    0.052622    0.030294    0.653201    
#> 045: 0.366302    1.125652    3.504651    0.149239    0.049991    0.028780    0.671126    
#> 046: 0.401027    1.136172    3.503175    0.173069    0.051236    0.029133    0.660222    
#> 047: 0.374650    1.126120    3.506764    0.182607    0.060999    0.030546    0.647862    
#> 048: 0.395599    1.122203    3.518078    0.192736    0.067926    0.029019    0.663309    
#> 049: 0.380392    1.112774    3.515392    0.183099    0.065822    0.027568    0.672376    
#> 050: 0.462873    1.085096    3.529616    0.173944    0.066766    0.026189    0.676980    
#> 051: 0.432624    1.095689    3.526858    0.175465    0.063427    0.030604    0.670426    
#> 052: 0.431450    1.101405    3.544815    0.178452    0.067133    0.029073    0.657986    
#> 053: 0.445353    1.098499    3.534023    0.178694    0.081597    0.027620    0.658132    
#> 054: 0.389366    1.096781    3.526784    0.192526    0.097198    0.026239    0.671185    
#> 055: 0.396150    1.095162    3.538259    0.197731    0.092991    0.027826    0.668886    
#> 056: 0.393159    1.090395    3.533480    0.190699    0.088341    0.029744    0.662490    
#> 057: 0.400551    1.089169    3.534586    0.181164    0.083924    0.028257    0.671690    
#> 058: 0.427798    1.085313    3.533017    0.181531    0.079728    0.026844    0.678913    
#> 059: 0.449311    1.033609    3.546769    0.172455    0.075741    0.029689    0.696492    
#> 060: 0.464136    1.022608    3.555964    0.165500    0.085376    0.028205    0.698098    
#> 061: 0.455934    1.068226    3.545179    0.173374    0.082437    0.026795    0.672156    
#> 062: 0.447745    1.079259    3.552123    0.164705    0.091914    0.025455    0.695930    
#> 063: 0.486040    1.055123    3.542725    0.168996    0.087318    0.024182    0.689402    
#> 064: 0.468136    1.066894    3.553189    0.182658    0.090343    0.022973    0.686325    
#> 065: 0.469494    1.055336    3.543077    0.178983    0.086932    0.021824    0.687346    
#> 066: 0.449229    1.086741    3.541032    0.178859    0.082585    0.020733    0.652867    
#> 067: 0.434197    1.076653    3.527451    0.186439    0.078456    0.023470    0.641383    
#> 068: 0.395732    1.093870    3.526395    0.188338    0.090951    0.022296    0.654143    
#> 069: 0.380815    1.106319    3.515033    0.178921    0.086403    0.021182    0.668613    
#> 070: 0.400116    1.119499    3.519907    0.181781    0.082083    0.022804    0.668239    
#> 071: 0.395260    1.137410    3.498730    0.184932    0.077979    0.021664    0.681141    
#> 072: 0.342177    1.114622    3.497831    0.175685    0.074232    0.020581    0.680562    
#> 073: 0.386063    1.131347    3.517177    0.166901    0.074174    0.022289    0.680826    
#> 074: 0.347010    1.133626    3.503195    0.164109    0.081979    0.021175    0.667037    
#> 075: 0.384580    1.115069    3.530739    0.162501    0.077880    0.020116    0.674568    
#> 076: 0.433890    1.099102    3.537394    0.172171    0.073986    0.019110    0.674571    
#> 077: 0.458018    1.092980    3.534343    0.163562    0.070287    0.027237    0.653845    
#> 078: 0.445605    1.100515    3.534142    0.155384    0.068789    0.025875    0.667913    
#> 079: 0.436924    1.111588    3.531586    0.180514    0.074558    0.024581    0.665624    
#> 080: 0.444583    1.099388    3.542159    0.171489    0.091714    0.025108    0.680793    
#> 081: 0.428289    1.109823    3.537930    0.162914    0.087128    0.026427    0.680231    
#> 082: 0.403747    1.089661    3.527363    0.154768    0.082772    0.025105    0.680390    
#> 083: 0.432517    1.112728    3.534592    0.167119    0.078633    0.023850    0.665475    
#> 084: 0.416661    1.110808    3.524188    0.158763    0.074702    0.029532    0.653301    
#> 085: 0.404442    1.108483    3.525296    0.183956    0.072591    0.028056    0.666140    
#> 086: 0.406291    1.107379    3.516475    0.196083    0.068961    0.026653    0.658228    
#> 087: 0.399358    1.109650    3.518661    0.189673    0.065513    0.026612    0.657411    
#> 088: 0.363851    1.106361    3.513526    0.231204    0.062238    0.025282    0.672502    
#> 089: 0.419509    1.123091    3.514475    0.228522    0.076260    0.024946    0.658665    
#> 090: 0.371510    1.122947    3.500294    0.217096    0.076760    0.023699    0.663874    
#> 091: 0.364679    1.112907    3.491895    0.206241    0.072922    0.023817    0.666398    
#> 092: 0.347044    1.124897    3.490688    0.208275    0.069276    0.026362    0.669997    
#> 093: 0.370355    1.108095    3.506316    0.205755    0.065812    0.027917    0.668591    
#> 094: 0.336897    1.139242    3.490251    0.204615    0.085231    0.026521    0.647960    
#> 095: 0.362383    1.134050    3.507360    0.204636    0.080970    0.025195    0.648137    
#> 096: 0.356420    1.122992    3.495130    0.195420    0.083616    0.023935    0.639518    
#> 097: 0.399241    1.137979    3.499842    0.185649    0.080474    0.022738    0.651280    
#> 098: 0.394742    1.149690    3.507389    0.199252    0.076450    0.030446    0.662303    
#> 099: 0.373499    1.140355    3.487426    0.217106    0.082952    0.028924    0.646429    
#> 100: 0.377443    1.129014    3.499005    0.206250    0.084317    0.027478    0.649227    
#> 101: 0.343141    1.121590    3.490220    0.195938    0.080101    0.026104    0.658830    
#> 102: 0.332054    1.158497    3.476135    0.193803    0.076096    0.024798    0.684317    
#> 103: 0.373620    1.142094    3.496034    0.197449    0.072291    0.023559    0.663919    
#> 104: 0.390740    1.145786    3.514870    0.187577    0.072455    0.022381    0.652340    
#> 105: 0.402021    1.120352    3.519513    0.178198    0.081554    0.023792    0.652013    
#> 106: 0.411344    1.105336    3.502013    0.180724    0.077476    0.022602    0.658964    
#> 107: 0.425829    1.118154    3.521750    0.196905    0.073602    0.022240    0.662999    
#> 108: 0.399075    1.098762    3.519544    0.195808    0.077311    0.021128    0.674562    
#> 109: 0.390355    1.097513    3.522391    0.186018    0.076475    0.020072    0.667004    
#> 110: 0.406775    1.087984    3.512865    0.190219    0.084466    0.019068    0.648057    
#> 111: 0.412611    1.096693    3.518407    0.180708    0.083458    0.018115    0.652394    
#> 112: 0.411977    1.089022    3.518708    0.199332    0.079286    0.018171    0.676020    
#> 113: 0.405088    1.109491    3.517434    0.198663    0.075321    0.019347    0.662478    
#> 114: 0.413959    1.117369    3.532153    0.188730    0.073429    0.019673    0.658165    
#> 115: 0.439609    1.083161    3.524097    0.179294    0.075843    0.022316    0.683036    
#> 116: 0.422588    1.115015    3.516635    0.170329    0.072051    0.026925    0.677741    
#> 117: 0.412774    1.129179    3.526972    0.173978    0.069359    0.025578    0.684125    
#> 118: 0.460150    1.108095    3.536819    0.193688    0.065891    0.024300    0.667957    
#> 119: 0.419954    1.122159    3.519718    0.190041    0.066427    0.024790    0.659773    
#> 120: 0.412996    1.094896    3.522177    0.202760    0.070126    0.023550    0.645314    
#> 121: 0.425600    1.132547    3.524713    0.192622    0.072424    0.022880    0.668097    
#> 122: 0.440159    1.099923    3.532377    0.182991    0.068803    0.022873    0.651536    
#> 123: 0.490954    1.109922    3.529644    0.186376    0.065363    0.021985    0.655475    
#> 124: 0.453603    1.138033    3.527267    0.184045    0.062094    0.024660    0.651842    
#> 125: 0.480127    1.112191    3.530887    0.174843    0.069765    0.025019    0.658010    
#> 126: 0.415831    1.115700    3.525738    0.182723    0.066277    0.030802    0.668009    
#> 127: 0.394441    1.115695    3.512602    0.173586    0.062963    0.029262    0.672369    
#> 128: 0.383306    1.114199    3.520545    0.164907    0.059815    0.027799    0.673528    
#> 129: 0.429855    1.123479    3.537415    0.188073    0.071438    0.026629    0.663664    
#> 130: 0.453702    1.112480    3.525855    0.180894    0.067867    0.028393    0.660847    
#> 131: 0.442075    1.108471    3.519441    0.171849    0.069704    0.027997    0.644251    
#> 132: 0.404306    1.110640    3.511403    0.182054    0.066764    0.027349    0.654964    
#> 133: 0.402393    1.096314    3.515959    0.179606    0.075510    0.025982    0.649710    
#> 134: 0.414572    1.086959    3.533699    0.170625    0.073547    0.024683    0.659566    
#> 135: 0.420055    1.076978    3.545001    0.162094    0.086718    0.023449    0.663893    
#> 136: 0.440433    1.071922    3.535533    0.153989    0.082382    0.026300    0.664723    
#> 137: 0.463260    1.066099    3.546957    0.146290    0.078263    0.032799    0.664484    
#> 138: 0.450476    1.068746    3.546718    0.139457    0.074350    0.031159    0.657045    
#> 139: 0.456913    1.091251    3.553532    0.164922    0.070633    0.029601    0.670376    
#> 140: 0.449835    1.085748    3.548174    0.156676    0.076572    0.028121    0.682455    
#> 141: 0.422712    1.072616    3.547406    0.148842    0.072743    0.026715    0.666214    
#> 142: 0.439919    1.057517    3.554547    0.154382    0.078423    0.025379    0.677898    
#> 143: 0.419343    1.074153    3.537487    0.176728    0.087174    0.024110    0.664221    
#> 144: 0.477353    1.087588    3.548255    0.199291    0.082815    0.022905    0.644561    
#> 145: 0.428414    1.107284    3.527243    0.189539    0.078675    0.022610    0.642373    
#> 146: 0.391540    1.097919    3.534063    0.193201    0.074741    0.024244    0.661646    
#> 147: 0.374427    1.090149    3.525238    0.192061    0.071004    0.033301    0.631003    
#> 148: 0.398676    1.117391    3.521677    0.182457    0.067454    0.031636    0.657133    
#> 149: 0.404807    1.106524    3.524466    0.175342    0.066200    0.032101    0.660793    
#> 150: 0.444174    1.084308    3.522803    0.195202    0.067179    0.030496    0.649170    
#> 151: 0.403742    1.092629    3.526297    0.214597    0.066966    0.028972    0.642110    
#> 152: 0.396817    1.097443    3.526992    0.190164    0.057802    0.028756    0.645189    
#> 153: 0.422466    1.105227    3.523889    0.195804    0.064968    0.028713    0.670338    
#> 154: 0.428832    1.121837    3.521442    0.194101    0.067174    0.029103    0.659530    
#> 155: 0.388615    1.112778    3.518586    0.198261    0.071102    0.022143    0.657526    
#> 156: 0.401797    1.105500    3.526074    0.203036    0.066695    0.027321    0.669382    
#> 157: 0.427669    1.103589    3.530190    0.188993    0.081065    0.026302    0.671744    
#> 158: 0.443418    1.115319    3.520323    0.188242    0.088424    0.022677    0.658486    
#> 159: 0.381210    1.108419    3.529577    0.150647    0.087314    0.023795    0.657969    
#> 160: 0.412077    1.082048    3.532048    0.163506    0.085993    0.024925    0.659239    
#> 161: 0.423813    1.102012    3.524137    0.134937    0.088504    0.023847    0.673735    
#> 162: 0.390700    1.127420    3.513930    0.145906    0.072408    0.023107    0.690283    
#> 163: 0.435198    1.112038    3.520464    0.154887    0.089858    0.023236    0.664207    
#> 164: 0.427670    1.108368    3.526530    0.147031    0.076314    0.023574    0.653579    
#> 165: 0.478778    1.092746    3.538944    0.155844    0.073711    0.030326    0.646248    
#> 166: 0.484026    1.119348    3.546409    0.145692    0.086577    0.027897    0.659958    
#> 167: 0.452023    1.105138    3.556918    0.138124    0.085498    0.025903    0.671360    
#> 168: 0.441980    1.110783    3.533967    0.148919    0.091327    0.022736    0.684796    
#> 169: 0.424299    1.140784    3.521983    0.125821    0.090610    0.021042    0.697625    
#> 170: 0.393537    1.127600    3.514235    0.124343    0.099822    0.023367    0.685498    
#> 171: 0.377625    1.114313    3.516841    0.138473    0.086434    0.022022    0.668020    
#> 172: 0.394607    1.124283    3.505154    0.182180    0.087556    0.020092    0.669528    
#> 173: 0.366913    1.148058    3.489451    0.169591    0.080834    0.016132    0.664275    
#> 174: 0.394333    1.128492    3.512629    0.174567    0.070928    0.018477    0.660224    
#> 175: 0.382842    1.137540    3.498897    0.217573    0.077805    0.018106    0.665690    
#> 176: 0.396853    1.130513    3.507001    0.179172    0.073309    0.018533    0.652772    
#> 177: 0.399709    1.125327    3.506078    0.174025    0.081883    0.015445    0.657992    
#> 178: 0.385596    1.116173    3.501502    0.192086    0.073916    0.020759    0.643128    
#> 179: 0.424340    1.128912    3.517994    0.153931    0.065398    0.023461    0.655783    
#> 180: 0.413619    1.121275    3.523922    0.159341    0.068643    0.025112    0.654979    
#> 181: 0.416677    1.110681    3.507667    0.171266    0.064149    0.027071    0.649778    
#> 182: 0.375333    1.129252    3.491232    0.181141    0.068899    0.026447    0.671315    
#> 183: 0.373248    1.140784    3.502891    0.173600    0.061528    0.028258    0.663164    
#> 184: 0.378218    1.111533    3.510766    0.167375    0.056545    0.029210    0.649697    
#> 185: 0.368612    1.141772    3.500578    0.191282    0.067839    0.028188    0.650772    
#> 186: 0.388372    1.147176    3.504311    0.179200    0.070859    0.028398    0.648814    
#> 187: 0.395156    1.099337    3.524697    0.154818    0.061155    0.028248    0.648027    
#> 188: 0.407969    1.132065    3.525799    0.158956    0.067482    0.026026    0.668679    
#> 189: 0.438772    1.125209    3.531527    0.152223    0.076045    0.027026    0.673353    
#> 190: 0.412432    1.116153    3.536087    0.151406    0.064426    0.031518    0.648095    
#> 191: 0.389220    1.117617    3.513089    0.166184    0.058202    0.027109    0.650943    
#> 192: 0.379213    1.122068    3.523574    0.140788    0.043567    0.025010    0.657659    
#> 193: 0.411584    1.127182    3.525103    0.136864    0.048056    0.022595    0.669364    
#> 194: 0.405873    1.109768    3.526683    0.134997    0.067303    0.024526    0.679964    
#> 195: 0.391759    1.096202    3.521847    0.150447    0.060604    0.023025    0.677569    
#> 196: 0.391741    1.091308    3.527955    0.182409    0.068071    0.022721    0.679118    
#> 197: 0.382549    1.102115    3.537228    0.209519    0.073058    0.024061    0.673919    
#> 198: 0.415742    1.118485    3.516983    0.169193    0.069854    0.024107    0.656168    
#> 199: 0.374298    1.130201    3.502148    0.170762    0.075354    0.021455    0.664140    
#> 200: 0.378335    1.119716    3.508379    0.163280    0.082521    0.018701    0.667622    
#> 201: 0.381948    1.113712    3.519304    0.154073    0.080740    0.019771    0.670657    
#> 202: 0.397261    1.109124    3.519406    0.164925    0.077097    0.020321    0.668078    
#> 203: 0.406774    1.108853    3.516899    0.177294    0.074562    0.020595    0.666426    
#> 204: 0.408789    1.104550    3.518237    0.180220    0.072995    0.020995    0.664484    
#> 205: 0.407183    1.108105    3.518753    0.183816    0.073501    0.020666    0.667415    
#> 206: 0.409616    1.111055    3.519200    0.189950    0.074070    0.020796    0.668253    
#> 207: 0.406257    1.110304    3.516990    0.189180    0.074658    0.020746    0.668424    
#> 208: 0.405519    1.109334    3.517545    0.188457    0.074475    0.020723    0.667162    
#> 209: 0.407873    1.107242    3.517213    0.186310    0.073331    0.020611    0.666867    
#> 210: 0.410569    1.105724    3.518040    0.182438    0.073053    0.020450    0.665877    
#> 211: 0.412876    1.106784    3.519347    0.181999    0.072520    0.020650    0.664313    
#> 212: 0.415880    1.107025    3.520294    0.182443    0.071343    0.020813    0.663626    
#> 213: 0.419505    1.105061    3.521891    0.182572    0.070335    0.021432    0.663950    
#> 214: 0.422446    1.103436    3.523411    0.181402    0.070012    0.021924    0.664145    
#> 215: 0.424254    1.102505    3.524791    0.179680    0.069533    0.022246    0.665000    
#> 216: 0.426798    1.099371    3.525636    0.177569    0.069783    0.022651    0.667127    
#> 217: 0.427173    1.099397    3.526380    0.176792    0.069273    0.022641    0.667280    
#> 218: 0.427853    1.100538    3.526264    0.175663    0.069377    0.022511    0.666367    
#> 219: 0.426929    1.099881    3.525287    0.173680    0.069343    0.022493    0.667230    
#> 220: 0.425562    1.100473    3.524952    0.172253    0.069135    0.022645    0.667025    
#> 221: 0.423085    1.100679    3.524530    0.170561    0.069126    0.022639    0.666360    
#> 222: 0.421595    1.100922    3.524136    0.169724    0.069380    0.022820    0.666134    
#> 223: 0.422677    1.101073    3.524299    0.169610    0.069567    0.022976    0.665857    
#> 224: 0.424494    1.101818    3.524424    0.170007    0.069925    0.022895    0.665772    
#> 225: 0.425125    1.100662    3.525134    0.169619    0.069977    0.022924    0.666096    
#> 226: 0.425313    1.099795    3.525098    0.169762    0.069934    0.022734    0.666356    
#> 227: 0.424878    1.099928    3.525186    0.169250    0.070051    0.022606    0.666936    
#> 228: 0.423215    1.100540    3.524516    0.169877    0.070234    0.022509    0.666876    
#> 229: 0.422643    1.100247    3.524322    0.170457    0.070363    0.022355    0.666182    
#> 230: 0.423494    1.099806    3.524168    0.171815    0.070212    0.022245    0.666173    
#> 231: 0.423442    1.100311    3.524448    0.172624    0.070406    0.022205    0.665672    
#> 232: 0.422500    1.100175    3.524756    0.172665    0.069988    0.022251    0.665480    
#> 233: 0.422365    1.099546    3.524967    0.173158    0.069883    0.022343    0.665501    
#> 234: 0.422277    1.099712    3.524961    0.173037    0.070176    0.022366    0.665027    
#> 235: 0.422428    1.100025    3.525072    0.172902    0.069923    0.022376    0.664713    
#> 236: 0.422044    1.100325    3.525200    0.173881    0.069837    0.022399    0.664425    
#> 237: 0.422352    1.100160    3.525209    0.174921    0.069683    0.022481    0.664757    
#> 238: 0.422987    1.100033    3.525327    0.174752    0.069822    0.022562    0.665180    
#> 239: 0.422917    1.100506    3.525213    0.174833    0.069950    0.022638    0.665024    
#> 240: 0.422554    1.100960    3.525058    0.175200    0.070158    0.022711    0.664421    
#> 241: 0.422003    1.100726    3.524967    0.175588    0.069987    0.022779    0.663982    
#> 242: 0.420675    1.100807    3.524495    0.176563    0.069864    0.022796    0.664053    
#> 243: 0.419032    1.101417    3.524056    0.177721    0.069701    0.022775    0.663962    
#> 244: 0.418101    1.101377    3.524000    0.178193    0.069449    0.022917    0.664015    
#> 245: 0.418568    1.100994    3.524216    0.179140    0.069245    0.023058    0.664269    
#> 246: 0.418549    1.100783    3.524224    0.179329    0.068677    0.023139    0.664725    
#> 247: 0.418566    1.100732    3.524297    0.180468    0.068551    0.023206    0.664905    
#> 248: 0.418891    1.101358    3.524146    0.181083    0.068562    0.023200    0.664732    
#> 249: 0.418966    1.101102    3.524311    0.180523    0.068497    0.023275    0.664905    
#> 250: 0.419931    1.101268    3.524587    0.181669    0.068417    0.023460    0.664813    
#> 251: 0.420276    1.101715    3.524879    0.182699    0.068352    0.023530    0.664700    
#> 252: 0.420665    1.102013    3.525235    0.182801    0.068446    0.023528    0.664764    
#> 253: 0.420892    1.102179    3.525366    0.182810    0.068529    0.023602    0.664807    
#> 254: 0.421266    1.102373    3.525398    0.182208    0.068467    0.023559    0.664680    
#> 255: 0.420973    1.102784    3.525208    0.182223    0.068412    0.023600    0.664750    
#> 256: 0.420366    1.102667    3.524878    0.182323    0.068361    0.023609    0.664683    
#> 257: 0.419288    1.102483    3.524567    0.181772    0.068307    0.023590    0.664702    
#> 258: 0.419396    1.102162    3.524537    0.182558    0.068137    0.023549    0.664759    
#> 259: 0.419450    1.101845    3.524705    0.182411    0.068129    0.023588    0.664861    
#> 260: 0.419661    1.101651    3.524876    0.182295    0.068122    0.023589    0.664649    
#> 261: 0.420243    1.101413    3.525164    0.181853    0.068063    0.023659    0.664686    
#> 262: 0.421035    1.101384    3.525461    0.181782    0.067924    0.023741    0.664802    
#> 263: 0.421106    1.101620    3.525562    0.181304    0.067975    0.023849    0.664701    
#> 264: 0.421121    1.101663    3.525684    0.181048    0.067842    0.023919    0.665165    
#> 265: 0.421283    1.101217    3.525914    0.180741    0.067668    0.023973    0.665410    
#> 266: 0.421546    1.101331    3.525932    0.180456    0.067521    0.023990    0.665383    
#> 267: 0.421849    1.101386    3.526177    0.179711    0.067660    0.024055    0.665295    
#> 268: 0.422388    1.101295    3.526257    0.179299    0.067815    0.024074    0.665266    
#> 269: 0.423174    1.101274    3.526394    0.179322    0.068049    0.024073    0.665124    
#> 270: 0.424051    1.101434    3.526519    0.179605    0.068112    0.024031    0.665124    
#> 271: 0.424644    1.101351    3.526526    0.179457    0.068223    0.024062    0.665271    
#> 272: 0.424885    1.100976    3.526475    0.179221    0.068241    0.024071    0.665696    
#> 273: 0.424463    1.101199    3.526381    0.178886    0.068107    0.024089    0.666021    
#> 274: 0.423960    1.101489    3.526389    0.178609    0.067930    0.024135    0.665993    
#> 275: 0.424070    1.101717    3.526302    0.178784    0.067787    0.024146    0.665933    
#> 276: 0.423992    1.101947    3.526511    0.178957    0.067585    0.024214    0.665994    
#> 277: 0.423825    1.102034    3.526791    0.178724    0.067523    0.024220    0.666085    
#> 278: 0.423527    1.102082    3.526855    0.178111    0.067579    0.024189    0.666119    
#> 279: 0.423058    1.102065    3.526793    0.177569    0.067807    0.024209    0.666108    
#> 280: 0.423032    1.102407    3.526745    0.177059    0.067782    0.024194    0.665848    
#> 281: 0.422605    1.102651    3.526663    0.177069    0.067669    0.024189    0.665787    
#> 282: 0.422431    1.102834    3.526768    0.177325    0.067623    0.024262    0.665669    
#> 283: 0.422387    1.102955    3.526921    0.177304    0.067613    0.024371    0.665830    
#> 284: 0.422379    1.102730    3.527009    0.177070    0.067546    0.024406    0.665872    
#> 285: 0.422659    1.102768    3.527002    0.177189    0.067632    0.024415    0.665875    
#> 286: 0.423117    1.102895    3.527043    0.177313    0.067475    0.024498    0.665999    
#> 287: 0.423517    1.102910    3.527127    0.177334    0.067388    0.024581    0.666075    
#> 288: 0.424157    1.102500    3.527397    0.177349    0.067302    0.024616    0.666258    
#> 289: 0.424974    1.102157    3.527675    0.177526    0.067262    0.024634    0.666161    
#> 290: 0.425115    1.101934    3.527854    0.177380    0.067312    0.024580    0.666099    
#> 291: 0.425242    1.102029    3.528029    0.176977    0.067275    0.024576    0.665867    
#> 292: 0.425083    1.102045    3.527967    0.176815    0.067232    0.024574    0.665770    
#> 293: 0.424992    1.102050    3.527951    0.176674    0.067242    0.024574    0.665587    
#> 294: 0.424672    1.102055    3.527791    0.176670    0.067215    0.024569    0.665433    
#> 295: 0.424700    1.101660    3.527812    0.176504    0.067212    0.024595    0.665275    
#> 296: 0.424405    1.101573    3.527663    0.176232    0.067049    0.024597    0.665197    
#> 297: 0.424248    1.101800    3.527551    0.176349    0.066977    0.024610    0.665068    
#> 298: 0.423799    1.101987    3.527293    0.176374    0.066921    0.024587    0.664955    
#> 299: 0.423492    1.102321    3.527072    0.176545    0.066897    0.024557    0.664774    
#> 300: 0.423234    1.102433    3.526919    0.176569    0.066858    0.024537    0.664736    
#> 301: 0.423246    1.102427    3.526746    0.176594    0.066777    0.024522    0.664913    
#> 302: 0.423348    1.102578    3.526723    0.176737    0.066835    0.024492    0.664785    
#> 303: 0.423186    1.102761    3.526656    0.176895    0.066821    0.024502    0.664542    
#> 304: 0.423451    1.102915    3.526601    0.177052    0.066803    0.024513    0.664455    
#> 305: 0.423309    1.102762    3.526485    0.177080    0.066892    0.024526    0.664262    
#> 306: 0.422970    1.102648    3.526303    0.177494    0.066920    0.024490    0.664212    
#> 307: 0.422544    1.102789    3.526131    0.177825    0.067017    0.024468    0.664225    
#> 308: 0.422142    1.102859    3.525966    0.178163    0.067100    0.024456    0.664238    
#> 309: 0.422488    1.102579    3.525941    0.178483    0.066959    0.024451    0.664572    
#> 310: 0.422600    1.102451    3.525786    0.178584    0.066878    0.024442    0.664709    
#> 311: 0.422823    1.102298    3.525905    0.178836    0.066687    0.024514    0.664592    
#> 312: 0.423117    1.102187    3.525988    0.179070    0.066517    0.024562    0.664463    
#> 313: 0.423134    1.101944    3.525969    0.179306    0.066499    0.024592    0.664470    
#> 314: 0.423046    1.101984    3.525971    0.179297    0.066438    0.024625    0.664365    
#> 315: 0.422682    1.102128    3.525898    0.179240    0.066406    0.024669    0.664280    
#> 316: 0.422630    1.102312    3.525737    0.179476    0.066601    0.024658    0.664183    
#> 317: 0.422747    1.102456    3.525761    0.179473    0.066847    0.024638    0.664196    
#> 318: 0.422817    1.102718    3.525634    0.179238    0.066965    0.024648    0.664119    
#> 319: 0.422633    1.102727    3.525592    0.179009    0.067016    0.024660    0.664218    
#> 320: 0.422246    1.102755    3.525438    0.179021    0.067102    0.024646    0.664246    
#> 321: 0.422081    1.102867    3.525328    0.178994    0.067179    0.024602    0.664338    
#> 322: 0.422005    1.102780    3.525258    0.178836    0.067265    0.024587    0.664230    
#> 323: 0.421679    1.102731    3.525291    0.178724    0.067222    0.024600    0.664167    
#> 324: 0.421656    1.102834    3.525311    0.178486    0.067157    0.024583    0.664156    
#> 325: 0.421459    1.103059    3.525196    0.178364    0.067136    0.024550    0.664129    
#> 326: 0.421297    1.103130    3.525148    0.178214    0.067161    0.024500    0.664022    
#> 327: 0.421282    1.103287    3.525159    0.178176    0.067238    0.024458    0.664065    
#> 328: 0.421279    1.103332    3.525140    0.178086    0.067293    0.024398    0.663962    
#> 329: 0.421365    1.103492    3.525112    0.177937    0.067373    0.024340    0.663852    
#> 330: 0.421266    1.103462    3.525134    0.178131    0.067345    0.024337    0.663749    
#> 331: 0.421259    1.103580    3.525121    0.177976    0.067233    0.024356    0.663737    
#> 332: 0.421276    1.103693    3.525208    0.177866    0.067131    0.024391    0.663839    
#> 333: 0.421108    1.103821    3.525178    0.177983    0.067079    0.024427    0.663760    
#> 334: 0.420779    1.103711    3.525003    0.178129    0.067077    0.024406    0.663792    
#> 335: 0.420535    1.103777    3.524885    0.178145    0.067083    0.024427    0.663687    
#> 336: 0.420284    1.103993    3.524795    0.178198    0.067086    0.024420    0.663757    
#> 337: 0.420053    1.104291    3.524617    0.178161    0.067069    0.024408    0.663764    
#> 338: 0.420015    1.104324    3.524598    0.178032    0.066974    0.024401    0.663688    
#> 339: 0.419767    1.104377    3.524506    0.177929    0.066947    0.024390    0.663594    
#> 340: 0.419670    1.104304    3.524437    0.177961    0.067018    0.024374    0.663482    
#> 341: 0.419721    1.104215    3.524452    0.178035    0.067072    0.024367    0.663417    
#> 342: 0.419420    1.104102    3.524389    0.178142    0.067033    0.024373    0.663271    
#> 343: 0.419087    1.104148    3.524350    0.178550    0.067010    0.024356    0.663101    
#> 344: 0.419171    1.104133    3.524371    0.178898    0.067031    0.024367    0.662948    
#> 345: 0.419151    1.104187    3.524369    0.178985    0.067035    0.024371    0.662863    
#> 346: 0.419139    1.104286    3.524287    0.179115    0.067016    0.024372    0.662773    
#> 347: 0.419126    1.104288    3.524176    0.179004    0.067076    0.024388    0.662882    
#> 348: 0.418840    1.104373    3.524084    0.179089    0.067134    0.024376    0.662917    
#> 349: 0.418760    1.104313    3.524015    0.178994    0.067144    0.024360    0.662926    
#> 350: 0.418534    1.104249    3.523884    0.178851    0.067276    0.024319    0.662903    
#> 351: 0.418495    1.104495    3.523785    0.178764    0.067359    0.024296    0.662917    
#> 352: 0.418035    1.104670    3.523722    0.178746    0.067519    0.024251    0.663024    
#> 353: 0.417973    1.104793    3.523615    0.178762    0.067532    0.024251    0.663101    
#> 354: 0.417858    1.104817    3.523499    0.178691    0.067508    0.024284    0.663072    
#> 355: 0.418122    1.104771    3.523480    0.178503    0.067547    0.024292    0.662988    
#> 356: 0.418050    1.104663    3.523482    0.178522    0.067625    0.024296    0.663028    
#> 357: 0.418203    1.104708    3.523562    0.178410    0.067570    0.024317    0.662968    
#> 358: 0.418177    1.104665    3.523584    0.178230    0.067502    0.024364    0.662864    
#> 359: 0.418081    1.104736    3.523535    0.178119    0.067492    0.024370    0.662817    
#> 360: 0.417618    1.104787    3.523324    0.178410    0.067591    0.024342    0.662742    
#> 361: 0.417348    1.104907    3.523178    0.178653    0.067645    0.024333    0.662717    
#> 362: 0.417265    1.105046    3.523042    0.178715    0.067666    0.024312    0.662609    
#> 363: 0.417178    1.105082    3.522979    0.179030    0.067658    0.024305    0.662445    
#> 364: 0.417144    1.105258    3.522926    0.179369    0.067683    0.024311    0.662377    
#> 365: 0.416951    1.105301    3.522900    0.179537    0.067714    0.024319    0.662364    
#> 366: 0.416767    1.105474    3.522700    0.179607    0.067759    0.024344    0.662250    
#> 367: 0.416474    1.105675    3.522495    0.179479    0.067795    0.024331    0.662214    
#> 368: 0.416481    1.105897    3.522366    0.179501    0.067773    0.024343    0.662175    
#> 369: 0.416349    1.105971    3.522330    0.179535    0.067787    0.024317    0.662241    
#> 370: 0.416111    1.106057    3.522267    0.179645    0.067808    0.024320    0.662278    
#> 371: 0.415772    1.106260    3.522104    0.179669    0.067773    0.024294    0.662248    
#> 372: 0.415612    1.106358    3.522017    0.179686    0.067808    0.024275    0.662151    
#> 373: 0.415362    1.106461    3.521982    0.179635    0.067862    0.024260    0.662204    
#> 374: 0.415386    1.106572    3.521946    0.179394    0.067883    0.024261    0.662134    
#> 375: 0.415165    1.106610    3.521913    0.179241    0.067887    0.024255    0.662143    
#> 376: 0.414899    1.106650    3.521893    0.179097    0.067944    0.024235    0.662054    
#> 377: 0.414633    1.106751    3.521812    0.179027    0.068031    0.024222    0.662016    
#> 378: 0.414494    1.106779    3.521729    0.179095    0.068098    0.024218    0.662015    
#> 379: 0.414346    1.106742    3.521706    0.179053    0.068107    0.024209    0.661999    
#> 380: 0.414292    1.106674    3.521738    0.179119    0.068201    0.024192    0.661935    
#> 381: 0.414164    1.106586    3.521714    0.179247    0.068193    0.024159    0.661951    
#> 382: 0.414214    1.106511    3.521728    0.179113    0.068192    0.024172    0.661863    
#> 383: 0.414325    1.106509    3.521709    0.179042    0.068121    0.024171    0.661828    
#> 384: 0.414167    1.106609    3.521662    0.179036    0.068124    0.024165    0.661754    
#> 385: 0.414142    1.106659    3.521636    0.179114    0.068090    0.024195    0.661701    
#> 386: 0.414131    1.106901    3.521629    0.179187    0.068109    0.024219    0.661680    
#> 387: 0.414202    1.107084    3.521674    0.179207    0.068083    0.024253    0.661635    
#> 388: 0.414092    1.107136    3.521668    0.179261    0.068005    0.024291    0.661560    
#> 389: 0.413962    1.106995    3.521635    0.179316    0.067888    0.024328    0.661585    
#> 390: 0.413797    1.107065    3.521535    0.179560    0.067782    0.024345    0.661648    
#> 391: 0.413873    1.107012    3.521519    0.179583    0.067708    0.024362    0.661561    
#> 392: 0.413808    1.107040    3.521527    0.179605    0.067675    0.024345    0.661712    
#> 393: 0.413693    1.107121    3.521487    0.179606    0.067660    0.024327    0.661760    
#> 394: 0.413714    1.107241    3.521406    0.179552    0.067694    0.024342    0.661815    
#> 395: 0.413849    1.107349    3.521400    0.179594    0.067711    0.024342    0.661798    
#> 396: 0.413885    1.107362    3.521415    0.179568    0.067689    0.024358    0.661811    
#> 397: 0.413929    1.107231    3.521438    0.179489    0.067648    0.024385    0.661817    
#> 398: 0.413938    1.107075    3.521504    0.179546    0.067603    0.024408    0.661820    
#> 399: 0.414206    1.106936    3.521633    0.179599    0.067580    0.024419    0.661731    
#> 400: 0.414292    1.106924    3.521667    0.179631    0.067612    0.024421    0.661640    
#> 401: 0.414391    1.106999    3.521652    0.179473    0.067653    0.024428    0.661620    
#> 402: 0.414374    1.107071    3.521672    0.179413    0.067598    0.024455    0.661554    
#> 403: 0.414363    1.107052    3.521669    0.179253    0.067595    0.024472    0.661491    
#> 404: 0.414278    1.107021    3.521595    0.179124    0.067602    0.024463    0.661429    
#> 405: 0.414103    1.107080    3.521539    0.178974    0.067602    0.024456    0.661423    
#> 406: 0.413961    1.107129    3.521476    0.178931    0.067654    0.024455    0.661497    
#> 407: 0.413887    1.107252    3.521429    0.178954    0.067750    0.024416    0.661520    
#> 408: 0.413719    1.107303    3.521420    0.179025    0.067797    0.024402    0.661604    
#> 409: 0.413606    1.107286    3.521372    0.179024    0.067767    0.024381    0.661605    
#> 410: 0.413688    1.107365    3.521335    0.179104    0.067796    0.024357    0.661635    
#> 411: 0.413883    1.107215    3.521350    0.179219    0.067782    0.024347    0.661702    
#> 412: 0.413948    1.107253    3.521373    0.179045    0.067792    0.024344    0.661663    
#> 413: 0.414102    1.107250    3.521427    0.178993    0.067798    0.024333    0.661661    
#> 414: 0.414004    1.107162    3.521476    0.179067    0.067792    0.024332    0.661578    
#> 415: 0.414111    1.107055    3.521484    0.179014    0.067812    0.024332    0.661497    
#> 416: 0.414240    1.107106    3.521533    0.178935    0.067883    0.024339    0.661403    
#> 417: 0.414368    1.107081    3.521533    0.179069    0.067888    0.024324    0.661346    
#> 418: 0.414134    1.107111    3.521529    0.179114    0.067965    0.024294    0.661317    
#> 419: 0.413996    1.107294    3.521463    0.179074    0.067975    0.024284    0.661347    
#> 420: 0.414101    1.107349    3.521451    0.178932    0.067963    0.024262    0.661330    
#> 421: 0.414040    1.107345    3.521495    0.178818    0.068028    0.024243    0.661251    
#> 422: 0.414134    1.107257    3.521552    0.178896    0.068051    0.024238    0.661220    
#> 423: 0.414396    1.107174    3.521640    0.178850    0.068057    0.024237    0.661239    
#> 424: 0.414524    1.107099    3.521659    0.178840    0.068029    0.024217    0.661256    
#> 425: 0.414754    1.107047    3.521690    0.178917    0.067983    0.024211    0.661374    
#> 426: 0.414736    1.107023    3.521707    0.178990    0.067948    0.024185    0.661371    
#> 427: 0.414650    1.106965    3.521756    0.179103    0.067902    0.024168    0.661318    
#> 428: 0.414473    1.107051    3.521737    0.179061    0.067961    0.024153    0.661305    
#> 429: 0.414391    1.107063    3.521737    0.179004    0.067988    0.024147    0.661299    
#> 430: 0.414378    1.107087    3.521736    0.179017    0.067994    0.024156    0.661261    
#> 431: 0.414306    1.107026    3.521722    0.179146    0.067995    0.024149    0.661190    
#> 432: 0.414285    1.107051    3.521747    0.179275    0.067986    0.024155    0.661123    
#> 433: 0.414352    1.107061    3.521779    0.179262    0.067956    0.024155    0.661151    
#> 434: 0.414337    1.106925    3.521833    0.179194    0.067942    0.024167    0.661101    
#> 435: 0.414428    1.106838    3.521871    0.179091    0.067920    0.024172    0.661110    
#> 436: 0.414473    1.106771    3.521933    0.179159    0.067836    0.024181    0.661113    
#> 437: 0.414605    1.106720    3.521968    0.179131    0.067801    0.024186    0.661129    
#> 438: 0.414585    1.106940    3.521962    0.179071    0.067819    0.024175    0.661159    
#> 439: 0.414600    1.107119    3.521943    0.178941    0.067816    0.024150    0.661155    
#> 440: 0.414488    1.107269    3.521946    0.178776    0.067825    0.024136    0.661158    
#> 441: 0.414477    1.107306    3.521973    0.178721    0.067894    0.024116    0.661090    
#> 442: 0.414411    1.107375    3.522002    0.178703    0.067965    0.024096    0.661016    
#> 443: 0.414311    1.107447    3.521964    0.178717    0.067922    0.024103    0.661042    
#> 444: 0.414280    1.107492    3.521915    0.178606    0.067918    0.024116    0.661030    
#> 445: 0.414172    1.107574    3.521904    0.178581    0.067888    0.024120    0.661099    
#> 446: 0.414011    1.107636    3.521856    0.178601    0.067843    0.024124    0.661034    
#> 447: 0.414114    1.107628    3.521913    0.178541    0.067780    0.024166    0.661005    
#> 448: 0.414129    1.107571    3.521970    0.178424    0.067765    0.024191    0.660979    
#> 449: 0.414206    1.107593    3.522093    0.178183    0.067754    0.024214    0.661002    
#> 450: 0.414219    1.107537    3.522146    0.178023    0.067705    0.024255    0.661036    
#> 451: 0.414188    1.107508    3.522136    0.177839    0.067760    0.024263    0.661075    
#> 452: 0.414128    1.107550    3.522119    0.177761    0.067795    0.024265    0.661091    
#> 453: 0.414072    1.107534    3.522086    0.177705    0.067778    0.024259    0.661055    
#> 454: 0.413959    1.107705    3.522023    0.177584    0.067783    0.024265    0.661093    
#> 455: 0.413865    1.107817    3.521958    0.177675    0.067811    0.024258    0.661156    
#> 456: 0.413639    1.107884    3.521910    0.177804    0.067826    0.024262    0.661157    
#> 457: 0.413661    1.107873    3.521914    0.177813    0.067838    0.024251    0.661071    
#> 458: 0.413666    1.107986    3.521944    0.177748    0.067835    0.024260    0.661091    
#> 459: 0.413705    1.108130    3.521966    0.177624    0.067865    0.024263    0.661087    
#> 460: 0.413737    1.108144    3.521991    0.177452    0.067832    0.024267    0.661098    
#> 461: 0.413697    1.108082    3.522034    0.177213    0.067830    0.024288    0.661069    
#> 462: 0.413738    1.108052    3.522097    0.177006    0.067796    0.024305    0.661072    
#> 463: 0.413915    1.108035    3.522229    0.176887    0.067735    0.024326    0.661137    
#> 464: 0.414148    1.108004    3.522293    0.176830    0.067694    0.024335    0.661080    
#> 465: 0.414205    1.107835    3.522368    0.176810    0.067666    0.024351    0.661117    
#> 466: 0.414319    1.107799    3.522367    0.176796    0.067635    0.024351    0.661126    
#> 467: 0.414389    1.107716    3.522429    0.176805    0.067623    0.024360    0.661043    
#> 468: 0.414626    1.107727    3.522507    0.176830    0.067608    0.024367    0.661080    
#> 469: 0.414649    1.107832    3.522545    0.176840    0.067591    0.024382    0.661122    
#> 470: 0.414591    1.107877    3.522521    0.176801    0.067626    0.024393    0.661096    
#> 471: 0.414484    1.107911    3.522515    0.176834    0.067623    0.024382    0.661053    
#> 472: 0.414425    1.107918    3.522504    0.176800    0.067630    0.024395    0.661064    
#> 473: 0.414342    1.107913    3.522489    0.176666    0.067607    0.024399    0.661010    
#> 474: 0.414319    1.107874    3.522498    0.176543    0.067608    0.024396    0.661014    
#> 475: 0.414275    1.107934    3.522465    0.176483    0.067566    0.024407    0.661005    
#> 476: 0.414172    1.108008    3.522413    0.176601    0.067549    0.024423    0.660973    
#> 477: 0.414112    1.108094    3.522413    0.176464    0.067507    0.024445    0.660932    
#> 478: 0.413974    1.108118    3.522384    0.176365    0.067465    0.024456    0.660883    
#> 479: 0.414028    1.108178    3.522375    0.176443    0.067439    0.024467    0.660828    
#> 480: 0.414025    1.108183    3.522331    0.176523    0.067395    0.024484    0.660932    
#> 481: 0.413891    1.108189    3.522288    0.176561    0.067350    0.024483    0.660963    
#> 482: 0.413865    1.108235    3.522234    0.176601    0.067372    0.024494    0.660975    
#> 483: 0.413811    1.108202    3.522252    0.176570    0.067330    0.024491    0.660941    
#> 484: 0.413841    1.108040    3.522302    0.176513    0.067332    0.024478    0.660972    
#> 485: 0.413866    1.107970    3.522305    0.176522    0.067375    0.024464    0.661038    
#> 486: 0.413833    1.107928    3.522314    0.176455    0.067365    0.024452    0.661049    
#> 487: 0.413935    1.107952    3.522368    0.176417    0.067343    0.024450    0.661078    
#> 488: 0.413923    1.107946    3.522368    0.176475    0.067335    0.024442    0.661044    
#> 489: 0.413965    1.107952    3.522336    0.176494    0.067371    0.024444    0.661061    
#> 490: 0.414010    1.107961    3.522361    0.176518    0.067338    0.024444    0.661048    
#> 491: 0.414016    1.107987    3.522416    0.176439    0.067341    0.024465    0.661001    
#> 492: 0.414055    1.107968    3.522433    0.176344    0.067340    0.024462    0.661027    
#> 493: 0.414162    1.107973    3.522491    0.176238    0.067328    0.024492    0.661016    
#> 494: 0.414337    1.108000    3.522494    0.176322    0.067279    0.024497    0.661011    
#> 495: 0.414439    1.108051    3.522495    0.176458    0.067255    0.024512    0.660956    
#> 496: 0.414629    1.108081    3.522496    0.176518    0.067220    0.024521    0.660961    
#> 497: 0.414574    1.108059    3.522500    0.176460    0.067234    0.024529    0.660897    
#> 498: 0.414614    1.108012    3.522499    0.176482    0.067221    0.024524    0.660847    
#> 499: 0.414649    1.108096    3.522490    0.176447    0.067273    0.024512    0.660773    
#> 500: 0.414746    1.108042    3.522524    0.176401    0.067259    0.024508    0.660783    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.279091    0.964824    3.437565    0.392401    0.083316    0.016800    1.629069    
#> 002: 0.275112    0.978335    3.441598    0.372781    0.079150    0.015960    1.165916    
#> 003: 0.402537    0.879770    3.429461    0.354142    0.075193    0.015162    0.883675    
#> 004: 0.352002    0.896215    3.414747    0.336435    0.071433    0.014404    0.807559    
#> 005: 0.436741    0.894997    3.408301    0.380538    0.067861    0.013684    0.730830    
#> 006: 0.382298    0.916437    3.390969    0.363938    0.064468    0.013000    0.675713    
#> 007: 0.351948    0.914295    3.387333    0.376994    0.082426    0.012954    0.701840    
#> 008: 0.346667    0.928455    3.386474    0.359719    0.078304    0.015755    0.698546    
#> 009: 0.324766    0.912602    3.389822    0.377765    0.074389    0.014967    0.701905    
#> 010: 0.325386    0.898921    3.390019    0.367620    0.070670    0.017140    0.693357    
#> 011: 0.360053    0.909057    3.389522    0.369389    0.067136    0.018808    0.693615    
#> 012: 0.383128    0.908036    3.381520    0.449871    0.063779    0.017867    0.683586    
#> 013: 0.389715    0.919972    3.379295    0.516072    0.063793    0.020391    0.671818    
#> 014: 0.390502    0.923395    3.387127    0.576638    0.062560    0.021419    0.685057    
#> 015: 0.406104    0.928824    3.387139    0.565197    0.069889    0.020348    0.673712    
#> 016: 0.417843    0.927701    3.399034    0.536937    0.066394    0.019331    0.676822    
#> 017: 0.374627    0.934219    3.398639    0.514495    0.063075    0.018364    0.667619    
#> 018: 0.377579    0.920932    3.392699    0.488770    0.070693    0.017446    0.666952    
#> 019: 0.389919    0.924157    3.397110    0.464331    0.067158    0.016574    0.688842    
#> 020: 0.411208    0.906312    3.398884    0.457830    0.065810    0.019878    0.684080    
#> 021: 0.399545    0.901184    3.402691    0.434939    0.062519    0.018884    0.684438    
#> 022: 0.374070    0.898853    3.411100    0.413192    0.059393    0.019060    0.689252    
#> 023: 0.491147    0.906978    3.422240    0.473013    0.056424    0.019201    0.727386    
#> 024: 0.455230    0.936810    3.408843    0.530976    0.053602    0.018241    0.703031    
#> 025: 0.451338    0.909425    3.404352    0.516793    0.050922    0.019202    0.689826    
#> 026: 0.428073    0.935446    3.393982    0.495554    0.062922    0.019931    0.668779    
#> 027: 0.399680    0.955552    3.385102    0.537954    0.059776    0.019646    0.688405    
#> 028: 0.425232    0.951016    3.397907    0.540576    0.056787    0.020033    0.687734    
#> 029: 0.393283    0.939901    3.385869    0.513547    0.053948    0.019031    0.710500    
#> 030: 0.383960    0.954133    3.383465    0.487870    0.058863    0.019834    0.678732    
#> 031: 0.360137    0.931801    3.391167    0.463476    0.060965    0.020250    0.680457    
#> 032: 0.365012    0.935223    3.394888    0.440303    0.063750    0.019237    0.679213    
#> 033: 0.345321    0.939046    3.385941    0.418287    0.060562    0.018275    0.687174    
#> 034: 0.383216    0.941631    3.386485    0.410360    0.062036    0.020771    0.677401    
#> 035: 0.354369    0.933671    3.381687    0.392944    0.058935    0.019733    0.670879    
#> 036: 0.345151    0.954886    3.378687    0.373297    0.055988    0.018746    0.678264    
#> 037: 0.334035    0.938337    3.385265    0.358486    0.053188    0.017809    0.690572    
#> 038: 0.368266    0.932003    3.385285    0.427494    0.050529    0.016918    0.660644    
#> 039: 0.386691    0.936574    3.383100    0.502747    0.048003    0.019140    0.668198    
#> 040: 0.363714    0.950274    3.390563    0.477609    0.053518    0.018183    0.680617    
#> 041: 0.349568    0.921608    3.391566    0.453729    0.053418    0.017859    0.675121    
#> 042: 0.404681    0.911220    3.393265    0.431042    0.050747    0.016966    0.671810    
#> 043: 0.370297    0.925519    3.377371    0.429790    0.052543    0.016118    0.676373    
#> 044: 0.359651    0.935736    3.377190    0.456989    0.053929    0.015312    0.675935    
#> 045: 0.359868    0.940751    3.371537    0.524003    0.054177    0.017179    0.665248    
#> 046: 0.347180    0.926135    3.379940    0.497802    0.055069    0.017669    0.673855    
#> 047: 0.367512    0.945622    3.379501    0.472912    0.052315    0.020770    0.683391    
#> 048: 0.343179    0.933142    3.382907    0.449267    0.049700    0.024623    0.679436    
#> 049: 0.378145    0.922048    3.388768    0.484596    0.047215    0.024324    0.687763    
#> 050: 0.432268    0.910797    3.397159    0.579822    0.044854    0.030042    0.678624    
#> 051: 0.382646    0.938527    3.375888    0.550831    0.042611    0.032487    0.678812    
#> 052: 0.390226    0.941590    3.386417    0.559625    0.045203    0.030862    0.663190    
#> 053: 0.386906    0.924114    3.383419    0.564519    0.049169    0.029319    0.667407    
#> 054: 0.317835    0.939191    3.376162    0.536293    0.058016    0.027853    0.707610    
#> 055: 0.304162    0.942317    3.371146    0.509478    0.057062    0.026461    0.689227    
#> 056: 0.329320    0.941672    3.366150    0.484004    0.061151    0.025138    0.684469    
#> 057: 0.357014    0.941455    3.376182    0.521886    0.058093    0.023881    0.702474    
#> 058: 0.373819    0.938851    3.372943    0.578234    0.055189    0.023454    0.677371    
#> 059: 0.329032    0.920160    3.370570    0.549322    0.062428    0.023769    0.686082    
#> 060: 0.313110    0.920333    3.369567    0.521856    0.059307    0.024430    0.680301    
#> 061: 0.367788    0.924857    3.385240    0.562093    0.056341    0.026654    0.678217    
#> 062: 0.400702    0.918060    3.392289    0.546409    0.053524    0.025321    0.705484    
#> 063: 0.416495    0.899010    3.396208    0.539438    0.052211    0.024055    0.697565    
#> 064: 0.386555    0.916770    3.398446    0.512467    0.049601    0.024231    0.697629    
#> 065: 0.389744    0.923359    3.380221    0.495652    0.047121    0.023020    0.668017    
#> 066: 0.356016    0.936695    3.382213    0.470870    0.055097    0.022581    0.660416    
#> 067: 0.351654    0.915466    3.378804    0.460728    0.052343    0.021785    0.659712    
#> 068: 0.319130    0.929641    3.383961    0.473149    0.049725    0.023422    0.679314    
#> 069: 0.334406    0.927795    3.378769    0.449492    0.047239    0.022251    0.687674    
#> 070: 0.336692    0.932323    3.385425    0.427017    0.049148    0.021138    0.690137    
#> 071: 0.324288    0.952368    3.367328    0.468404    0.052879    0.020081    0.696374    
#> 072: 0.320821    0.922255    3.372713    0.461315    0.055043    0.020818    0.685407    
#> 073: 0.386905    0.923104    3.392911    0.628620    0.052290    0.023253    0.682405    
#> 074: 0.365736    0.907569    3.375929    0.597189    0.053019    0.022090    0.685260    
#> 075: 0.352399    0.925915    3.391331    0.567329    0.056653    0.023676    0.668923    
#> 076: 0.406000    0.931158    3.400331    0.538963    0.057746    0.022492    0.667086    
#> 077: 0.422135    0.911774    3.403942    0.512015    0.054859    0.021368    0.671741    
#> 078: 0.394973    0.921320    3.392869    0.518682    0.052116    0.022191    0.651053    
#> 079: 0.400952    0.932426    3.385267    0.536418    0.049510    0.022515    0.688282    
#> 080: 0.384524    0.926704    3.381038    0.509597    0.055478    0.022787    0.696530    
#> 081: 0.371139    0.937028    3.372327    0.502559    0.052704    0.021648    0.678849    
#> 082: 0.363169    0.929903    3.385329    0.477431    0.050069    0.020566    0.688582    
#> 083: 0.389448    0.940681    3.385623    0.513465    0.048518    0.022968    0.666413    
#> 084: 0.386834    0.929334    3.390809    0.491594    0.051909    0.021819    0.680406    
#> 085: 0.380038    0.938280    3.394401    0.467015    0.049313    0.020728    0.669081    
#> 086: 0.403327    0.928187    3.390149    0.503044    0.046848    0.020006    0.675859    
#> 087: 0.419349    0.921516    3.389041    0.634245    0.049012    0.020873    0.675402    
#> 088: 0.341269    0.907862    3.391213    0.602532    0.052415    0.019829    0.692009    
#> 089: 0.354237    0.918417    3.376657    0.572406    0.049794    0.018838    0.678976    
#> 090: 0.353586    0.921190    3.367707    0.543785    0.049248    0.017896    0.698575    
#> 091: 0.342810    0.934687    3.355776    0.516596    0.046785    0.017001    0.683532    
#> 092: 0.328971    0.950454    3.352289    0.490766    0.054494    0.016151    0.688394    
#> 093: 0.307802    0.947224    3.350662    0.466228    0.052647    0.018136    0.692761    
#> 094: 0.303593    0.935735    3.352767    0.442917    0.050015    0.018370    0.694052    
#> 095: 0.319956    0.938282    3.373607    0.420771    0.058787    0.017452    0.678145    
#> 096: 0.319248    0.950630    3.363433    0.503851    0.055847    0.020133    0.666304    
#> 097: 0.333346    0.945697    3.362074    0.486441    0.053055    0.023347    0.664573    
#> 098: 0.317699    0.970877    3.361557    0.462119    0.050402    0.024096    0.678789    
#> 099: 0.339006    0.940390    3.366281    0.496186    0.047882    0.022891    0.671124    
#> 100: 0.337069    0.942008    3.369091    0.493515    0.045488    0.026937    0.642392    
#> 101: 0.303609    0.938751    3.358837    0.468839    0.043213    0.028597    0.637002    
#> 102: 0.318073    0.941749    3.355560    0.473725    0.049218    0.027167    0.657464    
#> 103: 0.322843    0.942558    3.365931    0.450039    0.046757    0.025809    0.648439    
#> 104: 0.346681    0.941729    3.383819    0.467393    0.051293    0.024519    0.664649    
#> 105: 0.349325    0.937773    3.379209    0.464968    0.053621    0.027001    0.673084    
#> 106: 0.394732    0.942207    3.379373    0.560423    0.052557    0.025651    0.654660    
#> 107: 0.394489    0.933726    3.386724    0.574837    0.049929    0.029654    0.653859    
#> 108: 0.382711    0.934762    3.396185    0.546095    0.053358    0.028172    0.680932    
#> 109: 0.376829    0.942131    3.398172    0.518791    0.050690    0.026763    0.696895    
#> 110: 0.363110    0.915398    3.385848    0.492851    0.048156    0.025425    0.698531    
#> 111: 0.379167    0.930506    3.389801    0.468209    0.046543    0.024154    0.691476    
#> 112: 0.374808    0.908481    3.375140    0.477056    0.044216    0.022946    0.685551    
#> 113: 0.343061    0.932678    3.376309    0.516771    0.042005    0.023613    0.672043    
#> 114: 0.363068    0.926833    3.377356    0.490932    0.039905    0.025063    0.668968    
#> 115: 0.364855    0.916004    3.378282    0.488332    0.037910    0.023810    0.688571    
#> 116: 0.391620    0.926652    3.377858    0.479672    0.038477    0.024023    0.683509    
#> 117: 0.367484    0.937752    3.386265    0.475917    0.039848    0.022822    0.680676    
#> 118: 0.381275    0.928891    3.388200    0.562333    0.039893    0.022902    0.670189    
#> 119: 0.416994    0.926816    3.383064    0.627366    0.037899    0.029185    0.685391    
#> 120: 0.375542    0.919293    3.392509    0.595998    0.036004    0.029123    0.678744    
#> 121: 0.403557    0.937088    3.388719    0.566198    0.041911    0.027666    0.662756    
#> 122: 0.360280    0.923685    3.387381    0.568868    0.042353    0.026283    0.678336    
#> 123: 0.402549    0.931792    3.381726    0.574434    0.041067    0.024969    0.670656    
#> 124: 0.394214    0.969687    3.374669    0.585161    0.039014    0.024601    0.666094    
#> 125: 0.389418    0.966541    3.366833    0.555903    0.037063    0.023371    0.661753    
#> 126: 0.369114    0.966746    3.358886    0.537240    0.035210    0.026185    0.670348    
#> 127: 0.370347    0.965459    3.351690    0.510378    0.037853    0.024876    0.667616    
#> 128: 0.334176    0.947590    3.365451    0.484859    0.039579    0.024228    0.668033    
#> 129: 0.354382    0.947341    3.376272    0.465931    0.043043    0.023016    0.690094    
#> 130: 0.374577    0.951414    3.384693    0.442634    0.045884    0.021865    0.693769    
#> 131: 0.321019    0.933182    3.365231    0.420503    0.043590    0.021109    0.680158    
#> 132: 0.346908    0.928246    3.362244    0.476061    0.048908    0.020054    0.681972    
#> 133: 0.309161    0.945295    3.369043    0.452258    0.049984    0.019051    0.682771    
#> 134: 0.353634    0.928798    3.377484    0.463320    0.057838    0.018098    0.673273    
#> 135: 0.345360    0.929641    3.383363    0.440154    0.056792    0.017194    0.669926    
#> 136: 0.339006    0.920973    3.383967    0.418147    0.057123    0.016334    0.676986    
#> 137: 0.372300    0.915144    3.392414    0.397239    0.054266    0.017176    0.700354    
#> 138: 0.357817    0.927414    3.388721    0.399546    0.053456    0.018321    0.699911    
#> 139: 0.342717    0.926413    3.396262    0.426218    0.050783    0.021078    0.694344    
#> 140: 0.349691    0.948005    3.393261    0.456937    0.052232    0.022233    0.706458    
#> 141: 0.323367    0.930977    3.380695    0.434090    0.058985    0.021121    0.695484    
#> 142: 0.370155    0.924621    3.396217    0.412386    0.056036    0.020065    0.698201    
#> 143: 0.348684    0.935807    3.388681    0.434135    0.053234    0.021938    0.711009    
#> 144: 0.408812    0.943764    3.394063    0.464075    0.050572    0.022055    0.674350    
#> 145: 0.363712    0.955918    3.364535    0.478022    0.048044    0.022061    0.677018    
#> 146: 0.340982    0.959136    3.377424    0.526164    0.046673    0.022629    0.691668    
#> 147: 0.329535    0.946969    3.360926    0.554143    0.044340    0.026444    0.663040    
#> 148: 0.286827    0.953021    3.371399    0.526436    0.047424    0.025806    0.674427    
#> 149: 0.354259    0.944114    3.372566    0.578220    0.056328    0.024516    0.655919    
#> 150: 0.388236    0.928908    3.370471    0.655861    0.056511    0.023290    0.669050    
#> 151: 0.359249    0.950924    3.369359    0.623068    0.053686    0.022126    0.670020    
#> 152: 0.307861    0.945523    3.361022    0.651436    0.045004    0.024371    0.668019    
#> 153: 0.342666    0.958176    3.377431    0.697596    0.047820    0.025080    0.694110    
#> 154: 0.354574    0.965006    3.380162    0.486040    0.040353    0.023271    0.705791    
#> 155: 0.340097    0.941882    3.376137    0.421156    0.041348    0.024502    0.695460    
#> 156: 0.335421    0.955992    3.373461    0.436550    0.052009    0.019320    0.704357    
#> 157: 0.328529    0.955885    3.372265    0.435203    0.054920    0.021195    0.707158    
#> 158: 0.355326    0.968477    3.369783    0.453051    0.059943    0.021567    0.676039    
#> 159: 0.318840    0.957239    3.374151    0.441273    0.056616    0.017583    0.679093    
#> 160: 0.358846    0.904067    3.400295    0.410642    0.067502    0.015716    0.686327    
#> 161: 0.350900    0.918856    3.392083    0.358102    0.061097    0.015309    0.691873    
#> 162: 0.354702    0.939990    3.383474    0.366312    0.053490    0.014915    0.695510    
#> 163: 0.345908    0.928988    3.374523    0.416025    0.065180    0.014594    0.676735    
#> 164: 0.362916    0.931386    3.376561    0.443510    0.059632    0.016497    0.658431    
#> 165: 0.371244    0.925786    3.382957    0.434627    0.046149    0.016901    0.681667    
#> 166: 0.360547    0.951437    3.381159    0.389254    0.045533    0.020252    0.690404    
#> 167: 0.395278    0.958095    3.383824    0.423447    0.045346    0.016311    0.691913    
#> 168: 0.363816    0.949816    3.389473    0.436572    0.053028    0.014886    0.681273    
#> 169: 0.368406    0.970298    3.374790    0.392913    0.061838    0.012957    0.697325    
#> 170: 0.362864    0.957119    3.379401    0.436931    0.055086    0.013039    0.679886    
#> 171: 0.337124    0.951529    3.372187    0.438530    0.061452    0.015465    0.669709    
#> 172: 0.347937    0.949808    3.376165    0.458466    0.054770    0.014303    0.671254    
#> 173: 0.339440    0.970322    3.360994    0.497219    0.053353    0.020525    0.662381    
#> 174: 0.354613    0.956501    3.370428    0.512633    0.044269    0.024034    0.673050    
#> 175: 0.329807    0.966882    3.351272    0.516876    0.036937    0.024249    0.679562    
#> 176: 0.316105    0.977048    3.366199    0.440414    0.034385    0.024239    0.672686    
#> 177: 0.336374    0.968708    3.373613    0.468819    0.042264    0.027914    0.657030    
#> 178: 0.358995    0.940777    3.370110    0.468230    0.036144    0.027691    0.654923    
#> 179: 0.382677    0.954402    3.380673    0.456975    0.041565    0.026908    0.677699    
#> 180: 0.343813    0.956213    3.376593    0.457649    0.044330    0.023189    0.675186    
#> 181: 0.352074    0.941669    3.348789    0.518476    0.045552    0.021898    0.687864    
#> 182: 0.331054    0.953266    3.356713    0.508765    0.038465    0.026848    0.701716    
#> 183: 0.339937    0.958671    3.364397    0.439584    0.036759    0.029375    0.684186    
#> 184: 0.335890    0.940915    3.372890    0.445399    0.038181    0.027601    0.665256    
#> 185: 0.314738    0.954121    3.360463    0.472689    0.044265    0.024119    0.662303    
#> 186: 0.313848    0.946117    3.367692    0.475620    0.037406    0.027983    0.697084    
#> 187: 0.337127    0.939815    3.373594    0.462604    0.043488    0.030420    0.678991    
#> 188: 0.308071    0.969828    3.360094    0.476768    0.046494    0.026274    0.697925    
#> 189: 0.295087    0.973511    3.373098    0.405837    0.042883    0.023994    0.696076    
#> 190: 0.313460    0.946738    3.370932    0.417577    0.046134    0.027058    0.681003    
#> 191: 0.337913    0.956074    3.371753    0.497065    0.038978    0.022445    0.669022    
#> 192: 0.322464    0.952895    3.371928    0.450516    0.043243    0.020538    0.663848    
#> 193: 0.383153    0.965415    3.382754    0.483658    0.046372    0.019619    0.669552    
#> 194: 0.366185    0.942273    3.375324    0.422612    0.054528    0.017126    0.681888    
#> 195: 0.310371    0.942130    3.366876    0.388347    0.051086    0.019535    0.681950    
#> 196: 0.347036    0.928604    3.383321    0.406662    0.057658    0.018007    0.698966    
#> 197: 0.314012    0.948188    3.393718    0.424181    0.050122    0.021902    0.697636    
#> 198: 0.355479    0.935753    3.379630    0.459575    0.038896    0.023249    0.684913    
#> 199: 0.340861    0.934035    3.376524    0.501909    0.038260    0.020145    0.662173    
#> 200: 0.330899    0.928825    3.370217    0.486315    0.048971    0.022749    0.673674    
#> 201: 0.350528    0.931343    3.375627    0.516274    0.046992    0.025499    0.662582    
#> 202: 0.346584    0.934654    3.378912    0.522845    0.046625    0.027185    0.660814    
#> 203: 0.359808    0.930017    3.379718    0.536512    0.046285    0.026883    0.665246    
#> 204: 0.362435    0.923202    3.383279    0.516840    0.044413    0.026438    0.670034    
#> 205: 0.367646    0.924856    3.384113    0.515553    0.043841    0.026379    0.674801    
#> 206: 0.369722    0.928785    3.384656    0.523695    0.043683    0.026408    0.675191    
#> 207: 0.366997    0.930701    3.383917    0.516285    0.044068    0.025834    0.674963    
#> 208: 0.364978    0.932754    3.383446    0.511791    0.043610    0.025376    0.673136    
#> 209: 0.365604    0.930783    3.382982    0.504970    0.042806    0.025221    0.673227    
#> 210: 0.369007    0.930489    3.384165    0.504606    0.043149    0.024950    0.672604    
#> 211: 0.373902    0.930838    3.385202    0.507859    0.043188    0.024712    0.672874    
#> 212: 0.375494    0.930336    3.386527    0.505019    0.042930    0.024536    0.673050    
#> 213: 0.377157    0.928338    3.387328    0.501603    0.042673    0.024326    0.673839    
#> 214: 0.378360    0.927147    3.387494    0.501485    0.042742    0.024148    0.674030    
#> 215: 0.378655    0.926576    3.388288    0.496091    0.042461    0.023940    0.674530    
#> 216: 0.381021    0.924643    3.389279    0.493362    0.042759    0.023899    0.675150    
#> 217: 0.382757    0.923909    3.390301    0.491509    0.042782    0.023615    0.674406    
#> 218: 0.383460    0.924286    3.390345    0.489488    0.042997    0.023592    0.674428    
#> 219: 0.382566    0.923802    3.389824    0.489798    0.043187    0.023395    0.674676    
#> 220: 0.380498    0.923389    3.389286    0.493411    0.043101    0.023318    0.675298    
#> 221: 0.379851    0.923803    3.388797    0.492281    0.043455    0.023166    0.675499    
#> 222: 0.379794    0.923994    3.388184    0.492949    0.044113    0.023107    0.676153    
#> 223: 0.379680    0.924272    3.387639    0.493358    0.044261    0.023041    0.675990    
#> 224: 0.380922    0.924585    3.387465    0.495049    0.043947    0.023064    0.675279    
#> 225: 0.380604    0.923514    3.387569    0.495957    0.043982    0.023115    0.675699    
#> 226: 0.380114    0.922484    3.387301    0.496385    0.044027    0.023021    0.675865    
#> 227: 0.379616    0.922547    3.386942    0.495000    0.044076    0.023001    0.675896    
#> 228: 0.378844    0.923588    3.386485    0.493144    0.044582    0.022904    0.676068    
#> 229: 0.377152    0.924137    3.386178    0.493012    0.044861    0.022905    0.675656    
#> 230: 0.377603    0.924656    3.385862    0.494883    0.045084    0.022841    0.675414    
#> 231: 0.377018    0.925370    3.385698    0.495967    0.045179    0.022643    0.675137    
#> 232: 0.376229    0.925521    3.385924    0.494982    0.045167    0.022468    0.675127    
#> 233: 0.376218    0.924679    3.386139    0.494919    0.045430    0.022335    0.675373    
#> 234: 0.375784    0.924523    3.386196    0.493949    0.045603    0.022331    0.675470    
#> 235: 0.375941    0.924145    3.386202    0.494448    0.045480    0.022326    0.675303    
#> 236: 0.376817    0.924020    3.386334    0.497904    0.045503    0.022284    0.675249    
#> 237: 0.377981    0.923926    3.386718    0.498464    0.045546    0.022274    0.676100    
#> 238: 0.379159    0.923637    3.386999    0.497924    0.045733    0.022259    0.677073    
#> 239: 0.379917    0.923806    3.387227    0.498605    0.045836    0.022408    0.676890    
#> 240: 0.381127    0.923471    3.387675    0.499769    0.045857    0.022510    0.676996    
#> 241: 0.381640    0.922608    3.387953    0.500688    0.045908    0.022378    0.677590    
#> 242: 0.381198    0.922152    3.387665    0.502530    0.046200    0.022284    0.678202    
#> 243: 0.379814    0.922616    3.387385    0.501919    0.046159    0.022267    0.678803    
#> 244: 0.378901    0.922542    3.387331    0.501210    0.046049    0.022316    0.678755    
#> 245: 0.378866    0.922212    3.387292    0.501439    0.046063    0.022368    0.679096    
#> 246: 0.378773    0.922270    3.387170    0.500835    0.046042    0.022481    0.679181    
#> 247: 0.378907    0.921929    3.387150    0.501873    0.046087    0.022487    0.678993    
#> 248: 0.378252    0.922524    3.386756    0.503390    0.046224    0.022509    0.678575    
#> 249: 0.377339    0.922911    3.386477    0.503174    0.046305    0.022508    0.678633    
#> 250: 0.377496    0.923517    3.386224    0.504033    0.046365    0.022504    0.678462    
#> 251: 0.376804    0.924316    3.386156    0.502654    0.046562    0.022454    0.678578    
#> 252: 0.376558    0.925071    3.386209    0.501478    0.046904    0.022470    0.678746    
#> 253: 0.375614    0.925454    3.386095    0.500122    0.047151    0.022441    0.678830    
#> 254: 0.375402    0.926093    3.385992    0.499358    0.047328    0.022421    0.679068    
#> 255: 0.375097    0.926652    3.385742    0.498712    0.047455    0.022428    0.679100    
#> 256: 0.374801    0.926936    3.385489    0.498188    0.047593    0.022426    0.679021    
#> 257: 0.374032    0.926846    3.385354    0.496494    0.047602    0.022483    0.678924    
#> 258: 0.373613    0.926812    3.385230    0.496318    0.047504    0.022502    0.678858    
#> 259: 0.373032    0.926678    3.385065    0.494877    0.047364    0.022460    0.678895    
#> 260: 0.372617    0.926795    3.385062    0.493637    0.047228    0.022428    0.678712    
#> 261: 0.372674    0.926644    3.385166    0.493836    0.047200    0.022423    0.678436    
#> 262: 0.372946    0.926824    3.385258    0.493930    0.047167    0.022391    0.677945    
#> 263: 0.372779    0.926999    3.385162    0.493393    0.047215    0.022409    0.677677    
#> 264: 0.372366    0.927231    3.385028    0.493057    0.047530    0.022394    0.677534    
#> 265: 0.372346    0.927103    3.384957    0.493819    0.047623    0.022464    0.677770    
#> 266: 0.373280    0.927182    3.385175    0.495069    0.047639    0.022580    0.677956    
#> 267: 0.373422    0.927236    3.385452    0.495207    0.047542    0.022643    0.678058    
#> 268: 0.373578    0.927022    3.385474    0.496060    0.047438    0.022690    0.677899    
#> 269: 0.374645    0.926726    3.385662    0.496700    0.047365    0.022774    0.677920    
#> 270: 0.374895    0.926747    3.385710    0.496566    0.047378    0.022751    0.677643    
#> 271: 0.375319    0.926843    3.385733    0.497605    0.047472    0.022781    0.677599    
#> 272: 0.375203    0.926732    3.385674    0.496431    0.047573    0.022757    0.678065    
#> 273: 0.374818    0.926967    3.385532    0.497010    0.047571    0.022788    0.678438    
#> 274: 0.374391    0.927265    3.385403    0.497262    0.047495    0.022800    0.678539    
#> 275: 0.374062    0.927524    3.385225    0.496418    0.047397    0.022801    0.678403    
#> 276: 0.374595    0.927758    3.385284    0.497435    0.047386    0.022838    0.678434    
#> 277: 0.374144    0.928154    3.385259    0.497185    0.047375    0.022856    0.678545    
#> 278: 0.374489    0.928262    3.385271    0.497617    0.047253    0.022895    0.678435    
#> 279: 0.374359    0.928178    3.385356    0.497731    0.047281    0.022924    0.678361    
#> 280: 0.374402    0.928192    3.385431    0.498065    0.047316    0.022947    0.678169    
#> 281: 0.374138    0.928222    3.385487    0.498587    0.047354    0.022973    0.678122    
#> 282: 0.373934    0.928460    3.385483    0.498415    0.047365    0.023003    0.678238    
#> 283: 0.373754    0.928676    3.385410    0.497719    0.047342    0.023021    0.678665    
#> 284: 0.373162    0.928703    3.385349    0.496124    0.047343    0.023045    0.678579    
#> 285: 0.372385    0.928969    3.385149    0.494534    0.047387    0.023016    0.678515    
#> 286: 0.371697    0.929303    3.384871    0.492953    0.047359    0.023005    0.678607    
#> 287: 0.370682    0.929569    3.384578    0.492405    0.047376    0.022988    0.678698    
#> 288: 0.370594    0.929827    3.384407    0.492424    0.047253    0.023049    0.678834    
#> 289: 0.370803    0.929876    3.384347    0.493713    0.047175    0.023091    0.678699    
#> 290: 0.370704    0.929937    3.384238    0.494331    0.047168    0.023131    0.678881    
#> 291: 0.370566    0.930093    3.384247    0.494139    0.047118    0.023158    0.678782    
#> 292: 0.370185    0.930080    3.384164    0.493669    0.047039    0.023200    0.678717    
#> 293: 0.370117    0.930186    3.384080    0.493824    0.046919    0.023233    0.678702    
#> 294: 0.369699    0.930219    3.383932    0.493990    0.046794    0.023274    0.678725    
#> 295: 0.369452    0.929952    3.383852    0.494305    0.046735    0.023262    0.678591    
#> 296: 0.369687    0.929700    3.383919    0.494564    0.046808    0.023208    0.678658    
#> 297: 0.370090    0.929502    3.384048    0.494576    0.046776    0.023143    0.678778    
#> 298: 0.370262    0.929351    3.384100    0.493905    0.046783    0.023098    0.678842    
#> 299: 0.370223    0.929418    3.384042    0.493058    0.046816    0.023082    0.678723    
#> 300: 0.370139    0.929333    3.384016    0.492552    0.046852    0.023076    0.678683    
#> 301: 0.370378    0.929354    3.383875    0.493251    0.046926    0.023053    0.678683    
#> 302: 0.370426    0.929619    3.383690    0.493922    0.046998    0.023043    0.678636    
#> 303: 0.369841    0.929928    3.383478    0.493863    0.047169    0.023035    0.678432    
#> 304: 0.369242    0.930282    3.383232    0.493715    0.047221    0.023055    0.678194    
#> 305: 0.368781    0.930210    3.383130    0.493757    0.047188    0.023065    0.678158    
#> 306: 0.368355    0.930176    3.383021    0.493498    0.047235    0.023083    0.678123    
#> 307: 0.367924    0.930128    3.382823    0.493683    0.047306    0.023102    0.678143    
#> 308: 0.367372    0.930125    3.382651    0.493561    0.047329    0.023113    0.678405    
#> 309: 0.367387    0.929887    3.382620    0.493933    0.047366    0.023137    0.678521    
#> 310: 0.367496    0.929740    3.382595    0.494046    0.047380    0.023153    0.678722    
#> 311: 0.367505    0.929657    3.382585    0.494401    0.047326    0.023181    0.678856    
#> 312: 0.367425    0.929528    3.382543    0.494560    0.047246    0.023224    0.679042    
#> 313: 0.367496    0.929205    3.382523    0.494943    0.047174    0.023244    0.679033    
#> 314: 0.367128    0.929070    3.382454    0.495500    0.047123    0.023243    0.679026    
#> 315: 0.366829    0.929042    3.382392    0.495649    0.047074    0.023216    0.679127    
#> 316: 0.366570    0.929135    3.382273    0.495134    0.047091    0.023184    0.679100    
#> 317: 0.366544    0.929226    3.382202    0.495287    0.047026    0.023176    0.679236    
#> 318: 0.366348    0.929367    3.382024    0.495415    0.046973    0.023174    0.679202    
#> 319: 0.366265    0.929407    3.381956    0.495966    0.046894    0.023231    0.679130    
#> 320: 0.365766    0.929404    3.381796    0.495587    0.046900    0.023260    0.679056    
#> 321: 0.365525    0.929589    3.381653    0.495179    0.046795    0.023297    0.679143    
#> 322: 0.365342    0.929716    3.381530    0.495128    0.046743    0.023347    0.679076    
#> 323: 0.364789    0.929863    3.381369    0.494557    0.046694    0.023373    0.679027    
#> 324: 0.364501    0.930084    3.381271    0.494535    0.046658    0.023410    0.678873    
#> 325: 0.364339    0.930410    3.381234    0.494365    0.046610    0.023397    0.678773    
#> 326: 0.364256    0.930292    3.381312    0.494167    0.046555    0.023399    0.678765    
#> 327: 0.364289    0.930296    3.381366    0.493770    0.046622    0.023428    0.678791    
#> 328: 0.364136    0.930402    3.381325    0.493488    0.046671    0.023424    0.678701    
#> 329: 0.364320    0.930338    3.381436    0.493432    0.046656    0.023406    0.678674    
#> 330: 0.364328    0.930225    3.381507    0.492964    0.046667    0.023375    0.678724    
#> 331: 0.364605    0.930274    3.381631    0.492530    0.046765    0.023344    0.678582    
#> 332: 0.365003    0.930205    3.381848    0.492373    0.046858    0.023327    0.678577    
#> 333: 0.365230    0.930109    3.381908    0.492241    0.046814    0.023323    0.678661    
#> 334: 0.365274    0.929983    3.381878    0.492241    0.046746    0.023367    0.678787    
#> 335: 0.365243    0.930027    3.381775    0.492728    0.046667    0.023405    0.678774    
#> 336: 0.364981    0.930092    3.381709    0.493017    0.046598    0.023449    0.678870    
#> 337: 0.364598    0.930232    3.381584    0.492805    0.046602    0.023483    0.678844    
#> 338: 0.364440    0.930251    3.381656    0.492850    0.046591    0.023521    0.678801    
#> 339: 0.364270    0.930321    3.381621    0.492680    0.046613    0.023538    0.678804    
#> 340: 0.364156    0.930234    3.381622    0.492416    0.046684    0.023541    0.678710    
#> 341: 0.364444    0.930209    3.381712    0.492604    0.046707    0.023526    0.678597    
#> 342: 0.364253    0.930047    3.381750    0.492287    0.046755    0.023488    0.678570    
#> 343: 0.364327    0.930066    3.381814    0.492183    0.046805    0.023452    0.678689    
#> 344: 0.364607    0.929998    3.382005    0.492396    0.046842    0.023438    0.678856    
#> 345: 0.364661    0.930009    3.382080    0.492135    0.046855    0.023407    0.678876    
#> 346: 0.364820    0.930005    3.382129    0.491510    0.046833    0.023383    0.678890    
#> 347: 0.364961    0.929838    3.382147    0.491360    0.046809    0.023370    0.678930    
#> 348: 0.364654    0.929962    3.382084    0.490939    0.046898    0.023366    0.678979    
#> 349: 0.364245    0.929931    3.382009    0.490378    0.046939    0.023356    0.678983    
#> 350: 0.364229    0.929848    3.382007    0.490413    0.046987    0.023358    0.678889    
#> 351: 0.364333    0.929929    3.382004    0.490718    0.046979    0.023360    0.678834    
#> 352: 0.364054    0.930062    3.381977    0.490175    0.046940    0.023376    0.678990    
#> 353: 0.363922    0.930151    3.381931    0.489734    0.046906    0.023411    0.678985    
#> 354: 0.363839    0.930254    3.381807    0.489226    0.046887    0.023428    0.678980    
#> 355: 0.364039    0.930220    3.381756    0.489350    0.046892    0.023403    0.678981    
#> 356: 0.364246    0.930205    3.381780    0.489447    0.046953    0.023364    0.679112    
#> 357: 0.364444    0.930249    3.381860    0.489298    0.046976    0.023345    0.679044    
#> 358: 0.364577    0.930374    3.381885    0.489072    0.047017    0.023313    0.679032    
#> 359: 0.364484    0.930571    3.381832    0.488668    0.047010    0.023299    0.679009    
#> 360: 0.364391    0.930690    3.381710    0.488406    0.047006    0.023286    0.678963    
#> 361: 0.363935    0.930817    3.381567    0.488013    0.046937    0.023264    0.678929    
#> 362: 0.363834    0.930884    3.381512    0.487869    0.046876    0.023259    0.678769    
#> 363: 0.363793    0.930948    3.381442    0.487801    0.046839    0.023257    0.678591    
#> 364: 0.363788    0.931001    3.381413    0.487953    0.046834    0.023246    0.678515    
#> 365: 0.363821    0.931002    3.381410    0.487973    0.046789    0.023233    0.678438    
#> 366: 0.363695    0.931079    3.381330    0.487687    0.046792    0.023219    0.678458    
#> 367: 0.363526    0.931201    3.381267    0.487427    0.046785    0.023214    0.678519    
#> 368: 0.363518    0.931294    3.381212    0.487546    0.046722    0.023239    0.678553    
#> 369: 0.363169    0.931278    3.381114    0.487585    0.046695    0.023251    0.678635    
#> 370: 0.362897    0.931364    3.380976    0.487438    0.046658    0.023283    0.678797    
#> 371: 0.362548    0.931471    3.380822    0.487061    0.046692    0.023284    0.678855    
#> 372: 0.362243    0.931667    3.380717    0.486722    0.046736    0.023295    0.678918    
#> 373: 0.361875    0.931841    3.380649    0.486432    0.046708    0.023315    0.678966    
#> 374: 0.361877    0.931819    3.380596    0.486555    0.046639    0.023349    0.678922    
#> 375: 0.361655    0.931821    3.380565    0.486297    0.046526    0.023383    0.678974    
#> 376: 0.361592    0.931871    3.380489    0.486415    0.046454    0.023435    0.678865    
#> 377: 0.361447    0.931971    3.380394    0.486390    0.046429    0.023470    0.678827    
#> 378: 0.361111    0.932044    3.380327    0.486031    0.046425    0.023471    0.678928    
#> 379: 0.360907    0.931985    3.380306    0.485838    0.046398    0.023469    0.679011    
#> 380: 0.360829    0.931920    3.380303    0.485647    0.046435    0.023487    0.678919    
#> 381: 0.360640    0.931940    3.380241    0.485700    0.046486    0.023491    0.678903    
#> 382: 0.360661    0.931923    3.380264    0.485815    0.046513    0.023482    0.678788    
#> 383: 0.360636    0.931911    3.380278    0.486021    0.046543    0.023474    0.678750    
#> 384: 0.360455    0.931901    3.380274    0.485970    0.046518    0.023482    0.678738    
#> 385: 0.360445    0.931870    3.380282    0.485884    0.046487    0.023469    0.678712    
#> 386: 0.360495    0.931940    3.380317    0.485669    0.046464    0.023447    0.678756    
#> 387: 0.360577    0.932048    3.380362    0.485633    0.046469    0.023431    0.678739    
#> 388: 0.360709    0.932111    3.380407    0.485673    0.046432    0.023411    0.678734    
#> 389: 0.360652    0.932055    3.380370    0.485706    0.046413    0.023401    0.678809    
#> 390: 0.360440    0.932108    3.380320    0.485372    0.046419    0.023357    0.678809    
#> 391: 0.360260    0.932138    3.380249    0.485159    0.046437    0.023350    0.678730    
#> 392: 0.360286    0.932193    3.380230    0.485351    0.046436    0.023325    0.678697    
#> 393: 0.360321    0.932116    3.380254    0.485229    0.046448    0.023329    0.678650    
#> 394: 0.360370    0.932108    3.380287    0.485311    0.046408    0.023325    0.678660    
#> 395: 0.360581    0.932127    3.380293    0.485717    0.046408    0.023329    0.678641    
#> 396: 0.360519    0.932188    3.380240    0.486121    0.046432    0.023343    0.678621    
#> 397: 0.360605    0.932111    3.380243    0.486511    0.046408    0.023346    0.678652    
#> 398: 0.360746    0.932053    3.380281    0.486541    0.046399    0.023348    0.678629    
#> 399: 0.360904    0.932087    3.380352    0.486950    0.046426    0.023353    0.678614    
#> 400: 0.361051    0.932087    3.380384    0.487300    0.046470    0.023353    0.678578    
#> 401: 0.361084    0.932131    3.380364    0.487321    0.046483    0.023363    0.678564    
#> 402: 0.361149    0.932229    3.380373    0.487446    0.046505    0.023354    0.678553    
#> 403: 0.361359    0.932247    3.380368    0.487501    0.046546    0.023324    0.678476    
#> 404: 0.361406    0.932320    3.380293    0.487657    0.046562    0.023307    0.678422    
#> 405: 0.361325    0.932323    3.380288    0.487491    0.046555    0.023303    0.678434    
#> 406: 0.361389    0.932379    3.380276    0.487936    0.046508    0.023305    0.678492    
#> 407: 0.361293    0.932467    3.380309    0.488081    0.046540    0.023298    0.678529    
#> 408: 0.361512    0.932584    3.380343    0.488308    0.046594    0.023272    0.678506    
#> 409: 0.361631    0.932571    3.380340    0.488634    0.046573    0.023265    0.678452    
#> 410: 0.361691    0.932554    3.380281    0.489039    0.046560    0.023249    0.678467    
#> 411: 0.361780    0.932396    3.380274    0.489579    0.046542    0.023233    0.678554    
#> 412: 0.361909    0.932377    3.380284    0.490086    0.046574    0.023208    0.678611    
#> 413: 0.361951    0.932425    3.380268    0.490479    0.046615    0.023188    0.678674    
#> 414: 0.361946    0.932416    3.380317    0.490665    0.046618    0.023182    0.678615    
#> 415: 0.362040    0.932455    3.380325    0.490523    0.046640    0.023178    0.678594    
#> 416: 0.362247    0.932459    3.380443    0.490455    0.046665    0.023181    0.678547    
#> 417: 0.362255    0.932409    3.380490    0.490229    0.046687    0.023158    0.678553    
#> 418: 0.362134    0.932370    3.380551    0.489840    0.046703    0.023147    0.678430    
#> 419: 0.362165    0.932349    3.380570    0.489905    0.046720    0.023125    0.678439    
#> 420: 0.362333    0.932361    3.380617    0.489913    0.046766    0.023103    0.678341    
#> 421: 0.362393    0.932330    3.380682    0.489960    0.046777    0.023099    0.678282    
#> 422: 0.362562    0.932245    3.380699    0.490357    0.046723    0.023100    0.678264    
#> 423: 0.362654    0.932167    3.380733    0.490489    0.046699    0.023097    0.678195    
#> 424: 0.362605    0.932119    3.380720    0.490402    0.046670    0.023110    0.678194    
#> 425: 0.362635    0.932193    3.380655    0.490648    0.046593    0.023150    0.678249    
#> 426: 0.362515    0.932333    3.380598    0.490654    0.046540    0.023163    0.678274    
#> 427: 0.362282    0.932394    3.380573    0.490638    0.046518    0.023169    0.678249    
#> 428: 0.362128    0.932426    3.380569    0.490865    0.046516    0.023157    0.678202    
#> 429: 0.362218    0.932408    3.380612    0.490752    0.046523    0.023138    0.678215    
#> 430: 0.362276    0.932405    3.380633    0.490609    0.046516    0.023106    0.678167    
#> 431: 0.362274    0.932279    3.380642    0.490509    0.046477    0.023083    0.678104    
#> 432: 0.362347    0.932247    3.380665    0.490833    0.046421    0.023091    0.678077    
#> 433: 0.362365    0.932348    3.380672    0.490814    0.046355    0.023104    0.678187    
#> 434: 0.362176    0.932321    3.380644    0.490478    0.046327    0.023078    0.678234    
#> 435: 0.362151    0.932319    3.380636    0.490026    0.046300    0.023069    0.678276    
#> 436: 0.362275    0.932204    3.380727    0.489637    0.046298    0.023039    0.678326    
#> 437: 0.362344    0.932127    3.380788    0.489132    0.046306    0.023006    0.678374    
#> 438: 0.362220    0.932249    3.380809    0.488693    0.046337    0.022990    0.678383    
#> 439: 0.362292    0.932359    3.380831    0.488571    0.046317    0.022985    0.678371    
#> 440: 0.362291    0.932411    3.380856    0.488484    0.046273    0.022971    0.678297    
#> 441: 0.362260    0.932364    3.380888    0.488263    0.046226    0.022967    0.678212    
#> 442: 0.362146    0.932371    3.380864    0.487926    0.046217    0.022951    0.678186    
#> 443: 0.362019    0.932450    3.380792    0.487560    0.046216    0.022951    0.678194    
#> 444: 0.361821    0.932547    3.380682    0.487446    0.046220    0.022968    0.678211    
#> 445: 0.361696    0.932623    3.380639    0.487342    0.046208    0.022988    0.678236    
#> 446: 0.361478    0.932649    3.380592    0.487190    0.046189    0.023012    0.678301    
#> 447: 0.361405    0.932702    3.380563    0.487205    0.046201    0.023035    0.678291    
#> 448: 0.361364    0.932795    3.380545    0.487486    0.046210    0.023066    0.678189    
#> 449: 0.361282    0.932915    3.380569    0.487500    0.046188    0.023069    0.678231    
#> 450: 0.361208    0.932976    3.380549    0.487759    0.046223    0.023075    0.678175    
#> 451: 0.361194    0.933035    3.380534    0.487952    0.046248    0.023077    0.678135    
#> 452: 0.361105    0.933088    3.380506    0.488355    0.046252    0.023091    0.678082    
#> 453: 0.361097    0.933124    3.380460    0.488583    0.046245    0.023095    0.677986    
#> 454: 0.361074    0.933225    3.380434    0.488546    0.046224    0.023097    0.677924    
#> 455: 0.361083    0.933268    3.380428    0.488763    0.046222    0.023097    0.677842    
#> 456: 0.361047    0.933244    3.380421    0.488625    0.046182    0.023088    0.677863    
#> 457: 0.360989    0.933225    3.380435    0.488303    0.046174    0.023066    0.677861    
#> 458: 0.360976    0.933325    3.380448    0.487978    0.046173    0.023054    0.677857    
#> 459: 0.360886    0.933475    3.380440    0.488058    0.046194    0.023041    0.677855    
#> 460: 0.360848    0.933520    3.380393    0.488033    0.046194    0.023026    0.677862    
#> 461: 0.360808    0.933607    3.380393    0.487900    0.046205    0.023024    0.677860    
#> 462: 0.360784    0.933657    3.380422    0.487597    0.046189    0.023006    0.677893    
#> 463: 0.360766    0.933723    3.380427    0.487338    0.046183    0.022986    0.677912    
#> 464: 0.360803    0.933737    3.380449    0.487210    0.046139    0.022982    0.677884    
#> 465: 0.360951    0.933638    3.380516    0.487156    0.046124    0.022967    0.677848    
#> 466: 0.361143    0.933633    3.380543    0.487247    0.046125    0.022961    0.677772    
#> 467: 0.361031    0.933615    3.380571    0.486988    0.046145    0.022950    0.677717    
#> 468: 0.360997    0.933579    3.380628    0.486792    0.046122    0.022960    0.677752    
#> 469: 0.361053    0.933689    3.380628    0.486869    0.046124    0.022967    0.677787    
#> 470: 0.360874    0.933767    3.380566    0.486997    0.046093    0.022976    0.677920    
#> 471: 0.360799    0.933802    3.380541    0.487159    0.046078    0.022982    0.677942    
#> 472: 0.360672    0.933823    3.380527    0.487028    0.046055    0.022971    0.677976    
#> 473: 0.360544    0.933863    3.380489    0.487018    0.046064    0.022962    0.677907    
#> 474: 0.360433    0.933844    3.380437    0.487080    0.046020    0.022980    0.677918    
#> 475: 0.360557    0.933964    3.380398    0.487307    0.046006    0.022981    0.677936    
#> 476: 0.360384    0.934009    3.380392    0.487024    0.045969    0.022975    0.677974    
#> 477: 0.360243    0.934040    3.380406    0.486837    0.045939    0.022974    0.677928    
#> 478: 0.360124    0.934049    3.380378    0.486929    0.045937    0.022973    0.677928    
#> 479: 0.360206    0.934073    3.380376    0.487344    0.045907    0.022964    0.677957    
#> 480: 0.360332    0.934142    3.380368    0.487662    0.045915    0.022951    0.677963    
#> 481: 0.360382    0.934217    3.380368    0.488031    0.045931    0.022942    0.677988    
#> 482: 0.360463    0.934275    3.380331    0.488250    0.045944    0.022917    0.677996    
#> 483: 0.360467    0.934314    3.380328    0.488277    0.045952    0.022907    0.677952    
#> 484: 0.360421    0.934275    3.380322    0.488151    0.045971    0.022902    0.677925    
#> 485: 0.360390    0.934244    3.380318    0.488077    0.045975    0.022894    0.677949    
#> 486: 0.360402    0.934290    3.380343    0.487918    0.045975    0.022880    0.677964    
#> 487: 0.360582    0.934350    3.380410    0.488218    0.046002    0.022869    0.677997    
#> 488: 0.360705    0.934369    3.380429    0.488615    0.045990    0.022858    0.677965    
#> 489: 0.360701    0.934363    3.380401    0.488579    0.046004    0.022844    0.677956    
#> 490: 0.360651    0.934399    3.380357    0.488419    0.045988    0.022838    0.677924    
#> 491: 0.360587    0.934496    3.380335    0.488278    0.045967    0.022836    0.677888    
#> 492: 0.360582    0.934573    3.380311    0.488305    0.045935    0.022851    0.677924    
#> 493: 0.360508    0.934633    3.380316    0.488371    0.045902    0.022850    0.677964    
#> 494: 0.360612    0.934703    3.380280    0.488542    0.045873    0.022843    0.677902    
#> 495: 0.360622    0.934744    3.380267    0.488604    0.045846    0.022842    0.677875    
#> 496: 0.360672    0.934730    3.380229    0.488614    0.045819    0.022832    0.677871    
#> 497: 0.360471    0.934728    3.380192    0.488424    0.045845    0.022828    0.677889    
#> 498: 0.360427    0.934703    3.380158    0.488390    0.045829    0.022829    0.677812    
#> 499: 0.360311    0.934732    3.380123    0.488381    0.045847    0.022823    0.677787    
#> 500: 0.360173    0.934728    3.380072    0.488334    0.045860    0.022806    0.677741    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.356725    0.962665    3.447872    0.392401    0.079297    0.016800    1.675653    
#> 002: 0.528229    1.017012    3.461338    0.372781    0.075332    0.015960    1.124710    
#> 003: 0.679269    1.014533    3.475624    0.354142    0.071565    0.015162    0.865604    
#> 004: 0.700649    1.061920    3.480510    0.349508    0.067987    0.014404    0.690940    
#> 005: 0.740282    1.092947    3.462748    0.351493    0.064588    0.013684    0.631125    
#> 006: 0.778190    1.079975    3.473441    0.442705    0.061358    0.013000    0.566965    
#> 007: 0.787390    1.080275    3.477433    0.550153    0.058290    0.013122    0.560236    
#> 008: 0.780522    1.074462    3.475983    0.522646    0.060770    0.014039    0.560428    
#> 009: 0.759644    1.058559    3.474709    0.517913    0.057731    0.013337    0.559541    
#> 010: 0.757521    1.071688    3.477390    0.533671    0.054845    0.018737    0.555614    
#> 011: 0.805872    1.085615    3.479165    0.506987    0.052103    0.017800    0.566216    
#> 012: 0.809103    1.077751    3.474402    0.583953    0.050253    0.019142    0.543592    
#> 013: 0.838841    1.064490    3.484445    0.619204    0.047740    0.019052    0.544639    
#> 014: 0.863967    1.059659    3.491692    0.673381    0.045353    0.018099    0.554747    
#> 015: 0.860059    1.060287    3.502442    0.639712    0.046781    0.017194    0.547033    
#> 016: 0.880095    1.064909    3.510483    0.618295    0.044442    0.019261    0.558522    
#> 017: 0.867331    1.066515    3.513162    0.587380    0.042220    0.018984    0.539187    
#> 018: 0.869742    1.057744    3.498782    0.596776    0.041151    0.018034    0.536654    
#> 019: 0.851720    1.069818    3.498197    0.566937    0.040164    0.017133    0.522361    
#> 020: 0.882028    1.060961    3.495060    0.642616    0.041375    0.019689    0.528100    
#> 021: 0.867048    1.052160    3.500288    0.633448    0.040189    0.018705    0.522277    
#> 022: 0.849624    1.059588    3.514205    0.601776    0.038180    0.022030    0.517713    
#> 023: 0.908824    1.063375    3.513241    0.578727    0.036285    0.020929    0.536237    
#> 024: 0.897323    1.086369    3.503524    0.606678    0.034471    0.019882    0.521806    
#> 025: 0.887874    1.060562    3.494826    0.666675    0.032747    0.021729    0.528822    
#> 026: 0.870826    1.081520    3.491269    0.633341    0.032143    0.020642    0.531974    
#> 027: 0.871447    1.081563    3.493378    0.669390    0.033761    0.022205    0.527350    
#> 028: 0.897748    1.067841    3.497217    0.776839    0.032073    0.021095    0.525599    
#> 029: 0.920114    1.076743    3.493427    0.806021    0.030469    0.020604    0.547088    
#> 030: 0.898611    1.094973    3.483692    0.812548    0.032233    0.020664    0.529536    
#> 031: 0.896443    1.072283    3.495041    0.823675    0.031623    0.021957    0.531260    
#> 032: 0.874900    1.063831    3.495179    0.782491    0.038507    0.021525    0.527577    
#> 033: 0.837088    1.080092    3.487042    0.743366    0.039740    0.022127    0.528731    
#> 034: 0.879634    1.095694    3.484968    0.736405    0.041590    0.021648    0.533093    
#> 035: 0.862455    1.083360    3.479560    0.699585    0.039511    0.020565    0.525183    
#> 036: 0.836525    1.089710    3.484075    0.664606    0.037535    0.019537    0.527546    
#> 037: 0.837802    1.082072    3.492634    0.631376    0.036671    0.022075    0.540481    
#> 038: 0.859497    1.076217    3.493047    0.599807    0.036452    0.021077    0.548038    
#> 039: 0.867789    1.063823    3.496700    0.688997    0.040889    0.022258    0.542718    
#> 040: 0.875743    1.052981    3.496428    0.658658    0.041916    0.021145    0.540844    
#> 041: 0.833500    1.051658    3.493742    0.625726    0.039820    0.020088    0.532690    
#> 042: 0.852303    1.065859    3.487687    0.618695    0.041745    0.019084    0.519259    
#> 043: 0.845371    1.078470    3.480297    0.658924    0.044477    0.018129    0.532881    
#> 044: 0.838924    1.085840    3.484651    0.625978    0.042254    0.018302    0.531563    
#> 045: 0.836637    1.096071    3.480035    0.684687    0.041812    0.021839    0.535165    
#> 046: 0.884600    1.071384    3.490677    0.739435    0.042735    0.020747    0.532613    
#> 047: 0.924367    1.067697    3.495522    0.786522    0.040598    0.019710    0.524602    
#> 048: 0.863357    1.063081    3.492259    0.747196    0.038568    0.020604    0.530452    
#> 049: 0.853776    1.054749    3.500197    0.709836    0.036639    0.019574    0.536636    
#> 050: 0.932803    1.037595    3.509628    0.798210    0.034808    0.021645    0.544861    
#> 051: 0.916955    1.047808    3.498962    0.758300    0.041226    0.020563    0.545264    
#> 052: 0.932321    1.050346    3.515760    0.720385    0.039945    0.019535    0.540072    
#> 053: 0.908135    1.040648    3.516550    0.684366    0.038204    0.019025    0.542476    
#> 054: 0.905923    1.045938    3.510553    0.650147    0.036610    0.019899    0.556617    
#> 055: 0.884131    1.051646    3.517462    0.617640    0.038321    0.019568    0.558192    
#> 056: 0.912786    1.041822    3.509900    0.625477    0.048890    0.018589    0.561960    
#> 057: 0.908475    1.035682    3.517292    0.611740    0.046446    0.017660    0.562607    
#> 058: 0.909812    1.051533    3.505356    0.634786    0.044124    0.020162    0.550759    
#> 059: 0.870276    1.042125    3.501391    0.679169    0.046198    0.019154    0.548747    
#> 060: 0.903949    1.043167    3.497163    0.745662    0.043888    0.018196    0.549442    
#> 061: 0.882109    1.042737    3.513491    0.708379    0.041694    0.020852    0.550209    
#> 062: 0.892941    1.071795    3.502917    0.725328    0.039609    0.022237    0.557787    
#> 063: 0.948157    1.050212    3.503547    0.745613    0.041461    0.022831    0.565688    
#> 064: 0.933539    1.040267    3.511418    0.708332    0.043204    0.021690    0.563128    
#> 065: 0.915823    1.038368    3.498770    0.701968    0.047472    0.020605    0.543531    
#> 066: 0.903895    1.054842    3.511205    0.738648    0.045099    0.019575    0.533327    
#> 067: 0.865977    1.037408    3.497034    0.701716    0.042844    0.018596    0.525194    
#> 068: 0.847201    1.056783    3.501000    0.666630    0.040702    0.018506    0.521331    
#> 069: 0.833897    1.063554    3.487699    0.651785    0.039876    0.020122    0.539953    
#> 070: 0.860656    1.053600    3.502015    0.649580    0.038036    0.020495    0.533583    
#> 071: 0.842934    1.072639    3.494302    0.617101    0.036134    0.020780    0.551033    
#> 072: 0.830833    1.056219    3.502775    0.586246    0.041983    0.021774    0.544361    
#> 073: 0.852813    1.058408    3.507322    0.558901    0.047568    0.020686    0.531773    
#> 074: 0.850859    1.042688    3.501991    0.536309    0.045189    0.019651    0.530041    
#> 075: 0.874129    1.044985    3.510654    0.639128    0.050460    0.020342    0.526506    
#> 076: 0.885368    1.048846    3.514252    0.644488    0.047937    0.020770    0.528791    
#> 077: 0.878531    1.047063    3.503125    0.618545    0.045540    0.020424    0.536914    
#> 078: 0.889567    1.061439    3.498220    0.678866    0.043263    0.020821    0.532158    
#> 079: 0.886575    1.075402    3.494093    0.779794    0.041200    0.021527    0.538895    
#> 080: 0.871863    1.066071    3.489931    0.757490    0.045080    0.021830    0.547749    
#> 081: 0.861384    1.083939    3.488095    0.719616    0.042826    0.021146    0.544524    
#> 082: 0.831330    1.058469    3.493103    0.683635    0.040685    0.022064    0.553886    
#> 083: 0.864178    1.067803    3.505383    0.649453    0.039246    0.024033    0.543542    
#> 084: 0.843337    1.064367    3.499900    0.616980    0.038635    0.022831    0.541608    
#> 085: 0.855793    1.070736    3.509002    0.608847    0.038429    0.021689    0.538146    
#> 086: 0.852428    1.068603    3.502284    0.578405    0.036508    0.020605    0.537707    
#> 087: 0.821494    1.068152    3.497648    0.549484    0.036502    0.019575    0.550951    
#> 088: 0.777647    1.060937    3.499666    0.522010    0.038083    0.018596    0.538689    
#> 089: 0.796847    1.072672    3.478943    0.542961    0.036179    0.017666    0.545049    
#> 090: 0.787910    1.068325    3.479100    0.530982    0.040410    0.016994    0.559593    
#> 091: 0.804732    1.054194    3.469941    0.504433    0.042607    0.016817    0.560923    
#> 092: 0.786054    1.072604    3.474530    0.547397    0.050149    0.016937    0.548869    
#> 093: 0.802937    1.070891    3.485217    0.574099    0.051978    0.016090    0.549850    
#> 094: 0.826976    1.081883    3.482969    0.555645    0.054161    0.015991    0.547312    
#> 095: 0.828281    1.088827    3.487673    0.631144    0.051453    0.015191    0.549312    
#> 096: 0.793772    1.072528    3.482405    0.599587    0.052173    0.015905    0.548595    
#> 097: 0.877588    1.067850    3.492454    0.618549    0.050652    0.016120    0.545509    
#> 098: 0.850869    1.075187    3.498870    0.587621    0.048120    0.015314    0.549408    
#> 099: 0.852055    1.063973    3.489735    0.656911    0.045714    0.014548    0.535752    
#> 100: 0.836092    1.071546    3.492999    0.670950    0.043428    0.017107    0.529187    
#> 101: 0.801025    1.070185    3.473418    0.637402    0.041257    0.019666    0.540415    
#> 102: 0.765201    1.082529    3.474112    0.605532    0.039194    0.018682    0.550517    
#> 103: 0.812748    1.080281    3.482962    0.592375    0.037739    0.020535    0.531666    
#> 104: 0.793465    1.079565    3.500954    0.562756    0.040726    0.019508    0.536996    
#> 105: 0.857462    1.071244    3.497685    0.649225    0.041504    0.020473    0.534731    
#> 106: 0.880911    1.054785    3.486123    0.705308    0.040831    0.023306    0.531566    
#> 107: 0.897262    1.061846    3.487518    0.820210    0.048593    0.022141    0.537723    
#> 108: 0.847567    1.064963    3.495460    0.779199    0.046164    0.021034    0.552778    
#> 109: 0.853254    1.069406    3.505424    0.740239    0.043855    0.019982    0.545828    
#> 110: 0.883803    1.043294    3.494801    0.703227    0.041663    0.018983    0.547104    
#> 111: 0.868064    1.060758    3.503599    0.668066    0.039580    0.018034    0.540343    
#> 112: 0.857722    1.050155    3.492190    0.634663    0.037601    0.017132    0.536965    
#> 113: 0.850288    1.073630    3.490730    0.617884    0.038976    0.017403    0.519362    
#> 114: 0.876312    1.078205    3.486177    0.668175    0.040033    0.019015    0.519866    
#> 115: 0.898639    1.062285    3.480473    0.773454    0.041558    0.018279    0.537607    
#> 116: 0.904759    1.076282    3.482729    0.818171    0.039481    0.020699    0.537766    
#> 117: 0.904337    1.085851    3.491863    0.841674    0.037507    0.021442    0.547282    
#> 118: 0.891887    1.078052    3.487125    0.829441    0.035631    0.023067    0.535097    
#> 119: 0.885170    1.073478    3.492951    0.824133    0.033862    0.026607    0.537007    
#> 120: 0.857002    1.055652    3.496149    0.782927    0.033305    0.025341    0.543186    
#> 121: 0.853223    1.072011    3.494492    0.766816    0.031640    0.025531    0.544342    
#> 122: 0.860631    1.061699    3.498421    0.728475    0.036440    0.024255    0.544082    
#> 123: 0.882248    1.072556    3.490605    0.692051    0.035952    0.023042    0.548132    
#> 124: 0.820091    1.102617    3.492432    0.657449    0.036327    0.021890    0.547001    
#> 125: 0.897569    1.088041    3.489044    0.729291    0.034510    0.020795    0.533900    
#> 126: 0.868379    1.090975    3.475574    0.729905    0.032785    0.022453    0.535539    
#> 127: 0.913990    1.081635    3.480425    0.879156    0.040089    0.024636    0.533789    
#> 128: 0.902235    1.073808    3.488946    0.835199    0.038085    0.023404    0.539369    
#> 129: 0.903041    1.091761    3.494605    0.812013    0.040501    0.022234    0.538168    
#> 130: 0.870782    1.086532    3.480119    0.771412    0.041889    0.021122    0.538798    
#> 131: 0.835415    1.064551    3.479894    0.732841    0.039795    0.020066    0.531092    
#> 132: 0.868009    1.072311    3.488626    0.696199    0.040621    0.019063    0.535061    
#> 133: 0.908155    1.056409    3.493529    0.749513    0.046075    0.018110    0.528223    
#> 134: 0.883645    1.039230    3.510184    0.712037    0.043772    0.017204    0.533963    
#> 135: 0.892509    1.047869    3.509702    0.676435    0.046687    0.019171    0.521172    
#> 136: 0.891750    1.041762    3.507912    0.642613    0.044353    0.018212    0.514849    
#> 137: 0.893064    1.039601    3.512818    0.610483    0.042135    0.017426    0.521154    
#> 138: 0.851938    1.058282    3.504356    0.579959    0.041023    0.017397    0.527077    
#> 139: 0.823711    1.064128    3.511393    0.551169    0.039434    0.016527    0.533001    
#> 140: 0.877575    1.067472    3.512475    0.608971    0.046938    0.018854    0.533117    
#> 141: 0.914468    1.068397    3.504779    0.757710    0.053745    0.018832    0.529243    
#> 142: 0.964620    1.047788    3.513206    0.847882    0.051058    0.017891    0.546868    
#> 143: 0.910533    1.044154    3.508287    0.805488    0.048505    0.020095    0.534484    
#> 144: 0.914245    1.049212    3.512251    0.777108    0.046080    0.019090    0.533504    
#> 145: 0.901852    1.065831    3.500756    0.738253    0.044194    0.018136    0.524599    
#> 146: 0.861743    1.073805    3.500062    0.701340    0.049094    0.017286    0.534131    
#> 147: 0.845200    1.057711    3.488985    0.666273    0.046639    0.017035    0.537661    
#> 148: 0.795382    1.069277    3.492218    0.632960    0.044307    0.017648    0.532760    
#> 149: 0.851475    1.053446    3.504144    0.601312    0.052224    0.016765    0.536242    
#> 150: 0.870088    1.055677    3.497887    0.571246    0.049613    0.017294    0.542666    
#> 151: 0.856806    1.070932    3.492824    0.662649    0.048104    0.019179    0.523737    
#> 152: 0.829512    1.069814    3.493133    0.645067    0.040684    0.020096    0.538422    
#> 153: 0.847521    1.072212    3.497370    0.655747    0.033575    0.022080    0.534988    
#> 154: 0.839201    1.088387    3.492053    0.635829    0.038600    0.022353    0.527425    
#> 155: 0.837683    1.068105    3.493366    0.615594    0.042340    0.020924    0.529414    
#> 156: 0.850732    1.073076    3.499558    0.533617    0.059625    0.019462    0.540591    
#> 157: 0.913124    1.042061    3.513247    0.689326    0.054176    0.020071    0.538866    
#> 158: 0.928758    1.062195    3.507559    0.678970    0.046454    0.019625    0.551606    
#> 159: 0.834534    1.061912    3.509705    0.547714    0.039659    0.017232    0.557991    
#> 160: 0.865472    1.043280    3.508661    0.633179    0.044833    0.012672    0.557778    
#> 161: 0.850982    1.073635    3.498114    0.643976    0.046438    0.012718    0.557749    
#> 162: 0.827722    1.100412    3.482080    0.587094    0.051544    0.014772    0.566708    
#> 163: 0.834674    1.082949    3.483393    0.520926    0.056439    0.014102    0.560885    
#> 164: 0.863273    1.075741    3.486873    0.633709    0.044634    0.016707    0.540426    
#> 165: 0.902648    1.065292    3.493882    0.747419    0.046699    0.014364    0.538237    
#> 166: 0.900439    1.084176    3.492789    0.773990    0.047003    0.016295    0.535462    
#> 167: 0.904290    1.089524    3.495031    0.881137    0.046861    0.014544    0.545944    
#> 168: 0.912790    1.074305    3.492653    0.757223    0.044460    0.016710    0.548484    
#> 169: 0.893493    1.093996    3.492591    0.784928    0.047966    0.013190    0.563260    
#> 170: 0.847974    1.068416    3.494370    0.614316    0.040644    0.015735    0.549572    
#> 171: 0.801097    1.060856    3.489636    0.532988    0.042710    0.019250    0.538220    
#> 172: 0.782072    1.081782    3.488951    0.514096    0.037951    0.019526    0.526983    
#> 173: 0.804091    1.094963    3.485451    0.533594    0.044924    0.016044    0.517697    
#> 174: 0.839363    1.077665    3.490286    0.579600    0.045149    0.018474    0.529486    
#> 175: 0.827246    1.085989    3.479203    0.596123    0.041196    0.021951    0.523141    
#> 176: 0.826647    1.082750    3.495501    0.524840    0.046843    0.022370    0.523110    
#> 177: 0.850953    1.074606    3.499448    0.553036    0.040304    0.027712    0.520887    
#> 178: 0.853647    1.074318    3.496999    0.599339    0.034507    0.024863    0.528931    
#> 179: 0.933358    1.082765    3.499245    0.760372    0.031911    0.025049    0.549864    
#> 180: 0.877082    1.077261    3.503073    0.663183    0.031048    0.024730    0.535445    
#> 181: 0.880262    1.063532    3.487257    0.649896    0.024444    0.026249    0.542076    
#> 182: 0.859911    1.059553    3.487467    0.626310    0.025236    0.028790    0.558000    
#> 183: 0.883269    1.070771    3.484943    0.703758    0.024368    0.026116    0.551346    
#> 184: 0.821798    1.069315    3.483760    0.627695    0.023544    0.027719    0.542610    
#> 185: 0.811418    1.078896    3.484582    0.617225    0.029414    0.025102    0.545868    
#> 186: 0.835568    1.076473    3.496106    0.628736    0.024768    0.028651    0.550743    
#> 187: 0.815859    1.066356    3.498611    0.595644    0.030090    0.021822    0.557137    
#> 188: 0.801617    1.079489    3.489590    0.529944    0.032759    0.023549    0.553953    
#> 189: 0.799241    1.091649    3.490861    0.560651    0.031328    0.026406    0.556804    
#> 190: 0.795592    1.092125    3.490403    0.566343    0.031389    0.023945    0.542612    
#> 191: 0.826787    1.096734    3.486174    0.618521    0.030501    0.021884    0.530480    
#> 192: 0.837486    1.077075    3.485437    0.616710    0.036212    0.019504    0.525336    
#> 193: 0.869878    1.084970    3.495446    0.648364    0.040402    0.017650    0.534666    
#> 194: 0.822595    1.083183    3.484556    0.547394    0.037682    0.018813    0.550278    
#> 195: 0.784718    1.077350    3.480482    0.585886    0.031838    0.019717    0.529726    
#> 196: 0.775441    1.076947    3.475070    0.570080    0.031080    0.018938    0.535658    
#> 197: 0.797115    1.090367    3.493132    0.636507    0.038026    0.019704    0.537906    
#> 198: 0.884178    1.072480    3.488078    0.723939    0.043135    0.020276    0.521728    
#> 199: 0.828625    1.061894    3.485968    0.638621    0.038546    0.019367    0.537041    
#> 200: 0.857479    1.058357    3.488791    0.697685    0.039732    0.021194    0.538678    
#> 201: 0.856606    1.056273    3.492667    0.698405    0.040326    0.021016    0.531377    
#> 202: 0.854286    1.060888    3.491516    0.690633    0.037559    0.021954    0.533465    
#> 203: 0.870264    1.059745    3.491059    0.717562    0.035365    0.022686    0.533375    
#> 204: 0.879593    1.056864    3.493916    0.753021    0.035522    0.022955    0.533957    
#> 205: 0.888241    1.060511    3.493302    0.772393    0.035825    0.023108    0.535366    
#> 206: 0.888985    1.064216    3.492153    0.776782    0.036312    0.023022    0.535134    
#> 207: 0.891967    1.065664    3.491877    0.801572    0.036778    0.022961    0.535281    
#> 208: 0.889540    1.067481    3.492165    0.791465    0.036408    0.023151    0.534002    
#> 209: 0.884707    1.067512    3.491250    0.783593    0.035962    0.023465    0.533754    
#> 210: 0.881414    1.066671    3.491603    0.770145    0.035675    0.023859    0.532773    
#> 211: 0.881701    1.066723    3.492283    0.760602    0.035634    0.024004    0.531768    
#> 212: 0.883348    1.066310    3.492552    0.755024    0.035772    0.024152    0.532337    
#> 213: 0.884789    1.063551    3.493793    0.744265    0.036073    0.024304    0.533010    
#> 214: 0.887101    1.062510    3.495082    0.736789    0.036363    0.024215    0.533295    
#> 215: 0.887829    1.061942    3.496825    0.725565    0.036753    0.024129    0.533340    
#> 216: 0.889569    1.060616    3.498043    0.716226    0.037249    0.024183    0.533781    
#> 217: 0.889530    1.060334    3.498551    0.709900    0.037769    0.024084    0.533624    
#> 218: 0.889217    1.060388    3.498397    0.704534    0.037687    0.024003    0.533963    
#> 219: 0.888136    1.059951    3.497860    0.701138    0.037749    0.023935    0.534634    
#> 220: 0.883578    1.060404    3.496914    0.697545    0.037953    0.023736    0.535286    
#> 221: 0.880809    1.060771    3.496384    0.694389    0.038099    0.023547    0.535179    
#> 222: 0.878505    1.060914    3.496097    0.689266    0.038453    0.023386    0.534914    
#> 223: 0.876484    1.061603    3.495689    0.684025    0.038610    0.023265    0.534759    
#> 224: 0.875748    1.062756    3.495537    0.679685    0.038685    0.023321    0.534450    
#> 225: 0.872875    1.062363    3.495529    0.673991    0.038722    0.023328    0.534589    
#> 226: 0.872903    1.061982    3.495629    0.673234    0.038861    0.023330    0.534409    
#> 227: 0.873473    1.061783    3.495605    0.673908    0.038670    0.023327    0.534050    
#> 228: 0.874648    1.062179    3.495466    0.675826    0.038649    0.023225    0.533829    
#> 229: 0.874553    1.062349    3.495399    0.676912    0.038497    0.023142    0.533518    
#> 230: 0.874334    1.062459    3.495338    0.675340    0.038558    0.023158    0.533379    
#> 231: 0.873065    1.063088    3.495199    0.671693    0.038671    0.023095    0.533062    
#> 232: 0.871443    1.063406    3.495100    0.667119    0.038755    0.023060    0.532465    
#> 233: 0.870419    1.063320    3.494914    0.665622    0.038736    0.022941    0.532453    
#> 234: 0.869142    1.063437    3.494648    0.663444    0.038633    0.022966    0.532496    
#> 235: 0.868205    1.063169    3.494393    0.661778    0.038622    0.022888    0.531928    
#> 236: 0.868544    1.063285    3.494207    0.663420    0.038764    0.022845    0.532029    
#> 237: 0.868092    1.062948    3.494224    0.661082    0.038825    0.022918    0.532685    
#> 238: 0.867904    1.062904    3.494346    0.658398    0.038762    0.022908    0.533189    
#> 239: 0.867215    1.063287    3.494172    0.656033    0.038745    0.022887    0.533288    
#> 240: 0.867188    1.063396    3.494310    0.655924    0.038600    0.022834    0.533378    
#> 241: 0.867284    1.062686    3.494300    0.656132    0.038546    0.022717    0.533763    
#> 242: 0.867526    1.062039    3.494286    0.653613    0.038481    0.022636    0.533974    
#> 243: 0.867239    1.062094    3.494227    0.651156    0.038462    0.022589    0.534231    
#> 244: 0.867091    1.062292    3.494569    0.649104    0.038433    0.022438    0.534271    
#> 245: 0.866849    1.062172    3.494871    0.647254    0.038379    0.022464    0.534573    
#> 246: 0.866995    1.062351    3.494962    0.646131    0.038369    0.022522    0.534751    
#> 247: 0.867238    1.062203    3.495088    0.645568    0.038230    0.022465    0.535157    
#> 248: 0.867004    1.062279    3.495150    0.642891    0.038171    0.022479    0.535276    
#> 249: 0.866315    1.062336    3.495266    0.642013    0.038217    0.022494    0.535155    
#> 250: 0.866534    1.062457    3.495339    0.642308    0.038139    0.022470    0.535036    
#> 251: 0.866319    1.062613    3.495244    0.643230    0.038250    0.022448    0.534880    
#> 252: 0.866064    1.063035    3.495185    0.642478    0.038203    0.022472    0.534892    
#> 253: 0.865158    1.063417    3.494942    0.641548    0.038108    0.022437    0.534878    
#> 254: 0.864569    1.063783    3.494742    0.641550    0.037958    0.022441    0.535044    
#> 255: 0.863673    1.064074    3.494472    0.641366    0.037865    0.022508    0.535045    
#> 256: 0.862718    1.064138    3.494270    0.641021    0.037764    0.022580    0.535075    
#> 257: 0.862152    1.063997    3.494175    0.641476    0.037664    0.022661    0.535143    
#> 258: 0.861872    1.063962    3.494139    0.641105    0.037568    0.022684    0.535052    
#> 259: 0.861775    1.064078    3.494023    0.641024    0.037444    0.022693    0.535200    
#> 260: 0.861266    1.064157    3.494016    0.640733    0.037327    0.022679    0.535343    
#> 261: 0.860615    1.064111    3.494008    0.639086    0.037184    0.022668    0.535699    
#> 262: 0.861390    1.064399    3.493942    0.641706    0.037240    0.022648    0.535653    
#> 263: 0.861010    1.064518    3.493896    0.642135    0.037259    0.022634    0.535817    
#> 264: 0.860395    1.064656    3.493631    0.643350    0.037236    0.022583    0.536011    
#> 265: 0.860379    1.064745    3.493534    0.644534    0.037209    0.022547    0.536055    
#> 266: 0.860949    1.065011    3.493588    0.645530    0.037293    0.022525    0.536148    
#> 267: 0.861083    1.064863    3.493785    0.646265    0.037248    0.022500    0.536341    
#> 268: 0.861225    1.064663    3.493726    0.646648    0.037230    0.022493    0.536368    
#> 269: 0.861859    1.064413    3.493775    0.647665    0.037235    0.022503    0.536458    
#> 270: 0.862126    1.064370    3.493832    0.647437    0.037372    0.022451    0.536473    
#> 271: 0.862146    1.064422    3.493839    0.647202    0.037538    0.022404    0.536546    
#> 272: 0.861760    1.064288    3.493746    0.646507    0.037558    0.022379    0.536747    
#> 273: 0.860982    1.064499    3.493790    0.645810    0.037561    0.022346    0.537010    
#> 274: 0.860959    1.064814    3.493830    0.644741    0.037706    0.022317    0.537155    
#> 275: 0.860603    1.065094    3.493775    0.643988    0.037743    0.022317    0.537139    
#> 276: 0.860537    1.065288    3.493724    0.644064    0.037849    0.022266    0.537225    
#> 277: 0.860273    1.065635    3.493822    0.643729    0.037900    0.022241    0.537269    
#> 278: 0.860266    1.065726    3.493970    0.644128    0.037968    0.022212    0.537292    
#> 279: 0.859771    1.065578    3.494049    0.643017    0.038007    0.022199    0.537359    
#> 280: 0.859107    1.065610    3.494095    0.641822    0.037969    0.022181    0.537285    
#> 281: 0.859051    1.065609    3.494212    0.641280    0.038002    0.022207    0.537281    
#> 282: 0.859225    1.065545    3.494379    0.641346    0.038003    0.022181    0.537423    
#> 283: 0.859704    1.065623    3.494578    0.641138    0.037997    0.022131    0.537577    
#> 284: 0.860191    1.065268    3.494739    0.641763    0.037971    0.022064    0.537482    
#> 285: 0.860137    1.065151    3.494688    0.641634    0.038023    0.022026    0.537382    
#> 286: 0.859941    1.065317    3.494569    0.641444    0.038046    0.021981    0.537345    
#> 287: 0.859542    1.065479    3.494425    0.642092    0.038114    0.021945    0.537348    
#> 288: 0.859365    1.065487    3.494342    0.641735    0.038031    0.021998    0.537430    
#> 289: 0.859874    1.065542    3.494370    0.642406    0.037922    0.022073    0.537371    
#> 290: 0.860017    1.065503    3.494348    0.642410    0.037912    0.022082    0.537545    
#> 291: 0.859928    1.065714    3.494413    0.642015    0.037943    0.022076    0.537434    
#> 292: 0.859649    1.065931    3.494322    0.641904    0.037964    0.022093    0.537325    
#> 293: 0.859426    1.066077    3.494124    0.642528    0.037916    0.022082    0.537367    
#> 294: 0.858872    1.066293    3.493869    0.642795    0.037854    0.022077    0.537406    
#> 295: 0.858299    1.066150    3.493724    0.642228    0.037844    0.022083    0.537413    
#> 296: 0.857745    1.066153    3.493588    0.641252    0.037894    0.022079    0.537506    
#> 297: 0.857377    1.066305    3.493490    0.641004    0.037981    0.022069    0.537671    
#> 298: 0.857489    1.066264    3.493410    0.641906    0.037987    0.022037    0.537642    
#> 299: 0.857083    1.066290    3.493377    0.641052    0.038013    0.021998    0.537614    
#> 300: 0.857026    1.066177    3.493471    0.640627    0.038016    0.021996    0.537694    
#> 301: 0.857201    1.066058    3.493513    0.639532    0.038024    0.021993    0.537884    
#> 302: 0.857258    1.066033    3.493473    0.639294    0.038018    0.021995    0.537977    
#> 303: 0.856999    1.066138    3.493412    0.638893    0.038065    0.021969    0.537942    
#> 304: 0.857018    1.066233    3.493392    0.639091    0.038132    0.021952    0.537941    
#> 305: 0.856842    1.066070    3.493337    0.639097    0.038188    0.021931    0.537902    
#> 306: 0.856344    1.065958    3.493235    0.639313    0.038189    0.021911    0.537883    
#> 307: 0.856126    1.065842    3.493234    0.639582    0.038155    0.021921    0.538077    
#> 308: 0.856004    1.065691    3.493279    0.639482    0.038163    0.021935    0.538202    
#> 309: 0.856370    1.065621    3.493358    0.639997    0.038147    0.021952    0.538248    
#> 310: 0.856470    1.065654    3.493305    0.639689    0.038089    0.021941    0.538447    
#> 311: 0.856544    1.065654    3.493341    0.639973    0.038011    0.021947    0.538478    
#> 312: 0.856120    1.065524    3.493329    0.639259    0.037969    0.021995    0.538455    
#> 313: 0.855501    1.065357    3.493246    0.638207    0.037899    0.022006    0.538582    
#> 314: 0.855022    1.065359    3.493205    0.637434    0.037850    0.021998    0.538673    
#> 315: 0.854867    1.065348    3.493148    0.637153    0.037824    0.021951    0.538619    
#> 316: 0.854699    1.065357    3.493097    0.636747    0.037831    0.021923    0.538522    
#> 317: 0.854761    1.065317    3.493157    0.636136    0.037868    0.021931    0.538514    
#> 318: 0.854808    1.065301    3.493154    0.635629    0.037891    0.021922    0.538542    
#> 319: 0.854901    1.065217    3.493306    0.635077    0.037907    0.021930    0.538631    
#> 320: 0.854921    1.065086    3.493337    0.635002    0.037944    0.021922    0.538837    
#> 321: 0.854902    1.065104    3.493362    0.634776    0.037973    0.021928    0.538850    
#> 322: 0.854475    1.065095    3.493344    0.633973    0.037966    0.021930    0.538804    
#> 323: 0.853956    1.065080    3.493323    0.633287    0.037959    0.021919    0.538783    
#> 324: 0.853489    1.065298    3.493251    0.632447    0.038024    0.021932    0.538758    
#> 325: 0.853260    1.065557    3.493168    0.632031    0.038022    0.021935    0.538690    
#> 326: 0.852969    1.065610    3.493119    0.631912    0.037969    0.021923    0.538682    
#> 327: 0.852904    1.065591    3.493073    0.631690    0.037968    0.021913    0.538572    
#> 328: 0.852771    1.065686    3.493030    0.631554    0.037987    0.021893    0.538452    
#> 329: 0.852979    1.065717    3.493052    0.632103    0.037993    0.021895    0.538355    
#> 330: 0.852994    1.065713    3.493055    0.631765    0.037948    0.021893    0.538258    
#> 331: 0.853175    1.065835    3.493079    0.631848    0.037967    0.021888    0.538067    
#> 332: 0.853395    1.065903    3.493118    0.631836    0.037991    0.021857    0.537980    
#> 333: 0.853419    1.065943    3.493063    0.631467    0.037978    0.021822    0.537979    
#> 334: 0.853206    1.065954    3.493066    0.630829    0.038017    0.021826    0.537951    
#> 335: 0.852909    1.066030    3.493016    0.630527    0.037974    0.021832    0.537951    
#> 336: 0.852343    1.066108    3.492949    0.630016    0.037908    0.021851    0.538055    
#> 337: 0.851975    1.066380    3.492827    0.629811    0.037929    0.021872    0.538086    
#> 338: 0.851644    1.066576    3.492721    0.629405    0.037958    0.021874    0.538029    
#> 339: 0.851132    1.066719    3.492612    0.629061    0.038015    0.021868    0.538032    
#> 340: 0.850881    1.066644    3.492539    0.629017    0.038070    0.021853    0.538051    
#> 341: 0.850950    1.066621    3.492504    0.629421    0.038140    0.021832    0.538011    
#> 342: 0.850858    1.066497    3.492529    0.629384    0.038162    0.021790    0.537959    
#> 343: 0.850624    1.066481    3.492573    0.628837    0.038167    0.021761    0.537982    
#> 344: 0.850939    1.066462    3.492633    0.629452    0.038176    0.021749    0.537989    
#> 345: 0.851072    1.066466    3.492635    0.629932    0.038129    0.021743    0.537933    
#> 346: 0.850926    1.066571    3.492575    0.629895    0.038115    0.021740    0.537850    
#> 347: 0.850617    1.066563    3.492536    0.629512    0.038091    0.021740    0.537811    
#> 348: 0.850314    1.066742    3.492434    0.629927    0.038113    0.021751    0.537852    
#> 349: 0.850110    1.066790    3.492323    0.630201    0.038084    0.021751    0.537839    
#> 350: 0.849547    1.066796    3.492158    0.630013    0.038081    0.021765    0.537843    
#> 351: 0.849405    1.066925    3.492060    0.630219    0.038050    0.021785    0.537914    
#> 352: 0.849068    1.067048    3.492032    0.630402    0.038040    0.021804    0.538013    
#> 353: 0.849024    1.067237    3.491979    0.630487    0.038011    0.021828    0.538020    
#> 354: 0.848891    1.067397    3.491894    0.630350    0.037989    0.021811    0.537956    
#> 355: 0.848924    1.067337    3.491863    0.630080    0.037999    0.021769    0.537867    
#> 356: 0.849084    1.067270    3.491945    0.629782    0.037995    0.021745    0.537917    
#> 357: 0.849552    1.067327    3.491962    0.630343    0.038010    0.021708    0.537875    
#> 358: 0.849503    1.067389    3.491966    0.629815    0.038026    0.021678    0.537773    
#> 359: 0.849462    1.067495    3.491933    0.629270    0.037991    0.021644    0.537894    
#> 360: 0.849335    1.067522    3.491897    0.628622    0.037993    0.021623    0.537911    
#> 361: 0.849101    1.067509    3.491855    0.628181    0.037979    0.021612    0.537941    
#> 362: 0.849036    1.067540    3.491829    0.627910    0.037970    0.021601    0.537824    
#> 363: 0.849104    1.067519    3.491872    0.627527    0.037982    0.021576    0.537681    
#> 364: 0.849183    1.067521    3.491913    0.626861    0.038010    0.021557    0.537673    
#> 365: 0.849110    1.067428    3.492000    0.626098    0.037991    0.021567    0.537769    
#> 366: 0.849025    1.067404    3.491983    0.625694    0.037987    0.021558    0.537852    
#> 367: 0.848790    1.067341    3.491952    0.624830    0.037989    0.021546    0.537899    
#> 368: 0.848701    1.067427    3.491944    0.623922    0.037967    0.021546    0.537827    
#> 369: 0.848503    1.067411    3.491937    0.623475    0.037955    0.021555    0.537834    
#> 370: 0.848288    1.067408    3.491927    0.622909    0.037946    0.021574    0.537806    
#> 371: 0.848134    1.067418    3.491888    0.622987    0.037956    0.021578    0.537799    
#> 372: 0.848033    1.067449    3.491851    0.622956    0.037973    0.021596    0.537746    
#> 373: 0.847822    1.067593    3.491754    0.623170    0.037948    0.021608    0.537729    
#> 374: 0.847777    1.067645    3.491744    0.623050    0.037895    0.021623    0.537681    
#> 375: 0.847710    1.067633    3.491777    0.622508    0.037859    0.021652    0.537744    
#> 376: 0.847646    1.067662    3.491824    0.621960    0.037824    0.021670    0.537784    
#> 377: 0.847679    1.067679    3.491794    0.621949    0.037802    0.021691    0.537757    
#> 378: 0.847798    1.067711    3.491758    0.622631    0.037759    0.021688    0.537756    
#> 379: 0.847821    1.067622    3.491737    0.623050    0.037716    0.021690    0.537755    
#> 380: 0.847732    1.067544    3.491729    0.622775    0.037705    0.021715    0.537752    
#> 381: 0.847535    1.067444    3.491732    0.622391    0.037673    0.021738    0.537731    
#> 382: 0.847328    1.067436    3.491730    0.622174    0.037620    0.021731    0.537683    
#> 383: 0.847266    1.067394    3.491753    0.622113    0.037568    0.021729    0.537604    
#> 384: 0.847010    1.067326    3.491779    0.621618    0.037541    0.021738    0.537579    
#> 385: 0.847051    1.067277    3.491819    0.621408    0.037504    0.021740    0.537508    
#> 386: 0.847198    1.067404    3.491850    0.621202    0.037462    0.021740    0.537537    
#> 387: 0.847307    1.067501    3.491894    0.621432    0.037422    0.021737    0.537556    
#> 388: 0.847348    1.067540    3.491908    0.621553    0.037395    0.021734    0.537497    
#> 389: 0.847213    1.067474    3.491876    0.621188    0.037412    0.021719    0.537515    
#> 390: 0.847119    1.067537    3.491873    0.620949    0.037403    0.021709    0.537511    
#> 391: 0.847244    1.067531    3.491895    0.620773    0.037393    0.021708    0.537447    
#> 392: 0.847160    1.067498    3.491946    0.620328    0.037359    0.021707    0.537453    
#> 393: 0.847085    1.067459    3.491957    0.620047    0.037377    0.021702    0.537391    
#> 394: 0.847114    1.067433    3.491903    0.619824    0.037347    0.021685    0.537458    
#> 395: 0.847134    1.067474    3.491889    0.619758    0.037358    0.021671    0.537474    
#> 396: 0.847063    1.067557    3.491836    0.619570    0.037379    0.021657    0.537434    
#> 397: 0.847085    1.067585    3.491857    0.619535    0.037371    0.021670    0.537438    
#> 398: 0.847271    1.067530    3.491914    0.619439    0.037368    0.021685    0.537472    
#> 399: 0.847368    1.067509    3.491992    0.619527    0.037341    0.021700    0.537466    
#> 400: 0.847405    1.067504    3.492012    0.619582    0.037300    0.021707    0.537462    
#> 401: 0.847525    1.067539    3.492019    0.620016    0.037284    0.021736    0.537427    
#> 402: 0.847614    1.067611    3.492021    0.620205    0.037262    0.021753    0.537446    
#> 403: 0.847862    1.067574    3.492046    0.620925    0.037261    0.021743    0.537451    
#> 404: 0.847932    1.067626    3.492011    0.621319    0.037273    0.021741    0.537393    
#> 405: 0.847965    1.067555    3.492045    0.621627    0.037272    0.021751    0.537356    
#> 406: 0.847919    1.067545    3.492006    0.621596    0.037252    0.021784    0.537317    
#> 407: 0.847889    1.067624    3.492015    0.621685    0.037243    0.021802    0.537336    
#> 408: 0.847954    1.067782    3.492023    0.621692    0.037291    0.021803    0.537318    
#> 409: 0.847937    1.067781    3.492000    0.621699    0.037303    0.021788    0.537233    
#> 410: 0.847881    1.067847    3.491991    0.621514    0.037330    0.021773    0.537182    
#> 411: 0.847965    1.067721    3.491972    0.622012    0.037355    0.021743    0.537218    
#> 412: 0.848010    1.067757    3.491961    0.622268    0.037381    0.021719    0.537306    
#> 413: 0.847936    1.067794    3.491952    0.622324    0.037374    0.021701    0.537416    
#> 414: 0.848012    1.067806    3.491971    0.622947    0.037381    0.021685    0.537431    
#> 415: 0.848174    1.067787    3.491967    0.622948    0.037395    0.021674    0.537428    
#> 416: 0.848256    1.067785    3.492007    0.623037    0.037385    0.021659    0.537459    
#> 417: 0.848197    1.067771    3.492014    0.622704    0.037381    0.021639    0.537547    
#> 418: 0.848108    1.067745    3.492036    0.622594    0.037387    0.021636    0.537524    
#> 419: 0.848059    1.067775    3.492027    0.622572    0.037424    0.021632    0.537491    
#> 420: 0.848134    1.067787    3.492040    0.622430    0.037463    0.021622    0.537421    
#> 421: 0.848098    1.067813    3.492059    0.622296    0.037458    0.021618    0.537337    
#> 422: 0.848255    1.067735    3.492089    0.622459    0.037458    0.021616    0.537264    
#> 423: 0.848333    1.067674    3.492120    0.622218    0.037498    0.021622    0.537229    
#> 424: 0.848222    1.067673    3.492123    0.622061    0.037485    0.021620    0.537215    
#> 425: 0.848022    1.067716    3.492063    0.621677    0.037467    0.021629    0.537324    
#> 426: 0.847851    1.067847    3.492006    0.621565    0.037468    0.021638    0.537267    
#> 427: 0.847557    1.067879    3.491998    0.621011    0.037479    0.021625    0.537256    
#> 428: 0.847227    1.067952    3.491984    0.620571    0.037514    0.021614    0.537216    
#> 429: 0.847063    1.068022    3.491965    0.620245    0.037522    0.021610    0.537216    
#> 430: 0.846849    1.068065    3.491907    0.620219    0.037535    0.021598    0.537206    
#> 431: 0.846786    1.068075    3.491872    0.620166    0.037548    0.021605    0.537115    
#> 432: 0.846640    1.068142    3.491829    0.619969    0.037553    0.021627    0.537094    
#> 433: 0.846681    1.068248    3.491845    0.619647    0.037533    0.021642    0.537111    
#> 434: 0.846647    1.068188    3.491856    0.619599    0.037532    0.021630    0.537060    
#> 435: 0.846617    1.068133    3.491844    0.619500    0.037515    0.021623    0.537058    
#> 436: 0.846629    1.068036    3.491884    0.619343    0.037516    0.021594    0.537115    
#> 437: 0.846642    1.068018    3.491901    0.619192    0.037565    0.021561    0.537141    
#> 438: 0.846620    1.068101    3.491901    0.619069    0.037582    0.021542    0.537193    
#> 439: 0.846628    1.068170    3.491856    0.619317    0.037594    0.021521    0.537215    
#> 440: 0.846669    1.068202    3.491877    0.619261    0.037580    0.021500    0.537253    
#> 441: 0.846707    1.068125    3.491892    0.619153    0.037584    0.021478    0.537234    
#> 442: 0.846616    1.068131    3.491883    0.619202    0.037598    0.021460    0.537183    
#> 443: 0.846493    1.068159    3.491832    0.618990    0.037631    0.021437    0.537140    
#> 444: 0.846233    1.068247    3.491730    0.618833    0.037663    0.021416    0.537166    
#> 445: 0.845964    1.068304    3.491649    0.618820    0.037684    0.021417    0.537266    
#> 446: 0.845757    1.068345    3.491601    0.618880    0.037683    0.021423    0.537311    
#> 447: 0.845769    1.068358    3.491598    0.618917    0.037708    0.021419    0.537340    
#> 448: 0.845569    1.068373    3.491557    0.618710    0.037716    0.021416    0.537336    
#> 449: 0.845606    1.068481    3.491588    0.618886    0.037710    0.021426    0.537368    
#> 450: 0.845636    1.068538    3.491589    0.618772    0.037707    0.021427    0.537390    
#> 451: 0.845640    1.068600    3.491606    0.619032    0.037709    0.021423    0.537395    
#> 452: 0.845885    1.068647    3.491646    0.619473    0.037694    0.021423    0.537340    
#> 453: 0.845859    1.068635    3.491654    0.619287    0.037650    0.021423    0.537334    
#> 454: 0.845742    1.068689    3.491641    0.619194    0.037620    0.021418    0.537334    
#> 455: 0.845644    1.068691    3.491623    0.618920    0.037581    0.021417    0.537331    
#> 456: 0.845525    1.068633    3.491622    0.619027    0.037559    0.021404    0.537365    
#> 457: 0.845457    1.068591    3.491646    0.618940    0.037560    0.021388    0.537313    
#> 458: 0.845506    1.068654    3.491675    0.618842    0.037581    0.021368    0.537268    
#> 459: 0.845336    1.068778    3.491638    0.618790    0.037633    0.021357    0.537245    
#> 460: 0.845137    1.068881    3.491582    0.618614    0.037671    0.021348    0.537217    
#> 461: 0.844999    1.068955    3.491578    0.618287    0.037686    0.021340    0.537194    
#> 462: 0.844907    1.069016    3.491578    0.618128    0.037705    0.021330    0.537162    
#> 463: 0.844929    1.069075    3.491594    0.618273    0.037703    0.021323    0.537120    
#> 464: 0.844947    1.069115    3.491566    0.618262    0.037708    0.021310    0.537060    
#> 465: 0.844934    1.069035    3.491589    0.618098    0.037738    0.021295    0.537032    
#> 466: 0.844958    1.069062    3.491596    0.617866    0.037760    0.021288    0.537011    
#> 467: 0.844933    1.069024    3.491621    0.617928    0.037770    0.021265    0.536985    
#> 468: 0.845162    1.069000    3.491651    0.618404    0.037771    0.021248    0.536982    
#> 469: 0.845369    1.068995    3.491705    0.618537    0.037785    0.021238    0.537005    
#> 470: 0.845340    1.068977    3.491696    0.618344    0.037789    0.021219    0.537048    
#> 471: 0.845306    1.068967    3.491733    0.618008    0.037802    0.021208    0.537062    
#> 472: 0.845280    1.068938    3.491758    0.617767    0.037824    0.021194    0.537078    
#> 473: 0.845232    1.068920    3.491784    0.617348    0.037842    0.021186    0.537050    
#> 474: 0.845229    1.068881    3.491808    0.617274    0.037831    0.021190    0.537064    
#> 475: 0.845208    1.068918    3.491809    0.617030    0.037839    0.021187    0.537078    
#> 476: 0.845139    1.068903    3.491817    0.616913    0.037840    0.021195    0.537068    
#> 477: 0.845063    1.068878    3.491872    0.616740    0.037840    0.021202    0.537051    
#> 478: 0.844926    1.068823    3.491900    0.616540    0.037845    0.021208    0.537055    
#> 479: 0.844995    1.068826    3.491919    0.616458    0.037852    0.021206    0.537066    
#> 480: 0.844941    1.068865    3.491913    0.616150    0.037881    0.021201    0.537084    
#> 481: 0.844970    1.068876    3.491912    0.616242    0.037870    0.021192    0.537077    
#> 482: 0.844987    1.068893    3.491867    0.616335    0.037889    0.021184    0.537134    
#> 483: 0.844889    1.068903    3.491842    0.616304    0.037914    0.021177    0.537135    
#> 484: 0.844838    1.068847    3.491841    0.616208    0.037924    0.021181    0.537101    
#> 485: 0.844897    1.068871    3.491851    0.616352    0.037941    0.021177    0.537085    
#> 486: 0.844994    1.068926    3.491889    0.616336    0.037935    0.021176    0.537113    
#> 487: 0.845178    1.068945    3.491971    0.616118    0.037949    0.021181    0.537168    
#> 488: 0.845207    1.068908    3.492010    0.615865    0.037962    0.021188    0.537158    
#> 489: 0.845312    1.068877    3.492011    0.615506    0.037977    0.021184    0.537182    
#> 490: 0.845453    1.068878    3.492053    0.615349    0.037978    0.021184    0.537193    
#> 491: 0.845745    1.068883    3.492114    0.615591    0.037961    0.021184    0.537212    
#> 492: 0.845773    1.068905    3.492140    0.615367    0.037990    0.021191    0.537266    
#> 493: 0.845750    1.068954    3.492125    0.615326    0.037994    0.021187    0.537270    
#> 494: 0.845761    1.069032    3.492086    0.615238    0.037987    0.021182    0.537288    
#> 495: 0.845691    1.069066    3.492053    0.615278    0.037975    0.021172    0.537284    
#> 496: 0.845751    1.069123    3.492038    0.615252    0.037977    0.021169    0.537323    
#> 497: 0.845762    1.069091    3.492031    0.615264    0.037959    0.021174    0.537433    
#> 498: 0.845806    1.069082    3.492032    0.615501    0.037956    0.021181    0.537444    
#> 499: 0.845778    1.069059    3.492009    0.615485    0.037988    0.021176    0.537455    
#> 500: 0.845909    1.068970    3.492016    0.615700    0.037968    0.021171    0.537423    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.304602    0.964978    3.447558    0.392401    0.074286    0.016800    1.671299    
#> 002: 0.555662    1.016619    3.467829    0.421717    0.075290    0.015960    1.091577    
#> 003: 0.707979    1.016663    3.476241    0.468862    0.080277    0.015162    0.880886    
#> 004: 0.827817    1.019413    3.485549    0.634494    0.076263    0.014404    0.726964    
#> 005: 0.930882    0.997391    3.493691    0.677771    0.072450    0.013684    0.700465    
#> 006: 0.890109    1.004989    3.484756    0.686354    0.068828    0.013000    0.660640    
#> 007: 0.877713    1.024870    3.473422    0.850908    0.065386    0.012350    0.669352    
#> 008: 0.877025    1.014230    3.467872    0.808363    0.062117    0.012334    0.662824    
#> 009: 0.850967    0.981134    3.465934    0.852428    0.059011    0.012165    0.667994    
#> 010: 0.893695    0.993703    3.469263    0.932188    0.056061    0.011557    0.666502    
#> 011: 0.913976    1.009359    3.476272    0.885579    0.053258    0.011542    0.656768    
#> 012: 0.918823    0.996334    3.455892    1.092420    0.050595    0.011580    0.655789    
#> 013: 0.932581    1.012663    3.456095    1.292328    0.048293    0.012555    0.669479    
#> 014: 0.939487    1.007269    3.458520    1.227712    0.055138    0.011927    0.677961    
#> 015: 0.924915    1.013283    3.465147    1.166326    0.054988    0.012137    0.648853    
#> 016: 0.963086    1.023866    3.478085    1.108010    0.062529    0.011530    0.670476    
#> 017: 0.991480    1.024955    3.476456    1.223088    0.059402    0.010954    0.651472    
#> 018: 0.992386    1.013424    3.463624    1.282832    0.056432    0.010406    0.647982    
#> 019: 0.912877    1.020601    3.470578    1.218691    0.053611    0.010144    0.633392    
#> 020: 1.021701    1.018163    3.476967    1.224935    0.050930    0.009878    0.661131    
#> 021: 0.999729    1.012955    3.475157    1.221414    0.048384    0.011272    0.650026    
#> 022: 0.940621    1.016281    3.485798    1.160343    0.045964    0.010708    0.652875    
#> 023: 1.024722    1.019269    3.477623    1.171536    0.056088    0.010173    0.647664    
#> 024: 1.031004    1.048978    3.472656    1.332205    0.056917    0.011036    0.639227    
#> 025: 1.044229    1.021180    3.473468    1.472359    0.055502    0.010767    0.648811    
#> 026: 1.032433    1.043544    3.466110    1.492735    0.052727    0.012499    0.659151    
#> 027: 1.004643    1.035655    3.468092    1.418098    0.050090    0.012974    0.666406    
#> 028: 1.055307    1.040137    3.462830    1.528541    0.053894    0.013490    0.658386    
#> 029: 1.060682    1.026474    3.467798    1.512818    0.051199    0.013910    0.660989    
#> 030: 1.090627    1.041173    3.470340    1.724377    0.048639    0.013354    0.655116    
#> 031: 0.979077    1.004125    3.479252    1.638158    0.046207    0.014817    0.651168    
#> 032: 0.992517    1.011310    3.486476    1.556250    0.043897    0.014076    0.654136    
#> 033: 0.933856    1.023493    3.474102    1.478438    0.041896    0.016084    0.645912    
#> 034: 0.972258    1.034426    3.470264    1.404516    0.041616    0.015280    0.652839    
#> 035: 0.904160    1.017531    3.465746    1.334290    0.044177    0.014516    0.637991    
#> 036: 0.970651    1.031868    3.463681    1.267575    0.052414    0.013790    0.661883    
#> 037: 1.011187    1.031326    3.473834    1.288371    0.049794    0.014558    0.673583    
#> 038: 0.952527    1.025094    3.469021    1.223952    0.047304    0.015083    0.673532    
#> 039: 1.015282    1.017551    3.484628    1.307393    0.050488    0.014329    0.665584    
#> 040: 1.041617    1.018368    3.479573    1.339343    0.047964    0.014082    0.650302    
#> 041: 0.941643    1.004110    3.483602    1.272376    0.045566    0.018379    0.638818    
#> 042: 0.978607    1.009303    3.481424    1.208757    0.043287    0.017460    0.630826    
#> 043: 0.909154    1.022889    3.458982    1.148319    0.041381    0.016587    0.634843    
#> 044: 0.853832    1.024883    3.455811    1.090903    0.039312    0.015758    0.647567    
#> 045: 0.880327    1.049892    3.453238    1.036358    0.037500    0.014970    0.647889    
#> 046: 0.957319    1.018990    3.465777    1.220312    0.035625    0.017061    0.648986    
#> 047: 0.962359    1.020185    3.463415    1.215386    0.041896    0.016208    0.662176    
#> 048: 0.897334    1.012857    3.461104    1.154617    0.054378    0.015398    0.663503    
#> 049: 0.938147    1.018939    3.463602    1.125508    0.051659    0.014628    0.664981    
#> 050: 0.920488    1.004773    3.459077    1.201964    0.052806    0.013896    0.680325    
#> 051: 0.915737    1.013459    3.459392    1.182379    0.058054    0.016478    0.679418    
#> 052: 0.946408    1.041116    3.463991    1.187575    0.055998    0.015654    0.657961    
#> 053: 1.010674    1.026631    3.463428    1.414343    0.066427    0.014871    0.660981    
#> 054: 0.885881    1.031169    3.459467    1.343626    0.063106    0.014128    0.655103    
#> 055: 0.944377    1.036207    3.456932    1.276444    0.059951    0.013433    0.651989    
#> 056: 0.985965    1.024782    3.467041    1.212622    0.056953    0.015047    0.651839    
#> 057: 0.912708    1.018005    3.473678    1.151991    0.060592    0.017251    0.652538    
#> 058: 0.913502    1.000084    3.468940    1.094391    0.057563    0.016388    0.658082    
#> 059: 0.947016    0.984831    3.478084    1.074971    0.054684    0.018318    0.672534    
#> 060: 0.961493    0.986764    3.481655    1.190986    0.051950    0.017402    0.679051    
#> 061: 0.951460    1.007125    3.478168    1.131437    0.054597    0.016532    0.684680    
#> 062: 0.952658    1.032906    3.471731    1.198402    0.063573    0.016121    0.686500    
#> 063: 1.062881    0.983118    3.481108    1.370962    0.060395    0.015314    0.693391    
#> 064: 1.111888    1.018417    3.480505    1.614710    0.057375    0.014549    0.658346    
#> 065: 1.041037    1.003928    3.470387    1.533975    0.056947    0.014154    0.644239    
#> 066: 1.044568    1.028546    3.469188    1.570730    0.054100    0.013446    0.656459    
#> 067: 0.960314    1.018146    3.459364    1.492194    0.051395    0.013590    0.640944    
#> 068: 0.901777    1.041298    3.458470    1.417584    0.053423    0.013935    0.647590    
#> 069: 1.006588    1.035086    3.464492    1.346705    0.053381    0.014737    0.644700    
#> 070: 0.992542    1.028716    3.468861    1.349734    0.050712    0.014001    0.633803    
#> 071: 0.978138    1.059819    3.452387    1.282247    0.056932    0.013301    0.649122    
#> 072: 0.889647    1.031198    3.458664    1.218135    0.054086    0.012636    0.650709    
#> 073: 0.860402    1.041208    3.474053    1.157228    0.051382    0.013122    0.645640    
#> 074: 0.929549    1.023401    3.470309    1.102433    0.048812    0.013430    0.623854    
#> 075: 1.026192    1.017444    3.484202    1.417844    0.046372    0.012759    0.651850    
#> 076: 0.996505    1.018698    3.475087    1.346952    0.044053    0.012121    0.633838    
#> 077: 1.058899    1.009131    3.475804    1.279604    0.042485    0.013493    0.637074    
#> 078: 1.062617    1.023141    3.476666    1.436558    0.042136    0.014673    0.623486    
#> 079: 1.038760    1.030997    3.480131    1.364730    0.051518    0.015260    0.642975    
#> 080: 0.921236    1.030390    3.465705    1.296493    0.048942    0.019016    0.665754    
#> 081: 0.935304    1.031043    3.466619    1.231669    0.046495    0.020765    0.665245    
#> 082: 0.911930    1.030080    3.460958    1.170085    0.047303    0.019726    0.667627    
#> 083: 0.931187    1.042821    3.471946    1.111581    0.044938    0.018740    0.656936    
#> 084: 0.989596    1.031231    3.471172    1.301104    0.042691    0.017803    0.643375    
#> 085: 0.967823    1.027017    3.479489    1.267330    0.048603    0.016913    0.643403    
#> 086: 0.990569    1.021643    3.471377    1.203963    0.046173    0.016067    0.648944    
#> 087: 0.964792    1.012218    3.467378    1.172098    0.043864    0.016978    0.635294    
#> 088: 0.876197    1.000915    3.463068    1.113493    0.042002    0.016129    0.648776    
#> 089: 0.897382    1.039632    3.450691    1.076529    0.049806    0.015323    0.645575    
#> 090: 0.857392    1.037768    3.451890    1.022703    0.047316    0.014557    0.654627    
#> 091: 0.822439    1.032777    3.443237    0.971568    0.047510    0.013829    0.658311    
#> 092: 0.864102    1.033824    3.446844    1.025023    0.045134    0.017303    0.663796    
#> 093: 0.810556    1.034032    3.440852    0.973772    0.042878    0.017272    0.656426    
#> 094: 0.881512    1.036700    3.447396    1.107115    0.040734    0.019309    0.644395    
#> 095: 0.927964    1.039245    3.457143    1.216463    0.039202    0.021495    0.648570    
#> 096: 0.884079    1.034530    3.449033    1.155640    0.042987    0.022975    0.644108    
#> 097: 0.945030    1.047495    3.446722    1.282653    0.045821    0.021826    0.649800    
#> 098: 0.885910    1.055689    3.448305    1.218521    0.043530    0.020735    0.644624    
#> 099: 0.899910    1.034018    3.442804    1.172203    0.043079    0.019698    0.624957    
#> 100: 0.930551    1.037560    3.451405    1.327227    0.050096    0.018713    0.636831    
#> 101: 0.886944    1.021714    3.436371    1.260866    0.048938    0.017778    0.653210    
#> 102: 0.854558    1.035185    3.430053    1.197823    0.046491    0.016889    0.656599    
#> 103: 0.883374    1.040854    3.447087    1.137931    0.044166    0.016044    0.646184    
#> 104: 0.844249    1.032488    3.470557    1.081035    0.041958    0.015242    0.666466    
#> 105: 0.984737    1.025258    3.466267    1.292552    0.039860    0.014480    0.672981    
#> 106: 0.962905    1.033289    3.458166    1.227924    0.041553    0.014240    0.651485    
#> 107: 1.003155    1.027072    3.447868    1.434726    0.041036    0.014980    0.656555    
#> 108: 0.951888    1.033371    3.454785    1.362990    0.046372    0.014231    0.667730    
#> 109: 0.905767    1.022540    3.471535    1.294840    0.044053    0.013519    0.667656    
#> 110: 1.010184    1.029672    3.459236    1.246351    0.051462    0.012843    0.659525    
#> 111: 0.961568    1.016092    3.466491    1.184034    0.050354    0.012201    0.649993    
#> 112: 0.933261    1.008795    3.464436    1.124832    0.054709    0.011591    0.646705    
#> 113: 0.959063    1.038810    3.461309    1.225585    0.051974    0.011012    0.640557    
#> 114: 1.031343    1.029893    3.465259    1.300889    0.049375    0.010461    0.647762    
#> 115: 1.116273    0.982064    3.486741    1.470542    0.055140    0.009938    0.676386    
#> 116: 1.180314    0.997163    3.488076    1.904084    0.056699    0.010593    0.664854    
#> 117: 1.115248    1.014647    3.480028    1.808880    0.056542    0.011402    0.654935    
#> 118: 1.079488    1.023037    3.472816    1.718436    0.053715    0.010832    0.663487    
#> 119: 1.062089    1.032184    3.468771    1.632514    0.051029    0.010291    0.671565    
#> 120: 1.013303    1.004915    3.479957    1.550888    0.048478    0.010867    0.665830    
#> 121: 0.965119    1.039636    3.465429    1.473344    0.052035    0.010995    0.656854    
#> 122: 0.947990    1.028170    3.466963    1.399677    0.053259    0.010445    0.655121    
#> 123: 0.975875    1.036805    3.462821    1.329693    0.050596    0.009923    0.656450    
#> 124: 1.053569    1.055775    3.456610    1.594042    0.053019    0.010329    0.643048    
#> 125: 1.091651    1.033380    3.456666    1.714448    0.050368    0.012323    0.637159    
#> 126: 1.036766    1.031959    3.453820    1.628726    0.047850    0.011707    0.648161    
#> 127: 1.055528    1.004374    3.458672    1.601963    0.045457    0.011816    0.654428    
#> 128: 1.062095    1.016128    3.471465    1.602180    0.045381    0.011900    0.645435    
#> 129: 1.138358    1.024731    3.476307    1.849558    0.045387    0.012568    0.651030    
#> 130: 1.227362    1.044828    3.470176    2.015563    0.049610    0.011939    0.648138    
#> 131: 1.101470    1.020588    3.468719    1.914785    0.051073    0.015698    0.638305    
#> 132: 1.056739    1.021170    3.462181    1.819046    0.048519    0.015325    0.654610    
#> 133: 1.129260    1.015780    3.461073    1.861051    0.046093    0.019664    0.661894    
#> 134: 1.090219    1.008794    3.472454    1.767998    0.043789    0.022039    0.672316    
#> 135: 1.039018    1.014255    3.469915    1.679598    0.042667    0.020937    0.668006    
#> 136: 0.975182    1.006528    3.464005    1.595618    0.045667    0.019890    0.660528    
#> 137: 0.999748    0.997367    3.473278    1.515837    0.043383    0.018895    0.665766    
#> 138: 0.977638    0.996201    3.473192    1.440045    0.047301    0.017951    0.656902    
#> 139: 0.963230    1.014713    3.471465    1.368043    0.047865    0.017053    0.648594    
#> 140: 1.077619    1.018569    3.478501    1.594293    0.047216    0.016200    0.653557    
#> 141: 1.064466    1.008725    3.477320    1.612234    0.053169    0.015390    0.662688    
#> 142: 1.042738    0.992688    3.483791    1.531622    0.060466    0.014621    0.649129    
#> 143: 0.998796    0.998741    3.478390    1.455041    0.060429    0.013890    0.652417    
#> 144: 0.948596    1.019698    3.477996    1.382289    0.057407    0.013195    0.658966    
#> 145: 0.965111    1.010095    3.463480    1.313175    0.054537    0.012536    0.642850    
#> 146: 0.950117    1.024137    3.468332    1.247516    0.057346    0.011909    0.633748    
#> 147: 0.893798    1.022861    3.462974    1.185140    0.054479    0.011459    0.637443    
#> 148: 0.871749    1.028274    3.474092    1.125883    0.051755    0.011791    0.646499    
#> 149: 0.860224    1.017942    3.471948    1.069589    0.049167    0.011412    0.655183    
#> 150: 0.942144    1.016439    3.474203    1.016110    0.046709    0.012151    0.660441    
#> 151: 0.895041    1.042512    3.467755    0.980087    0.044373    0.011543    0.670064    
#> 152: 0.906730    1.033371    3.470275    1.025283    0.040047    0.008587    0.664434    
#> 153: 0.848551    1.036308    3.466525    0.865672    0.048458    0.008937    0.669059    
#> 154: 0.880733    1.021505    3.469030    0.896206    0.045411    0.009949    0.665381    
#> 155: 0.882599    1.009885    3.460725    0.941319    0.052301    0.009765    0.658045    
#> 156: 0.957710    1.003351    3.480876    1.048153    0.057477    0.009139    0.654763    
#> 157: 0.956737    0.999168    3.490478    1.054646    0.068377    0.009789    0.663953    
#> 158: 1.037700    1.014615    3.488163    1.155073    0.055127    0.009814    0.666427    
#> 159: 0.911226    1.027139    3.491785    0.938937    0.049916    0.009963    0.669789    
#> 160: 0.991521    1.000862    3.495063    1.107246    0.047593    0.012105    0.651932    
#> 161: 1.002420    1.022513    3.478976    1.245984    0.052473    0.010415    0.676418    
#> 162: 0.937115    1.046550    3.449112    1.175102    0.050000    0.009123    0.667109    
#> 163: 0.939061    1.032169    3.449483    1.127198    0.061539    0.009716    0.673575    
#> 164: 0.944909    1.028740    3.462978    1.146529    0.049408    0.007918    0.646352    
#> 165: 1.012872    1.020447    3.466275    1.401302    0.053512    0.007867    0.644891    
#> 166: 1.062971    1.055362    3.461709    1.478222    0.057004    0.009772    0.647303    
#> 167: 1.116435    1.038140    3.476610    1.615126    0.052284    0.010843    0.652181    
#> 168: 1.132973    1.043208    3.472862    1.633199    0.054872    0.011809    0.644155    
#> 169: 1.146712    1.063833    3.459250    1.745474    0.060206    0.010278    0.659835    
#> 170: 1.020832    1.025641    3.463548    1.340558    0.056569    0.011016    0.650791    
#> 171: 0.995687    1.026552    3.464793    1.267187    0.053180    0.011723    0.636261    
#> 172: 0.942041    1.053046    3.456534    1.168984    0.055795    0.011511    0.637516    
#> 173: 0.941418    1.052834    3.446917    1.182627    0.056645    0.010965    0.649495    
#> 174: 0.974950    1.040335    3.458236    1.096148    0.046685    0.009259    0.647609    
#> 175: 0.962569    1.035516    3.448783    1.277554    0.051532    0.007166    0.664364    
#> 176: 0.924122    1.029818    3.459906    1.056499    0.052038    0.007185    0.648891    
#> 177: 0.928025    1.027949    3.470234    0.968140    0.038053    0.007856    0.666493    
#> 178: 0.951689    1.015900    3.461030    1.048745    0.044650    0.007547    0.685171    
#> 179: 1.002932    1.017943    3.470026    1.421485    0.057183    0.009379    0.676560    
#> 180: 0.952722    1.026288    3.478651    0.967695    0.060799    0.011343    0.676559    
#> 181: 0.949045    0.990932    3.460191    1.058622    0.049116    0.008776    0.646534    
#> 182: 0.939915    1.010378    3.450359    1.205025    0.059467    0.008906    0.655556    
#> 183: 0.953328    1.039717    3.452695    1.158935    0.053846    0.009451    0.640848    
#> 184: 0.995036    1.017744    3.458470    1.368939    0.054236    0.008260    0.626351    
#> 185: 0.968277    1.044632    3.459124    1.320952    0.057256    0.010288    0.636126    
#> 186: 1.011335    1.054431    3.462967    1.297997    0.060188    0.010439    0.658002    
#> 187: 0.991031    1.027781    3.470019    1.165657    0.058534    0.007439    0.652876    
#> 188: 0.921299    1.023474    3.471231    0.941010    0.058925    0.008795    0.657640    
#> 189: 0.897498    1.054278    3.475184    0.835303    0.065175    0.008107    0.676207    
#> 190: 0.909603    1.029771    3.473134    0.974247    0.051498    0.007188    0.655974    
#> 191: 0.912848    1.037781    3.465069    1.027806    0.049969    0.007205    0.649612    
#> 192: 0.891553    1.039922    3.461629    0.896826    0.042173    0.005988    0.663690    
#> 193: 0.926784    1.046151    3.467417    0.946751    0.045325    0.005008    0.654886    
#> 194: 0.906092    1.040801    3.461286    0.926984    0.057285    0.005538    0.661490    
#> 195: 0.824290    1.046954    3.454200    0.824889    0.059550    0.005974    0.654973    
#> 196: 0.890247    1.036641    3.463466    0.883005    0.059525    0.003295    0.684594    
#> 197: 0.923247    1.017392    3.475191    0.998148    0.060056    0.003667    0.678276    
#> 198: 0.943499    1.010677    3.468563    1.118192    0.064498    0.004762    0.664644    
#> 199: 0.891722    1.011516    3.466862    0.949616    0.059980    0.004183    0.662361    
#> 200: 0.910343    1.020060    3.464459    1.019433    0.069193    0.004942    0.676560    
#> 201: 0.905346    1.019403    3.465457    1.007224    0.064589    0.005782    0.664614    
#> 202: 0.898352    1.021631    3.462272    1.004124    0.063191    0.005747    0.668722    
#> 203: 0.910222    1.022898    3.459457    1.031655    0.065239    0.005890    0.668205    
#> 204: 0.932372    1.022539    3.461827    1.068053    0.067652    0.006011    0.667253    
#> 205: 0.939096    1.026471    3.463384    1.083319    0.068658    0.006065    0.670098    
#> 206: 0.938073    1.032043    3.464373    1.089665    0.068655    0.005855    0.671314    
#> 207: 0.946755    1.033485    3.463122    1.130514    0.069988    0.005645    0.671271    
#> 208: 0.948344    1.033439    3.462733    1.131447    0.069427    0.005511    0.669807    
#> 209: 0.944478    1.031094    3.462236    1.115255    0.068671    0.005492    0.670386    
#> 210: 0.938157    1.030085    3.461846    1.097121    0.067875    0.005457    0.669867    
#> 211: 0.935408    1.030617    3.461631    1.086850    0.067605    0.005365    0.668890    
#> 212: 0.935142    1.030077    3.461677    1.082652    0.067031    0.005321    0.668069    
#> 213: 0.932564    1.028553    3.461515    1.071404    0.067000    0.005351    0.668107    
#> 214: 0.934693    1.027290    3.461836    1.071485    0.066413    0.005313    0.668219    
#> 215: 0.934903    1.027072    3.462046    1.068534    0.066294    0.005272    0.667644    
#> 216: 0.937759    1.026286    3.462235    1.065704    0.066539    0.005200    0.667534    
#> 217: 0.937010    1.027595    3.462112    1.062511    0.066880    0.005106    0.666965    
#> 218: 0.935772    1.028434    3.461526    1.058972    0.067488    0.005040    0.666809    
#> 219: 0.933969    1.028610    3.460615    1.057614    0.067574    0.004983    0.667218    
#> 220: 0.932449    1.028393    3.460305    1.060665    0.067788    0.004981    0.666707    
#> 221: 0.930271    1.028584    3.459851    1.061060    0.067400    0.004960    0.666519    
#> 222: 0.931335    1.028515    3.459597    1.063487    0.066872    0.005006    0.666335    
#> 223: 0.932371    1.028352    3.459461    1.063636    0.066425    0.005030    0.666296    
#> 224: 0.933183    1.028976    3.459490    1.061765    0.066013    0.005049    0.666038    
#> 225: 0.930272    1.027743    3.459663    1.051272    0.065935    0.005051    0.665616    
#> 226: 0.928925    1.026175    3.459781    1.045259    0.065667    0.005039    0.665723    
#> 227: 0.927062    1.025785    3.460153    1.035455    0.065963    0.005043    0.665484    
#> 228: 0.926837    1.026601    3.460053    1.034209    0.066062    0.005052    0.665305    
#> 229: 0.926249    1.026337    3.460012    1.034337    0.065992    0.005084    0.665160    
#> 230: 0.926427    1.026102    3.460060    1.034065    0.065766    0.005093    0.664983    
#> 231: 0.928589    1.026017    3.460428    1.038407    0.065997    0.005116    0.664457    
#> 232: 0.927068    1.026415    3.460878    1.032773    0.066191    0.005108    0.664404    
#> 233: 0.927258    1.026250    3.461262    1.034772    0.066396    0.005089    0.664026    
#> 234: 0.927377    1.026195    3.461716    1.031736    0.066504    0.005094    0.663987    
#> 235: 0.927322    1.025745    3.461938    1.027361    0.066279    0.005066    0.664252    
#> 236: 0.927638    1.025749    3.462096    1.024706    0.066000    0.005043    0.664530    
#> 237: 0.928896    1.025446    3.462115    1.028654    0.066010    0.005050    0.664555    
#> 238: 0.931136    1.024895    3.462268    1.035606    0.066076    0.005079    0.664852    
#> 239: 0.932487    1.025339    3.462226    1.040342    0.065856    0.005067    0.664834    
#> 240: 0.934664    1.025267    3.462364    1.049890    0.065827    0.005068    0.664600    
#> 241: 0.934845    1.024690    3.462593    1.049472    0.065526    0.005095    0.664573    
#> 242: 0.934192    1.024224    3.462626    1.044627    0.065510    0.005147    0.664822    
#> 243: 0.932364    1.024290    3.462709    1.038906    0.065432    0.005183    0.665199    
#> 244: 0.931476    1.024375    3.462790    1.035379    0.065021    0.005229    0.665403    
#> 245: 0.932254    1.023829    3.462951    1.037381    0.064662    0.005237    0.665918    
#> 246: 0.931972    1.023510    3.463093    1.035609    0.064512    0.005252    0.666055    
#> 247: 0.931958    1.023221    3.463335    1.034199    0.064422    0.005263    0.665960    
#> 248: 0.931238    1.023513    3.463233    1.032451    0.064376    0.005250    0.665685    
#> 249: 0.930235    1.023990    3.463201    1.032304    0.064321    0.005243    0.665791    
#> 250: 0.931089    1.024581    3.463243    1.033929    0.064276    0.005253    0.665865    
#> 251: 0.932563    1.025093    3.463482    1.036660    0.064305    0.005235    0.666097    
#> 252: 0.931554    1.025316    3.463769    1.032022    0.064331    0.005238    0.666410    
#> 253: 0.930567    1.025397    3.463981    1.029847    0.064127    0.005257    0.666434    
#> 254: 0.930720    1.025773    3.464166    1.029188    0.064108    0.005256    0.666347    
#> 255: 0.931179    1.025915    3.464372    1.029251    0.064108    0.005257    0.666437    
#> 256: 0.931322    1.025976    3.464326    1.029316    0.064150    0.005256    0.666422    
#> 257: 0.931244    1.025537    3.464422    1.028495    0.064502    0.005259    0.666445    
#> 258: 0.930099    1.025257    3.464471    1.025640    0.064660    0.005247    0.666502    
#> 259: 0.930345    1.025096    3.464516    1.027751    0.064608    0.005255    0.666593    
#> 260: 0.931013    1.025284    3.464627    1.029142    0.064635    0.005245    0.666521    
#> 261: 0.930442    1.025248    3.464700    1.027899    0.064698    0.005233    0.666434    
#> 262: 0.931518    1.025177    3.464849    1.029860    0.064736    0.005217    0.666411    
#> 263: 0.931092    1.025321    3.464874    1.028711    0.064659    0.005228    0.666337    
#> 264: 0.930930    1.025228    3.464905    1.028892    0.064507    0.005247    0.666375    
#> 265: 0.931830    1.025115    3.465015    1.032511    0.064383    0.005243    0.666506    
#> 266: 0.933359    1.025220    3.465049    1.037617    0.064337    0.005226    0.666491    
#> 267: 0.933705    1.025262    3.465006    1.040982    0.064485    0.005203    0.666617    
#> 268: 0.934254    1.025238    3.464951    1.043517    0.064594    0.005180    0.666579    
#> 269: 0.935234    1.025203    3.464956    1.046880    0.064669    0.005158    0.666396    
#> 270: 0.936130    1.025187    3.464956    1.047826    0.064668    0.005144    0.666162    
#> 271: 0.936998    1.025064    3.464882    1.048640    0.064648    0.005137    0.666220    
#> 272: 0.937634    1.024869    3.464761    1.049398    0.064536    0.005121    0.666482    
#> 273: 0.938311    1.025033    3.464675    1.054312    0.064504    0.005122    0.666653    
#> 274: 0.937786    1.025158    3.464728    1.053354    0.064597    0.005110    0.666701    
#> 275: 0.937693    1.025234    3.464630    1.053767    0.064715    0.005116    0.666664    
#> 276: 0.937028    1.025317    3.464788    1.052499    0.064771    0.005142    0.666711    
#> 277: 0.936593    1.025443    3.465001    1.051256    0.064759    0.005162    0.666697    
#> 278: 0.936412    1.025319    3.465160    1.049850    0.064652    0.005177    0.666715    
#> 279: 0.936592    1.024994    3.465266    1.050181    0.064642    0.005192    0.666944    
#> 280: 0.936589    1.025105    3.465387    1.050376    0.064593    0.005191    0.666938    
#> 281: 0.936905    1.025080    3.465604    1.049229    0.064626    0.005183    0.666893    
#> 282: 0.937059    1.025060    3.465806    1.048096    0.064620    0.005192    0.667053    
#> 283: 0.937339    1.025043    3.465986    1.047065    0.064662    0.005231    0.667161    
#> 284: 0.937468    1.024756    3.466113    1.046617    0.064653    0.005259    0.666873    
#> 285: 0.937805    1.024717    3.466099    1.046381    0.064527    0.005288    0.666953    
#> 286: 0.938070    1.024878    3.466076    1.047277    0.064443    0.005334    0.666897    
#> 287: 0.938005    1.025198    3.465979    1.049551    0.064254    0.005358    0.667143    
#> 288: 0.938319    1.025373    3.465941    1.048971    0.064222    0.005377    0.667051    
#> 289: 0.938427    1.025411    3.465866    1.050077    0.064168    0.005389    0.666922    
#> 290: 0.938168    1.025429    3.465772    1.050015    0.064170    0.005389    0.666959    
#> 291: 0.938289    1.025818    3.465673    1.050385    0.064224    0.005376    0.666899    
#> 292: 0.938619    1.025868    3.465563    1.051173    0.064231    0.005361    0.666997    
#> 293: 0.938813    1.026101    3.465431    1.051698    0.064162    0.005345    0.667125    
#> 294: 0.938829    1.026145    3.465309    1.052141    0.064045    0.005338    0.667414    
#> 295: 0.939160    1.025740    3.465279    1.055096    0.064125    0.005333    0.667445    
#> 296: 0.938641    1.025584    3.465341    1.054477    0.064165    0.005332    0.667577    
#> 297: 0.938938    1.025664    3.465425    1.055224    0.064262    0.005334    0.667804    
#> 298: 0.940077    1.025656    3.465489    1.057820    0.064273    0.005334    0.667777    
#> 299: 0.940501    1.025636    3.465492    1.059831    0.064182    0.005330    0.667652    
#> 300: 0.940476    1.025407    3.465567    1.060495    0.064191    0.005325    0.667583    
#> 301: 0.941132    1.025103    3.465614    1.061169    0.064108    0.005314    0.667552    
#> 302: 0.941251    1.025154    3.465619    1.061267    0.064040    0.005307    0.667531    
#> 303: 0.941395    1.025308    3.465608    1.061811    0.063912    0.005324    0.667488    
#> 304: 0.941313    1.025626    3.465551    1.061972    0.063839    0.005348    0.667317    
#> 305: 0.941984    1.025414    3.465558    1.065413    0.063770    0.005373    0.667168    
#> 306: 0.941926    1.025370    3.465437    1.066570    0.063712    0.005372    0.667078    
#> 307: 0.941643    1.025330    3.465391    1.066967    0.063523    0.005378    0.667122    
#> 308: 0.941553    1.025282    3.465321    1.068402    0.063428    0.005393    0.667117    
#> 309: 0.941853    1.025119    3.465235    1.070512    0.063451    0.005410    0.667312    
#> 310: 0.941789    1.025018    3.465106    1.070414    0.063430    0.005419    0.667533    
#> 311: 0.941978    1.025017    3.465098    1.071352    0.063422    0.005437    0.667663    
#> 312: 0.941907    1.024801    3.465086    1.071306    0.063379    0.005443    0.667740    
#> 313: 0.941282    1.024669    3.465043    1.069396    0.063403    0.005441    0.667993    
#> 314: 0.940905    1.024623    3.465002    1.068263    0.063415    0.005434    0.667992    
#> 315: 0.940755    1.024643    3.464976    1.068236    0.063487    0.005435    0.667981    
#> 316: 0.941200    1.024729    3.464966    1.069753    0.063593    0.005435    0.668054    
#> 317: 0.941738    1.024840    3.464931    1.070660    0.063717    0.005418    0.668324    
#> 318: 0.941912    1.024922    3.464888    1.070246    0.063731    0.005411    0.668304    
#> 319: 0.942149    1.024790    3.464882    1.070887    0.063736    0.005409    0.668191    
#> 320: 0.941563    1.024858    3.464753    1.070354    0.063787    0.005414    0.668140    
#> 321: 0.940751    1.024956    3.464567    1.069040    0.063821    0.005430    0.668221    
#> 322: 0.940139    1.025016    3.464378    1.069163    0.063877    0.005428    0.668362    
#> 323: 0.939529    1.025086    3.464274    1.069408    0.063843    0.005424    0.668438    
#> 324: 0.939146    1.025182    3.464299    1.069351    0.063808    0.005426    0.668333    
#> 325: 0.939301    1.025272    3.464275    1.069921    0.063755    0.005427    0.668198    
#> 326: 0.939407    1.025128    3.464190    1.071584    0.063779    0.005429    0.668130    
#> 327: 0.939741    1.025017    3.464191    1.073727    0.063828    0.005441    0.668055    
#> 328: 0.939830    1.025090    3.464113    1.074638    0.063803    0.005443    0.668012    
#> 329: 0.939910    1.025134    3.464047    1.076068    0.063816    0.005445    0.667928    
#> 330: 0.939782    1.025189    3.464031    1.076562    0.063799    0.005460    0.667794    
#> 331: 0.939835    1.025458    3.464020    1.077157    0.063749    0.005470    0.667812    
#> 332: 0.940324    1.025337    3.464071    1.079524    0.063679    0.005488    0.667843    
#> 333: 0.940010    1.025334    3.463997    1.079515    0.063577    0.005506    0.667943    
#> 334: 0.939706    1.025034    3.463949    1.079145    0.063461    0.005518    0.668184    
#> 335: 0.939239    1.025025    3.463826    1.078305    0.063409    0.005530    0.668210    
#> 336: 0.938920    1.025307    3.463724    1.077707    0.063334    0.005552    0.668233    
#> 337: 0.939131    1.025642    3.463634    1.079194    0.063321    0.005556    0.668228    
#> 338: 0.938828    1.025872    3.463599    1.078336    0.063391    0.005548    0.668294    
#> 339: 0.938749    1.025930    3.463616    1.077557    0.063397    0.005538    0.668294    
#> 340: 0.938301    1.025750    3.463623    1.076697    0.063459    0.005533    0.668300    
#> 341: 0.938022    1.025760    3.463627    1.075442    0.063436    0.005534    0.668424    
#> 342: 0.937695    1.025658    3.463615    1.074409    0.063422    0.005541    0.668388    
#> 343: 0.937487    1.025637    3.463648    1.073415    0.063414    0.005544    0.668269    
#> 344: 0.938027    1.025644    3.463717    1.074998    0.063494    0.005559    0.668131    
#> 345: 0.938033    1.025613    3.463756    1.074625    0.063556    0.005566    0.668066    
#> 346: 0.938216    1.025645    3.463786    1.073631    0.063530    0.005560    0.668025    
#> 347: 0.938126    1.025585    3.463748    1.072760    0.063512    0.005558    0.668066    
#> 348: 0.937781    1.025659    3.463688    1.072623    0.063406    0.005568    0.668119    
#> 349: 0.937431    1.025506    3.463603    1.073249    0.063341    0.005583    0.668054    
#> 350: 0.936890    1.025316    3.463572    1.072797    0.063286    0.005596    0.668010    
#> 351: 0.936704    1.025287    3.463547    1.072647    0.063230    0.005613    0.667832    
#> 352: 0.936451    1.025302    3.463552    1.072872    0.063178    0.005629    0.667768    
#> 353: 0.936695    1.025403    3.463591    1.073081    0.063156    0.005631    0.667812    
#> 354: 0.936917    1.025392    3.463526    1.074158    0.063084    0.005627    0.667794    
#> 355: 0.937135    1.025261    3.463478    1.074852    0.063042    0.005624    0.667777    
#> 356: 0.936980    1.025253    3.463449    1.073934    0.063090    0.005632    0.667791    
#> 357: 0.937376    1.025409    3.463440    1.074607    0.063089    0.005629    0.667631    
#> 358: 0.937159    1.025387    3.463436    1.074244    0.063043    0.005632    0.667556    
#> 359: 0.936799    1.025489    3.463419    1.073276    0.063114    0.005628    0.667548    
#> 360: 0.936370    1.025574    3.463299    1.071918    0.063077    0.005625    0.667514    
#> 361: 0.935916    1.025615    3.463181    1.071110    0.063125    0.005628    0.667423    
#> 362: 0.935495    1.025586    3.463122    1.070667    0.063104    0.005629    0.667403    
#> 363: 0.935769    1.025539    3.463081    1.071530    0.063095    0.005626    0.667333    
#> 364: 0.935500    1.025573    3.462993    1.071086    0.063134    0.005620    0.667307    
#> 365: 0.935398    1.025535    3.462995    1.070348    0.063167    0.005623    0.667273    
#> 366: 0.935171    1.025438    3.462942    1.069306    0.063126    0.005634    0.667329    
#> 367: 0.934632    1.025385    3.462912    1.068357    0.063082    0.005640    0.667343    
#> 368: 0.934370    1.025540    3.462851    1.067213    0.063041    0.005651    0.667307    
#> 369: 0.934188    1.025630    3.462801    1.066651    0.063038    0.005644    0.667233    
#> 370: 0.933844    1.025731    3.462763    1.065336    0.063090    0.005640    0.667196    
#> 371: 0.933612    1.025807    3.462654    1.064878    0.063109    0.005632    0.667108    
#> 372: 0.933238    1.025944    3.462586    1.064672    0.063169    0.005625    0.667049    
#> 373: 0.932705    1.026087    3.462512    1.064031    0.063243    0.005614    0.666931    
#> 374: 0.932046    1.026199    3.462375    1.062753    0.063250    0.005620    0.666889    
#> 375: 0.931340    1.026316    3.462268    1.061580    0.063319    0.005624    0.666868    
#> 376: 0.930730    1.026514    3.462181    1.060472    0.063310    0.005619    0.666874    
#> 377: 0.930395    1.026649    3.462123    1.059814    0.063391    0.005620    0.666759    
#> 378: 0.930057    1.026726    3.462050    1.059224    0.063360    0.005623    0.666723    
#> 379: 0.930089    1.026644    3.462039    1.059272    0.063352    0.005622    0.666632    
#> 380: 0.930081    1.026567    3.462034    1.059438    0.063355    0.005622    0.666609    
#> 381: 0.929815    1.026506    3.462044    1.058732    0.063306    0.005616    0.666632    
#> 382: 0.929491    1.026466    3.462094    1.057320    0.063264    0.005610    0.666577    
#> 383: 0.929655    1.026469    3.462129    1.057734    0.063267    0.005611    0.666590    
#> 384: 0.929418    1.026310    3.462139    1.057509    0.063281    0.005608    0.666533    
#> 385: 0.929268    1.026262    3.462170    1.056930    0.063226    0.005609    0.666566    
#> 386: 0.929211    1.026400    3.462215    1.056428    0.063239    0.005612    0.666513    
#> 387: 0.929248    1.026458    3.462261    1.056613    0.063235    0.005621    0.666523    
#> 388: 0.929205    1.026501    3.462284    1.056470    0.063239    0.005629    0.666524    
#> 389: 0.929056    1.026401    3.462264    1.055776    0.063261    0.005630    0.666534    
#> 390: 0.928798    1.026397    3.462207    1.055243    0.063267    0.005625    0.666545    
#> 391: 0.928476    1.026420    3.462138    1.055109    0.063280    0.005624    0.666427    
#> 392: 0.928227    1.026493    3.462133    1.054826    0.063355    0.005620    0.666332    
#> 393: 0.928253    1.026410    3.462099    1.055442    0.063374    0.005616    0.666225    
#> 394: 0.928281    1.026436    3.462078    1.056034    0.063402    0.005609    0.666101    
#> 395: 0.928827    1.026533    3.462102    1.058211    0.063427    0.005605    0.666122    
#> 396: 0.929372    1.026676    3.462128    1.060387    0.063427    0.005604    0.666123    
#> 397: 0.929809    1.026592    3.462175    1.061890    0.063441    0.005618    0.666023    
#> 398: 0.930272    1.026532    3.462239    1.063333    0.063404    0.005633    0.666033    
#> 399: 0.931002    1.026512    3.462354    1.066172    0.063374    0.005643    0.665968    
#> 400: 0.931512    1.026599    3.462427    1.067772    0.063332    0.005652    0.665899    
#> 401: 0.931709    1.026662    3.462469    1.067520    0.063347    0.005667    0.665812    
#> 402: 0.931847    1.026738    3.462510    1.067153    0.063328    0.005681    0.665766    
#> 403: 0.932386    1.026754    3.462554    1.067882    0.063288    0.005698    0.665612    
#> 404: 0.932694    1.026827    3.462548    1.067826    0.063238    0.005709    0.665512    
#> 405: 0.932397    1.026855    3.462559    1.067335    0.063174    0.005717    0.665487    
#> 406: 0.932211    1.026957    3.462533    1.067019    0.063166    0.005729    0.665485    
#> 407: 0.932240    1.027055    3.462532    1.067492    0.063126    0.005732    0.665513    
#> 408: 0.932344    1.027138    3.462561    1.067523    0.063060    0.005739    0.665489    
#> 409: 0.932085    1.027027    3.462547    1.066720    0.063006    0.005740    0.665428    
#> 410: 0.931795    1.027029    3.462512    1.065445    0.063003    0.005740    0.665434    
#> 411: 0.931810    1.026877    3.462519    1.065324    0.063034    0.005739    0.665423    
#> 412: 0.931827    1.026859    3.462513    1.064868    0.063018    0.005741    0.665430    
#> 413: 0.932051    1.026845    3.462500    1.065125    0.063031    0.005743    0.665403    
#> 414: 0.932074    1.026782    3.462487    1.066225    0.062999    0.005745    0.665359    
#> 415: 0.932267    1.026772    3.462504    1.066661    0.062964    0.005748    0.665366    
#> 416: 0.932456    1.026845    3.462533    1.067470    0.062956    0.005758    0.665315    
#> 417: 0.932307    1.026839    3.462513    1.067247    0.062927    0.005760    0.665298    
#> 418: 0.931956    1.026840    3.462497    1.066880    0.062919    0.005763    0.665261    
#> 419: 0.931752    1.026900    3.462474    1.066649    0.062894    0.005762    0.665202    
#> 420: 0.931571    1.026956    3.462473    1.066018    0.062910    0.005757    0.665124    
#> 421: 0.931327    1.027010    3.462476    1.065046    0.062935    0.005753    0.665018    
#> 422: 0.931558    1.026985    3.462463    1.065610    0.062948    0.005753    0.665000    
#> 423: 0.931221    1.026956    3.462465    1.064359    0.062977    0.005754    0.665079    
#> 424: 0.930841    1.026976    3.462460    1.063053    0.063002    0.005749    0.665096    
#> 425: 0.930680    1.027014    3.462486    1.062314    0.063042    0.005750    0.665196    
#> 426: 0.930936    1.027059    3.462513    1.062307    0.063033    0.005753    0.665258    
#> 427: 0.930837    1.026893    3.462546    1.061292    0.062928    0.005761    0.665342    
#> 428: 0.930420    1.026871    3.462560    1.060160    0.062860    0.005769    0.665342    
#> 429: 0.930159    1.026862    3.462568    1.058962    0.062861    0.005776    0.665304    
#> 430: 0.930095    1.026922    3.462563    1.058750    0.062851    0.005785    0.665274    
#> 431: 0.930192    1.026880    3.462557    1.058865    0.062829    0.005792    0.665147    
#> 432: 0.930176    1.026954    3.462559    1.058527    0.062829    0.005801    0.665077    
#> 433: 0.930185    1.026992    3.462595    1.058189    0.062849    0.005811    0.665043    
#> 434: 0.930099    1.026833    3.462606    1.058218    0.062853    0.005815    0.665025    
#> 435: 0.930029    1.026825    3.462591    1.058116    0.062835    0.005819    0.665011    
#> 436: 0.930098    1.026805    3.462588    1.058035    0.062840    0.005816    0.665024    
#> 437: 0.930115    1.026827    3.462577    1.058176    0.062804    0.005818    0.665029    
#> 438: 0.930199    1.026981    3.462560    1.058663    0.062770    0.005819    0.664999    
#> 439: 0.930223    1.027136    3.462515    1.058884    0.062750    0.005811    0.664920    
#> 440: 0.929902    1.027209    3.462534    1.057626    0.062763    0.005805    0.664848    
#> 441: 0.929795    1.027169    3.462548    1.057037    0.062821    0.005804    0.664772    
#> 442: 0.929868    1.027202    3.462583    1.057021    0.062813    0.005803    0.664691    
#> 443: 0.930185    1.027228    3.462596    1.058007    0.062748    0.005808    0.664632    
#> 444: 0.929984    1.027260    3.462586    1.057780    0.062712    0.005814    0.664608    
#> 445: 0.929879    1.027288    3.462536    1.057866    0.062646    0.005822    0.664574    
#> 446: 0.929752    1.027358    3.462489    1.057779    0.062618    0.005828    0.664549    
#> 447: 0.929655    1.027366    3.462473    1.057149    0.062575    0.005840    0.664462    
#> 448: 0.929386    1.027402    3.462480    1.056508    0.062556    0.005856    0.664355    
#> 449: 0.929319    1.027422    3.462538    1.056459    0.062563    0.005873    0.664261    
#> 450: 0.929341    1.027382    3.462584    1.056291    0.062493    0.005883    0.664253    
#> 451: 0.929548    1.027371    3.462599    1.056889    0.062465    0.005892    0.664205    
#> 452: 0.929922    1.027375    3.462603    1.058057    0.062421    0.005895    0.664152    
#> 453: 0.929896    1.027399    3.462591    1.058347    0.062415    0.005901    0.664046    
#> 454: 0.929846    1.027502    3.462574    1.058135    0.062393    0.005905    0.663937    
#> 455: 0.929854    1.027484    3.462564    1.057964    0.062372    0.005906    0.663901    
#> 456: 0.929792    1.027450    3.462549    1.057855    0.062375    0.005914    0.663943    
#> 457: 0.929833    1.027451    3.462575    1.058471    0.062371    0.005919    0.663972    
#> 458: 0.930009    1.027517    3.462618    1.059097    0.062363    0.005925    0.663934    
#> 459: 0.929643    1.027638    3.462617    1.058410    0.062363    0.005928    0.663999    
#> 460: 0.929286    1.027719    3.462577    1.057501    0.062406    0.005931    0.663946    
#> 461: 0.929065    1.027805    3.462587    1.056893    0.062424    0.005934    0.663924    
#> 462: 0.929170    1.027846    3.462631    1.056840    0.062403    0.005941    0.663835    
#> 463: 0.929387    1.027901    3.462666    1.057035    0.062386    0.005947    0.663768    
#> 464: 0.929692    1.027923    3.462710    1.057229    0.062380    0.005955    0.663719    
#> 465: 0.929673    1.027781    3.462725    1.056678    0.062358    0.005958    0.663709    
#> 466: 0.929460    1.027867    3.462688    1.056081    0.062353    0.005959    0.663710    
#> 467: 0.929240    1.027917    3.462673    1.055780    0.062310    0.005972    0.663606    
#> 468: 0.929323    1.027918    3.462678    1.056101    0.062288    0.005977    0.663604    
#> 469: 0.929320    1.028011    3.462656    1.056430    0.062238    0.005982    0.663592    
#> 470: 0.929181    1.027994    3.462632    1.056734    0.062212    0.005996    0.663573    
#> 471: 0.928891    1.027988    3.462602    1.055926    0.062183    0.006002    0.663543    
#> 472: 0.928678    1.028011    3.462598    1.055523    0.062189    0.006011    0.663558    
#> 473: 0.928259    1.028030    3.462580    1.054678    0.062190    0.006014    0.663561    
#> 474: 0.927920    1.028062    3.462554    1.053844    0.062242    0.006014    0.663611    
#> 475: 0.927829    1.028153    3.462551    1.053279    0.062232    0.006011    0.663674    
#> 476: 0.927739    1.028135    3.462523    1.052897    0.062271    0.006008    0.663705    
#> 477: 0.927663    1.028148    3.462501    1.052881    0.062304    0.006004    0.663656    
#> 478: 0.927420    1.028080    3.462504    1.052642    0.062254    0.006002    0.663707    
#> 479: 0.927461    1.028162    3.462512    1.052984    0.062265    0.006001    0.663744    
#> 480: 0.927522    1.028164    3.462538    1.053121    0.062245    0.006002    0.663772    
#> 481: 0.927568    1.028093    3.462562    1.053329    0.062238    0.006004    0.663797    
#> 482: 0.927699    1.028087    3.462579    1.054164    0.062197    0.006009    0.663828    
#> 483: 0.927627    1.028038    3.462590    1.054392    0.062188    0.006007    0.663919    
#> 484: 0.927765    1.027915    3.462601    1.055239    0.062169    0.006003    0.663950    
#> 485: 0.928200    1.027897    3.462574    1.057155    0.062172    0.005999    0.663991    
#> 486: 0.928280    1.027900    3.462576    1.057536    0.062164    0.005997    0.663934    
#> 487: 0.928362    1.027898    3.462612    1.057763    0.062116    0.005998    0.663943    
#> 488: 0.928430    1.027908    3.462635    1.058352    0.062090    0.005994    0.663952    
#> 489: 0.928605    1.027870    3.462664    1.058547    0.062128    0.005993    0.663929    
#> 490: 0.928880    1.027890    3.462722    1.059173    0.062125    0.005995    0.663934    
#> 491: 0.929172    1.027903    3.462760    1.060065    0.062123    0.005997    0.663933    
#> 492: 0.929290    1.027921    3.462793    1.060012    0.062095    0.006000    0.663981    
#> 493: 0.929166    1.027845    3.462819    1.059462    0.062107    0.006009    0.663953    
#> 494: 0.929188    1.027834    3.462823    1.059221    0.062122    0.006013    0.663920    
#> 495: 0.929433    1.027793    3.462838    1.059603    0.062101    0.006017    0.663883    
#> 496: 0.929305    1.027846    3.462816    1.058937    0.062048    0.006023    0.663904    
#> 497: 0.929207    1.027881    3.462822    1.058681    0.062024    0.006027    0.663886    
#> 498: 0.929098    1.027926    3.462811    1.058614    0.062002    0.006028    0.663848    
#> 499: 0.928994    1.028001    3.462769    1.058593    0.061980    0.006033    0.663801    
#> 500: 0.929063    1.027949    3.462735    1.059222    0.061988    0.006029    0.663798    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.284377    0.966315    3.453520    0.392401    0.089516    0.016800    1.657521    
#> 002: 0.264589    0.976038    3.488126    0.372781    0.085040    0.015960    1.064819    
#> 003: 0.376409    0.957083    3.523232    0.354142    0.089408    0.015162    0.828697    
#> 004: 0.342398    0.963359    3.521340    0.336435    0.088049    0.014404    0.692755    
#> 005: 0.377286    0.967854    3.511295    0.319613    0.094310    0.013684    0.676835    
#> 006: 0.328895    0.989583    3.492591    0.321816    0.092428    0.013000    0.613843    
#> 007: 0.289411    1.004095    3.485981    0.314181    0.113016    0.012350    0.621833    
#> 008: 0.287972    0.999128    3.469542    0.314196    0.107365    0.011732    0.609223    
#> 009: 0.243798    0.997283    3.460602    0.346002    0.101997    0.011146    0.611836    
#> 010: 0.239082    1.019347    3.457185    0.328702    0.096897    0.010761    0.625156    
#> 011: 0.284024    1.021989    3.456871    0.377417    0.120912    0.010223    0.603979    
#> 012: 0.296149    1.032251    3.456305    0.382761    0.114866    0.009711    0.596886    
#> 013: 0.266255    1.039780    3.456953    0.399383    0.109123    0.011378    0.586283    
#> 014: 0.282539    1.018487    3.465268    0.478659    0.105461    0.010839    0.598050    
#> 015: 0.298738    1.027028    3.465953    0.454726    0.105122    0.011298    0.575872    
#> 016: 0.299573    1.033181    3.475889    0.431990    0.110956    0.014166    0.589515    
#> 017: 0.316541    1.016011    3.484739    0.410391    0.109188    0.013457    0.582081    
#> 018: 0.315668    1.019581    3.473097    0.450496    0.120494    0.012785    0.584286    
#> 019: 0.301950    1.013748    3.470776    0.427971    0.114470    0.012145    0.584137    
#> 020: 0.347092    1.028971    3.473048    0.447006    0.108746    0.011538    0.595964    
#> 021: 0.323858    0.995111    3.475117    0.462695    0.103309    0.010961    0.583365    
#> 022: 0.309353    0.998328    3.479616    0.439560    0.098143    0.010413    0.571361    
#> 023: 0.369271    1.015620    3.483995    0.470426    0.093236    0.009892    0.594727    
#> 024: 0.340136    1.024590    3.478426    0.446905    0.091934    0.009398    0.583515    
#> 025: 0.314411    1.006962    3.476438    0.428480    0.087523    0.009829    0.584429    
#> 026: 0.307849    1.037691    3.470163    0.487608    0.090076    0.012515    0.586536    
#> 027: 0.315999    1.045446    3.472389    0.511729    0.101281    0.012407    0.593751    
#> 028: 0.327988    1.042143    3.468841    0.486142    0.096217    0.013233    0.583447    
#> 029: 0.342008    1.011817    3.474936    0.490318    0.091406    0.012572    0.603620    
#> 030: 0.321768    1.018470    3.472648    0.465802    0.100379    0.011943    0.591608    
#> 031: 0.284586    0.999766    3.465042    0.442512    0.106982    0.011346    0.589628    
#> 032: 0.276542    1.001872    3.461343    0.436492    0.102687    0.010779    0.591168    
#> 033: 0.285055    1.018845    3.463660    0.445939    0.109391    0.010240    0.602930    
#> 034: 0.330384    1.018496    3.473201    0.439491    0.107118    0.009908    0.594656    
#> 035: 0.310848    0.999372    3.469669    0.466099    0.101763    0.009412    0.589188    
#> 036: 0.311581    1.026238    3.466730    0.481888    0.105163    0.009239    0.597932    
#> 037: 0.289105    1.034017    3.467132    0.457793    0.110486    0.008777    0.614218    
#> 038: 0.281733    1.027738    3.463985    0.438469    0.104961    0.008338    0.602529    
#> 039: 0.298650    1.038994    3.462251    0.481701    0.099713    0.008758    0.583192    
#> 040: 0.299372    1.044399    3.466908    0.457616    0.095806    0.008396    0.598177    
#> 041: 0.270991    1.021873    3.463219    0.434735    0.104518    0.009156    0.579767    
#> 042: 0.292209    1.038269    3.461778    0.412998    0.100974    0.009542    0.563623    
#> 043: 0.280222    1.038451    3.451993    0.416912    0.095926    0.009065    0.580884    
#> 044: 0.283165    1.055613    3.451299    0.396067    0.110433    0.008612    0.589936    
#> 045: 0.270530    1.048235    3.446408    0.386739    0.107941    0.008571    0.599641    
#> 046: 0.263157    1.021150    3.455626    0.452284    0.105836    0.009508    0.596783    
#> 047: 0.304368    1.027999    3.455268    0.449891    0.100544    0.010667    0.586504    
#> 048: 0.284211    1.025832    3.464603    0.428440    0.098351    0.011115    0.586866    
#> 049: 0.322467    1.004026    3.483305    0.467445    0.093433    0.013020    0.597530    
#> 050: 0.372428    0.981902    3.490815    0.480183    0.088762    0.012888    0.593217    
#> 051: 0.351447    0.990849    3.485767    0.501372    0.084324    0.014827    0.597961    
#> 052: 0.374472    0.991231    3.503498    0.476303    0.096472    0.014330    0.590087    
#> 053: 0.374278    1.002280    3.493355    0.460378    0.107343    0.013614    0.580401    
#> 054: 0.349014    0.990154    3.492372    0.456262    0.105735    0.012933    0.593532    
#> 055: 0.333453    0.997191    3.480523    0.521027    0.100448    0.012286    0.606920    
#> 056: 0.365336    0.997892    3.484412    0.603349    0.110299    0.011672    0.604585    
#> 057: 0.370745    1.005021    3.490760    0.573182    0.104784    0.013311    0.607609    
#> 058: 0.383856    1.002156    3.480986    0.544523    0.099545    0.012646    0.590637    
#> 059: 0.347925    0.964508    3.485104    0.517297    0.094568    0.014714    0.617460    
#> 060: 0.341945    0.982279    3.488455    0.510038    0.091329    0.014337    0.615243    
#> 061: 0.345386    1.019180    3.480557    0.484536    0.112752    0.013620    0.612283    
#> 062: 0.358405    1.023265    3.482511    0.505791    0.116450    0.013630    0.605386    
#> 063: 0.395080    0.986564    3.492502    0.552962    0.110628    0.015008    0.600064    
#> 064: 0.339868    0.987599    3.487301    0.544294    0.105096    0.014257    0.603188    
#> 065: 0.355088    0.995654    3.475400    0.517079    0.099841    0.013544    0.604434    
#> 066: 0.345354    1.009798    3.480518    0.546272    0.094849    0.014435    0.588415    
#> 067: 0.338809    1.005844    3.482318    0.520744    0.090107    0.015079    0.578429    
#> 068: 0.305042    1.015773    3.489346    0.494707    0.105005    0.014991    0.601435    
#> 069: 0.308171    1.013951    3.466949    0.536626    0.099754    0.014242    0.616763    
#> 070: 0.325355    1.005513    3.482152    0.509795    0.098549    0.013530    0.586377    
#> 071: 0.311030    1.011097    3.465434    0.484305    0.114969    0.012853    0.594312    
#> 072: 0.309467    0.993579    3.478827    0.467046    0.109221    0.012211    0.596058    
#> 073: 0.339872    0.991810    3.498111    0.443694    0.103760    0.013165    0.581695    
#> 074: 0.348120    0.979499    3.491083    0.432277    0.098572    0.012506    0.586413    
#> 075: 0.352913    0.979488    3.502968    0.470286    0.102747    0.011881    0.590472    
#> 076: 0.362147    1.006419    3.502779    0.503705    0.097610    0.013176    0.601754    
#> 077: 0.363590    1.003334    3.493701    0.492108    0.101152    0.012517    0.590436    
#> 078: 0.356597    1.023609    3.492224    0.530670    0.096761    0.011891    0.583308    
#> 079: 0.372632    1.005701    3.494542    0.504136    0.098049    0.012652    0.604653    
#> 080: 0.375252    0.995336    3.496082    0.519859    0.125978    0.012020    0.590528    
#> 081: 0.372867    1.004212    3.492986    0.493866    0.119679    0.011419    0.581022    
#> 082: 0.360509    0.986378    3.507072    0.469173    0.113695    0.011055    0.592279    
#> 083: 0.359558    1.012152    3.502568    0.445714    0.108010    0.012241    0.596970    
#> 084: 0.327361    1.001798    3.494712    0.423429    0.102610    0.011629    0.583912    
#> 085: 0.370653    1.002435    3.509966    0.457330    0.097479    0.011242    0.592853    
#> 086: 0.381187    1.004914    3.505442    0.468237    0.102354    0.011899    0.574877    
#> 087: 0.365903    0.998387    3.496450    0.444826    0.111300    0.011304    0.581223    
#> 088: 0.309942    1.003685    3.485152    0.422584    0.105735    0.010739    0.601220    
#> 089: 0.310432    1.019927    3.471569    0.449803    0.118383    0.010202    0.584107    
#> 090: 0.313472    1.015187    3.471425    0.471032    0.123090    0.009692    0.585625    
#> 091: 0.312643    1.010089    3.463171    0.487891    0.116936    0.009207    0.597921    
#> 092: 0.305196    1.035449    3.463154    0.479889    0.111089    0.008747    0.596413    
#> 093: 0.300537    1.014615    3.459533    0.480070    0.115914    0.008310    0.606562    
#> 094: 0.297506    1.025222    3.457486    0.456066    0.112284    0.007894    0.606417    
#> 095: 0.303860    1.022279    3.467062    0.459142    0.112734    0.007499    0.609191    
#> 096: 0.240997    1.032960    3.464331    0.436185    0.111367    0.007322    0.603994    
#> 097: 0.270911    1.027123    3.457760    0.438715    0.107676    0.007415    0.585415    
#> 098: 0.279150    1.039278    3.468433    0.416779    0.107693    0.007670    0.589435    
#> 099: 0.283658    1.009808    3.464497    0.450783    0.102308    0.008268    0.584154    
#> 100: 0.303886    1.039755    3.459365    0.438786    0.105962    0.008322    0.580017    
#> 101: 0.262218    1.025360    3.452192    0.416847    0.107652    0.008134    0.581844    
#> 102: 0.273571    1.026262    3.448084    0.396005    0.131449    0.007728    0.593941    
#> 103: 0.286135    1.026657    3.463820    0.417363    0.124876    0.007341    0.587173    
#> 104: 0.291825    1.020636    3.476878    0.411514    0.118632    0.007059    0.606862    
#> 105: 0.296298    0.996803    3.476657    0.390938    0.113289    0.007181    0.621621    
#> 106: 0.309924    1.012421    3.475574    0.410466    0.113375    0.008065    0.594696    
#> 107: 0.302844    1.024618    3.481090    0.419880    0.107706    0.009158    0.601015    
#> 108: 0.311694    0.999187    3.483742    0.437231    0.107582    0.008701    0.613728    
#> 109: 0.351799    1.032820    3.481053    0.502329    0.102203    0.008266    0.601245    
#> 110: 0.343683    1.013638    3.463324    0.534728    0.097093    0.007852    0.593374    
#> 111: 0.340238    1.021845    3.467251    0.507992    0.095276    0.007460    0.587147    
#> 112: 0.327627    1.012347    3.462979    0.482592    0.090512    0.007087    0.601060    
#> 113: 0.303016    1.045288    3.464411    0.458463    0.088787    0.006732    0.582512    
#> 114: 0.317698    1.030906    3.468879    0.470651    0.097544    0.006635    0.591136    
#> 115: 0.323018    1.018341    3.466972    0.499668    0.093019    0.006303    0.608094    
#> 116: 0.297042    1.037332    3.468523    0.474685    0.118908    0.006071    0.603180    
#> 117: 0.315444    1.035464    3.465576    0.465477    0.113851    0.005767    0.601005    
#> 118: 0.331006    1.034090    3.468699    0.442204    0.108158    0.006532    0.593076    
#> 119: 0.328721    1.037581    3.467176    0.426742    0.102923    0.007355    0.611465    
#> 120: 0.269208    1.017384    3.461025    0.423812    0.097777    0.007206    0.595998    
#> 121: 0.321197    1.048617    3.465218    0.434536    0.094312    0.007830    0.594451    
#> 122: 0.303036    1.023815    3.475869    0.417994    0.107910    0.007439    0.582302    
#> 123: 0.339354    1.040356    3.473779    0.422638    0.102515    0.007067    0.596636    
#> 124: 0.320434    1.048219    3.469594    0.401506    0.106460    0.008728    0.597884    
#> 125: 0.327834    1.045921    3.461245    0.448568    0.101137    0.008292    0.590471    
#> 126: 0.303733    1.040033    3.454135    0.426140    0.096080    0.008089    0.594310    
#> 127: 0.317284    1.028362    3.455801    0.411442    0.091276    0.009040    0.596054    
#> 128: 0.286595    1.043439    3.462007    0.396149    0.107121    0.008588    0.582299    
#> 129: 0.296448    1.033731    3.471508    0.448384    0.101765    0.008347    0.582939    
#> 130: 0.319726    1.022037    3.475447    0.425965    0.096677    0.009783    0.583596    
#> 131: 0.309639    1.023995    3.466817    0.427128    0.111178    0.009324    0.592639    
#> 132: 0.272314    1.041480    3.453540    0.415563    0.113102    0.008858    0.611571    
#> 133: 0.308249    1.035575    3.459675    0.549437    0.114504    0.009060    0.586199    
#> 134: 0.317216    1.013886    3.466609    0.544169    0.110531    0.009233    0.594682    
#> 135: 0.336607    1.009353    3.476173    0.516961    0.105005    0.008771    0.590772    
#> 136: 0.342294    0.994944    3.475290    0.510651    0.099755    0.008735    0.577921    
#> 137: 0.343495    1.002622    3.486273    0.485118    0.102135    0.008299    0.582423    
#> 138: 0.341878    1.021539    3.479325    0.460862    0.101646    0.007884    0.582313    
#> 139: 0.322522    1.014934    3.482471    0.437819    0.096564    0.008336    0.580705    
#> 140: 0.325258    1.030596    3.487463    0.452465    0.102169    0.010736    0.592058    
#> 141: 0.293023    1.003612    3.484536    0.457191    0.098226    0.010199    0.603273    
#> 142: 0.348723    0.992505    3.497557    0.504948    0.093315    0.009689    0.588135    
#> 143: 0.330214    1.018372    3.490988    0.536622    0.103090    0.009205    0.600280    
#> 144: 0.371977    1.010855    3.495257    0.509791    0.100525    0.008744    0.580995    
#> 145: 0.337186    1.019890    3.480444    0.484301    0.101813    0.008307    0.578432    
#> 146: 0.321750    1.014301    3.482934    0.460086    0.098098    0.008444    0.593035    
#> 147: 0.279597    1.005359    3.474877    0.437082    0.099218    0.009333    0.574443    
#> 148: 0.307955    1.017699    3.481440    0.491030    0.117796    0.008867    0.576494    
#> 149: 0.342385    0.994696    3.488737    0.466478    0.111907    0.008423    0.581022    
#> 150: 0.348535    1.004358    3.478891    0.451660    0.108250    0.009622    0.607935    
#> 151: 0.303114    1.028003    3.470337    0.502495    0.102837    0.009877    0.597392    
#> 152: 0.280391    1.021379    3.473345    0.493369    0.083407    0.012126    0.590246    
#> 153: 0.282678    1.029819    3.474586    0.467701    0.087981    0.008974    0.602555    
#> 154: 0.312608    1.038089    3.477767    0.444769    0.083815    0.009198    0.600370    
#> 155: 0.294895    1.017979    3.471113    0.375029    0.107794    0.008703    0.588467    
#> 156: 0.324286    1.007997    3.489255    0.349799    0.103677    0.008718    0.597716    
#> 157: 0.380700    0.994231    3.492200    0.440741    0.099729    0.008271    0.602147    
#> 158: 0.385931    1.008116    3.490848    0.471835    0.112459    0.007592    0.580828    
#> 159: 0.350268    1.015012    3.493575    0.439653    0.124071    0.007781    0.603328    
#> 160: 0.365123    0.989472    3.503508    0.459086    0.134969    0.007091    0.608530    
#> 161: 0.350575    0.983330    3.501200    0.375512    0.109472    0.008465    0.605555    
#> 162: 0.348454    0.987683    3.488391    0.368691    0.103046    0.007244    0.612919    
#> 163: 0.358028    1.010205    3.490196    0.414776    0.113492    0.007141    0.600738    
#> 164: 0.336439    1.003526    3.484095    0.503359    0.091815    0.007588    0.590391    
#> 165: 0.399505    0.992216    3.498140    0.467245    0.095157    0.010286    0.590900    
#> 166: 0.412540    1.004832    3.503555    0.467854    0.102572    0.009377    0.601575    
#> 167: 0.390572    1.008842    3.502818    0.526242    0.091163    0.010692    0.601812    
#> 168: 0.393010    0.991230    3.510301    0.445407    0.081711    0.009923    0.595373    
#> 169: 0.369166    1.023591    3.500594    0.408110    0.085952    0.008510    0.599915    
#> 170: 0.371956    1.009365    3.493040    0.443529    0.103363    0.007170    0.589193    
#> 171: 0.343588    1.000289    3.493767    0.424261    0.108198    0.008464    0.579080    
#> 172: 0.289185    1.032193    3.482362    0.379939    0.095905    0.008495    0.579149    
#> 173: 0.287106    1.037588    3.467882    0.336650    0.091164    0.009573    0.581612    
#> 174: 0.299681    1.026876    3.474822    0.334907    0.093597    0.011460    0.596762    
#> 175: 0.306088    1.016487    3.470134    0.382249    0.095791    0.009715    0.601604    
#> 176: 0.278018    1.022151    3.480740    0.294116    0.105362    0.010409    0.597249    
#> 177: 0.316317    0.990378    3.486505    0.318276    0.102554    0.008381    0.599582    
#> 178: 0.318407    0.995321    3.489392    0.374498    0.092501    0.011114    0.582991    
#> 179: 0.332554    1.027968    3.479138    0.351172    0.092757    0.010509    0.597100    
#> 180: 0.314217    1.007596    3.476607    0.388972    0.092871    0.010848    0.574882    
#> 181: 0.328947    1.014985    3.463387    0.418322    0.086610    0.009485    0.579032    
#> 182: 0.287320    1.025957    3.458588    0.368339    0.075702    0.012072    0.596251    
#> 183: 0.275958    1.048064    3.462614    0.375657    0.084935    0.012780    0.588666    
#> 184: 0.281819    1.026536    3.466702    0.368835    0.077424    0.013435    0.577406    
#> 185: 0.298156    1.024552    3.468795    0.417666    0.085568    0.012959    0.581677    
#> 186: 0.301938    1.030890    3.475635    0.438897    0.090272    0.014366    0.594905    
#> 187: 0.308523    1.009051    3.479958    0.426144    0.103296    0.013710    0.572496    
#> 188: 0.307803    1.009222    3.480064    0.436416    0.092370    0.013953    0.577102    
#> 189: 0.326001    1.019170    3.484129    0.488201    0.086275    0.012842    0.579932    
#> 190: 0.332997    1.031818    3.483588    0.508172    0.081895    0.012985    0.577691    
#> 191: 0.321466    1.025016    3.474964    0.404688    0.083149    0.011128    0.586090    
#> 192: 0.331327    1.025732    3.490030    0.423327    0.089542    0.015171    0.583326    
#> 193: 0.347563    1.030732    3.488874    0.446618    0.091976    0.013262    0.592812    
#> 194: 0.314873    1.030448    3.475184    0.377135    0.102254    0.015612    0.593076    
#> 195: 0.322348    1.004438    3.487179    0.404609    0.089720    0.013542    0.585198    
#> 196: 0.347487    0.993229    3.495166    0.404200    0.083247    0.013196    0.601529    
#> 197: 0.322494    1.002650    3.505583    0.364828    0.097482    0.012757    0.608378    
#> 198: 0.327609    0.986195    3.485919    0.370633    0.083661    0.015110    0.589691    
#> 199: 0.315155    0.990370    3.488047    0.411761    0.097192    0.013292    0.594462    
#> 200: 0.328883    1.001094    3.489958    0.434261    0.109094    0.011733    0.607887    
#> 201: 0.321572    0.997435    3.491790    0.420067    0.101581    0.013157    0.599710    
#> 202: 0.312221    0.998837    3.490339    0.402046    0.098747    0.013907    0.598184    
#> 203: 0.318672    1.000231    3.487518    0.401982    0.096191    0.013573    0.596732    
#> 204: 0.328175    0.996184    3.489822    0.405072    0.092645    0.013755    0.597625    
#> 205: 0.328327    0.999942    3.490315    0.400059    0.089607    0.013585    0.604144    
#> 206: 0.326296    1.003657    3.490842    0.391347    0.090148    0.013797    0.606401    
#> 207: 0.332964    1.003344    3.490664    0.401940    0.089317    0.013768    0.604741    
#> 208: 0.336920    1.002568    3.491709    0.397593    0.088629    0.013793    0.602793    
#> 209: 0.339071    1.000209    3.491876    0.397271    0.089010    0.013598    0.601600    
#> 210: 0.343281    0.998920    3.492374    0.395628    0.088393    0.013503    0.601500    
#> 211: 0.345459    0.998545    3.493519    0.395185    0.088222    0.013319    0.600550    
#> 212: 0.346448    0.997794    3.494046    0.394175    0.089124    0.013152    0.601378    
#> 213: 0.349491    0.996951    3.494869    0.395451    0.090359    0.013252    0.601365    
#> 214: 0.353566    0.996737    3.495558    0.396706    0.091770    0.013220    0.600786    
#> 215: 0.355460    0.996245    3.496735    0.395873    0.092157    0.013195    0.601506    
#> 216: 0.359123    0.994126    3.497527    0.396700    0.093391    0.013179    0.602517    
#> 217: 0.358325    0.994146    3.497760    0.394764    0.094162    0.013189    0.602080    
#> 218: 0.357905    0.994591    3.497589    0.391959    0.094333    0.013170    0.602325    
#> 219: 0.357796    0.994109    3.497118    0.392350    0.094120    0.013068    0.601959    
#> 220: 0.355573    0.994163    3.497053    0.391481    0.093974    0.013018    0.601834    
#> 221: 0.354485    0.994520    3.497043    0.389862    0.093503    0.012945    0.601401    
#> 222: 0.354451    0.993890    3.497083    0.388628    0.093786    0.012866    0.601868    
#> 223: 0.355927    0.993397    3.497548    0.387334    0.093817    0.012769    0.602169    
#> 224: 0.356901    0.993251    3.497718    0.386884    0.093860    0.012651    0.602295    
#> 225: 0.355769    0.992178    3.497956    0.385525    0.093443    0.012627    0.602736    
#> 226: 0.355598    0.991471    3.497612    0.384697    0.093481    0.012482    0.602758    
#> 227: 0.354604    0.991525    3.497640    0.384202    0.093148    0.012390    0.602880    
#> 228: 0.353385    0.992753    3.497047    0.384773    0.093520    0.012343    0.602406    
#> 229: 0.351882    0.992879    3.496522    0.385306    0.093348    0.012230    0.602096    
#> 230: 0.351110    0.993216    3.495876    0.387122    0.093332    0.012073    0.602141    
#> 231: 0.350785    0.993795    3.495565    0.388993    0.093584    0.011921    0.601425    
#> 232: 0.348927    0.994345    3.495060    0.389719    0.093698    0.011863    0.601120    
#> 233: 0.346818    0.993681    3.494627    0.390387    0.093696    0.011869    0.601262    
#> 234: 0.344849    0.993703    3.494218    0.391594    0.093902    0.011869    0.601142    
#> 235: 0.343267    0.994086    3.493590    0.392072    0.093816    0.011814    0.601067    
#> 236: 0.342781    0.994936    3.493180    0.392873    0.094009    0.011778    0.600699    
#> 237: 0.342659    0.995463    3.492836    0.393165    0.093859    0.011742    0.601060    
#> 238: 0.342304    0.996036    3.492341    0.391986    0.094150    0.011746    0.602052    
#> 239: 0.341442    0.996962    3.491853    0.392195    0.095012    0.011700    0.602082    
#> 240: 0.340730    0.996664    3.491838    0.392934    0.095445    0.011657    0.601865    
#> 241: 0.340788    0.995717    3.491995    0.393679    0.095691    0.011586    0.601707    
#> 242: 0.340571    0.995135    3.491936    0.394163    0.095489    0.011534    0.601921    
#> 243: 0.340185    0.995469    3.491913    0.395566    0.095419    0.011522    0.601975    
#> 244: 0.340392    0.996016    3.491959    0.396169    0.095519    0.011500    0.602137    
#> 245: 0.340870    0.995637    3.492118    0.397466    0.095893    0.011495    0.602320    
#> 246: 0.341489    0.995969    3.492131    0.399094    0.095955    0.011488    0.602102    
#> 247: 0.341897    0.995676    3.492401    0.400233    0.096416    0.011476    0.601948    
#> 248: 0.341176    0.995808    3.492332    0.399904    0.096829    0.011431    0.601946    
#> 249: 0.340555    0.996043    3.492212    0.401046    0.096983    0.011416    0.601969    
#> 250: 0.340920    0.996225    3.492172    0.403186    0.097096    0.011443    0.602029    
#> 251: 0.341226    0.996728    3.492232    0.405075    0.097182    0.011432    0.601882    
#> 252: 0.341712    0.997400    3.492242    0.406372    0.097261    0.011435    0.601915    
#> 253: 0.341578    0.997925    3.492162    0.408324    0.097292    0.011459    0.601771    
#> 254: 0.341480    0.998472    3.492085    0.409129    0.097431    0.011485    0.601735    
#> 255: 0.341158    0.999212    3.491824    0.409109    0.097506    0.011514    0.601784    
#> 256: 0.341003    0.999243    3.491526    0.409275    0.097469    0.011516    0.601890    
#> 257: 0.340832    0.999197    3.491338    0.410109    0.097540    0.011539    0.601730    
#> 258: 0.340273    0.999166    3.491251    0.410118    0.097470    0.011518    0.601851    
#> 259: 0.340306    0.999282    3.491088    0.410798    0.097578    0.011529    0.601616    
#> 260: 0.340258    0.999463    3.491031    0.410824    0.097625    0.011530    0.601315    
#> 261: 0.340324    0.999559    3.491054    0.409914    0.097637    0.011503    0.601197    
#> 262: 0.340480    0.999868    3.490946    0.409232    0.097586    0.011497    0.600985    
#> 263: 0.340480    1.000130    3.490846    0.408513    0.097467    0.011496    0.600987    
#> 264: 0.340444    1.000330    3.490838    0.409220    0.097540    0.011479    0.600762    
#> 265: 0.340430    1.000471    3.490803    0.409180    0.097572    0.011489    0.600446    
#> 266: 0.340609    1.000659    3.490869    0.408763    0.097564    0.011489    0.600320    
#> 267: 0.340663    1.000503    3.491192    0.408117    0.097470    0.011502    0.600292    
#> 268: 0.341040    1.000052    3.491216    0.408015    0.097568    0.011466    0.600208    
#> 269: 0.341872    0.999678    3.491372    0.408611    0.097818    0.011459    0.600410    
#> 270: 0.342279    0.999633    3.491459    0.408219    0.097867    0.011445    0.600250    
#> 271: 0.342513    0.999673    3.491453    0.408482    0.097938    0.011427    0.600286    
#> 272: 0.343020    0.999517    3.491507    0.408541    0.097879    0.011433    0.600324    
#> 273: 0.342756    0.999669    3.491626    0.407460    0.098001    0.011416    0.600389    
#> 274: 0.342463    0.999972    3.491702    0.406488    0.097846    0.011430    0.600341    
#> 275: 0.342521    1.000115    3.491704    0.405428    0.097607    0.011451    0.600338    
#> 276: 0.342364    1.000330    3.491890    0.404313    0.097542    0.011510    0.600435    
#> 277: 0.342296    1.000563    3.492083    0.404196    0.097549    0.011579    0.600419    
#> 278: 0.342198    1.000645    3.492140    0.404444    0.097544    0.011605    0.600437    
#> 279: 0.341965    1.000589    3.492106    0.404458    0.097858    0.011609    0.600442    
#> 280: 0.341626    1.000857    3.492021    0.403928    0.098085    0.011582    0.600195    
#> 281: 0.341077    1.001108    3.491952    0.403490    0.098199    0.011552    0.600085    
#> 282: 0.341126    1.001277    3.491993    0.403294    0.098313    0.011530    0.599999    
#> 283: 0.341199    1.001271    3.492021    0.404120    0.098347    0.011518    0.600306    
#> 284: 0.340999    1.001348    3.491827    0.405045    0.098336    0.011523    0.600245    
#> 285: 0.340954    1.001552    3.491567    0.405783    0.098475    0.011512    0.600311    
#> 286: 0.340786    1.001647    3.491339    0.406491    0.098506    0.011499    0.600348    
#> 287: 0.340517    1.001987    3.491060    0.407990    0.098632    0.011498    0.600447    
#> 288: 0.340701    1.002071    3.490938    0.408842    0.098628    0.011511    0.600423    
#> 289: 0.340702    1.002089    3.490868    0.408593    0.098640    0.011546    0.600341    
#> 290: 0.340554    1.002207    3.490781    0.408114    0.098687    0.011553    0.600452    
#> 291: 0.340571    1.002426    3.490806    0.407505    0.098691    0.011580    0.600351    
#> 292: 0.340780    1.002331    3.490874    0.408269    0.098732    0.011585    0.600186    
#> 293: 0.340809    1.002273    3.490914    0.409533    0.098634    0.011574    0.600025    
#> 294: 0.340937    1.002236    3.490884    0.410585    0.098627    0.011560    0.599891    
#> 295: 0.341205    1.001948    3.490803    0.410991    0.098617    0.011535    0.599770    
#> 296: 0.341286    1.001960    3.490847    0.410899    0.098588    0.011533    0.599887    
#> 297: 0.341569    1.002207    3.490905    0.411299    0.098529    0.011522    0.599945    
#> 298: 0.341832    1.002202    3.490843    0.412624    0.098467    0.011517    0.599885    
#> 299: 0.341804    1.002148    3.490778    0.412940    0.098366    0.011532    0.599756    
#> 300: 0.342098    1.002089    3.490757    0.412887    0.098382    0.011526    0.599677    
#> 301: 0.342101    1.002070    3.490682    0.412135    0.098402    0.011503    0.599818    
#> 302: 0.341800    1.002135    3.490577    0.411555    0.098417    0.011468    0.599857    
#> 303: 0.341338    1.002377    3.490403    0.410950    0.098537    0.011435    0.599698    
#> 304: 0.341054    1.002741    3.490266    0.411363    0.098585    0.011417    0.599561    
#> 305: 0.340942    1.002619    3.490204    0.411971    0.098595    0.011395    0.599492    
#> 306: 0.340657    1.002529    3.490122    0.412347    0.098561    0.011388    0.599478    
#> 307: 0.340527    1.002640    3.489953    0.412391    0.098625    0.011389    0.599481    
#> 308: 0.339920    1.002737    3.489776    0.412595    0.098595    0.011378    0.599505    
#> 309: 0.339296    1.002822    3.489554    0.412448    0.098626    0.011376    0.599572    
#> 310: 0.339049    1.002950    3.489343    0.412764    0.098528    0.011373    0.599572    
#> 311: 0.339067    1.003132    3.489288    0.413197    0.098450    0.011371    0.599535    
#> 312: 0.338791    1.003167    3.489105    0.412842    0.098321    0.011372    0.599533    
#> 313: 0.338226    1.003127    3.488868    0.412279    0.098102    0.011355    0.599563    
#> 314: 0.337476    1.003374    3.488589    0.412201    0.098027    0.011343    0.599513    
#> 315: 0.336928    1.003628    3.488380    0.412618    0.098067    0.011328    0.599433    
#> 316: 0.336581    1.003859    3.488205    0.412984    0.098126    0.011315    0.599332    
#> 317: 0.336554    1.004097    3.488110    0.413235    0.097999    0.011305    0.599399    
#> 318: 0.336596    1.004184    3.487991    0.413330    0.097983    0.011311    0.599291    
#> 319: 0.336348    1.004193    3.487915    0.413095    0.097946    0.011327    0.599213    
#> 320: 0.336043    1.004055    3.487839    0.413319    0.097934    0.011339    0.599240    
#> 321: 0.335898    1.004156    3.487724    0.413433    0.097954    0.011318    0.599411    
#> 322: 0.335755    1.004052    3.487602    0.413182    0.097947    0.011336    0.599311    
#> 323: 0.335474    1.004118    3.487508    0.412905    0.097894    0.011338    0.599178    
#> 324: 0.335328    1.004148    3.487453    0.412472    0.097808    0.011339    0.599013    
#> 325: 0.335176    1.004295    3.487379    0.412480    0.097713    0.011329    0.598833    
#> 326: 0.335335    1.004198    3.487355    0.412676    0.097616    0.011313    0.598766    
#> 327: 0.335459    1.004323    3.487301    0.412893    0.097585    0.011285    0.598743    
#> 328: 0.335586    1.004418    3.487251    0.413513    0.097564    0.011267    0.598657    
#> 329: 0.335635    1.004442    3.487199    0.414004    0.097614    0.011246    0.598586    
#> 330: 0.335311    1.004400    3.487180    0.413898    0.097587    0.011230    0.598450    
#> 331: 0.335378    1.004434    3.487143    0.413925    0.097570    0.011224    0.598325    
#> 332: 0.335468    1.004570    3.487156    0.413956    0.097641    0.011224    0.598256    
#> 333: 0.335288    1.004600    3.487068    0.413999    0.097690    0.011217    0.598162    
#> 334: 0.334936    1.004588    3.486947    0.413697    0.097712    0.011199    0.598185    
#> 335: 0.334596    1.004680    3.486793    0.413167    0.097655    0.011198    0.598189    
#> 336: 0.333902    1.004856    3.486642    0.412613    0.097622    0.011188    0.598190    
#> 337: 0.333577    1.005235    3.486478    0.412821    0.097707    0.011175    0.598221    
#> 338: 0.333261    1.005335    3.486369    0.412626    0.097676    0.011155    0.598230    
#> 339: 0.332803    1.005525    3.486195    0.412455    0.097764    0.011142    0.598157    
#> 340: 0.332720    1.005338    3.486124    0.412931    0.097828    0.011119    0.598196    
#> 341: 0.332739    1.005328    3.486139    0.413514    0.098076    0.011101    0.598123    
#> 342: 0.332596    1.005164    3.486109    0.413564    0.098294    0.011075    0.598175    
#> 343: 0.332322    1.005171    3.486039    0.413797    0.098444    0.011037    0.598163    
#> 344: 0.332466    1.005096    3.486026    0.414176    0.098400    0.011015    0.598259    
#> 345: 0.332526    1.005094    3.486049    0.414505    0.098464    0.010993    0.598205    
#> 346: 0.332581    1.005126    3.486001    0.414613    0.098633    0.010964    0.598129    
#> 347: 0.332688    1.005071    3.485913    0.414325    0.098722    0.010960    0.598083    
#> 348: 0.332499    1.005135    3.485796    0.414602    0.098803    0.010950    0.598021    
#> 349: 0.332214    1.005109    3.485654    0.414630    0.098777    0.010947    0.598053    
#> 350: 0.331696    1.005110    3.485491    0.414494    0.098911    0.010933    0.598094    
#> 351: 0.331387    1.005374    3.485282    0.414662    0.099059    0.010917    0.598164    
#> 352: 0.330936    1.005562    3.485147    0.415117    0.099147    0.010910    0.598262    
#> 353: 0.330670    1.005808    3.484987    0.415294    0.099140    0.010923    0.598273    
#> 354: 0.330372    1.006019    3.484796    0.415192    0.099122    0.010937    0.598231    
#> 355: 0.330255    1.006099    3.484678    0.415211    0.099112    0.010940    0.598297    
#> 356: 0.330133    1.006230    3.484672    0.415243    0.099162    0.010916    0.598429    
#> 357: 0.330330    1.006462    3.484657    0.415878    0.099139    0.010912    0.598349    
#> 358: 0.330372    1.006558    3.484709    0.415578    0.099089    0.010917    0.598307    
#> 359: 0.330345    1.006667    3.484761    0.415023    0.099065    0.010917    0.598303    
#> 360: 0.330226    1.006795    3.484714    0.414608    0.099060    0.010915    0.598229    
#> 361: 0.330190    1.006835    3.484727    0.414603    0.099025    0.010906    0.598178    
#> 362: 0.330402    1.006836    3.484780    0.414861    0.099046    0.010897    0.598008    
#> 363: 0.330468    1.006772    3.484837    0.415005    0.099075    0.010872    0.597936    
#> 364: 0.330639    1.006676    3.484879    0.414726    0.099102    0.010856    0.597994    
#> 365: 0.330654    1.006530    3.484888    0.414381    0.099100    0.010841    0.598036    
#> 366: 0.330722    1.006491    3.484864    0.413893    0.099177    0.010843    0.598157    
#> 367: 0.330825    1.006351    3.484904    0.413570    0.099211    0.010827    0.598188    
#> 368: 0.330922    1.006482    3.484870    0.413677    0.099222    0.010817    0.598205    
#> 369: 0.330934    1.006566    3.484881    0.413496    0.099230    0.010811    0.598244    
#> 370: 0.330898    1.006617    3.484876    0.413253    0.099230    0.010807    0.598194    
#> 371: 0.330686    1.006762    3.484775    0.412882    0.099305    0.010791    0.598171    
#> 372: 0.330290    1.006834    3.484637    0.412551    0.099344    0.010780    0.598187    
#> 373: 0.329875    1.007104    3.484446    0.412701    0.099330    0.010776    0.598180    
#> 374: 0.329613    1.007270    3.484299    0.412547    0.099259    0.010782    0.598154    
#> 375: 0.329436    1.007427    3.484210    0.412794    0.099221    0.010787    0.598176    
#> 376: 0.329352    1.007574    3.484151    0.412569    0.099226    0.010809    0.598136    
#> 377: 0.329360    1.007645    3.484111    0.412783    0.099253    0.010821    0.598014    
#> 378: 0.329322    1.007627    3.484042    0.413017    0.099244    0.010831    0.598045    
#> 379: 0.329213    1.007606    3.484018    0.413202    0.099190    0.010832    0.597946    
#> 380: 0.329118    1.007654    3.484006    0.413020    0.099207    0.010853    0.597923    
#> 381: 0.328914    1.007688    3.483981    0.413186    0.099314    0.010857    0.597872    
#> 382: 0.328706    1.007668    3.483934    0.413146    0.099350    0.010853    0.597846    
#> 383: 0.328712    1.007649    3.483896    0.413381    0.099342    0.010844    0.597799    
#> 384: 0.328599    1.007603    3.483902    0.413428    0.099419    0.010840    0.597727    
#> 385: 0.328602    1.007664    3.483887    0.413733    0.099478    0.010826    0.597593    
#> 386: 0.328715    1.007699    3.483934    0.413752    0.099534    0.010811    0.597550    
#> 387: 0.328930    1.007694    3.483982    0.414018    0.099562    0.010807    0.597493    
#> 388: 0.328882    1.007707    3.483992    0.413779    0.099540    0.010802    0.597525    
#> 389: 0.328893    1.007580    3.483981    0.413638    0.099510    0.010797    0.597567    
#> 390: 0.328867    1.007733    3.483898    0.413858    0.099539    0.010774    0.597541    
#> 391: 0.328830    1.007794    3.483837    0.414120    0.099559    0.010765    0.597479    
#> 392: 0.328747    1.007862    3.483865    0.413737    0.099501    0.010765    0.597491    
#> 393: 0.328678    1.007828    3.483847    0.413694    0.099481    0.010770    0.597469    
#> 394: 0.328723    1.007903    3.483803    0.413812    0.099513    0.010774    0.597448    
#> 395: 0.328948    1.007980    3.483831    0.413791    0.099515    0.010786    0.597471    
#> 396: 0.329066    1.008020    3.483856    0.413686    0.099463    0.010791    0.597407    
#> 397: 0.329179    1.008036    3.483884    0.413786    0.099448    0.010800    0.597406    
#> 398: 0.329478    1.008031    3.483906    0.413787    0.099395    0.010802    0.597433    
#> 399: 0.329807    1.007957    3.483996    0.413881    0.099373    0.010804    0.597397    
#> 400: 0.329897    1.007910    3.484060    0.413654    0.099410    0.010796    0.597360    
#> 401: 0.329930    1.008006    3.484073    0.413507    0.099410    0.010792    0.597378    
#> 402: 0.329800    1.008112    3.484046    0.413223    0.099449    0.010792    0.597342    
#> 403: 0.329753    1.008095    3.483993    0.413335    0.099497    0.010792    0.597240    
#> 404: 0.329725    1.008184    3.483914    0.413616    0.099475    0.010789    0.597183    
#> 405: 0.329741    1.008289    3.483909    0.413707    0.099360    0.010792    0.597163    
#> 406: 0.329750    1.008328    3.483882    0.413966    0.099290    0.010790    0.597133    
#> 407: 0.329771    1.008392    3.483845    0.414131    0.099246    0.010781    0.597097    
#> 408: 0.329785    1.008429    3.483840    0.414084    0.099283    0.010763    0.597070    
#> 409: 0.329691    1.008360    3.483761    0.414129    0.099275    0.010746    0.597036    
#> 410: 0.329492    1.008462    3.483654    0.414164    0.099250    0.010729    0.597030    
#> 411: 0.329282    1.008299    3.483570    0.414002    0.099214    0.010722    0.597130    
#> 412: 0.329052    1.008464    3.483447    0.413999    0.099206    0.010711    0.597136    
#> 413: 0.328848    1.008588    3.483335    0.413904    0.099171    0.010704    0.597188    
#> 414: 0.328720    1.008694    3.483275    0.414056    0.099155    0.010695    0.597180    
#> 415: 0.328804    1.008652    3.483255    0.413761    0.099159    0.010687    0.597168    
#> 416: 0.328929    1.008619    3.483284    0.413803    0.099162    0.010684    0.597186    
#> 417: 0.328871    1.008642    3.483266    0.413547    0.099127    0.010670    0.597238    
#> 418: 0.328856    1.008710    3.483270    0.413557    0.099109    0.010664    0.597189    
#> 419: 0.328748    1.008789    3.483230    0.413428    0.099167    0.010660    0.597170    
#> 420: 0.328635    1.008827    3.483191    0.413467    0.099257    0.010654    0.597088    
#> 421: 0.328610    1.008863    3.483209    0.413458    0.099282    0.010653    0.597008    
#> 422: 0.328667    1.008861    3.483186    0.413571    0.099291    0.010639    0.596985    
#> 423: 0.328694    1.008829    3.483186    0.413699    0.099390    0.010626    0.597003    
#> 424: 0.328673    1.008819    3.483156    0.413740    0.099388    0.010616    0.597039    
#> 425: 0.328552    1.008884    3.483122    0.413437    0.099345    0.010606    0.597086    
#> 426: 0.328475    1.009044    3.483067    0.413619    0.099336    0.010602    0.597051    
#> 427: 0.328451    1.009055    3.483054    0.413571    0.099326    0.010594    0.597009    
#> 428: 0.328465    1.009177    3.483038    0.413795    0.099359    0.010591    0.596979    
#> 429: 0.328485    1.009173    3.483041    0.413713    0.099360    0.010594    0.596932    
#> 430: 0.328491    1.009186    3.483023    0.413841    0.099311    0.010591    0.596906    
#> 431: 0.328380    1.009213    3.482951    0.414092    0.099340    0.010585    0.596844    
#> 432: 0.328274    1.009259    3.482923    0.414302    0.099315    0.010588    0.596789    
#> 433: 0.328256    1.009355    3.482896    0.414092    0.099265    0.010591    0.596824    
#> 434: 0.328203    1.009374    3.482905    0.414095    0.099258    0.010587    0.596830    
#> 435: 0.328185    1.009455    3.482875    0.413931    0.099271    0.010583    0.596810    
#> 436: 0.328076    1.009540    3.482866    0.413947    0.099284    0.010569    0.596815    
#> 437: 0.328093    1.009530    3.482835    0.414162    0.099278    0.010559    0.596763    
#> 438: 0.328117    1.009575    3.482797    0.414493    0.099261    0.010557    0.596678    
#> 439: 0.328112    1.009727    3.482732    0.414517    0.099244    0.010548    0.596635    
#> 440: 0.328070    1.009816    3.482731    0.414487    0.099253    0.010550    0.596593    
#> 441: 0.328079    1.009800    3.482752    0.414574    0.099220    0.010557    0.596486    
#> 442: 0.328111    1.009852    3.482797    0.414496    0.099187    0.010567    0.596438    
#> 443: 0.328111    1.009904    3.482796    0.414435    0.099123    0.010579    0.596384    
#> 444: 0.327950    1.010007    3.482754    0.414239    0.099066    0.010590    0.596405    
#> 445: 0.327731    1.010077    3.482708    0.414147    0.099019    0.010592    0.596473    
#> 446: 0.327588    1.010170    3.482664    0.413998    0.098974    0.010584    0.596462    
#> 447: 0.327634    1.010197    3.482657    0.414048    0.098976    0.010588    0.596468    
#> 448: 0.327511    1.010151    3.482672    0.413902    0.098946    0.010599    0.596398    
#> 449: 0.327534    1.010235    3.482728    0.413772    0.098963    0.010597    0.596440    
#> 450: 0.327588    1.010252    3.482746    0.413722    0.099036    0.010594    0.596438    
#> 451: 0.327686    1.010238    3.482734    0.414055    0.099082    0.010587    0.596428    
#> 452: 0.327649    1.010307    3.482691    0.414231    0.099110    0.010587    0.596433    
#> 453: 0.327528    1.010360    3.482631    0.414138    0.099106    0.010591    0.596365    
#> 454: 0.327420    1.010512    3.482562    0.414102    0.099085    0.010583    0.596338    
#> 455: 0.327344    1.010588    3.482501    0.414111    0.099119    0.010571    0.596318    
#> 456: 0.327196    1.010582    3.482445    0.414258    0.099181    0.010565    0.596290    
#> 457: 0.327123    1.010546    3.482426    0.414469    0.099253    0.010555    0.596240    
#> 458: 0.327098    1.010664    3.482403    0.414574    0.099290    0.010546    0.596186    
#> 459: 0.326940    1.010806    3.482376    0.414416    0.099299    0.010538    0.596229    
#> 460: 0.326797    1.010860    3.482307    0.414251    0.099300    0.010535    0.596219    
#> 461: 0.326735    1.010876    3.482291    0.414113    0.099330    0.010532    0.596226    
#> 462: 0.326643    1.010960    3.482276    0.414040    0.099323    0.010529    0.596235    
#> 463: 0.326683    1.011011    3.482290    0.414172    0.099313    0.010530    0.596201    
#> 464: 0.326857    1.010996    3.482318    0.414116    0.099274    0.010530    0.596113    
#> 465: 0.326937    1.010931    3.482347    0.414113    0.099251    0.010524    0.596042    
#> 466: 0.326992    1.010972    3.482302    0.414200    0.099243    0.010519    0.595968    
#> 467: 0.326852    1.010920    3.482281    0.414293    0.099257    0.010507    0.595895    
#> 468: 0.326989    1.010913    3.482327    0.414457    0.099193    0.010512    0.595893    
#> 469: 0.326937    1.011006    3.482328    0.414381    0.099148    0.010520    0.595925    
#> 470: 0.326865    1.011057    3.482295    0.414112    0.099039    0.010519    0.595986    
#> 471: 0.326703    1.011011    3.482228    0.414253    0.098983    0.010522    0.595969    
#> 472: 0.326586    1.010997    3.482208    0.414417    0.098940    0.010522    0.595927    
#> 473: 0.326429    1.011068    3.482186    0.414187    0.098929    0.010527    0.595905    
#> 474: 0.326301    1.011096    3.482198    0.414027    0.098955    0.010534    0.595960    
#> 475: 0.326337    1.011158    3.482195    0.413827    0.098976    0.010539    0.595988    
#> 476: 0.326282    1.011090    3.482198    0.413722    0.098957    0.010544    0.596022    
#> 477: 0.326363    1.011030    3.482238    0.413921    0.098924    0.010551    0.595925    
#> 478: 0.326403    1.011040    3.482251    0.413955    0.098917    0.010555    0.595908    
#> 479: 0.326498    1.011032    3.482301    0.413859    0.098809    0.010557    0.595976    
#> 480: 0.326574    1.011014    3.482322    0.413666    0.098785    0.010559    0.595991    
#> 481: 0.326616    1.011030    3.482326    0.413492    0.098753    0.010559    0.596000    
#> 482: 0.326787    1.010994    3.482335    0.413553    0.098747    0.010556    0.595981    
#> 483: 0.326646    1.010896    3.482342    0.413415    0.098773    0.010551    0.595996    
#> 484: 0.326601    1.010750    3.482358    0.413193    0.098798    0.010555    0.596065    
#> 485: 0.326548    1.010721    3.482376    0.413158    0.098806    0.010549    0.596114    
#> 486: 0.326565    1.010731    3.482401    0.413117    0.098776    0.010543    0.596105    
#> 487: 0.326704    1.010702    3.482477    0.413055    0.098816    0.010548    0.596086    
#> 488: 0.326825    1.010646    3.482537    0.412988    0.098824    0.010543    0.596085    
#> 489: 0.326958    1.010615    3.482577    0.412831    0.098885    0.010537    0.596151    
#> 490: 0.327091    1.010603    3.482610    0.412805    0.098920    0.010527    0.596140    
#> 491: 0.327284    1.010668    3.482669    0.412867    0.098900    0.010519    0.596115    
#> 492: 0.327250    1.010638    3.482708    0.412682    0.098841    0.010519    0.596170    
#> 493: 0.327244    1.010609    3.482751    0.412584    0.098792    0.010524    0.596128    
#> 494: 0.327408    1.010613    3.482753    0.412540    0.098727    0.010525    0.596063    
#> 495: 0.327463    1.010576    3.482761    0.412472    0.098711    0.010520    0.595997    
#> 496: 0.327538    1.010605    3.482734    0.412409    0.098674    0.010516    0.596060    
#> 497: 0.327524    1.010634    3.482750    0.412438    0.098687    0.010516    0.596058    
#> 498: 0.327546    1.010640    3.482741    0.412725    0.098675    0.010511    0.595979    
#> 499: 0.327628    1.010672    3.482719    0.412908    0.098697    0.010504    0.595907    
#> 500: 0.327618    1.010710    3.482697    0.412948    0.098685    0.010498    0.595843    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.299957    0.989923    3.443854    0.392401    0.084666    0.016800    1.787688    
#> 002: 0.400854    1.006797    3.459494    0.372781    0.080433    0.015960    1.245745    
#> 003: 0.521324    0.955509    3.453875    0.354142    0.096400    0.015162    0.873121    
#> 004: 0.498659    0.962305    3.458708    0.336435    0.103217    0.014404    0.740652    
#> 005: 0.538533    0.967512    3.454906    0.376896    0.103680    0.013684    0.675244    
#> 006: 0.501444    0.990056    3.448121    0.405237    0.098496    0.013532    0.633525    
#> 007: 0.498249    0.990645    3.445395    0.400258    0.099086    0.014631    0.631778    
#> 008: 0.488293    0.981414    3.444836    0.380245    0.122693    0.013951    0.629699    
#> 009: 0.461764    0.979564    3.441912    0.361813    0.116559    0.013342    0.637395    
#> 010: 0.491271    0.988316    3.444712    0.423020    0.112994    0.016814    0.625259    
#> 011: 0.536690    0.974994    3.451029    0.402192    0.107344    0.018040    0.625067    
#> 012: 0.559759    0.963507    3.450241    0.457779    0.122283    0.017138    0.626761    
#> 013: 0.513497    0.996879    3.441973    0.435287    0.123520    0.016281    0.619704    
#> 014: 0.523401    0.990453    3.444328    0.524304    0.117344    0.016375    0.622082    
#> 015: 0.534810    0.997584    3.452835    0.498089    0.111477    0.015556    0.622538    
#> 016: 0.533682    0.992073    3.454611    0.484082    0.105903    0.017595    0.629017    
#> 017: 0.549270    1.002426    3.451446    0.523611    0.108544    0.017696    0.603772    
#> 018: 0.548372    0.988476    3.456502    0.497431    0.105593    0.018856    0.629593    
#> 019: 0.543515    0.983138    3.453466    0.476651    0.100314    0.020102    0.610430    
#> 020: 0.558591    0.989123    3.457029    0.452818    0.095298    0.020236    0.606787    
#> 021: 0.547646    0.984850    3.468089    0.463098    0.102333    0.019224    0.606835    
#> 022: 0.565350    0.995717    3.468218    0.525401    0.110829    0.020048    0.600496    
#> 023: 0.646605    0.971139    3.485363    0.507882    0.106722    0.019046    0.634885    
#> 024: 0.603303    0.997547    3.476035    0.482741    0.111570    0.018094    0.620538    
#> 025: 0.585290    0.973431    3.470959    0.480306    0.107937    0.018248    0.638030    
#> 026: 0.569856    0.991415    3.461152    0.509085    0.106666    0.018971    0.618030    
#> 027: 0.544269    1.001074    3.452209    0.483631    0.106671    0.020964    0.613676    
#> 028: 0.561179    0.988219    3.455191    0.463400    0.101338    0.020202    0.611508    
#> 029: 0.577225    0.974574    3.457957    0.440230    0.104313    0.019192    0.644013    
#> 030: 0.592292    0.993260    3.459647    0.418219    0.107328    0.019467    0.633513    
#> 031: 0.541897    0.957863    3.472251    0.397308    0.115905    0.018494    0.630286    
#> 032: 0.504914    0.947999    3.470917    0.444135    0.117966    0.018727    0.624450    
#> 033: 0.538282    0.960960    3.465447    0.465483    0.112067    0.018061    0.633328    
#> 034: 0.557103    1.006254    3.469158    0.452364    0.108857    0.017158    0.620404    
#> 035: 0.574688    0.970840    3.464689    0.451425    0.103414    0.016300    0.612887    
#> 036: 0.564484    0.973120    3.473141    0.428854    0.106922    0.021885    0.619034    
#> 037: 0.566141    0.970333    3.472033    0.411956    0.119517    0.023219    0.611099    
#> 038: 0.604894    0.985288    3.468828    0.502559    0.113541    0.023994    0.617898    
#> 039: 0.578545    0.981114    3.473429    0.502836    0.107864    0.026528    0.606498    
#> 040: 0.572011    0.981058    3.477553    0.477694    0.110022    0.026480    0.621132    
#> 041: 0.584641    0.966624    3.477079    0.453809    0.104521    0.025156    0.624195    
#> 042: 0.573681    0.979750    3.465673    0.454671    0.099295    0.023973    0.597854    
#> 043: 0.550766    1.000316    3.451879    0.431938    0.102423    0.023404    0.609053    
#> 044: 0.534044    0.999395    3.453729    0.479682    0.100306    0.024171    0.616968    
#> 045: 0.519025    0.995782    3.448398    0.455698    0.102635    0.024924    0.600762    
#> 046: 0.528253    0.987747    3.457651    0.432913    0.118471    0.023677    0.605089    
#> 047: 0.528101    1.002195    3.454570    0.443477    0.117237    0.022494    0.610257    
#> 048: 0.549325    0.985575    3.469044    0.520144    0.111375    0.026338    0.618864    
#> 049: 0.540288    0.992621    3.458368    0.494136    0.105807    0.025021    0.616425    
#> 050: 0.596547    0.969263    3.470146    0.508869    0.100516    0.024793    0.610284    
#> 051: 0.609359    0.965298    3.465293    0.564007    0.100562    0.023553    0.608421    
#> 052: 0.626095    0.972822    3.477610    0.603626    0.095533    0.023301    0.607888    
#> 053: 0.604073    0.959119    3.468489    0.573445    0.090757    0.025251    0.617895    
#> 054: 0.544075    0.959680    3.464327    0.544773    0.097349    0.025225    0.625299    
#> 055: 0.542990    0.974104    3.459832    0.517534    0.092482    0.023964    0.635771    
#> 056: 0.559736    0.976913    3.464378    0.491657    0.100353    0.022766    0.637318    
#> 057: 0.604136    0.972404    3.474278    0.507759    0.095335    0.021627    0.643028    
#> 058: 0.572565    0.977906    3.460881    0.482371    0.107053    0.020546    0.639111    
#> 059: 0.594098    0.937029    3.474239    0.485962    0.115454    0.020431    0.632285    
#> 060: 0.597766    0.933258    3.483815    0.555006    0.109681    0.024590    0.645609    
#> 061: 0.640853    0.970541    3.490784    0.652096    0.104197    0.026166    0.647772    
#> 062: 0.593839    0.973014    3.491591    0.619491    0.099909    0.027859    0.648775    
#> 063: 0.610098    0.958717    3.471697    0.588517    0.115965    0.028663    0.643968    
#> 064: 0.570685    0.971360    3.464230    0.569480    0.110167    0.027230    0.630016    
#> 065: 0.591805    0.954450    3.460261    0.548793    0.110292    0.025868    0.637626    
#> 066: 0.546239    0.984381    3.464054    0.521353    0.106114    0.024575    0.641550    
#> 067: 0.557839    0.970437    3.445379    0.495956    0.100808    0.023346    0.641093    
#> 068: 0.530932    0.993336    3.463862    0.471158    0.110141    0.022179    0.645095    
#> 069: 0.502941    0.982359    3.451802    0.447600    0.110178    0.024234    0.636314    
#> 070: 0.523093    0.967362    3.462964    0.467511    0.104937    0.024484    0.622604    
#> 071: 0.543305    0.988302    3.459719    0.444135    0.102661    0.023260    0.635855    
#> 072: 0.532016    0.964089    3.466222    0.466905    0.112133    0.022852    0.618266    
#> 073: 0.548190    0.974612    3.475138    0.504459    0.108010    0.021710    0.623946    
#> 074: 0.558616    0.950199    3.476327    0.479236    0.102609    0.020624    0.610021    
#> 075: 0.593077    0.944837    3.492778    0.486380    0.114117    0.023287    0.607627    
#> 076: 0.603745    0.953993    3.491147    0.462061    0.108411    0.022123    0.613533    
#> 077: 0.632083    0.950650    3.495538    0.438958    0.102991    0.021017    0.624571    
#> 078: 0.597675    0.956107    3.481029    0.473969    0.106395    0.020241    0.608850    
#> 079: 0.605254    0.953699    3.483971    0.481043    0.101075    0.023258    0.619822    
#> 080: 0.628550    0.965079    3.487720    0.508989    0.096021    0.025027    0.631767    
#> 081: 0.619596    0.980200    3.478418    0.529167    0.091220    0.024808    0.616200    
#> 082: 0.588515    0.969713    3.481338    0.502709    0.089228    0.027784    0.616517    
#> 083: 0.581787    0.989175    3.476594    0.477573    0.096983    0.026395    0.621149    
#> 084: 0.559365    0.990685    3.463255    0.453695    0.102130    0.025075    0.621850    
#> 085: 0.566699    0.976870    3.476736    0.480886    0.097024    0.023822    0.630306    
#> 086: 0.565625    0.986124    3.470999    0.462563    0.098812    0.025936    0.604957    
#> 087: 0.547871    0.982239    3.455261    0.462813    0.093871    0.024639    0.630929    
#> 088: 0.502401    0.986554    3.458024    0.507451    0.102770    0.023407    0.619052    
#> 089: 0.501843    0.992012    3.451081    0.482079    0.097632    0.022237    0.607021    
#> 090: 0.518153    0.982095    3.447232    0.488494    0.092750    0.023594    0.617994    
#> 091: 0.515871    0.997067    3.427749    0.509972    0.105873    0.022415    0.612351    
#> 092: 0.485655    1.013307    3.435905    0.484473    0.118730    0.021294    0.627419    
#> 093: 0.444702    0.985659    3.431403    0.493730    0.135344    0.020229    0.654031    
#> 094: 0.467170    0.999795    3.433643    0.469044    0.153854    0.019218    0.666527    
#> 095: 0.498550    1.005939    3.442876    0.505127    0.146161    0.018257    0.659669    
#> 096: 0.501141    0.988748    3.446051    0.560774    0.138853    0.017344    0.635388    
#> 097: 0.528756    1.000779    3.449023    0.532735    0.131910    0.019030    0.618998    
#> 098: 0.562343    0.998575    3.451439    0.506098    0.125315    0.018436    0.615492    
#> 099: 0.555699    0.960542    3.455695    0.526833    0.119049    0.023541    0.611046    
#> 100: 0.555098    0.992562    3.456678    0.500492    0.113097    0.023346    0.611445    
#> 101: 0.519437    0.986179    3.440919    0.497627    0.117632    0.023600    0.602483    
#> 102: 0.511536    0.999644    3.444987    0.472746    0.111750    0.022420    0.616287    
#> 103: 0.537105    0.991662    3.457450    0.449199    0.106163    0.021554    0.601076    
#> 104: 0.532946    0.983321    3.467503    0.431780    0.114121    0.022752    0.610363    
#> 105: 0.573754    0.976345    3.464067    0.499148    0.109718    0.021614    0.618276    
#> 106: 0.589909    0.970492    3.468740    0.474191    0.120080    0.020533    0.622656    
#> 107: 0.582755    0.977131    3.458088    0.484849    0.123888    0.020704    0.622514    
#> 108: 0.561779    0.977818    3.466985    0.460607    0.117694    0.019669    0.632040    
#> 109: 0.565970    0.976496    3.477607    0.491826    0.129885    0.018686    0.637295    
#> 110: 0.573809    0.962501    3.474927    0.467235    0.123391    0.017751    0.621216    
#> 111: 0.580114    0.959346    3.481774    0.443873    0.127056    0.016864    0.620000    
#> 112: 0.573322    0.951839    3.465914    0.434454    0.120704    0.016021    0.639363    
#> 113: 0.536946    0.994284    3.469830    0.422651    0.114668    0.015220    0.623886    
#> 114: 0.598149    0.984753    3.469516    0.430837    0.116424    0.017231    0.616863    
#> 115: 0.559162    0.965865    3.466025    0.409295    0.128471    0.018070    0.628249    
#> 116: 0.584298    0.963878    3.465574    0.402678    0.124649    0.017167    0.614324    
#> 117: 0.570613    0.978825    3.477042    0.474703    0.118416    0.016308    0.626215    
#> 118: 0.602361    0.952846    3.479617    0.510661    0.112495    0.020265    0.609781    
#> 119: 0.616349    0.950669    3.480469    0.663582    0.106871    0.025164    0.615350    
#> 120: 0.576518    0.955374    3.484375    0.630402    0.101527    0.025602    0.609382    
#> 121: 0.622730    0.972734    3.484549    0.598882    0.096451    0.027511    0.610149    
#> 122: 0.577656    0.956854    3.475592    0.568938    0.091628    0.026135    0.599154    
#> 123: 0.600360    0.986747    3.476685    0.540491    0.089842    0.026367    0.618972    
#> 124: 0.604911    0.991316    3.473184    0.513467    0.085350    0.025049    0.609195    
#> 125: 0.569721    0.995115    3.466847    0.494531    0.099635    0.024697    0.593483    
#> 126: 0.569786    1.007915    3.456195    0.469805    0.101546    0.024989    0.611738    
#> 127: 0.560227    0.998843    3.438147    0.446314    0.096468    0.023740    0.613700    
#> 128: 0.530143    0.998024    3.450023    0.457298    0.091645    0.022553    0.618365    
#> 129: 0.551977    0.986018    3.457594    0.483114    0.108142    0.021425    0.637708    
#> 130: 0.588912    0.983352    3.454317    0.499365    0.104380    0.020731    0.620433    
#> 131: 0.526188    0.980416    3.448915    0.474396    0.104309    0.022716    0.626302    
#> 132: 0.486513    1.001573    3.430162    0.450677    0.115671    0.021580    0.626119    
#> 133: 0.493905    0.980419    3.441275    0.428143    0.116259    0.020501    0.625700    
#> 134: 0.496123    0.977453    3.458351    0.406736    0.116759    0.019476    0.612901    
#> 135: 0.537454    0.962047    3.470002    0.386399    0.110921    0.021509    0.611492    
#> 136: 0.549390    0.943470    3.473384    0.409836    0.105375    0.021662    0.606659    
#> 137: 0.596957    0.955535    3.480273    0.393961    0.100106    0.021353    0.630856    
#> 138: 0.583980    0.971299    3.481367    0.389688    0.098395    0.023193    0.624553    
#> 139: 0.592038    0.966314    3.493001    0.424574    0.105466    0.027117    0.618565    
#> 140: 0.610863    0.953398    3.484322    0.461718    0.100193    0.025761    0.626426    
#> 141: 0.578322    0.951678    3.473223    0.504011    0.101355    0.024473    0.643323    
#> 142: 0.611586    0.957996    3.482457    0.510995    0.096288    0.023432    0.644232    
#> 143: 0.550175    0.977286    3.469269    0.532514    0.092206    0.022414    0.645904    
#> 144: 0.606216    0.977441    3.474952    0.505888    0.090607    0.021293    0.624539    
#> 145: 0.542220    0.995196    3.456799    0.480594    0.102076    0.023068    0.612798    
#> 146: 0.540514    0.988855    3.468114    0.497739    0.096972    0.024904    0.623542    
#> 147: 0.496312    0.979846    3.442889    0.479542    0.102577    0.023659    0.605280    
#> 148: 0.522738    0.985118    3.459602    0.501462    0.097448    0.023944    0.605433    
#> 149: 0.542013    0.965563    3.454354    0.476389    0.095357    0.022747    0.593388    
#> 150: 0.559063    0.973275    3.452731    0.473438    0.104697    0.021610    0.627507    
#> 151: 0.512002    0.991535    3.454054    0.451133    0.099462    0.022572    0.623672    
#> 152: 0.516465    0.997095    3.469232    0.452789    0.088678    0.024234    0.632288    
#> 153: 0.541469    0.975349    3.477680    0.447997    0.079841    0.030197    0.645624    
#> 154: 0.567483    0.984278    3.466519    0.432720    0.084352    0.030133    0.641121    
#> 155: 0.531135    0.953685    3.471268    0.386784    0.069087    0.033222    0.650158    
#> 156: 0.580009    0.962254    3.481775    0.367287    0.085571    0.033965    0.672680    
#> 157: 0.548906    0.944337    3.481678    0.362627    0.072683    0.036405    0.657832    
#> 158: 0.587204    0.957450    3.478043    0.428862    0.082128    0.028923    0.622397    
#> 159: 0.566928    0.953917    3.486506    0.360473    0.084876    0.025270    0.645608    
#> 160: 0.587931    0.945638    3.489210    0.434426    0.100829    0.025507    0.639204    
#> 161: 0.585263    0.961964    3.479147    0.376060    0.084004    0.030340    0.626893    
#> 162: 0.551763    0.988717    3.471025    0.360632    0.077839    0.031174    0.623347    
#> 163: 0.594654    0.979083    3.472410    0.403922    0.082731    0.027856    0.617573    
#> 164: 0.607064    0.969973    3.480655    0.406823    0.084164    0.028687    0.611517    
#> 165: 0.586041    0.954942    3.480438    0.395279    0.087430    0.026016    0.623812    
#> 166: 0.614351    0.982331    3.476383    0.430486    0.081217    0.025834    0.637923    
#> 167: 0.607850    0.980406    3.490306    0.421494    0.094221    0.031219    0.623894    
#> 168: 0.617798    0.975222    3.489870    0.379085    0.090200    0.030363    0.624659    
#> 169: 0.615737    0.997992    3.476891    0.403993    0.092009    0.029804    0.638213    
#> 170: 0.588382    0.978591    3.482498    0.345081    0.082609    0.030564    0.627914    
#> 171: 0.552121    0.973085    3.470558    0.387789    0.089986    0.025797    0.622612    
#> 172: 0.532856    0.996845    3.463723    0.413688    0.081145    0.026574    0.609044    
#> 173: 0.533780    1.024478    3.445785    0.458087    0.085236    0.028350    0.601588    
#> 174: 0.533010    1.012929    3.462663    0.430357    0.092042    0.027083    0.619089    
#> 175: 0.524630    0.995022    3.444643    0.507578    0.090323    0.024777    0.628948    
#> 176: 0.516902    1.012023    3.459385    0.436870    0.084377    0.025138    0.617994    
#> 177: 0.576300    0.994895    3.464305    0.531641    0.102637    0.027420    0.618958    
#> 178: 0.560916    0.980885    3.464744    0.476028    0.114435    0.023925    0.613887    
#> 179: 0.601957    0.977585    3.469354    0.458204    0.117373    0.019106    0.645013    
#> 180: 0.571829    0.975612    3.475614    0.404292    0.110119    0.017905    0.642961    
#> 181: 0.567104    0.980344    3.458259    0.436214    0.099633    0.017648    0.633391    
#> 182: 0.528733    0.985345    3.451479    0.410026    0.116992    0.016211    0.634429    
#> 183: 0.543762    0.983601    3.462491    0.339889    0.110710    0.017792    0.640682    
#> 184: 0.553899    0.962861    3.473725    0.390732    0.110121    0.019160    0.638332    
#> 185: 0.537105    0.962222    3.465611    0.410653    0.110981    0.021873    0.631436    
#> 186: 0.552585    0.971674    3.466127    0.455444    0.096122    0.028278    0.628086    
#> 187: 0.591762    0.974118    3.465880    0.574712    0.083447    0.032146    0.608920    
#> 188: 0.562059    1.000602    3.456188    0.583325    0.095628    0.026716    0.609899    
#> 189: 0.544458    0.988128    3.465294    0.505724    0.100252    0.027589    0.607306    
#> 190: 0.531352    0.989387    3.465221    0.397641    0.102109    0.025831    0.596882    
#> 191: 0.536914    0.989663    3.453163    0.441380    0.098488    0.023436    0.608486    
#> 192: 0.505768    1.018533    3.446033    0.432216    0.108144    0.021015    0.596699    
#> 193: 0.542262    1.012525    3.454342    0.428502    0.104447    0.021952    0.607963    
#> 194: 0.513427    0.987711    3.455663    0.400279    0.101350    0.018693    0.601662    
#> 195: 0.494615    0.982517    3.451654    0.386169    0.088367    0.021301    0.611444    
#> 196: 0.531846    0.984825    3.468807    0.423432    0.102020    0.025326    0.631646    
#> 197: 0.495345    0.981440    3.475914    0.363897    0.091439    0.027786    0.667906    
#> 198: 0.573431    0.948193    3.466936    0.479076    0.095211    0.023453    0.631826    
#> 199: 0.520798    0.961677    3.462335    0.407887    0.099625    0.021443    0.639078    
#> 200: 0.544516    0.975404    3.465254    0.447038    0.104065    0.021228    0.637909    
#> 201: 0.535506    0.973489    3.466217    0.432074    0.106784    0.020352    0.627142    
#> 202: 0.536571    0.971617    3.468007    0.439211    0.105218    0.020790    0.623215    
#> 203: 0.547527    0.969630    3.467409    0.448427    0.103668    0.021354    0.622305    
#> 204: 0.548051    0.965372    3.468297    0.445416    0.102696    0.020967    0.625636    
#> 205: 0.552035    0.972069    3.469686    0.441991    0.104369    0.021289    0.630883    
#> 206: 0.557883    0.976207    3.470214    0.455750    0.106220    0.021357    0.633614    
#> 207: 0.556232    0.977440    3.469656    0.450942    0.105957    0.021422    0.630275    
#> 208: 0.556885    0.978184    3.469417    0.443579    0.105084    0.021518    0.626827    
#> 209: 0.559329    0.977085    3.469068    0.452032    0.103875    0.021781    0.625354    
#> 210: 0.560036    0.975755    3.469292    0.454185    0.103822    0.021666    0.623395    
#> 211: 0.564065    0.975788    3.470181    0.457659    0.103971    0.021759    0.622342    
#> 212: 0.567232    0.974211    3.470662    0.461229    0.103589    0.021686    0.622187    
#> 213: 0.568139    0.973191    3.470821    0.456876    0.103694    0.021629    0.622213    
#> 214: 0.569869    0.971876    3.471082    0.456069    0.105370    0.021872    0.622304    
#> 215: 0.570466    0.971658    3.471645    0.454012    0.106333    0.022148    0.621463    
#> 216: 0.576131    0.970370    3.472306    0.460059    0.106375    0.022396    0.621589    
#> 217: 0.578069    0.970852    3.472651    0.464571    0.105746    0.022554    0.620578    
#> 218: 0.579381    0.970746    3.472737    0.471416    0.104939    0.022874    0.619302    
#> 219: 0.580967    0.970753    3.472224    0.476677    0.103483    0.023329    0.618295    
#> 220: 0.579371    0.971244    3.471717    0.479268    0.102011    0.023664    0.618343    
#> 221: 0.577223    0.972146    3.470785    0.478656    0.101088    0.023847    0.618016    
#> 222: 0.576415    0.973076    3.469983    0.480377    0.100599    0.024097    0.618825    
#> 223: 0.577403    0.972571    3.469925    0.481805    0.100036    0.024501    0.619292    
#> 224: 0.580905    0.972855    3.470222    0.486740    0.099468    0.024724    0.619386    
#> 225: 0.583033    0.971048    3.471101    0.491970    0.099045    0.024987    0.619654    
#> 226: 0.584268    0.969713    3.471344    0.494531    0.099042    0.025056    0.619415    
#> 227: 0.584953    0.969559    3.471543    0.495650    0.098850    0.025150    0.618776    
#> 228: 0.585214    0.969606    3.471183    0.495673    0.098590    0.025166    0.618355    
#> 229: 0.584164    0.969789    3.470735    0.495279    0.098225    0.025146    0.617870    
#> 230: 0.583907    0.969680    3.470498    0.493567    0.098111    0.025208    0.618048    
#> 231: 0.582834    0.970198    3.470516    0.491695    0.097660    0.025181    0.618608    
#> 232: 0.582500    0.970619    3.470564    0.491861    0.097767    0.025156    0.618501    
#> 233: 0.582286    0.970107    3.470753    0.493201    0.097700    0.025182    0.618597    
#> 234: 0.581178    0.969906    3.470621    0.492921    0.097319    0.025209    0.618817    
#> 235: 0.580581    0.970128    3.470502    0.492094    0.097640    0.025155    0.618961    
#> 236: 0.580512    0.969981    3.470487    0.492488    0.098179    0.025088    0.618944    
#> 237: 0.581139    0.969786    3.470814    0.491532    0.098354    0.024991    0.619350    
#> 238: 0.582587    0.969946    3.470861    0.490321    0.098381    0.024983    0.620002    
#> 239: 0.582796    0.970645    3.470684    0.490121    0.098580    0.025062    0.619822    
#> 240: 0.582767    0.970645    3.470885    0.489055    0.098704    0.025062    0.619474    
#> 241: 0.582980    0.969683    3.471007    0.489992    0.098945    0.024979    0.619222    
#> 242: 0.581985    0.969283    3.470817    0.488780    0.099487    0.024852    0.620071    
#> 243: 0.581374    0.969613    3.470794    0.488382    0.100102    0.024809    0.620874    
#> 244: 0.580184    0.969888    3.470664    0.487333    0.100420    0.024759    0.621142    
#> 245: 0.579242    0.969886    3.470456    0.485725    0.100558    0.024820    0.621602    
#> 246: 0.577762    0.969670    3.470182    0.484370    0.100547    0.024979    0.621954    
#> 247: 0.577369    0.969487    3.470257    0.484458    0.100599    0.025079    0.622349    
#> 248: 0.576702    0.969823    3.470064    0.484753    0.100508    0.025078    0.622155    
#> 249: 0.575682    0.970014    3.469953    0.483954    0.100010    0.025164    0.621918    
#> 250: 0.575602    0.970355    3.469818    0.483635    0.099907    0.025159    0.621604    
#> 251: 0.575879    0.971048    3.469887    0.483783    0.099914    0.025204    0.621513    
#> 252: 0.576747    0.971381    3.470146    0.485839    0.099809    0.025356    0.621358    
#> 253: 0.576444    0.971477    3.470197    0.486217    0.099740    0.025345    0.621449    
#> 254: 0.576560    0.971561    3.470246    0.486462    0.099565    0.025301    0.621408    
#> 255: 0.576438    0.971924    3.470121    0.486127    0.099492    0.025250    0.621380    
#> 256: 0.576056    0.971959    3.469985    0.486580    0.099544    0.025252    0.621530    
#> 257: 0.575602    0.972039    3.469829    0.486714    0.099266    0.025264    0.621672    
#> 258: 0.575018    0.972206    3.469682    0.488219    0.099485    0.025168    0.621524    
#> 259: 0.574944    0.972444    3.469552    0.488199    0.099637    0.025110    0.621499    
#> 260: 0.574964    0.972487    3.469630    0.487173    0.099687    0.025059    0.621194    
#> 261: 0.575076    0.972375    3.469680    0.487017    0.099791    0.024982    0.621034    
#> 262: 0.575539    0.972462    3.469648    0.488259    0.100011    0.024905    0.620807    
#> 263: 0.575545    0.972794    3.469598    0.489187    0.100123    0.024879    0.620899    
#> 264: 0.575375    0.973267    3.469481    0.490209    0.100207    0.024777    0.620972    
#> 265: 0.574603    0.973543    3.469282    0.489766    0.100482    0.024745    0.620952    
#> 266: 0.574797    0.973830    3.469417    0.490321    0.100490    0.024785    0.620963    
#> 267: 0.574885    0.973905    3.469627    0.490922    0.100264    0.024842    0.620945    
#> 268: 0.574556    0.973898    3.469518    0.490899    0.100130    0.024821    0.620838    
#> 269: 0.574864    0.973890    3.469509    0.490982    0.100083    0.024804    0.620806    
#> 270: 0.575209    0.974086    3.469478    0.491698    0.100014    0.024749    0.620558    
#> 271: 0.575333    0.974114    3.469488    0.492334    0.100058    0.024665    0.620732    
#> 272: 0.575300    0.974079    3.469476    0.491216    0.100073    0.024673    0.621062    
#> 273: 0.574745    0.974544    3.469393    0.491354    0.100144    0.024683    0.621220    
#> 274: 0.574966    0.975023    3.469365    0.491865    0.100174    0.024719    0.621178    
#> 275: 0.574726    0.975544    3.469089    0.492111    0.100341    0.024722    0.621056    
#> 276: 0.574680    0.975941    3.468994    0.493619    0.100383    0.024716    0.620828    
#> 277: 0.574319    0.976150    3.469031    0.492755    0.100322    0.024680    0.620796    
#> 278: 0.574356    0.976005    3.469255    0.492654    0.100296    0.024593    0.620761    
#> 279: 0.574536    0.975668    3.469351    0.493409    0.100089    0.024539    0.620749    
#> 280: 0.574801    0.975606    3.469485    0.493144    0.100251    0.024508    0.620567    
#> 281: 0.574740    0.975478    3.469583    0.492872    0.100323    0.024463    0.620455    
#> 282: 0.575157    0.975544    3.469751    0.493041    0.100405    0.024377    0.620564    
#> 283: 0.575347    0.975677    3.469847    0.493150    0.100442    0.024291    0.621053    
#> 284: 0.575014    0.975639    3.469874    0.492878    0.100476    0.024206    0.621101    
#> 285: 0.574655    0.975607    3.469764    0.492073    0.100647    0.024129    0.621434    
#> 286: 0.574267    0.975606    3.469632    0.491348    0.100865    0.024058    0.621364    
#> 287: 0.574275    0.975678    3.469576    0.491437    0.100972    0.024003    0.621392    
#> 288: 0.574192    0.975636    3.469482    0.490668    0.100987    0.023944    0.621419    
#> 289: 0.574258    0.975707    3.469428    0.490117    0.100960    0.023980    0.621324    
#> 290: 0.574450    0.975741    3.469437    0.490358    0.101016    0.023964    0.621402    
#> 291: 0.574494    0.975725    3.469477    0.490657    0.100998    0.023944    0.621331    
#> 292: 0.574496    0.975659    3.469504    0.490701    0.101012    0.023938    0.621281    
#> 293: 0.574441    0.975649    3.469499    0.490205    0.100989    0.023915    0.621346    
#> 294: 0.574293    0.975678    3.469456    0.490551    0.101003    0.023906    0.621269    
#> 295: 0.574282    0.975362    3.469401    0.490441    0.101062    0.023893    0.621273    
#> 296: 0.573965    0.975379    3.469373    0.489283    0.101082    0.023900    0.621520    
#> 297: 0.574027    0.975293    3.469549    0.488735    0.101077    0.023942    0.621754    
#> 298: 0.574421    0.975115    3.469665    0.488015    0.101052    0.023910    0.621871    
#> 299: 0.574042    0.975193    3.469567    0.487711    0.101154    0.023859    0.621779    
#> 300: 0.573908    0.975092    3.469579    0.487584    0.100963    0.023898    0.621766    
#> 301: 0.574007    0.975007    3.469552    0.487474    0.100927    0.023929    0.621799    
#> 302: 0.573819    0.975102    3.469446    0.487123    0.100848    0.023940    0.621851    
#> 303: 0.573459    0.975180    3.469405    0.486817    0.100910    0.023922    0.621793    
#> 304: 0.573296    0.975353    3.469277    0.486586    0.100867    0.023893    0.621788    
#> 305: 0.572950    0.975163    3.469275    0.486150    0.100936    0.023864    0.621723    
#> 306: 0.572501    0.975017    3.469218    0.485365    0.100950    0.023816    0.621623    
#> 307: 0.572326    0.974914    3.469238    0.484694    0.101024    0.023775    0.621701    
#> 308: 0.572079    0.974786    3.469249    0.483809    0.100905    0.023777    0.621794    
#> 309: 0.571994    0.974573    3.469404    0.483275    0.100886    0.023784    0.621845    
#> 310: 0.572265    0.974427    3.469400    0.483757    0.100839    0.023798    0.622013    
#> 311: 0.572303    0.974558    3.469373    0.484187    0.100833    0.023795    0.622040    
#> 312: 0.572121    0.974573    3.469304    0.484671    0.100854    0.023802    0.621961    
#> 313: 0.571916    0.974257    3.469221    0.485223    0.100750    0.023818    0.622096    
#> 314: 0.571188    0.974554    3.468876    0.485787    0.100705    0.023841    0.622074    
#> 315: 0.570597    0.974974    3.468549    0.486168    0.100705    0.023819    0.622020    
#> 316: 0.569922    0.975399    3.468312    0.485854    0.100725    0.023805    0.621958    
#> 317: 0.569362    0.975608    3.468176    0.485647    0.100775    0.023793    0.622113    
#> 318: 0.569174    0.975964    3.467918    0.485145    0.100784    0.023765    0.622172    
#> 319: 0.568781    0.976191    3.467826    0.484467    0.100695    0.023785    0.622386    
#> 320: 0.568522    0.976243    3.467646    0.484398    0.100632    0.023770    0.622506    
#> 321: 0.568120    0.976405    3.467440    0.484381    0.100639    0.023763    0.622613    
#> 322: 0.567912    0.976511    3.467244    0.484659    0.100674    0.023776    0.622572    
#> 323: 0.567467    0.976597    3.467131    0.484540    0.100799    0.023765    0.622459    
#> 324: 0.567446    0.976697    3.467134    0.484712    0.100789    0.023765    0.622230    
#> 325: 0.567477    0.976867    3.467077    0.484593    0.100797    0.023733    0.622236    
#> 326: 0.567305    0.976699    3.467063    0.484270    0.100762    0.023711    0.622253    
#> 327: 0.567533    0.976532    3.467157    0.484394    0.100604    0.023698    0.622301    
#> 328: 0.567760    0.976488    3.467155    0.484308    0.100568    0.023665    0.622289    
#> 329: 0.567738    0.976524    3.467145    0.484274    0.100544    0.023618    0.622177    
#> 330: 0.567313    0.976550    3.467064    0.483959    0.100504    0.023573    0.622095    
#> 331: 0.567215    0.976590    3.467049    0.483650    0.100541    0.023536    0.621965    
#> 332: 0.567222    0.976624    3.467124    0.483090    0.100638    0.023464    0.622112    
#> 333: 0.567449    0.976631    3.467115    0.483233    0.100710    0.023451    0.622164    
#> 334: 0.567217    0.976623    3.467013    0.483060    0.100858    0.023457    0.622303    
#> 335: 0.567121    0.976734    3.466814    0.483458    0.100851    0.023472    0.622289    
#> 336: 0.566463    0.977002    3.466618    0.483233    0.100874    0.023483    0.622233    
#> 337: 0.565887    0.977435    3.466371    0.483627    0.100989    0.023506    0.622193    
#> 338: 0.565629    0.977591    3.466217    0.483904    0.101142    0.023533    0.622150    
#> 339: 0.565338    0.977887    3.466054    0.483892    0.101128    0.023541    0.622102    
#> 340: 0.565196    0.977843    3.465922    0.484238    0.101070    0.023547    0.622035    
#> 341: 0.565067    0.977862    3.465884    0.484820    0.101066    0.023574    0.621920    
#> 342: 0.564739    0.977882    3.465809    0.484947    0.101056    0.023571    0.621884    
#> 343: 0.564258    0.978063    3.465721    0.484776    0.101084    0.023565    0.621775    
#> 344: 0.564044    0.978115    3.465693    0.484752    0.101035    0.023565    0.621726    
#> 345: 0.563797    0.978079    3.465672    0.484319    0.100942    0.023556    0.621716    
#> 346: 0.563450    0.978177    3.465530    0.484040    0.100916    0.023528    0.621695    
#> 347: 0.563276    0.978235    3.465417    0.483900    0.101011    0.023486    0.621660    
#> 348: 0.562935    0.978385    3.465254    0.484044    0.100981    0.023453    0.621685    
#> 349: 0.562732    0.978365    3.465163    0.484160    0.100917    0.023432    0.621658    
#> 350: 0.562481    0.978420    3.464999    0.484322    0.100886    0.023411    0.621655    
#> 351: 0.562364    0.978667    3.464880    0.484329    0.100882    0.023375    0.621680    
#> 352: 0.562104    0.978883    3.464763    0.484131    0.100891    0.023353    0.621832    
#> 353: 0.562147    0.979076    3.464682    0.484205    0.100960    0.023358    0.621848    
#> 354: 0.562091    0.979059    3.464599    0.484546    0.100983    0.023398    0.621843    
#> 355: 0.562302    0.979004    3.464547    0.484849    0.101073    0.023387    0.621849    
#> 356: 0.562357    0.978926    3.464569    0.484433    0.101108    0.023352    0.622006    
#> 357: 0.562531    0.978880    3.464614    0.484292    0.101196    0.023307    0.622046    
#> 358: 0.562444    0.978882    3.464655    0.484048    0.101307    0.023274    0.622018    
#> 359: 0.562199    0.978925    3.464653    0.483515    0.101277    0.023240    0.621964    
#> 360: 0.562094    0.978891    3.464600    0.483201    0.101261    0.023229    0.621825    
#> 361: 0.562091    0.978887    3.464607    0.482959    0.101205    0.023208    0.621732    
#> 362: 0.562087    0.978847    3.464551    0.482921    0.101263    0.023187    0.621544    
#> 363: 0.562149    0.978769    3.464607    0.482764    0.101262    0.023152    0.621454    
#> 364: 0.562444    0.978745    3.464628    0.482950    0.101307    0.023142    0.621393    
#> 365: 0.562239    0.978674    3.464635    0.482788    0.101322    0.023151    0.621336    
#> 366: 0.562069    0.978641    3.464582    0.482284    0.101278    0.023153    0.621359    
#> 367: 0.562157    0.978633    3.464576    0.482195    0.101245    0.023163    0.621405    
#> 368: 0.562339    0.978728    3.464522    0.482481    0.101212    0.023184    0.621451    
#> 369: 0.562409    0.978696    3.464514    0.483207    0.101193    0.023229    0.621491    
#> 370: 0.562446    0.978725    3.464517    0.483606    0.101104    0.023300    0.621545    
#> 371: 0.562230    0.978824    3.464400    0.483564    0.101043    0.023316    0.621566    
#> 372: 0.561962    0.979023    3.464288    0.483327    0.101002    0.023326    0.621586    
#> 373: 0.561488    0.979226    3.464137    0.482990    0.100989    0.023317    0.621646    
#> 374: 0.561291    0.979292    3.464018    0.482669    0.100979    0.023283    0.621577    
#> 375: 0.560885    0.979407    3.463889    0.482222    0.100970    0.023268    0.621592    
#> 376: 0.560641    0.979507    3.463804    0.482052    0.100982    0.023277    0.621421    
#> 377: 0.560450    0.979569    3.463743    0.481979    0.100996    0.023253    0.621325    
#> 378: 0.560095    0.979656    3.463670    0.481673    0.100907    0.023237    0.621355    
#> 379: 0.559912    0.979555    3.463631    0.481722    0.100803    0.023241    0.621306    
#> 380: 0.559905    0.979520    3.463639    0.481612    0.100835    0.023258    0.621240    
#> 381: 0.559833    0.979597    3.463625    0.481731    0.100788    0.023283    0.621277    
#> 382: 0.559588    0.979694    3.463624    0.481459    0.100700    0.023308    0.621185    
#> 383: 0.559484    0.979747    3.463570    0.481236    0.100593    0.023336    0.621112    
#> 384: 0.559241    0.979843    3.463566    0.481060    0.100536    0.023372    0.621052    
#> 385: 0.559430    0.979893    3.463602    0.481047    0.100443    0.023382    0.621020    
#> 386: 0.559673    0.979936    3.463639    0.481148    0.100406    0.023397    0.621056    
#> 387: 0.559817    0.980011    3.463667    0.481446    0.100318    0.023418    0.621021    
#> 388: 0.559798    0.980023    3.463677    0.481336    0.100246    0.023417    0.621000    
#> 389: 0.559662    0.979920    3.463666    0.481429    0.100215    0.023402    0.621112    
#> 390: 0.559504    0.979938    3.463664    0.481557    0.100162    0.023396    0.621115    
#> 391: 0.559537    0.979882    3.463642    0.481634    0.100104    0.023414    0.621010    
#> 392: 0.559563    0.979854    3.463614    0.482039    0.099988    0.023399    0.621084    
#> 393: 0.559565    0.979893    3.463530    0.482161    0.099960    0.023392    0.621002    
#> 394: 0.559741    0.979926    3.463536    0.482364    0.099863    0.023400    0.621002    
#> 395: 0.559940    0.979979    3.463540    0.482597    0.099798    0.023411    0.620970    
#> 396: 0.559971    0.979915    3.463607    0.482379    0.099760    0.023401    0.620916    
#> 397: 0.560012    0.979847    3.463680    0.482112    0.099758    0.023403    0.620898    
#> 398: 0.560393    0.979707    3.463756    0.482290    0.099828    0.023403    0.620866    
#> 399: 0.560572    0.979643    3.463853    0.482084    0.099832    0.023394    0.620785    
#> 400: 0.560862    0.979648    3.463917    0.482234    0.099749    0.023383    0.620737    
#> 401: 0.560976    0.979653    3.463929    0.482328    0.099787    0.023362    0.620717    
#> 402: 0.561104    0.979743    3.463925    0.482417    0.099873    0.023345    0.620670    
#> 403: 0.561403    0.979721    3.463922    0.482671    0.099962    0.023315    0.620704    
#> 404: 0.561315    0.979757    3.463823    0.482791    0.100088    0.023283    0.620684    
#> 405: 0.561301    0.979788    3.463797    0.483235    0.100211    0.023262    0.620680    
#> 406: 0.561339    0.979825    3.463772    0.483807    0.100217    0.023255    0.620749    
#> 407: 0.561223    0.979901    3.463763    0.484329    0.100293    0.023251    0.620743    
#> 408: 0.561126    0.980027    3.463708    0.484705    0.100406    0.023236    0.620701    
#> 409: 0.560962    0.979963    3.463663    0.484924    0.100329    0.023229    0.620684    
#> 410: 0.560864    0.979993    3.463625    0.484905    0.100299    0.023234    0.620684    
#> 411: 0.560843    0.979896    3.463579    0.484971    0.100323    0.023239    0.620741    
#> 412: 0.560818    0.979992    3.463565    0.484696    0.100418    0.023218    0.620811    
#> 413: 0.560671    0.980026    3.463543    0.483933    0.100400    0.023201    0.620943    
#> 414: 0.560626    0.980017    3.463601    0.484002    0.100363    0.023206    0.620955    
#> 415: 0.560792    0.979967    3.463639    0.483830    0.100309    0.023208    0.620910    
#> 416: 0.560784    0.979956    3.463694    0.483648    0.100273    0.023200    0.620877    
#> 417: 0.560893    0.979870    3.463702    0.483999    0.100319    0.023184    0.620924    
#> 418: 0.560882    0.979805    3.463735    0.484304    0.100361    0.023186    0.620878    
#> 419: 0.560878    0.979840    3.463753    0.484258    0.100353    0.023187    0.620890    
#> 420: 0.560810    0.979859    3.463758    0.484046    0.100419    0.023183    0.620767    
#> 421: 0.560790    0.979845    3.463793    0.484100    0.100415    0.023186    0.620712    
#> 422: 0.560922    0.979701    3.463819    0.484266    0.100373    0.023174    0.620673    
#> 423: 0.560951    0.979681    3.463848    0.484282    0.100369    0.023171    0.620615    
#> 424: 0.560918    0.979616    3.463831    0.484370    0.100323    0.023164    0.620558    
#> 425: 0.561074    0.979623    3.463827    0.484814    0.100262    0.023170    0.620516    
#> 426: 0.561253    0.979661    3.463833    0.485496    0.100264    0.023184    0.620423    
#> 427: 0.561348    0.979663    3.463865    0.485813    0.100306    0.023178    0.620311    
#> 428: 0.561435    0.979732    3.463886    0.485975    0.100355    0.023160    0.620249    
#> 429: 0.561474    0.979796    3.463872    0.485999    0.100352    0.023142    0.620184    
#> 430: 0.561333    0.979848    3.463842    0.485606    0.100410    0.023118    0.620219    
#> 431: 0.561139    0.979858    3.463811    0.485205    0.100431    0.023103    0.620153    
#> 432: 0.560907    0.980000    3.463772    0.485073    0.100451    0.023095    0.620143    
#> 433: 0.560833    0.980055    3.463745    0.484911    0.100457    0.023089    0.620117    
#> 434: 0.560642    0.980024    3.463725    0.484591    0.100468    0.023077    0.620064    
#> 435: 0.560547    0.980074    3.463669    0.484382    0.100497    0.023068    0.619976    
#> 436: 0.560492    0.980036    3.463702    0.484297    0.100539    0.023058    0.619961    
#> 437: 0.560504    0.980012    3.463701    0.484169    0.100542    0.023049    0.619926    
#> 438: 0.560344    0.980138    3.463710    0.483893    0.100591    0.023026    0.619922    
#> 439: 0.560341    0.980180    3.463721    0.483762    0.100573    0.023020    0.619843    
#> 440: 0.560404    0.980207    3.463719    0.483499    0.100589    0.023003    0.619889    
#> 441: 0.560507    0.980151    3.463741    0.483621    0.100621    0.022988    0.619845    
#> 442: 0.560341    0.980162    3.463739    0.483602    0.100660    0.022990    0.619805    
#> 443: 0.560199    0.980316    3.463630    0.483496    0.100731    0.022974    0.619769    
#> 444: 0.559945    0.980508    3.463488    0.483493    0.100781    0.022956    0.619775    
#> 445: 0.559796    0.980585    3.463417    0.483760    0.100801    0.022940    0.619784    
#> 446: 0.559572    0.980607    3.463328    0.483941    0.100794    0.022936    0.619747    
#> 447: 0.559425    0.980693    3.463226    0.484156    0.100802    0.022934    0.619687    
#> 448: 0.559265    0.980777    3.463165    0.484163    0.100804    0.022937    0.619628    
#> 449: 0.559220    0.980845    3.463190    0.483905    0.100744    0.022938    0.619631    
#> 450: 0.559120    0.980856    3.463160    0.483835    0.100777    0.022933    0.619629    
#> 451: 0.559185    0.980839    3.463163    0.484040    0.100776    0.022929    0.619620    
#> 452: 0.559170    0.980886    3.463182    0.484119    0.100800    0.022929    0.619598    
#> 453: 0.559141    0.980874    3.463170    0.484113    0.100804    0.022929    0.619516    
#> 454: 0.559079    0.980978    3.463143    0.484075    0.100812    0.022925    0.619400    
#> 455: 0.559036    0.981011    3.463110    0.484146    0.100775    0.022907    0.619323    
#> 456: 0.558958    0.980895    3.463092    0.484024    0.100792    0.022903    0.619334    
#> 457: 0.558947    0.980857    3.463131    0.483938    0.100746    0.022900    0.619352    
#> 458: 0.559031    0.980945    3.463167    0.483926    0.100690    0.022905    0.619357    
#> 459: 0.558970    0.981062    3.463183    0.483883    0.100649    0.022907    0.619370    
#> 460: 0.558762    0.981090    3.463144    0.483617    0.100634    0.022920    0.619354    
#> 461: 0.558681    0.981141    3.463156    0.483378    0.100620    0.022924    0.619355    
#> 462: 0.558572    0.981250    3.463143    0.483117    0.100645    0.022909    0.619309    
#> 463: 0.558432    0.981320    3.463143    0.482738    0.100615    0.022895    0.619330    
#> 464: 0.558401    0.981363    3.463111    0.482557    0.100587    0.022888    0.619273    
#> 465: 0.558404    0.981270    3.463114    0.482593    0.100542    0.022874    0.619244    
#> 466: 0.558457    0.981309    3.463086    0.482344    0.100535    0.022872    0.619214    
#> 467: 0.558319    0.981255    3.463132    0.482040    0.100586    0.022852    0.619181    
#> 468: 0.558350    0.981246    3.463173    0.481903    0.100615    0.022846    0.619159    
#> 469: 0.558374    0.981333    3.463173    0.482005    0.100651    0.022851    0.619198    
#> 470: 0.558374    0.981360    3.463157    0.482048    0.100701    0.022831    0.619211    
#> 471: 0.558365    0.981284    3.463148    0.482175    0.100732    0.022817    0.619228    
#> 472: 0.558366    0.981148    3.463155    0.482202    0.100736    0.022806    0.619247    
#> 473: 0.558289    0.981105    3.463192    0.482122    0.100751    0.022808    0.619138    
#> 474: 0.558244    0.981115    3.463220    0.482075    0.100711    0.022820    0.619147    
#> 475: 0.558318    0.981152    3.463234    0.481946    0.100686    0.022817    0.619079    
#> 476: 0.558309    0.981119    3.463242    0.481996    0.100639    0.022813    0.619024    
#> 477: 0.558287    0.981115    3.463261    0.482040    0.100624    0.022816    0.618980    
#> 478: 0.558339    0.981112    3.463278    0.482274    0.100661    0.022825    0.618877    
#> 479: 0.558495    0.981097    3.463284    0.482405    0.100688    0.022831    0.618822    
#> 480: 0.558469    0.981059    3.463290    0.482388    0.100654    0.022833    0.618825    
#> 481: 0.558465    0.981105    3.463279    0.482317    0.100609    0.022841    0.618787    
#> 482: 0.558448    0.981124    3.463247    0.482495    0.100632    0.022843    0.618795    
#> 483: 0.558395    0.981110    3.463252    0.482413    0.100668    0.022840    0.618785    
#> 484: 0.558386    0.981048    3.463240    0.482335    0.100670    0.022836    0.618790    
#> 485: 0.558303    0.981074    3.463219    0.482246    0.100610    0.022845    0.618825    
#> 486: 0.558259    0.981129    3.463217    0.482093    0.100576    0.022846    0.618848    
#> 487: 0.558332    0.981162    3.463254    0.482034    0.100553    0.022853    0.618879    
#> 488: 0.558312    0.981130    3.463266    0.482051    0.100622    0.022861    0.618858    
#> 489: 0.558402    0.981092    3.463260    0.482205    0.100642    0.022865    0.618819    
#> 490: 0.558461    0.981106    3.463258    0.482523    0.100631    0.022878    0.618761    
#> 491: 0.558395    0.981152    3.463262    0.482445    0.100652    0.022875    0.618688    
#> 492: 0.558374    0.981182    3.463257    0.482474    0.100691    0.022880    0.618661    
#> 493: 0.558337    0.981117    3.463263    0.482493    0.100697    0.022885    0.618642    
#> 494: 0.558395    0.981134    3.463231    0.482464    0.100675    0.022901    0.618629    
#> 495: 0.558372    0.981160    3.463201    0.482368    0.100603    0.022920    0.618610    
#> 496: 0.558408    0.981298    3.463172    0.482317    0.100587    0.022934    0.618581    
#> 497: 0.558351    0.981333    3.463166    0.482388    0.100549    0.022944    0.618618    
#> 498: 0.558229    0.981346    3.463112    0.482407    0.100497    0.022952    0.618564    
#> 499: 0.558199    0.981374    3.463056    0.482530    0.100507    0.022951    0.618530    
#> 500: 0.558134    0.981392    3.463009    0.482446    0.100495    0.022953    0.618510    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.309256    0.958349    3.438685    0.392401    0.085455    0.016800    1.732822    
#> 002: 0.389704    0.943695    3.431237    0.372781    0.081183    0.015960    1.199133    
#> 003: 0.543891    0.857618    3.450181    0.354142    0.077124    0.015162    0.932346    
#> 004: 0.498386    0.863098    3.440958    0.336435    0.073267    0.014404    0.874270    
#> 005: 0.522160    0.871436    3.428644    0.319613    0.069604    0.013684    0.851092    
#> 006: 0.465311    0.883770    3.411783    0.303633    0.079491    0.013000    0.848672    
#> 007: 0.408572    0.896262    3.412109    0.288451    0.086063    0.012350    0.867912    
#> 008: 0.384625    0.875029    3.406072    0.274029    0.083408    0.011867    0.887283    
#> 009: 0.394348    0.878140    3.399107    0.260327    0.079237    0.013283    0.878975    
#> 010: 0.422982    0.884170    3.406382    0.247311    0.075276    0.012619    0.875224    
#> 011: 0.443674    0.877712    3.407837    0.234945    0.071512    0.012728    0.874309    
#> 012: 0.421470    0.890786    3.396360    0.223198    0.072368    0.012091    0.850215    
#> 013: 0.352239    0.914753    3.386069    0.212038    0.092901    0.011487    0.849400    
#> 014: 0.424114    0.890497    3.392493    0.270305    0.094565    0.011005    0.856277    
#> 015: 0.435138    0.899104    3.412936    0.256790    0.089836    0.010454    0.841892    
#> 016: 0.423511    0.920474    3.417183    0.243951    0.085345    0.011037    0.862647    
#> 017: 0.480721    0.913685    3.422173    0.231753    0.081077    0.012094    0.845793    
#> 018: 0.469356    0.896488    3.407451    0.220165    0.098616    0.011489    0.861282    
#> 019: 0.388687    0.901603    3.402297    0.209157    0.093686    0.010915    0.825994    
#> 020: 0.404964    0.887066    3.407812    0.208157    0.089001    0.010369    0.856632    
#> 021: 0.440498    0.876844    3.414505    0.197749    0.084551    0.009851    0.866242    
#> 022: 0.448391    0.874938    3.419429    0.196257    0.080324    0.009358    0.859828    
#> 023: 0.493187    0.882380    3.428775    0.186444    0.076307    0.008890    0.903674    
#> 024: 0.524844    0.901412    3.435987    0.198370    0.072492    0.008446    0.895094    
#> 025: 0.479001    0.869438    3.428031    0.234706    0.088337    0.008023    0.849449    
#> 026: 0.499237    0.899350    3.422828    0.267803    0.095268    0.007966    0.843227    
#> 027: 0.454100    0.918345    3.418830    0.254412    0.094338    0.009257    0.862481    
#> 028: 0.445515    0.888289    3.423928    0.241692    0.089621    0.008794    0.857334    
#> 029: 0.506341    0.900269    3.411447    0.229607    0.087621    0.008355    0.897000    
#> 030: 0.469554    0.912225    3.405624    0.218127    0.083240    0.007937    0.895607    
#> 031: 0.428611    0.896904    3.407085    0.211740    0.090758    0.007540    0.867673    
#> 032: 0.402025    0.899658    3.408884    0.201153    0.099228    0.007163    0.860785    
#> 033: 0.411114    0.917222    3.404423    0.231348    0.094266    0.006805    0.851628    
#> 034: 0.428043    0.914179    3.403231    0.275449    0.102147    0.006465    0.855775    
#> 035: 0.417289    0.881724    3.404644    0.261677    0.099211    0.006141    0.852115    
#> 036: 0.415216    0.888038    3.404780    0.248593    0.099677    0.006201    0.862747    
#> 037: 0.438782    0.898594    3.416800    0.238184    0.094693    0.005891    0.864208    
#> 038: 0.521073    0.886772    3.418676    0.263009    0.095418    0.005597    0.865970    
#> 039: 0.474315    0.883326    3.420317    0.302541    0.096064    0.005317    0.861956    
#> 040: 0.460178    0.904178    3.421943    0.287414    0.091261    0.005051    0.867492    
#> 041: 0.440486    0.879971    3.421562    0.273044    0.086698    0.004799    0.871288    
#> 042: 0.484989    0.854614    3.422487    0.286686    0.082363    0.004559    0.841916    
#> 043: 0.403362    0.879841    3.408786    0.272352    0.082947    0.004536    0.849844    
#> 044: 0.386121    0.907089    3.410158    0.258734    0.097446    0.004486    0.849818    
#> 045: 0.430519    0.913980    3.396229    0.262935    0.092574    0.004294    0.857166    
#> 046: 0.425569    0.909310    3.390931    0.303964    0.095899    0.004208    0.870657    
#> 047: 0.431234    0.900656    3.396821    0.305100    0.091104    0.005493    0.842288    
#> 048: 0.447555    0.873840    3.401279    0.355827    0.091584    0.006501    0.835881    
#> 049: 0.422250    0.889307    3.412085    0.338036    0.103535    0.006176    0.852650    
#> 050: 0.530068    0.859317    3.416611    0.335234    0.098358    0.005867    0.874484    
#> 051: 0.467861    0.914718    3.409535    0.318473    0.093440    0.005574    0.868300    
#> 052: 0.467999    0.899556    3.418571    0.302549    0.088768    0.005295    0.835899    
#> 053: 0.502834    0.878014    3.425172    0.287422    0.091675    0.005030    0.841653    
#> 054: 0.450617    0.873186    3.428401    0.290403    0.111838    0.004779    0.851211    
#> 055: 0.469666    0.888392    3.428302    0.275883    0.106246    0.004540    0.853390    
#> 056: 0.513490    0.870676    3.433332    0.305549    0.119351    0.004313    0.890678    
#> 057: 0.478809    0.855193    3.442339    0.290272    0.113384    0.004097    0.896852    
#> 058: 0.474363    0.846525    3.429014    0.275758    0.107715    0.003892    0.889899    
#> 059: 0.487294    0.848582    3.426765    0.261970    0.102329    0.003698    0.871957    
#> 060: 0.475976    0.847778    3.436677    0.332842    0.098901    0.003513    0.867317    
#> 061: 0.536417    0.854764    3.438981    0.416758    0.113998    0.003337    0.871060    
#> 062: 0.503771    0.890266    3.437109    0.395920    0.108372    0.004010    0.893137    
#> 063: 0.523585    0.852904    3.431401    0.402260    0.112657    0.004066    0.865882    
#> 064: 0.456863    0.865208    3.427263    0.382147    0.110314    0.003863    0.849936    
#> 065: 0.514158    0.872555    3.419320    0.363040    0.104799    0.003670    0.859688    
#> 066: 0.489731    0.881415    3.417723    0.344888    0.112444    0.003486    0.831782    
#> 067: 0.485692    0.866951    3.417374    0.327643    0.106822    0.003320    0.848720    
#> 068: 0.439084    0.882351    3.417364    0.311261    0.101481    0.003154    0.861592    
#> 069: 0.429319    0.888493    3.413452    0.295698    0.101172    0.003475    0.864966    
#> 070: 0.424891    0.876972    3.417073    0.280913    0.101537    0.003490    0.855242    
#> 071: 0.424680    0.908539    3.404334    0.266868    0.100325    0.003316    0.885716    
#> 072: 0.420823    0.856719    3.411107    0.253524    0.109552    0.003567    0.867805    
#> 073: 0.426556    0.892133    3.414950    0.240848    0.122357    0.003388    0.857783    
#> 074: 0.420478    0.867985    3.418518    0.246778    0.129061    0.003219    0.859384    
#> 075: 0.454106    0.842927    3.432203    0.266108    0.126186    0.003066    0.869942    
#> 076: 0.465504    0.882042    3.444582    0.252802    0.119877    0.002945    0.882029    
#> 077: 0.516827    0.836832    3.430423    0.240162    0.113883    0.002798    0.886888    
#> 078: 0.500546    0.840957    3.433896    0.264648    0.108189    0.002658    0.869917    
#> 079: 0.489461    0.871195    3.437971    0.347048    0.102779    0.002525    0.880448    
#> 080: 0.514029    0.867195    3.435304    0.329696    0.108693    0.002399    0.892082    
#> 081: 0.483858    0.872752    3.430773    0.313211    0.103259    0.002492    0.876710    
#> 082: 0.472045    0.861158    3.436696    0.297551    0.108061    0.002625    0.870932    
#> 083: 0.462650    0.896329    3.431984    0.282673    0.102658    0.003128    0.841389    
#> 084: 0.465210    0.886027    3.420220    0.275530    0.105502    0.003977    0.834274    
#> 085: 0.461012    0.896447    3.426781    0.272973    0.100227    0.003778    0.850142    
#> 086: 0.450161    0.913168    3.425996    0.290574    0.095331    0.003636    0.828259    
#> 087: 0.453355    0.890757    3.421827    0.276045    0.090564    0.003454    0.876033    
#> 088: 0.381966    0.867958    3.417321    0.322351    0.101492    0.003376    0.870449    
#> 089: 0.428406    0.908937    3.405301    0.306233    0.107924    0.003317    0.841699    
#> 090: 0.395642    0.899484    3.400703    0.290921    0.103231    0.003151    0.852484    
#> 091: 0.371550    0.880222    3.387190    0.276375    0.118276    0.002993    0.852065    
#> 092: 0.404681    0.918604    3.388859    0.262557    0.112362    0.002844    0.855167    
#> 093: 0.362605    0.912630    3.383141    0.249429    0.106744    0.002701    0.866035    
#> 094: 0.389162    0.920337    3.378776    0.236957    0.111487    0.002566    0.878206    
#> 095: 0.414952    0.917567    3.389715    0.313130    0.105912    0.002438    0.865548    
#> 096: 0.376658    0.905050    3.386654    0.297474    0.100617    0.002316    0.858308    
#> 097: 0.446554    0.915247    3.388501    0.282600    0.095979    0.002200    0.854517    
#> 098: 0.426185    0.924097    3.390676    0.268470    0.092064    0.002090    0.874420    
#> 099: 0.391680    0.893167    3.387746    0.288990    0.099871    0.002271    0.838145    
#> 100: 0.434336    0.886985    3.389055    0.274540    0.094877    0.002576    0.841711    
#> 101: 0.358792    0.903193    3.382712    0.260813    0.090133    0.002447    0.860336    
#> 102: 0.383454    0.904586    3.382987    0.247772    0.095812    0.002325    0.868165    
#> 103: 0.430612    0.898641    3.394024    0.243946    0.091452    0.002209    0.852500    
#> 104: 0.408012    0.904429    3.395647    0.293759    0.102347    0.002098    0.854484    
#> 105: 0.410382    0.894690    3.388252    0.291386    0.111281    0.001993    0.840822    
#> 106: 0.436729    0.910315    3.387673    0.324932    0.105717    0.001894    0.842594    
#> 107: 0.430882    0.920471    3.394397    0.314672    0.113283    0.001799    0.853416    
#> 108: 0.445146    0.897388    3.389905    0.307415    0.119707    0.001709    0.839698    
#> 109: 0.399859    0.922679    3.394135    0.293525    0.114313    0.001624    0.845677    
#> 110: 0.415214    0.897250    3.384239    0.278848    0.113474    0.001542    0.844725    
#> 111: 0.392162    0.906762    3.384836    0.280530    0.113708    0.001465    0.854178    
#> 112: 0.381122    0.889251    3.384341    0.283432    0.108022    0.001392    0.863173    
#> 113: 0.409130    0.943929    3.382859    0.269261    0.102621    0.001322    0.870307    
#> 114: 0.384749    0.932327    3.383661    0.255798    0.097490    0.001526    0.875979    
#> 115: 0.420152    0.904569    3.383286    0.249363    0.092616    0.001651    0.869846    
#> 116: 0.398386    0.924299    3.383928    0.236895    0.094887    0.001730    0.868937    
#> 117: 0.375529    0.941634    3.382554    0.237172    0.090143    0.001643    0.904649    
#> 118: 0.389692    0.916555    3.383099    0.242893    0.085635    0.001694    0.887370    
#> 119: 0.380299    0.884685    3.385081    0.230749    0.081354    0.002034    0.872657    
#> 120: 0.380425    0.881865    3.386373    0.219211    0.085474    0.002246    0.877326    
#> 121: 0.407070    0.932264    3.384492    0.223041    0.084633    0.002842    0.871242    
#> 122: 0.408305    0.905473    3.384904    0.292540    0.089443    0.002700    0.851978    
#> 123: 0.433474    0.916755    3.391411    0.280410    0.094757    0.002565    0.862658    
#> 124: 0.426204    0.945336    3.384888    0.268064    0.090019    0.002719    0.861308    
#> 125: 0.453257    0.945033    3.386415    0.285745    0.096772    0.002583    0.840400    
#> 126: 0.405370    0.939191    3.381188    0.293231    0.095689    0.003188    0.842070    
#> 127: 0.397273    0.911728    3.380304    0.317200    0.098254    0.003543    0.869410    
#> 128: 0.379762    0.911156    3.393691    0.315350    0.093508    0.004364    0.847517    
#> 129: 0.418041    0.911998    3.396721    0.320673    0.116416    0.004146    0.863600    
#> 130: 0.441417    0.927798    3.399134    0.304639    0.110596    0.003939    0.851832    
#> 131: 0.463007    0.891743    3.400579    0.289407    0.107784    0.004711    0.877438    
#> 132: 0.395620    0.920206    3.385492    0.274937    0.111206    0.004476    0.868705    
#> 133: 0.409427    0.887914    3.392484    0.261190    0.135927    0.004252    0.873970    
#> 134: 0.441291    0.880931    3.399989    0.248131    0.131974    0.004661    0.848041    
#> 135: 0.402234    0.892961    3.402929    0.235724    0.125376    0.004428    0.865532    
#> 136: 0.414610    0.870939    3.403196    0.228065    0.119107    0.004207    0.857840    
#> 137: 0.463366    0.866553    3.406113    0.216662    0.113151    0.003996    0.869194    
#> 138: 0.437325    0.888461    3.415770    0.205829    0.107494    0.004005    0.848484    
#> 139: 0.442174    0.881858    3.421424    0.207900    0.102119    0.004854    0.834352    
#> 140: 0.417082    0.917505    3.413983    0.197534    0.097013    0.005700    0.842422    
#> 141: 0.416525    0.881947    3.416820    0.187657    0.100938    0.006234    0.854238    
#> 142: 0.442233    0.859150    3.423626    0.205177    0.095891    0.006310    0.861172    
#> 143: 0.442558    0.877338    3.420645    0.290570    0.096025    0.005995    0.855000    
#> 144: 0.494246    0.872257    3.428372    0.356031    0.091224    0.005695    0.839160    
#> 145: 0.468519    0.897426    3.417067    0.365044    0.086662    0.005410    0.821743    
#> 146: 0.449495    0.891012    3.423914    0.346792    0.082602    0.005140    0.843896    
#> 147: 0.441493    0.878476    3.421627    0.329452    0.093361    0.005007    0.832844    
#> 148: 0.420451    0.892104    3.417841    0.312980    0.088693    0.004757    0.861619    
#> 149: 0.444187    0.880696    3.418710    0.297331    0.097878    0.004519    0.886136    
#> 150: 0.476587    0.878790    3.421062    0.282464    0.118704    0.004293    0.886971    
#> 151: 0.423016    0.913465    3.413506    0.268341    0.118855    0.004079    0.871454    
#> 152: 0.413922    0.888839    3.410814    0.220817    0.084863    0.004370    0.865936    
#> 153: 0.440562    0.878585    3.417189    0.233417    0.075302    0.003254    0.872306    
#> 154: 0.474485    0.880145    3.431361    0.249679    0.080521    0.003983    0.877129    
#> 155: 0.445469    0.851228    3.429982    0.215684    0.076237    0.004923    0.865579    
#> 156: 0.486303    0.859252    3.441445    0.191917    0.090152    0.006802    0.860388    
#> 157: 0.502368    0.845183    3.442407    0.226009    0.115693    0.006543    0.874910    
#> 158: 0.517888    0.882507    3.440795    0.234537    0.107279    0.005307    0.850802    
#> 159: 0.475138    0.856003    3.438509    0.246697    0.106306    0.005100    0.843281    
#> 160: 0.520860    0.833928    3.442835    0.283888    0.133447    0.004383    0.840623    
#> 161: 0.515831    0.861199    3.440009    0.231727    0.105243    0.005645    0.837336    
#> 162: 0.516279    0.864714    3.430758    0.217099    0.110432    0.004380    0.845317    
#> 163: 0.516512    0.861750    3.433798    0.245240    0.142972    0.004388    0.828719    
#> 164: 0.501454    0.868978    3.436623    0.234069    0.102716    0.006367    0.828902    
#> 165: 0.530207    0.869286    3.447582    0.235452    0.106490    0.007434    0.848999    
#> 166: 0.532847    0.887975    3.442391    0.188287    0.110417    0.006646    0.856186    
#> 167: 0.566304    0.887289    3.450886    0.253878    0.108553    0.008236    0.846160    
#> 168: 0.535534    0.879203    3.445343    0.259102    0.092531    0.009332    0.858463    
#> 169: 0.518811    0.899389    3.434772    0.191174    0.103994    0.009061    0.873409    
#> 170: 0.514372    0.869906    3.431908    0.194578    0.094414    0.008508    0.867472    
#> 171: 0.464740    0.866333    3.433584    0.162257    0.095270    0.006975    0.846014    
#> 172: 0.446393    0.904420    3.427300    0.164334    0.078803    0.005769    0.884078    
#> 173: 0.470701    0.917713    3.418752    0.201938    0.078851    0.007307    0.860601    
#> 174: 0.469764    0.910231    3.416869    0.211220    0.088623    0.006096    0.841413    
#> 175: 0.451002    0.900970    3.406964    0.243662    0.086382    0.006679    0.852086    
#> 176: 0.453931    0.913879    3.409677    0.242765    0.089984    0.005387    0.872510    
#> 177: 0.459005    0.926101    3.415176    0.198634    0.086767    0.004265    0.862079    
#> 178: 0.429371    0.918128    3.411589    0.199871    0.091644    0.004231    0.855769    
#> 179: 0.481101    0.935055    3.414961    0.194548    0.092441    0.003654    0.877674    
#> 180: 0.469720    0.885698    3.431121    0.202394    0.092558    0.002784    0.865678    
#> 181: 0.479992    0.871841    3.417316    0.232573    0.078952    0.002449    0.864379    
#> 182: 0.449161    0.884767    3.409218    0.202564    0.077648    0.003024    0.882126    
#> 183: 0.443402    0.903238    3.404417    0.223332    0.078063    0.003392    0.867242    
#> 184: 0.464545    0.861063    3.409802    0.208808    0.083137    0.003333    0.856554    
#> 185: 0.422723    0.881778    3.408278    0.209495    0.085863    0.004374    0.855445    
#> 186: 0.464423    0.906928    3.418887    0.252410    0.084466    0.005117    0.841351    
#> 187: 0.479931    0.887831    3.430605    0.239701    0.085792    0.005801    0.844304    
#> 188: 0.442120    0.915036    3.424540    0.221226    0.093000    0.006546    0.862840    
#> 189: 0.460162    0.900065    3.421172    0.240435    0.082022    0.006162    0.857648    
#> 190: 0.462567    0.877101    3.425553    0.221776    0.082468    0.007422    0.851523    
#> 191: 0.470810    0.892525    3.422320    0.221479    0.076748    0.005308    0.845349    
#> 192: 0.440094    0.908491    3.422496    0.245683    0.080884    0.006875    0.836950    
#> 193: 0.473514    0.909638    3.425217    0.227099    0.097792    0.005613    0.842547    
#> 194: 0.447772    0.894677    3.413047    0.238737    0.111883    0.004294    0.851168    
#> 195: 0.415565    0.887512    3.407278    0.273029    0.069624    0.005015    0.866060    
#> 196: 0.387609    0.883972    3.410115    0.234297    0.079314    0.006279    0.854061    
#> 197: 0.401302    0.893916    3.423727    0.236217    0.089878    0.006581    0.846231    
#> 198: 0.484258    0.885060    3.417009    0.247177    0.089702    0.007257    0.806597    
#> 199: 0.414588    0.899880    3.404483    0.273846    0.098129    0.005321    0.823162    
#> 200: 0.421943    0.871061    3.407175    0.263260    0.099254    0.004747    0.851228    
#> 201: 0.438509    0.866117    3.413223    0.236488    0.100054    0.005739    0.845130    
#> 202: 0.449827    0.870698    3.413208    0.245521    0.101577    0.005996    0.848052    
#> 203: 0.459542    0.873832    3.412658    0.258430    0.098951    0.006072    0.848108    
#> 204: 0.462236    0.870468    3.412289    0.275636    0.099705    0.005903    0.849792    
#> 205: 0.457277    0.875894    3.411649    0.277938    0.099690    0.005737    0.852090    
#> 206: 0.449170    0.884890    3.410601    0.274722    0.101051    0.005599    0.853511    
#> 207: 0.441538    0.891710    3.408155    0.267859    0.100770    0.005410    0.851660    
#> 208: 0.440123    0.891741    3.407824    0.265584    0.098753    0.005276    0.850162    
#> 209: 0.439314    0.890438    3.406941    0.263933    0.096879    0.005340    0.850513    
#> 210: 0.442220    0.888607    3.407539    0.260939    0.098113    0.005380    0.850774    
#> 211: 0.443192    0.889176    3.407972    0.257823    0.099019    0.005301    0.849382    
#> 212: 0.445561    0.888405    3.407676    0.257198    0.098373    0.005131    0.849289    
#> 213: 0.448408    0.885700    3.407616    0.259888    0.099810    0.005180    0.850175    
#> 214: 0.450298    0.885743    3.407871    0.258850    0.100825    0.005192    0.849063    
#> 215: 0.451630    0.886575    3.408570    0.259345    0.100848    0.005244    0.848313    
#> 216: 0.452859    0.885521    3.408930    0.259846    0.101349    0.005250    0.848536    
#> 217: 0.453927    0.886776    3.409037    0.262857    0.100754    0.005210    0.847680    
#> 218: 0.454556    0.888044    3.408778    0.261557    0.100694    0.005258    0.847126    
#> 219: 0.454177    0.886916    3.408468    0.258635    0.100424    0.005337    0.846680    
#> 220: 0.453232    0.885886    3.408952    0.255524    0.099099    0.005358    0.846910    
#> 221: 0.452428    0.885564    3.409216    0.255113    0.099268    0.005374    0.846292    
#> 222: 0.452362    0.884919    3.409214    0.251732    0.099956    0.005478    0.845897    
#> 223: 0.453380    0.884077    3.409633    0.250750    0.099962    0.005549    0.845424    
#> 224: 0.454846    0.884483    3.410366    0.250738    0.099157    0.005578    0.845675    
#> 225: 0.455721    0.882290    3.411027    0.251250    0.098860    0.005641    0.846069    
#> 226: 0.455924    0.881067    3.411241    0.252774    0.099253    0.005663    0.846586    
#> 227: 0.455815    0.880160    3.411849    0.252158    0.099188    0.005647    0.847377    
#> 228: 0.455483    0.880055    3.411929    0.254317    0.099392    0.005631    0.847377    
#> 229: 0.454607    0.879195    3.411933    0.253543    0.099552    0.005667    0.847220    
#> 230: 0.455518    0.879094    3.411982    0.252998    0.098852    0.005704    0.847110    
#> 231: 0.456388    0.879471    3.412200    0.252095    0.098841    0.005729    0.847328    
#> 232: 0.455380    0.879279    3.412635    0.251720    0.098108    0.005809    0.847249    
#> 233: 0.454740    0.878668    3.412813    0.251660    0.098115    0.005871    0.847016    
#> 234: 0.454019    0.878966    3.412901    0.250549    0.098040    0.005907    0.846870    
#> 235: 0.453291    0.878839    3.412726    0.250451    0.097440    0.005915    0.847142    
#> 236: 0.453179    0.879326    3.412735    0.251613    0.097315    0.005924    0.847650    
#> 237: 0.454519    0.879551    3.412851    0.251109    0.096825    0.005980    0.848144    
#> 238: 0.454704    0.880014    3.412855    0.249099    0.097182    0.005984    0.848737    
#> 239: 0.454067    0.880960    3.412671    0.247067    0.097268    0.006038    0.848780    
#> 240: 0.454178    0.881145    3.412711    0.246985    0.097264    0.006063    0.847863    
#> 241: 0.454516    0.880262    3.412884    0.246977    0.097263    0.006033    0.848033    
#> 242: 0.453944    0.880313    3.412830    0.247033    0.097473    0.005999    0.848610    
#> 243: 0.452670    0.881233    3.412767    0.246885    0.097130    0.006006    0.849268    
#> 244: 0.452223    0.881864    3.412725    0.246305    0.096905    0.005978    0.849408    
#> 245: 0.451802    0.881644    3.412716    0.245992    0.097217    0.005950    0.849798    
#> 246: 0.452127    0.881220    3.413071    0.245346    0.096767    0.005965    0.849664    
#> 247: 0.451592    0.881078    3.413474    0.244842    0.096515    0.005975    0.849788    
#> 248: 0.451227    0.881170    3.413651    0.244586    0.096554    0.005948    0.849592    
#> 249: 0.451140    0.881428    3.413859    0.243762    0.096629    0.005918    0.849516    
#> 250: 0.451159    0.882154    3.413932    0.243648    0.096788    0.005878    0.849697    
#> 251: 0.451296    0.882988    3.414063    0.243328    0.096727    0.005837    0.849771    
#> 252: 0.451586    0.883165    3.414256    0.243586    0.097396    0.005800    0.849690    
#> 253: 0.451503    0.883267    3.414369    0.244544    0.097834    0.005742    0.849357    
#> 254: 0.451476    0.883209    3.414497    0.244568    0.098005    0.005710    0.849534    
#> 255: 0.451054    0.883293    3.414623    0.244793    0.098130    0.005693    0.849461    
#> 256: 0.451146    0.882979    3.414591    0.246550    0.098128    0.005664    0.849362    
#> 257: 0.451252    0.882846    3.414515    0.246715    0.098108    0.005636    0.849973    
#> 258: 0.451103    0.882703    3.414374    0.248031    0.098279    0.005611    0.849711    
#> 259: 0.450836    0.882846    3.414336    0.248687    0.098366    0.005618    0.849722    
#> 260: 0.450996    0.882788    3.414461    0.249372    0.098406    0.005627    0.849410    
#> 261: 0.451560    0.882641    3.414606    0.249750    0.098207    0.005623    0.849358    
#> 262: 0.451895    0.882968    3.414517    0.249847    0.098190    0.005600    0.849545    
#> 263: 0.451466    0.883343    3.414408    0.249819    0.098370    0.005579    0.849564    
#> 264: 0.451011    0.883730    3.414297    0.249509    0.098523    0.005555    0.849839    
#> 265: 0.451274    0.883514    3.414343    0.250078    0.098737    0.005570    0.849805    
#> 266: 0.451352    0.883909    3.414248    0.249798    0.098704    0.005580    0.849732    
#> 267: 0.450983    0.883862    3.414197    0.249652    0.098647    0.005597    0.849966    
#> 268: 0.450795    0.883781    3.413869    0.249311    0.098641    0.005592    0.850157    
#> 269: 0.451343    0.883963    3.413669    0.249351    0.098638    0.005593    0.850087    
#> 270: 0.451760    0.884396    3.413381    0.248970    0.098700    0.005585    0.849702    
#> 271: 0.451836    0.884648    3.413151    0.249063    0.098613    0.005580    0.849850    
#> 272: 0.451390    0.884727    3.413019    0.248523    0.098703    0.005564    0.850053    
#> 273: 0.451197    0.885209    3.412908    0.247874    0.098733    0.005553    0.850386    
#> 274: 0.450755    0.885644    3.412869    0.247500    0.098613    0.005538    0.850374    
#> 275: 0.450453    0.885940    3.412741    0.246942    0.098443    0.005532    0.850318    
#> 276: 0.450085    0.886173    3.412843    0.247491    0.098192    0.005551    0.850257    
#> 277: 0.449898    0.886215    3.412922    0.247416    0.097999    0.005559    0.850196    
#> 278: 0.449322    0.886104    3.412914    0.247161    0.098049    0.005560    0.850222    
#> 279: 0.448582    0.886203    3.412913    0.246445    0.097942    0.005557    0.850361    
#> 280: 0.448384    0.886366    3.412956    0.246366    0.097830    0.005561    0.850293    
#> 281: 0.448267    0.886568    3.413023    0.246601    0.097834    0.005566    0.850363    
#> 282: 0.448505    0.886896    3.413112    0.246816    0.097839    0.005581    0.850216    
#> 283: 0.448344    0.887026    3.413158    0.247091    0.097841    0.005596    0.850334    
#> 284: 0.448054    0.886810    3.413133    0.247065    0.097602    0.005601    0.850362    
#> 285: 0.448043    0.886875    3.412943    0.246513    0.097571    0.005618    0.850495    
#> 286: 0.447539    0.887169    3.412722    0.246031    0.097354    0.005644    0.850539    
#> 287: 0.447108    0.887400    3.412547    0.245566    0.097222    0.005653    0.850642    
#> 288: 0.447151    0.887550    3.412431    0.244872    0.096991    0.005657    0.851001    
#> 289: 0.447441    0.887509    3.412399    0.244324    0.097070    0.005663    0.851132    
#> 290: 0.447436    0.887536    3.412375    0.243849    0.097058    0.005652    0.851340    
#> 291: 0.447711    0.887855    3.412451    0.243601    0.096880    0.005664    0.851219    
#> 292: 0.447602    0.887785    3.412457    0.243705    0.096651    0.005663    0.851257    
#> 293: 0.447398    0.888002    3.412389    0.244095    0.096479    0.005648    0.851210    
#> 294: 0.447069    0.888185    3.412351    0.244595    0.096444    0.005649    0.851087    
#> 295: 0.446957    0.888050    3.412303    0.244168    0.096328    0.005645    0.851103    
#> 296: 0.447045    0.887950    3.412344    0.244325    0.096205    0.005654    0.851281    
#> 297: 0.447306    0.888258    3.412338    0.244338    0.096073    0.005662    0.851286    
#> 298: 0.447600    0.888044    3.412403    0.244340    0.096036    0.005648    0.851479    
#> 299: 0.447738    0.888128    3.412409    0.243985    0.096071    0.005631    0.851580    
#> 300: 0.447991    0.887916    3.412537    0.244162    0.095931    0.005622    0.851449    
#> 301: 0.447970    0.887740    3.412479    0.243859    0.095850    0.005613    0.851538    
#> 302: 0.448014    0.887941    3.412403    0.243504    0.095931    0.005600    0.851532    
#> 303: 0.447803    0.888334    3.412330    0.243273    0.096175    0.005594    0.851390    
#> 304: 0.448027    0.888638    3.412301    0.243907    0.096296    0.005580    0.851247    
#> 305: 0.447975    0.888426    3.412301    0.244040    0.096469    0.005568    0.851273    
#> 306: 0.447666    0.888330    3.412207    0.244441    0.096582    0.005561    0.851148    
#> 307: 0.447645    0.888453    3.412147    0.245208    0.096743    0.005544    0.851271    
#> 308: 0.447320    0.888500    3.412095    0.245694    0.096789    0.005536    0.851378    
#> 309: 0.447662    0.888300    3.412072    0.245907    0.096728    0.005521    0.851490    
#> 310: 0.447930    0.888212    3.411943    0.245831    0.096489    0.005515    0.851501    
#> 311: 0.447787    0.888353    3.411882    0.246152    0.096342    0.005511    0.851536    
#> 312: 0.447471    0.888382    3.411810    0.246383    0.096237    0.005502    0.851495    
#> 313: 0.447093    0.888109    3.411765    0.246405    0.096122    0.005491    0.851739    
#> 314: 0.446614    0.888183    3.411656    0.246822    0.096079    0.005479    0.851809    
#> 315: 0.446112    0.888397    3.411492    0.247350    0.096084    0.005469    0.851950    
#> 316: 0.446000    0.888820    3.411383    0.247635    0.096170    0.005465    0.852061    
#> 317: 0.446021    0.888908    3.411381    0.247722    0.096276    0.005458    0.852064    
#> 318: 0.446269    0.888928    3.411331    0.247767    0.096126    0.005444    0.852088    
#> 319: 0.446375    0.888828    3.411342    0.247825    0.096062    0.005445    0.851927    
#> 320: 0.446061    0.888733    3.411304    0.248003    0.096018    0.005452    0.851909    
#> 321: 0.445818    0.888787    3.411178    0.248028    0.096045    0.005432    0.851982    
#> 322: 0.445661    0.888894    3.411033    0.248099    0.096174    0.005428    0.851957    
#> 323: 0.444895    0.889185    3.410871    0.248077    0.096164    0.005419    0.852123    
#> 324: 0.444799    0.889539    3.410787    0.248101    0.096202    0.005414    0.851996    
#> 325: 0.444454    0.889905    3.410663    0.247834    0.096195    0.005410    0.852017    
#> 326: 0.444114    0.889908    3.410550    0.247438    0.096094    0.005405    0.852099    
#> 327: 0.444069    0.890000    3.410495    0.246977    0.096080    0.005397    0.852340    
#> 328: 0.443792    0.890196    3.410354    0.246763    0.096046    0.005387    0.852426    
#> 329: 0.443603    0.890357    3.410299    0.246594    0.095993    0.005369    0.852662    
#> 330: 0.443252    0.890576    3.410231    0.246457    0.095789    0.005356    0.852852    
#> 331: 0.443258    0.890767    3.410189    0.246246    0.095700    0.005345    0.852829    
#> 332: 0.443106    0.890707    3.410215    0.246428    0.095706    0.005341    0.852711    
#> 333: 0.442882    0.890639    3.410121    0.246668    0.095617    0.005342    0.852681    
#> 334: 0.443031    0.890543    3.410053    0.247014    0.095562    0.005343    0.852554    
#> 335: 0.443012    0.890737    3.409941    0.247114    0.095495    0.005340    0.852508    
#> 336: 0.442600    0.890944    3.409863    0.247236    0.095464    0.005329    0.852420    
#> 337: 0.442492    0.891340    3.409760    0.247408    0.095562    0.005322    0.852459    
#> 338: 0.442557    0.891380    3.409788    0.247532    0.095612    0.005319    0.852562    
#> 339: 0.442315    0.891442    3.409783    0.247792    0.095706    0.005315    0.852568    
#> 340: 0.442403    0.891155    3.409845    0.248446    0.095796    0.005310    0.852617    
#> 341: 0.442907    0.891167    3.409913    0.248913    0.095855    0.005309    0.852609    
#> 342: 0.442684    0.890978    3.409876    0.248885    0.095870    0.005310    0.852563    
#> 343: 0.442364    0.891017    3.409919    0.248825    0.095795    0.005305    0.852619    
#> 344: 0.442371    0.890992    3.409991    0.248917    0.095602    0.005298    0.852714    
#> 345: 0.442450    0.890910    3.410032    0.249240    0.095559    0.005300    0.852673    
#> 346: 0.442302    0.890893    3.410004    0.249526    0.095493    0.005294    0.852533    
#> 347: 0.442526    0.890819    3.409958    0.249587    0.095524    0.005297    0.852574    
#> 348: 0.442345    0.890804    3.409929    0.249496    0.095596    0.005294    0.852670    
#> 349: 0.442204    0.890730    3.409870    0.249484    0.095591    0.005295    0.852758    
#> 350: 0.442083    0.890626    3.409822    0.249393    0.095701    0.005291    0.852779    
#> 351: 0.441927    0.890777    3.409784    0.249156    0.095739    0.005279    0.853001    
#> 352: 0.441533    0.890811    3.409737    0.249348    0.095839    0.005265    0.853128    
#> 353: 0.441345    0.890991    3.409646    0.249507    0.095773    0.005266    0.853178    
#> 354: 0.441348    0.891145    3.409513    0.249523    0.095678    0.005273    0.853126    
#> 355: 0.441687    0.891193    3.409445    0.249998    0.095673    0.005268    0.853077    
#> 356: 0.441660    0.891223    3.409426    0.250568    0.095791    0.005253    0.853271    
#> 357: 0.441542    0.891404    3.409418    0.250887    0.095751    0.005247    0.853273    
#> 358: 0.441460    0.891413    3.409471    0.250798    0.095691    0.005245    0.853125    
#> 359: 0.441395    0.891394    3.409500    0.250689    0.095500    0.005248    0.853017    
#> 360: 0.441200    0.891436    3.409436    0.250731    0.095507    0.005251    0.852827    
#> 361: 0.440877    0.891465    3.409401    0.250522    0.095440    0.005259    0.852853    
#> 362: 0.440858    0.891371    3.409370    0.250170    0.095424    0.005256    0.852827    
#> 363: 0.440701    0.891287    3.409311    0.250118    0.095399    0.005263    0.852767    
#> 364: 0.440489    0.891465    3.409269    0.249996    0.095380    0.005264    0.852817    
#> 365: 0.440446    0.891488    3.409333    0.249936    0.095350    0.005269    0.852889    
#> 366: 0.440626    0.891364    3.409319    0.250025    0.095354    0.005280    0.852924    
#> 367: 0.440779    0.891442    3.409354    0.249829    0.095369    0.005276    0.852918    
#> 368: 0.440844    0.891424    3.409365    0.249629    0.095381    0.005275    0.852912    
#> 369: 0.440746    0.891393    3.409319    0.249601    0.095406    0.005272    0.852947    
#> 370: 0.440592    0.891481    3.409284    0.249616    0.095302    0.005269    0.853001    
#> 371: 0.440452    0.891437    3.409203    0.249573    0.095240    0.005268    0.853046    
#> 372: 0.440374    0.891440    3.409175    0.249364    0.095223    0.005270    0.853045    
#> 373: 0.440299    0.891602    3.409123    0.249657    0.095038    0.005271    0.853121    
#> 374: 0.440398    0.891645    3.409140    0.249507    0.094903    0.005263    0.853189    
#> 375: 0.440243    0.891675    3.409117    0.249496    0.094811    0.005257    0.853256    
#> 376: 0.440078    0.891710    3.409075    0.249493    0.094864    0.005260    0.853038    
#> 377: 0.439928    0.891756    3.409054    0.249604    0.094821    0.005260    0.853002    
#> 378: 0.439680    0.891803    3.408970    0.249895    0.094805    0.005257    0.853059    
#> 379: 0.439549    0.891722    3.408962    0.250505    0.094800    0.005248    0.852930    
#> 380: 0.439280    0.891763    3.408882    0.250558    0.094851    0.005248    0.852814    
#> 381: 0.439227    0.891795    3.408849    0.250431    0.094982    0.005237    0.852785    
#> 382: 0.439229    0.891787    3.408866    0.250441    0.094960    0.005239    0.852599    
#> 383: 0.439559    0.891731    3.408906    0.250654    0.094922    0.005246    0.852482    
#> 384: 0.439550    0.891628    3.408959    0.250674    0.094996    0.005248    0.852460    
#> 385: 0.439679    0.891601    3.409015    0.250980    0.095044    0.005250    0.852399    
#> 386: 0.439967    0.891774    3.409111    0.251171    0.095036    0.005252    0.852352    
#> 387: 0.440256    0.891862    3.409207    0.251240    0.095118    0.005259    0.852218    
#> 388: 0.440392    0.891919    3.409265    0.251138    0.095120    0.005260    0.852165    
#> 389: 0.440521    0.891772    3.409304    0.251011    0.095045    0.005260    0.852289    
#> 390: 0.440461    0.891761    3.409297    0.251158    0.094972    0.005256    0.852283    
#> 391: 0.440569    0.891635    3.409345    0.251110    0.094902    0.005256    0.852222    
#> 392: 0.440843    0.891660    3.409402    0.251090    0.094775    0.005253    0.852404    
#> 393: 0.440832    0.891567    3.409437    0.251355    0.094757    0.005254    0.852360    
#> 394: 0.440833    0.891563    3.409452    0.251193    0.094743    0.005257    0.852357    
#> 395: 0.441031    0.891644    3.409460    0.251022    0.094784    0.005262    0.852272    
#> 396: 0.441225    0.891740    3.409476    0.251054    0.094822    0.005261    0.852176    
#> 397: 0.441302    0.891641    3.409499    0.251041    0.094774    0.005263    0.852137    
#> 398: 0.441422    0.891534    3.409529    0.250810    0.094828    0.005257    0.852217    
#> 399: 0.441681    0.891478    3.409637    0.250958    0.094857    0.005256    0.852201    
#> 400: 0.441750    0.891562    3.409708    0.251041    0.094968    0.005256    0.852287    
#> 401: 0.441792    0.891551    3.409719    0.250918    0.094970    0.005254    0.852342    
#> 402: 0.441791    0.891654    3.409720    0.250834    0.094971    0.005254    0.852457    
#> 403: 0.442137    0.891711    3.409734    0.250654    0.095027    0.005253    0.852442    
#> 404: 0.442260    0.891772    3.409719    0.250589    0.095070    0.005252    0.852387    
#> 405: 0.442191    0.891856    3.409740    0.250511    0.095092    0.005257    0.852460    
#> 406: 0.442168    0.891858    3.409747    0.250583    0.095110    0.005259    0.852647    
#> 407: 0.442214    0.891942    3.409775    0.250553    0.095298    0.005254    0.852608    
#> 408: 0.442295    0.891965    3.409778    0.250574    0.095449    0.005242    0.852632    
#> 409: 0.442327    0.891931    3.409734    0.250658    0.095452    0.005228    0.852554    
#> 410: 0.442249    0.891933    3.409679    0.250557    0.095492    0.005221    0.852518    
#> 411: 0.442361    0.891776    3.409668    0.250500    0.095417    0.005216    0.852603    
#> 412: 0.442380    0.891845    3.409654    0.250588    0.095510    0.005210    0.852612    
#> 413: 0.442345    0.891875    3.409623    0.250388    0.095509    0.005205    0.852632    
#> 414: 0.442202    0.891833    3.409626    0.250129    0.095610    0.005198    0.852584    
#> 415: 0.442393    0.891783    3.409630    0.250123    0.095570    0.005190    0.852565    
#> 416: 0.442667    0.891849    3.409642    0.250345    0.095526    0.005188    0.852519    
#> 417: 0.442950    0.891864    3.409677    0.250541    0.095567    0.005184    0.852459    
#> 418: 0.442824    0.891924    3.409631    0.250557    0.095678    0.005181    0.852361    
#> 419: 0.442762    0.892036    3.409607    0.250696    0.095772    0.005178    0.852356    
#> 420: 0.442753    0.892089    3.409632    0.250801    0.095814    0.005175    0.852314    
#> 421: 0.442711    0.892130    3.409687    0.250667    0.095862    0.005170    0.852299    
#> 422: 0.442817    0.892021    3.409705    0.250621    0.095835    0.005165    0.852337    
#> 423: 0.442889    0.892022    3.409730    0.250474    0.095862    0.005164    0.852401    
#> 424: 0.442927    0.892053    3.409734    0.250454    0.095768    0.005161    0.852452    
#> 425: 0.443113    0.892173    3.409742    0.250443    0.095622    0.005167    0.852522    
#> 426: 0.443166    0.892392    3.409746    0.250299    0.095538    0.005161    0.852553    
#> 427: 0.443006    0.892423    3.409741    0.250243    0.095539    0.005161    0.852571    
#> 428: 0.442838    0.892515    3.409710    0.250176    0.095624    0.005155    0.852577    
#> 429: 0.442838    0.892589    3.409706    0.250087    0.095631    0.005155    0.852526    
#> 430: 0.442870    0.892580    3.409714    0.250265    0.095666    0.005153    0.852450    
#> 431: 0.442726    0.892512    3.409655    0.250472    0.095747    0.005144    0.852364    
#> 432: 0.442535    0.892559    3.409643    0.250582    0.095836    0.005140    0.852302    
#> 433: 0.442470    0.892680    3.409635    0.250541    0.095781    0.005141    0.852279    
#> 434: 0.442212    0.892596    3.409633    0.250436    0.095753    0.005139    0.852318    
#> 435: 0.442218    0.892662    3.409632    0.250224    0.095709    0.005136    0.852306    
#> 436: 0.442182    0.892627    3.409632    0.250166    0.095650    0.005139    0.852301    
#> 437: 0.442180    0.892633    3.409608    0.250192    0.095684    0.005136    0.852320    
#> 438: 0.441983    0.892721    3.409596    0.249853    0.095687    0.005133    0.852349    
#> 439: 0.442027    0.892790    3.409593    0.249613    0.095690    0.005131    0.852304    
#> 440: 0.441910    0.892912    3.409589    0.249581    0.095657    0.005128    0.852212    
#> 441: 0.441900    0.892928    3.409610    0.249645    0.095636    0.005130    0.852132    
#> 442: 0.441759    0.893065    3.409583    0.249766    0.095691    0.005132    0.852021    
#> 443: 0.441528    0.893223    3.409535    0.249602    0.095721    0.005132    0.852069    
#> 444: 0.441412    0.893360    3.409468    0.249510    0.095752    0.005131    0.852035    
#> 445: 0.441340    0.893506    3.409410    0.249403    0.095717    0.005126    0.852094    
#> 446: 0.441197    0.893664    3.409362    0.249220    0.095661    0.005119    0.852173    
#> 447: 0.441269    0.893730    3.409358    0.249019    0.095603    0.005117    0.852296    
#> 448: 0.441223    0.893803    3.409382    0.248664    0.095582    0.005119    0.852355    
#> 449: 0.441314    0.893923    3.409468    0.248389    0.095547    0.005119    0.852404    
#> 450: 0.441387    0.893910    3.409524    0.248150    0.095531    0.005121    0.852470    
#> 451: 0.441427    0.893939    3.409534    0.247912    0.095542    0.005119    0.852518    
#> 452: 0.441352    0.894032    3.409493    0.247762    0.095572    0.005118    0.852478    
#> 453: 0.441278    0.894103    3.409466    0.247681    0.095544    0.005114    0.852471    
#> 454: 0.441179    0.894196    3.409438    0.247512    0.095550    0.005111    0.852411    
#> 455: 0.441222    0.894264    3.409390    0.247516    0.095551    0.005105    0.852405    
#> 456: 0.441174    0.894255    3.409385    0.247489    0.095575    0.005100    0.852431    
#> 457: 0.441112    0.894232    3.409424    0.247344    0.095657    0.005095    0.852356    
#> 458: 0.441090    0.894359    3.409441    0.247210    0.095665    0.005088    0.852406    
#> 459: 0.440982    0.894530    3.409443    0.247008    0.095717    0.005082    0.852505    
#> 460: 0.440858    0.894577    3.409425    0.246891    0.095737    0.005080    0.852502    
#> 461: 0.440687    0.894655    3.409416    0.246691    0.095719    0.005077    0.852511    
#> 462: 0.440667    0.894738    3.409449    0.246534    0.095698    0.005074    0.852536    
#> 463: 0.440709    0.894797    3.409480    0.246425    0.095622    0.005074    0.852550    
#> 464: 0.440802    0.894739    3.409526    0.246280    0.095561    0.005076    0.852476    
#> 465: 0.440863    0.894529    3.409547    0.246103    0.095529    0.005075    0.852490    
#> 466: 0.440951    0.894548    3.409533    0.245996    0.095532    0.005074    0.852480    
#> 467: 0.440955    0.894485    3.409525    0.245934    0.095496    0.005074    0.852427    
#> 468: 0.441017    0.894508    3.409524    0.245932    0.095467    0.005080    0.852451    
#> 469: 0.441044    0.894591    3.409579    0.245897    0.095510    0.005079    0.852415    
#> 470: 0.440911    0.894692    3.409570    0.245730    0.095522    0.005085    0.852414    
#> 471: 0.440791    0.894721    3.409560    0.245686    0.095496    0.005085    0.852330    
#> 472: 0.440793    0.894747    3.409597    0.245851    0.095473    0.005085    0.852269    
#> 473: 0.440613    0.894744    3.409603    0.245689    0.095474    0.005086    0.852154    
#> 474: 0.440587    0.894708    3.409605    0.245454    0.095453    0.005097    0.852141    
#> 475: 0.440669    0.894815    3.409609    0.245426    0.095411    0.005101    0.852082    
#> 476: 0.440726    0.894782    3.409587    0.245457    0.095350    0.005104    0.852153    
#> 477: 0.440747    0.894785    3.409601    0.245462    0.095240    0.005107    0.852073    
#> 478: 0.440771    0.894791    3.409629    0.245320    0.095239    0.005109    0.852058    
#> 479: 0.440871    0.894827    3.409646    0.245256    0.095182    0.005111    0.852113    
#> 480: 0.440879    0.894807    3.409663    0.245134    0.095177    0.005109    0.852185    
#> 481: 0.440993    0.894724    3.409701    0.245128    0.095193    0.005106    0.852300    
#> 482: 0.441121    0.894759    3.409749    0.245211    0.095159    0.005104    0.852311    
#> 483: 0.441079    0.894705    3.409748    0.245374    0.095171    0.005100    0.852294    
#> 484: 0.441049    0.894530    3.409738    0.245508    0.095137    0.005096    0.852308    
#> 485: 0.441132    0.894542    3.409725    0.245573    0.095181    0.005089    0.852315    
#> 486: 0.441186    0.894606    3.409720    0.245448    0.095092    0.005084    0.852343    
#> 487: 0.441357    0.894552    3.409783    0.245464    0.095055    0.005084    0.852328    
#> 488: 0.441293    0.894560    3.409796    0.245555    0.095048    0.005086    0.852329    
#> 489: 0.441433    0.894608    3.409804    0.245731    0.095079    0.005085    0.852345    
#> 490: 0.441521    0.894661    3.409816    0.245888    0.095035    0.005084    0.852267    
#> 491: 0.441524    0.894754    3.409818    0.245963    0.095032    0.005084    0.852181    
#> 492: 0.441560    0.894823    3.409815    0.246033    0.095014    0.005086    0.852285    
#> 493: 0.441629    0.894752    3.409828    0.246205    0.094934    0.005098    0.852297    
#> 494: 0.441809    0.894764    3.409842    0.246099    0.094853    0.005102    0.852265    
#> 495: 0.441870    0.894772    3.409870    0.245917    0.094774    0.005106    0.852241    
#> 496: 0.441977    0.894785    3.409877    0.245810    0.094786    0.005106    0.852286    
#> 497: 0.441830    0.894789    3.409860    0.245751    0.094782    0.005102    0.852366    
#> 498: 0.441798    0.894836    3.409807    0.245715    0.094782    0.005098    0.852352    
#> 499: 0.441831    0.894885    3.409759    0.245769    0.094780    0.005102    0.852328    
#> 500: 0.441807    0.894875    3.409704    0.245763    0.094684    0.005106    0.852330    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.298667    0.983033    3.445331    0.392401    0.080455    0.016800    1.629648    
#> 002: 0.422768    1.064358    3.454527    0.372781    0.076432    0.015960    1.115515    
#> 003: 0.594230    0.987126    3.475140    0.354142    0.072610    0.015162    0.819091    
#> 004: 0.606955    1.018168    3.499535    0.336435    0.068980    0.014404    0.697768    
#> 005: 0.658772    1.008506    3.500651    0.319613    0.072287    0.013684    0.638783    
#> 006: 0.642161    1.019657    3.493308    0.303633    0.070985    0.013000    0.601439    
#> 007: 0.634353    1.023776    3.492958    0.288451    0.077636    0.012350    0.608121    
#> 008: 0.608804    1.024622    3.489894    0.274029    0.091507    0.011732    0.607401    
#> 009: 0.557385    1.019413    3.475422    0.260327    0.086931    0.011146    0.609722    
#> 010: 0.616041    1.018997    3.491045    0.247311    0.083833    0.010588    0.605119    
#> 011: 0.672270    1.023876    3.494094    0.234945    0.090049    0.010059    0.608848    
#> 012: 0.681137    1.024837    3.488796    0.223198    0.088840    0.009556    0.607724    
#> 013: 0.632462    1.031941    3.489367    0.212038    0.086609    0.009078    0.609534    
#> 014: 0.662439    1.024491    3.496321    0.201436    0.082278    0.008624    0.625158    
#> 015: 0.668694    1.031261    3.499527    0.191364    0.078164    0.010195    0.603361    
#> 016: 0.658493    1.033579    3.499924    0.181796    0.074645    0.009686    0.606963    
#> 017: 0.632385    1.033405    3.496061    0.172706    0.070912    0.011520    0.579264    
#> 018: 0.645688    1.042979    3.482310    0.164071    0.070774    0.010944    0.601408    
#> 019: 0.622153    1.023417    3.494102    0.155867    0.067236    0.010397    0.583281    
#> 020: 0.631535    1.038961    3.499770    0.148074    0.082286    0.010444    0.600966    
#> 021: 0.625990    1.016631    3.501604    0.140670    0.084873    0.009922    0.595079    
#> 022: 0.641458    1.013667    3.510535    0.133637    0.092597    0.009426    0.585565    
#> 023: 0.713306    1.002322    3.520348    0.126955    0.087967    0.009179    0.613333    
#> 024: 0.710093    1.009560    3.523389    0.125172    0.083569    0.009212    0.613158    
#> 025: 0.678647    0.969523    3.517739    0.129108    0.092387    0.008752    0.607385    
#> 026: 0.671159    1.010096    3.505922    0.122652    0.087768    0.008314    0.602349    
#> 027: 0.650834    1.029366    3.500160    0.139066    0.087273    0.007898    0.606454    
#> 028: 0.672284    1.035638    3.499249    0.132112    0.082909    0.007863    0.601519    
#> 029: 0.667309    1.031686    3.494414    0.145636    0.087339    0.009350    0.609259    
#> 030: 0.655215    1.028454    3.498404    0.138354    0.082972    0.009569    0.599574    
#> 031: 0.655068    1.017727    3.505821    0.131436    0.079692    0.009091    0.591665    
#> 032: 0.656993    0.997556    3.507712    0.124864    0.087403    0.008636    0.586035    
#> 033: 0.646810    1.014930    3.500834    0.118684    0.086809    0.008205    0.619976    
#> 034: 0.671701    1.025814    3.499471    0.122328    0.088383    0.009357    0.605108    
#> 035: 0.670485    0.986458    3.511002    0.136053    0.092472    0.009232    0.581599    
#> 036: 0.675446    1.025434    3.510664    0.151951    0.087849    0.009707    0.587882    
#> 037: 0.643470    1.032107    3.501613    0.148847    0.086128    0.011773    0.576706    
#> 038: 0.691508    1.022898    3.501445    0.174652    0.092208    0.011184    0.589601    
#> 039: 0.697061    1.020500    3.508469    0.165919    0.087598    0.011995    0.575232    
#> 040: 0.681837    1.013294    3.521637    0.169623    0.096610    0.012561    0.581294    
#> 041: 0.676689    0.997027    3.517567    0.161141    0.091780    0.011933    0.575440    
#> 042: 0.686982    1.004759    3.503830    0.153084    0.087191    0.011552    0.570852    
#> 043: 0.643945    1.024748    3.490401    0.145430    0.082831    0.010975    0.577154    
#> 044: 0.618171    1.041601    3.487036    0.138159    0.078690    0.010426    0.587747    
#> 045: 0.611214    1.060832    3.483695    0.134456    0.090422    0.010923    0.580416    
#> 046: 0.636783    1.032565    3.492379    0.128569    0.088461    0.011053    0.576104    
#> 047: 0.645799    1.046097    3.491438    0.122141    0.088880    0.011196    0.585826    
#> 048: 0.645124    1.029079    3.497016    0.116034    0.085746    0.013564    0.593179    
#> 049: 0.619231    1.051178    3.491499    0.136856    0.081458    0.012886    0.588787    
#> 050: 0.669095    1.025482    3.494316    0.160214    0.083337    0.012241    0.589357    
#> 051: 0.643135    1.036113    3.487679    0.152204    0.081837    0.011629    0.599822    
#> 052: 0.649166    1.034687    3.495803    0.144593    0.077746    0.011048    0.577896    
#> 053: 0.652483    1.017351    3.493983    0.137364    0.073858    0.011498    0.593232    
#> 054: 0.606283    1.021569    3.494375    0.130496    0.070165    0.013612    0.594558    
#> 055: 0.622668    1.018761    3.494773    0.138308    0.070441    0.012932    0.599078    
#> 056: 0.648354    0.998008    3.501477    0.131392    0.067138    0.012285    0.608375    
#> 057: 0.646870    1.005125    3.512688    0.131018    0.074901    0.011671    0.623975    
#> 058: 0.678435    0.991806    3.512210    0.142000    0.071156    0.011087    0.611015    
#> 059: 0.691991    0.984553    3.516532    0.145579    0.088041    0.011246    0.604250    
#> 060: 0.669000    0.991034    3.515828    0.153195    0.083639    0.016454    0.620596    
#> 061: 0.691687    1.011073    3.507564    0.155515    0.079457    0.015631    0.641742    
#> 062: 0.677182    1.037656    3.511857    0.167943    0.078044    0.014849    0.610339    
#> 063: 0.714546    1.009122    3.509660    0.191314    0.080597    0.014107    0.596697    
#> 064: 0.721799    0.997354    3.529175    0.181748    0.076567    0.015569    0.599300    
#> 065: 0.709957    0.989728    3.513352    0.172661    0.072739    0.014848    0.604754    
#> 066: 0.714818    1.004988    3.521887    0.164028    0.074257    0.014106    0.596918    
#> 067: 0.698963    0.966995    3.520925    0.155826    0.070544    0.013400    0.607961    
#> 068: 0.651307    1.008088    3.510486    0.148035    0.071097    0.012730    0.599609    
#> 069: 0.664426    1.003926    3.503619    0.146191    0.078257    0.012202    0.596517    
#> 070: 0.657925    0.999165    3.511097    0.164507    0.074344    0.011592    0.597979    
#> 071: 0.638259    1.019375    3.492815    0.158825    0.071360    0.011012    0.604827    
#> 072: 0.609395    1.015288    3.494632    0.175756    0.079165    0.012309    0.600498    
#> 073: 0.659298    0.994387    3.516847    0.175679    0.087269    0.011694    0.606173    
#> 074: 0.667940    0.983458    3.514206    0.166895    0.082905    0.011109    0.584726    
#> 075: 0.679242    0.996039    3.527940    0.158551    0.097189    0.011518    0.582770    
#> 076: 0.692175    1.027335    3.523897    0.156788    0.096551    0.014939    0.580465    
#> 077: 0.710365    1.012031    3.517018    0.148948    0.091724    0.014192    0.590587    
#> 078: 0.676046    1.007540    3.511827    0.141501    0.088557    0.013483    0.581545    
#> 079: 0.678421    1.010485    3.501879    0.137475    0.084129    0.012809    0.587599    
#> 080: 0.651908    1.018553    3.496983    0.162864    0.080473    0.012168    0.591436    
#> 081: 0.654904    1.039444    3.495420    0.172427    0.076450    0.011560    0.587518    
#> 082: 0.648178    1.012503    3.502886    0.163806    0.073751    0.010982    0.597611    
#> 083: 0.654335    1.034874    3.506350    0.155616    0.083297    0.010920    0.587556    
#> 084: 0.665039    1.016415    3.502188    0.147835    0.085552    0.010374    0.581584    
#> 085: 0.649323    1.026937    3.506809    0.145540    0.081274    0.010007    0.591558    
#> 086: 0.655398    1.042056    3.498673    0.138263    0.085082    0.012757    0.572426    
#> 087: 0.644350    1.001679    3.493701    0.131350    0.080828    0.012119    0.589134    
#> 088: 0.626170    1.021062    3.498215    0.124783    0.082491    0.012098    0.598373    
#> 089: 0.652253    1.015169    3.495006    0.123957    0.078366    0.013290    0.593956    
#> 090: 0.623744    1.012648    3.491635    0.126598    0.080505    0.013513    0.594287    
#> 091: 0.656770    1.013749    3.495567    0.149595    0.080245    0.012837    0.590844    
#> 092: 0.636861    1.036738    3.484455    0.168419    0.086586    0.012195    0.585995    
#> 093: 0.613113    1.014747    3.488054    0.159998    0.082412    0.011639    0.588370    
#> 094: 0.630425    1.021826    3.489649    0.151998    0.078390    0.011791    0.599909    
#> 095: 0.639905    1.034579    3.504779    0.144398    0.084415    0.011202    0.595914    
#> 096: 0.618389    1.011641    3.498435    0.137178    0.080195    0.010642    0.593266    
#> 097: 0.626335    1.041958    3.489714    0.130319    0.076185    0.010111    0.577488    
#> 098: 0.606636    1.059345    3.492237    0.123803    0.085164    0.009605    0.610293    
#> 099: 0.606936    1.016295    3.485811    0.134543    0.080906    0.009394    0.583692    
#> 100: 0.597774    1.033250    3.482423    0.143379    0.076861    0.009475    0.588095    
#> 101: 0.588522    1.032728    3.470003    0.146817    0.078728    0.009853    0.599243    
#> 102: 0.584447    1.039372    3.469468    0.139476    0.077766    0.010264    0.616570    
#> 103: 0.637629    1.042716    3.489695    0.137532    0.073877    0.010450    0.580795    
#> 104: 0.645904    1.041257    3.502513    0.147222    0.090232    0.009927    0.588871    
#> 105: 0.630837    1.020706    3.498867    0.142147    0.093520    0.009431    0.597632    
#> 106: 0.675303    1.013659    3.499508    0.152813    0.094556    0.008959    0.575446    
#> 107: 0.696520    1.028986    3.501708    0.156634    0.091654    0.009263    0.581978    
#> 108: 0.670241    1.014179    3.495466    0.168483    0.089896    0.010220    0.596365    
#> 109: 0.639666    1.031134    3.502935    0.160059    0.107193    0.009709    0.585473    
#> 110: 0.680943    0.997886    3.492835    0.152056    0.101834    0.012308    0.568097    
#> 111: 0.663482    0.996572    3.501570    0.144453    0.096742    0.011732    0.564297    
#> 112: 0.651404    0.989901    3.494784    0.138209    0.091905    0.012679    0.572009    
#> 113: 0.648878    1.020211    3.499199    0.136414    0.087310    0.012045    0.571834    
#> 114: 0.640155    1.021195    3.494324    0.160464    0.086264    0.011443    0.587501    
#> 115: 0.632162    1.005344    3.485545    0.164554    0.092960    0.011915    0.599105    
#> 116: 0.624295    1.029384    3.486619    0.156326    0.088312    0.013016    0.592258    
#> 117: 0.611826    1.038635    3.493302    0.157621    0.083896    0.012365    0.593078    
#> 118: 0.637076    1.013307    3.497206    0.149740    0.089367    0.011747    0.582781    
#> 119: 0.640435    1.027764    3.493874    0.168937    0.096502    0.013540    0.586733    
#> 120: 0.641465    1.000492    3.497879    0.160490    0.091677    0.012863    0.581896    
#> 121: 0.646882    1.025674    3.507706    0.152465    0.087093    0.012220    0.587250    
#> 122: 0.690883    1.002206    3.514733    0.144842    0.082738    0.011609    0.599709    
#> 123: 0.693061    1.018739    3.510571    0.137600    0.085616    0.011029    0.589369    
#> 124: 0.676477    1.043013    3.502739    0.130720    0.085257    0.010477    0.602957    
#> 125: 0.657175    1.028442    3.490661    0.126399    0.102349    0.009953    0.585529    
#> 126: 0.610743    1.037812    3.479997    0.128248    0.097231    0.010007    0.584986    
#> 127: 0.632096    1.012534    3.484234    0.139728    0.092370    0.009506    0.594834    
#> 128: 0.603552    1.030630    3.486953    0.134645    0.100926    0.009304    0.596416    
#> 129: 0.638850    1.030853    3.492104    0.138287    0.096244    0.008839    0.588909    
#> 130: 0.670991    1.029896    3.486112    0.131372    0.091431    0.008397    0.589455    
#> 131: 0.640588    1.040196    3.480418    0.124804    0.088488    0.007977    0.595142    
#> 132: 0.596272    1.047529    3.470973    0.119905    0.090981    0.007579    0.615159    
#> 133: 0.617149    1.028063    3.479868    0.187265    0.086432    0.007510    0.605953    
#> 134: 0.655561    1.013944    3.499027    0.184639    0.082472    0.012264    0.588541    
#> 135: 0.637416    0.999877    3.505979    0.175407    0.078349    0.011675    0.591084    
#> 136: 0.658769    0.992318    3.504012    0.170543    0.087313    0.011822    0.576603    
#> 137: 0.676540    1.000834    3.504941    0.162016    0.082947    0.011231    0.595880    
#> 138: 0.652673    1.024413    3.495823    0.153915    0.078800    0.012566    0.593104    
#> 139: 0.643219    1.029178    3.504538    0.146307    0.089460    0.011938    0.575414    
#> 140: 0.677889    1.030648    3.504970    0.175567    0.085555    0.011341    0.581597    
#> 141: 0.659191    1.012356    3.504768    0.185984    0.081277    0.010774    0.583797    
#> 142: 0.717349    1.005103    3.518782    0.176685    0.077213    0.010617    0.589885    
#> 143: 0.657431    1.028830    3.505821    0.168823    0.077356    0.013017    0.590036    
#> 144: 0.696568    1.006554    3.520619    0.160382    0.073488    0.012367    0.593246    
#> 145: 0.688542    1.019153    3.505961    0.152363    0.084008    0.011748    0.565415    
#> 146: 0.666714    1.018032    3.514356    0.144745    0.079808    0.011161    0.576926    
#> 147: 0.619717    1.022328    3.498145    0.137508    0.079878    0.010603    0.591429    
#> 148: 0.650472    1.027475    3.503404    0.131153    0.075884    0.010073    0.580665    
#> 149: 0.648988    1.013270    3.503312    0.128725    0.077179    0.009876    0.601413    
#> 150: 0.682993    1.009404    3.498529    0.131894    0.075698    0.009754    0.610436    
#> 151: 0.645839    1.020210    3.502652    0.125299    0.072131    0.011357    0.593649    
#> 152: 0.649644    1.022291    3.504589    0.143452    0.070237    0.012502    0.583163    
#> 153: 0.654629    1.020408    3.510339    0.141942    0.070304    0.016921    0.576872    
#> 154: 0.667359    1.025492    3.515694    0.138951    0.082721    0.012848    0.597340    
#> 155: 0.649948    1.021309    3.501617    0.132224    0.059202    0.015310    0.585222    
#> 156: 0.655420    1.008091    3.511266    0.133372    0.072073    0.014878    0.587583    
#> 157: 0.675337    0.999265    3.516542    0.156564    0.063427    0.013111    0.602237    
#> 158: 0.679512    1.011008    3.512202    0.148977    0.062645    0.016227    0.581231    
#> 159: 0.625987    1.010058    3.509358    0.128563    0.061304    0.015503    0.592525    
#> 160: 0.672268    1.000084    3.509831    0.146333    0.067896    0.014206    0.579803    
#> 161: 0.657533    1.007288    3.508556    0.129587    0.063117    0.015104    0.583787    
#> 162: 0.659356    1.027066    3.499152    0.159431    0.071183    0.018543    0.588290    
#> 163: 0.697588    1.012635    3.500143    0.192863    0.065224    0.017046    0.589630    
#> 164: 0.673372    1.018887    3.495442    0.209853    0.060453    0.016745    0.581131    
#> 165: 0.687746    1.018345    3.501962    0.173783    0.062700    0.013228    0.596943    
#> 166: 0.689030    1.039921    3.504165    0.194483    0.061321    0.014372    0.591751    
#> 167: 0.684384    1.043907    3.502841    0.194616    0.070741    0.013363    0.585448    
#> 168: 0.688845    1.043496    3.503975    0.188852    0.072100    0.012650    0.574181    
#> 169: 0.671588    1.069721    3.496553    0.175954    0.069271    0.013125    0.588522    
#> 170: 0.668500    1.038034    3.496393    0.161272    0.069974    0.012988    0.584242    
#> 171: 0.644250    1.007113    3.489576    0.159069    0.067749    0.011777    0.564839    
#> 172: 0.638387    1.048806    3.487534    0.139932    0.065439    0.011618    0.579213    
#> 173: 0.648798    1.047717    3.491575    0.149197    0.068336    0.013538    0.576628    
#> 174: 0.646689    1.029631    3.505195    0.156871    0.073513    0.012410    0.581661    
#> 175: 0.660308    1.033088    3.499756    0.137001    0.082418    0.015294    0.582064    
#> 176: 0.655081    1.044717    3.509335    0.120344    0.076913    0.013198    0.587494    
#> 177: 0.684611    1.009474    3.513445    0.140425    0.084998    0.017347    0.580045    
#> 178: 0.692973    1.011817    3.515686    0.121147    0.089916    0.012885    0.588857    
#> 179: 0.697448    1.017040    3.509570    0.136475    0.090998    0.011795    0.593480    
#> 180: 0.647091    1.023159    3.502518    0.150045    0.093554    0.009455    0.588676    
#> 181: 0.655956    1.016716    3.488540    0.116893    0.087806    0.009219    0.594984    
#> 182: 0.625799    1.040051    3.484998    0.123212    0.101396    0.009241    0.592286    
#> 183: 0.624729    1.054877    3.487454    0.114637    0.090509    0.008774    0.594227    
#> 184: 0.635274    1.027293    3.495191    0.131799    0.082840    0.010108    0.598175    
#> 185: 0.630259    1.032730    3.494835    0.138440    0.061395    0.009445    0.603803    
#> 186: 0.651017    1.040735    3.498687    0.136722    0.071083    0.009803    0.598353    
#> 187: 0.666590    1.019773    3.500390    0.173540    0.067481    0.010115    0.582358    
#> 188: 0.654636    1.017284    3.499331    0.170499    0.070604    0.009599    0.580641    
#> 189: 0.684859    1.024748    3.514810    0.138171    0.084639    0.009945    0.598339    
#> 190: 0.647523    1.034266    3.502089    0.154110    0.088617    0.010968    0.578349    
#> 191: 0.614778    1.040688    3.491118    0.109141    0.093013    0.010572    0.576946    
#> 192: 0.628218    1.036453    3.490893    0.138339    0.087355    0.010212    0.562949    
#> 193: 0.643979    1.035286    3.496789    0.148274    0.079370    0.010871    0.569028    
#> 194: 0.631029    1.014682    3.480891    0.145932    0.079969    0.008628    0.601089    
#> 195: 0.616233    1.035445    3.481686    0.152195    0.086022    0.009323    0.574841    
#> 196: 0.623942    1.019616    3.497293    0.141531    0.087007    0.010399    0.567369    
#> 197: 0.609361    1.001271    3.511464    0.137498    0.078305    0.011346    0.613933    
#> 198: 0.658902    0.999133    3.500123    0.123608    0.084331    0.010131    0.594464    
#> 199: 0.634656    1.005384    3.503199    0.121776    0.081234    0.009919    0.591432    
#> 200: 0.639904    1.011527    3.506109    0.143212    0.071783    0.011260    0.601057    
#> 201: 0.645610    1.009690    3.506496    0.151721    0.074622    0.011739    0.593378    
#> 202: 0.648044    1.013826    3.503997    0.146228    0.076020    0.011725    0.591643    
#> 203: 0.653247    1.013485    3.500185    0.143357    0.078993    0.012096    0.589551    
#> 204: 0.658154    1.009337    3.502527    0.143301    0.079607    0.012502    0.588627    
#> 205: 0.662634    1.013057    3.503311    0.144613    0.080955    0.013258    0.589455    
#> 206: 0.661694    1.015681    3.503820    0.143903    0.080305    0.013377    0.588343    
#> 207: 0.661103    1.014426    3.503096    0.146832    0.078199    0.013282    0.588551    
#> 208: 0.659796    1.016006    3.503509    0.145534    0.076178    0.013216    0.588101    
#> 209: 0.665352    1.014871    3.503578    0.146981    0.075857    0.013314    0.588534    
#> 210: 0.666244    1.012752    3.504114    0.148178    0.074772    0.013415    0.587733    
#> 211: 0.667510    1.013769    3.503978    0.147683    0.074790    0.013251    0.587441    
#> 212: 0.668822    1.013161    3.504232    0.146172    0.075357    0.013125    0.587826    
#> 213: 0.669135    1.011625    3.504449    0.142880    0.076309    0.012736    0.588820    
#> 214: 0.670187    1.010525    3.504824    0.141845    0.077178    0.012432    0.589593    
#> 215: 0.669270    1.011139    3.505047    0.141104    0.077542    0.012359    0.589249    
#> 216: 0.670801    1.009827    3.505459    0.141212    0.077691    0.012418    0.590109    
#> 217: 0.671468    1.011589    3.505711    0.140025    0.077809    0.012401    0.589619    
#> 218: 0.672997    1.012364    3.505666    0.140179    0.077299    0.012466    0.588718    
#> 219: 0.673923    1.011998    3.505559    0.141697    0.076495    0.012565    0.587943    
#> 220: 0.673577    1.012019    3.505446    0.143812    0.076033    0.012640    0.587581    
#> 221: 0.672800    1.013155    3.504859    0.144489    0.075903    0.012674    0.587568    
#> 222: 0.672771    1.013928    3.504656    0.145106    0.075951    0.012755    0.587349    
#> 223: 0.672953    1.013640    3.504498    0.144692    0.075944    0.012797    0.587350    
#> 224: 0.673790    1.014213    3.504594    0.145397    0.076221    0.012913    0.587047    
#> 225: 0.673094    1.013193    3.504990    0.146451    0.076450    0.012985    0.587209    
#> 226: 0.672393    1.012787    3.504680    0.146913    0.076733    0.013097    0.586511    
#> 227: 0.670985    1.013220    3.504470    0.147742    0.076503    0.013135    0.586581    
#> 228: 0.669880    1.014147    3.504279    0.148054    0.076141    0.013162    0.586592    
#> 229: 0.669493    1.014237    3.504143    0.147560    0.075945    0.013238    0.585940    
#> 230: 0.670194    1.013820    3.504057    0.146862    0.076016    0.013350    0.585884    
#> 231: 0.670264    1.014314    3.504117    0.146941    0.075934    0.013401    0.585844    
#> 232: 0.669300    1.014597    3.503990    0.146947    0.075980    0.013398    0.585776    
#> 233: 0.668502    1.014415    3.503913    0.146941    0.075576    0.013399    0.586135    
#> 234: 0.667467    1.014925    3.503749    0.147014    0.075119    0.013431    0.586291    
#> 235: 0.666962    1.014844    3.503392    0.147556    0.075635    0.013487    0.585887    
#> 236: 0.666545    1.015363    3.503097    0.147349    0.075574    0.013527    0.586004    
#> 237: 0.666492    1.015647    3.503093    0.147220    0.075289    0.013552    0.586875    
#> 238: 0.667142    1.015461    3.503398    0.147290    0.075288    0.013557    0.587662    
#> 239: 0.667271    1.015794    3.503466    0.147278    0.075181    0.013522    0.587445    
#> 240: 0.667572    1.015573    3.503752    0.146875    0.074996    0.013471    0.587076    
#> 241: 0.667727    1.014753    3.503936    0.146704    0.075014    0.013393    0.586946    
#> 242: 0.667511    1.014104    3.503964    0.146001    0.075316    0.013338    0.587237    
#> 243: 0.667550    1.013743    3.504224    0.145682    0.075553    0.013291    0.587642    
#> 244: 0.667246    1.013900    3.504366    0.145447    0.075825    0.013230    0.588045    
#> 245: 0.666954    1.013613    3.504492    0.145648    0.076155    0.013166    0.588475    
#> 246: 0.666471    1.013855    3.504529    0.145574    0.076116    0.013131    0.588544    
#> 247: 0.666232    1.013794    3.504696    0.145349    0.075883    0.013077    0.588684    
#> 248: 0.666127    1.014013    3.504604    0.145069    0.075662    0.013045    0.588926    
#> 249: 0.665575    1.014048    3.504545    0.144962    0.075617    0.013027    0.589139    
#> 250: 0.665928    1.014448    3.504607    0.144485    0.075553    0.013020    0.589468    
#> 251: 0.666538    1.015032    3.504927    0.144189    0.075568    0.013031    0.589780    
#> 252: 0.667075    1.015296    3.505308    0.143877    0.075456    0.013093    0.590017    
#> 253: 0.667234    1.015407    3.505323    0.144028    0.075436    0.013141    0.590086    
#> 254: 0.667467    1.015493    3.505599    0.144104    0.075294    0.013177    0.590471    
#> 255: 0.667357    1.015352    3.505800    0.143656    0.075128    0.013190    0.590717    
#> 256: 0.667185    1.015206    3.505809    0.143132    0.075011    0.013239    0.590829    
#> 257: 0.666632    1.014970    3.505812    0.142976    0.074774    0.013244    0.590985    
#> 258: 0.666217    1.014598    3.505729    0.142333    0.074807    0.013227    0.590965    
#> 259: 0.665935    1.014672    3.505565    0.141972    0.074947    0.013211    0.591119    
#> 260: 0.665622    1.014800    3.505600    0.141960    0.074750    0.013224    0.591022    
#> 261: 0.665636    1.014609    3.505712    0.142139    0.074693    0.013239    0.590996    
#> 262: 0.665952    1.014673    3.505771    0.141990    0.074779    0.013178    0.591016    
#> 263: 0.666301    1.014693    3.505972    0.141910    0.074601    0.013145    0.591039    
#> 264: 0.666680    1.014376    3.506043    0.142202    0.074495    0.013125    0.591075    
#> 265: 0.666904    1.014534    3.506062    0.142113    0.074447    0.013096    0.590958    
#> 266: 0.667150    1.014634    3.506035    0.141937    0.074473    0.013035    0.590723    
#> 267: 0.666972    1.014914    3.506027    0.142040    0.074515    0.013011    0.590559    
#> 268: 0.666967    1.014957    3.505938    0.142094    0.074613    0.012975    0.590532    
#> 269: 0.667090    1.015078    3.505881    0.141975    0.074689    0.012947    0.590569    
#> 270: 0.667049    1.015415    3.505642    0.141945    0.074759    0.012896    0.590408    
#> 271: 0.667101    1.015661    3.505414    0.142322    0.074883    0.012865    0.590390    
#> 272: 0.667028    1.015643    3.505389    0.142527    0.075044    0.012841    0.590407    
#> 273: 0.666603    1.015734    3.505349    0.142342    0.075227    0.012783    0.590456    
#> 274: 0.666445    1.015986    3.505303    0.142177    0.075300    0.012746    0.590503    
#> 275: 0.666304    1.016200    3.505142    0.141950    0.075418    0.012726    0.590369    
#> 276: 0.666261    1.016493    3.505200    0.141866    0.075428    0.012699    0.590426    
#> 277: 0.666248    1.016664    3.505275    0.141814    0.075477    0.012699    0.590287    
#> 278: 0.666297    1.016730    3.505342    0.141734    0.075448    0.012701    0.590301    
#> 279: 0.665969    1.016601    3.505332    0.141822    0.075417    0.012713    0.590559    
#> 280: 0.666174    1.016689    3.505406    0.141687    0.075542    0.012742    0.590445    
#> 281: 0.666030    1.016668    3.505518    0.141520    0.075553    0.012769    0.590241    
#> 282: 0.666436    1.016702    3.505691    0.141344    0.075389    0.012782    0.590274    
#> 283: 0.666597    1.016839    3.505811    0.141194    0.075295    0.012788    0.590402    
#> 284: 0.666625    1.016582    3.505890    0.141168    0.075228    0.012791    0.590409    
#> 285: 0.666651    1.016628    3.505790    0.141352    0.075245    0.012800    0.590511    
#> 286: 0.666754    1.016720    3.505661    0.141439    0.075461    0.012826    0.590478    
#> 287: 0.666559    1.016996    3.505595    0.141761    0.075660    0.012840    0.590437    
#> 288: 0.666493    1.017002    3.505654    0.142047    0.075656    0.012842    0.590659    
#> 289: 0.667109    1.016890    3.505825    0.142250    0.075689    0.012848    0.590615    
#> 290: 0.667475    1.016832    3.505942    0.142243    0.075686    0.012832    0.590784    
#> 291: 0.667833    1.016929    3.506080    0.142116    0.075658    0.012825    0.590609    
#> 292: 0.667784    1.016836    3.506115    0.142182    0.075679    0.012809    0.590353    
#> 293: 0.667638    1.016779    3.506097    0.142178    0.075661    0.012782    0.590204    
#> 294: 0.667294    1.016796    3.506039    0.141951    0.075704    0.012766    0.590072    
#> 295: 0.667127    1.016641    3.505968    0.141928    0.075647    0.012772    0.589846    
#> 296: 0.666965    1.016614    3.505961    0.142085    0.075611    0.012788    0.589774    
#> 297: 0.667224    1.016760    3.505988    0.142077    0.075672    0.012815    0.589692    
#> 298: 0.667137    1.016753    3.505907    0.142335    0.075634    0.012820    0.589537    
#> 299: 0.666920    1.016922    3.505772    0.142531    0.075737    0.012781    0.589369    
#> 300: 0.667053    1.016831    3.505861    0.142447    0.075747    0.012754    0.589269    
#> 301: 0.667145    1.016807    3.505822    0.142339    0.075794    0.012723    0.589299    
#> 302: 0.667370    1.016836    3.505840    0.142454    0.075778    0.012720    0.589266    
#> 303: 0.667405    1.016945    3.505865    0.142321    0.075850    0.012721    0.589108    
#> 304: 0.667666    1.017076    3.505845    0.142047    0.075781    0.012725    0.589241    
#> 305: 0.667473    1.017061    3.505787    0.142200    0.075853    0.012717    0.589105    
#> 306: 0.667052    1.017044    3.505653    0.142070    0.075955    0.012693    0.589142    
#> 307: 0.666769    1.017166    3.505468    0.141974    0.076181    0.012666    0.589250    
#> 308: 0.666398    1.017114    3.505351    0.141963    0.076287    0.012651    0.589380    
#> 309: 0.666291    1.016965    3.505264    0.141877    0.076424    0.012626    0.589592    
#> 310: 0.666351    1.016913    3.505118    0.142179    0.076520    0.012615    0.589874    
#> 311: 0.666323    1.016880    3.505054    0.142191    0.076593    0.012612    0.589870    
#> 312: 0.666251    1.016903    3.504959    0.141988    0.076693    0.012598    0.589874    
#> 313: 0.666106    1.016674    3.504889    0.141816    0.076754    0.012575    0.590090    
#> 314: 0.665883    1.016845    3.504734    0.141817    0.076761    0.012563    0.590187    
#> 315: 0.665662    1.017075    3.504604    0.142097    0.076753    0.012568    0.590208    
#> 316: 0.665677    1.017175    3.504523    0.142056    0.076716    0.012584    0.590298    
#> 317: 0.665684    1.017185    3.504489    0.141911    0.076743    0.012589    0.590349    
#> 318: 0.665652    1.017160    3.504432    0.141936    0.076671    0.012587    0.590283    
#> 319: 0.665465    1.017198    3.504345    0.141923    0.076625    0.012589    0.590203    
#> 320: 0.664914    1.017194    3.504246    0.142010    0.076583    0.012584    0.590362    
#> 321: 0.664605    1.017303    3.504090    0.142029    0.076515    0.012608    0.590447    
#> 322: 0.664553    1.017467    3.503955    0.142067    0.076458    0.012616    0.590449    
#> 323: 0.664156    1.017467    3.503892    0.142297    0.076472    0.012629    0.590416    
#> 324: 0.663915    1.017627    3.503827    0.142342    0.076436    0.012628    0.590322    
#> 325: 0.663634    1.017775    3.503732    0.142373    0.076400    0.012633    0.590178    
#> 326: 0.663731    1.017525    3.503773    0.142425    0.076325    0.012650    0.590196    
#> 327: 0.663909    1.017333    3.503863    0.142593    0.076163    0.012673    0.590283    
#> 328: 0.664066    1.017229    3.503901    0.142572    0.076100    0.012681    0.590245    
#> 329: 0.664243    1.017259    3.503960    0.142730    0.076062    0.012682    0.590206    
#> 330: 0.663982    1.017201    3.503989    0.142372    0.076026    0.012677    0.590260    
#> 331: 0.663951    1.017250    3.504007    0.142206    0.076101    0.012650    0.590306    
#> 332: 0.663711    1.017240    3.504024    0.142121    0.076138    0.012634    0.590322    
#> 333: 0.663626    1.017106    3.503983    0.142124    0.076251    0.012621    0.590324    
#> 334: 0.663457    1.016857    3.503878    0.142016    0.076378    0.012595    0.590358    
#> 335: 0.663290    1.017003    3.503768    0.141924    0.076440    0.012572    0.590343    
#> 336: 0.662979    1.017162    3.503662    0.141828    0.076439    0.012571    0.590395    
#> 337: 0.662928    1.017473    3.503589    0.141961    0.076460    0.012574    0.590371    
#> 338: 0.662847    1.017630    3.503588    0.141980    0.076536    0.012588    0.590356    
#> 339: 0.662611    1.017725    3.503519    0.142013    0.076482    0.012581    0.590299    
#> 340: 0.662563    1.017588    3.503568    0.141995    0.076453    0.012586    0.590255    
#> 341: 0.662787    1.017533    3.503633    0.141864    0.076470    0.012586    0.590340    
#> 342: 0.662626    1.017294    3.503694    0.141618    0.076366    0.012592    0.590403    
#> 343: 0.662498    1.017239    3.503717    0.141448    0.076345    0.012586    0.590407    
#> 344: 0.662623    1.017094    3.503810    0.141282    0.076237    0.012588    0.590530    
#> 345: 0.662743    1.016967    3.503875    0.141102    0.076175    0.012601    0.590552    
#> 346: 0.662776    1.016973    3.503765    0.140950    0.076144    0.012592    0.590520    
#> 347: 0.663001    1.016896    3.503693    0.140878    0.076207    0.012587    0.590533    
#> 348: 0.662819    1.016875    3.503633    0.140878    0.076132    0.012591    0.590464    
#> 349: 0.662577    1.016779    3.503573    0.140842    0.076082    0.012594    0.590435    
#> 350: 0.662478    1.016613    3.503566    0.140831    0.076054    0.012586    0.590464    
#> 351: 0.662610    1.016591    3.503534    0.140874    0.076057    0.012579    0.590483    
#> 352: 0.662344    1.016775    3.503484    0.140940    0.076044    0.012577    0.590626    
#> 353: 0.662244    1.016914    3.503396    0.140814    0.076070    0.012567    0.590666    
#> 354: 0.662094    1.016939    3.503291    0.140779    0.076026    0.012563    0.590662    
#> 355: 0.662264    1.016905    3.503270    0.140857    0.075988    0.012568    0.590642    
#> 356: 0.662377    1.016862    3.503295    0.140916    0.075940    0.012581    0.590801    
#> 357: 0.662358    1.016904    3.503248    0.141147    0.075914    0.012585    0.590789    
#> 358: 0.662346    1.016898    3.503262    0.141162    0.075848    0.012578    0.590696    
#> 359: 0.662318    1.016880    3.503297    0.141014    0.075775    0.012573    0.590636    
#> 360: 0.662212    1.016836    3.503274    0.140811    0.075760    0.012561    0.590565    
#> 361: 0.661968    1.016811    3.503237    0.140665    0.075720    0.012540    0.590573    
#> 362: 0.662032    1.016750    3.503211    0.140698    0.075709    0.012524    0.590418    
#> 363: 0.662020    1.016739    3.503193    0.140593    0.075694    0.012523    0.590305    
#> 364: 0.662037    1.016761    3.503187    0.140425    0.075676    0.012515    0.590405    
#> 365: 0.661943    1.016692    3.503191    0.140281    0.075642    0.012516    0.590453    
#> 366: 0.661673    1.016744    3.503072    0.140199    0.075662    0.012502    0.590491    
#> 367: 0.661597    1.016895    3.503004    0.140135    0.075712    0.012489    0.590498    
#> 368: 0.661525    1.017035    3.502909    0.140021    0.075709    0.012477    0.590444    
#> 369: 0.661315    1.017081    3.502885    0.139967    0.075758    0.012473    0.590467    
#> 370: 0.661096    1.017194    3.502827    0.139855    0.075731    0.012480    0.590532    
#> 371: 0.660990    1.017292    3.502759    0.139830    0.075718    0.012484    0.590499    
#> 372: 0.660886    1.017339    3.502754    0.139755    0.075665    0.012490    0.590510    
#> 373: 0.660710    1.017444    3.502693    0.139731    0.075633    0.012498    0.590494    
#> 374: 0.660527    1.017486    3.502588    0.139748    0.075645    0.012488    0.590415    
#> 375: 0.660283    1.017585    3.502508    0.139728    0.075636    0.012484    0.590384    
#> 376: 0.660143    1.017716    3.502437    0.139657    0.075653    0.012479    0.590353    
#> 377: 0.659893    1.017823    3.502353    0.139569    0.075591    0.012489    0.590371    
#> 378: 0.659660    1.017902    3.502284    0.139547    0.075549    0.012486    0.590496    
#> 379: 0.659408    1.017883    3.502236    0.139471    0.075504    0.012489    0.590463    
#> 380: 0.659156    1.017890    3.502176    0.139411    0.075507    0.012478    0.590494    
#> 381: 0.658967    1.017872    3.502170    0.139375    0.075510    0.012481    0.590480    
#> 382: 0.658944    1.017918    3.502172    0.139190    0.075524    0.012472    0.590451    
#> 383: 0.659053    1.017921    3.502229    0.138958    0.075568    0.012462    0.590451    
#> 384: 0.658919    1.017841    3.502282    0.138856    0.075577    0.012453    0.590464    
#> 385: 0.658862    1.017716    3.502290    0.138820    0.075616    0.012441    0.590535    
#> 386: 0.658960    1.017841    3.502328    0.138740    0.075759    0.012431    0.590583    
#> 387: 0.659150    1.017901    3.502413    0.138742    0.075797    0.012427    0.590555    
#> 388: 0.659298    1.017904    3.502487    0.138672    0.075792    0.012421    0.590548    
#> 389: 0.659390    1.017677    3.502543    0.138656    0.075790    0.012429    0.590635    
#> 390: 0.659360    1.017665    3.502547    0.138551    0.075781    0.012440    0.590571    
#> 391: 0.659401    1.017587    3.502562    0.138515    0.075785    0.012445    0.590553    
#> 392: 0.659369    1.017555    3.502601    0.138594    0.075801    0.012455    0.590587    
#> 393: 0.659270    1.017572    3.502583    0.138515    0.075775    0.012463    0.590557    
#> 394: 0.659185    1.017616    3.502572    0.138605    0.075733    0.012472    0.590535    
#> 395: 0.659299    1.017793    3.502579    0.138556    0.075672    0.012484    0.590586    
#> 396: 0.659535    1.017891    3.502585    0.138421    0.075678    0.012484    0.590524    
#> 397: 0.659641    1.017842    3.502632    0.138412    0.075727    0.012493    0.590432    
#> 398: 0.659776    1.017793    3.502699    0.138415    0.075848    0.012492    0.590430    
#> 399: 0.659896    1.017807    3.502720    0.138517    0.075944    0.012489    0.590380    
#> 400: 0.659864    1.017783    3.502723    0.138439    0.075924    0.012483    0.590341    
#> 401: 0.659895    1.017831    3.502688    0.138429    0.075936    0.012472    0.590355    
#> 402: 0.659792    1.017975    3.502640    0.138305    0.075902    0.012462    0.590447    
#> 403: 0.659882    1.018005    3.502613    0.138325    0.075871    0.012448    0.590417    
#> 404: 0.660037    1.017984    3.502596    0.138327    0.075871    0.012433    0.590381    
#> 405: 0.660013    1.018004    3.502631    0.138360    0.075904    0.012418    0.590408    
#> 406: 0.660049    1.018062    3.502652    0.138458    0.075888    0.012413    0.590424    
#> 407: 0.660109    1.018123    3.502689    0.138478    0.075925    0.012418    0.590386    
#> 408: 0.660064    1.018149    3.502716    0.138534    0.075989    0.012412    0.590451    
#> 409: 0.659848    1.018133    3.502674    0.138486    0.076024    0.012408    0.590450    
#> 410: 0.659757    1.018169    3.502599    0.138432    0.076072    0.012407    0.590521    
#> 411: 0.659731    1.018016    3.502574    0.138342    0.076147    0.012402    0.590617    
#> 412: 0.659724    1.018060    3.502563    0.138393    0.076148    0.012392    0.590681    
#> 413: 0.659753    1.018000    3.502550    0.138385    0.076115    0.012386    0.590754    
#> 414: 0.659893    1.017872    3.502613    0.138422    0.076068    0.012388    0.590715    
#> 415: 0.660065    1.017796    3.502660    0.138453    0.076031    0.012393    0.590741    
#> 416: 0.660140    1.017828    3.502686    0.138476    0.076010    0.012386    0.590725    
#> 417: 0.660335    1.017737    3.502716    0.138360    0.076032    0.012385    0.590710    
#> 418: 0.660340    1.017806    3.502744    0.138251    0.076067    0.012384    0.590645    
#> 419: 0.660349    1.017900    3.502735    0.138234    0.076061    0.012395    0.590577    
#> 420: 0.660319    1.017964    3.502687    0.138223    0.076053    0.012395    0.590511    
#> 421: 0.660195    1.017999    3.502679    0.138354    0.075994    0.012402    0.590482    
#> 422: 0.660277    1.017992    3.502661    0.138441    0.075943    0.012402    0.590513    
#> 423: 0.660408    1.017958    3.502677    0.138458    0.075901    0.012406    0.590519    
#> 424: 0.660462    1.017934    3.502680    0.138461    0.075889    0.012396    0.590508    
#> 425: 0.660729    1.017877    3.502726    0.138546    0.075911    0.012391    0.590493    
#> 426: 0.660865    1.017889    3.502748    0.138506    0.075939    0.012381    0.590418    
#> 427: 0.660859    1.017800    3.502793    0.138484    0.076028    0.012374    0.590374    
#> 428: 0.660723    1.017758    3.502813    0.138484    0.076021    0.012379    0.590393    
#> 429: 0.660734    1.017739    3.502831    0.138582    0.075993    0.012382    0.590355    
#> 430: 0.660760    1.017796    3.502856    0.138652    0.075993    0.012383    0.590378    
#> 431: 0.660628    1.017804    3.502812    0.138556    0.076047    0.012381    0.590374    
#> 432: 0.660589    1.017807    3.502843    0.138421    0.076038    0.012385    0.590418    
#> 433: 0.660635    1.017877    3.502889    0.138452    0.076092    0.012388    0.590454    
#> 434: 0.660476    1.017856    3.502891    0.138423    0.076120    0.012386    0.590472    
#> 435: 0.660489    1.017864    3.502877    0.138391    0.076165    0.012378    0.590462    
#> 436: 0.660460    1.017817    3.502923    0.138259    0.076187    0.012369    0.590458    
#> 437: 0.660391    1.017753    3.502923    0.138306    0.076197    0.012368    0.590433    
#> 438: 0.660424    1.017777    3.502928    0.138440    0.076223    0.012361    0.590368    
#> 439: 0.660487    1.017819    3.502968    0.138429    0.076174    0.012364    0.590295    
#> 440: 0.660427    1.017813    3.502979    0.138377    0.076188    0.012361    0.590194    
#> 441: 0.660356    1.017773    3.502965    0.138300    0.076165    0.012359    0.590181    
#> 442: 0.660287    1.017835    3.502981    0.138258    0.076130    0.012360    0.590115    
#> 443: 0.660256    1.017875    3.502944    0.138239    0.076204    0.012349    0.590136    
#> 444: 0.660132    1.017964    3.502880    0.138176    0.076264    0.012339    0.590150    
#> 445: 0.659958    1.017972    3.502823    0.138113    0.076312    0.012333    0.590171    
#> 446: 0.659685    1.018108    3.502742    0.138087    0.076367    0.012323    0.590142    
#> 447: 0.659575    1.018194    3.502690    0.138036    0.076463    0.012307    0.590186    
#> 448: 0.659401    1.018223    3.502678    0.138111    0.076451    0.012292    0.590184    
#> 449: 0.659409    1.018280    3.502737    0.138166    0.076418    0.012288    0.590248    
#> 450: 0.659433    1.018237    3.502737    0.138257    0.076422    0.012284    0.590284    
#> 451: 0.659493    1.018201    3.502734    0.138360    0.076415    0.012291    0.590286    
#> 452: 0.659513    1.018192    3.502714    0.138388    0.076430    0.012284    0.590279    
#> 453: 0.659332    1.018264    3.502648    0.138372    0.076401    0.012272    0.590290    
#> 454: 0.659118    1.018451    3.502579    0.138260    0.076429    0.012256    0.590333    
#> 455: 0.659037    1.018499    3.502552    0.138134    0.076411    0.012247    0.590346    
#> 456: 0.658928    1.018471    3.502549    0.137993    0.076418    0.012239    0.590373    
#> 457: 0.658851    1.018483    3.502571    0.137936    0.076431    0.012238    0.590351    
#> 458: 0.658721    1.018654    3.502553    0.137855    0.076429    0.012241    0.590315    
#> 459: 0.658503    1.018787    3.502541    0.137845    0.076434    0.012251    0.590288    
#> 460: 0.658463    1.018755    3.502513    0.137860    0.076407    0.012256    0.590283    
#> 461: 0.658295    1.018827    3.502495    0.137855    0.076372    0.012247    0.590313    
#> 462: 0.658210    1.018891    3.502493    0.137874    0.076369    0.012251    0.590290    
#> 463: 0.658276    1.018978    3.502524    0.137868    0.076335    0.012257    0.590234    
#> 464: 0.658345    1.019063    3.502506    0.137899    0.076281    0.012253    0.590217    
#> 465: 0.658372    1.018961    3.502514    0.137980    0.076225    0.012246    0.590245    
#> 466: 0.658407    1.018991    3.502465    0.138165    0.076184    0.012246    0.590206    
#> 467: 0.658381    1.018967    3.502475    0.138279    0.076239    0.012235    0.590134    
#> 468: 0.658584    1.018952    3.502534    0.138341    0.076293    0.012225    0.590187    
#> 469: 0.658603    1.019000    3.502548    0.138338    0.076333    0.012216    0.590255    
#> 470: 0.658590    1.018961    3.502553    0.138369    0.076370    0.012213    0.590269    
#> 471: 0.658552    1.018828    3.502578    0.138343    0.076370    0.012214    0.590307    
#> 472: 0.658623    1.018772    3.502587    0.138283    0.076440    0.012208    0.590351    
#> 473: 0.658516    1.018740    3.502594    0.138300    0.076455    0.012207    0.590284    
#> 474: 0.658560    1.018669    3.502618    0.138400    0.076426    0.012207    0.590298    
#> 475: 0.658608    1.018682    3.502635    0.138372    0.076412    0.012199    0.590273    
#> 476: 0.658654    1.018618    3.502617    0.138301    0.076409    0.012190    0.590313    
#> 477: 0.658524    1.018585    3.502613    0.138277    0.076430    0.012178    0.590276    
#> 478: 0.658433    1.018603    3.502593    0.138207    0.076453    0.012165    0.590284    
#> 479: 0.658499    1.018663    3.502586    0.138087    0.076471    0.012158    0.590285    
#> 480: 0.658515    1.018640    3.502598    0.137977    0.076536    0.012148    0.590310    
#> 481: 0.658461    1.018664    3.502565    0.137927    0.076569    0.012141    0.590266    
#> 482: 0.658533    1.018669    3.502548    0.137892    0.076594    0.012141    0.590285    
#> 483: 0.658433    1.018658    3.502520    0.137816    0.076614    0.012139    0.590254    
#> 484: 0.658439    1.018578    3.502507    0.137816    0.076608    0.012140    0.590265    
#> 485: 0.658546    1.018570    3.502522    0.137782    0.076562    0.012147    0.590309    
#> 486: 0.658584    1.018518    3.502555    0.137821    0.076566    0.012148    0.590306    
#> 487: 0.658675    1.018465    3.502610    0.137824    0.076556    0.012151    0.590243    
#> 488: 0.658733    1.018477    3.502650    0.137781    0.076534    0.012157    0.590195    
#> 489: 0.658912    1.018447    3.502689    0.137731    0.076489    0.012164    0.590190    
#> 490: 0.659085    1.018455    3.502743    0.137761    0.076474    0.012161    0.590183    
#> 491: 0.659179    1.018528    3.502795    0.137807    0.076511    0.012157    0.590149    
#> 492: 0.659195    1.018630    3.502797    0.137835    0.076556    0.012155    0.590131    
#> 493: 0.659171    1.018618    3.502821    0.137724    0.076554    0.012147    0.590176    
#> 494: 0.659227    1.018668    3.502804    0.137688    0.076576    0.012145    0.590165    
#> 495: 0.659312    1.018703    3.502774    0.137638    0.076618    0.012132    0.590121    
#> 496: 0.659449    1.018769    3.502737    0.137668    0.076637    0.012131    0.590111    
#> 497: 0.659399    1.018774    3.502709    0.137749    0.076637    0.012133    0.590096    
#> 498: 0.659451    1.018771    3.502674    0.137856    0.076667    0.012130    0.590068    
#> 499: 0.659424    1.018779    3.502641    0.137877    0.076706    0.012126    0.590032    
#> 500: 0.659394    1.018760    3.502610    0.137853    0.076762    0.012124    0.589987    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.305251    0.974677    3.450702    0.392401    0.079242    0.016800    1.716646    
#> 002: 0.359067    1.044088    3.474479    0.372781    0.075280    0.015960    1.218298    
#> 003: 0.531071    0.982487    3.494765    0.354142    0.083060    0.015162    0.835246    
#> 004: 0.510888    0.995501    3.491116    0.336435    0.084008    0.014404    0.750428    
#> 005: 0.535859    1.013413    3.491579    0.319613    0.079808    0.013684    0.683254    
#> 006: 0.527522    1.004640    3.471741    0.355124    0.077196    0.013000    0.619785    
#> 007: 0.497004    1.014685    3.460726    0.423171    0.082388    0.012350    0.609880    
#> 008: 0.468687    1.013694    3.460050    0.402012    0.085891    0.011804    0.612590    
#> 009: 0.440684    0.994091    3.458102    0.381911    0.081597    0.012346    0.616729    
#> 010: 0.459674    1.004513    3.458876    0.391103    0.080768    0.011729    0.627049    
#> 011: 0.566135    0.991865    3.466355    0.463887    0.091751    0.011143    0.618127    
#> 012: 0.566490    1.004068    3.473645    0.450432    0.087361    0.010585    0.603716    
#> 013: 0.533884    1.019592    3.475628    0.443517    0.086065    0.010658    0.592015    
#> 014: 0.545450    1.011425    3.475428    0.421341    0.081762    0.010125    0.606408    
#> 015: 0.575573    1.016090    3.485678    0.437376    0.081024    0.009988    0.581464    
#> 016: 0.559048    1.008789    3.481525    0.467455    0.084985    0.012634    0.586050    
#> 017: 0.521807    1.010613    3.489059    0.444082    0.083623    0.013789    0.586344    
#> 018: 0.548963    0.989273    3.481488    0.461347    0.093334    0.013099    0.592788    
#> 019: 0.545875    0.979246    3.486024    0.438279    0.089752    0.012445    0.583276    
#> 020: 0.549444    0.991299    3.482045    0.416365    0.091595    0.011822    0.606577    
#> 021: 0.591849    0.982607    3.491186    0.477074    0.094987    0.011231    0.586240    
#> 022: 0.541954    0.986101    3.492075    0.453220    0.096495    0.010862    0.583807    
#> 023: 0.617337    0.994205    3.501587    0.494166    0.095259    0.010319    0.619082    
#> 024: 0.577581    1.013325    3.486920    0.469457    0.090496    0.012731    0.606609    
#> 025: 0.538341    0.996257    3.482295    0.454826    0.085971    0.016169    0.587966    
#> 026: 0.555884    1.009934    3.481436    0.445761    0.081672    0.015360    0.593016    
#> 027: 0.558274    1.025249    3.478312    0.456872    0.077589    0.016353    0.584251    
#> 028: 0.589895    1.004279    3.482370    0.477236    0.073709    0.015535    0.576105    
#> 029: 0.554598    1.009252    3.472694    0.526787    0.084363    0.016155    0.583854    
#> 030: 0.573195    1.008597    3.474195    0.567961    0.080145    0.016083    0.579133    
#> 031: 0.534390    0.997799    3.483753    0.539563    0.088579    0.015453    0.586419    
#> 032: 0.521494    0.995662    3.480532    0.512585    0.084150    0.014680    0.585467    
#> 033: 0.547672    0.995738    3.484649    0.486955    0.079942    0.013946    0.578576    
#> 034: 0.568927    1.000300    3.481758    0.484864    0.075945    0.013249    0.604849    
#> 035: 0.546733    0.992095    3.480586    0.510402    0.074627    0.013665    0.584971    
#> 036: 0.548366    1.006870    3.473934    0.484882    0.086949    0.013387    0.581959    
#> 037: 0.532840    1.010692    3.480953    0.482547    0.093711    0.013410    0.599184    
#> 038: 0.542043    1.008047    3.479688    0.458420    0.094074    0.012739    0.588847    
#> 039: 0.580962    1.018030    3.481733    0.495769    0.089370    0.012183    0.577382    
#> 040: 0.558399    1.021614    3.487087    0.470981    0.084902    0.011839    0.585083    
#> 041: 0.562720    1.002427    3.484598    0.464136    0.083873    0.011247    0.577198    
#> 042: 0.601798    0.995708    3.486090    0.550775    0.079679    0.010920    0.566235    
#> 043: 0.581451    0.990694    3.476536    0.596076    0.078207    0.011503    0.570813    
#> 044: 0.548325    1.001069    3.473362    0.566272    0.086671    0.010928    0.579281    
#> 045: 0.529648    1.000399    3.471633    0.537959    0.082337    0.010381    0.573184    
#> 046: 0.567760    0.982840    3.481225    0.511061    0.089479    0.010030    0.574036    
#> 047: 0.556678    1.003147    3.473050    0.521644    0.088493    0.012335    0.572306    
#> 048: 0.558140    1.005028    3.476156    0.572738    0.086310    0.012955    0.583921    
#> 049: 0.514600    0.997968    3.480837    0.544101    0.090516    0.012307    0.593041    
#> 050: 0.574373    0.982152    3.481304    0.531363    0.100642    0.011692    0.591611    
#> 051: 0.561561    1.002123    3.479164    0.504794    0.095610    0.011107    0.590804    
#> 052: 0.574248    1.003495    3.486154    0.479555    0.090829    0.012021    0.581308    
#> 053: 0.575409    1.001368    3.484330    0.506653    0.086288    0.011420    0.589065    
#> 054: 0.568161    0.987831    3.490353    0.484759    0.092765    0.011920    0.604457    
#> 055: 0.581481    0.987113    3.491068    0.482409    0.088487    0.011324    0.599766    
#> 056: 0.585154    0.988338    3.486893    0.538399    0.085361    0.013378    0.600575    
#> 057: 0.529844    0.992127    3.482357    0.511479    0.084470    0.012996    0.611773    
#> 058: 0.540828    0.997657    3.476612    0.504591    0.080246    0.012347    0.597808    
#> 059: 0.566482    0.969662    3.478465    0.556041    0.095968    0.011729    0.609116    
#> 060: 0.581860    0.972044    3.484892    0.528239    0.091999    0.012735    0.607551    
#> 061: 0.635395    0.987070    3.498123    0.565804    0.087399    0.015399    0.621770    
#> 062: 0.587042    0.992966    3.499704    0.537513    0.097303    0.016053    0.627374    
#> 063: 0.631715    0.971381    3.502342    0.510638    0.099378    0.016079    0.625859    
#> 064: 0.568791    0.974460    3.503883    0.509507    0.094409    0.015275    0.624872    
#> 065: 0.583727    0.980933    3.484179    0.488070    0.089688    0.014662    0.604938    
#> 066: 0.601253    0.985665    3.499768    0.505222    0.095693    0.013929    0.581645    
#> 067: 0.570525    0.980026    3.481976    0.534767    0.090908    0.013233    0.581662    
#> 068: 0.525947    0.979980    3.480739    0.511353    0.086363    0.012571    0.607005    
#> 069: 0.533773    0.981807    3.476749    0.570965    0.083883    0.011942    0.607111    
#> 070: 0.549263    0.988290    3.486892    0.542416    0.084073    0.011545    0.596745    
#> 071: 0.522068    1.008290    3.462983    0.515296    0.080215    0.010984    0.594874    
#> 072: 0.497047    1.006763    3.465021    0.528577    0.094527    0.011761    0.581926    
#> 073: 0.540668    1.026772    3.480684    0.502148    0.101727    0.011173    0.581957    
#> 074: 0.528882    0.991625    3.481637    0.477041    0.096641    0.011145    0.590092    
#> 075: 0.557649    0.979331    3.494968    0.467254    0.094818    0.012484    0.584686    
#> 076: 0.597725    0.984969    3.510231    0.462182    0.090077    0.012647    0.594641    
#> 077: 0.629580    0.949373    3.513836    0.439072    0.085573    0.013365    0.610304    
#> 078: 0.592007    0.973473    3.514335    0.440644    0.081294    0.012696    0.583798    
#> 079: 0.614904    0.999141    3.502636    0.497952    0.100242    0.012062    0.599936    
#> 080: 0.600086    0.977198    3.498116    0.527735    0.100314    0.012307    0.628926    
#> 081: 0.612173    0.985338    3.495824    0.532371    0.095298    0.014048    0.608950    
#> 082: 0.602331    0.975297    3.508889    0.505752    0.092139    0.013346    0.614846    
#> 083: 0.594360    0.982196    3.500430    0.480465    0.088667    0.012678    0.612291    
#> 084: 0.615925    0.970359    3.495020    0.573035    0.086741    0.012045    0.617859    
#> 085: 0.555019    0.976726    3.499347    0.544383    0.082404    0.011442    0.617328    
#> 086: 0.612369    0.987047    3.495644    0.517164    0.099216    0.014556    0.589885    
#> 087: 0.564234    0.993868    3.492397    0.491305    0.094255    0.015583    0.588983    
#> 088: 0.524937    0.995518    3.488477    0.466740    0.089542    0.014804    0.590969    
#> 089: 0.520322    1.004199    3.473826    0.474630    0.085065    0.015366    0.592387    
#> 090: 0.541581    1.015294    3.468691    0.490230    0.092805    0.014598    0.580123    
#> 091: 0.500499    1.009595    3.452846    0.490257    0.088747    0.013868    0.580092    
#> 092: 0.507426    1.035358    3.453016    0.465744    0.084309    0.014106    0.582618    
#> 093: 0.493904    1.017282    3.450611    0.490906    0.080094    0.014964    0.592769    
#> 094: 0.472570    1.035702    3.449191    0.466361    0.091796    0.014215    0.599878    
#> 095: 0.512695    1.011115    3.467416    0.446201    0.090211    0.014150    0.607364    
#> 096: 0.480429    1.018545    3.463330    0.527338    0.085701    0.015630    0.589675    
#> 097: 0.529790    1.012282    3.461985    0.529276    0.081416    0.014849    0.581927    
#> 098: 0.561013    1.028998    3.467177    0.502812    0.088149    0.014106    0.585283    
#> 099: 0.535759    1.013850    3.462209    0.477671    0.083742    0.013913    0.589152    
#> 100: 0.510585    1.023345    3.466086    0.480139    0.092304    0.013217    0.589548    
#> 101: 0.485404    1.005407    3.449370    0.468103    0.093039    0.012557    0.586282    
#> 102: 0.490512    1.017108    3.452442    0.505896    0.089320    0.011929    0.597350    
#> 103: 0.519621    1.005078    3.458009    0.486134    0.092423    0.011332    0.592766    
#> 104: 0.524779    1.008874    3.469884    0.561570    0.097998    0.010766    0.616815    
#> 105: 0.532000    1.006894    3.469733    0.565120    0.097748    0.010227    0.598659    
#> 106: 0.553740    1.012635    3.459535    0.614976    0.096062    0.011463    0.581079    
#> 107: 0.540959    1.008102    3.468095    0.584227    0.093211    0.012128    0.580995    
#> 108: 0.521930    0.996918    3.467670    0.555015    0.093281    0.011522    0.585900    
#> 109: 0.535124    1.007383    3.481045    0.527265    0.088617    0.010946    0.592679    
#> 110: 0.580057    1.000674    3.472322    0.500901    0.084827    0.011938    0.582711    
#> 111: 0.550464    0.995686    3.479952    0.479066    0.084590    0.011341    0.572598    
#> 112: 0.537187    0.975876    3.478726    0.455113    0.085248    0.011070    0.585212    
#> 113: 0.514166    1.027200    3.476309    0.432357    0.084217    0.010973    0.577977    
#> 114: 0.536215    1.007303    3.474250    0.437427    0.088614    0.010971    0.571106    
#> 115: 0.572602    0.980703    3.473128    0.516658    0.084183    0.011007    0.589176    
#> 116: 0.580477    0.988551    3.478042    0.539755    0.079974    0.012593    0.575434    
#> 117: 0.534075    1.004562    3.480693    0.512767    0.078252    0.012982    0.599268    
#> 118: 0.574753    0.982553    3.489310    0.509019    0.074339    0.014543    0.583467    
#> 119: 0.566800    1.007837    3.480059    0.523347    0.078644    0.015204    0.584845    
#> 120: 0.537353    0.988290    3.478199    0.580064    0.077533    0.014444    0.598051    
#> 121: 0.547331    1.015870    3.475701    0.573388    0.076705    0.013774    0.595951    
#> 122: 0.541820    0.989750    3.483522    0.544719    0.080222    0.013513    0.575419    
#> 123: 0.565753    1.012432    3.480397    0.517483    0.082545    0.015372    0.566085    
#> 124: 0.544983    1.032907    3.471607    0.491609    0.078418    0.015101    0.586441    
#> 125: 0.568872    1.041002    3.472273    0.489808    0.074945    0.014346    0.583042    
#> 126: 0.558095    1.033639    3.465940    0.468827    0.071197    0.018324    0.598483    
#> 127: 0.576514    1.038123    3.458005    0.611173    0.070235    0.017408    0.613995    
#> 128: 0.525036    1.023271    3.474963    0.580614    0.077380    0.016713    0.620418    
#> 129: 0.560783    1.007339    3.486307    0.564894    0.076614    0.015878    0.601495    
#> 130: 0.571970    1.013565    3.474527    0.536649    0.085054    0.015084    0.590536    
#> 131: 0.529842    1.000919    3.468280    0.509817    0.098464    0.014330    0.597645    
#> 132: 0.500790    1.013429    3.453892    0.484326    0.099069    0.013613    0.612792    
#> 133: 0.529357    1.018384    3.463111    0.500328    0.094115    0.012932    0.614555    
#> 134: 0.541836    0.998734    3.480911    0.475312    0.091014    0.013171    0.597339    
#> 135: 0.541494    0.992318    3.487288    0.457924    0.096169    0.012512    0.597112    
#> 136: 0.559091    0.986367    3.485279    0.493795    0.091360    0.012040    0.585985    
#> 137: 0.602438    0.997472    3.484919    0.582617    0.086792    0.011438    0.587242    
#> 138: 0.572123    1.008106    3.481187    0.553486    0.086573    0.012495    0.576686    
#> 139: 0.539407    0.994444    3.474269    0.541611    0.098020    0.013304    0.586111    
#> 140: 0.568582    0.996788    3.480394    0.528982    0.093119    0.012639    0.588285    
#> 141: 0.558174    0.984599    3.498337    0.502533    0.093410    0.012184    0.579389    
#> 142: 0.564288    0.992045    3.496932    0.477406    0.088739    0.011575    0.586678    
#> 143: 0.536103    1.009709    3.491266    0.453536    0.089438    0.014820    0.601979    
#> 144: 0.612481    0.997524    3.500737    0.524267    0.084966    0.014079    0.579436    
#> 145: 0.584826    1.017535    3.485556    0.498053    0.080932    0.013876    0.578362    
#> 146: 0.581263    1.007627    3.494196    0.505919    0.076886    0.013964    0.576600    
#> 147: 0.538906    1.002316    3.478630    0.515695    0.078679    0.015010    0.562307    
#> 148: 0.514586    1.011550    3.478402    0.489910    0.084560    0.014260    0.584795    
#> 149: 0.538699    0.995358    3.479499    0.465414    0.087949    0.013547    0.579124    
#> 150: 0.543443    0.998722    3.467209    0.482763    0.085007    0.013153    0.590513    
#> 151: 0.507835    1.019273    3.470741    0.479074    0.080757    0.014329    0.585300    
#> 152: 0.502911    1.022791    3.474522    0.457899    0.082099    0.013666    0.580685    
#> 153: 0.531617    1.024495    3.479707    0.494758    0.078277    0.015516    0.585820    
#> 154: 0.548299    1.000936    3.481892    0.479994    0.083908    0.014504    0.587043    
#> 155: 0.515301    1.007057    3.474125    0.406551    0.089152    0.014957    0.590025    
#> 156: 0.537494    1.008169    3.488400    0.418542    0.094473    0.014989    0.594891    
#> 157: 0.565621    1.002120    3.489648    0.500704    0.086840    0.014194    0.584267    
#> 158: 0.601700    1.004579    3.489518    0.458291    0.080895    0.014539    0.595456    
#> 159: 0.566687    0.992918    3.497137    0.496518    0.089600    0.015948    0.590928    
#> 160: 0.585301    0.968693    3.497874    0.513172    0.094030    0.014134    0.599201    
#> 161: 0.581296    0.986531    3.483189    0.528902    0.075062    0.012264    0.594898    
#> 162: 0.567766    1.013053    3.476938    0.531481    0.086088    0.014759    0.605087    
#> 163: 0.584951    1.014945    3.475884    0.527976    0.089370    0.011956    0.587750    
#> 164: 0.568408    1.008869    3.482758    0.525573    0.083277    0.015293    0.577486    
#> 165: 0.565426    0.979890    3.496205    0.509972    0.072911    0.014443    0.584472    
#> 166: 0.576885    1.011205    3.488370    0.492567    0.068160    0.013046    0.582725    
#> 167: 0.593584    1.005714    3.490938    0.547890    0.083351    0.012937    0.591640    
#> 168: 0.582358    1.011353    3.492025    0.502242    0.088277    0.012412    0.580053    
#> 169: 0.581088    1.032790    3.483347    0.538053    0.080861    0.012930    0.595289    
#> 170: 0.598234    1.012847    3.485674    0.587309    0.084419    0.012600    0.577426    
#> 171: 0.558542    1.009463    3.474170    0.540054    0.070275    0.013951    0.570173    
#> 172: 0.506171    1.030553    3.471681    0.426898    0.074790    0.012527    0.583784    
#> 173: 0.525936    1.038702    3.466961    0.420966    0.069005    0.015116    0.579227    
#> 174: 0.547922    1.020840    3.480709    0.500026    0.068285    0.018277    0.578192    
#> 175: 0.533551    1.015107    3.467240    0.444636    0.069810    0.020293    0.584115    
#> 176: 0.542542    1.010782    3.477839    0.501660    0.082708    0.014705    0.581069    
#> 177: 0.562908    0.999283    3.487360    0.457580    0.070704    0.015013    0.588581    
#> 178: 0.565070    1.002307    3.483358    0.466223    0.079967    0.014884    0.582580    
#> 179: 0.600700    1.024856    3.475074    0.515408    0.094664    0.012405    0.587527    
#> 180: 0.603527    1.008025    3.481573    0.570977    0.081402    0.012554    0.580247    
#> 181: 0.581430    1.013741    3.467262    0.511267    0.090294    0.013195    0.585981    
#> 182: 0.528094    1.020049    3.461487    0.485784    0.096053    0.014860    0.585573    
#> 183: 0.543247    1.038400    3.458082    0.517708    0.090451    0.014662    0.594579    
#> 184: 0.506854    1.038007    3.458948    0.462819    0.071220    0.014988    0.585280    
#> 185: 0.514245    1.029580    3.456926    0.472831    0.073458    0.017202    0.590849    
#> 186: 0.513208    1.058090    3.457314    0.476271    0.083622    0.018942    0.589710    
#> 187: 0.547778    1.029075    3.471029    0.571947    0.073111    0.017162    0.560599    
#> 188: 0.539558    1.025020    3.474643    0.557807    0.072978    0.014245    0.580056    
#> 189: 0.566945    1.018964    3.480377    0.631920    0.071562    0.014804    0.588935    
#> 190: 0.603369    1.022536    3.487369    0.655967    0.074136    0.014747    0.573255    
#> 191: 0.549909    1.014877    3.470165    0.544350    0.075993    0.014156    0.566326    
#> 192: 0.546840    1.016622    3.474501    0.506933    0.078304    0.013748    0.579091    
#> 193: 0.551682    1.027283    3.475297    0.553913    0.091460    0.012084    0.577622    
#> 194: 0.544023    1.026988    3.460598    0.531775    0.088628    0.010872    0.595818    
#> 195: 0.519355    1.019452    3.461576    0.514770    0.091689    0.008950    0.603273    
#> 196: 0.522676    1.015585    3.465816    0.464317    0.094953    0.011170    0.605479    
#> 197: 0.531457    1.022274    3.486291    0.431815    0.087996    0.011131    0.612395    
#> 198: 0.564592    0.981236    3.480438    0.452884    0.098069    0.013163    0.605425    
#> 199: 0.555752    0.987922    3.475778    0.504320    0.101311    0.010224    0.594300    
#> 200: 0.534260    1.002381    3.477501    0.470435    0.097681    0.010467    0.608675    
#> 201: 0.541066    1.002211    3.481017    0.444711    0.093592    0.010217    0.601537    
#> 202: 0.539937    1.004828    3.481377    0.426598    0.088818    0.011205    0.604798    
#> 203: 0.551614    1.003345    3.480297    0.415664    0.087271    0.012008    0.606430    
#> 204: 0.553739    0.996116    3.483274    0.410849    0.084604    0.012100    0.608015    
#> 205: 0.557471    0.999071    3.483654    0.415003    0.082956    0.012147    0.607988    
#> 206: 0.553949    1.004057    3.483364    0.417219    0.083812    0.011784    0.608055    
#> 207: 0.555535    1.006056    3.481972    0.420634    0.083080    0.011631    0.605599    
#> 208: 0.556730    1.006749    3.481010    0.430255    0.083688    0.011455    0.602343    
#> 209: 0.556951    1.005095    3.480647    0.436067    0.083923    0.011224    0.599422    
#> 210: 0.555940    1.002619    3.481089    0.440162    0.083721    0.010935    0.599178    
#> 211: 0.559126    1.002426    3.482014    0.443274    0.084833    0.010780    0.597821    
#> 212: 0.563514    1.002663    3.482120    0.446234    0.084492    0.010714    0.597888    
#> 213: 0.567107    1.001640    3.482505    0.455483    0.083206    0.010660    0.598402    
#> 214: 0.569167    1.000543    3.482325    0.462537    0.083443    0.010706    0.597697    
#> 215: 0.571629    1.000444    3.482617    0.469689    0.083797    0.010765    0.596611    
#> 216: 0.572899    0.998755    3.483074    0.470251    0.084702    0.010768    0.596563    
#> 217: 0.573217    1.000027    3.483198    0.467743    0.085172    0.010743    0.596465    
#> 218: 0.572773    1.000792    3.482720    0.469180    0.085153    0.010908    0.596216    
#> 219: 0.572499    1.000788    3.482017    0.471912    0.084709    0.011051    0.596010    
#> 220: 0.572024    1.001221    3.481823    0.475931    0.084017    0.011276    0.596009    
#> 221: 0.572785    1.001562    3.481815    0.479900    0.083747    0.011327    0.595021    
#> 222: 0.573317    1.001384    3.481720    0.482376    0.083816    0.011489    0.594696    
#> 223: 0.573398    1.001077    3.482069    0.482831    0.083791    0.011654    0.594169    
#> 224: 0.574274    1.001572    3.482448    0.480790    0.083668    0.011763    0.593990    
#> 225: 0.573274    1.000495    3.482560    0.480966    0.082994    0.011856    0.594247    
#> 226: 0.572518    0.999758    3.482418    0.481141    0.082886    0.011894    0.594516    
#> 227: 0.571565    0.999788    3.482392    0.479989    0.082532    0.011956    0.594443    
#> 228: 0.570192    1.000126    3.482013    0.479497    0.082305    0.012018    0.593866    
#> 229: 0.568799    1.000282    3.481719    0.478812    0.082209    0.012110    0.593743    
#> 230: 0.568844    1.000221    3.481557    0.479704    0.082227    0.012139    0.593481    
#> 231: 0.568774    1.000759    3.481507    0.482135    0.081999    0.012238    0.592985    
#> 232: 0.567122    1.001080    3.481259    0.481332    0.082091    0.012305    0.592778    
#> 233: 0.565513    1.000602    3.481180    0.481187    0.081782    0.012458    0.593129    
#> 234: 0.565011    1.000557    3.480997    0.482918    0.081596    0.012519    0.592771    
#> 235: 0.564120    1.000892    3.480556    0.483556    0.081379    0.012572    0.592193    
#> 236: 0.563063    1.001414    3.480100    0.483476    0.081442    0.012632    0.591707    
#> 237: 0.562753    1.001644    3.480062    0.483685    0.081474    0.012706    0.591454    
#> 238: 0.562624    1.001005    3.480199    0.484599    0.081370    0.012728    0.591965    
#> 239: 0.561814    1.001087    3.480100    0.482882    0.081581    0.012739    0.591684    
#> 240: 0.561439    1.000540    3.480229    0.481470    0.081611    0.012737    0.591151    
#> 241: 0.561186    0.999537    3.480357    0.480777    0.082074    0.012731    0.591002    
#> 242: 0.560723    0.998997    3.480233    0.480347    0.082008    0.012751    0.591380    
#> 243: 0.559901    0.999545    3.479998    0.480091    0.082311    0.012782    0.591277    
#> 244: 0.558715    0.999732    3.480039    0.479006    0.082471    0.012866    0.591464    
#> 245: 0.558650    0.999679    3.480127    0.479125    0.082722    0.012885    0.591508    
#> 246: 0.558472    0.999475    3.480240    0.478730    0.082754    0.012833    0.591461    
#> 247: 0.558844    0.999260    3.480511    0.477649    0.083071    0.012813    0.591738    
#> 248: 0.558764    0.999355    3.480703    0.477226    0.083161    0.012779    0.592034    
#> 249: 0.558664    0.999469    3.480706    0.478469    0.083336    0.012761    0.592048    
#> 250: 0.559044    0.999655    3.480817    0.478198    0.083653    0.012821    0.591891    
#> 251: 0.559410    1.000094    3.481218    0.477705    0.083784    0.012827    0.591744    
#> 252: 0.559488    1.000436    3.481477    0.478171    0.083835    0.012835    0.591342    
#> 253: 0.559437    1.000538    3.481479    0.478326    0.083935    0.012854    0.591204    
#> 254: 0.559675    1.000392    3.481624    0.478164    0.084019    0.012823    0.591162    
#> 255: 0.560057    1.000758    3.481855    0.477934    0.083764    0.012871    0.591227    
#> 256: 0.560178    1.000506    3.482013    0.477929    0.083559    0.012865    0.591449    
#> 257: 0.559991    1.000227    3.482088    0.477503    0.083444    0.012829    0.591681    
#> 258: 0.559754    1.000203    3.482151    0.476909    0.083386    0.012821    0.591823    
#> 259: 0.559547    0.999962    3.482217    0.477017    0.083395    0.012882    0.591648    
#> 260: 0.559564    0.999867    3.482320    0.477211    0.083391    0.012921    0.591196    
#> 261: 0.559862    0.999659    3.482329    0.477697    0.083466    0.012953    0.591031    
#> 262: 0.559588    0.999689    3.482283    0.477225    0.083580    0.012931    0.590912    
#> 263: 0.559161    0.999844    3.482314    0.477261    0.083686    0.012954    0.590818    
#> 264: 0.558923    1.000034    3.482254    0.477923    0.083691    0.012981    0.591064    
#> 265: 0.558354    1.000144    3.482331    0.476932    0.083842    0.012974    0.591318    
#> 266: 0.558421    1.000194    3.482384    0.476233    0.083898    0.012935    0.591273    
#> 267: 0.558139    1.000193    3.482420    0.477396    0.083867    0.012923    0.591373    
#> 268: 0.558044    0.999971    3.482320    0.478549    0.083756    0.012881    0.591622    
#> 269: 0.558542    0.999661    3.482419    0.477965    0.083771    0.012882    0.591707    
#> 270: 0.558479    0.999821    3.482407    0.477034    0.083805    0.012869    0.591701    
#> 271: 0.558327    0.999869    3.482299    0.477672    0.083803    0.012899    0.591498    
#> 272: 0.558846    0.999507    3.482308    0.478941    0.083825    0.012941    0.591616    
#> 273: 0.558735    0.999736    3.482244    0.479289    0.083667    0.013002    0.591701    
#> 274: 0.558637    0.999925    3.482331    0.479493    0.083450    0.013051    0.591637    
#> 275: 0.558466    1.000105    3.482213    0.479293    0.083276    0.013106    0.591507    
#> 276: 0.558166    1.000339    3.482244    0.479536    0.083245    0.013124    0.591365    
#> 277: 0.557813    1.000384    3.482305    0.479599    0.083189    0.013158    0.591371    
#> 278: 0.557173    1.000354    3.482337    0.479696    0.083200    0.013166    0.591489    
#> 279: 0.556784    1.000206    3.482320    0.480284    0.083171    0.013196    0.591651    
#> 280: 0.556536    1.000407    3.482208    0.481232    0.083123    0.013199    0.591558    
#> 281: 0.555916    1.000672    3.482073    0.481176    0.083056    0.013223    0.591368    
#> 282: 0.555700    1.000935    3.482041    0.480855    0.083076    0.013223    0.591352    
#> 283: 0.555648    1.001018    3.482076    0.481691    0.083057    0.013208    0.591736    
#> 284: 0.555457    1.000862    3.482046    0.482266    0.083103    0.013216    0.591873    
#> 285: 0.555112    1.001045    3.481944    0.482225    0.083178    0.013225    0.591949    
#> 286: 0.554786    1.001305    3.481850    0.483109    0.083368    0.013213    0.591746    
#> 287: 0.553976    1.001492    3.481536    0.483006    0.083456    0.013215    0.591828    
#> 288: 0.553873    1.001515    3.481356    0.482989    0.083568    0.013195    0.591837    
#> 289: 0.554078    1.001550    3.481287    0.483001    0.083642    0.013206    0.591744    
#> 290: 0.554326    1.001354    3.481272    0.483354    0.083650    0.013232    0.591867    
#> 291: 0.554349    1.001530    3.481341    0.483672    0.083554    0.013274    0.591680    
#> 292: 0.554380    1.001633    3.481331    0.484344    0.083535    0.013291    0.591561    
#> 293: 0.553919    1.001643    3.481226    0.484189    0.083489    0.013293    0.591628    
#> 294: 0.553662    1.001749    3.481046    0.484564    0.083495    0.013300    0.591519    
#> 295: 0.553162    1.001510    3.480952    0.484174    0.083468    0.013345    0.591330    
#> 296: 0.552903    1.001623    3.480766    0.484461    0.083247    0.013397    0.591275    
#> 297: 0.552720    1.001862    3.480577    0.485327    0.083172    0.013444    0.591226    
#> 298: 0.552462    1.001907    3.480463    0.485554    0.083064    0.013450    0.591218    
#> 299: 0.552365    1.002127    3.480392    0.485725    0.083128    0.013438    0.591113    
#> 300: 0.552625    1.001902    3.480466    0.486875    0.083226    0.013427    0.591122    
#> 301: 0.552960    1.001694    3.480417    0.486952    0.083329    0.013405    0.591287    
#> 302: 0.553293    1.001729    3.480504    0.486992    0.083419    0.013402    0.591248    
#> 303: 0.553501    1.001687    3.480585    0.486557    0.083428    0.013429    0.591018    
#> 304: 0.553522    1.001766    3.480591    0.486263    0.083399    0.013443    0.590898    
#> 305: 0.553432    1.001568    3.480614    0.485900    0.083450    0.013445    0.590720    
#> 306: 0.553184    1.001485    3.480573    0.485638    0.083331    0.013427    0.590756    
#> 307: 0.553183    1.001450    3.480421    0.486038    0.083458    0.013409    0.590748    
#> 308: 0.552568    1.001472    3.480255    0.485927    0.083523    0.013387    0.590788    
#> 309: 0.551972    1.001650    3.480102    0.485901    0.083479    0.013363    0.590995    
#> 310: 0.551803    1.001827    3.479950    0.485495    0.083462    0.013375    0.591092    
#> 311: 0.551753    1.002038    3.479827    0.485570    0.083471    0.013404    0.591154    
#> 312: 0.551215    1.002119    3.479688    0.485136    0.083443    0.013427    0.591335    
#> 313: 0.551009    1.002154    3.479593    0.485014    0.083415    0.013416    0.591517    
#> 314: 0.550576    1.002320    3.479460    0.484975    0.083427    0.013407    0.591534    
#> 315: 0.550219    1.002661    3.479364    0.484869    0.083480    0.013386    0.591538    
#> 316: 0.550218    1.002842    3.479307    0.485070    0.083446    0.013364    0.591506    
#> 317: 0.550273    1.002955    3.479293    0.484991    0.083397    0.013361    0.591604    
#> 318: 0.550397    1.002977    3.479273    0.485005    0.083274    0.013358    0.591529    
#> 319: 0.550267    1.002957    3.479318    0.484740    0.083152    0.013371    0.591528    
#> 320: 0.549795    1.002839    3.479238    0.484079    0.083029    0.013373    0.591641    
#> 321: 0.549540    1.002862    3.479150    0.483751    0.083002    0.013356    0.591710    
#> 322: 0.549213    1.002910    3.478966    0.483816    0.083013    0.013345    0.591709    
#> 323: 0.548992    1.003010    3.478914    0.483589    0.083068    0.013341    0.591622    
#> 324: 0.549049    1.003098    3.478917    0.484185    0.083189    0.013316    0.591557    
#> 325: 0.549011    1.003299    3.478815    0.484050    0.083241    0.013287    0.591416    
#> 326: 0.549094    1.003268    3.478810    0.484006    0.083332    0.013266    0.591317    
#> 327: 0.549129    1.003247    3.478851    0.483331    0.083477    0.013234    0.591379    
#> 328: 0.549288    1.003337    3.478862    0.483481    0.083420    0.013208    0.591398    
#> 329: 0.549602    1.003266    3.478944    0.483792    0.083489    0.013177    0.591298    
#> 330: 0.549378    1.003334    3.478913    0.483437    0.083391    0.013175    0.591338    
#> 331: 0.549342    1.003472    3.478895    0.483852    0.083375    0.013179    0.591230    
#> 332: 0.549338    1.003595    3.478928    0.483715    0.083346    0.013194    0.591277    
#> 333: 0.549411    1.003803    3.478792    0.483708    0.083388    0.013199    0.591389    
#> 334: 0.549091    1.003824    3.478605    0.483545    0.083432    0.013189    0.591410    
#> 335: 0.548807    1.004019    3.478478    0.483455    0.083355    0.013201    0.591403    
#> 336: 0.548475    1.004300    3.478340    0.483956    0.083379    0.013202    0.591427    
#> 337: 0.547983    1.004613    3.478212    0.484146    0.083386    0.013189    0.591404    
#> 338: 0.547787    1.004832    3.478155    0.484333    0.083437    0.013172    0.591366    
#> 339: 0.547396    1.005081    3.477994    0.484556    0.083480    0.013158    0.591309    
#> 340: 0.547241    1.005042    3.477952    0.484671    0.083502    0.013151    0.591232    
#> 341: 0.547247    1.004915    3.477984    0.484924    0.083628    0.013161    0.591180    
#> 342: 0.547088    1.004802    3.478026    0.484958    0.083660    0.013177    0.591085    
#> 343: 0.546997    1.004769    3.478079    0.484453    0.083753    0.013180    0.591077    
#> 344: 0.547322    1.004732    3.478135    0.484461    0.083688    0.013192    0.591065    
#> 345: 0.547505    1.004632    3.478165    0.484562    0.083655    0.013206    0.591014    
#> 346: 0.547591    1.004571    3.478137    0.484679    0.083618    0.013197    0.590955    
#> 347: 0.547767    1.004461    3.478093    0.485022    0.083750    0.013197    0.591027    
#> 348: 0.547369    1.004555    3.477965    0.485003    0.083784    0.013212    0.591073    
#> 349: 0.547006    1.004611    3.477882    0.485065    0.083731    0.013217    0.591113    
#> 350: 0.546701    1.004516    3.477861    0.485027    0.083650    0.013207    0.591157    
#> 351: 0.546599    1.004553    3.477797    0.484835    0.083549    0.013194    0.591271    
#> 352: 0.546402    1.004649    3.477819    0.484555    0.083540    0.013183    0.591437    
#> 353: 0.546441    1.004880    3.477833    0.484473    0.083489    0.013188    0.591506    
#> 354: 0.546551    1.004970    3.477788    0.484621    0.083406    0.013183    0.591557    
#> 355: 0.546844    1.004826    3.477817    0.484876    0.083392    0.013188    0.591562    
#> 356: 0.546996    1.004798    3.477841    0.485371    0.083394    0.013199    0.591527    
#> 357: 0.547225    1.004802    3.477879    0.485854    0.083363    0.013224    0.591452    
#> 358: 0.547244    1.004922    3.477859    0.486130    0.083400    0.013241    0.591419    
#> 359: 0.547124    1.005035    3.477791    0.486492    0.083386    0.013250    0.591332    
#> 360: 0.546852    1.005064    3.477639    0.486409    0.083422    0.013250    0.591224    
#> 361: 0.546589    1.005256    3.477532    0.486232    0.083382    0.013253    0.591053    
#> 362: 0.546603    1.005354    3.477454    0.486430    0.083396    0.013258    0.590890    
#> 363: 0.546516    1.005260    3.477435    0.486287    0.083369    0.013254    0.590789    
#> 364: 0.546574    1.005177    3.477427    0.486012    0.083400    0.013270    0.590782    
#> 365: 0.546671    1.005069    3.477482    0.485971    0.083368    0.013291    0.590808    
#> 366: 0.546905    1.005090    3.477491    0.486035    0.083324    0.013320    0.590793    
#> 367: 0.547104    1.005119    3.477509    0.486202    0.083294    0.013339    0.590774    
#> 368: 0.547528    1.005228    3.477520    0.487182    0.083224    0.013360    0.590765    
#> 369: 0.547610    1.005284    3.477553    0.487558    0.083216    0.013383    0.590803    
#> 370: 0.547482    1.005406    3.477510    0.487439    0.083102    0.013411    0.590828    
#> 371: 0.547122    1.005654    3.477327    0.487431    0.083044    0.013413    0.590871    
#> 372: 0.546719    1.005818    3.477213    0.487459    0.082979    0.013415    0.590899    
#> 373: 0.546318    1.005956    3.477064    0.487960    0.082918    0.013416    0.591015    
#> 374: 0.546280    1.006049    3.476937    0.488635    0.082865    0.013419    0.590970    
#> 375: 0.546234    1.006182    3.476841    0.489000    0.082858    0.013422    0.590886    
#> 376: 0.546133    1.006220    3.476785    0.489096    0.082810    0.013445    0.590823    
#> 377: 0.545969    1.006218    3.476735    0.489270    0.082783    0.013463    0.590791    
#> 378: 0.545856    1.006222    3.476715    0.489334    0.082749    0.013467    0.590831    
#> 379: 0.545638    1.006173    3.476675    0.489350    0.082755    0.013469    0.590758    
#> 380: 0.545452    1.006116    3.476623    0.489255    0.082755    0.013461    0.590687    
#> 381: 0.545255    1.006124    3.476570    0.489299    0.082776    0.013457    0.590653    
#> 382: 0.545217    1.006168    3.476544    0.490023    0.082789    0.013446    0.590567    
#> 383: 0.545271    1.006095    3.476561    0.490044    0.082814    0.013441    0.590533    
#> 384: 0.545192    1.006062    3.476579    0.489780    0.082814    0.013436    0.590495    
#> 385: 0.545262    1.006046    3.476569    0.489831    0.082852    0.013441    0.590421    
#> 386: 0.545523    1.006079    3.476674    0.489925    0.082848    0.013454    0.590438    
#> 387: 0.545671    1.006111    3.476775    0.490243    0.082839    0.013459    0.590376    
#> 388: 0.545746    1.006210    3.476794    0.490582    0.082808    0.013467    0.590295    
#> 389: 0.545837    1.006156    3.476783    0.490905    0.082794    0.013482    0.590293    
#> 390: 0.545875    1.006311    3.476735    0.490948    0.082777    0.013491    0.590192    
#> 391: 0.545861    1.006341    3.476704    0.490876    0.082733    0.013489    0.590165    
#> 392: 0.545838    1.006374    3.476709    0.491000    0.082631    0.013485    0.590199    
#> 393: 0.545838    1.006294    3.476718    0.491144    0.082543    0.013497    0.590245    
#> 394: 0.546073    1.006303    3.476702    0.491861    0.082433    0.013510    0.590227    
#> 395: 0.546550    1.006368    3.476719    0.492954    0.082352    0.013526    0.590187    
#> 396: 0.546870    1.006435    3.476729    0.493617    0.082276    0.013537    0.590154    
#> 397: 0.546986    1.006431    3.476787    0.493506    0.082231    0.013548    0.590117    
#> 398: 0.547040    1.006386    3.476860    0.493467    0.082225    0.013555    0.590096    
#> 399: 0.547248    1.006313    3.476960    0.493683    0.082192    0.013564    0.590046    
#> 400: 0.547413    1.006207    3.477068    0.493424    0.082145    0.013559    0.590015    
#> 401: 0.547528    1.006219    3.477107    0.493318    0.082132    0.013558    0.590052    
#> 402: 0.547503    1.006252    3.477116    0.493025    0.082071    0.013559    0.590119    
#> 403: 0.547550    1.006243    3.477140    0.492529    0.082073    0.013553    0.590109    
#> 404: 0.547548    1.006219    3.477072    0.492354    0.082079    0.013552    0.590062    
#> 405: 0.547438    1.006279    3.477058    0.492194    0.082086    0.013550    0.590047    
#> 406: 0.547440    1.006318    3.477037    0.492224    0.082055    0.013553    0.590125    
#> 407: 0.547558    1.006361    3.477048    0.492265    0.082073    0.013547    0.590171    
#> 408: 0.547657    1.006518    3.477048    0.491953    0.082110    0.013541    0.590182    
#> 409: 0.547574    1.006515    3.477007    0.491717    0.082134    0.013526    0.590103    
#> 410: 0.547392    1.006571    3.476944    0.491392    0.082168    0.013516    0.590162    
#> 411: 0.547210    1.006475    3.476912    0.491036    0.082191    0.013501    0.590177    
#> 412: 0.547062    1.006514    3.476848    0.490973    0.082201    0.013485    0.590197    
#> 413: 0.547020    1.006496    3.476833    0.490993    0.082178    0.013481    0.590199    
#> 414: 0.546732    1.006403    3.476822    0.490740    0.082131    0.013466    0.590216    
#> 415: 0.546872    1.006274    3.476845    0.490621    0.082077    0.013457    0.590170    
#> 416: 0.547020    1.006275    3.476885    0.490690    0.082058    0.013452    0.590120    
#> 417: 0.547082    1.006338    3.476846    0.490666    0.082121    0.013451    0.590115    
#> 418: 0.547046    1.006333    3.476845    0.490642    0.082211    0.013440    0.590057    
#> 419: 0.546973    1.006451    3.476819    0.490765    0.082334    0.013434    0.589941    
#> 420: 0.546873    1.006562    3.476772    0.490622    0.082452    0.013419    0.589828    
#> 421: 0.546743    1.006639    3.476766    0.490299    0.082500    0.013404    0.589812    
#> 422: 0.546697    1.006599    3.476743    0.489864    0.082548    0.013384    0.589838    
#> 423: 0.546771    1.006483    3.476770    0.489758    0.082591    0.013380    0.589831    
#> 424: 0.546729    1.006399    3.476763    0.489564    0.082645    0.013361    0.589863    
#> 425: 0.546922    1.006367    3.476759    0.490019    0.082672    0.013343    0.589911    
#> 426: 0.547114    1.006468    3.476799    0.490374    0.082726    0.013332    0.589914    
#> 427: 0.547105    1.006466    3.476832    0.490293    0.082744    0.013325    0.589984    
#> 428: 0.547119    1.006475    3.476872    0.490068    0.082742    0.013321    0.589998    
#> 429: 0.547203    1.006496    3.476927    0.489732    0.082747    0.013320    0.590018    
#> 430: 0.547198    1.006542    3.476953    0.489446    0.082765    0.013321    0.590040    
#> 431: 0.547294    1.006523    3.476978    0.489406    0.082777    0.013320    0.589989    
#> 432: 0.547343    1.006550    3.476995    0.489676    0.082820    0.013323    0.589881    
#> 433: 0.547404    1.006583    3.477030    0.489519    0.082804    0.013314    0.589862    
#> 434: 0.547315    1.006522    3.477032    0.489250    0.082769    0.013308    0.589874    
#> 435: 0.547416    1.006585    3.477005    0.489153    0.082762    0.013297    0.589845    
#> 436: 0.547549    1.006553    3.477041    0.489155    0.082793    0.013297    0.589851    
#> 437: 0.547584    1.006577    3.477041    0.488901    0.082816    0.013289    0.589898    
#> 438: 0.547571    1.006641    3.476973    0.489075    0.082796    0.013289    0.589871    
#> 439: 0.547483    1.006729    3.476945    0.489117    0.082747    0.013281    0.589825    
#> 440: 0.547473    1.006772    3.476935    0.489164    0.082723    0.013278    0.589835    
#> 441: 0.547460    1.006726    3.476911    0.489012    0.082722    0.013267    0.589832    
#> 442: 0.547420    1.006792    3.476914    0.488836    0.082758    0.013256    0.589772    
#> 443: 0.547361    1.006827    3.476879    0.488533    0.082785    0.013238    0.589708    
#> 444: 0.547215    1.006911    3.476785    0.488350    0.082849    0.013224    0.589697    
#> 445: 0.546930    1.007040    3.476698    0.488347    0.082883    0.013212    0.589782    
#> 446: 0.546701    1.007162    3.476627    0.488271    0.082949    0.013208    0.589816    
#> 447: 0.546674    1.007169    3.476610    0.488289    0.082941    0.013212    0.589795    
#> 448: 0.546585    1.007124    3.476621    0.488107    0.082922    0.013212    0.589751    
#> 449: 0.546699    1.007170    3.476707    0.487960    0.082921    0.013217    0.589789    
#> 450: 0.546874    1.007119    3.476760    0.488117    0.082931    0.013226    0.589784    
#> 451: 0.546970    1.007092    3.476763    0.488487    0.082909    0.013227    0.589747    
#> 452: 0.547033    1.007143    3.476781    0.488367    0.082868    0.013231    0.589767    
#> 453: 0.547093    1.007142    3.476782    0.488360    0.082810    0.013235    0.589709    
#> 454: 0.547227    1.007235    3.476802    0.488628    0.082818    0.013236    0.589609    
#> 455: 0.547379    1.007236    3.476819    0.488790    0.082784    0.013241    0.589561    
#> 456: 0.547386    1.007215    3.476804    0.488712    0.082778    0.013238    0.589564    
#> 457: 0.547339    1.007179    3.476838    0.488654    0.082763    0.013236    0.589518    
#> 458: 0.547290    1.007239    3.476847    0.488676    0.082768    0.013223    0.589415    
#> 459: 0.547145    1.007327    3.476815    0.488741    0.082742    0.013215    0.589389    
#> 460: 0.547006    1.007333    3.476764    0.488764    0.082713    0.013212    0.589355    
#> 461: 0.546847    1.007362    3.476756    0.488690    0.082720    0.013204    0.589352    
#> 462: 0.546823    1.007327    3.476784    0.488528    0.082743    0.013203    0.589276    
#> 463: 0.546863    1.007340    3.476824    0.488406    0.082757    0.013213    0.589271    
#> 464: 0.546914    1.007364    3.476811    0.488536    0.082760    0.013210    0.589222    
#> 465: 0.546820    1.007240    3.476830    0.488388    0.082744    0.013204    0.589247    
#> 466: 0.546949    1.007264    3.476822    0.488505    0.082783    0.013197    0.589228    
#> 467: 0.546983    1.007195    3.476857    0.488673    0.082841    0.013184    0.589233    
#> 468: 0.547231    1.007156    3.476935    0.489300    0.082857    0.013184    0.589246    
#> 469: 0.547378    1.007254    3.476982    0.489635    0.082884    0.013184    0.589252    
#> 470: 0.547241    1.007303    3.476948    0.489839    0.082912    0.013185    0.589234    
#> 471: 0.547132    1.007258    3.476923    0.489754    0.082867    0.013190    0.589215    
#> 472: 0.547176    1.007228    3.476938    0.489842    0.082882    0.013189    0.589192    
#> 473: 0.547176    1.007231    3.476935    0.489858    0.082919    0.013186    0.589138    
#> 474: 0.547108    1.007209    3.476906    0.489768    0.082936    0.013186    0.589188    
#> 475: 0.547156    1.007247    3.476911    0.489751    0.082934    0.013180    0.589261    
#> 476: 0.547072    1.007260    3.476909    0.489812    0.082908    0.013187    0.589299    
#> 477: 0.547035    1.007267    3.476918    0.489936    0.082875    0.013187    0.589266    
#> 478: 0.546954    1.007287    3.476919    0.489853    0.082882    0.013190    0.589292    
#> 479: 0.546989    1.007344    3.476919    0.489803    0.082910    0.013193    0.589306    
#> 480: 0.547017    1.007365    3.476893    0.489911    0.082942    0.013186    0.589317    
#> 481: 0.547050    1.007373    3.476888    0.489887    0.082961    0.013181    0.589308    
#> 482: 0.547098    1.007330    3.476876    0.490062    0.082954    0.013178    0.589332    
#> 483: 0.547083    1.007275    3.476890    0.489921    0.082973    0.013167    0.589285    
#> 484: 0.547008    1.007069    3.476930    0.489817    0.082973    0.013160    0.589304    
#> 485: 0.547066    1.007018    3.476962    0.489836    0.082984    0.013162    0.589295    
#> 486: 0.547161    1.007018    3.476992    0.489726    0.082973    0.013155    0.589259    
#> 487: 0.547339    1.007006    3.477047    0.489713    0.083001    0.013147    0.589177    
#> 488: 0.547373    1.007051    3.477074    0.489697    0.083083    0.013134    0.589145    
#> 489: 0.547484    1.007032    3.477075    0.489763    0.083100    0.013125    0.589122    
#> 490: 0.547656    1.006998    3.477135    0.489805    0.083099    0.013127    0.589100    
#> 491: 0.547768    1.007023    3.477219    0.489802    0.083124    0.013132    0.589079    
#> 492: 0.547760    1.007039    3.477256    0.489505    0.083123    0.013132    0.589137    
#> 493: 0.547765    1.007032    3.477263    0.489603    0.083099    0.013141    0.589109    
#> 494: 0.547858    1.007078    3.477255    0.489502    0.083071    0.013148    0.589106    
#> 495: 0.547882    1.007106    3.477246    0.489431    0.083058    0.013147    0.589091    
#> 496: 0.548009    1.007224    3.477215    0.489559    0.083062    0.013154    0.589082    
#> 497: 0.547942    1.007185    3.477229    0.489504    0.083019    0.013164    0.589071    
#> 498: 0.547879    1.007162    3.477211    0.489431    0.083008    0.013168    0.589041    
#> 499: 0.547880    1.007153    3.477197    0.489228    0.083027    0.013165    0.589015    
#> 500: 0.547896    1.007114    3.477168    0.489150    0.083030    0.013163    0.589039    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.299428    0.971839    3.455406    0.392401    0.088821    0.016800    1.574843    
#> 002: 0.279879    0.985147    3.487949    0.372781    0.084380    0.015960    1.082488    
#> 003: 0.387849    0.966743    3.493327    0.354142    0.080161    0.015550    0.864033    
#> 004: 0.343735    0.988533    3.479318    0.336435    0.076153    0.014772    0.814841    
#> 005: 0.388064    1.020831    3.462480    0.319613    0.072345    0.014034    0.779831    
#> 006: 0.348135    1.026140    3.450750    0.303633    0.068728    0.013332    0.761697    
#> 007: 0.324744    1.010738    3.451380    0.288451    0.065292    0.013285    0.770031    
#> 008: 0.312911    1.008566    3.437953    0.274029    0.062027    0.012761    0.788082    
#> 009: 0.284616    1.015956    3.441504    0.260327    0.071639    0.014593    0.767127    
#> 010: 0.303008    1.020811    3.438104    0.247311    0.075330    0.015600    0.753724    
#> 011: 0.339384    1.013005    3.447856    0.274154    0.071563    0.018558    0.747305    
#> 012: 0.339898    1.017656    3.444297    0.260446    0.067985    0.017630    0.739364    
#> 013: 0.283983    1.034157    3.432249    0.247424    0.064586    0.018665    0.749555    
#> 014: 0.324159    1.038872    3.439367    0.273056    0.075835    0.017731    0.757205    
#> 015: 0.358725    1.040393    3.454775    0.274548    0.072043    0.016845    0.728358    
#> 016: 0.332421    1.034982    3.448367    0.301651    0.068441    0.016003    0.751530    
#> 017: 0.342374    1.040742    3.452185    0.286568    0.065019    0.015202    0.741830    
#> 018: 0.323945    1.064622    3.432504    0.272240    0.061768    0.014442    0.765296    
#> 019: 0.267396    1.065439    3.427578    0.258628    0.058680    0.013720    0.765397    
#> 020: 0.322186    1.051074    3.439841    0.245697    0.055746    0.015253    0.757844    
#> 021: 0.349897    1.036493    3.450424    0.261650    0.052958    0.014491    0.743890    
#> 022: 0.356007    1.026499    3.460842    0.287600    0.050310    0.014954    0.745003    
#> 023: 0.435710    1.021478    3.470907    0.276533    0.048363    0.014206    0.768525    
#> 024: 0.374211    1.049762    3.452294    0.262707    0.045945    0.013660    0.786020    
#> 025: 0.349966    1.037513    3.449619    0.255903    0.053695    0.012977    0.757206    
#> 026: 0.306957    1.081389    3.426052    0.252683    0.059149    0.015936    0.752038    
#> 027: 0.283221    1.098682    3.412421    0.253439    0.065027    0.015234    0.764917    
#> 028: 0.331154    1.067734    3.436640    0.296086    0.061776    0.014881    0.759553    
#> 029: 0.311641    1.056479    3.417679    0.281281    0.058687    0.014137    0.798935    
#> 030: 0.364081    1.062325    3.434421    0.288966    0.066577    0.013430    0.743393    
#> 031: 0.316004    1.051672    3.440533    0.274518    0.063248    0.014272    0.754917    
#> 032: 0.302788    1.039772    3.447483    0.260792    0.060085    0.015427    0.748744    
#> 033: 0.320126    1.038524    3.434448    0.310353    0.057081    0.017945    0.740909    
#> 034: 0.337287    1.047957    3.444317    0.351735    0.054227    0.017190    0.740002    
#> 035: 0.321416    1.024136    3.433998    0.334148    0.051516    0.016330    0.745271    
#> 036: 0.297202    1.046481    3.429924    0.317441    0.058264    0.015514    0.750505    
#> 037: 0.287892    1.061465    3.436897    0.301569    0.055350    0.014738    0.772331    
#> 038: 0.321503    1.048888    3.433262    0.286490    0.052583    0.018423    0.758864    
#> 039: 0.320254    1.050532    3.446988    0.272166    0.059593    0.017926    0.753015    
#> 040: 0.330294    1.051173    3.450956    0.258557    0.064470    0.018949    0.772218    
#> 041: 0.328246    1.039332    3.439832    0.245629    0.061247    0.019091    0.764533    
#> 042: 0.364048    1.024632    3.452088    0.305993    0.058184    0.020041    0.741058    
#> 043: 0.305101    1.063219    3.427344    0.290693    0.055275    0.019039    0.735099    
#> 044: 0.269081    1.050908    3.431259    0.276158    0.052511    0.019301    0.749557    
#> 045: 0.316174    1.056294    3.434670    0.262350    0.049886    0.022849    0.743665    
#> 046: 0.334597    1.042222    3.449851    0.250515    0.047391    0.021706    0.746790    
#> 047: 0.308323    1.038585    3.426880    0.272459    0.045022    0.020621    0.759811    
#> 048: 0.306510    1.036809    3.427500    0.269157    0.051571    0.019590    0.760770    
#> 049: 0.288592    1.043019    3.440358    0.255699    0.049539    0.020950    0.749218    
#> 050: 0.358578    1.029229    3.450345    0.286718    0.049686    0.023963    0.764151    
#> 051: 0.347477    1.024133    3.451662    0.272382    0.058631    0.022765    0.760250    
#> 052: 0.368044    1.033449    3.467296    0.258763    0.056129    0.021627    0.735724    
#> 053: 0.368605    0.999928    3.465346    0.285997    0.059968    0.020546    0.750338    
#> 054: 0.319769    1.024094    3.454868    0.271697    0.056969    0.020474    0.759315    
#> 055: 0.301477    1.037801    3.432642    0.258112    0.054121    0.019641    0.763430    
#> 056: 0.346218    1.037769    3.444622    0.321890    0.052922    0.018659    0.772153    
#> 057: 0.346751    1.025304    3.454985    0.320022    0.050276    0.017726    0.768104    
#> 058: 0.350010    1.048002    3.440677    0.304021    0.047762    0.020970    0.751774    
#> 059: 0.334037    1.008686    3.453563    0.288820    0.045374    0.025086    0.771537    
#> 060: 0.351843    0.981388    3.460723    0.274379    0.043105    0.027167    0.785643    
#> 061: 0.383174    0.975836    3.474483    0.290003    0.049276    0.025808    0.792501    
#> 062: 0.355447    1.017833    3.466148    0.275503    0.046919    0.024518    0.794539    
#> 063: 0.354186    0.993323    3.471570    0.261728    0.049123    0.023292    0.786863    
#> 064: 0.341290    1.017181    3.467408    0.248642    0.052312    0.022128    0.777819    
#> 065: 0.378478    1.000838    3.455307    0.236210    0.059114    0.021021    0.753214    
#> 066: 0.365660    1.027230    3.463594    0.247790    0.056158    0.019970    0.741489    
#> 067: 0.369421    1.010603    3.459571    0.262443    0.053350    0.018972    0.749659    
#> 068: 0.342325    1.017945    3.467012    0.249320    0.050683    0.021852    0.761985    
#> 069: 0.344633    1.019587    3.458245    0.301694    0.048148    0.028858    0.760410    
#> 070: 0.299030    1.030029    3.445507    0.286609    0.045741    0.029137    0.764794    
#> 071: 0.294768    1.056240    3.428631    0.274662    0.051273    0.032790    0.779873    
#> 072: 0.273796    1.036384    3.426340    0.300390    0.048710    0.031151    0.762996    
#> 073: 0.333539    1.049275    3.456493    0.286916    0.046274    0.029593    0.748553    
#> 074: 0.320019    1.030643    3.443893    0.272570    0.043960    0.028114    0.743341    
#> 075: 0.348422    1.014957    3.473074    0.258942    0.041762    0.026708    0.763942    
#> 076: 0.370459    1.023138    3.488169    0.246280    0.041955    0.028413    0.752818    
#> 077: 0.408212    0.999444    3.483414    0.250904    0.042778    0.026992    0.763844    
#> 078: 0.397244    0.987627    3.484911    0.239068    0.044687    0.025642    0.766582    
#> 079: 0.408885    0.994969    3.478841    0.267019    0.043030    0.024360    0.779794    
#> 080: 0.407637    0.998531    3.481767    0.281685    0.040878    0.028666    0.764662    
#> 081: 0.403056    1.005308    3.476463    0.286451    0.038834    0.028437    0.742828    
#> 082: 0.366986    1.002936    3.478178    0.272128    0.036893    0.027015    0.749646    
#> 083: 0.399233    0.991622    3.480610    0.258522    0.036087    0.032191    0.754260    
#> 084: 0.371604    0.998943    3.466603    0.299908    0.039395    0.030582    0.737008    
#> 085: 0.344747    1.020852    3.473559    0.284913    0.042598    0.029053    0.757888    
#> 086: 0.353630    1.019709    3.462152    0.270667    0.041294    0.027600    0.730746    
#> 087: 0.311828    1.038235    3.445835    0.257134    0.041048    0.026220    0.742034    
#> 088: 0.267456    1.029873    3.438841    0.336759    0.046550    0.024909    0.759382    
#> 089: 0.315690    1.059146    3.436744    0.319921    0.050765    0.023664    0.756097    
#> 090: 0.310239    1.051740    3.433587    0.327195    0.048227    0.022480    0.767319    
#> 091: 0.319005    1.049353    3.412336    0.356146    0.045815    0.023449    0.755366    
#> 092: 0.278827    1.086604    3.398619    0.361668    0.043525    0.022277    0.754285    
#> 093: 0.206999    1.086969    3.396260    0.362738    0.041348    0.021163    0.775786    
#> 094: 0.232184    1.088378    3.391515    0.344601    0.046544    0.020105    0.761316    
#> 095: 0.289929    1.056799    3.427228    0.327371    0.051474    0.019099    0.750666    
#> 096: 0.249845    1.053646    3.423468    0.311003    0.062648    0.018740    0.734966    
#> 097: 0.285706    1.068235    3.416390    0.295453    0.059516    0.017803    0.736554    
#> 098: 0.297176    1.085107    3.431730    0.283620    0.056540    0.019080    0.741703    
#> 099: 0.287548    1.070172    3.418701    0.279003    0.057351    0.018126    0.728174    
#> 100: 0.252856    1.072579    3.421295    0.265053    0.054484    0.018444    0.720750    
#> 101: 0.253966    1.051834    3.406934    0.251800    0.051760    0.018346    0.723560    
#> 102: 0.277515    1.048929    3.414702    0.275133    0.049172    0.017429    0.730862    
#> 103: 0.322215    1.046261    3.434171    0.283070    0.046713    0.018642    0.731475    
#> 104: 0.319038    1.044438    3.449140    0.291208    0.044377    0.021988    0.735751    
#> 105: 0.349464    1.034447    3.456132    0.276648    0.048931    0.020889    0.765112    
#> 106: 0.378012    1.031759    3.437150    0.284662    0.057169    0.020420    0.743555    
#> 107: 0.339685    1.040059    3.445660    0.270429    0.056694    0.019980    0.733654    
#> 108: 0.285527    1.047937    3.438468    0.256907    0.062487    0.018981    0.764173    
#> 109: 0.293988    1.050884    3.448691    0.252969    0.065482    0.018032    0.769504    
#> 110: 0.359388    1.023787    3.446669    0.240320    0.063823    0.017130    0.757230    
#> 111: 0.320057    1.037548    3.444944    0.241772    0.060632    0.016274    0.751405    
#> 112: 0.305751    1.021157    3.428798    0.229683    0.057600    0.015460    0.773389    
#> 113: 0.313112    1.048645    3.434486    0.228829    0.054720    0.014687    0.752491    
#> 114: 0.299054    1.050640    3.441513    0.220587    0.051984    0.016894    0.750582    
#> 115: 0.354592    1.029984    3.447159    0.247346    0.050753    0.017640    0.761532    
#> 116: 0.338918    1.040745    3.443214    0.256929    0.059124    0.016758    0.758935    
#> 117: 0.310562    1.064699    3.435252    0.244083    0.064774    0.015920    0.768431    
#> 118: 0.348852    1.039125    3.443606    0.231879    0.061919    0.018044    0.729228    
#> 119: 0.305998    1.034586    3.448633    0.220285    0.058823    0.023237    0.740340    
#> 120: 0.362031    1.025631    3.456068    0.220388    0.056675    0.022075    0.740425    
#> 121: 0.380984    1.051957    3.470844    0.214852    0.068113    0.020972    0.761716    
#> 122: 0.352811    1.006700    3.470526    0.241083    0.064707    0.019923    0.769694    
#> 123: 0.384571    1.043478    3.461952    0.282723    0.061472    0.018927    0.757492    
#> 124: 0.359180    1.058623    3.447547    0.268587    0.065475    0.017981    0.751324    
#> 125: 0.341547    1.029896    3.436909    0.264460    0.062201    0.017082    0.759268    
#> 126: 0.305355    1.052088    3.427426    0.251237    0.060531    0.016228    0.772594    
#> 127: 0.321664    1.054136    3.419711    0.282419    0.061070    0.015416    0.781565    
#> 128: 0.319507    1.039097    3.446871    0.320578    0.058017    0.014645    0.754690    
#> 129: 0.323938    1.039539    3.446200    0.304549    0.055116    0.013913    0.763180    
#> 130: 0.342578    1.062166    3.440033    0.289321    0.066953    0.013920    0.760116    
#> 131: 0.296891    1.050018    3.422566    0.274855    0.063606    0.017539    0.753945    
#> 132: 0.263385    1.059218    3.412200    0.261112    0.060425    0.016662    0.782262    
#> 133: 0.255079    1.045705    3.419029    0.249036    0.057404    0.016504    0.767069    
#> 134: 0.342479    1.028478    3.454617    0.236584    0.054534    0.018379    0.752935    
#> 135: 0.310459    1.026407    3.458236    0.236620    0.051807    0.022276    0.761474    
#> 136: 0.332286    1.015689    3.453115    0.224789    0.049217    0.021162    0.748660    
#> 137: 0.391299    1.003771    3.470806    0.224979    0.046756    0.020104    0.753085    
#> 138: 0.383492    1.023224    3.470768    0.258790    0.044418    0.023966    0.732685    
#> 139: 0.370028    1.025630    3.470651    0.245851    0.042197    0.024551    0.748042    
#> 140: 0.379703    1.032803    3.477482    0.303535    0.041401    0.031850    0.759246    
#> 141: 0.357516    1.012682    3.467377    0.288358    0.039331    0.030257    0.741299    
#> 142: 0.374922    1.010472    3.479140    0.273940    0.049749    0.028745    0.744508    
#> 143: 0.334942    1.016670    3.462084    0.260243    0.047261    0.027307    0.776291    
#> 144: 0.369275    1.031536    3.465211    0.290240    0.046020    0.025942    0.740422    
#> 145: 0.350575    1.040378    3.445825    0.283029    0.043719    0.024645    0.749167    
#> 146: 0.348213    1.028052    3.464865    0.289645    0.044720    0.023413    0.757861    
#> 147: 0.314040    1.014783    3.460592    0.275163    0.046934    0.022242    0.744960    
#> 148: 0.327219    1.022823    3.468297    0.271215    0.044587    0.021911    0.756521    
#> 149: 0.340042    1.018324    3.476369    0.257655    0.043687    0.020815    0.783837    
#> 150: 0.356112    1.015335    3.457903    0.251935    0.046082    0.019775    0.770561    
#> 151: 0.304631    1.048571    3.446594    0.239338    0.055238    0.018786    0.743895    
#> 152: 0.314514    1.033964    3.450925    0.230515    0.053926    0.017444    0.742265    
#> 153: 0.307097    1.067806    3.454597    0.221801    0.047701    0.018956    0.766816    
#> 154: 0.335269    1.041091    3.465872    0.235141    0.041333    0.023675    0.775829    
#> 155: 0.360079    1.000121    3.475071    0.253738    0.037003    0.023182    0.753952    
#> 156: 0.370508    1.023805    3.466178    0.215911    0.043980    0.019959    0.771029    
#> 157: 0.357675    1.018046    3.462464    0.237082    0.045990    0.022822    0.773460    
#> 158: 0.357387    1.027522    3.468213    0.212644    0.048478    0.025511    0.763119    
#> 159: 0.302845    1.051284    3.462382    0.262280    0.038655    0.022426    0.755568    
#> 160: 0.368651    0.999708    3.481900    0.215750    0.039902    0.022462    0.763437    
#> 161: 0.374561    1.011905    3.467831    0.242390    0.033627    0.025314    0.735567    
#> 162: 0.343920    1.044148    3.446518    0.227715    0.034988    0.021082    0.762755    
#> 163: 0.351138    1.031757    3.444256    0.248993    0.045908    0.023220    0.744661    
#> 164: 0.349350    1.038291    3.454367    0.224025    0.047016    0.024197    0.732801    
#> 165: 0.379335    1.037996    3.460540    0.217966    0.057993    0.017638    0.759593    
#> 166: 0.360566    1.068150    3.452894    0.195757    0.055242    0.019391    0.754101    
#> 167: 0.353296    1.053541    3.468341    0.208192    0.054200    0.019939    0.771558    
#> 168: 0.377282    1.048499    3.467893    0.218237    0.046238    0.022194    0.766714    
#> 169: 0.356604    1.069445    3.454388    0.230052    0.052058    0.015396    0.784998    
#> 170: 0.363561    1.049245    3.451847    0.252608    0.053037    0.013696    0.753723    
#> 171: 0.329152    1.055052    3.445237    0.234297    0.050375    0.012205    0.728061    
#> 172: 0.314610    1.059045    3.448149    0.216488    0.055443    0.015592    0.737981    
#> 173: 0.322386    1.073325    3.432539    0.175913    0.048563    0.018430    0.765051    
#> 174: 0.297350    1.060883    3.434893    0.193174    0.046854    0.019090    0.761070    
#> 175: 0.294498    1.059082    3.429260    0.218720    0.040692    0.017902    0.772850    
#> 176: 0.328867    1.072543    3.440943    0.273252    0.043261    0.019326    0.745220    
#> 177: 0.372993    1.049889    3.452720    0.265603    0.047957    0.018296    0.753302    
#> 178: 0.365431    1.033103    3.454768    0.264222    0.045444    0.020437    0.760057    
#> 179: 0.389587    1.047538    3.450094    0.248178    0.055509    0.020879    0.759773    
#> 180: 0.355876    1.030623    3.452017    0.299243    0.057402    0.017132    0.747426    
#> 181: 0.365101    1.003265    3.439855    0.288324    0.045063    0.014062    0.785286    
#> 182: 0.297540    1.018352    3.424514    0.262019    0.048075    0.015702    0.789859    
#> 183: 0.315789    1.044430    3.427540    0.242185    0.046765    0.016812    0.787888    
#> 184: 0.280325    1.058564    3.427922    0.239279    0.050393    0.015570    0.780273    
#> 185: 0.263918    1.065014    3.419577    0.220221    0.066558    0.013181    0.771498    
#> 186: 0.272030    1.068764    3.422433    0.211971    0.060571    0.017195    0.777045    
#> 187: 0.286027    1.041264    3.441569    0.206747    0.057226    0.018469    0.751016    
#> 188: 0.270102    1.090594    3.428373    0.229556    0.055450    0.015293    0.765516    
#> 189: 0.306783    1.098586    3.438323    0.304277    0.054804    0.015577    0.753269    
#> 190: 0.308980    1.082028    3.436605    0.380341    0.050070    0.015240    0.738649    
#> 191: 0.254393    1.077231    3.413522    0.278378    0.049286    0.014851    0.732466    
#> 192: 0.269362    1.060784    3.431384    0.271677    0.047490    0.019627    0.727452    
#> 193: 0.349061    1.063087    3.446315    0.269193    0.048522    0.021424    0.723528    
#> 194: 0.315132    1.048278    3.429190    0.253404    0.048479    0.020121    0.762477    
#> 195: 0.315943    1.030678    3.431235    0.261778    0.040878    0.024045    0.767842    
#> 196: 0.303131    1.034146    3.447294    0.224690    0.042402    0.023744    0.762441    
#> 197: 0.289153    1.055130    3.460986    0.192044    0.046628    0.022099    0.770433    
#> 198: 0.350343    1.033411    3.461624    0.184768    0.047434    0.020787    0.761220    
#> 199: 0.326556    1.027592    3.452100    0.227714    0.036310    0.021787    0.761223    
#> 200: 0.330383    1.031118    3.449926    0.235584    0.037616    0.024708    0.760452    
#> 201: 0.324514    1.030927    3.454680    0.230527    0.038403    0.025377    0.761013    
#> 202: 0.333134    1.034494    3.453982    0.216154    0.037942    0.025501    0.760785    
#> 203: 0.341569    1.031405    3.452885    0.211356    0.039312    0.024512    0.758118    
#> 204: 0.348813    1.029591    3.456292    0.211271    0.041716    0.023228    0.755124    
#> 205: 0.350587    1.034871    3.458197    0.212141    0.042159    0.022811    0.758390    
#> 206: 0.350641    1.037848    3.459378    0.210948    0.040820    0.023124    0.763284    
#> 207: 0.347118    1.039650    3.456128    0.216735    0.040053    0.023209    0.762931    
#> 208: 0.346912    1.039950    3.455565    0.221457    0.039205    0.023440    0.762683    
#> 209: 0.343973    1.039425    3.453241    0.220840    0.039192    0.023611    0.763361    
#> 210: 0.342969    1.039038    3.453441    0.222788    0.039710    0.023498    0.761433    
#> 211: 0.343352    1.039929    3.454319    0.221668    0.040017    0.023258    0.761350    
#> 212: 0.344621    1.040371    3.454347    0.223876    0.040826    0.022720    0.761145    
#> 213: 0.346441    1.037764    3.455021    0.228559    0.042125    0.022523    0.761054    
#> 214: 0.350004    1.036815    3.455439    0.229982    0.043288    0.022382    0.760063    
#> 215: 0.350195    1.036600    3.456260    0.233421    0.043719    0.022629    0.759472    
#> 216: 0.351296    1.034202    3.457265    0.233810    0.043720    0.022731    0.760883    
#> 217: 0.352822    1.033946    3.457954    0.230344    0.043794    0.022700    0.761154    
#> 218: 0.354656    1.033673    3.458057    0.229658    0.044148    0.022362    0.761487    
#> 219: 0.355452    1.033071    3.457801    0.229610    0.044003    0.022539    0.761246    
#> 220: 0.354478    1.033385    3.458057    0.231477    0.044347    0.022492    0.760473    
#> 221: 0.354428    1.033281    3.458260    0.234159    0.044694    0.022398    0.759632    
#> 222: 0.354120    1.032663    3.458139    0.237468    0.044652    0.022454    0.759738    
#> 223: 0.355295    1.032412    3.458238    0.237948    0.044469    0.022358    0.759219    
#> 224: 0.356254    1.032745    3.458494    0.236450    0.044164    0.022271    0.758987    
#> 225: 0.355902    1.031188    3.458866    0.235761    0.044002    0.022458    0.758889    
#> 226: 0.355931    1.030100    3.458491    0.235680    0.043964    0.022353    0.759238    
#> 227: 0.355318    1.030328    3.458348    0.235477    0.043745    0.022397    0.758993    
#> 228: 0.353693    1.031274    3.457502    0.234916    0.043654    0.022448    0.758988    
#> 229: 0.352399    1.031264    3.456897    0.233592    0.043651    0.022445    0.758334    
#> 230: 0.350947    1.030932    3.456372    0.231849    0.043607    0.022470    0.758361    
#> 231: 0.349920    1.031327    3.456218    0.230360    0.043619    0.022343    0.758395    
#> 232: 0.348184    1.031308    3.456216    0.230496    0.043539    0.022428    0.758121    
#> 233: 0.347413    1.030325    3.456227    0.229526    0.043622    0.022374    0.758492    
#> 234: 0.346485    1.030457    3.456159    0.229987    0.043778    0.022360    0.758643    
#> 235: 0.346346    1.029964    3.455932    0.230186    0.043844    0.022338    0.758666    
#> 236: 0.346092    1.030235    3.455428    0.230326    0.043947    0.022389    0.759132    
#> 237: 0.347318    1.029847    3.455613    0.230238    0.043899    0.022600    0.760003    
#> 238: 0.348785    1.029201    3.455930    0.231028    0.043631    0.022831    0.760204    
#> 239: 0.348851    1.029379    3.456307    0.230673    0.043530    0.022995    0.760088    
#> 240: 0.348636    1.029296    3.456526    0.230238    0.043624    0.023014    0.760058    
#> 241: 0.348351    1.028819    3.456384    0.230080    0.043525    0.022948    0.760066    
#> 242: 0.347586    1.028616    3.455948    0.230719    0.043496    0.022948    0.760324    
#> 243: 0.346562    1.029418    3.455648    0.230937    0.043746    0.022860    0.760406    
#> 244: 0.345317    1.029535    3.455693    0.231074    0.043804    0.022868    0.760787    
#> 245: 0.345605    1.029075    3.455874    0.231373    0.043767    0.022903    0.761033    
#> 246: 0.345545    1.028717    3.456181    0.230806    0.043681    0.023004    0.760954    
#> 247: 0.345440    1.028416    3.456474    0.230254    0.043674    0.023016    0.760791    
#> 248: 0.345067    1.029041    3.456323    0.230192    0.043742    0.022983    0.760685    
#> 249: 0.344296    1.029368    3.456041    0.231392    0.043644    0.023057    0.760353    
#> 250: 0.344320    1.029597    3.456056    0.231557    0.043520    0.023076    0.760618    
#> 251: 0.344850    1.029991    3.456344    0.232378    0.043408    0.023115    0.761003    
#> 252: 0.345203    1.030056    3.456571    0.233395    0.043350    0.023181    0.761167    
#> 253: 0.345469    1.029882    3.456595    0.235077    0.043200    0.023153    0.761313    
#> 254: 0.345945    1.030203    3.456832    0.236252    0.043076    0.023152    0.761219    
#> 255: 0.346546    1.030154    3.456980    0.237039    0.043000    0.023068    0.761311    
#> 256: 0.346189    1.029700    3.457037    0.237774    0.043032    0.023068    0.761223    
#> 257: 0.345940    1.029232    3.456955    0.237349    0.043199    0.023126    0.761018    
#> 258: 0.345506    1.028709    3.456941    0.237154    0.043197    0.023126    0.760749    
#> 259: 0.345096    1.028585    3.456918    0.237585    0.043160    0.023166    0.760606    
#> 260: 0.345079    1.028696    3.457252    0.236830    0.043180    0.023160    0.760582    
#> 261: 0.345451    1.028380    3.457532    0.236037    0.043163    0.023096    0.761115    
#> 262: 0.345893    1.028634    3.457699    0.235417    0.043186    0.023044    0.761471    
#> 263: 0.345568    1.029135    3.457697    0.236043    0.043220    0.022992    0.761813    
#> 264: 0.345514    1.029168    3.457774    0.236461    0.043314    0.022967    0.762112    
#> 265: 0.345198    1.029182    3.457827    0.235666    0.043398    0.022986    0.762647    
#> 266: 0.344964    1.029441    3.457705    0.235154    0.043451    0.023063    0.762694    
#> 267: 0.344906    1.029639    3.457687    0.235942    0.043466    0.023163    0.762675    
#> 268: 0.344310    1.029599    3.457283    0.235701    0.043474    0.023139    0.762375    
#> 269: 0.344199    1.029518    3.457162    0.235450    0.043502    0.023158    0.761996    
#> 270: 0.344568    1.029366    3.457250    0.235063    0.043374    0.023127    0.761995    
#> 271: 0.344407    1.029193    3.457103    0.235468    0.043280    0.023125    0.761901    
#> 272: 0.344346    1.028967    3.457087    0.236001    0.043367    0.023060    0.761980    
#> 273: 0.344287    1.029132    3.457196    0.235959    0.043538    0.023054    0.762161    
#> 274: 0.344261    1.029152    3.457242    0.235427    0.043533    0.023068    0.761799    
#> 275: 0.344137    1.029402    3.457129    0.235152    0.043593    0.023060    0.761438    
#> 276: 0.344029    1.029406    3.457108    0.235044    0.043713    0.023064    0.761250    
#> 277: 0.343643    1.029690    3.457063    0.234752    0.043727    0.023104    0.761013    
#> 278: 0.343447    1.029856    3.457059    0.234842    0.043640    0.023134    0.760980    
#> 279: 0.343354    1.029630    3.457078    0.235450    0.043469    0.023140    0.761032    
#> 280: 0.343431    1.029516    3.457163    0.235998    0.043330    0.023172    0.760738    
#> 281: 0.343144    1.029375    3.457288    0.236096    0.043341    0.023196    0.760600    
#> 282: 0.343345    1.029331    3.457420    0.235795    0.043333    0.023195    0.760645    
#> 283: 0.343531    1.029347    3.457524    0.236039    0.043485    0.023149    0.760658    
#> 284: 0.343593    1.029158    3.457665    0.236154    0.043485    0.023071    0.760385    
#> 285: 0.343727    1.029258    3.457613    0.235992    0.043486    0.023044    0.760382    
#> 286: 0.343881    1.029204    3.457629    0.236501    0.043428    0.023040    0.760297    
#> 287: 0.343778    1.029267    3.457519    0.236699    0.043414    0.023034    0.760182    
#> 288: 0.344125    1.029088    3.457597    0.237060    0.043357    0.023048    0.760248    
#> 289: 0.344305    1.029018    3.457713    0.237325    0.043500    0.023033    0.760190    
#> 290: 0.344702    1.029086    3.457725    0.237370    0.043804    0.022985    0.760265    
#> 291: 0.345017    1.029333    3.457800    0.237263    0.043898    0.022910    0.760138    
#> 292: 0.344803    1.029420    3.457779    0.237666    0.043939    0.022901    0.760016    
#> 293: 0.344489    1.029661    3.457589    0.237662    0.043897    0.022835    0.760024    
#> 294: 0.343808    1.029940    3.457228    0.237988    0.043884    0.022801    0.759929    
#> 295: 0.343448    1.029905    3.457020    0.237784    0.043965    0.022786    0.759975    
#> 296: 0.343357    1.029813    3.457020    0.237855    0.044069    0.022720    0.760129    
#> 297: 0.343575    1.029728    3.457003    0.238212    0.044083    0.022673    0.760285    
#> 298: 0.343766    1.029544    3.457005    0.237919    0.044144    0.022628    0.760075    
#> 299: 0.343639    1.029709    3.456905    0.237789    0.044087    0.022639    0.759874    
#> 300: 0.343593    1.029766    3.456865    0.238131    0.044038    0.022664    0.759760    
#> 301: 0.343716    1.029731    3.456660    0.237873    0.043933    0.022673    0.759911    
#> 302: 0.343625    1.029764    3.456558    0.237611    0.043778    0.022656    0.759951    
#> 303: 0.343334    1.029875    3.456407    0.237322    0.043644    0.022604    0.759877    
#> 304: 0.343226    1.030162    3.456247    0.237145    0.043673    0.022540    0.759906    
#> 305: 0.342917    1.030063    3.456099    0.237213    0.043645    0.022483    0.759880    
#> 306: 0.342570    1.030043    3.456033    0.237299    0.043653    0.022488    0.759777    
#> 307: 0.342189    1.030021    3.455890    0.237117    0.043558    0.022467    0.759961    
#> 308: 0.341648    1.030078    3.455783    0.236945    0.043391    0.022501    0.760232    
#> 309: 0.341721    1.029970    3.455707    0.237171    0.043320    0.022526    0.760128    
#> 310: 0.341791    1.029890    3.455576    0.237103    0.043255    0.022527    0.760329    
#> 311: 0.341647    1.029959    3.455573    0.236923    0.043240    0.022547    0.760226    
#> 312: 0.341219    1.030078    3.455345    0.236703    0.043203    0.022620    0.760245    
#> 313: 0.340814    1.030143    3.455116    0.236741    0.043156    0.022661    0.760151    
#> 314: 0.340509    1.030220    3.454914    0.236941    0.043065    0.022669    0.760093    
#> 315: 0.340236    1.030331    3.454835    0.236997    0.043084    0.022637    0.760088    
#> 316: 0.339967    1.030542    3.454684    0.237341    0.043254    0.022591    0.760089    
#> 317: 0.339552    1.030631    3.454603    0.237513    0.043480    0.022519    0.760271    
#> 318: 0.339634    1.030612    3.454498    0.237515    0.043654    0.022478    0.760103    
#> 319: 0.339878    1.030456    3.454613    0.237100    0.043712    0.022503    0.760129    
#> 320: 0.339445    1.030321    3.454527    0.236652    0.043808    0.022498    0.760284    
#> 321: 0.339089    1.030209    3.454444    0.236522    0.043798    0.022494    0.760470    
#> 322: 0.338833    1.030179    3.454282    0.236731    0.043793    0.022512    0.760427    
#> 323: 0.338443    1.030268    3.454167    0.236907    0.043838    0.022523    0.760336    
#> 324: 0.338760    1.030362    3.454227    0.237466    0.043839    0.022544    0.760153    
#> 325: 0.338579    1.030591    3.454121    0.237571    0.043792    0.022505    0.760042    
#> 326: 0.338438    1.030523    3.454010    0.237809    0.043726    0.022497    0.759983    
#> 327: 0.338525    1.030591    3.453995    0.237822    0.043564    0.022526    0.760067    
#> 328: 0.338543    1.030638    3.453951    0.238142    0.043496    0.022531    0.759885    
#> 329: 0.338597    1.030767    3.453935    0.238125    0.043396    0.022515    0.759837    
#> 330: 0.338268    1.030853    3.453857    0.238224    0.043389    0.022460    0.759856    
#> 331: 0.338368    1.030954    3.453829    0.238562    0.043383    0.022439    0.759804    
#> 332: 0.338232    1.031030    3.453845    0.238642    0.043427    0.022408    0.759836    
#> 333: 0.337903    1.031132    3.453646    0.239082    0.043378    0.022392    0.759851    
#> 334: 0.337509    1.031085    3.453415    0.239193    0.043363    0.022377    0.759863    
#> 335: 0.337212    1.031160    3.453225    0.239027    0.043278    0.022345    0.759930    
#> 336: 0.336965    1.031319    3.453195    0.238962    0.043227    0.022357    0.759990    
#> 337: 0.336866    1.031621    3.453051    0.238933    0.043272    0.022348    0.759868    
#> 338: 0.336662    1.031767    3.453036    0.239021    0.043327    0.022357    0.759816    
#> 339: 0.336387    1.031956    3.452884    0.238995    0.043398    0.022342    0.759706    
#> 340: 0.336208    1.031927    3.452757    0.239195    0.043477    0.022334    0.759642    
#> 341: 0.336320    1.031907    3.452795    0.239326    0.043489    0.022317    0.759568    
#> 342: 0.336093    1.031737    3.452783    0.239560    0.043458    0.022299    0.759616    
#> 343: 0.335865    1.031939    3.452831    0.239501    0.043484    0.022268    0.759500    
#> 344: 0.335843    1.032039    3.452879    0.239545    0.043524    0.022254    0.759457    
#> 345: 0.336001    1.032077    3.452925    0.239824    0.043609    0.022228    0.759337    
#> 346: 0.335876    1.032222    3.452844    0.240199    0.043634    0.022194    0.759289    
#> 347: 0.336018    1.032144    3.452722    0.240424    0.043672    0.022185    0.759384    
#> 348: 0.335743    1.032242    3.452573    0.240561    0.043673    0.022153    0.759532    
#> 349: 0.335738    1.032215    3.452505    0.240907    0.043695    0.022106    0.759530    
#> 350: 0.335647    1.032169    3.452403    0.241098    0.043795    0.022107    0.759429    
#> 351: 0.335530    1.032423    3.452264    0.241484    0.043922    0.022101    0.759291    
#> 352: 0.335223    1.032521    3.452182    0.241735    0.043945    0.022124    0.759379    
#> 353: 0.335110    1.032638    3.452088    0.242099    0.044052    0.022140    0.759278    
#> 354: 0.335049    1.032700    3.451914    0.242151    0.044118    0.022155    0.759238    
#> 355: 0.335327    1.032529    3.451913    0.242361    0.044182    0.022114    0.759190    
#> 356: 0.335435    1.032399    3.452000    0.242867    0.044280    0.022068    0.759464    
#> 357: 0.335711    1.032359    3.452044    0.243113    0.044278    0.022020    0.759429    
#> 358: 0.335930    1.032389    3.452106    0.243127    0.044254    0.022006    0.759406    
#> 359: 0.335943    1.032559    3.452079    0.243325    0.044280    0.021974    0.759324    
#> 360: 0.335624    1.032676    3.451861    0.243222    0.044276    0.021963    0.759252    
#> 361: 0.335327    1.032877    3.451712    0.243309    0.044303    0.021936    0.759112    
#> 362: 0.335106    1.032894    3.451614    0.243341    0.044308    0.021929    0.758922    
#> 363: 0.334968    1.032820    3.451610    0.243240    0.044302    0.021901    0.758758    
#> 364: 0.335103    1.032794    3.451608    0.243142    0.044250    0.021883    0.758824    
#> 365: 0.335108    1.032847    3.451617    0.243117    0.044350    0.021895    0.758869    
#> 366: 0.334886    1.032945    3.451482    0.243016    0.044380    0.021913    0.758916    
#> 367: 0.334865    1.032987    3.451424    0.243078    0.044333    0.021907    0.758797    
#> 368: 0.335187    1.033032    3.451430    0.243718    0.044353    0.021925    0.758601    
#> 369: 0.335346    1.032938    3.451475    0.244124    0.044310    0.021951    0.758599    
#> 370: 0.335285    1.033031    3.451418    0.244148    0.044365    0.021998    0.758570    
#> 371: 0.335042    1.033129    3.451231    0.244246    0.044365    0.022029    0.758429    
#> 372: 0.334935    1.033223    3.451126    0.244247    0.044350    0.022045    0.758302    
#> 373: 0.334576    1.033422    3.450990    0.244509    0.044366    0.022042    0.758299    
#> 374: 0.334485    1.033443    3.450898    0.244708    0.044347    0.022045    0.758258    
#> 375: 0.334345    1.033447    3.450790    0.244925    0.044293    0.022049    0.758345    
#> 376: 0.334143    1.033529    3.450714    0.244844    0.044295    0.022062    0.758291    
#> 377: 0.333930    1.033677    3.450711    0.244849    0.044373    0.022044    0.758229    
#> 378: 0.333803    1.033622    3.450662    0.244944    0.044390    0.022048    0.758268    
#> 379: 0.333795    1.033491    3.450683    0.244901    0.044372    0.022058    0.758292    
#> 380: 0.333641    1.033431    3.450662    0.244669    0.044404    0.022098    0.758257    
#> 381: 0.333555    1.033397    3.450673    0.244926    0.044410    0.022137    0.758259    
#> 382: 0.333599    1.033341    3.450661    0.245166    0.044363    0.022154    0.758196    
#> 383: 0.333639    1.033298    3.450650    0.245455    0.044375    0.022152    0.758052    
#> 384: 0.333440    1.033418    3.450618    0.245586    0.044421    0.022162    0.757917    
#> 385: 0.333542    1.033495    3.450612    0.245828    0.044459    0.022163    0.757855    
#> 386: 0.333516    1.033730    3.450604    0.245927    0.044587    0.022147    0.757787    
#> 387: 0.333658    1.033842    3.450615    0.245912    0.044659    0.022119    0.757636    
#> 388: 0.333733    1.033826    3.450641    0.245908    0.044690    0.022086    0.757597    
#> 389: 0.333598    1.033734    3.450571    0.245802    0.044725    0.022048    0.757646    
#> 390: 0.333368    1.033750    3.450447    0.245900    0.044722    0.022013    0.757619    
#> 391: 0.333489    1.033743    3.450473    0.245816    0.044722    0.022017    0.757588    
#> 392: 0.333640    1.033768    3.450558    0.245807    0.044751    0.022019    0.757559    
#> 393: 0.333584    1.033803    3.450503    0.245808    0.044809    0.022010    0.757463    
#> 394: 0.333686    1.033897    3.450454    0.246329    0.044835    0.022001    0.757350    
#> 395: 0.333912    1.034047    3.450447    0.246736    0.044919    0.021992    0.757313    
#> 396: 0.334154    1.034117    3.450505    0.246804    0.044983    0.021982    0.757218    
#> 397: 0.334315    1.034133    3.450579    0.246833    0.045040    0.022001    0.757165    
#> 398: 0.334459    1.034117    3.450633    0.246819    0.045047    0.022018    0.757138    
#> 399: 0.334630    1.034138    3.450728    0.246771    0.045065    0.022036    0.757122    
#> 400: 0.334818    1.034162    3.450768    0.246704    0.045061    0.022029    0.757120    
#> 401: 0.334880    1.034269    3.450738    0.246642    0.045073    0.022037    0.757191    
#> 402: 0.334717    1.034363    3.450686    0.246587    0.045132    0.022022    0.757176    
#> 403: 0.334944    1.034336    3.450703    0.246368    0.045150    0.021996    0.757306    
#> 404: 0.335012    1.034359    3.450669    0.246269    0.045213    0.021987    0.757284    
#> 405: 0.335098    1.034300    3.450726    0.246087    0.045223    0.021980    0.757306    
#> 406: 0.335369    1.034283    3.450792    0.246063    0.045317    0.022001    0.757310    
#> 407: 0.335539    1.034314    3.450874    0.246159    0.045324    0.021994    0.757318    
#> 408: 0.335598    1.034411    3.450927    0.245934    0.045341    0.021974    0.757542    
#> 409: 0.335679    1.034378    3.450900    0.245974    0.045285    0.021948    0.757635    
#> 410: 0.335630    1.034362    3.450854    0.245987    0.045291    0.021939    0.757670    
#> 411: 0.335506    1.034214    3.450789    0.245866    0.045316    0.021929    0.757782    
#> 412: 0.335306    1.034292    3.450677    0.245826    0.045335    0.021914    0.757852    
#> 413: 0.335119    1.034410    3.450573    0.245932    0.045330    0.021885    0.757824    
#> 414: 0.334809    1.034511    3.450524    0.245797    0.045350    0.021888    0.757813    
#> 415: 0.334830    1.034583    3.450455    0.245851    0.045369    0.021882    0.757712    
#> 416: 0.334901    1.034676    3.450448    0.246183    0.045330    0.021890    0.757653    
#> 417: 0.334818    1.034668    3.450385    0.246352    0.045321    0.021873    0.757670    
#> 418: 0.334722    1.034695    3.450390    0.246471    0.045283    0.021870    0.757665    
#> 419: 0.334665    1.034768    3.450353    0.246474    0.045234    0.021850    0.757743    
#> 420: 0.334786    1.034764    3.450353    0.246530    0.045256    0.021833    0.757668    
#> 421: 0.334736    1.034730    3.450421    0.246405    0.045250    0.021815    0.757627    
#> 422: 0.334892    1.034626    3.450457    0.246231    0.045260    0.021790    0.757609    
#> 423: 0.335149    1.034513    3.450523    0.246335    0.045303    0.021776    0.757550    
#> 424: 0.335260    1.034436    3.450524    0.246525    0.045357    0.021747    0.757548    
#> 425: 0.335519    1.034436    3.450513    0.246977    0.045421    0.021735    0.757502    
#> 426: 0.335607    1.034518    3.450504    0.247351    0.045450    0.021728    0.757368    
#> 427: 0.335524    1.034506    3.450500    0.247288    0.045439    0.021684    0.757330    
#> 428: 0.335373    1.034561    3.450531    0.247189    0.045464    0.021650    0.757402    
#> 429: 0.335349    1.034580    3.450520    0.247132    0.045465    0.021619    0.757462    
#> 430: 0.335273    1.034636    3.450449    0.246986    0.045469    0.021587    0.757416    
#> 431: 0.335090    1.034678    3.450375    0.246972    0.045480    0.021560    0.757395    
#> 432: 0.335117    1.034727    3.450406    0.247285    0.045528    0.021551    0.757416    
#> 433: 0.335217    1.034801    3.450460    0.247385    0.045600    0.021553    0.757350    
#> 434: 0.335076    1.034658    3.450466    0.247368    0.045653    0.021546    0.757312    
#> 435: 0.335198    1.034575    3.450474    0.247457    0.045661    0.021535    0.757240    
#> 436: 0.335162    1.034540    3.450502    0.247553    0.045696    0.021523    0.757206    
#> 437: 0.335030    1.034605    3.450457    0.247418    0.045707    0.021518    0.757139    
#> 438: 0.334952    1.034700    3.450430    0.247416    0.045696    0.021528    0.757054    
#> 439: 0.334972    1.034717    3.450426    0.247241    0.045673    0.021542    0.757005    
#> 440: 0.334941    1.034704    3.450466    0.247327    0.045653    0.021540    0.757010    
#> 441: 0.334931    1.034636    3.450500    0.247358    0.045633    0.021557    0.756973    
#> 442: 0.334779    1.034681    3.450507    0.247217    0.045630    0.021564    0.756966    
#> 443: 0.334800    1.034756    3.450466    0.247080    0.045572    0.021581    0.756973    
#> 444: 0.334729    1.034833    3.450381    0.247026    0.045519    0.021620    0.757026    
#> 445: 0.334672    1.034834    3.450333    0.247054    0.045450    0.021651    0.757065    
#> 446: 0.334476    1.034898    3.450277    0.247023    0.045363    0.021668    0.757095    
#> 447: 0.334518    1.034941    3.450276    0.247111    0.045292    0.021703    0.757102    
#> 448: 0.334328    1.035158    3.450231    0.247037    0.045313    0.021724    0.757105    
#> 449: 0.334214    1.035290    3.450247    0.246901    0.045305    0.021734    0.757202    
#> 450: 0.334271    1.035323    3.450261    0.246949    0.045326    0.021729    0.757207    
#> 451: 0.334420    1.035370    3.450233    0.247159    0.045338    0.021734    0.757225    
#> 452: 0.334350    1.035431    3.450164    0.247202    0.045334    0.021725    0.757231    
#> 453: 0.334259    1.035493    3.450128    0.247008    0.045362    0.021722    0.757212    
#> 454: 0.334325    1.035589    3.450087    0.247279    0.045372    0.021729    0.757141    
#> 455: 0.334278    1.035639    3.450013    0.247593    0.045417    0.021726    0.757101    
#> 456: 0.334084    1.035648    3.449967    0.247673    0.045476    0.021719    0.757068    
#> 457: 0.334104    1.035646    3.449994    0.247720    0.045531    0.021696    0.757034    
#> 458: 0.334080    1.035752    3.450056    0.247744    0.045557    0.021683    0.757032    
#> 459: 0.333994    1.035863    3.450054    0.247676    0.045599    0.021673    0.757101    
#> 460: 0.333974    1.035883    3.450040    0.247596    0.045630    0.021678    0.757096    
#> 461: 0.334002    1.035883    3.450063    0.247616    0.045631    0.021689    0.757084    
#> 462: 0.333853    1.035971    3.450027    0.247579    0.045627    0.021674    0.757082    
#> 463: 0.333832    1.036028    3.450035    0.247673    0.045638    0.021668    0.757159    
#> 464: 0.333838    1.036075    3.450018    0.247677    0.045653    0.021672    0.757168    
#> 465: 0.333798    1.035991    3.450024    0.247653    0.045662    0.021663    0.757168    
#> 466: 0.333832    1.036081    3.449934    0.247831    0.045677    0.021668    0.757138    
#> 467: 0.333819    1.036106    3.449908    0.248115    0.045657    0.021675    0.757031    
#> 468: 0.333890    1.036150    3.449921    0.248570    0.045621    0.021694    0.756965    
#> 469: 0.333857    1.036277    3.449918    0.248747    0.045603    0.021708    0.756987    
#> 470: 0.333817    1.036346    3.449864    0.248895    0.045549    0.021734    0.756922    
#> 471: 0.333712    1.036421    3.449797    0.249007    0.045548    0.021738    0.756798    
#> 472: 0.333758    1.036486    3.449788    0.249079    0.045520    0.021746    0.756787    
#> 473: 0.333734    1.036531    3.449772    0.249077    0.045529    0.021756    0.756734    
#> 474: 0.333652    1.036570    3.449739    0.249036    0.045518    0.021776    0.756728    
#> 475: 0.333583    1.036739    3.449659    0.248934    0.045552    0.021774    0.756788    
#> 476: 0.333540    1.036743    3.449607    0.248766    0.045523    0.021787    0.756856    
#> 477: 0.333529    1.036810    3.449620    0.248748    0.045488    0.021818    0.756766    
#> 478: 0.333494    1.036826    3.449625    0.248763    0.045449    0.021832    0.756692    
#> 479: 0.333502    1.036861    3.449621    0.248707    0.045431    0.021837    0.756739    
#> 480: 0.333517    1.036959    3.449582    0.248864    0.045407    0.021855    0.756744    
#> 481: 0.333569    1.036944    3.449605    0.248824    0.045360    0.021871    0.756691    
#> 482: 0.333668    1.036893    3.449619    0.248849    0.045345    0.021880    0.756713    
#> 483: 0.333705    1.036817    3.449652    0.248872    0.045345    0.021892    0.756665    
#> 484: 0.333845    1.036692    3.449698    0.248781    0.045388    0.021908    0.756584    
#> 485: 0.333968    1.036681    3.449737    0.248841    0.045435    0.021905    0.756516    
#> 486: 0.334013    1.036679    3.449796    0.248754    0.045447    0.021902    0.756484    
#> 487: 0.334383    1.036746    3.449888    0.248877    0.045442    0.021906    0.756480    
#> 488: 0.334532    1.036704    3.449961    0.249046    0.045457    0.021911    0.756416    
#> 489: 0.334684    1.036652    3.449982    0.249025    0.045497    0.021907    0.756488    
#> 490: 0.334831    1.036668    3.450038    0.249081    0.045500    0.021909    0.756556    
#> 491: 0.334926    1.036695    3.450073    0.249138    0.045494    0.021904    0.756547    
#> 492: 0.334867    1.036730    3.450050    0.248986    0.045504    0.021911    0.756621    
#> 493: 0.334706    1.036812    3.450002    0.249106    0.045520    0.021915    0.756654    
#> 494: 0.334723    1.036892    3.449926    0.249153    0.045524    0.021922    0.756670    
#> 495: 0.334705    1.036934    3.449912    0.249196    0.045538    0.021931    0.756573    
#> 496: 0.334808    1.037005    3.449874    0.249387    0.045525    0.021937    0.756547    
#> 497: 0.334732    1.037022    3.449825    0.249497    0.045539    0.021941    0.756561    
#> 498: 0.334611    1.037049    3.449736    0.249446    0.045521    0.021953    0.756570    
#> 499: 0.334585    1.037125    3.449650    0.249598    0.045525    0.021947    0.756514    
#> 500: 0.334628    1.037082    3.449653    0.249630    0.045498    0.021936    0.756493    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.325774    0.985431    3.445237    0.392401    0.082588    0.016800    1.895926    
#> 002: 0.305877    1.048901    3.459182    0.372781    0.078458    0.017183    1.339928    
#> 003: 0.442453    0.953137    3.485997    0.354142    0.074535    0.016323    1.009050    
#> 004: 0.433442    0.950489    3.484413    0.336435    0.074920    0.016572    0.883765    
#> 005: 0.464259    0.990737    3.465193    0.319613    0.079313    0.016782    0.841134    
#> 006: 0.434324    1.001818    3.458994    0.303633    0.096832    0.018112    0.764923    
#> 007: 0.409119    0.976917    3.459591    0.288451    0.101168    0.019573    0.755594    
#> 008: 0.397143    0.989988    3.454864    0.274029    0.111692    0.025992    0.741277    
#> 009: 0.390029    0.971955    3.454652    0.260327    0.106107    0.024692    0.753508    
#> 010: 0.373248    0.979989    3.463521    0.247311    0.104773    0.023458    0.768746    
#> 011: 0.459117    0.971157    3.474455    0.234945    0.106570    0.023276    0.783906    
#> 012: 0.432563    0.980509    3.465630    0.223198    0.113236    0.022252    0.748403    
#> 013: 0.387070    1.012382    3.442556    0.236537    0.107574    0.022427    0.742385    
#> 014: 0.434389    0.979767    3.460115    0.224710    0.108586    0.024493    0.767582    
#> 015: 0.450861    0.974272    3.470935    0.292835    0.117873    0.023268    0.733305    
#> 016: 0.426823    0.981563    3.475610    0.278193    0.111979    0.025263    0.756999    
#> 017: 0.432886    0.996028    3.476062    0.264284    0.108354    0.025282    0.746458    
#> 018: 0.439902    0.997176    3.457350    0.294628    0.111863    0.027161    0.733075    
#> 019: 0.393957    0.995147    3.450655    0.288836    0.106270    0.027350    0.740606    
#> 020: 0.405599    1.008874    3.460909    0.274394    0.100956    0.034212    0.730685    
#> 021: 0.419698    1.017747    3.462721    0.260674    0.095908    0.032982    0.732756    
#> 022: 0.429817    0.997972    3.467976    0.264037    0.091113    0.034990    0.732365    
#> 023: 0.473501    1.003096    3.483617    0.250835    0.087834    0.033689    0.748473    
#> 024: 0.498782    1.001715    3.487913    0.238293    0.088476    0.032005    0.757464    
#> 025: 0.449415    0.969220    3.475798    0.228306    0.100749    0.030405    0.771228    
#> 026: 0.455428    0.993570    3.471991    0.216890    0.112467    0.028884    0.760182    
#> 027: 0.410251    1.008600    3.463545    0.230735    0.106843    0.028863    0.754416    
#> 028: 0.434717    0.999984    3.465026    0.289587    0.101501    0.027420    0.747464    
#> 029: 0.428234    1.012361    3.448230    0.275108    0.100965    0.026049    0.777935    
#> 030: 0.448162    1.013956    3.448105    0.283796    0.095916    0.026677    0.763057    
#> 031: 0.431699    0.978805    3.472905    0.269606    0.091121    0.029676    0.760864    
#> 032: 0.399750    0.986311    3.459824    0.256126    0.104887    0.028192    0.737188    
#> 033: 0.385395    1.010014    3.455912    0.243319    0.116406    0.026782    0.762678    
#> 034: 0.421887    1.019961    3.454589    0.231620    0.110586    0.025443    0.745906    
#> 035: 0.359621    0.990904    3.435771    0.220039    0.114606    0.024171    0.744779    
#> 036: 0.354333    1.015307    3.451465    0.209037    0.115653    0.022963    0.771647    
#> 037: 0.369986    1.016812    3.440262    0.198585    0.109870    0.021814    0.797014    
#> 038: 0.406020    1.038116    3.434219    0.206191    0.104377    0.021111    0.789725    
#> 039: 0.393397    1.022148    3.440927    0.218425    0.099158    0.020516    0.752866    
#> 040: 0.371404    1.034643    3.449416    0.249943    0.110206    0.019490    0.768532    
#> 041: 0.331933    1.001987    3.433798    0.237446    0.116441    0.018516    0.751446    
#> 042: 0.360777    1.012174    3.438267    0.225573    0.110619    0.018089    0.738742    
#> 043: 0.368007    1.027894    3.431659    0.219839    0.127350    0.017184    0.753971    
#> 044: 0.346263    1.044873    3.432946    0.217786    0.120982    0.020510    0.744586    
#> 045: 0.374235    1.047401    3.430704    0.238167    0.129610    0.019484    0.748191    
#> 046: 0.380308    1.007015    3.440575    0.246867    0.123130    0.022485    0.748920    
#> 047: 0.401442    1.035142    3.435046    0.236390    0.125791    0.021360    0.741618    
#> 048: 0.414977    1.004360    3.441836    0.235484    0.119501    0.020292    0.750868    
#> 049: 0.413649    0.999713    3.452160    0.240690    0.113526    0.021700    0.755945    
#> 050: 0.466322    0.969061    3.465342    0.262534    0.114470    0.028103    0.789134    
#> 051: 0.417646    1.001237    3.451029    0.282007    0.108747    0.026698    0.778221    
#> 052: 0.423118    0.991592    3.468953    0.267907    0.103864    0.025363    0.742551    
#> 053: 0.439182    1.000462    3.463978    0.270697    0.098671    0.024095    0.741696    
#> 054: 0.401876    1.007933    3.467924    0.257162    0.134637    0.022890    0.769407    
#> 055: 0.405896    0.977294    3.469622    0.259828    0.133136    0.021746    0.757137    
#> 056: 0.435210    0.974927    3.470884    0.252101    0.135419    0.021077    0.767243    
#> 057: 0.439272    0.978396    3.475613    0.248185    0.128648    0.020023    0.776747    
#> 058: 0.436590    0.986775    3.464905    0.258249    0.122216    0.019405    0.757860    
#> 059: 0.461532    0.944715    3.479946    0.276242    0.116105    0.022660    0.772121    
#> 060: 0.465485    0.934593    3.490282    0.262430    0.110300    0.029043    0.760755    
#> 061: 0.502828    0.958884    3.494004    0.280232    0.108002    0.032201    0.772498    
#> 062: 0.502642    0.999151    3.494590    0.266221    0.102602    0.031833    0.782335    
#> 063: 0.518778    0.964351    3.486757    0.252910    0.097472    0.037097    0.758398    
#> 064: 0.494417    0.995554    3.490613    0.240264    0.104362    0.036741    0.750067    
#> 065: 0.505805    0.963148    3.490654    0.241759    0.099144    0.035864    0.748495    
#> 066: 0.509546    0.985094    3.497250    0.229671    0.094187    0.043784    0.748363    
#> 067: 0.496859    0.963373    3.493803    0.245451    0.089478    0.041595    0.734562    
#> 068: 0.448383    0.975047    3.471369    0.255819    0.095539    0.039515    0.750544    
#> 069: 0.412908    0.998254    3.456051    0.243028    0.090762    0.037539    0.761077    
#> 070: 0.439730    1.011354    3.475634    0.230877    0.105443    0.035662    0.727934    
#> 071: 0.422072    1.020380    3.443236    0.262773    0.119640    0.033879    0.750419    
#> 072: 0.391025    1.005190    3.444343    0.249634    0.113658    0.032185    0.760878    
#> 073: 0.439159    1.019399    3.470729    0.237152    0.107975    0.030576    0.769766    
#> 074: 0.355925    1.000692    3.459702    0.225295    0.110729    0.029047    0.751261    
#> 075: 0.444014    0.968206    3.487266    0.214030    0.105192    0.027595    0.748471    
#> 076: 0.490616    0.964178    3.496280    0.236108    0.099933    0.026215    0.759491    
#> 077: 0.505209    0.947138    3.493838    0.224302    0.121315    0.024904    0.748936    
#> 078: 0.483952    0.966540    3.488163    0.213087    0.123332    0.024431    0.746997    
#> 079: 0.434238    0.994952    3.469085    0.236371    0.117165    0.025082    0.764098    
#> 080: 0.448362    0.978806    3.484271    0.234667    0.117618    0.023828    0.763789    
#> 081: 0.444820    0.992544    3.463882    0.236729    0.113947    0.022637    0.743048    
#> 082: 0.446890    0.970240    3.478084    0.237332    0.108249    0.022240    0.746675    
#> 083: 0.458222    0.994645    3.484623    0.260821    0.102837    0.022465    0.743876    
#> 084: 0.441178    1.015309    3.468206    0.247780    0.113036    0.021342    0.745322    
#> 085: 0.426420    1.013239    3.463992    0.235391    0.125844    0.020275    0.755630    
#> 086: 0.399782    1.048956    3.444494    0.223622    0.119552    0.021401    0.730145    
#> 087: 0.407653    1.012217    3.443863    0.247884    0.113574    0.021340    0.735564    
#> 088: 0.358747    0.998576    3.449087    0.235489    0.117742    0.020273    0.747531    
#> 089: 0.375992    1.013968    3.440406    0.257662    0.111855    0.024490    0.753329    
#> 090: 0.384365    1.011353    3.439381    0.271195    0.106262    0.023266    0.731737    
#> 091: 0.394621    0.994651    3.433797    0.260997    0.100949    0.022102    0.742637    
#> 092: 0.378867    1.009841    3.434449    0.272095    0.106854    0.022799    0.756171    
#> 093: 0.387554    1.010911    3.446229    0.258491    0.105982    0.021659    0.748465    
#> 094: 0.408937    1.021053    3.450296    0.252306    0.100683    0.020576    0.754504    
#> 095: 0.380352    1.012593    3.449199    0.239691    0.109292    0.024154    0.758580    
#> 096: 0.351142    1.014334    3.430371    0.248012    0.103828    0.024688    0.742780    
#> 097: 0.386091    1.033826    3.434808    0.235611    0.098636    0.023454    0.763013    
#> 098: 0.359141    1.050304    3.441838    0.223831    0.094119    0.022281    0.783226    
#> 099: 0.349985    1.014590    3.434922    0.212639    0.089413    0.021167    0.755426    
#> 100: 0.351813    1.036845    3.432812    0.202007    0.098848    0.020109    0.744580    
#> 101: 0.343082    1.024157    3.423457    0.191907    0.102453    0.019384    0.746468    
#> 102: 0.344780    1.033947    3.420558    0.191160    0.120714    0.019941    0.759879    
#> 103: 0.379658    1.022600    3.440697    0.231122    0.114678    0.018944    0.743714    
#> 104: 0.385446    1.009383    3.451817    0.225147    0.117553    0.017997    0.768156    
#> 105: 0.440619    1.009080    3.466851    0.213890    0.144120    0.017097    0.786017    
#> 106: 0.457442    0.988541    3.467219    0.209269    0.136914    0.016242    0.774550    
#> 107: 0.466340    1.008236    3.466016    0.232582    0.130068    0.015991    0.766331    
#> 108: 0.442338    0.998894    3.466296    0.220953    0.123565    0.016840    0.785151    
#> 109: 0.395602    0.995271    3.475238    0.209906    0.121003    0.015998    0.763885    
#> 110: 0.425611    0.965874    3.458839    0.205060    0.125490    0.015198    0.755397    
#> 111: 0.427644    0.983892    3.466294    0.194807    0.153447    0.014438    0.750618    
#> 112: 0.458609    0.948527    3.467311    0.215922    0.173682    0.013716    0.785467    
#> 113: 0.449886    1.003485    3.473266    0.205408    0.164998    0.013030    0.748750    
#> 114: 0.430374    0.996249    3.460289    0.249908    0.156748    0.012379    0.747110    
#> 115: 0.436022    0.985223    3.455874    0.237413    0.148911    0.012643    0.776697    
#> 116: 0.427637    1.008506    3.458307    0.243803    0.141465    0.013843    0.771662    
#> 117: 0.407646    1.021640    3.456291    0.231613    0.148825    0.015779    0.758432    
#> 118: 0.446551    0.996570    3.466070    0.220032    0.141384    0.015434    0.738807    
#> 119: 0.438663    1.016290    3.469174    0.214055    0.134314    0.018422    0.745096    
#> 120: 0.416911    0.984839    3.464738    0.209050    0.127599    0.017501    0.743287    
#> 121: 0.423066    1.022365    3.463272    0.198597    0.121219    0.020644    0.761888    
#> 122: 0.438369    0.986700    3.463453    0.212013    0.115158    0.024037    0.749470    
#> 123: 0.472135    1.005184    3.459563    0.263596    0.109400    0.025611    0.729227    
#> 124: 0.419020    1.035130    3.448705    0.304497    0.114616    0.024330    0.743657    
#> 125: 0.427696    1.039368    3.447563    0.289273    0.108885    0.023457    0.716996    
#> 126: 0.383750    1.050325    3.437199    0.287892    0.103441    0.025074    0.738984    
#> 127: 0.415514    1.012073    3.446837    0.273498    0.098269    0.023821    0.758529    
#> 128: 0.382326    0.995790    3.445433    0.259823    0.107093    0.026097    0.782166    
#> 129: 0.407547    1.051324    3.460645    0.246832    0.119908    0.024792    0.762194    
#> 130: 0.475161    1.036847    3.463444    0.234490    0.113913    0.025816    0.733572    
#> 131: 0.432226    1.006961    3.454004    0.225609    0.108217    0.028853    0.743428    
#> 132: 0.410579    1.012666    3.440596    0.214328    0.102806    0.027411    0.775291    
#> 133: 0.422618    1.004211    3.464810    0.203612    0.112755    0.026442    0.772264    
#> 134: 0.446995    0.998828    3.475037    0.216556    0.110573    0.025120    0.757184    
#> 135: 0.456263    0.967639    3.482411    0.205728    0.115126    0.023864    0.749031    
#> 136: 0.465316    0.950706    3.488309    0.195441    0.117658    0.022671    0.742462    
#> 137: 0.491850    0.955878    3.497300    0.198811    0.111776    0.024971    0.754196    
#> 138: 0.459921    0.982480    3.474200    0.197403    0.106187    0.023723    0.762102    
#> 139: 0.460213    1.003194    3.481016    0.197458    0.104413    0.025396    0.748504    
#> 140: 0.446022    1.010983    3.470867    0.187585    0.104546    0.024126    0.773349    
#> 141: 0.425076    0.990373    3.475312    0.181596    0.117167    0.022920    0.767940    
#> 142: 0.443988    0.969717    3.490913    0.197960    0.126637    0.021774    0.764017    
#> 143: 0.426082    0.995379    3.474574    0.239916    0.120305    0.020685    0.759520    
#> 144: 0.456277    0.991785    3.481799    0.227920    0.114290    0.019923    0.742995    
#> 145: 0.444647    1.009005    3.455601    0.222582    0.108576    0.022576    0.746824    
#> 146: 0.417949    1.013875    3.458981    0.270484    0.110990    0.022223    0.742266    
#> 147: 0.403432    1.007684    3.452631    0.256959    0.105441    0.027264    0.731714    
#> 148: 0.394281    1.018573    3.463625    0.244111    0.105228    0.025901    0.744166    
#> 149: 0.414826    1.021780    3.457701    0.247465    0.127060    0.027182    0.752191    
#> 150: 0.465636    0.999139    3.452008    0.309471    0.121779    0.025822    0.743005    
#> 151: 0.410183    1.028954    3.453894    0.331504    0.115690    0.024531    0.734795    
#> 152: 0.396290    1.028098    3.447967    0.288881    0.102041    0.027663    0.735339    
#> 153: 0.419296    1.033405    3.462999    0.323788    0.108068    0.025984    0.741287    
#> 154: 0.450058    1.017556    3.463717    0.323795    0.099306    0.027599    0.737785    
#> 155: 0.398248    0.988662    3.455287    0.286782    0.102603    0.023296    0.731860    
#> 156: 0.450822    0.985707    3.478262    0.287975    0.111016    0.027247    0.736208    
#> 157: 0.448138    1.004677    3.476785    0.218641    0.107978    0.027590    0.740202    
#> 158: 0.452332    1.025877    3.463731    0.246307    0.104242    0.028013    0.721642    
#> 159: 0.393339    1.013434    3.467884    0.201785    0.097671    0.024709    0.743034    
#> 160: 0.442668    0.962822    3.471125    0.253553    0.101793    0.024840    0.734992    
#> 161: 0.433671    0.988517    3.465811    0.231012    0.117454    0.021149    0.730916    
#> 162: 0.402808    1.008885    3.453909    0.265827    0.111281    0.021653    0.750544    
#> 163: 0.421431    1.008923    3.446846    0.214763    0.117273    0.021185    0.758470    
#> 164: 0.420280    1.011038    3.456002    0.198595    0.122982    0.020795    0.753180    
#> 165: 0.472526    0.983648    3.476112    0.227430    0.116238    0.019443    0.764665    
#> 166: 0.483433    1.015829    3.478030    0.215045    0.125104    0.016275    0.766447    
#> 167: 0.473205    0.999421    3.491728    0.188965    0.116473    0.014871    0.795133    
#> 168: 0.487112    1.017321    3.475398    0.227575    0.105649    0.015996    0.804188    
#> 169: 0.421724    1.061680    3.459834    0.202593    0.114317    0.013912    0.819471    
#> 170: 0.439045    1.006042    3.464163    0.195487    0.108763    0.013191    0.764855    
#> 171: 0.444045    0.966149    3.468374    0.230595    0.144960    0.011735    0.741464    
#> 172: 0.432839    0.999355    3.464091    0.239974    0.107434    0.013396    0.738853    
#> 173: 0.427318    1.019387    3.446925    0.224714    0.114038    0.014594    0.743546    
#> 174: 0.416786    1.008749    3.460480    0.223087    0.113912    0.015571    0.748119    
#> 175: 0.421310    1.024895    3.448633    0.246921    0.133357    0.018025    0.760726    
#> 176: 0.432578    1.024652    3.473948    0.225579    0.103894    0.021486    0.764934    
#> 177: 0.431324    0.979656    3.483206    0.194950    0.118735    0.023455    0.763507    
#> 178: 0.461868    0.976181    3.475044    0.191778    0.119119    0.020831    0.735417    
#> 179: 0.458989    1.005926    3.467619    0.200754    0.106386    0.017067    0.769316    
#> 180: 0.436474    1.007359    3.470612    0.223597    0.101963    0.022335    0.751488    
#> 181: 0.428152    1.002073    3.452043    0.231898    0.102384    0.022710    0.751007    
#> 182: 0.374336    1.008495    3.433803    0.220436    0.134634    0.018970    0.760553    
#> 183: 0.379567    1.034620    3.437659    0.205703    0.096493    0.014202    0.793070    
#> 184: 0.418403    1.006315    3.451315    0.213031    0.113764    0.014461    0.778998    
#> 185: 0.367999    1.017154    3.445770    0.206143    0.094953    0.017319    0.766859    
#> 186: 0.406106    1.039060    3.444130    0.184416    0.091638    0.018733    0.779662    
#> 187: 0.393866    0.997563    3.454374    0.166140    0.101767    0.014751    0.770193    
#> 188: 0.383476    1.032153    3.448272    0.245578    0.111827    0.016989    0.765725    
#> 189: 0.401841    1.028292    3.449585    0.200897    0.104972    0.019183    0.755144    
#> 190: 0.382883    1.034652    3.444186    0.208758    0.105731    0.016643    0.750572    
#> 191: 0.362054    1.042367    3.426136    0.219725    0.098851    0.015589    0.746967    
#> 192: 0.342830    1.030622    3.432254    0.195194    0.103666    0.018326    0.753633    
#> 193: 0.381289    1.029893    3.437882    0.171331    0.100084    0.018201    0.742920    
#> 194: 0.362937    1.027877    3.434187    0.183312    0.120825    0.020637    0.766803    
#> 195: 0.347932    1.021790    3.434857    0.182366    0.106586    0.020006    0.735725    
#> 196: 0.367129    1.013579    3.451715    0.204014    0.119986    0.019310    0.752557    
#> 197: 0.354117    0.994301    3.462737    0.223177    0.102787    0.020572    0.776006    
#> 198: 0.407707    0.992739    3.452115    0.231585    0.099528    0.024004    0.755665    
#> 199: 0.383836    1.001526    3.452713    0.252719    0.107685    0.021181    0.755462    
#> 200: 0.378645    1.002181    3.447016    0.232926    0.105237    0.020428    0.759519    
#> 201: 0.382302    0.999250    3.455593    0.228899    0.101700    0.020921    0.763811    
#> 202: 0.392239    1.003055    3.456642    0.232757    0.101757    0.022351    0.755450    
#> 203: 0.411915    1.004054    3.454661    0.250391    0.100241    0.023860    0.749887    
#> 204: 0.421045    0.997669    3.458265    0.246867    0.099297    0.024679    0.749791    
#> 205: 0.425940    0.999554    3.460937    0.248422    0.101109    0.025495    0.752018    
#> 206: 0.427691    1.001610    3.462465    0.249356    0.100898    0.025348    0.753060    
#> 207: 0.427307    1.000325    3.462490    0.250831    0.098459    0.024980    0.756499    
#> 208: 0.427872    1.000646    3.463032    0.254345    0.097001    0.025113    0.754289    
#> 209: 0.432486    0.997510    3.463266    0.255652    0.096019    0.025162    0.753423    
#> 210: 0.434072    0.995121    3.464532    0.253450    0.096693    0.025220    0.752025    
#> 211: 0.434939    0.995814    3.465695    0.253382    0.095861    0.025063    0.751242    
#> 212: 0.436122    0.995699    3.466729    0.251757    0.094911    0.025256    0.751368    
#> 213: 0.437819    0.991820    3.467411    0.250126    0.094412    0.025230    0.753071    
#> 214: 0.439924    0.990486    3.468181    0.250681    0.095594    0.025446    0.752764    
#> 215: 0.439956    0.990234    3.469219    0.248458    0.095794    0.025531    0.752601    
#> 216: 0.442799    0.988272    3.470308    0.245919    0.096679    0.025216    0.752971    
#> 217: 0.444498    0.988625    3.470880    0.245569    0.096210    0.025212    0.752656    
#> 218: 0.442957    0.989541    3.470180    0.246758    0.095942    0.025372    0.752216    
#> 219: 0.441889    0.989314    3.469152    0.247864    0.095817    0.025198    0.752698    
#> 220: 0.440575    0.989537    3.469022    0.247369    0.095588    0.024945    0.752690    
#> 221: 0.439642    0.990248    3.468600    0.246611    0.095155    0.024766    0.753274    
#> 222: 0.439303    0.990345    3.468445    0.245981    0.094722    0.024623    0.753712    
#> 223: 0.441949    0.989981    3.468819    0.246917    0.095048    0.024767    0.752634    
#> 224: 0.444211    0.990137    3.469374    0.246904    0.095584    0.024710    0.752362    
#> 225: 0.444157    0.988112    3.470051    0.246421    0.095906    0.024671    0.751913    
#> 226: 0.444490    0.987333    3.470066    0.245183    0.095750    0.024506    0.751936    
#> 227: 0.443689    0.987908    3.470109    0.243984    0.095531    0.024326    0.752073    
#> 228: 0.442466    0.988657    3.469458    0.242329    0.096035    0.024214    0.751990    
#> 229: 0.442143    0.988679    3.469381    0.240679    0.096574    0.024069    0.752157    
#> 230: 0.442866    0.987928    3.469506    0.240883    0.097067    0.023939    0.752027    
#> 231: 0.444263    0.987803    3.470115    0.241262    0.097360    0.023911    0.752133    
#> 232: 0.443771    0.987976    3.470649    0.240493    0.097645    0.023913    0.752077    
#> 233: 0.443128    0.987573    3.470691    0.240155    0.097920    0.023937    0.751922    
#> 234: 0.443248    0.987516    3.470826    0.238947    0.097950    0.024009    0.751946    
#> 235: 0.443489    0.987527    3.470832    0.238361    0.097466    0.023815    0.752432    
#> 236: 0.443319    0.987529    3.470889    0.237186    0.097517    0.023778    0.752538    
#> 237: 0.444308    0.987317    3.470985    0.237272    0.097482    0.023988    0.752616    
#> 238: 0.445154    0.987197    3.470976    0.236580    0.097888    0.024055    0.753117    
#> 239: 0.445393    0.987532    3.470878    0.237481    0.097567    0.024036    0.753391    
#> 240: 0.444610    0.988076    3.470848    0.237707    0.097406    0.024056    0.752977    
#> 241: 0.444109    0.987393    3.470753    0.237926    0.096956    0.024129    0.753057    
#> 242: 0.443359    0.986956    3.470383    0.239610    0.097106    0.024176    0.753163    
#> 243: 0.442239    0.987856    3.470044    0.239736    0.096772    0.024171    0.753550    
#> 244: 0.441142    0.988406    3.470110    0.240119    0.096910    0.024173    0.753392    
#> 245: 0.440889    0.988230    3.469912    0.240594    0.096566    0.024173    0.753536    
#> 246: 0.440467    0.988236    3.469717    0.240072    0.096394    0.024231    0.753297    
#> 247: 0.440282    0.988014    3.469733    0.240179    0.096290    0.024262    0.752897    
#> 248: 0.440057    0.988698    3.469578    0.239794    0.096324    0.024264    0.752824    
#> 249: 0.439521    0.988930    3.469569    0.238698    0.096240    0.024297    0.752376    
#> 250: 0.440013    0.989099    3.469666    0.239556    0.096048    0.024317    0.752199    
#> 251: 0.440385    0.989507    3.469822    0.239870    0.096212    0.024261    0.752559    
#> 252: 0.441175    0.989822    3.470177    0.239730    0.096278    0.024312    0.752511    
#> 253: 0.441110    0.990173    3.470061    0.239448    0.096632    0.024348    0.752578    
#> 254: 0.441062    0.990380    3.470112    0.239106    0.096786    0.024391    0.752378    
#> 255: 0.440737    0.991022    3.470203    0.239416    0.096947    0.024552    0.752495    
#> 256: 0.441143    0.990934    3.470316    0.239758    0.096818    0.024686    0.752456    
#> 257: 0.440866    0.990586    3.470436    0.238832    0.096606    0.024655    0.752539    
#> 258: 0.441063    0.989926    3.470569    0.238929    0.096567    0.024627    0.752824    
#> 259: 0.441075    0.989792    3.470602    0.238792    0.096882    0.024605    0.753092    
#> 260: 0.440959    0.989937    3.470729    0.238261    0.096844    0.024597    0.753073    
#> 261: 0.441366    0.989540    3.471003    0.238244    0.096857    0.024619    0.753289    
#> 262: 0.442164    0.989106    3.471338    0.238075    0.097057    0.024634    0.753434    
#> 263: 0.442426    0.989455    3.471367    0.237838    0.097144    0.024636    0.753561    
#> 264: 0.442074    0.989274    3.471408    0.237135    0.097050    0.024554    0.754150    
#> 265: 0.441984    0.989416    3.471401    0.236413    0.097067    0.024538    0.754331    
#> 266: 0.442293    0.989724    3.471330    0.236222    0.097188    0.024541    0.754108    
#> 267: 0.442224    0.989732    3.471336    0.236209    0.097185    0.024574    0.753822    
#> 268: 0.441927    0.989589    3.471152    0.236554    0.097390    0.024608    0.753578    
#> 269: 0.442518    0.989336    3.471119    0.237083    0.097493    0.024623    0.753570    
#> 270: 0.443106    0.989380    3.471023    0.237729    0.097625    0.024588    0.753375    
#> 271: 0.443154    0.989708    3.470808    0.238556    0.097929    0.024598    0.753617    
#> 272: 0.443117    0.989562    3.470705    0.239145    0.097978    0.024563    0.754100    
#> 273: 0.442933    0.990043    3.470648    0.239742    0.098217    0.024535    0.754513    
#> 274: 0.442521    0.990663    3.470573    0.239743    0.098458    0.024465    0.754652    
#> 275: 0.442386    0.991041    3.470315    0.239411    0.098793    0.024386    0.754652    
#> 276: 0.441772    0.991346    3.470292    0.238647    0.098852    0.024336    0.754705    
#> 277: 0.441366    0.991824    3.470282    0.237695    0.098889    0.024262    0.754739    
#> 278: 0.440828    0.992096    3.470259    0.237378    0.098853    0.024224    0.754703    
#> 279: 0.440368    0.991930    3.470136    0.237708    0.099086    0.024242    0.754676    
#> 280: 0.440077    0.992248    3.470031    0.237488    0.099279    0.024212    0.754359    
#> 281: 0.439376    0.992443    3.469881    0.237851    0.099242    0.024221    0.754227    
#> 282: 0.439279    0.992639    3.469914    0.237999    0.099138    0.024179    0.754329    
#> 283: 0.439405    0.992991    3.469874    0.237803    0.098964    0.024165    0.754778    
#> 284: 0.439149    0.993048    3.469777    0.237664    0.098953    0.024180    0.754720    
#> 285: 0.438850    0.993286    3.469457    0.237960    0.099149    0.024167    0.754836    
#> 286: 0.438304    0.993719    3.469092    0.238461    0.099218    0.024112    0.755025    
#> 287: 0.437577    0.994159    3.468720    0.238730    0.099547    0.024085    0.755114    
#> 288: 0.437194    0.994436    3.468475    0.239223    0.099493    0.024029    0.755189    
#> 289: 0.437181    0.994482    3.468296    0.239843    0.099473    0.023993    0.755164    
#> 290: 0.437041    0.994570    3.468280    0.240231    0.099578    0.023946    0.755301    
#> 291: 0.437163    0.994828    3.468397    0.240148    0.099720    0.023976    0.755055    
#> 292: 0.436871    0.995132    3.468332    0.239813    0.099879    0.023937    0.754963    
#> 293: 0.436492    0.995185    3.468178    0.239578    0.099863    0.023918    0.754706    
#> 294: 0.436317    0.995312    3.468046    0.239286    0.099834    0.023928    0.754659    
#> 295: 0.436071    0.995156    3.468001    0.239152    0.099824    0.023891    0.754542    
#> 296: 0.436145    0.995050    3.467957    0.239221    0.099739    0.023891    0.754665    
#> 297: 0.436359    0.995050    3.468030    0.239228    0.099741    0.023907    0.754614    
#> 298: 0.436429    0.994776    3.467995    0.238741    0.099755    0.023876    0.754802    
#> 299: 0.436553    0.994731    3.467999    0.238715    0.099780    0.023855    0.754577    
#> 300: 0.436815    0.994529    3.468143    0.238545    0.099795    0.023855    0.754488    
#> 301: 0.436977    0.994223    3.468101    0.238749    0.099862    0.023827    0.754612    
#> 302: 0.436939    0.994402    3.467965    0.238996    0.100040    0.023784    0.754489    
#> 303: 0.436572    0.994732    3.467767    0.239428    0.100222    0.023766    0.754180    
#> 304: 0.436449    0.995186    3.467447    0.239496    0.100170    0.023760    0.754100    
#> 305: 0.436433    0.995016    3.467288    0.239580    0.100154    0.023738    0.754077    
#> 306: 0.435967    0.995132    3.467050    0.239427    0.100077    0.023717    0.753992    
#> 307: 0.435997    0.995285    3.466877    0.239512    0.100309    0.023695    0.753976    
#> 308: 0.435640    0.995122    3.466836    0.239516    0.100498    0.023671    0.754100    
#> 309: 0.435711    0.994808    3.466850    0.239851    0.100519    0.023663    0.754340    
#> 310: 0.435838    0.994727    3.466797    0.239984    0.100481    0.023632    0.754266    
#> 311: 0.435824    0.994661    3.466737    0.240344    0.100539    0.023628    0.754162    
#> 312: 0.435663    0.994541    3.466727    0.240711    0.100525    0.023656    0.754117    
#> 313: 0.435557    0.994311    3.466632    0.241021    0.100541    0.023678    0.754132    
#> 314: 0.435037    0.994606    3.466391    0.241120    0.100646    0.023710    0.753931    
#> 315: 0.434418    0.995099    3.466185    0.241351    0.100531    0.023737    0.753876    
#> 316: 0.434266    0.995485    3.465977    0.242082    0.100709    0.023698    0.753700    
#> 317: 0.434411    0.995552    3.465921    0.242486    0.100691    0.023721    0.753769    
#> 318: 0.434113    0.995789    3.465682    0.242884    0.100641    0.023736    0.753682    
#> 319: 0.433866    0.995960    3.465599    0.243115    0.100791    0.023733    0.753779    
#> 320: 0.433334    0.996002    3.465460    0.243328    0.100857    0.023744    0.753861    
#> 321: 0.432881    0.996218    3.465203    0.243597    0.100940    0.023719    0.754039    
#> 322: 0.432666    0.996543    3.464991    0.243638    0.101068    0.023659    0.754115    
#> 323: 0.431972    0.996692    3.464832    0.243765    0.101049    0.023588    0.754218    
#> 324: 0.431913    0.996973    3.464755    0.243761    0.101125    0.023554    0.754150    
#> 325: 0.431718    0.997218    3.464632    0.243836    0.101239    0.023529    0.754027    
#> 326: 0.431375    0.997102    3.464514    0.243991    0.101232    0.023493    0.754120    
#> 327: 0.431155    0.997284    3.464514    0.243933    0.101416    0.023501    0.754181    
#> 328: 0.430975    0.997487    3.464439    0.243802    0.101550    0.023473    0.754131    
#> 329: 0.430942    0.997726    3.464423    0.243306    0.101642    0.023441    0.754213    
#> 330: 0.430872    0.997767    3.464456    0.243157    0.101656    0.023440    0.754121    
#> 331: 0.431161    0.997754    3.464544    0.243018    0.101600    0.023415    0.754095    
#> 332: 0.431335    0.997698    3.464564    0.243072    0.101561    0.023365    0.754214    
#> 333: 0.431163    0.997813    3.464460    0.242994    0.101643    0.023300    0.754205    
#> 334: 0.430968    0.997764    3.464394    0.243041    0.101673    0.023282    0.754106    
#> 335: 0.430915    0.997940    3.464387    0.243088    0.101789    0.023289    0.753997    
#> 336: 0.430539    0.998256    3.464246    0.243173    0.101873    0.023287    0.754054    
#> 337: 0.430187    0.998698    3.464084    0.243006    0.101910    0.023275    0.754112    
#> 338: 0.430071    0.998842    3.464047    0.242720    0.101977    0.023269    0.754202    
#> 339: 0.429817    0.999052    3.463994    0.242216    0.102017    0.023279    0.754217    
#> 340: 0.429544    0.998916    3.463953    0.241892    0.102236    0.023274    0.754156    
#> 341: 0.429714    0.998969    3.463927    0.241597    0.102432    0.023275    0.754204    
#> 342: 0.429574    0.998939    3.463895    0.241366    0.102641    0.023231    0.754172    
#> 343: 0.429550    0.998952    3.463862    0.241455    0.102745    0.023193    0.754046    
#> 344: 0.429657    0.998913    3.463838    0.241588    0.102800    0.023164    0.754063    
#> 345: 0.429776    0.998828    3.463877    0.241338    0.102970    0.023157    0.753994    
#> 346: 0.429770    0.998866    3.463791    0.241302    0.102987    0.023149    0.753831    
#> 347: 0.430098    0.998751    3.463779    0.241425    0.102925    0.023178    0.753879    
#> 348: 0.429989    0.998749    3.463765    0.241210    0.102867    0.023188    0.753800    
#> 349: 0.429991    0.998674    3.463781    0.241335    0.102787    0.023212    0.753762    
#> 350: 0.429834    0.998681    3.463689    0.241268    0.102795    0.023202    0.753610    
#> 351: 0.429919    0.998819    3.463597    0.241410    0.102828    0.023201    0.753641    
#> 352: 0.429646    0.998957    3.463584    0.241459    0.102872    0.023213    0.753872    
#> 353: 0.429645    0.999069    3.463509    0.241499    0.102886    0.023245    0.753960    
#> 354: 0.429829    0.999098    3.463471    0.241399    0.102856    0.023260    0.753987    
#> 355: 0.430460    0.998954    3.463545    0.241583    0.102839    0.023254    0.754068    
#> 356: 0.430506    0.998814    3.463592    0.241672    0.102903    0.023257    0.754196    
#> 357: 0.430579    0.998847    3.463623    0.241552    0.102840    0.023242    0.754270    
#> 358: 0.430567    0.998747    3.463705    0.241302    0.102794    0.023235    0.754264    
#> 359: 0.430646    0.998708    3.463797    0.241260    0.102741    0.023249    0.754090    
#> 360: 0.430536    0.998710    3.463757    0.241129    0.102691    0.023257    0.753918    
#> 361: 0.430420    0.998691    3.463728    0.241009    0.102602    0.023260    0.753877    
#> 362: 0.430327    0.998737    3.463679    0.240665    0.102522    0.023252    0.753684    
#> 363: 0.430269    0.998805    3.463674    0.240661    0.102547    0.023254    0.753487    
#> 364: 0.430310    0.998897    3.463652    0.240912    0.102613    0.023263    0.753411    
#> 365: 0.430318    0.998920    3.463631    0.241130    0.102555    0.023278    0.753373    
#> 366: 0.430385    0.998856    3.463581    0.241237    0.102654    0.023258    0.753519    
#> 367: 0.430383    0.998875    3.463555    0.240914    0.102729    0.023238    0.753511    
#> 368: 0.430429    0.998929    3.463480    0.240996    0.102691    0.023226    0.753435    
#> 369: 0.430346    0.998986    3.463429    0.241126    0.102741    0.023235    0.753455    
#> 370: 0.430064    0.999101    3.463352    0.241342    0.102703    0.023269    0.753490    
#> 371: 0.429883    0.999219    3.463221    0.241339    0.102689    0.023253    0.753430    
#> 372: 0.429713    0.999304    3.463109    0.241349    0.102639    0.023236    0.753399    
#> 373: 0.429479    0.999440    3.463033    0.241084    0.102708    0.023248    0.753428    
#> 374: 0.429278    0.999538    3.462929    0.240925    0.102855    0.023229    0.753372    
#> 375: 0.428826    0.999666    3.462792    0.240664    0.102880    0.023206    0.753411    
#> 376: 0.428582    0.999915    3.462685    0.240374    0.102906    0.023193    0.753445    
#> 377: 0.428358    1.000006    3.462644    0.240101    0.103033    0.023181    0.753381    
#> 378: 0.428087    1.000048    3.462546    0.239691    0.103193    0.023169    0.753405    
#> 379: 0.427795    0.999946    3.462539    0.239296    0.103290    0.023150    0.753457    
#> 380: 0.427648    0.999915    3.462507    0.239092    0.103443    0.023131    0.753425    
#> 381: 0.427462    0.999911    3.462437    0.239086    0.103562    0.023096    0.753425    
#> 382: 0.427652    0.999800    3.462527    0.238980    0.103638    0.023088    0.753335    
#> 383: 0.428015    0.999658    3.462611    0.238901    0.103624    0.023094    0.753234    
#> 384: 0.427870    0.999565    3.462651    0.238932    0.103590    0.023116    0.753237    
#> 385: 0.427923    0.999456    3.462695    0.238836    0.103537    0.023116    0.753316    
#> 386: 0.427938    0.999559    3.462721    0.238602    0.103517    0.023126    0.753449    
#> 387: 0.428111    0.999582    3.462804    0.238603    0.103468    0.023137    0.753367    
#> 388: 0.428214    0.999727    3.462879    0.238706    0.103367    0.023132    0.753429    
#> 389: 0.428220    0.999632    3.462851    0.238648    0.103318    0.023151    0.753430    
#> 390: 0.428129    0.999591    3.462848    0.238594    0.103265    0.023181    0.753420    
#> 391: 0.428237    0.999521    3.462852    0.238661    0.103210    0.023209    0.753289    
#> 392: 0.428351    0.999451    3.462917    0.238837    0.103149    0.023215    0.753263    
#> 393: 0.428419    0.999293    3.462915    0.238827    0.103141    0.023205    0.753205    
#> 394: 0.428588    0.999249    3.462957    0.238913    0.103116    0.023223    0.753157    
#> 395: 0.428985    0.999245    3.463028    0.239054    0.103006    0.023245    0.753230    
#> 396: 0.429480    0.999195    3.463142    0.239255    0.102951    0.023281    0.753171    
#> 397: 0.429994    0.999082    3.463286    0.239407    0.102893    0.023261    0.753200    
#> 398: 0.430357    0.998958    3.463375    0.239471    0.102905    0.023232    0.753322    
#> 399: 0.430745    0.998903    3.463466    0.239636    0.102892    0.023211    0.753295    
#> 400: 0.430996    0.998890    3.463554    0.239869    0.102945    0.023211    0.753264    
#> 401: 0.431027    0.998993    3.463556    0.239852    0.102972    0.023218    0.753284    
#> 402: 0.431081    0.999111    3.463541    0.239950    0.102959    0.023204    0.753299    
#> 403: 0.431223    0.999098    3.463543    0.240069    0.103030    0.023181    0.753207    
#> 404: 0.431365    0.999048    3.463513    0.240212    0.103121    0.023175    0.753087    
#> 405: 0.431363    0.999044    3.463528    0.240027    0.103087    0.023153    0.753057    
#> 406: 0.431529    0.998962    3.463540    0.239979    0.103063    0.023161    0.753127    
#> 407: 0.431580    0.999037    3.463555    0.240017    0.103104    0.023160    0.753048    
#> 408: 0.431684    0.999143    3.463585    0.240041    0.103228    0.023152    0.753091    
#> 409: 0.431697    0.999062    3.463587    0.239966    0.103332    0.023147    0.753098    
#> 410: 0.431663    0.999076    3.463538    0.240049    0.103380    0.023144    0.753202    
#> 411: 0.431835    0.998844    3.463537    0.240224    0.103412    0.023132    0.753265    
#> 412: 0.431849    0.998823    3.463529    0.240103    0.103505    0.023139    0.753319    
#> 413: 0.431902    0.998912    3.463494    0.240123    0.103544    0.023125    0.753359    
#> 414: 0.431684    0.998993    3.463460    0.240130    0.103619    0.023095    0.753301    
#> 415: 0.431671    0.998962    3.463429    0.240047    0.103644    0.023079    0.753248    
#> 416: 0.431820    0.999046    3.463453    0.239971    0.103737    0.023054    0.753256    
#> 417: 0.431965    0.998958    3.463517    0.239874    0.103788    0.023049    0.753230    
#> 418: 0.431846    0.998956    3.463534    0.239711    0.103827    0.023036    0.753184    
#> 419: 0.431948    0.999022    3.463511    0.239530    0.103850    0.023017    0.753143    
#> 420: 0.432117    0.998941    3.463570    0.239501    0.103879    0.023006    0.753051    
#> 421: 0.432129    0.998866    3.463649    0.239445    0.103863    0.022997    0.753068    
#> 422: 0.432398    0.998751    3.463715    0.239486    0.103835    0.023007    0.753010    
#> 423: 0.432633    0.998582    3.463812    0.239504    0.103869    0.023037    0.753003    
#> 424: 0.432678    0.998518    3.463807    0.239392    0.103863    0.023044    0.753060    
#> 425: 0.432756    0.998521    3.463838    0.239443    0.103769    0.023064    0.753180    
#> 426: 0.432886    0.998497    3.463898    0.239569    0.103724    0.023067    0.753188    
#> 427: 0.432849    0.998424    3.463976    0.239759    0.103700    0.023105    0.753128    
#> 428: 0.432868    0.998476    3.464010    0.239850    0.103679    0.023113    0.753080    
#> 429: 0.432950    0.998508    3.464064    0.239950    0.103655    0.023115    0.753109    
#> 430: 0.432908    0.998555    3.464084    0.239952    0.103592    0.023142    0.753062    
#> 431: 0.432892    0.998561    3.464033    0.240150    0.103492    0.023154    0.752961    
#> 432: 0.432749    0.998644    3.464003    0.240341    0.103380    0.023197    0.752868    
#> 433: 0.432702    0.998759    3.463976    0.240495    0.103318    0.023206    0.752917    
#> 434: 0.432547    0.998705    3.463961    0.240583    0.103311    0.023216    0.752859    
#> 435: 0.432577    0.998709    3.463938    0.240499    0.103335    0.023216    0.752764    
#> 436: 0.432521    0.998518    3.464008    0.240651    0.103305    0.023224    0.752876    
#> 437: 0.432642    0.998368    3.464089    0.240563    0.103312    0.023232    0.752952    
#> 438: 0.432712    0.998532    3.464108    0.240526    0.103414    0.023196    0.753076    
#> 439: 0.432793    0.998589    3.464121    0.240385    0.103363    0.023185    0.753078    
#> 440: 0.432686    0.998643    3.464123    0.240244    0.103356    0.023171    0.753069    
#> 441: 0.432688    0.998690    3.464173    0.240189    0.103338    0.023161    0.753027    
#> 442: 0.432608    0.998776    3.464211    0.239864    0.103326    0.023151    0.753013    
#> 443: 0.432524    0.998915    3.464151    0.239725    0.103369    0.023118    0.752947    
#> 444: 0.432388    0.999044    3.464034    0.239658    0.103350    0.023105    0.752918    
#> 445: 0.432173    0.999156    3.463957    0.239673    0.103455    0.023088    0.752916    
#> 446: 0.431948    0.999277    3.463871    0.239649    0.103461    0.023060    0.752898    
#> 447: 0.431968    0.999265    3.463897    0.239640    0.103499    0.023043    0.752886    
#> 448: 0.431914    0.999163    3.463942    0.239594    0.103492    0.023035    0.752853    
#> 449: 0.431878    0.999139    3.464012    0.239579    0.103554    0.023026    0.752920    
#> 450: 0.431817    0.999066    3.464029    0.239558    0.103549    0.022997    0.752976    
#> 451: 0.431782    0.999069    3.463980    0.239573    0.103608    0.022977    0.752998    
#> 452: 0.431595    0.999184    3.463909    0.239621    0.103704    0.022968    0.752940    
#> 453: 0.431304    0.999324    3.463792    0.239591    0.103732    0.022953    0.752874    
#> 454: 0.431106    0.999546    3.463704    0.239510    0.103673    0.022935    0.752895    
#> 455: 0.431041    0.999591    3.463665    0.239528    0.103749    0.022911    0.752913    
#> 456: 0.430836    0.999538    3.463595    0.239430    0.103716    0.022905    0.752954    
#> 457: 0.430698    0.999521    3.463608    0.239336    0.103697    0.022894    0.752946    
#> 458: 0.430637    0.999623    3.463625    0.239217    0.103728    0.022881    0.752905    
#> 459: 0.430528    0.999753    3.463609    0.239181    0.103803    0.022878    0.752931    
#> 460: 0.430428    0.999761    3.463539    0.239155    0.103751    0.022889    0.752982    
#> 461: 0.430265    0.999785    3.463526    0.239153    0.103728    0.022882    0.753010    
#> 462: 0.430154    0.999870    3.463519    0.239110    0.103782    0.022869    0.753011    
#> 463: 0.430265    0.999919    3.463559    0.239055    0.103809    0.022852    0.752998    
#> 464: 0.430361    0.999941    3.463555    0.238985    0.103855    0.022841    0.752960    
#> 465: 0.430420    0.999738    3.463575    0.238856    0.103856    0.022832    0.752932    
#> 466: 0.430430    0.999652    3.463577    0.238706    0.103818    0.022807    0.752975    
#> 467: 0.430391    0.999599    3.463586    0.238762    0.103829    0.022785    0.752868    
#> 468: 0.430472    0.999587    3.463629    0.238759    0.103823    0.022774    0.752907    
#> 469: 0.430496    0.999656    3.463663    0.238695    0.103835    0.022777    0.752975    
#> 470: 0.430419    0.999760    3.463598    0.238760    0.103890    0.022749    0.752959    
#> 471: 0.430145    0.999817    3.463503    0.238863    0.103914    0.022719    0.752984    
#> 472: 0.430051    0.999876    3.463459    0.238726    0.103933    0.022696    0.752960    
#> 473: 0.429870    0.999881    3.463398    0.238738    0.103949    0.022690    0.752938    
#> 474: 0.429692    0.999908    3.463328    0.238547    0.103970    0.022666    0.753058    
#> 475: 0.429737    1.000004    3.463304    0.238416    0.103935    0.022657    0.753057    
#> 476: 0.429781    1.000034    3.463270    0.238345    0.103976    0.022635    0.753125    
#> 477: 0.429741    0.999999    3.463327    0.238168    0.104027    0.022626    0.753094    
#> 478: 0.429676    0.999991    3.463302    0.238151    0.104083    0.022611    0.753116    
#> 479: 0.429775    1.000039    3.463277    0.238362    0.104153    0.022599    0.753061    
#> 480: 0.429770    1.000100    3.463226    0.238431    0.104213    0.022592    0.753019    
#> 481: 0.429787    1.000105    3.463197    0.238455    0.104199    0.022590    0.752990    
#> 482: 0.429787    1.000116    3.463145    0.238358    0.104203    0.022594    0.752998    
#> 483: 0.429575    1.000188    3.463062    0.238427    0.104173    0.022589    0.752965    
#> 484: 0.429453    1.000095    3.463049    0.238418    0.104157    0.022574    0.752978    
#> 485: 0.429488    1.000156    3.463037    0.238420    0.104149    0.022563    0.753009    
#> 486: 0.429532    1.000133    3.463088    0.238352    0.104122    0.022555    0.753003    
#> 487: 0.429795    1.000131    3.463209    0.238318    0.104143    0.022562    0.753003    
#> 488: 0.429866    1.000094    3.463293    0.238314    0.104109    0.022571    0.752955    
#> 489: 0.430009    1.000079    3.463320    0.238326    0.104098    0.022587    0.752959    
#> 490: 0.430007    1.000116    3.463353    0.238386    0.104091    0.022586    0.752922    
#> 491: 0.430039    1.000196    3.463404    0.238244    0.104109    0.022575    0.752929    
#> 492: 0.429988    1.000254    3.463396    0.238145    0.104141    0.022573    0.752985    
#> 493: 0.429866    1.000227    3.463396    0.238078    0.104120    0.022582    0.753078    
#> 494: 0.429901    1.000270    3.463354    0.238166    0.104071    0.022585    0.753129    
#> 495: 0.430103    1.000258    3.463372    0.238217    0.104054    0.022603    0.753126    
#> 496: 0.430194    1.000336    3.463327    0.238257    0.104030    0.022598    0.753214    
#> 497: 0.430169    1.000315    3.463323    0.238297    0.104092    0.022604    0.753276    
#> 498: 0.430124    1.000331    3.463294    0.238283    0.104087    0.022605    0.753319    
#> 499: 0.429981    1.000424    3.463243    0.238181    0.104135    0.022629    0.753330    
#> 500: 0.429963    1.000421    3.463210    0.238157    0.104143    0.022631    0.753305    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.309836    0.973236    3.446629    0.392401    0.080679    0.016800    1.673982    
#> 002: 0.391487    0.957571    3.481910    0.372781    0.076645    0.015960    1.208231    
#> 003: 0.458051    0.982554    3.470768    0.354142    0.072813    0.015162    0.960247    
#> 004: 0.496069    0.986569    3.483979    0.392860    0.092197    0.014404    0.797327    
#> 005: 0.593159    0.986863    3.486140    0.441384    0.099287    0.013684    0.735806    
#> 006: 0.552607    1.000413    3.485315    0.419315    0.094323    0.013000    0.702704    
#> 007: 0.548255    1.006682    3.481161    0.398349    0.089606    0.012803    0.729730    
#> 008: 0.517015    1.014921    3.473995    0.392421    0.089277    0.012163    0.722452    
#> 009: 0.485253    1.006504    3.464352    0.392974    0.084813    0.011555    0.730617    
#> 010: 0.524242    1.022118    3.467095    0.399853    0.087183    0.015187    0.720861    
#> 011: 0.580633    1.002958    3.474377    0.425225    0.083787    0.016533    0.730949    
#> 012: 0.603874    1.010854    3.470864    0.509823    0.111097    0.015707    0.718433    
#> 013: 0.553865    1.003497    3.463814    0.539580    0.105542    0.015638    0.721170    
#> 014: 0.593222    1.008560    3.471186    0.639790    0.103782    0.017380    0.723045    
#> 015: 0.579769    1.014696    3.480406    0.607800    0.098592    0.016511    0.707048    
#> 016: 0.559229    1.035443    3.476436    0.577410    0.093663    0.017165    0.709382    
#> 017: 0.542984    1.034283    3.473848    0.555264    0.088980    0.016307    0.697348    
#> 018: 0.530731    1.026876    3.456802    0.581448    0.084531    0.015492    0.700172    
#> 019: 0.498749    1.049810    3.443676    0.586522    0.088511    0.014717    0.698650    
#> 020: 0.535661    1.048807    3.456966    0.708969    0.097363    0.014707    0.694777    
#> 021: 0.550417    1.030384    3.468917    0.673520    0.093246    0.013972    0.695799    
#> 022: 0.570694    1.027628    3.480511    0.639844    0.096075    0.014504    0.685412    
#> 023: 0.603666    1.043936    3.484089    0.607852    0.104644    0.013779    0.708100    
#> 024: 0.567261    1.047496    3.471325    0.577459    0.099412    0.013090    0.714612    
#> 025: 0.527490    1.023893    3.458300    0.555604    0.094441    0.012435    0.719844    
#> 026: 0.519770    1.050085    3.447782    0.576856    0.089719    0.012483    0.724160    
#> 027: 0.509246    1.054106    3.439240    0.615540    0.085233    0.014172    0.726288    
#> 028: 0.515169    1.051051    3.456486    0.584763    0.080972    0.015334    0.702922    
#> 029: 0.551644    1.039298    3.450991    0.555525    0.076923    0.014934    0.746516    
#> 030: 0.557210    1.050477    3.454208    0.527749    0.091279    0.017241    0.710599    
#> 031: 0.533801    1.028582    3.462363    0.544314    0.086715    0.017126    0.715107    
#> 032: 0.542135    1.022565    3.465689    0.583452    0.084432    0.018594    0.699645    
#> 033: 0.534061    1.047530    3.461391    0.591541    0.083832    0.018410    0.696035    
#> 034: 0.570048    1.052206    3.469017    0.566608    0.088721    0.017489    0.703971    
#> 035: 0.531305    1.030545    3.462535    0.538278    0.084285    0.016615    0.697947    
#> 036: 0.527657    1.049697    3.463594    0.511364    0.080071    0.015784    0.710106    
#> 037: 0.543383    1.030449    3.478004    0.485796    0.079582    0.014995    0.723785    
#> 038: 0.619437    1.033183    3.479910    0.495236    0.080263    0.015376    0.717432    
#> 039: 0.608121    1.014745    3.497102    0.530614    0.099075    0.016219    0.694122    
#> 040: 0.593996    1.021192    3.494742    0.504083    0.094122    0.017487    0.706561    
#> 041: 0.504665    1.032525    3.485575    0.478879    0.089415    0.020614    0.720338    
#> 042: 0.563895    1.026713    3.478313    0.458858    0.084945    0.019583    0.699134    
#> 043: 0.582529    1.038824    3.475812    0.531577    0.083103    0.018604    0.693518    
#> 044: 0.534038    1.041075    3.476175    0.504998    0.078948    0.018944    0.706995    
#> 045: 0.503995    1.054693    3.462897    0.479748    0.081278    0.018118    0.702634    
#> 046: 0.499352    1.039762    3.458127    0.457376    0.081642    0.017212    0.694692    
#> 047: 0.533499    1.042691    3.457433    0.489680    0.077560    0.016352    0.701966    
#> 048: 0.520102    1.024292    3.464185    0.480561    0.073682    0.015534    0.718611    
#> 049: 0.536540    1.023743    3.461786    0.499316    0.084137    0.014757    0.706946    
#> 050: 0.576632    1.009022    3.463119    0.519045    0.089522    0.014400    0.727996    
#> 051: 0.554122    1.036780    3.467166    0.493093    0.085046    0.014332    0.726207    
#> 052: 0.579530    1.035468    3.484157    0.468438    0.080794    0.014422    0.713470    
#> 053: 0.603149    1.015778    3.481055    0.562559    0.076754    0.013701    0.726046    
#> 054: 0.526760    1.007234    3.478830    0.534431    0.072916    0.018621    0.722096    
#> 055: 0.546565    1.015847    3.475611    0.507709    0.070307    0.017690    0.728945    
#> 056: 0.590278    1.010243    3.480474    0.597379    0.090968    0.016805    0.713244    
#> 057: 0.612115    0.999614    3.485851    0.601225    0.086419    0.015965    0.728201    
#> 058: 0.601655    1.032039    3.477976    0.571387    0.090343    0.015167    0.714664    
#> 059: 0.578199    0.984619    3.486767    0.542818    0.088761    0.015248    0.737393    
#> 060: 0.599670    0.988017    3.497263    0.588308    0.084323    0.016611    0.736720    
#> 061: 0.627006    0.999997    3.501776    0.558892    0.080107    0.021167    0.754202    
#> 062: 0.627080    0.999156    3.506387    0.646162    0.076101    0.023828    0.748293    
#> 063: 0.697920    0.977200    3.497640    0.767195    0.082565    0.023540    0.754780    
#> 064: 0.618917    1.004042    3.496921    0.728835    0.079421    0.022363    0.744669    
#> 065: 0.639671    1.009809    3.486377    0.692393    0.076225    0.021245    0.732443    
#> 066: 0.600618    1.028729    3.480349    0.657773    0.072414    0.020182    0.712835    
#> 067: 0.581072    1.003011    3.476103    0.624885    0.082031    0.019173    0.687524    
#> 068: 0.521965    1.027387    3.473399    0.593641    0.077930    0.019740    0.712471    
#> 069: 0.530977    1.044710    3.468855    0.563958    0.080426    0.020494    0.727454    
#> 070: 0.567977    1.025658    3.480312    0.535761    0.076405    0.021284    0.708891    
#> 071: 0.524047    1.032530    3.461005    0.508973    0.072585    0.020220    0.715170    
#> 072: 0.528315    1.016780    3.466684    0.483524    0.077017    0.019209    0.705841    
#> 073: 0.524936    1.039414    3.472158    0.459348    0.081082    0.018249    0.706119    
#> 074: 0.540657    1.015829    3.480486    0.436380    0.077028    0.017336    0.709666    
#> 075: 0.562932    0.997224    3.503289    0.421744    0.080982    0.017614    0.709001    
#> 076: 0.596744    1.020245    3.499668    0.431993    0.076933    0.017102    0.719275    
#> 077: 0.621781    1.009258    3.495773    0.445863    0.089494    0.016247    0.733121    
#> 078: 0.589573    1.012645    3.499697    0.521993    0.088712    0.016084    0.707200    
#> 079: 0.617525    1.022521    3.507058    0.495893    0.084276    0.021545    0.714466    
#> 080: 0.622950    0.991384    3.506664    0.474260    0.080063    0.022600    0.704196    
#> 081: 0.606991    1.005533    3.505119    0.471931    0.076059    0.021470    0.710116    
#> 082: 0.576296    1.003993    3.504175    0.448335    0.072256    0.021053    0.738538    
#> 083: 0.582567    1.053627    3.492820    0.456859    0.078258    0.021606    0.727005    
#> 084: 0.546355    1.033279    3.481361    0.434016    0.083728    0.021093    0.723702    
#> 085: 0.576128    1.040560    3.494693    0.426072    0.083680    0.020885    0.727685    
#> 086: 0.541044    1.021990    3.497153    0.405049    0.086089    0.019840    0.730438    
#> 087: 0.559198    1.015524    3.483667    0.471173    0.083743    0.018848    0.709426    
#> 088: 0.494680    1.013688    3.470869    0.471271    0.079556    0.017906    0.734050    
#> 089: 0.534332    1.048283    3.464267    0.463447    0.083953    0.017290    0.731554    
#> 090: 0.535097    1.045288    3.469537    0.457652    0.079755    0.018048    0.721157    
#> 091: 0.541074    1.023108    3.460669    0.434769    0.081936    0.018717    0.721117    
#> 092: 0.533393    1.040291    3.460217    0.461989    0.097797    0.018850    0.721354    
#> 093: 0.485137    1.036207    3.452498    0.519711    0.100390    0.017907    0.717095    
#> 094: 0.527220    1.042787    3.457549    0.547864    0.095371    0.017012    0.724626    
#> 095: 0.531034    1.046689    3.474586    0.520471    0.090602    0.020147    0.699810    
#> 096: 0.465799    1.038580    3.462092    0.494447    0.086072    0.019140    0.699030    
#> 097: 0.540777    1.039050    3.472145    0.469725    0.092705    0.018183    0.685931    
#> 098: 0.541531    1.051137    3.475740    0.446239    0.088070    0.017273    0.709861    
#> 099: 0.513269    1.034127    3.458377    0.470968    0.083666    0.016728    0.715647    
#> 100: 0.500051    1.052973    3.462864    0.447420    0.079483    0.016880    0.691927    
#> 101: 0.491477    1.041481    3.445182    0.521703    0.075509    0.016146    0.696168    
#> 102: 0.482530    1.033563    3.440565    0.495618    0.078461    0.016127    0.708667    
#> 103: 0.502216    1.051581    3.451830    0.482276    0.082757    0.019449    0.695416    
#> 104: 0.492769    1.040538    3.463498    0.488133    0.078619    0.019253    0.727533    
#> 105: 0.537743    1.027014    3.467032    0.517399    0.079167    0.018290    0.744037    
#> 106: 0.592388    1.017208    3.479206    0.540916    0.080361    0.017376    0.732822    
#> 107: 0.575804    1.026846    3.474036    0.553169    0.086190    0.016803    0.706583    
#> 108: 0.557906    1.017792    3.470561    0.607634    0.082967    0.015963    0.721012    
#> 109: 0.603939    1.007848    3.485070    0.577253    0.081737    0.016827    0.692681    
#> 110: 0.595854    1.001549    3.475070    0.559870    0.085753    0.015985    0.709466    
#> 111: 0.593847    1.009741    3.487129    0.531877    0.081465    0.015186    0.700441    
#> 112: 0.540422    1.000649    3.465623    0.505283    0.077392    0.014427    0.717862    
#> 113: 0.521034    1.034512    3.468847    0.530614    0.085112    0.013706    0.701455    
#> 114: 0.601669    1.036938    3.477149    0.602393    0.089321    0.013020    0.713500    
#> 115: 0.558778    1.000863    3.485432    0.572273    0.101197    0.014548    0.717385    
#> 116: 0.589289    1.024946    3.484092    0.543660    0.100915    0.013820    0.704740    
#> 117: 0.537266    1.026865    3.480394    0.516477    0.095869    0.013129    0.717466    
#> 118: 0.573791    0.999578    3.488303    0.564350    0.092194    0.013298    0.724425    
#> 119: 0.610854    1.018983    3.478065    0.586677    0.087584    0.019694    0.735428    
#> 120: 0.515533    1.004803    3.476856    0.557343    0.083205    0.019177    0.730033    
#> 121: 0.564298    1.036363    3.473593    0.529476    0.079045    0.019398    0.734342    
#> 122: 0.557726    1.025104    3.478207    0.525652    0.075092    0.018600    0.716251    
#> 123: 0.611983    1.033155    3.472977    0.583222    0.071338    0.018603    0.719577    
#> 124: 0.572784    1.080164    3.464006    0.577085    0.074060    0.017885    0.720545    
#> 125: 0.570505    1.065998    3.455744    0.611927    0.072306    0.016991    0.708246    
#> 126: 0.509096    1.065400    3.441418    0.581331    0.083502    0.016873    0.701644    
#> 127: 0.513915    1.045408    3.430971    0.613650    0.091918    0.016030    0.709887    
#> 128: 0.512195    1.045259    3.448234    0.632649    0.090139    0.016873    0.716740    
#> 129: 0.552920    1.040836    3.451822    0.670557    0.094981    0.016029    0.721646    
#> 130: 0.555997    1.064231    3.443701    0.637029    0.090232    0.017867    0.705586    
#> 131: 0.517265    1.041677    3.440183    0.605178    0.085720    0.019992    0.711503    
#> 132: 0.501916    1.066179    3.432857    0.574919    0.081434    0.018992    0.719665    
#> 133: 0.522557    1.052508    3.443595    0.754663    0.086065    0.020738    0.709646    
#> 134: 0.552768    1.034878    3.472812    0.720664    0.081762    0.021855    0.709609    
#> 135: 0.548170    1.027793    3.468858    0.684631    0.077674    0.021834    0.708779    
#> 136: 0.539476    1.035683    3.466557    0.650399    0.073790    0.022684    0.692369    
#> 137: 0.543303    1.026937    3.461709    0.617879    0.079091    0.021549    0.717670    
#> 138: 0.527469    1.041778    3.457982    0.586985    0.079716    0.020472    0.700838    
#> 139: 0.520938    1.041219    3.468777    0.557636    0.075730    0.020997    0.714986    
#> 140: 0.534366    1.052069    3.467125    0.529754    0.078627    0.021241    0.700133    
#> 141: 0.518818    1.040887    3.466363    0.529748    0.090497    0.020512    0.718319    
#> 142: 0.584979    1.014457    3.486957    0.569921    0.085973    0.019486    0.709730    
#> 143: 0.535505    1.036610    3.467295    0.659485    0.102605    0.018512    0.716738    
#> 144: 0.599048    1.025036    3.481036    0.626511    0.097475    0.017586    0.710109    
#> 145: 0.596071    1.062422    3.469264    0.608535    0.100458    0.016707    0.706440    
#> 146: 0.559938    1.045871    3.480555    0.578109    0.099033    0.015872    0.704992    
#> 147: 0.541663    1.022786    3.472019    0.555794    0.094081    0.015078    0.697005    
#> 148: 0.573903    1.039469    3.479324    0.619294    0.101656    0.014996    0.685675    
#> 149: 0.561821    1.008434    3.488077    0.588329    0.102546    0.014246    0.701140    
#> 150: 0.571187    1.013845    3.473565    0.558913    0.097419    0.015682    0.713661    
#> 151: 0.541055    1.031284    3.476135    0.530967    0.092548    0.018072    0.707098    
#> 152: 0.527627    1.037123    3.479431    0.489470    0.091924    0.017033    0.701814    
#> 153: 0.559093    1.041171    3.475672    0.459440    0.088265    0.015844    0.707534    
#> 154: 0.564355    1.042210    3.479296    0.463836    0.088056    0.015655    0.717723    
#> 155: 0.526965    1.024508    3.467783    0.438665    0.093940    0.013131    0.702836    
#> 156: 0.561440    1.029365    3.484216    0.406946    0.092326    0.011911    0.731445    
#> 157: 0.579268    1.013349    3.493569    0.394838    0.094117    0.014343    0.718315    
#> 158: 0.632278    1.026746    3.487425    0.496716    0.088004    0.012958    0.694578    
#> 159: 0.538807    1.036303    3.490065    0.413100    0.086593    0.011499    0.729448    
#> 160: 0.594924    0.989685    3.496365    0.485237    0.076066    0.011977    0.728704    
#> 161: 0.565203    1.011433    3.490226    0.433976    0.066370    0.014363    0.731316    
#> 162: 0.555995    1.032094    3.470795    0.423375    0.078274    0.013930    0.721526    
#> 163: 0.561693    1.058430    3.468700    0.391821    0.082228    0.015521    0.717364    
#> 164: 0.560313    1.045782    3.460352    0.514461    0.074300    0.016510    0.707660    
#> 165: 0.530061    1.032140    3.463475    0.475538    0.075686    0.014836    0.714509    
#> 166: 0.511208    1.057464    3.458069    0.404793    0.079467    0.017623    0.721805    
#> 167: 0.574424    1.067695    3.470842    0.456428    0.078977    0.015741    0.724980    
#> 168: 0.583861    1.061758    3.479189    0.408677    0.080120    0.014024    0.724674    
#> 169: 0.547674    1.069661    3.460882    0.409911    0.094854    0.012678    0.744957    
#> 170: 0.561889    1.046527    3.461258    0.432553    0.080958    0.011730    0.724438    
#> 171: 0.512608    1.039092    3.455366    0.457468    0.088255    0.013310    0.697310    
#> 172: 0.497174    1.057741    3.458665    0.480172    0.085866    0.014767    0.703468    
#> 173: 0.502963    1.061612    3.441371    0.481503    0.080763    0.017106    0.713018    
#> 174: 0.505011    1.051594    3.459999    0.449471    0.084730    0.014827    0.735376    
#> 175: 0.476264    1.065922    3.442409    0.544642    0.090218    0.018115    0.718355    
#> 176: 0.486695    1.084169    3.448800    0.445349    0.091778    0.014225    0.711029    
#> 177: 0.494473    1.069355    3.455172    0.460983    0.087339    0.018042    0.713657    
#> 178: 0.528999    1.036009    3.463657    0.542574    0.088158    0.015462    0.715533    
#> 179: 0.551296    1.061792    3.469405    0.413535    0.067967    0.014248    0.719526    
#> 180: 0.526755    1.053368    3.464590    0.463790    0.085557    0.012430    0.704696    
#> 181: 0.533582    1.041881    3.446271    0.465910    0.074975    0.008744    0.743390    
#> 182: 0.503828    1.063657    3.441261    0.462060    0.085968    0.008896    0.737621    
#> 183: 0.505600    1.076575    3.443532    0.418848    0.097219    0.006117    0.743183    
#> 184: 0.474570    1.054404    3.449613    0.382705    0.109273    0.006098    0.734284    
#> 185: 0.499255    1.043988    3.450921    0.443677    0.108355    0.007880    0.723659    
#> 186: 0.493643    1.056872    3.454002    0.467296    0.091307    0.009409    0.727775    
#> 187: 0.535313    1.029922    3.463888    0.452766    0.082107    0.011409    0.705343    
#> 188: 0.508418    1.052647    3.461769    0.453759    0.090490    0.013442    0.709309    
#> 189: 0.527559    1.048770    3.468449    0.443169    0.089593    0.014456    0.720964    
#> 190: 0.514097    1.038003    3.471161    0.470876    0.073785    0.012315    0.700257    
#> 191: 0.514289    1.035394    3.466392    0.413123    0.067666    0.013517    0.692491    
#> 192: 0.518441    1.046987    3.462547    0.473146    0.089722    0.015232    0.686610    
#> 193: 0.557194    1.042302    3.475229    0.438852    0.085375    0.015491    0.701815    
#> 194: 0.549490    1.029962    3.470807    0.465939    0.064751    0.014919    0.718918    
#> 195: 0.527417    1.035955    3.463142    0.490066    0.063248    0.016185    0.720154    
#> 196: 0.547448    1.026489    3.472755    0.512380    0.059509    0.015678    0.734882    
#> 197: 0.512996    1.044118    3.486113    0.495203    0.063709    0.018647    0.723342    
#> 198: 0.544892    1.038305    3.471641    0.489911    0.075426    0.020502    0.705226    
#> 199: 0.524661    1.017219    3.468467    0.449085    0.080080    0.016196    0.705346    
#> 200: 0.550032    1.021002    3.476694    0.545361    0.080546    0.015151    0.722684    
#> 201: 0.546540    1.014123    3.482746    0.553810    0.082167    0.016023    0.713868    
#> 202: 0.546893    1.020591    3.480344    0.541051    0.082728    0.016525    0.717953    
#> 203: 0.560551    1.021227    3.478272    0.556529    0.083892    0.017362    0.721756    
#> 204: 0.566117    1.019666    3.478034    0.560972    0.085787    0.016834    0.726680    
#> 205: 0.558038    1.023441    3.475340    0.552340    0.085472    0.016742    0.729288    
#> 206: 0.550140    1.028773    3.475092    0.550097    0.085993    0.016378    0.730358    
#> 207: 0.542781    1.032050    3.471625    0.554121    0.088515    0.015800    0.730217    
#> 208: 0.538629    1.033232    3.469271    0.544191    0.087931    0.015683    0.727588    
#> 209: 0.536493    1.032062    3.468153    0.534746    0.088123    0.015502    0.726073    
#> 210: 0.536671    1.032207    3.467900    0.530927    0.088016    0.015460    0.724363    
#> 211: 0.539726    1.032208    3.468914    0.525937    0.086502    0.015623    0.723898    
#> 212: 0.542777    1.031690    3.469948    0.524192    0.087179    0.015713    0.722595    
#> 213: 0.546911    1.030527    3.470365    0.525189    0.088177    0.015736    0.722869    
#> 214: 0.547656    1.030900    3.471087    0.520794    0.088743    0.015576    0.723102    
#> 215: 0.548674    1.030604    3.471822    0.512934    0.090767    0.015295    0.722785    
#> 216: 0.552489    1.029870    3.472233    0.509668    0.091304    0.015044    0.723644    
#> 217: 0.551747    1.030222    3.472269    0.504231    0.091813    0.014959    0.723971    
#> 218: 0.552506    1.031061    3.471828    0.505606    0.092189    0.014938    0.723529    
#> 219: 0.550772    1.030434    3.471404    0.507323    0.091732    0.015069    0.723052    
#> 220: 0.549002    1.030337    3.471093    0.511743    0.092058    0.015151    0.723769    
#> 221: 0.547884    1.030763    3.470557    0.511200    0.091874    0.015135    0.723490    
#> 222: 0.546456    1.031402    3.469895    0.511036    0.091707    0.015239    0.723204    
#> 223: 0.546601    1.031877    3.469441    0.509016    0.091315    0.015314    0.722498    
#> 224: 0.547908    1.032899    3.469626    0.508992    0.091364    0.015403    0.721977    
#> 225: 0.546580    1.032525    3.469565    0.507129    0.091008    0.015641    0.721758    
#> 226: 0.546438    1.032275    3.469120    0.506538    0.090739    0.015823    0.721224    
#> 227: 0.546204    1.031975    3.469248    0.505679    0.090726    0.015902    0.720976    
#> 228: 0.546524    1.032278    3.469086    0.507707    0.090834    0.016048    0.720010    
#> 229: 0.545762    1.032290    3.468740    0.509650    0.090183    0.016225    0.719451    
#> 230: 0.545522    1.032338    3.468553    0.511395    0.090093    0.016288    0.718770    
#> 231: 0.545968    1.032226    3.468871    0.511366    0.090435    0.016266    0.718733    
#> 232: 0.545693    1.032391    3.469098    0.509798    0.090446    0.016293    0.718492    
#> 233: 0.544772    1.031333    3.469284    0.507589    0.090842    0.016378    0.718637    
#> 234: 0.544198    1.031000    3.469240    0.506608    0.090768    0.016526    0.718418    
#> 235: 0.543508    1.031548    3.468824    0.505939    0.091162    0.016524    0.718541    
#> 236: 0.543746    1.032077    3.468691    0.506932    0.091296    0.016442    0.718940    
#> 237: 0.544587    1.032436    3.468632    0.506810    0.091280    0.016478    0.719453    
#> 238: 0.544462    1.032748    3.468439    0.504381    0.091054    0.016501    0.719914    
#> 239: 0.543486    1.033619    3.468164    0.503618    0.091136    0.016437    0.719747    
#> 240: 0.543081    1.033494    3.468199    0.504435    0.091071    0.016343    0.719636    
#> 241: 0.543676    1.032665    3.468594    0.503800    0.091081    0.016254    0.719818    
#> 242: 0.543952    1.032245    3.468510    0.502023    0.091074    0.016181    0.720921    
#> 243: 0.544341    1.032483    3.468774    0.501806    0.090600    0.016183    0.721460    
#> 244: 0.544140    1.032696    3.468908    0.502454    0.090356    0.016135    0.721461    
#> 245: 0.544768    1.032349    3.469209    0.502485    0.090205    0.016226    0.721219    
#> 246: 0.545345    1.032070    3.469301    0.502165    0.090306    0.016285    0.721253    
#> 247: 0.545741    1.032238    3.469477    0.503946    0.090427    0.016385    0.720864    
#> 248: 0.545148    1.032781    3.469379    0.503161    0.090482    0.016511    0.720415    
#> 249: 0.544405    1.033267    3.469175    0.504153    0.090283    0.016609    0.720016    
#> 250: 0.544257    1.033836    3.468984    0.503855    0.090040    0.016639    0.720048    
#> 251: 0.543903    1.034352    3.468962    0.504391    0.090163    0.016605    0.719856    
#> 252: 0.544099    1.034561    3.468974    0.502786    0.089954    0.016605    0.720070    
#> 253: 0.543835    1.034576    3.468838    0.502723    0.089714    0.016567    0.719969    
#> 254: 0.543906    1.034904    3.468821    0.502804    0.089422    0.016551    0.719529    
#> 255: 0.544479    1.035414    3.468840    0.503185    0.089362    0.016567    0.719224    
#> 256: 0.545048    1.035438    3.468822    0.503943    0.089116    0.016597    0.718982    
#> 257: 0.545429    1.035215    3.468678    0.505209    0.088874    0.016648    0.718952    
#> 258: 0.544669    1.034959    3.468724    0.505505    0.088849    0.016650    0.718814    
#> 259: 0.544266    1.034737    3.468742    0.504994    0.088823    0.016652    0.718450    
#> 260: 0.543684    1.034737    3.468849    0.504111    0.088669    0.016655    0.718339    
#> 261: 0.543986    1.034597    3.468913    0.503110    0.088430    0.016658    0.718445    
#> 262: 0.543921    1.035003    3.468999    0.503501    0.088404    0.016675    0.718105    
#> 263: 0.544154    1.035445    3.468995    0.503763    0.088397    0.016705    0.718023    
#> 264: 0.544473    1.035834    3.468940    0.505790    0.088628    0.016640    0.717862    
#> 265: 0.544718    1.036166    3.468888    0.506361    0.088924    0.016609    0.717667    
#> 266: 0.544723    1.036495    3.468936    0.506281    0.089032    0.016582    0.717749    
#> 267: 0.544705    1.036765    3.469006    0.505686    0.088860    0.016517    0.717762    
#> 268: 0.544878    1.036984    3.468797    0.505732    0.088730    0.016434    0.717594    
#> 269: 0.545094    1.037270    3.468618    0.506731    0.088635    0.016371    0.717535    
#> 270: 0.544751    1.037644    3.468456    0.506327    0.088553    0.016302    0.717290    
#> 271: 0.544307    1.037913    3.468249    0.506314    0.088425    0.016211    0.717544    
#> 272: 0.544321    1.037821    3.468100    0.506086    0.088428    0.016196    0.717865    
#> 273: 0.544418    1.038076    3.468219    0.505096    0.088496    0.016172    0.718038    
#> 274: 0.544667    1.038275    3.468388    0.503939    0.088717    0.016133    0.718303    
#> 275: 0.544526    1.038630    3.468261    0.503564    0.088572    0.016116    0.718220    
#> 276: 0.544175    1.038890    3.468426    0.503437    0.088565    0.016144    0.718144    
#> 277: 0.543829    1.039087    3.468498    0.503125    0.088551    0.016161    0.717921    
#> 278: 0.543581    1.039345    3.468521    0.502859    0.088565    0.016153    0.717929    
#> 279: 0.543006    1.039101    3.468591    0.502310    0.088571    0.016180    0.718030    
#> 280: 0.543206    1.039158    3.468750    0.500813    0.088416    0.016199    0.717931    
#> 281: 0.542965    1.039284    3.468811    0.499840    0.088361    0.016179    0.717885    
#> 282: 0.542517    1.039319    3.468890    0.498719    0.088257    0.016123    0.718026    
#> 283: 0.542614    1.039128    3.469015    0.498291    0.088199    0.016094    0.718280    
#> 284: 0.542812    1.038726    3.468989    0.498306    0.088137    0.016069    0.718525    
#> 285: 0.542562    1.038619    3.468912    0.497195    0.088249    0.016044    0.718614    
#> 286: 0.542244    1.038645    3.468844    0.496406    0.088002    0.016051    0.718713    
#> 287: 0.542088    1.038784    3.468768    0.496770    0.087935    0.016071    0.718636    
#> 288: 0.542214    1.038680    3.468794    0.495823    0.087688    0.016134    0.718559    
#> 289: 0.542580    1.038479    3.468942    0.495088    0.087490    0.016193    0.718536    
#> 290: 0.542840    1.038233    3.469131    0.494216    0.087548    0.016224    0.718694    
#> 291: 0.542889    1.038169    3.469336    0.492717    0.087514    0.016209    0.718693    
#> 292: 0.543129    1.038103    3.469413    0.493014    0.087407    0.016224    0.718564    
#> 293: 0.543586    1.037963    3.469416    0.494205    0.087214    0.016225    0.718493    
#> 294: 0.543947    1.037844    3.469452    0.494850    0.087044    0.016247    0.718365    
#> 295: 0.544158    1.037168    3.469647    0.494760    0.086903    0.016294    0.718284    
#> 296: 0.544354    1.036785    3.469819    0.494487    0.086878    0.016322    0.718475    
#> 297: 0.544475    1.036745    3.469856    0.494482    0.086856    0.016326    0.718642    
#> 298: 0.544573    1.036704    3.469889    0.494837    0.086758    0.016315    0.718544    
#> 299: 0.544699    1.036673    3.469837    0.494071    0.086730    0.016297    0.718335    
#> 300: 0.544846    1.036720    3.469878    0.493378    0.086676    0.016299    0.718090    
#> 301: 0.545008    1.036743    3.469845    0.493570    0.086666    0.016290    0.717978    
#> 302: 0.544984    1.036758    3.469773    0.493645    0.086584    0.016272    0.717873    
#> 303: 0.544440    1.037028    3.469708    0.492974    0.086704    0.016245    0.717728    
#> 304: 0.544289    1.037164    3.469613    0.493417    0.086848    0.016243    0.717466    
#> 305: 0.544252    1.037022    3.469585    0.494191    0.086771    0.016262    0.717312    
#> 306: 0.544014    1.036966    3.469463    0.494933    0.086740    0.016275    0.717163    
#> 307: 0.543872    1.036838    3.469341    0.494713    0.086633    0.016256    0.717291    
#> 308: 0.543477    1.036757    3.469321    0.494188    0.086606    0.016233    0.717225    
#> 309: 0.543543    1.036625    3.469311    0.493990    0.086624    0.016249    0.717284    
#> 310: 0.543797    1.036582    3.469201    0.493932    0.086440    0.016261    0.717603    
#> 311: 0.543838    1.036609    3.469250    0.494039    0.086380    0.016289    0.717677    
#> 312: 0.543695    1.036583    3.469277    0.493483    0.086333    0.016317    0.717705    
#> 313: 0.543528    1.036330    3.469343    0.492370    0.086308    0.016339    0.717784    
#> 314: 0.543172    1.036348    3.469249    0.491847    0.086292    0.016368    0.717691    
#> 315: 0.543072    1.036369    3.469184    0.491399    0.086368    0.016367    0.717534    
#> 316: 0.542817    1.036389    3.469142    0.490842    0.086293    0.016358    0.717509    
#> 317: 0.542949    1.036372    3.469202    0.491170    0.086257    0.016330    0.717617    
#> 318: 0.543150    1.036459    3.469163    0.490899    0.086255    0.016319    0.717502    
#> 319: 0.543101    1.036500    3.469137    0.490563    0.086202    0.016309    0.717408    
#> 320: 0.542949    1.036563    3.469051    0.490674    0.086207    0.016292    0.717293    
#> 321: 0.542662    1.036708    3.468899    0.490101    0.086169    0.016281    0.717357    
#> 322: 0.542575    1.036719    3.468769    0.489739    0.086105    0.016302    0.717291    
#> 323: 0.542286    1.036719    3.468737    0.489612    0.085992    0.016320    0.717345    
#> 324: 0.542315    1.036913    3.468772    0.489489    0.086009    0.016326    0.717103    
#> 325: 0.542336    1.037131    3.468734    0.489692    0.085957    0.016286    0.717035    
#> 326: 0.542280    1.037065    3.468645    0.489962    0.085970    0.016272    0.716917    
#> 327: 0.542406    1.037075    3.468604    0.490256    0.085986    0.016271    0.716842    
#> 328: 0.542460    1.037082    3.468554    0.491109    0.085994    0.016267    0.716643    
#> 329: 0.542553    1.037179    3.468491    0.491860    0.085950    0.016271    0.716544    
#> 330: 0.541878    1.037232    3.468398    0.492069    0.085887    0.016250    0.716482    
#> 331: 0.541684    1.037403    3.468354    0.491531    0.086009    0.016232    0.716312    
#> 332: 0.541629    1.037383    3.468421    0.490849    0.086161    0.016201    0.716415    
#> 333: 0.541423    1.037324    3.468372    0.490446    0.086264    0.016201    0.716475    
#> 334: 0.541153    1.037157    3.468323    0.490268    0.086424    0.016193    0.716494    
#> 335: 0.540742    1.037204    3.468277    0.490014    0.086364    0.016189    0.716488    
#> 336: 0.540146    1.037344    3.468230    0.489434    0.086356    0.016201    0.716446    
#> 337: 0.539910    1.037722    3.468143    0.489346    0.086428    0.016208    0.716442    
#> 338: 0.539924    1.037832    3.468185    0.489275    0.086433    0.016233    0.716390    
#> 339: 0.539811    1.037876    3.468117    0.488999    0.086494    0.016233    0.716271    
#> 340: 0.539802    1.037692    3.468078    0.488742    0.086473    0.016239    0.716400    
#> 341: 0.539940    1.037616    3.468164    0.488877    0.086498    0.016230    0.716472    
#> 342: 0.539764    1.037407    3.468186    0.488793    0.086542    0.016228    0.716479    
#> 343: 0.539638    1.037469    3.468261    0.488697    0.086501    0.016202    0.716482    
#> 344: 0.539845    1.037519    3.468342    0.488737    0.086457    0.016204    0.716566    
#> 345: 0.540077    1.037272    3.468447    0.488713    0.086248    0.016213    0.716665    
#> 346: 0.540091    1.037267    3.468362    0.488620    0.086235    0.016196    0.716718    
#> 347: 0.540042    1.037246    3.468244    0.488331    0.086177    0.016178    0.716825    
#> 348: 0.539689    1.037310    3.468093    0.488552    0.086121    0.016163    0.716948    
#> 349: 0.539537    1.037333    3.467947    0.488609    0.086091    0.016135    0.717082    
#> 350: 0.538958    1.037229    3.467784    0.488702    0.086127    0.016111    0.717176    
#> 351: 0.538818    1.037283    3.467615    0.488821    0.086112    0.016105    0.717311    
#> 352: 0.538485    1.037452    3.467498    0.488885    0.086064    0.016142    0.717405    
#> 353: 0.538528    1.037621    3.467433    0.488803    0.086026    0.016180    0.717344    
#> 354: 0.538370    1.037598    3.467291    0.488908    0.086084    0.016202    0.717319    
#> 355: 0.538562    1.037476    3.467222    0.489056    0.086148    0.016227    0.717316    
#> 356: 0.538741    1.037392    3.467300    0.488536    0.086060    0.016226    0.717475    
#> 357: 0.539081    1.037458    3.467292    0.488926    0.085982    0.016199    0.717532    
#> 358: 0.539211    1.037662    3.467352    0.489009    0.086046    0.016186    0.717483    
#> 359: 0.539164    1.037899    3.467369    0.488783    0.086086    0.016170    0.717540    
#> 360: 0.538966    1.037979    3.467264    0.488282    0.086000    0.016170    0.717560    
#> 361: 0.538748    1.037983    3.467221    0.488093    0.085947    0.016171    0.717610    
#> 362: 0.539082    1.037922    3.467185    0.488860    0.085906    0.016167    0.717466    
#> 363: 0.539147    1.037792    3.467152    0.489570    0.085924    0.016164    0.717327    
#> 364: 0.539264    1.037789    3.467153    0.489711    0.085907    0.016167    0.717319    
#> 365: 0.539353    1.037813    3.467178    0.489793    0.085945    0.016183    0.717251    
#> 366: 0.539194    1.037855    3.467068    0.489654    0.085895    0.016180    0.717385    
#> 367: 0.539103    1.037806    3.467082    0.489378    0.085888    0.016188    0.717315    
#> 368: 0.539253    1.037858    3.467046    0.489435    0.085837    0.016206    0.717255    
#> 369: 0.539071    1.037832    3.467071    0.489524    0.085750    0.016233    0.717354    
#> 370: 0.539224    1.037773    3.467128    0.489430    0.085752    0.016269    0.717350    
#> 371: 0.539029    1.037777    3.467098    0.488887    0.085777    0.016281    0.717272    
#> 372: 0.538804    1.037788    3.467068    0.488402    0.085817    0.016272    0.717143    
#> 373: 0.538602    1.037910    3.466992    0.488030    0.085780    0.016271    0.717158    
#> 374: 0.538656    1.037880    3.466983    0.487457    0.085725    0.016281    0.717110    
#> 375: 0.538839    1.037867    3.467045    0.487031    0.085700    0.016295    0.717008    
#> 376: 0.538857    1.037888    3.467088    0.486788    0.085624    0.016294    0.716871    
#> 377: 0.538765    1.037941    3.467122    0.486773    0.085621    0.016281    0.716814    
#> 378: 0.538764    1.037955    3.467100    0.486886    0.085540    0.016275    0.716802    
#> 379: 0.538725    1.037782    3.467094    0.487078    0.085435    0.016266    0.716698    
#> 380: 0.538892    1.037726    3.467144    0.487021    0.085316    0.016278    0.716591    
#> 381: 0.538854    1.037739    3.467139    0.486995    0.085300    0.016281    0.716434    
#> 382: 0.538727    1.037725    3.467119    0.486720    0.085205    0.016263    0.716293    
#> 383: 0.538740    1.037719    3.467082    0.486928    0.085188    0.016233    0.716278    
#> 384: 0.538572    1.037748    3.467022    0.487229    0.085229    0.016223    0.716193    
#> 385: 0.538754    1.037748    3.467023    0.487812    0.085284    0.016218    0.716155    
#> 386: 0.538954    1.037893    3.467065    0.487991    0.085323    0.016213    0.716195    
#> 387: 0.539308    1.037913    3.467136    0.488306    0.085260    0.016216    0.716241    
#> 388: 0.539413    1.037902    3.467215    0.488112    0.085304    0.016214    0.716287    
#> 389: 0.539444    1.037734    3.467217    0.487701    0.085415    0.016201    0.716370    
#> 390: 0.539529    1.037853    3.467153    0.488001    0.085445    0.016189    0.716341    
#> 391: 0.539683    1.037850    3.467108    0.488249    0.085426    0.016184    0.716216    
#> 392: 0.539535    1.037860    3.467103    0.488150    0.085426    0.016172    0.716174    
#> 393: 0.539427    1.037760    3.467076    0.488231    0.085487    0.016162    0.716054    
#> 394: 0.539556    1.037733    3.467075    0.488368    0.085455    0.016146    0.716023    
#> 395: 0.539791    1.037774    3.467136    0.488730    0.085483    0.016140    0.715946    
#> 396: 0.539943    1.037808    3.467166    0.488928    0.085567    0.016138    0.715874    
#> 397: 0.540028    1.037724    3.467251    0.489161    0.085586    0.016140    0.715828    
#> 398: 0.540347    1.037668    3.467343    0.489207    0.085628    0.016133    0.715742    
#> 399: 0.540591    1.037542    3.467477    0.488841    0.085529    0.016119    0.715781    
#> 400: 0.540950    1.037607    3.467587    0.488742    0.085563    0.016112    0.715742    
#> 401: 0.541123    1.037644    3.467653    0.488562    0.085614    0.016109    0.715797    
#> 402: 0.541223    1.037798    3.467667    0.488181    0.085672    0.016102    0.715801    
#> 403: 0.541430    1.037779    3.467646    0.488354    0.085720    0.016069    0.715923    
#> 404: 0.541541    1.037737    3.467579    0.488624    0.085688    0.016060    0.715903    
#> 405: 0.541449    1.037669    3.467569    0.488927    0.085715    0.016058    0.715887    
#> 406: 0.541438    1.037703    3.467507    0.489650    0.085666    0.016069    0.715797    
#> 407: 0.541562    1.037751    3.467548    0.489968    0.085635    0.016062    0.715818    
#> 408: 0.541773    1.037872    3.467570    0.490106    0.085734    0.016054    0.715754    
#> 409: 0.541816    1.037812    3.467563    0.490119    0.085747    0.016037    0.715657    
#> 410: 0.541901    1.037804    3.467552    0.490060    0.085723    0.016034    0.715603    
#> 411: 0.542030    1.037579    3.467590    0.489967    0.085641    0.016030    0.715601    
#> 412: 0.542088    1.037628    3.467585    0.490051    0.085586    0.016025    0.715614    
#> 413: 0.542048    1.037678    3.467550    0.490294    0.085514    0.016019    0.715597    
#> 414: 0.541898    1.037627    3.467562    0.490544    0.085468    0.016020    0.715521    
#> 415: 0.541934    1.037752    3.467508    0.490763    0.085427    0.016021    0.715532    
#> 416: 0.542009    1.037879    3.467458    0.491070    0.085372    0.016009    0.715480    
#> 417: 0.541809    1.037923    3.467397    0.490934    0.085330    0.015994    0.715510    
#> 418: 0.541670    1.037936    3.467346    0.490981    0.085291    0.015990    0.715463    
#> 419: 0.541381    1.038036    3.467271    0.490592    0.085275    0.015977    0.715499    
#> 420: 0.541409    1.038101    3.467253    0.490472    0.085274    0.015967    0.715405    
#> 421: 0.541255    1.038174    3.467249    0.490339    0.085204    0.015968    0.715391    
#> 422: 0.541450    1.038118    3.467250    0.490338    0.085165    0.015959    0.715405    
#> 423: 0.541693    1.038018    3.467293    0.490343    0.085153    0.015960    0.715385    
#> 424: 0.541609    1.037955    3.467269    0.490077    0.085096    0.015954    0.715415    
#> 425: 0.541776    1.037959    3.467227    0.490253    0.085077    0.015955    0.715397    
#> 426: 0.541727    1.038204    3.467212    0.490503    0.085191    0.015959    0.715328    
#> 427: 0.541596    1.038262    3.467228    0.490418    0.085266    0.015958    0.715276    
#> 428: 0.541613    1.038353    3.467248    0.490514    0.085279    0.015956    0.715248    
#> 429: 0.541706    1.038344    3.467287    0.490493    0.085229    0.015965    0.715230    
#> 430: 0.541623    1.038404    3.467248    0.490641    0.085220    0.015965    0.715142    
#> 431: 0.541423    1.038440    3.467198    0.490642    0.085214    0.015958    0.715091    
#> 432: 0.541276    1.038543    3.467148    0.490651    0.085237    0.015957    0.715006    
#> 433: 0.541150    1.038666    3.467137    0.490365    0.085229    0.015961    0.714940    
#> 434: 0.541046    1.038624    3.467169    0.490292    0.085192    0.015960    0.714830    
#> 435: 0.541133    1.038586    3.467166    0.490018    0.085156    0.015957    0.714725    
#> 436: 0.541164    1.038487    3.467210    0.489774    0.085155    0.015945    0.714740    
#> 437: 0.541333    1.038312    3.467270    0.489915    0.085155    0.015941    0.714717    
#> 438: 0.541465    1.038367    3.467308    0.490098    0.085104    0.015931    0.714642    
#> 439: 0.541569    1.038413    3.467342    0.490521    0.085096    0.015935    0.714555    
#> 440: 0.541550    1.038424    3.467416    0.490464    0.085041    0.015930    0.714616    
#> 441: 0.541770    1.038395    3.467488    0.490317    0.084982    0.015917    0.714540    
#> 442: 0.541702    1.038404    3.467525    0.490301    0.084928    0.015913    0.714482    
#> 443: 0.541632    1.038408    3.467530    0.490112    0.084959    0.015903    0.714430    
#> 444: 0.541395    1.038485    3.467469    0.489558    0.084962    0.015899    0.714410    
#> 445: 0.541003    1.038494    3.467386    0.489175    0.084886    0.015904    0.714497    
#> 446: 0.540667    1.038534    3.467330    0.488768    0.084833    0.015905    0.714484    
#> 447: 0.540666    1.038539    3.467346    0.488508    0.084825    0.015900    0.714463    
#> 448: 0.540606    1.038528    3.467381    0.488290    0.084819    0.015888    0.714385    
#> 449: 0.540598    1.038570    3.467463    0.488172    0.084841    0.015875    0.714405    
#> 450: 0.540683    1.038541    3.467477    0.488115    0.084850    0.015854    0.714414    
#> 451: 0.540693    1.038587    3.467460    0.488000    0.084892    0.015838    0.714414    
#> 452: 0.540623    1.038698    3.467427    0.487967    0.084871    0.015827    0.714411    
#> 453: 0.540456    1.038682    3.467408    0.487795    0.084843    0.015820    0.714367    
#> 454: 0.540386    1.038775    3.467383    0.487980    0.084811    0.015820    0.714279    
#> 455: 0.540310    1.038811    3.467359    0.488261    0.084817    0.015821    0.714270    
#> 456: 0.540316    1.038794    3.467332    0.488326    0.084828    0.015825    0.714236    
#> 457: 0.540259    1.038791    3.467361    0.488275    0.084830    0.015831    0.714137    
#> 458: 0.540270    1.038889    3.467382    0.488145    0.084842    0.015830    0.714049    
#> 459: 0.540231    1.039040    3.467399    0.487792    0.084905    0.015824    0.714016    
#> 460: 0.540095    1.039093    3.467372    0.487524    0.084972    0.015824    0.714012    
#> 461: 0.540013    1.039115    3.467358    0.487432    0.085004    0.015837    0.713996    
#> 462: 0.539810    1.039167    3.467358    0.487221    0.085050    0.015837    0.714021    
#> 463: 0.539776    1.039180    3.467350    0.487199    0.085034    0.015829    0.714018    
#> 464: 0.539876    1.039191    3.467351    0.487202    0.085031    0.015820    0.713953    
#> 465: 0.539980    1.039032    3.467389    0.487285    0.085052    0.015810    0.713859    
#> 466: 0.540193    1.039014    3.467399    0.487487    0.085025    0.015811    0.713806    
#> 467: 0.540190    1.038892    3.467455    0.487435    0.084964    0.015804    0.713788    
#> 468: 0.540446    1.038835    3.467549    0.487629    0.084939    0.015808    0.713799    
#> 469: 0.540512    1.038869    3.467646    0.487589    0.084911    0.015835    0.713859    
#> 470: 0.540567    1.038882    3.467678    0.487519    0.084830    0.015851    0.713898    
#> 471: 0.540602    1.038853    3.467699    0.487650    0.084818    0.015857    0.713875    
#> 472: 0.540677    1.038831    3.467754    0.487881    0.084767    0.015870    0.713790    
#> 473: 0.540717    1.038798    3.467758    0.487716    0.084714    0.015867    0.713739    
#> 474: 0.540692    1.038782    3.467786    0.487479    0.084677    0.015871    0.713790    
#> 475: 0.540826    1.038852    3.467796    0.487360    0.084709    0.015864    0.713812    
#> 476: 0.540745    1.038828    3.467808    0.487182    0.084712    0.015863    0.713840    
#> 477: 0.540637    1.038868    3.467793    0.487345    0.084728    0.015857    0.713773    
#> 478: 0.540520    1.038842    3.467792    0.487513    0.084744    0.015864    0.713731    
#> 479: 0.540518    1.038869    3.467774    0.487508    0.084801    0.015866    0.713680    
#> 480: 0.540499    1.038843    3.467760    0.487314    0.084850    0.015874    0.713691    
#> 481: 0.540496    1.038843    3.467740    0.487218    0.084822    0.015875    0.713745    
#> 482: 0.540642    1.038817    3.467712    0.487373    0.084840    0.015877    0.713869    
#> 483: 0.540542    1.038777    3.467731    0.487272    0.084864    0.015871    0.713926    
#> 484: 0.540645    1.038667    3.467772    0.487403    0.084889    0.015883    0.713901    
#> 485: 0.540729    1.038661    3.467809    0.487495    0.084924    0.015903    0.713928    
#> 486: 0.540726    1.038671    3.467851    0.487457    0.084901    0.015906    0.713930    
#> 487: 0.540909    1.038716    3.467930    0.487432    0.084929    0.015903    0.713900    
#> 488: 0.540945    1.038659    3.467969    0.487562    0.084936    0.015892    0.713839    
#> 489: 0.541091    1.038576    3.468004    0.487523    0.084936    0.015898    0.713816    
#> 490: 0.541318    1.038582    3.468070    0.487468    0.084924    0.015897    0.713767    
#> 491: 0.541569    1.038639    3.468102    0.487740    0.084888    0.015901    0.713684    
#> 492: 0.541609    1.038706    3.468096    0.487643    0.084881    0.015907    0.713715    
#> 493: 0.541612    1.038705    3.468115    0.487653    0.084868    0.015931    0.713687    
#> 494: 0.541769    1.038746    3.468105    0.487821    0.084836    0.015939    0.713656    
#> 495: 0.541810    1.038749    3.468118    0.487774    0.084813    0.015945    0.713618    
#> 496: 0.541894    1.038726    3.468084    0.487641    0.084785    0.015945    0.713605    
#> 497: 0.541828    1.038728    3.468059    0.487379    0.084731    0.015942    0.713693    
#> 498: 0.541866    1.038748    3.468056    0.487535    0.084678    0.015940    0.713614    
#> 499: 0.541909    1.038751    3.468033    0.487648    0.084644    0.015945    0.713538    
#> 500: 0.541854    1.038712    3.468037    0.487424    0.084626    0.015945    0.713548    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.269793    0.963456    3.449640    0.392401    0.085891    0.016800    1.680088    
#> 002: 0.325252    0.925116    3.450324    0.372781    0.085939    0.015960    1.175977    
#> 003: 0.386147    0.858221    3.451835    0.354142    0.108763    0.015162    0.873747    
#> 004: 0.363305    0.859258    3.446927    0.336435    0.103325    0.014404    0.785798    
#> 005: 0.375457    0.880256    3.425448    0.319613    0.106201    0.013684    0.742480    
#> 006: 0.326549    0.900851    3.419572    0.365534    0.105999    0.013000    0.707225    
#> 007: 0.353407    0.918156    3.421561    0.347258    0.120540    0.012350    0.706180    
#> 008: 0.312783    0.908552    3.411739    0.374616    0.126213    0.011732    0.684989    
#> 009: 0.314628    0.907210    3.403459    0.355885    0.126397    0.011146    0.688279    
#> 010: 0.298114    0.903402    3.405907    0.369340    0.136678    0.011708    0.695661    
#> 011: 0.338933    0.903307    3.412223    0.412507    0.129844    0.013376    0.690740    
#> 012: 0.367490    0.904232    3.412386    0.406395    0.123352    0.014562    0.678594    
#> 013: 0.317268    0.911652    3.412091    0.386076    0.117184    0.016791    0.683888    
#> 014: 0.353093    0.918000    3.414426    0.366772    0.111325    0.015951    0.684920    
#> 015: 0.380857    0.918533    3.429013    0.379913    0.117424    0.015154    0.670307    
#> 016: 0.378242    0.910184    3.433649    0.360918    0.120193    0.014396    0.675275    
#> 017: 0.368558    0.909506    3.436816    0.402539    0.122087    0.013676    0.655999    
#> 018: 0.385786    0.934806    3.422556    0.440361    0.135371    0.013925    0.667911    
#> 019: 0.362925    0.916475    3.420112    0.418343    0.128602    0.014803    0.664036    
#> 020: 0.358073    0.924809    3.425019    0.397426    0.122172    0.017472    0.675524    
#> 021: 0.361949    0.898292    3.430551    0.383278    0.116063    0.016599    0.668299    
#> 022: 0.357359    0.909612    3.437932    0.364114    0.112788    0.015769    0.678950    
#> 023: 0.446285    0.897391    3.451562    0.411335    0.107149    0.014980    0.702258    
#> 024: 0.453042    0.875274    3.454064    0.450301    0.101791    0.015945    0.692619    
#> 025: 0.391431    0.866802    3.440765    0.427786    0.108978    0.015148    0.678621    
#> 026: 0.382122    0.904711    3.438008    0.406397    0.105511    0.016770    0.677509    
#> 027: 0.401507    0.929323    3.428773    0.394865    0.115517    0.015931    0.678561    
#> 028: 0.402586    0.918088    3.433558    0.405782    0.109741    0.016073    0.666695    
#> 029: 0.413358    0.902848    3.422821    0.536682    0.104254    0.016840    0.679031    
#> 030: 0.411646    0.912039    3.427683    0.509848    0.123138    0.015998    0.664538    
#> 031: 0.387348    0.873687    3.440407    0.542290    0.116981    0.020464    0.660900    
#> 032: 0.396598    0.861207    3.442808    0.515175    0.111132    0.019441    0.662727    
#> 033: 0.336087    0.885906    3.433213    0.489417    0.105575    0.020818    0.678788    
#> 034: 0.380249    0.919765    3.437603    0.464946    0.108174    0.019777    0.674917    
#> 035: 0.359206    0.882628    3.430733    0.443684    0.102766    0.018788    0.660593    
#> 036: 0.409328    0.908640    3.430996    0.550253    0.117332    0.017849    0.670089    
#> 037: 0.389691    0.905853    3.434785    0.522740    0.123489    0.018534    0.675044    
#> 038: 0.395553    0.890874    3.427780    0.513629    0.120815    0.019229    0.663129    
#> 039: 0.391509    0.896348    3.441525    0.487948    0.114774    0.019973    0.659701    
#> 040: 0.412667    0.906163    3.447196    0.525186    0.112820    0.018974    0.684104    
#> 041: 0.417815    0.889398    3.442127    0.525415    0.109688    0.018795    0.678159    
#> 042: 0.395741    0.896259    3.437732    0.499144    0.106806    0.018842    0.663564    
#> 043: 0.325482    0.919602    3.415591    0.474187    0.110018    0.019200    0.670291    
#> 044: 0.308643    0.934289    3.412547    0.450478    0.114507    0.018240    0.683086    
#> 045: 0.328295    0.935419    3.413550    0.427954    0.117684    0.018748    0.652699    
#> 046: 0.321749    0.894641    3.419293    0.406556    0.116034    0.018486    0.648764    
#> 047: 0.330075    0.917399    3.416141    0.386228    0.110233    0.018425    0.652842    
#> 048: 0.354554    0.901391    3.422900    0.366917    0.104721    0.020045    0.660850    
#> 049: 0.365282    0.897599    3.433335    0.377310    0.099742    0.021544    0.675753    
#> 050: 0.396188    0.873967    3.446752    0.377368    0.094944    0.023344    0.689560    
#> 051: 0.401092    0.876529    3.445227    0.359627    0.107098    0.023877    0.680131    
#> 052: 0.422389    0.886517    3.450118    0.404989    0.103015    0.022683    0.669847    
#> 053: 0.400347    0.870120    3.444566    0.413314    0.098627    0.021549    0.672513    
#> 054: 0.362851    0.902017    3.436609    0.392995    0.103282    0.020471    0.683884    
#> 055: 0.385595    0.874446    3.438052    0.441556    0.098118    0.019448    0.689013    
#> 056: 0.397895    0.895121    3.434075    0.419478    0.116423    0.019665    0.696310    
#> 057: 0.388415    0.898016    3.444338    0.398504    0.110602    0.018809    0.688558    
#> 058: 0.396193    0.875008    3.437246    0.378579    0.105072    0.017868    0.684121    
#> 059: 0.391853    0.869245    3.441732    0.407556    0.114186    0.018915    0.688832    
#> 060: 0.379013    0.872062    3.438470    0.387178    0.112019    0.017969    0.684471    
#> 061: 0.425988    0.876344    3.451993    0.406385    0.106884    0.017071    0.682990    
#> 062: 0.407783    0.893124    3.454673    0.386065    0.119524    0.016217    0.701965    
#> 063: 0.434754    0.868900    3.452272    0.431321    0.116019    0.015877    0.694789    
#> 064: 0.410402    0.868557    3.449595    0.429412    0.110218    0.017274    0.683777    
#> 065: 0.427015    0.845580    3.435631    0.407941    0.110543    0.016410    0.677989    
#> 066: 0.391116    0.888170    3.440660    0.420826    0.105016    0.018344    0.669844    
#> 067: 0.389112    0.872595    3.437632    0.403455    0.104228    0.017747    0.675341    
#> 068: 0.379729    0.900477    3.439676    0.411750    0.105600    0.023764    0.678899    
#> 069: 0.365869    0.902375    3.428631    0.460155    0.107699    0.022576    0.664235    
#> 070: 0.335373    0.891811    3.420794    0.469483    0.102314    0.023525    0.668301    
#> 071: 0.350180    0.919010    3.412512    0.480542    0.100063    0.024213    0.681768    
#> 072: 0.348861    0.881020    3.426977    0.457666    0.095060    0.023002    0.672653    
#> 073: 0.380872    0.916012    3.435027    0.494634    0.111125    0.021852    0.635181    
#> 074: 0.385968    0.906962    3.422098    0.507638    0.112643    0.020759    0.641916    
#> 075: 0.395986    0.873391    3.445122    0.482256    0.109487    0.022435    0.654202    
#> 076: 0.385329    0.898789    3.443483    0.490491    0.108784    0.021746    0.665869    
#> 077: 0.415657    0.883722    3.443618    0.497621    0.108209    0.020659    0.664211    
#> 078: 0.405033    0.886966    3.443460    0.472740    0.102799    0.019626    0.661895    
#> 079: 0.397076    0.896360    3.441467    0.449103    0.105365    0.021038    0.689514    
#> 080: 0.406323    0.902670    3.439130    0.477663    0.112794    0.024747    0.664151    
#> 081: 0.402244    0.918343    3.430044    0.453780    0.109421    0.026482    0.656008    
#> 082: 0.387342    0.892822    3.446959    0.447537    0.118961    0.025158    0.683992    
#> 083: 0.393883    0.912918    3.438189    0.425161    0.113013    0.025945    0.678802    
#> 084: 0.406282    0.901179    3.431950    0.433424    0.107362    0.024647    0.671641    
#> 085: 0.384371    0.905882    3.450784    0.411753    0.106292    0.023415    0.673075    
#> 086: 0.371963    0.902306    3.439524    0.391165    0.129842    0.022244    0.657842    
#> 087: 0.378636    0.909888    3.429525    0.379441    0.126950    0.021132    0.652721    
#> 088: 0.323920    0.924048    3.420107    0.378401    0.136465    0.020075    0.671477    
#> 089: 0.328210    0.930677    3.397594    0.404444    0.132242    0.019072    0.673612    
#> 090: 0.317536    0.932613    3.396870    0.433744    0.129802    0.018118    0.685686    
#> 091: 0.339743    0.918043    3.391842    0.491865    0.130391    0.017212    0.687378    
#> 092: 0.319957    0.941632    3.395467    0.467272    0.132675    0.016352    0.685258    
#> 093: 0.305235    0.924441    3.395793    0.492358    0.126041    0.017402    0.685199    
#> 094: 0.342500    0.924058    3.395444    0.577311    0.119739    0.016532    0.673979    
#> 095: 0.326789    0.931699    3.399557    0.548445    0.117253    0.016048    0.680674    
#> 096: 0.286583    0.920121    3.396443    0.521023    0.118492    0.018303    0.664719    
#> 097: 0.327455    0.927750    3.403419    0.525644    0.112568    0.017387    0.676688    
#> 098: 0.328020    0.944387    3.407381    0.513662    0.121386    0.016518    0.661518    
#> 099: 0.342173    0.915121    3.398572    0.487979    0.119379    0.015692    0.656265    
#> 100: 0.342391    0.934463    3.411619    0.463580    0.113410    0.015437    0.652075    
#> 101: 0.313171    0.921020    3.400387    0.440401    0.117171    0.014665    0.654829    
#> 102: 0.338464    0.915916    3.398439    0.418381    0.125805    0.013932    0.661749    
#> 103: 0.337338    0.917400    3.413778    0.465475    0.119515    0.014516    0.657275    
#> 104: 0.332109    0.916619    3.419135    0.503282    0.113539    0.016024    0.665720    
#> 105: 0.343705    0.915717    3.412328    0.478118    0.107862    0.016265    0.681067    
#> 106: 0.363278    0.927830    3.407120    0.454212    0.102469    0.015452    0.674623    
#> 107: 0.352700    0.935669    3.406165    0.431501    0.107258    0.018276    0.667473    
#> 108: 0.345309    0.917394    3.412142    0.462527    0.101895    0.017362    0.685687    
#> 109: 0.325996    0.912421    3.415708    0.457472    0.096800    0.016494    0.693873    
#> 110: 0.348578    0.890912    3.409488    0.469811    0.108011    0.015669    0.693825    
#> 111: 0.347160    0.902867    3.426868    0.446320    0.102611    0.014886    0.675022    
#> 112: 0.327920    0.889270    3.402545    0.494398    0.103544    0.014141    0.683504    
#> 113: 0.308661    0.950707    3.406383    0.480727    0.098367    0.013434    0.674808    
#> 114: 0.323680    0.944345    3.404400    0.456690    0.099512    0.012763    0.672258    
#> 115: 0.351299    0.914565    3.409293    0.433856    0.094700    0.012770    0.681377    
#> 116: 0.362052    0.919484    3.423163    0.412163    0.101199    0.012852    0.665734    
#> 117: 0.363336    0.939764    3.415448    0.502744    0.118236    0.012210    0.671444    
#> 118: 0.362191    0.909608    3.427845    0.477607    0.112324    0.013473    0.667434    
#> 119: 0.340329    0.920497    3.423078    0.453726    0.107139    0.017117    0.683408    
#> 120: 0.322018    0.909209    3.413837    0.431040    0.114649    0.016261    0.673401    
#> 121: 0.344907    0.937160    3.412106    0.409488    0.108916    0.015448    0.679780    
#> 122: 0.348781    0.928336    3.421603    0.389014    0.131385    0.016642    0.667802    
#> 123: 0.367261    0.945414    3.416494    0.369563    0.124816    0.015810    0.683273    
#> 124: 0.314543    0.937123    3.412667    0.351085    0.127994    0.015019    0.674679    
#> 125: 0.353414    0.942652    3.407534    0.384405    0.121594    0.014914    0.678924    
#> 126: 0.333290    0.948154    3.391471    0.373040    0.115515    0.014168    0.705311    
#> 127: 0.365403    0.926309    3.410250    0.439151    0.109739    0.013460    0.691280    
#> 128: 0.328191    0.903257    3.422350    0.417193    0.106737    0.012787    0.692550    
#> 129: 0.346810    0.919765    3.420002    0.411062    0.127606    0.012148    0.668222    
#> 130: 0.400719    0.902076    3.427688    0.401610    0.130781    0.011540    0.672108    
#> 131: 0.371971    0.908834    3.420834    0.428178    0.139572    0.012400    0.669823    
#> 132: 0.350187    0.929200    3.408755    0.406769    0.132593    0.011780    0.677024    
#> 133: 0.367643    0.919978    3.415387    0.495880    0.134811    0.012047    0.652387    
#> 134: 0.359600    0.904623    3.423575    0.502793    0.133278    0.015263    0.654388    
#> 135: 0.377463    0.900509    3.431257    0.477654    0.126614    0.017126    0.650725    
#> 136: 0.368877    0.896222    3.432881    0.558498    0.132251    0.016269    0.637985    
#> 137: 0.414614    0.890181    3.432668    0.530574    0.125639    0.015456    0.652481    
#> 138: 0.411427    0.903384    3.425753    0.540117    0.119357    0.015371    0.667263    
#> 139: 0.379171    0.900715    3.435439    0.513112    0.113389    0.018436    0.665829    
#> 140: 0.377378    0.883861    3.447542    0.487456    0.107719    0.020885    0.678967    
#> 141: 0.424417    0.849452    3.456896    0.463083    0.125821    0.019841    0.689007    
#> 142: 0.408631    0.862439    3.460576    0.439929    0.135418    0.018849    0.701516    
#> 143: 0.363784    0.897158    3.442507    0.417933    0.128647    0.020944    0.704271    
#> 144: 0.400384    0.897598    3.448353    0.420565    0.122214    0.019897    0.696142    
#> 145: 0.390553    0.897548    3.434348    0.399537    0.116104    0.018902    0.681111    
#> 146: 0.362577    0.899464    3.435545    0.379560    0.117484    0.017957    0.668257    
#> 147: 0.350783    0.889394    3.424368    0.360582    0.128972    0.017323    0.661189    
#> 148: 0.313209    0.905165    3.429932    0.351319    0.122524    0.021016    0.667846    
#> 149: 0.353071    0.896331    3.424961    0.441117    0.116398    0.020570    0.654064    
#> 150: 0.365519    0.904759    3.415534    0.431935    0.110578    0.019542    0.667345    
#> 151: 0.316693    0.922249    3.415658    0.431114    0.105049    0.018565    0.666721    
#> 152: 0.350736    0.917790    3.427470    0.404807    0.112631    0.017743    0.664275    
#> 153: 0.361106    0.906693    3.441652    0.392115    0.102974    0.017495    0.676941    
#> 154: 0.399023    0.909759    3.441805    0.432686    0.106341    0.018044    0.686805    
#> 155: 0.384399    0.887553    3.442073    0.395273    0.099369    0.019338    0.680913    
#> 156: 0.411016    0.863999    3.452451    0.449547    0.120757    0.017826    0.676266    
#> 157: 0.415102    0.873399    3.442982    0.492374    0.106298    0.020468    0.662409    
#> 158: 0.431193    0.907893    3.440564    0.433899    0.113039    0.017215    0.671354    
#> 159: 0.395480    0.902942    3.450086    0.435394    0.113227    0.014483    0.666795    
#> 160: 0.372851    0.872573    3.454625    0.431159    0.113517    0.015845    0.671339    
#> 161: 0.364452    0.898817    3.435200    0.475429    0.123834    0.013504    0.663384    
#> 162: 0.374164    0.908822    3.415143    0.487923    0.120349    0.010118    0.689936    
#> 163: 0.371852    0.918171    3.408336    0.485705    0.156009    0.008743    0.668307    
#> 164: 0.350599    0.934123    3.412436    0.477362    0.142427    0.009395    0.681525    
#> 165: 0.376707    0.920656    3.414190    0.415067    0.116023    0.011909    0.689420    
#> 166: 0.418247    0.941116    3.420500    0.552256    0.103606    0.012177    0.682752    
#> 167: 0.390064    0.933477    3.430738    0.499238    0.117524    0.018341    0.666451    
#> 168: 0.396832    0.926163    3.426723    0.503221    0.123175    0.019565    0.648116    
#> 169: 0.397586    0.935085    3.416446    0.497598    0.127106    0.012586    0.671584    
#> 170: 0.405366    0.933322    3.420037    0.530520    0.124598    0.014003    0.668981    
#> 171: 0.360542    0.913719    3.423398    0.439024    0.111501    0.016036    0.666196    
#> 172: 0.353672    0.912152    3.427192    0.431033    0.115093    0.015421    0.662680    
#> 173: 0.363836    0.913016    3.419909    0.426661    0.122955    0.015267    0.650776    
#> 174: 0.374784    0.906289    3.436099    0.465798    0.101092    0.017838    0.654887    
#> 175: 0.383523    0.914572    3.428820    0.437611    0.089770    0.017118    0.663595    
#> 176: 0.365452    0.927533    3.431639    0.503735    0.099213    0.021179    0.669617    
#> 177: 0.403292    0.905849    3.444386    0.481630    0.099779    0.017719    0.683660    
#> 178: 0.401800    0.885129    3.438604    0.446943    0.107246    0.016741    0.694559    
#> 179: 0.464244    0.910613    3.433422    0.593825    0.113616    0.017243    0.672795    
#> 180: 0.418646    0.892409    3.431254    0.600303    0.104711    0.017180    0.657002    
#> 181: 0.394856    0.907345    3.410470    0.570492    0.114639    0.016522    0.660411    
#> 182: 0.363357    0.917448    3.406911    0.550684    0.111064    0.016571    0.673571    
#> 183: 0.369605    0.933541    3.410558    0.526530    0.110160    0.020015    0.665588    
#> 184: 0.355374    0.906330    3.416156    0.497414    0.112042    0.020030    0.667192    
#> 185: 0.335438    0.927385    3.419078    0.431852    0.109913    0.021004    0.668802    
#> 186: 0.362702    0.918680    3.431267    0.426358    0.096132    0.018929    0.676594    
#> 187: 0.362468    0.897356    3.430038    0.518850    0.110500    0.018447    0.637916    
#> 188: 0.339213    0.904709    3.420099    0.446933    0.114353    0.016085    0.645329    
#> 189: 0.334076    0.928388    3.426013    0.478792    0.103784    0.018464    0.663127    
#> 190: 0.381014    0.922769    3.432638    0.469422    0.116845    0.017969    0.649226    
#> 191: 0.353267    0.914299    3.422549    0.420997    0.126180    0.015422    0.648415    
#> 192: 0.339364    0.934774    3.414290    0.449965    0.124643    0.014426    0.648964    
#> 193: 0.386217    0.924589    3.417224    0.493940    0.117748    0.013344    0.661820    
#> 194: 0.371398    0.921075    3.408933    0.534813    0.109569    0.012332    0.685146    
#> 195: 0.343284    0.921725    3.404632    0.493199    0.109962    0.014831    0.685496    
#> 196: 0.346391    0.923744    3.412786    0.461495    0.099684    0.011259    0.695231    
#> 197: 0.333206    0.902273    3.435513    0.378748    0.107849    0.012974    0.698811    
#> 198: 0.355232    0.908679    3.424784    0.388360    0.105378    0.016762    0.658586    
#> 199: 0.321461    0.916989    3.419697    0.382242    0.102356    0.015725    0.667746    
#> 200: 0.337525    0.918290    3.426093    0.415476    0.108209    0.017674    0.677470    
#> 201: 0.338458    0.919945    3.424491    0.424213    0.113002    0.015860    0.671566    
#> 202: 0.344450    0.918161    3.425794    0.427687    0.108247    0.016565    0.670451    
#> 203: 0.359342    0.916825    3.424844    0.413265    0.107119    0.016865    0.670273    
#> 204: 0.359582    0.913373    3.426045    0.412297    0.105967    0.016593    0.669834    
#> 205: 0.359961    0.914465    3.426854    0.411728    0.104935    0.016418    0.673627    
#> 206: 0.360049    0.917373    3.426467    0.422389    0.103294    0.016729    0.671482    
#> 207: 0.358032    0.918690    3.425143    0.424171    0.102664    0.017099    0.669518    
#> 208: 0.358921    0.920627    3.424186    0.429566    0.103480    0.017380    0.666678    
#> 209: 0.360006    0.918279    3.423648    0.434721    0.104261    0.017851    0.665003    
#> 210: 0.360009    0.916508    3.424383    0.433626    0.104067    0.017828    0.665098    
#> 211: 0.361279    0.915532    3.425750    0.427540    0.104705    0.017712    0.663975    
#> 212: 0.361723    0.914458    3.426249    0.422257    0.105762    0.017273    0.663301    
#> 213: 0.365255    0.911672    3.427320    0.422926    0.106912    0.017215    0.665456    
#> 214: 0.368785    0.909130    3.428834    0.422832    0.107541    0.017331    0.665905    
#> 215: 0.370605    0.906779    3.429638    0.422370    0.107646    0.017262    0.666983    
#> 216: 0.374867    0.905114    3.430584    0.422981    0.107946    0.017390    0.668040    
#> 217: 0.376029    0.904440    3.431531    0.420178    0.108307    0.017238    0.668237    
#> 218: 0.377387    0.904132    3.431198    0.424239    0.109532    0.016932    0.668003    
#> 219: 0.377530    0.903814    3.430465    0.429279    0.109860    0.016709    0.667820    
#> 220: 0.374668    0.903569    3.430329    0.429815    0.110139    0.016793    0.668186    
#> 221: 0.374517    0.902881    3.430415    0.432082    0.110506    0.016687    0.668650    
#> 222: 0.374844    0.902684    3.430357    0.433673    0.110798    0.016730    0.668607    
#> 223: 0.376153    0.902350    3.430391    0.434362    0.109481    0.016807    0.668489    
#> 224: 0.378010    0.902163    3.430583    0.434500    0.108633    0.016874    0.668238    
#> 225: 0.378677    0.900392    3.431229    0.435833    0.108191    0.016889    0.669022    
#> 226: 0.379565    0.899927    3.431275    0.435990    0.107915    0.016882    0.669112    
#> 227: 0.379438    0.899708    3.431385    0.436354    0.107203    0.016929    0.668739    
#> 228: 0.378731    0.899959    3.430803    0.435827    0.107015    0.016887    0.668582    
#> 229: 0.377188    0.899797    3.430173    0.436302    0.106862    0.016819    0.668444    
#> 230: 0.377083    0.899945    3.429757    0.436750    0.107230    0.016845    0.667992    
#> 231: 0.376033    0.900333    3.429512    0.436765    0.106932    0.016834    0.667638    
#> 232: 0.375761    0.900585    3.429601    0.436248    0.106968    0.016885    0.667404    
#> 233: 0.376018    0.899895    3.429639    0.436189    0.106722    0.016859    0.667088    
#> 234: 0.375307    0.900058    3.429680    0.435761    0.106255    0.016878    0.667125    
#> 235: 0.375299    0.900338    3.429345    0.437021    0.105668    0.016922    0.666905    
#> 236: 0.375630    0.900686    3.429293    0.436461    0.105767    0.016973    0.667434    
#> 237: 0.376519    0.901335    3.429365    0.436961    0.105405    0.017085    0.668404    
#> 238: 0.377357    0.901617    3.429473    0.437837    0.104784    0.017130    0.669246    
#> 239: 0.376052    0.902524    3.429251    0.437703    0.104664    0.017136    0.669454    
#> 240: 0.375495    0.902743    3.429252    0.435930    0.104471    0.017159    0.669422    
#> 241: 0.375075    0.902280    3.429246    0.435079    0.104463    0.017184    0.669484    
#> 242: 0.374545    0.901984    3.428999    0.435124    0.104313    0.017265    0.669502    
#> 243: 0.373019    0.902541    3.428682    0.434002    0.104700    0.017331    0.670014    
#> 244: 0.372497    0.902597    3.428554    0.435467    0.104787    0.017323    0.669989    
#> 245: 0.371645    0.902342    3.428459    0.435960    0.105015    0.017269    0.670612    
#> 246: 0.370946    0.902469    3.428374    0.436886    0.105293    0.017295    0.670720    
#> 247: 0.370631    0.901951    3.428567    0.435503    0.105830    0.017317    0.670928    
#> 248: 0.370362    0.901810    3.428688    0.434556    0.106245    0.017251    0.670891    
#> 249: 0.370155    0.901803    3.428793    0.433810    0.106116    0.017239    0.671132    
#> 250: 0.371132    0.901933    3.429060    0.433656    0.106370    0.017257    0.671371    
#> 251: 0.372086    0.902227    3.429471    0.434953    0.106706    0.017240    0.671515    
#> 252: 0.373107    0.902263    3.429770    0.435571    0.106706    0.017268    0.671455    
#> 253: 0.372842    0.902477    3.429807    0.435604    0.106687    0.017243    0.671330    
#> 254: 0.372824    0.902845    3.429777    0.435960    0.106682    0.017261    0.671257    
#> 255: 0.372544    0.903213    3.429684    0.435774    0.106715    0.017296    0.671342    
#> 256: 0.372323    0.903324    3.429584    0.435761    0.106683    0.017351    0.671323    
#> 257: 0.371744    0.903213    3.429349    0.435592    0.106698    0.017339    0.671443    
#> 258: 0.371052    0.903113    3.429323    0.434031    0.106774    0.017232    0.671654    
#> 259: 0.371119    0.903019    3.429291    0.433776    0.106677    0.017197    0.671663    
#> 260: 0.371313    0.903004    3.429339    0.435074    0.106587    0.017213    0.671469    
#> 261: 0.371712    0.902777    3.429429    0.436988    0.106440    0.017194    0.671381    
#> 262: 0.371999    0.902831    3.429570    0.436946    0.106409    0.017153    0.671105    
#> 263: 0.371641    0.903079    3.429457    0.437120    0.106192    0.017165    0.671203    
#> 264: 0.371500    0.903002    3.429371    0.437626    0.106428    0.017153    0.671302    
#> 265: 0.371507    0.903249    3.429374    0.438374    0.106273    0.017196    0.671313    
#> 266: 0.371668    0.903052    3.429544    0.438449    0.106363    0.017219    0.671007    
#> 267: 0.371548    0.903016    3.429638    0.438448    0.106333    0.017207    0.671006    
#> 268: 0.370899    0.902881    3.429472    0.438344    0.106419    0.017210    0.671075    
#> 269: 0.371572    0.902737    3.429470    0.438114    0.106594    0.017229    0.671236    
#> 270: 0.371652    0.902919    3.429235    0.439458    0.106688    0.017231    0.671096    
#> 271: 0.371424    0.903134    3.428958    0.440972    0.107014    0.017242    0.671138    
#> 272: 0.371614    0.903055    3.428813    0.441932    0.107274    0.017234    0.671119    
#> 273: 0.371666    0.903141    3.428829    0.442044    0.107423    0.017210    0.671138    
#> 274: 0.371892    0.903422    3.428887    0.442036    0.107624    0.017189    0.671173    
#> 275: 0.372016    0.903870    3.428703    0.441796    0.107981    0.017168    0.671234    
#> 276: 0.371651    0.904256    3.428740    0.442256    0.108098    0.017180    0.671321    
#> 277: 0.371444    0.904752    3.428685    0.442562    0.108138    0.017205    0.671441    
#> 278: 0.371341    0.904936    3.428752    0.442519    0.107907    0.017240    0.671624    
#> 279: 0.370929    0.904962    3.428711    0.442214    0.107929    0.017223    0.671933    
#> 280: 0.370656    0.905073    3.428730    0.442266    0.108102    0.017200    0.671905    
#> 281: 0.370362    0.905260    3.428800    0.441807    0.108131    0.017189    0.672108    
#> 282: 0.370346    0.905539    3.428871    0.441228    0.108112    0.017159    0.672258    
#> 283: 0.370189    0.905551    3.428970    0.441165    0.108338    0.017131    0.672651    
#> 284: 0.370148    0.905358    3.429049    0.440806    0.108487    0.017097    0.672587    
#> 285: 0.369965    0.905352    3.428902    0.441599    0.108661    0.017076    0.672536    
#> 286: 0.369758    0.905369    3.428839    0.441857    0.108847    0.017044    0.672407    
#> 287: 0.369146    0.905640    3.428560    0.442202    0.109052    0.017012    0.672440    
#> 288: 0.369169    0.905618    3.428433    0.442867    0.109145    0.017008    0.672562    
#> 289: 0.369507    0.905627    3.428456    0.442562    0.109200    0.016986    0.672662    
#> 290: 0.369948    0.905663    3.428427    0.443029    0.109533    0.016989    0.672883    
#> 291: 0.370099    0.905726    3.428500    0.443474    0.109698    0.016967    0.672922    
#> 292: 0.369945    0.905598    3.428526    0.443924    0.109834    0.016953    0.673021    
#> 293: 0.369797    0.905537    3.428382    0.443952    0.109842    0.016952    0.672869    
#> 294: 0.369208    0.905718    3.428181    0.443721    0.109782    0.016944    0.672824    
#> 295: 0.368896    0.905742    3.427960    0.444092    0.109751    0.016917    0.672691    
#> 296: 0.368888    0.905833    3.427776    0.444979    0.109899    0.016892    0.672666    
#> 297: 0.368730    0.906056    3.427701    0.444738    0.109970    0.016888    0.672556    
#> 298: 0.368995    0.906051    3.427645    0.445873    0.109986    0.016882    0.672528    
#> 299: 0.368987    0.906268    3.427428    0.446924    0.110088    0.016871    0.672488    
#> 300: 0.368937    0.906176    3.427396    0.447455    0.110012    0.016888    0.672674    
#> 301: 0.369293    0.906113    3.427224    0.448228    0.109895    0.016878    0.672909    
#> 302: 0.369445    0.906208    3.427137    0.449249    0.109927    0.016869    0.672909    
#> 303: 0.369309    0.906461    3.427058    0.448905    0.109981    0.016849    0.672793    
#> 304: 0.369250    0.906660    3.427007    0.449105    0.110080    0.016852    0.672628    
#> 305: 0.369178    0.906458    3.426958    0.449015    0.109957    0.016850    0.672504    
#> 306: 0.368653    0.906418    3.426764    0.449124    0.109856    0.016860    0.672325    
#> 307: 0.368322    0.906373    3.426730    0.448728    0.109619    0.016885    0.672353    
#> 308: 0.367873    0.906332    3.426643    0.448343    0.109307    0.016901    0.672450    
#> 309: 0.367737    0.906227    3.426516    0.448430    0.109284    0.016932    0.672622    
#> 310: 0.367782    0.906325    3.426383    0.449243    0.109185    0.016952    0.672693    
#> 311: 0.367671    0.906455    3.426272    0.449422    0.109173    0.016950    0.672466    
#> 312: 0.367388    0.906450    3.426209    0.448979    0.109253    0.016940    0.672423    
#> 313: 0.367199    0.906107    3.426144    0.448652    0.109231    0.016914    0.672770    
#> 314: 0.366767    0.906087    3.426033    0.448207    0.109242    0.016894    0.672782    
#> 315: 0.366420    0.906281    3.425917    0.448146    0.109330    0.016865    0.672720    
#> 316: 0.365991    0.906444    3.425803    0.447594    0.109448    0.016849    0.672744    
#> 317: 0.365788    0.906594    3.425756    0.447613    0.109557    0.016847    0.672901    
#> 318: 0.365759    0.906657    3.425607    0.448067    0.109435    0.016862    0.672732    
#> 319: 0.365601    0.906744    3.425558    0.448278    0.109292    0.016893    0.672706    
#> 320: 0.365273    0.906618    3.425481    0.448604    0.109309    0.016925    0.672828    
#> 321: 0.365009    0.906704    3.425337    0.448692    0.109242    0.016927    0.673016    
#> 322: 0.364857    0.906789    3.425140    0.449105    0.109243    0.016921    0.673035    
#> 323: 0.364453    0.906834    3.424957    0.449616    0.109284    0.016915    0.672913    
#> 324: 0.364275    0.906935    3.424894    0.449558    0.109221    0.016913    0.672761    
#> 325: 0.364132    0.907010    3.424846    0.449266    0.109106    0.016907    0.672679    
#> 326: 0.364126    0.906896    3.424818    0.448745    0.108895    0.016909    0.672730    
#> 327: 0.364221    0.906848    3.424882    0.448808    0.108722    0.016933    0.672770    
#> 328: 0.363866    0.907103    3.424832    0.448330    0.108744    0.016912    0.672671    
#> 329: 0.363871    0.907168    3.424848    0.448126    0.108818    0.016892    0.672727    
#> 330: 0.363612    0.907374    3.424819    0.447620    0.108822    0.016892    0.672671    
#> 331: 0.363349    0.907658    3.424686    0.447073    0.108872    0.016887    0.672521    
#> 332: 0.363222    0.907894    3.424702    0.446618    0.108890    0.016879    0.672522    
#> 333: 0.363090    0.908030    3.424615    0.446231    0.108807    0.016863    0.672573    
#> 334: 0.362797    0.908048    3.424419    0.446588    0.108946    0.016858    0.672445    
#> 335: 0.362533    0.908225    3.424237    0.446260    0.108797    0.016862    0.672431    
#> 336: 0.361948    0.908577    3.424049    0.446219    0.108733    0.016886    0.672454    
#> 337: 0.361622    0.909082    3.423904    0.446190    0.108835    0.016893    0.672400    
#> 338: 0.361284    0.909378    3.423752    0.446266    0.108901    0.016875    0.672264    
#> 339: 0.360974    0.909645    3.423605    0.446335    0.108984    0.016849    0.672243    
#> 340: 0.360795    0.909575    3.423484    0.446355    0.109195    0.016811    0.672279    
#> 341: 0.360747    0.909641    3.423453    0.446451    0.109317    0.016775    0.672258    
#> 342: 0.360298    0.909577    3.423359    0.446119    0.109278    0.016744    0.672243    
#> 343: 0.360044    0.909562    3.423300    0.446164    0.109327    0.016724    0.672252    
#> 344: 0.359942    0.909607    3.423271    0.445905    0.109416    0.016714    0.672317    
#> 345: 0.359714    0.909705    3.423227    0.445803    0.109530    0.016705    0.672299    
#> 346: 0.359400    0.909708    3.423130    0.445708    0.109747    0.016659    0.672349    
#> 347: 0.359458    0.909618    3.423065    0.446011    0.109897    0.016669    0.672310    
#> 348: 0.359265    0.909606    3.422957    0.446132    0.109936    0.016652    0.672398    
#> 349: 0.359314    0.909562    3.422928    0.446393    0.109973    0.016655    0.672315    
#> 350: 0.359324    0.909521    3.422876    0.447094    0.110107    0.016644    0.672264    
#> 351: 0.359517    0.909670    3.422789    0.447372    0.110165    0.016637    0.672235    
#> 352: 0.359308    0.909914    3.422705    0.447694    0.110163    0.016620    0.672390    
#> 353: 0.359060    0.910071    3.422578    0.447671    0.110214    0.016609    0.672377    
#> 354: 0.358838    0.910125    3.422413    0.447262    0.110179    0.016609    0.672393    
#> 355: 0.358745    0.910121    3.422249    0.447388    0.110280    0.016595    0.672378    
#> 356: 0.358606    0.910112    3.422248    0.447296    0.110347    0.016579    0.672509    
#> 357: 0.358585    0.910233    3.422238    0.447393    0.110467    0.016558    0.672471    
#> 358: 0.358633    0.910314    3.422259    0.447409    0.110610    0.016555    0.672348    
#> 359: 0.358538    0.910348    3.422195    0.447286    0.110647    0.016557    0.672351    
#> 360: 0.358419    0.910367    3.422102    0.447203    0.110673    0.016563    0.672328    
#> 361: 0.358123    0.910390    3.421947    0.446867    0.110651    0.016569    0.672361    
#> 362: 0.358006    0.910440    3.421772    0.447060    0.110619    0.016574    0.672180    
#> 363: 0.357877    0.910443    3.421753    0.446348    0.110584    0.016579    0.672153    
#> 364: 0.357614    0.910526    3.421680    0.446020    0.110583    0.016585    0.672224    
#> 365: 0.357397    0.910569    3.421646    0.445736    0.110592    0.016622    0.672161    
#> 366: 0.357353    0.910567    3.421580    0.445867    0.110604    0.016666    0.672155    
#> 367: 0.357426    0.910584    3.421594    0.446647    0.110488    0.016676    0.672152    
#> 368: 0.357792    0.910588    3.421590    0.447129    0.110465    0.016669    0.672099    
#> 369: 0.357728    0.910558    3.421583    0.446943    0.110427    0.016652    0.672180    
#> 370: 0.357548    0.910559    3.421578    0.446710    0.110399    0.016669    0.672219    
#> 371: 0.357385    0.910538    3.421519    0.446467    0.110388    0.016660    0.672163    
#> 372: 0.357338    0.910567    3.421502    0.446586    0.110429    0.016646    0.672136    
#> 373: 0.357103    0.910693    3.421435    0.446667    0.110406    0.016611    0.672203    
#> 374: 0.357143    0.910689    3.421394    0.446978    0.110348    0.016584    0.672144    
#> 375: 0.357047    0.910660    3.421396    0.447305    0.110251    0.016573    0.672202    
#> 376: 0.357162    0.910665    3.421464    0.447293    0.110092    0.016584    0.672140    
#> 377: 0.357030    0.910758    3.421472    0.446986    0.110095    0.016571    0.672163    
#> 378: 0.356801    0.910828    3.421425    0.446763    0.110143    0.016561    0.672137    
#> 379: 0.356529    0.910823    3.421394    0.446649    0.110200    0.016528    0.672199    
#> 380: 0.356374    0.910765    3.421379    0.446299    0.110305    0.016502    0.672160    
#> 381: 0.356016    0.910783    3.421335    0.446051    0.110373    0.016479    0.672138    
#> 382: 0.355991    0.910889    3.421264    0.446697    0.110395    0.016461    0.672053    
#> 383: 0.355889    0.910811    3.421254    0.446581    0.110397    0.016456    0.671905    
#> 384: 0.355842    0.910827    3.421280    0.446777    0.110377    0.016465    0.671859    
#> 385: 0.355808    0.910815    3.421293    0.446690    0.110383    0.016470    0.671886    
#> 386: 0.355858    0.910969    3.421349    0.446510    0.110383    0.016458    0.671946    
#> 387: 0.355978    0.911146    3.421403    0.446253    0.110408    0.016458    0.671960    
#> 388: 0.355898    0.911183    3.421439    0.445887    0.110416    0.016454    0.672005    
#> 389: 0.355918    0.911135    3.421448    0.445597    0.110495    0.016437    0.672054    
#> 390: 0.355816    0.911213    3.421423    0.445241    0.110580    0.016411    0.672099    
#> 391: 0.355736    0.911209    3.421392    0.444940    0.110602    0.016408    0.672009    
#> 392: 0.355733    0.911298    3.421404    0.445093    0.110551    0.016393    0.672010    
#> 393: 0.355701    0.911246    3.421345    0.444868    0.110516    0.016379    0.671972    
#> 394: 0.355662    0.911259    3.421304    0.444860    0.110480    0.016366    0.672032    
#> 395: 0.355643    0.911406    3.421222    0.444960    0.110554    0.016345    0.672015    
#> 396: 0.355655    0.911427    3.421209    0.444734    0.110701    0.016330    0.671941    
#> 397: 0.355643    0.911423    3.421247    0.444272    0.110757    0.016336    0.671957    
#> 398: 0.355710    0.911414    3.421308    0.444108    0.110765    0.016340    0.672013    
#> 399: 0.355811    0.911463    3.421350    0.444060    0.110838    0.016339    0.671962    
#> 400: 0.356003    0.911480    3.421434    0.443596    0.110811    0.016334    0.671996    
#> 401: 0.356121    0.911503    3.421491    0.443502    0.110783    0.016347    0.672073    
#> 402: 0.356177    0.911562    3.421539    0.443163    0.110934    0.016346    0.672139    
#> 403: 0.356415    0.911555    3.421623    0.442910    0.111092    0.016341    0.672141    
#> 404: 0.356499    0.911586    3.421617    0.442726    0.111178    0.016332    0.672142    
#> 405: 0.356585    0.911601    3.421677    0.442987    0.111115    0.016331    0.672193    
#> 406: 0.356797    0.911602    3.421718    0.443102    0.111169    0.016326    0.672228    
#> 407: 0.356801    0.911579    3.421760    0.442890    0.111239    0.016312    0.672310    
#> 408: 0.356909    0.911583    3.421779    0.442627    0.111337    0.016288    0.672313    
#> 409: 0.356903    0.911400    3.421773    0.442368    0.111337    0.016257    0.672374    
#> 410: 0.356831    0.911369    3.421701    0.442176    0.111393    0.016244    0.672414    
#> 411: 0.356828    0.911214    3.421702    0.441845    0.111423    0.016242    0.672545    
#> 412: 0.356951    0.911256    3.421710    0.442011    0.111449    0.016249    0.672557    
#> 413: 0.357170    0.911250    3.421704    0.442467    0.111442    0.016244    0.672553    
#> 414: 0.357150    0.911242    3.421722    0.442789    0.111433    0.016249    0.672457    
#> 415: 0.357413    0.911274    3.421736    0.443343    0.111488    0.016244    0.672445    
#> 416: 0.357602    0.911217    3.421793    0.443830    0.111435    0.016236    0.672342    
#> 417: 0.357807    0.911067    3.421825    0.444463    0.111455    0.016232    0.672252    
#> 418: 0.357709    0.911027    3.421821    0.444372    0.111447    0.016229    0.672133    
#> 419: 0.357808    0.911093    3.421796    0.444720    0.111491    0.016218    0.672083    
#> 420: 0.357829    0.911188    3.421761    0.444880    0.111533    0.016198    0.671990    
#> 421: 0.357786    0.911248    3.421774    0.444972    0.111522    0.016193    0.671959    
#> 422: 0.357956    0.911244    3.421796    0.444772    0.111511    0.016184    0.672057    
#> 423: 0.358120    0.911195    3.421819    0.444830    0.111575    0.016179    0.672182    
#> 424: 0.358031    0.911134    3.421785    0.444810    0.111564    0.016163    0.672213    
#> 425: 0.358117    0.911142    3.421755    0.445135    0.111486    0.016166    0.672249    
#> 426: 0.358144    0.911162    3.421742    0.445277    0.111444    0.016156    0.672186    
#> 427: 0.358058    0.911143    3.421743    0.445182    0.111438    0.016136    0.672170    
#> 428: 0.358036    0.911192    3.421769    0.445066    0.111531    0.016112    0.672173    
#> 429: 0.358150    0.911216    3.421831    0.445142    0.111516    0.016097    0.672150    
#> 430: 0.358234    0.911197    3.421857    0.445242    0.111542    0.016079    0.672187    
#> 431: 0.358352    0.911183    3.421869    0.445162    0.111603    0.016074    0.672149    
#> 432: 0.358279    0.911199    3.421914    0.444936    0.111616    0.016083    0.672070    
#> 433: 0.358169    0.911285    3.421908    0.444655    0.111583    0.016095    0.672114    
#> 434: 0.357992    0.911250    3.421889    0.444307    0.111575    0.016082    0.672058    
#> 435: 0.358024    0.911284    3.421873    0.444166    0.111584    0.016084    0.671968    
#> 436: 0.358064    0.911202    3.421920    0.443936    0.111642    0.016080    0.671943    
#> 437: 0.358205    0.911156    3.421918    0.443947    0.111654    0.016065    0.671922    
#> 438: 0.358306    0.911257    3.421909    0.444113    0.111593    0.016059    0.671843    
#> 439: 0.358407    0.911353    3.421914    0.444110    0.111583    0.016051    0.671790    
#> 440: 0.358483    0.911406    3.421956    0.444129    0.111596    0.016043    0.671757    
#> 441: 0.358482    0.911419    3.421981    0.444119    0.111631    0.016042    0.671696    
#> 442: 0.358379    0.911385    3.422045    0.443948    0.111673    0.016035    0.671661    
#> 443: 0.358493    0.911407    3.422048    0.444085    0.111657    0.016039    0.671670    
#> 444: 0.358437    0.911451    3.422000    0.444089    0.111598    0.016042    0.671630    
#> 445: 0.358307    0.911630    3.421937    0.444126    0.111578    0.016040    0.671722    
#> 446: 0.358074    0.911787    3.421860    0.444062    0.111557    0.016040    0.671722    
#> 447: 0.357966    0.911821    3.421820    0.444274    0.111494    0.016057    0.671647    
#> 448: 0.357962    0.911774    3.421844    0.444385    0.111436    0.016078    0.671551    
#> 449: 0.358101    0.911755    3.421968    0.444469    0.111410    0.016096    0.671560    
#> 450: 0.358140    0.911666    3.422025    0.444387    0.111483    0.016099    0.671595    
#> 451: 0.358230    0.911641    3.422039    0.444221    0.111547    0.016102    0.671627    
#> 452: 0.358346    0.911606    3.422085    0.443831    0.111595    0.016109    0.671592    
#> 453: 0.358306    0.911638    3.422061    0.443795    0.111610    0.016098    0.671496    
#> 454: 0.358173    0.911738    3.422012    0.443648    0.111587    0.016091    0.671465    
#> 455: 0.358174    0.911817    3.421986    0.443479    0.111599    0.016078    0.671497    
#> 456: 0.358138    0.911790    3.422011    0.443295    0.111602    0.016074    0.671502    
#> 457: 0.358189    0.911741    3.422042    0.443102    0.111642    0.016055    0.671466    
#> 458: 0.358245    0.911799    3.422062    0.443008    0.111608    0.016047    0.671384    
#> 459: 0.358172    0.911867    3.422051    0.443000    0.111638    0.016035    0.671330    
#> 460: 0.358053    0.911896    3.421999    0.442966    0.111628    0.016051    0.671281    
#> 461: 0.358022    0.911936    3.422000    0.442773    0.111614    0.016062    0.671296    
#> 462: 0.358049    0.911943    3.422021    0.442872    0.111632    0.016059    0.671283    
#> 463: 0.358087    0.911971    3.422033    0.442913    0.111632    0.016052    0.671281    
#> 464: 0.358200    0.911956    3.422048    0.442942    0.111613    0.016053    0.671222    
#> 465: 0.358403    0.911785    3.422109    0.443047    0.111609    0.016056    0.671187    
#> 466: 0.358596    0.911753    3.422146    0.443109    0.111685    0.016050    0.671151    
#> 467: 0.358585    0.911659    3.422166    0.443032    0.111727    0.016035    0.671069    
#> 468: 0.358709    0.911621    3.422229    0.442974    0.111703    0.016031    0.671067    
#> 469: 0.358861    0.911672    3.422286    0.442878    0.111695    0.016025    0.671139    
#> 470: 0.358874    0.911640    3.422294    0.442586    0.111648    0.016028    0.671096    
#> 471: 0.358890    0.911574    3.422286    0.442236    0.111601    0.016036    0.671106    
#> 472: 0.358867    0.911559    3.422274    0.442131    0.111584    0.016043    0.671118    
#> 473: 0.358817    0.911600    3.422225    0.442367    0.111614    0.016060    0.671015    
#> 474: 0.358733    0.911661    3.422163    0.442498    0.111599    0.016085    0.671047    
#> 475: 0.358716    0.911749    3.422125    0.442620    0.111604    0.016101    0.671010    
#> 476: 0.358631    0.911809    3.422093    0.442697    0.111544    0.016125    0.671045    
#> 477: 0.358502    0.911832    3.422094    0.442623    0.111466    0.016140    0.670982    
#> 478: 0.358447    0.911867    3.422100    0.442727    0.111424    0.016149    0.670990    
#> 479: 0.358399    0.911948    3.422058    0.442884    0.111418    0.016154    0.671020    
#> 480: 0.358382    0.912003    3.421987    0.443186    0.111417    0.016167    0.670994    
#> 481: 0.358415    0.912105    3.421917    0.443372    0.111401    0.016184    0.671026    
#> 482: 0.358394    0.912153    3.421844    0.443495    0.111402    0.016196    0.671094    
#> 483: 0.358230    0.912150    3.421801    0.443408    0.111467    0.016189    0.671050    
#> 484: 0.358147    0.912032    3.421776    0.443601    0.111575    0.016184    0.671096    
#> 485: 0.358126    0.912048    3.421772    0.443588    0.111632    0.016173    0.671202    
#> 486: 0.358202    0.912114    3.421776    0.443794    0.111639    0.016166    0.671182    
#> 487: 0.358420    0.912099    3.421819    0.444222    0.111676    0.016169    0.671090    
#> 488: 0.358408    0.912169    3.421846    0.444037    0.111754    0.016168    0.671062    
#> 489: 0.358540    0.912170    3.421863    0.444089    0.111840    0.016169    0.671094    
#> 490: 0.358591    0.912132    3.421893    0.444153    0.111837    0.016182    0.671068    
#> 491: 0.358695    0.912153    3.421955    0.444128    0.111789    0.016197    0.671066    
#> 492: 0.358748    0.912171    3.422003    0.444202    0.111737    0.016214    0.671149    
#> 493: 0.358704    0.912218    3.422011    0.444108    0.111698    0.016220    0.671147    
#> 494: 0.358836    0.912243    3.422043    0.443812    0.111646    0.016225    0.671134    
#> 495: 0.358917    0.912241    3.422058    0.443694    0.111609    0.016233    0.671105    
#> 496: 0.359070    0.912292    3.422058    0.443589    0.111508    0.016244    0.671144    
#> 497: 0.359026    0.912311    3.422062    0.443783    0.111457    0.016253    0.671148    
#> 498: 0.359045    0.912293    3.422053    0.444041    0.111417    0.016251    0.671100    
#> 499: 0.359034    0.912299    3.422008    0.444240    0.111403    0.016228    0.671094    
#> 500: 0.359050    0.912295    3.421988    0.444212    0.111418    0.016214    0.671080    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.326643    0.969917    3.445531    0.392401    0.073767    0.016800    1.542876    
#> 002: 0.427747    1.019428    3.454345    0.372781    0.070078    0.015960    0.994263    
#> 003: 0.579948    0.973138    3.480237    0.354142    0.066661    0.015162    0.747014    
#> 004: 0.565894    0.971350    3.494498    0.336435    0.063328    0.014404    0.687876    
#> 005: 0.622051    0.986529    3.479544    0.319613    0.060161    0.013684    0.623341    
#> 006: 0.611390    0.975978    3.475982    0.303633    0.071026    0.013000    0.564059    
#> 007: 0.578067    0.982116    3.474142    0.295523    0.067934    0.012350    0.581511    
#> 008: 0.591074    0.974264    3.475760    0.310904    0.064537    0.011732    0.576556    
#> 009: 0.581934    0.972749    3.469524    0.324107    0.070359    0.011146    0.570001    
#> 010: 0.622948    0.949614    3.480581    0.412750    0.066842    0.010588    0.565554    
#> 011: 0.621625    0.972000    3.483097    0.392112    0.063499    0.010059    0.572256    
#> 012: 0.643050    0.961936    3.480055    0.394827    0.060324    0.009556    0.559620    
#> 013: 0.592611    0.970550    3.473453    0.375086    0.063819    0.010599    0.570688    
#> 014: 0.621950    0.969513    3.481337    0.356331    0.066370    0.010069    0.577036    
#> 015: 0.649240    0.973659    3.492299    0.338515    0.063860    0.009565    0.570771    
#> 016: 0.654741    0.982396    3.493967    0.333351    0.069544    0.009087    0.556210    
#> 017: 0.646085    0.980090    3.496915    0.330308    0.078325    0.008633    0.535392    
#> 018: 0.645036    0.972305    3.486935    0.313792    0.089763    0.008201    0.559624    
#> 019: 0.621816    0.968882    3.484054    0.359107    0.085275    0.007791    0.544037    
#> 020: 0.625358    0.993717    3.482157    0.341152    0.081011    0.007401    0.564046    
#> 021: 0.638268    0.971912    3.492103    0.336425    0.076961    0.007031    0.551328    
#> 022: 0.618490    0.955447    3.492845    0.319604    0.073113    0.007817    0.544945    
#> 023: 0.706370    0.968197    3.502067    0.436946    0.069457    0.007747    0.564683    
#> 024: 0.708069    0.987928    3.502069    0.442102    0.065984    0.008424    0.547399    
#> 025: 0.662517    0.962763    3.494199    0.490405    0.070691    0.009774    0.554423    
#> 026: 0.622087    0.985629    3.484922    0.465885    0.067156    0.011614    0.561496    
#> 027: 0.651456    0.997950    3.484896    0.442591    0.066728    0.013361    0.572941    
#> 028: 0.643316    0.980419    3.484346    0.420461    0.063391    0.012693    0.554497    
#> 029: 0.667232    0.971819    3.490931    0.428715    0.061215    0.014870    0.566049    
#> 030: 0.701931    0.989842    3.489080    0.484960    0.058154    0.014127    0.560781    
#> 031: 0.629327    0.969070    3.484265    0.465349    0.055246    0.013420    0.542226    
#> 032: 0.610562    0.968850    3.487851    0.442081    0.052484    0.012749    0.546043    
#> 033: 0.642264    0.985599    3.484222    0.419977    0.054579    0.014127    0.537451    
#> 034: 0.659582    0.989150    3.493838    0.398979    0.057471    0.013462    0.537191    
#> 035: 0.620501    0.976220    3.475250    0.413536    0.054598    0.012789    0.535392    
#> 036: 0.635180    0.982553    3.477027    0.408025    0.068082    0.012150    0.532367    
#> 037: 0.615835    0.996669    3.481178    0.387624    0.067011    0.011542    0.554452    
#> 038: 0.626800    0.989979    3.477450    0.381707    0.063660    0.011650    0.540958    
#> 039: 0.639934    0.982334    3.483885    0.362621    0.067227    0.013471    0.530745    
#> 040: 0.632482    0.981101    3.491907    0.380436    0.065372    0.012798    0.542456    
#> 041: 0.644296    0.967908    3.494569    0.421846    0.062104    0.012446    0.534359    
#> 042: 0.666424    0.960921    3.492640    0.434422    0.060145    0.011823    0.531682    
#> 043: 0.635612    0.968617    3.480954    0.412701    0.059870    0.011605    0.533238    
#> 044: 0.632726    0.978383    3.477453    0.392066    0.058634    0.013327    0.533517    
#> 045: 0.625626    0.993529    3.473495    0.433323    0.055703    0.012660    0.536836    
#> 046: 0.629713    0.980213    3.477083    0.411657    0.063080    0.012027    0.534277    
#> 047: 0.614341    0.995356    3.473736    0.391074    0.062160    0.012392    0.537931    
#> 048: 0.615919    0.975490    3.483237    0.371520    0.060644    0.012989    0.548320    
#> 049: 0.613804    0.977087    3.486733    0.352944    0.063698    0.012339    0.556934    
#> 050: 0.669038    0.949798    3.494168    0.376473    0.060513    0.011722    0.568177    
#> 051: 0.622517    0.971163    3.483684    0.357649    0.059061    0.012688    0.564666    
#> 052: 0.639315    0.977879    3.491749    0.378680    0.060922    0.012706    0.548301    
#> 053: 0.612939    0.966147    3.483812    0.359746    0.067963    0.012071    0.545482    
#> 054: 0.606203    0.980878    3.481254    0.341758    0.075361    0.011467    0.561076    
#> 055: 0.610238    0.981508    3.481080    0.324671    0.071593    0.010894    0.551894    
#> 056: 0.630805    0.967059    3.490499    0.355117    0.068613    0.010596    0.562997    
#> 057: 0.609547    0.969172    3.490725    0.337361    0.065182    0.012286    0.577244    
#> 058: 0.628030    0.973227    3.472529    0.328292    0.062004    0.011671    0.572376    
#> 059: 0.598155    0.968384    3.480483    0.350085    0.070396    0.011486    0.570889    
#> 060: 0.598458    0.962551    3.480198    0.358711    0.073423    0.011667    0.575621    
#> 061: 0.604339    0.991758    3.475505    0.363256    0.076893    0.011084    0.551276    
#> 062: 0.599913    0.993035    3.475713    0.396420    0.075750    0.011113    0.572125    
#> 063: 0.626480    0.964391    3.470639    0.376599    0.072047    0.011687    0.573359    
#> 064: 0.609599    0.980313    3.477527    0.366704    0.078119    0.011102    0.558263    
#> 065: 0.640168    0.965700    3.477841    0.375625    0.074213    0.010547    0.552923    
#> 066: 0.622687    0.983018    3.479598    0.388067    0.070502    0.013652    0.539347    
#> 067: 0.599010    0.973408    3.468285    0.373749    0.067863    0.012970    0.537210    
#> 068: 0.593465    0.986700    3.480344    0.368305    0.078313    0.012321    0.565405    
#> 069: 0.595400    0.994603    3.473470    0.389048    0.083601    0.011705    0.564504    
#> 070: 0.568571    0.991468    3.482795    0.369596    0.079421    0.011120    0.542039    
#> 071: 0.589631    0.994990    3.471085    0.351116    0.075450    0.010564    0.552292    
#> 072: 0.598916    0.962105    3.471780    0.377285    0.071677    0.010036    0.552556    
#> 073: 0.666634    0.986484    3.488944    0.502785    0.082359    0.009643    0.539321    
#> 074: 0.617804    0.966661    3.485276    0.477645    0.078241    0.009579    0.545218    
#> 075: 0.602921    0.974994    3.492261    0.453763    0.074329    0.009961    0.542089    
#> 076: 0.672615    0.969321    3.501946    0.431075    0.070613    0.009847    0.545478    
#> 077: 0.672416    0.941431    3.501104    0.409521    0.067082    0.010460    0.550103    
#> 078: 0.658606    0.957769    3.493201    0.397142    0.063728    0.011343    0.541173    
#> 079: 0.676382    0.982801    3.491975    0.465107    0.069917    0.012195    0.553113    
#> 080: 0.646370    0.969609    3.492717    0.441851    0.069789    0.012900    0.553575    
#> 081: 0.645773    0.971027    3.487983    0.419946    0.066300    0.013831    0.551051    
#> 082: 0.630790    0.974381    3.489075    0.398949    0.062985    0.013140    0.566802    
#> 083: 0.663723    0.998808    3.489582    0.380882    0.059836    0.012483    0.561983    
#> 084: 0.620780    0.994452    3.482756    0.361838    0.061585    0.011858    0.562987    
#> 085: 0.613228    0.983491    3.492653    0.343746    0.058505    0.011266    0.545628    
#> 086: 0.613866    1.006085    3.488797    0.326559    0.066201    0.011444    0.556267    
#> 087: 0.616174    0.999612    3.475938    0.337268    0.062891    0.010872    0.543746    
#> 088: 0.580056    0.991927    3.475320    0.377904    0.065692    0.010328    0.545609    
#> 089: 0.563111    1.002228    3.465820    0.359009    0.071349    0.009812    0.550012    
#> 090: 0.579856    0.994826    3.458841    0.346429    0.073756    0.009321    0.565236    
#> 091: 0.585222    0.990333    3.455703    0.342544    0.070068    0.008855    0.553441    
#> 092: 0.593722    1.001996    3.456674    0.378757    0.076453    0.008412    0.570663    
#> 093: 0.553956    0.988473    3.455553    0.359819    0.072630    0.008645    0.585840    
#> 094: 0.566919    0.987412    3.461194    0.347475    0.078779    0.008213    0.581818    
#> 095: 0.570232    1.002377    3.470605    0.330101    0.074840    0.007802    0.572803    
#> 096: 0.560637    0.989436    3.466334    0.350167    0.077895    0.008329    0.551335    
#> 097: 0.632634    0.985826    3.473347    0.359332    0.074000    0.007913    0.561858    
#> 098: 0.614215    1.001199    3.481767    0.352586    0.070300    0.007517    0.557572    
#> 099: 0.623225    0.978590    3.476704    0.370297    0.070336    0.007141    0.555265    
#> 100: 0.592898    0.979933    3.480148    0.351782    0.066819    0.008209    0.558854    
#> 101: 0.570318    0.983630    3.462869    0.342976    0.065895    0.007798    0.562696    
#> 102: 0.583293    0.992010    3.455929    0.332952    0.062600    0.007408    0.563764    
#> 103: 0.589942    0.994328    3.464546    0.340896    0.059470    0.007038    0.544806    
#> 104: 0.609650    1.007379    3.472911    0.347379    0.067475    0.006731    0.553997    
#> 105: 0.604223    1.005995    3.471425    0.330010    0.064102    0.007016    0.561937    
#> 106: 0.615162    0.987770    3.472029    0.376200    0.061796    0.006727    0.559109    
#> 107: 0.605501    1.001486    3.471365    0.398115    0.062816    0.007275    0.558670    
#> 108: 0.613806    0.973585    3.471011    0.413797    0.065960    0.006911    0.563174    
#> 109: 0.596374    0.968651    3.476144    0.393107    0.075538    0.006565    0.552252    
#> 110: 0.619045    0.982936    3.466678    0.373452    0.087961    0.007100    0.553950    
#> 111: 0.616223    0.977238    3.472799    0.356771    0.083563    0.006881    0.546709    
#> 112: 0.603166    0.964233    3.468209    0.404399    0.079385    0.007599    0.567104    
#> 113: 0.552867    1.012532    3.465884    0.384747    0.075622    0.007269    0.559917    
#> 114: 0.623419    0.994632    3.469223    0.418443    0.071841    0.007386    0.555551    
#> 115: 0.650372    0.974972    3.475767    0.397521    0.068249    0.008654    0.561669    
#> 116: 0.631636    0.965340    3.483698    0.377645    0.073800    0.010002    0.549435    
#> 117: 0.605987    0.994874    3.484240    0.359614    0.070110    0.010168    0.546835    
#> 118: 0.632651    0.974855    3.489732    0.341633    0.066605    0.009659    0.552028    
#> 119: 0.651404    0.985752    3.486510    0.386539    0.063275    0.012130    0.576320    
#> 120: 0.615330    0.970823    3.490354    0.369596    0.060111    0.012050    0.554515    
#> 121: 0.632364    0.990783    3.481679    0.351116    0.057474    0.011448    0.566313    
#> 122: 0.629588    0.977793    3.484736    0.337725    0.064074    0.010875    0.556285    
#> 123: 0.642009    0.988190    3.477309    0.394094    0.061352    0.010712    0.556323    
#> 124: 0.648995    1.014395    3.475227    0.399255    0.058284    0.011890    0.548949    
#> 125: 0.665681    1.006466    3.471402    0.383238    0.059758    0.011296    0.544675    
#> 126: 0.627686    1.017628    3.467593    0.364076    0.058771    0.013586    0.556507    
#> 127: 0.638465    1.006566    3.477131    0.345872    0.055832    0.013448    0.555677    
#> 128: 0.629550    0.986488    3.488419    0.328579    0.053040    0.013596    0.557757    
#> 129: 0.627297    0.986885    3.483975    0.360560    0.064829    0.012916    0.548590    
#> 130: 0.654320    0.994058    3.487417    0.361970    0.067240    0.012270    0.536833    
#> 131: 0.670179    0.997530    3.485435    0.427123    0.074006    0.011657    0.552296    
#> 132: 0.675904    0.980085    3.486929    0.439657    0.071463    0.011074    0.565702    
#> 133: 0.634706    0.957122    3.496023    0.417674    0.076454    0.010699    0.562432    
#> 134: 0.651275    0.952143    3.496918    0.396791    0.076446    0.012190    0.536111    
#> 135: 0.672127    0.961998    3.499196    0.390458    0.078445    0.012426    0.542670    
#> 136: 0.648447    0.948862    3.496832    0.381439    0.074523    0.011804    0.542175    
#> 137: 0.674507    0.945024    3.500522    0.362367    0.070797    0.011214    0.563229    
#> 138: 0.638323    0.960869    3.493265    0.357908    0.067257    0.011738    0.560270    
#> 139: 0.619770    0.969510    3.496170    0.347438    0.064235    0.012075    0.552807    
#> 140: 0.632266    0.976269    3.496786    0.330066    0.074056    0.011472    0.563551    
#> 141: 0.655470    0.961152    3.503750    0.319258    0.078816    0.010898    0.552061    
#> 142: 0.663635    0.952611    3.513936    0.349167    0.078991    0.010353    0.559502    
#> 143: 0.649098    0.977204    3.506488    0.342768    0.078965    0.010406    0.559716    
#> 144: 0.679858    0.968614    3.509328    0.325630    0.075017    0.009886    0.548881    
#> 145: 0.643989    0.980896    3.490821    0.314037    0.071266    0.010759    0.545548    
#> 146: 0.621409    0.989409    3.488496    0.367301    0.067703    0.012292    0.545094    
#> 147: 0.609119    0.973301    3.477187    0.359607    0.064317    0.014315    0.542861    
#> 148: 0.591018    0.981036    3.482622    0.349122    0.061102    0.013599    0.551257    
#> 149: 0.581458    0.982307    3.476391    0.350273    0.066385    0.014373    0.552196    
#> 150: 0.638629    0.980105    3.476207    0.341417    0.063066    0.013655    0.560631    
#> 151: 0.586458    1.010704    3.477452    0.341249    0.069822    0.012972    0.556973    
#> 152: 0.583669    0.991338    3.479073    0.415368    0.066379    0.011554    0.563067    
#> 153: 0.571105    0.988570    3.483696    0.409556    0.064454    0.013676    0.568423    
#> 154: 0.596555    0.988354    3.483739    0.341844    0.070462    0.013981    0.571017    
#> 155: 0.614428    0.967971    3.485137    0.310732    0.069497    0.013997    0.553678    
#> 156: 0.648915    0.977748    3.489235    0.312462    0.074147    0.014438    0.556737    
#> 157: 0.659464    0.961978    3.496864    0.317028    0.077444    0.012292    0.569182    
#> 158: 0.654701    0.979603    3.496759    0.331494    0.077422    0.011219    0.563019    
#> 159: 0.618534    0.973200    3.492830    0.351627    0.072021    0.010628    0.549718    
#> 160: 0.642877    0.945955    3.499753    0.361700    0.083841    0.011830    0.560046    
#> 161: 0.657301    0.959464    3.494656    0.352009    0.071148    0.010661    0.561201    
#> 162: 0.623188    0.976025    3.480465    0.318402    0.068914    0.009053    0.578527    
#> 163: 0.628592    0.967607    3.475278    0.364109    0.091627    0.007424    0.564694    
#> 164: 0.639779    0.983348    3.480780    0.368321    0.080328    0.007818    0.557274    
#> 165: 0.656977    0.965001    3.495361    0.292833    0.071746    0.010993    0.561062    
#> 166: 0.627034    0.992588    3.489100    0.268845    0.072966    0.008656    0.560067    
#> 167: 0.628063    0.993674    3.488331    0.285286    0.075737    0.009658    0.572424    
#> 168: 0.637024    0.982940    3.484725    0.349189    0.073695    0.009027    0.551008    
#> 169: 0.642636    1.004092    3.482488    0.342667    0.071731    0.009355    0.563914    
#> 170: 0.655788    0.988445    3.480859    0.362477    0.081234    0.010221    0.546196    
#> 171: 0.612312    0.976735    3.480816    0.369055    0.075192    0.010776    0.538247    
#> 172: 0.580222    0.980612    3.477691    0.347105    0.066989    0.011574    0.537472    
#> 173: 0.622399    1.006660    3.467002    0.401074    0.060365    0.011878    0.528215    
#> 174: 0.612761    0.979892    3.478181    0.389959    0.056643    0.013506    0.528482    
#> 175: 0.622074    0.990740    3.472850    0.396090    0.065405    0.011417    0.542315    
#> 176: 0.638485    1.003496    3.485237    0.379347    0.062662    0.011010    0.534263    
#> 177: 0.644467    0.978987    3.490372    0.388782    0.067066    0.010974    0.536703    
#> 178: 0.651774    0.965267    3.492739    0.352034    0.067459    0.011033    0.541867    
#> 179: 0.656405    0.986016    3.487573    0.348357    0.058030    0.012325    0.554821    
#> 180: 0.615911    0.991365    3.477796    0.334221    0.057562    0.013272    0.549043    
#> 181: 0.596417    0.992959    3.467111    0.333149    0.046701    0.013677    0.552690    
#> 182: 0.594296    0.998516    3.468472    0.358116    0.051240    0.013621    0.549479    
#> 183: 0.617039    0.996049    3.477153    0.313645    0.048880    0.014323    0.559330    
#> 184: 0.614852    0.988880    3.474268    0.340148    0.052329    0.013414    0.556086    
#> 185: 0.604275    0.996280    3.471589    0.359513    0.060562    0.014250    0.542467    
#> 186: 0.597212    1.006149    3.471354    0.355920    0.058466    0.017004    0.540092    
#> 187: 0.623184    0.985425    3.477920    0.391962    0.062617    0.014238    0.540086    
#> 188: 0.600192    0.987665    3.477067    0.356545    0.058030    0.011797    0.555554    
#> 189: 0.614800    1.002309    3.488070    0.389426    0.049502    0.012548    0.559018    
#> 190: 0.617154    0.996599    3.487647    0.334653    0.047612    0.013950    0.546161    
#> 191: 0.611281    0.991699    3.483363    0.310346    0.047837    0.012492    0.545255    
#> 192: 0.610929    0.995156    3.481037    0.364734    0.046257    0.012191    0.542207    
#> 193: 0.650735    1.009694    3.479488    0.405074    0.058640    0.010614    0.555296    
#> 194: 0.602212    0.991298    3.475374    0.375115    0.053929    0.012199    0.552402    
#> 195: 0.578198    0.990684    3.477002    0.355765    0.048598    0.011735    0.560671    
#> 196: 0.579783    0.989713    3.477859    0.284292    0.057041    0.011296    0.564777    
#> 197: 0.593286    0.982208    3.494159    0.284632    0.065857    0.010834    0.564903    
#> 198: 0.641479    0.951896    3.491401    0.338916    0.076785    0.010955    0.562727    
#> 199: 0.626403    0.963587    3.490078    0.359147    0.069651    0.009581    0.552128    
#> 200: 0.611715    0.974278    3.487540    0.377895    0.070902    0.009949    0.550745    
#> 201: 0.617319    0.966216    3.488562    0.409657    0.072572    0.010094    0.550166    
#> 202: 0.618113    0.969143    3.485886    0.427136    0.072874    0.010459    0.549642    
#> 203: 0.629186    0.972996    3.481987    0.437914    0.072134    0.010962    0.547825    
#> 204: 0.631894    0.973618    3.482043    0.440815    0.072322    0.010686    0.548719    
#> 205: 0.634495    0.979871    3.481782    0.439091    0.070844    0.010590    0.552492    
#> 206: 0.632870    0.985614    3.481770    0.431714    0.070855    0.010553    0.553780    
#> 207: 0.633835    0.988788    3.480473    0.433152    0.070571    0.010646    0.552471    
#> 208: 0.634780    0.989403    3.479745    0.429390    0.070896    0.010525    0.550774    
#> 209: 0.635789    0.987372    3.479246    0.431027    0.070203    0.010516    0.549290    
#> 210: 0.636107    0.985735    3.479444    0.428001    0.070239    0.010431    0.549530    
#> 211: 0.637343    0.986761    3.480239    0.424532    0.069861    0.010387    0.549324    
#> 212: 0.636211    0.986479    3.480317    0.416296    0.068895    0.010291    0.549720    
#> 213: 0.634933    0.986131    3.480125    0.408977    0.068706    0.010212    0.550624    
#> 214: 0.634771    0.985287    3.480677    0.406626    0.068820    0.010246    0.550419    
#> 215: 0.635729    0.984355    3.481349    0.400794    0.068934    0.010391    0.550961    
#> 216: 0.636978    0.981972    3.481941    0.397300    0.069100    0.010580    0.552088    
#> 217: 0.636021    0.982463    3.481845    0.393625    0.068986    0.010593    0.551623    
#> 218: 0.635284    0.983508    3.481494    0.392554    0.069352    0.010686    0.551636    
#> 219: 0.633689    0.983538    3.480636    0.389961    0.069497    0.010867    0.551571    
#> 220: 0.632683    0.983816    3.480499    0.392998    0.069673    0.011091    0.551614    
#> 221: 0.632879    0.984048    3.480313    0.393550    0.069815    0.011135    0.551688    
#> 222: 0.633485    0.983480    3.480671    0.390633    0.069905    0.011274    0.551708    
#> 223: 0.634520    0.982670    3.481246    0.389389    0.069683    0.011367    0.551737    
#> 224: 0.636416    0.982626    3.481803    0.389768    0.069174    0.011396    0.551423    
#> 225: 0.636760    0.981137    3.482547    0.389145    0.068774    0.011473    0.551473    
#> 226: 0.637836    0.979994    3.482775    0.387123    0.068565    0.011379    0.551762    
#> 227: 0.637448    0.979560    3.483232    0.384872    0.068432    0.011364    0.552335    
#> 228: 0.637125    0.980102    3.483132    0.384267    0.068191    0.011365    0.552037    
#> 229: 0.635328    0.979847    3.483084    0.382128    0.067922    0.011391    0.551860    
#> 230: 0.635075    0.980024    3.482871    0.380624    0.067770    0.011457    0.551856    
#> 231: 0.633898    0.981113    3.482568    0.380768    0.068172    0.011434    0.551918    
#> 232: 0.632112    0.981617    3.482225    0.379865    0.068223    0.011463    0.552085    
#> 233: 0.630219    0.981615    3.481806    0.380595    0.068267    0.011509    0.552193    
#> 234: 0.629297    0.981682    3.481558    0.380321    0.068378    0.011505    0.552300    
#> 235: 0.628198    0.981573    3.481104    0.379028    0.068011    0.011545    0.552605    
#> 236: 0.627717    0.982316    3.480931    0.379629    0.067960    0.011592    0.552788    
#> 237: 0.628272    0.982404    3.481081    0.378743    0.067638    0.011681    0.553321    
#> 238: 0.628856    0.982326    3.481166    0.378891    0.067317    0.011671    0.553639    
#> 239: 0.628178    0.982825    3.480877    0.378485    0.067205    0.011659    0.553496    
#> 240: 0.628195    0.982593    3.481002    0.377216    0.067058    0.011668    0.553309    
#> 241: 0.628670    0.981692    3.481216    0.377101    0.066834    0.011705    0.553188    
#> 242: 0.628123    0.981270    3.481109    0.376355    0.066556    0.011777    0.553345    
#> 243: 0.627497    0.981632    3.481047    0.375508    0.066263    0.011824    0.553311    
#> 244: 0.627287    0.982081    3.481045    0.376152    0.066117    0.011862    0.553329    
#> 245: 0.626854    0.982280    3.480861    0.377106    0.065955    0.011890    0.553906    
#> 246: 0.626976    0.982450    3.480878    0.377548    0.065732    0.011921    0.553996    
#> 247: 0.627027    0.981971    3.481079    0.377267    0.065547    0.011949    0.554309    
#> 248: 0.626911    0.981970    3.481165    0.376864    0.065476    0.011908    0.554394    
#> 249: 0.626311    0.981935    3.481155    0.375355    0.065402    0.011904    0.554483    
#> 250: 0.626033    0.982146    3.481251    0.374491    0.065413    0.011917    0.554625    
#> 251: 0.626367    0.982481    3.481569    0.373262    0.065554    0.011900    0.555050    
#> 252: 0.627090    0.982631    3.481764    0.374371    0.065694    0.011874    0.555226    
#> 253: 0.627088    0.982700    3.481722    0.375724    0.065789    0.011833    0.555305    
#> 254: 0.627357    0.983017    3.481689    0.377790    0.065883    0.011802    0.555354    
#> 255: 0.627734    0.983087    3.481702    0.380388    0.065913    0.011807    0.555226    
#> 256: 0.627887    0.983144    3.481663    0.380920    0.065899    0.011821    0.555169    
#> 257: 0.627564    0.982837    3.481712    0.380195    0.065842    0.011830    0.555315    
#> 258: 0.627454    0.982613    3.481903    0.379655    0.065859    0.011821    0.555651    
#> 259: 0.627611    0.982545    3.482051    0.379235    0.065814    0.011851    0.555705    
#> 260: 0.627890    0.982313    3.482274    0.379007    0.065666    0.011888    0.555670    
#> 261: 0.628311    0.982000    3.482438    0.379519    0.065533    0.011926    0.555677    
#> 262: 0.628353    0.982021    3.482440    0.379748    0.065392    0.011944    0.555532    
#> 263: 0.628229    0.982172    3.482412    0.379511    0.065336    0.011963    0.555680    
#> 264: 0.627800    0.981987    3.482306    0.379484    0.065170    0.011961    0.555949    
#> 265: 0.627714    0.981981    3.482305    0.379877    0.064988    0.011958    0.555996    
#> 266: 0.628356    0.981913    3.482429    0.380612    0.064945    0.011944    0.555881    
#> 267: 0.628776    0.982036    3.482532    0.382060    0.065027    0.011940    0.555698    
#> 268: 0.628350    0.982048    3.482527    0.381127    0.065205    0.011897    0.555628    
#> 269: 0.628484    0.981897    3.482513    0.380630    0.065301    0.011850    0.555616    
#> 270: 0.628560    0.981993    3.482524    0.380148    0.065361    0.011821    0.555429    
#> 271: 0.628312    0.981862    3.482424    0.380588    0.065385    0.011814    0.555481    
#> 272: 0.628099    0.981503    3.482379    0.379862    0.065409    0.011872    0.555629    
#> 273: 0.628474    0.981526    3.482430    0.380453    0.065435    0.011888    0.555652    
#> 274: 0.629005    0.981473    3.482596    0.380897    0.065451    0.011903    0.555543    
#> 275: 0.629050    0.981389    3.482550    0.380698    0.065362    0.011919    0.555524    
#> 276: 0.629111    0.981578    3.482566    0.381287    0.065378    0.011945    0.555379    
#> 277: 0.628805    0.981737    3.482599    0.381444    0.065397    0.011949    0.555452    
#> 278: 0.628915    0.981731    3.482607    0.381489    0.065386    0.011930    0.555529    
#> 279: 0.628600    0.981601    3.482602    0.381625    0.065403    0.011949    0.555626    
#> 280: 0.628677    0.981623    3.482681    0.381217    0.065311    0.011953    0.555623    
#> 281: 0.627945    0.981644    3.482667    0.380134    0.065208    0.011961    0.555744    
#> 282: 0.627490    0.981796    3.482677    0.379324    0.065181    0.011943    0.555781    
#> 283: 0.627343    0.981991    3.482697    0.378631    0.065337    0.011928    0.556131    
#> 284: 0.626695    0.981991    3.482628    0.377746    0.065418    0.011919    0.556120    
#> 285: 0.626434    0.982122    3.482515    0.377281    0.065580    0.011907    0.556198    
#> 286: 0.626403    0.982169    3.482443    0.377075    0.065598    0.011888    0.556102    
#> 287: 0.625859    0.982238    3.482357    0.376702    0.065671    0.011866    0.556186    
#> 288: 0.625965    0.982133    3.482390    0.376349    0.065631    0.011847    0.556184    
#> 289: 0.626467    0.982070    3.482522    0.376175    0.065537    0.011843    0.556093    
#> 290: 0.626973    0.981943    3.482674    0.375858    0.065648    0.011817    0.556163    
#> 291: 0.627227    0.981962    3.482796    0.375397    0.065644    0.011806    0.556118    
#> 292: 0.627056    0.981965    3.482761    0.375017    0.065636    0.011803    0.555971    
#> 293: 0.626872    0.982184    3.482693    0.374985    0.065517    0.011800    0.555854    
#> 294: 0.626802    0.982199    3.482613    0.375105    0.065394    0.011790    0.555686    
#> 295: 0.626675    0.982047    3.482538    0.375468    0.065293    0.011796    0.555560    
#> 296: 0.626973    0.982031    3.482538    0.376658    0.065219    0.011799    0.555490    
#> 297: 0.627398    0.982279    3.482556    0.377895    0.065316    0.011818    0.555546    
#> 298: 0.627524    0.982293    3.482506    0.378821    0.065364    0.011819    0.555400    
#> 299: 0.627357    0.982425    3.482368    0.379566    0.065409    0.011803    0.555218    
#> 300: 0.627315    0.982334    3.482383    0.379872    0.065291    0.011787    0.555171    
#> 301: 0.627426    0.982185    3.482313    0.380715    0.065225    0.011755    0.555178    
#> 302: 0.627737    0.982113    3.482319    0.380910    0.065262    0.011735    0.555113    
#> 303: 0.627780    0.982042    3.482303    0.380690    0.065305    0.011736    0.554843    
#> 304: 0.628005    0.982289    3.482284    0.381185    0.065308    0.011734    0.554811    
#> 305: 0.628046    0.982135    3.482258    0.381212    0.065318    0.011718    0.554808    
#> 306: 0.627751    0.982066    3.482084    0.381253    0.065313    0.011699    0.554703    
#> 307: 0.627537    0.982073    3.481896    0.381482    0.065225    0.011680    0.554760    
#> 308: 0.627093    0.982083    3.481731    0.381548    0.065145    0.011658    0.554741    
#> 309: 0.626742    0.981987    3.481611    0.381682    0.065066    0.011643    0.554818    
#> 310: 0.627072    0.982003    3.481577    0.381778    0.064936    0.011638    0.554741    
#> 311: 0.627046    0.982096    3.481549    0.381591    0.064824    0.011651    0.554713    
#> 312: 0.626574    0.982208    3.481402    0.381123    0.064730    0.011667    0.554744    
#> 313: 0.626284    0.982099    3.481289    0.380868    0.064636    0.011663    0.554797    
#> 314: 0.625761    0.982248    3.481172    0.380664    0.064629    0.011653    0.554749    
#> 315: 0.625441    0.982334    3.481115    0.380266    0.064690    0.011644    0.554704    
#> 316: 0.624944    0.982488    3.480945    0.379793    0.064813    0.011617    0.554668    
#> 317: 0.624544    0.982510    3.480855    0.379468    0.064928    0.011599    0.554734    
#> 318: 0.624350    0.982625    3.480774    0.379333    0.064899    0.011593    0.554711    
#> 319: 0.624249    0.982655    3.480759    0.379354    0.064892    0.011600    0.554761    
#> 320: 0.623890    0.982635    3.480680    0.379241    0.064958    0.011593    0.554791    
#> 321: 0.623428    0.982654    3.480560    0.378662    0.064971    0.011569    0.554870    
#> 322: 0.623246    0.982698    3.480508    0.378291    0.065093    0.011553    0.554914    
#> 323: 0.622952    0.982680    3.480473    0.378147    0.065160    0.011550    0.554934    
#> 324: 0.622998    0.982727    3.480496    0.378353    0.065151    0.011551    0.554910    
#> 325: 0.622913    0.982910    3.480465    0.378248    0.065136    0.011537    0.554914    
#> 326: 0.622978    0.982885    3.480498    0.377716    0.065116    0.011521    0.554998    
#> 327: 0.623039    0.982867    3.480551    0.377363    0.065082    0.011519    0.555134    
#> 328: 0.623095    0.982890    3.480548    0.377183    0.065112    0.011500    0.555103    
#> 329: 0.623070    0.982883    3.480589    0.376983    0.065122    0.011488    0.555082    
#> 330: 0.622756    0.982909    3.480534    0.376632    0.065062    0.011487    0.555074    
#> 331: 0.622774    0.983014    3.480499    0.376461    0.065022    0.011490    0.554965    
#> 332: 0.622722    0.983136    3.480593    0.376221    0.065039    0.011510    0.554908    
#> 333: 0.622666    0.983173    3.480593    0.375882    0.065003    0.011520    0.554946    
#> 334: 0.622540    0.983084    3.480507    0.376030    0.065047    0.011520    0.554931    
#> 335: 0.622403    0.983131    3.480481    0.375772    0.064998    0.011532    0.554870    
#> 336: 0.622181    0.983283    3.480411    0.375660    0.064988    0.011536    0.554819    
#> 337: 0.622138    0.983617    3.480328    0.376050    0.065005    0.011524    0.554842    
#> 338: 0.621852    0.983777    3.480287    0.375835    0.065063    0.011511    0.554799    
#> 339: 0.621586    0.983887    3.480256    0.375705    0.065227    0.011499    0.554717    
#> 340: 0.621494    0.983731    3.480250    0.375457    0.065318    0.011465    0.554731    
#> 341: 0.621566    0.983671    3.480309    0.375291    0.065447    0.011452    0.554731    
#> 342: 0.621574    0.983437    3.480376    0.375208    0.065486    0.011451    0.554721    
#> 343: 0.621583    0.983338    3.480425    0.375000    0.065496    0.011442    0.554753    
#> 344: 0.621535    0.983173    3.480478    0.374489    0.065553    0.011451    0.554709    
#> 345: 0.621461    0.983145    3.480532    0.374267    0.065639    0.011454    0.554726    
#> 346: 0.621378    0.983213    3.480490    0.373872    0.065657    0.011445    0.554651    
#> 347: 0.621681    0.983195    3.480519    0.374609    0.065722    0.011445    0.554628    
#> 348: 0.621557    0.983235    3.480495    0.374710    0.065765    0.011432    0.554711    
#> 349: 0.621587    0.983072    3.480515    0.374585    0.065745    0.011428    0.554700    
#> 350: 0.621563    0.982955    3.480504    0.374726    0.065824    0.011406    0.554723    
#> 351: 0.621706    0.983024    3.480498    0.374997    0.065824    0.011391    0.554813    
#> 352: 0.621813    0.983102    3.480515    0.375197    0.065857    0.011368    0.554934    
#> 353: 0.621842    0.983232    3.480518    0.374822    0.065861    0.011346    0.554973    
#> 354: 0.621957    0.983296    3.480476    0.374498    0.065864    0.011342    0.555001    
#> 355: 0.622138    0.983160    3.480477    0.374374    0.065946    0.011327    0.554979    
#> 356: 0.622352    0.983073    3.480552    0.374469    0.065998    0.011329    0.554977    
#> 357: 0.622443    0.983061    3.480592    0.374250    0.065995    0.011333    0.554956    
#> 358: 0.622493    0.982999    3.480631    0.374415    0.066017    0.011344    0.554870    
#> 359: 0.622529    0.983043    3.480615    0.374306    0.065984    0.011337    0.554866    
#> 360: 0.622421    0.983140    3.480491    0.374664    0.065995    0.011337    0.554783    
#> 361: 0.622266    0.983170    3.480415    0.374728    0.065962    0.011331    0.554726    
#> 362: 0.622166    0.983180    3.480370    0.374666    0.065921    0.011317    0.554564    
#> 363: 0.622227    0.983103    3.480373    0.374735    0.065932    0.011302    0.554445    
#> 364: 0.622393    0.983126    3.480432    0.374858    0.065992    0.011305    0.554433    
#> 365: 0.622393    0.983025    3.480514    0.374651    0.066006    0.011321    0.554446    
#> 366: 0.622412    0.983028    3.480501    0.374224    0.065992    0.011341    0.554450    
#> 367: 0.622458    0.983074    3.480508    0.374197    0.065928    0.011346    0.554452    
#> 368: 0.622620    0.983022    3.480534    0.374347    0.065879    0.011349    0.554397    
#> 369: 0.622508    0.983048    3.480512    0.374276    0.065853    0.011338    0.554490    
#> 370: 0.622513    0.983058    3.480535    0.373951    0.065806    0.011348    0.554474    
#> 371: 0.622380    0.983204    3.480466    0.373728    0.065824    0.011336    0.554513    
#> 372: 0.622184    0.983402    3.480370    0.373807    0.065871    0.011344    0.554577    
#> 373: 0.622052    0.983575    3.480280    0.374071    0.065824    0.011342    0.554627    
#> 374: 0.622254    0.983567    3.480255    0.374414    0.065722    0.011351    0.554656    
#> 375: 0.622289    0.983592    3.480283    0.374672    0.065635    0.011362    0.554674    
#> 376: 0.622288    0.983644    3.480302    0.374949    0.065595    0.011370    0.554609    
#> 377: 0.622154    0.983760    3.480284    0.375199    0.065629    0.011370    0.554582    
#> 378: 0.621904    0.983765    3.480252    0.375143    0.065631    0.011377    0.554613    
#> 379: 0.621783    0.983669    3.480245    0.374948    0.065594    0.011360    0.554614    
#> 380: 0.621717    0.983649    3.480253    0.374972    0.065648    0.011346    0.554524    
#> 381: 0.621615    0.983544    3.480283    0.374709    0.065646    0.011342    0.554560    
#> 382: 0.621545    0.983468    3.480331    0.374395    0.065657    0.011338    0.554538    
#> 383: 0.621372    0.983448    3.480309    0.374039    0.065697    0.011328    0.554453    
#> 384: 0.621263    0.983414    3.480309    0.373772    0.065708    0.011316    0.554391    
#> 385: 0.621252    0.983357    3.480309    0.373896    0.065713    0.011311    0.554445    
#> 386: 0.621385    0.983490    3.480343    0.374275    0.065751    0.011317    0.554475    
#> 387: 0.621450    0.983609    3.480360    0.374206    0.065747    0.011331    0.554478    
#> 388: 0.621603    0.983648    3.480384    0.374109    0.065692    0.011348    0.554504    
#> 389: 0.621557    0.983539    3.480386    0.373813    0.065664    0.011361    0.554579    
#> 390: 0.621461    0.983528    3.480360    0.373465    0.065572    0.011372    0.554638    
#> 391: 0.621469    0.983533    3.480320    0.373450    0.065492    0.011394    0.554571    
#> 392: 0.621384    0.983531    3.480280    0.373702    0.065430    0.011397    0.554596    
#> 393: 0.621287    0.983475    3.480212    0.373876    0.065404    0.011405    0.554593    
#> 394: 0.621245    0.983494    3.480190    0.373890    0.065389    0.011415    0.554526    
#> 395: 0.621244    0.983567    3.480180    0.373771    0.065427    0.011431    0.554507    
#> 396: 0.621137    0.983638    3.480114    0.373750    0.065407    0.011443    0.554444    
#> 397: 0.621106    0.983662    3.480095    0.373753    0.065380    0.011466    0.554406    
#> 398: 0.621256    0.983662    3.480083    0.373792    0.065377    0.011478    0.554379    
#> 399: 0.621193    0.983676    3.480110    0.373690    0.065396    0.011481    0.554342    
#> 400: 0.621247    0.983649    3.480145    0.373490    0.065412    0.011482    0.554281    
#> 401: 0.621408    0.983678    3.480176    0.373323    0.065405    0.011488    0.554309    
#> 402: 0.621435    0.983736    3.480171    0.373335    0.065383    0.011491    0.554307    
#> 403: 0.621553    0.983749    3.480173    0.373209    0.065395    0.011492    0.554265    
#> 404: 0.621481    0.983823    3.480110    0.372885    0.065425    0.011489    0.554173    
#> 405: 0.621327    0.983848    3.480106    0.372725    0.065457    0.011482    0.554143    
#> 406: 0.621331    0.983874    3.480099    0.373106    0.065502    0.011481    0.554162    
#> 407: 0.621293    0.983908    3.480117    0.373200    0.065620    0.011468    0.554143    
#> 408: 0.621391    0.983971    3.480097    0.373109    0.065695    0.011457    0.554138    
#> 409: 0.621402    0.983888    3.480069    0.373214    0.065704    0.011443    0.554189    
#> 410: 0.621358    0.983921    3.480023    0.373297    0.065725    0.011433    0.554157    
#> 411: 0.621396    0.983850    3.479995    0.373384    0.065670    0.011429    0.554192    
#> 412: 0.621514    0.983913    3.479972    0.373391    0.065660    0.011428    0.554173    
#> 413: 0.621498    0.983983    3.479947    0.373244    0.065654    0.011420    0.554160    
#> 414: 0.621234    0.983947    3.479958    0.373129    0.065642    0.011406    0.554148    
#> 415: 0.621199    0.983970    3.479932    0.373194    0.065635    0.011399    0.554112    
#> 416: 0.621166    0.984102    3.479923    0.373254    0.065636    0.011398    0.554043    
#> 417: 0.621141    0.984208    3.479856    0.373323    0.065655    0.011391    0.553995    
#> 418: 0.621002    0.984265    3.479812    0.373300    0.065663    0.011391    0.553872    
#> 419: 0.620922    0.984405    3.479755    0.373379    0.065674    0.011390    0.553847    
#> 420: 0.620900    0.984471    3.479728    0.373374    0.065684    0.011371    0.553766    
#> 421: 0.620819    0.984541    3.479715    0.373363    0.065705    0.011348    0.553718    
#> 422: 0.620897    0.984504    3.479709    0.373448    0.065738    0.011323    0.553750    
#> 423: 0.620926    0.984487    3.479686    0.373260    0.065825    0.011306    0.553789    
#> 424: 0.620751    0.984474    3.479614    0.373107    0.065821    0.011289    0.553769    
#> 425: 0.620834    0.984531    3.479568    0.373141    0.065773    0.011279    0.553830    
#> 426: 0.620796    0.984594    3.479529    0.373168    0.065739    0.011272    0.553865    
#> 427: 0.620684    0.984616    3.479514    0.372908    0.065675    0.011265    0.553884    
#> 428: 0.620626    0.984651    3.479487    0.372803    0.065744    0.011261    0.553853    
#> 429: 0.620599    0.984669    3.479503    0.372647    0.065746    0.011261    0.553826    
#> 430: 0.620610    0.984652    3.479535    0.372567    0.065797    0.011262    0.553798    
#> 431: 0.620577    0.984667    3.479500    0.372572    0.065812    0.011264    0.553716    
#> 432: 0.620431    0.984717    3.479494    0.372560    0.065808    0.011282    0.553619    
#> 433: 0.620405    0.984802    3.479501    0.372666    0.065765    0.011292    0.553619    
#> 434: 0.620314    0.984784    3.479491    0.372684    0.065783    0.011302    0.553569    
#> 435: 0.620341    0.984794    3.479465    0.372601    0.065746    0.011307    0.553529    
#> 436: 0.620394    0.984750    3.479508    0.372517    0.065706    0.011315    0.553517    
#> 437: 0.620429    0.984699    3.479521    0.372331    0.065744    0.011306    0.553555    
#> 438: 0.620448    0.984772    3.479535    0.372194    0.065699    0.011295    0.553549    
#> 439: 0.620480    0.984859    3.479525    0.372172    0.065707    0.011282    0.553508    
#> 440: 0.620556    0.984863    3.479581    0.372213    0.065713    0.011283    0.553512    
#> 441: 0.620726    0.984816    3.479630    0.372408    0.065734    0.011280    0.553471    
#> 442: 0.620681    0.984779    3.479665    0.372358    0.065801    0.011280    0.553456    
#> 443: 0.620649    0.984752    3.479655    0.372271    0.065771    0.011279    0.553520    
#> 444: 0.620635    0.984782    3.479622    0.372339    0.065734    0.011272    0.553559    
#> 445: 0.620499    0.984865    3.479584    0.372230    0.065683    0.011262    0.553553    
#> 446: 0.620347    0.984917    3.479543    0.372060    0.065636    0.011255    0.553515    
#> 447: 0.620349    0.985011    3.479521    0.371862    0.065591    0.011260    0.553498    
#> 448: 0.620268    0.985024    3.479503    0.371707    0.065554    0.011272    0.553444    
#> 449: 0.620263    0.985083    3.479522    0.371760    0.065530    0.011285    0.553424    
#> 450: 0.620200    0.985100    3.479515    0.371690    0.065550    0.011292    0.553387    
#> 451: 0.620223    0.985124    3.479500    0.371757    0.065615    0.011292    0.553357    
#> 452: 0.620127    0.985179    3.479479    0.371881    0.065634    0.011304    0.553304    
#> 453: 0.620086    0.985199    3.479439    0.371976    0.065633    0.011304    0.553284    
#> 454: 0.620057    0.985293    3.479432    0.372028    0.065576    0.011304    0.553259    
#> 455: 0.620060    0.985316    3.479429    0.371995    0.065572    0.011300    0.553247    
#> 456: 0.619957    0.985266    3.479426    0.371789    0.065589    0.011299    0.553232    
#> 457: 0.620011    0.985219    3.479473    0.371627    0.065607    0.011294    0.553167    
#> 458: 0.620035    0.985288    3.479532    0.371304    0.065574    0.011291    0.553127    
#> 459: 0.619981    0.985382    3.479542    0.371076    0.065571    0.011289    0.553082    
#> 460: 0.619960    0.985404    3.479550    0.371002    0.065613    0.011291    0.553071    
#> 461: 0.620005    0.985411    3.479575    0.370896    0.065623    0.011294    0.553082    
#> 462: 0.619923    0.985399    3.479619    0.370706    0.065597    0.011296    0.553049    
#> 463: 0.619799    0.985407    3.479615    0.370496    0.065578    0.011298    0.553067    
#> 464: 0.619808    0.985394    3.479601    0.370431    0.065568    0.011296    0.553052    
#> 465: 0.619847    0.985324    3.479590    0.370394    0.065562    0.011292    0.553015    
#> 466: 0.619798    0.985386    3.479546    0.370279    0.065588    0.011286    0.552985    
#> 467: 0.619686    0.985389    3.479526    0.370459    0.065584    0.011271    0.552968    
#> 468: 0.619772    0.985341    3.479566    0.370497    0.065579    0.011272    0.552969    
#> 469: 0.619806    0.985401    3.479574    0.370295    0.065560    0.011271    0.552990    
#> 470: 0.619770    0.985389    3.479553    0.370498    0.065542    0.011269    0.553000    
#> 471: 0.619825    0.985341    3.479570    0.370604    0.065506    0.011274    0.552975    
#> 472: 0.620011    0.985279    3.479607    0.370891    0.065482    0.011283    0.552944    
#> 473: 0.620067    0.985250    3.479620    0.370972    0.065508    0.011292    0.552913    
#> 474: 0.620056    0.985198    3.479624    0.370870    0.065540    0.011303    0.552977    
#> 475: 0.620126    0.985263    3.479639    0.370960    0.065549    0.011306    0.553018    
#> 476: 0.620062    0.985174    3.479663    0.370794    0.065519    0.011310    0.553071    
#> 477: 0.620086    0.985113    3.479717    0.370969    0.065467    0.011311    0.553081    
#> 478: 0.620088    0.985063    3.479741    0.371211    0.065458    0.011320    0.553134    
#> 479: 0.620242    0.985116    3.479761    0.371506    0.065430    0.011323    0.553149    
#> 480: 0.620369    0.985097    3.479770    0.371679    0.065393    0.011328    0.553188    
#> 481: 0.620509    0.985109    3.479775    0.371917    0.065355    0.011329    0.553226    
#> 482: 0.620655    0.985125    3.479770    0.372209    0.065359    0.011333    0.553253    
#> 483: 0.620577    0.985102    3.479751    0.372196    0.065347    0.011328    0.553233    
#> 484: 0.620595    0.984983    3.479739    0.372471    0.065411    0.011321    0.553221    
#> 485: 0.620591    0.984955    3.479736    0.372433    0.065475    0.011311    0.553193    
#> 486: 0.620593    0.984963    3.479758    0.372609    0.065465    0.011308    0.553160    
#> 487: 0.620891    0.984947    3.479821    0.373005    0.065428    0.011313    0.553168    
#> 488: 0.620950    0.984942    3.479842    0.373036    0.065454    0.011313    0.553108    
#> 489: 0.621091    0.984866    3.479830    0.373197    0.065499    0.011314    0.553077    
#> 490: 0.621168    0.984811    3.479854    0.373215    0.065486    0.011320    0.553018    
#> 491: 0.621161    0.984877    3.479869    0.373190    0.065479    0.011319    0.552948    
#> 492: 0.621167    0.984941    3.479890    0.373172    0.065480    0.011316    0.552951    
#> 493: 0.621061    0.984861    3.479915    0.372908    0.065453    0.011316    0.552980    
#> 494: 0.621159    0.984843    3.479928    0.372730    0.065416    0.011311    0.552963    
#> 495: 0.621250    0.984855    3.479950    0.372693    0.065392    0.011309    0.552956    
#> 496: 0.621418    0.984879    3.479962    0.372542    0.065389    0.011306    0.552976    
#> 497: 0.621498    0.984843    3.479997    0.372428    0.065403    0.011304    0.553027    
#> 498: 0.621500    0.984796    3.479984    0.372538    0.065374    0.011293    0.553019    
#> 499: 0.621481    0.984813    3.479957    0.372526    0.065417    0.011279    0.552972    
#> 500: 0.621475    0.984776    3.479941    0.372464    0.065407    0.011272    0.552978    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.271907    0.954673    3.443733    0.392401    0.071476    0.016800    1.753797    
#> 002: 0.362770    0.956603    3.461933    0.372781    0.067902    0.015960    1.221995    
#> 003: 0.470313    0.856210    3.480147    0.354142    0.064507    0.015162    0.868615    
#> 004: 0.453450    0.843604    3.469376    0.336435    0.072861    0.015436    0.772220    
#> 005: 0.500232    0.874339    3.453332    0.319613    0.069218    0.015008    0.709748    
#> 006: 0.448461    0.850935    3.440177    0.303633    0.076728    0.014257    0.672349    
#> 007: 0.410118    0.863182    3.435406    0.288451    0.079647    0.014218    0.665804    
#> 008: 0.386623    0.864013    3.426637    0.317383    0.075664    0.018734    0.643391    
#> 009: 0.388765    0.833073    3.427407    0.319044    0.071881    0.018074    0.633574    
#> 010: 0.389778    0.849048    3.429804    0.325508    0.073180    0.018640    0.634698    
#> 011: 0.432855    0.865500    3.432205    0.312916    0.091079    0.017708    0.620893    
#> 012: 0.448523    0.859703    3.435393    0.297271    0.093827    0.016823    0.621380    
#> 013: 0.399912    0.880363    3.422589    0.282407    0.089135    0.017284    0.638553    
#> 014: 0.436118    0.865796    3.433447    0.281803    0.085437    0.016531    0.641361    
#> 015: 0.444789    0.868534    3.436440    0.307492    0.083291    0.015705    0.626689    
#> 016: 0.434510    0.886004    3.447582    0.300497    0.079126    0.022114    0.635156    
#> 017: 0.434431    0.884722    3.445044    0.296278    0.075170    0.021008    0.605900    
#> 018: 0.455314    0.894497    3.431043    0.302616    0.082153    0.020564    0.617824    
#> 019: 0.428712    0.890217    3.431119    0.287485    0.088012    0.019535    0.603786    
#> 020: 0.438846    0.890347    3.440190    0.290464    0.085542    0.018559    0.613764    
#> 021: 0.464888    0.871814    3.440698    0.275941    0.081265    0.017631    0.626262    
#> 022: 0.451770    0.873428    3.450848    0.290810    0.077201    0.017118    0.604967    
#> 023: 0.500402    0.863415    3.453393    0.349486    0.074188    0.019307    0.625604    
#> 024: 0.496070    0.892340    3.446540    0.332012    0.085141    0.018342    0.609497    
#> 025: 0.455992    0.876023    3.442537    0.320837    0.083284    0.019137    0.604701    
#> 026: 0.425315    0.893300    3.433661    0.304795    0.085252    0.018181    0.614545    
#> 027: 0.433088    0.896046    3.426970    0.289555    0.080989    0.017272    0.625544    
#> 028: 0.428972    0.898465    3.434451    0.285035    0.084686    0.018436    0.595491    
#> 029: 0.415961    0.895563    3.422080    0.297619    0.094369    0.018754    0.613764    
#> 030: 0.418103    0.908657    3.408422    0.289709    0.089650    0.017816    0.612658    
#> 031: 0.357092    0.895458    3.417307    0.302478    0.085168    0.016925    0.617039    
#> 032: 0.380757    0.890110    3.418087    0.287354    0.082037    0.016079    0.622176    
#> 033: 0.354090    0.906546    3.410357    0.272987    0.088116    0.015275    0.617445    
#> 034: 0.384925    0.916670    3.410370    0.288115    0.096592    0.014511    0.628873    
#> 035: 0.384558    0.900443    3.410289    0.286579    0.102915    0.013786    0.612492    
#> 036: 0.393780    0.905323    3.418071    0.312233    0.097769    0.014597    0.614537    
#> 037: 0.389727    0.913190    3.412991    0.316732    0.092881    0.015687    0.626446    
#> 038: 0.372585    0.908811    3.405011    0.300896    0.088237    0.016872    0.611692    
#> 039: 0.404428    0.906012    3.419022    0.349769    0.089952    0.020839    0.587724    
#> 040: 0.387893    0.921192    3.413411    0.338093    0.100679    0.019797    0.606002    
#> 041: 0.379871    0.915169    3.411870    0.321189    0.095645    0.018807    0.596278    
#> 042: 0.416758    0.892282    3.417611    0.306667    0.090863    0.018043    0.594755    
#> 043: 0.392739    0.901962    3.407626    0.320826    0.091205    0.020867    0.593182    
#> 044: 0.379807    0.916018    3.405549    0.317098    0.086645    0.020153    0.595610    
#> 045: 0.362897    0.933666    3.393462    0.346133    0.093189    0.019146    0.596402    
#> 046: 0.370662    0.918957    3.402288    0.328826    0.088530    0.018188    0.607395    
#> 047: 0.372607    0.907572    3.398529    0.361155    0.088040    0.017279    0.612125    
#> 048: 0.383900    0.913282    3.404400    0.343098    0.083638    0.016603    0.609979    
#> 049: 0.379951    0.909982    3.413170    0.325943    0.079456    0.017383    0.621189    
#> 050: 0.427868    0.868188    3.421790    0.309646    0.088469    0.017275    0.636548    
#> 051: 0.424407    0.895755    3.415976    0.325503    0.084045    0.020468    0.625066    
#> 052: 0.398105    0.900127    3.426552    0.309228    0.084723    0.019444    0.620140    
#> 053: 0.421888    0.875079    3.422480    0.317627    0.080487    0.019369    0.604072    
#> 054: 0.381776    0.898817    3.419803    0.307106    0.092264    0.018636    0.611638    
#> 055: 0.382246    0.889243    3.421432    0.291750    0.099435    0.017705    0.619923    
#> 056: 0.405961    0.884157    3.427118    0.300238    0.094463    0.019040    0.634870    
#> 057: 0.422235    0.881838    3.434648    0.303166    0.098769    0.019445    0.623873    
#> 058: 0.427390    0.880608    3.428551    0.288007    0.093830    0.018472    0.630975    
#> 059: 0.423152    0.848376    3.428910    0.337153    0.089139    0.017549    0.639044    
#> 060: 0.455388    0.856577    3.438895    0.328843    0.084682    0.018970    0.622719    
#> 061: 0.455085    0.873041    3.441604    0.329083    0.084107    0.019056    0.632995    
#> 062: 0.425989    0.899252    3.435088    0.329719    0.113964    0.018103    0.647518    
#> 063: 0.444543    0.858244    3.438066    0.330141    0.108266    0.019875    0.643510    
#> 064: 0.469675    0.883864    3.442535    0.337902    0.109514    0.018882    0.632608    
#> 065: 0.464914    0.875581    3.430600    0.328185    0.104038    0.017938    0.619807    
#> 066: 0.441636    0.891561    3.437702    0.355019    0.098836    0.020902    0.603033    
#> 067: 0.433652    0.876144    3.427308    0.374971    0.093894    0.023701    0.595554    
#> 068: 0.411749    0.886722    3.436106    0.373339    0.089200    0.022516    0.616601    
#> 069: 0.419084    0.883775    3.418910    0.354672    0.088437    0.021391    0.627807    
#> 070: 0.420773    0.884266    3.424739    0.345705    0.096526    0.020321    0.606885    
#> 071: 0.402460    0.909103    3.413662    0.328420    0.106927    0.019305    0.601143    
#> 072: 0.368796    0.886278    3.414859    0.311999    0.101581    0.018340    0.614819    
#> 073: 0.377932    0.910850    3.422986    0.296399    0.096502    0.017423    0.625917    
#> 074: 0.374975    0.877747    3.411747    0.285187    0.091677    0.016552    0.609113    
#> 075: 0.398150    0.874757    3.432457    0.311091    0.087093    0.017697    0.590366    
#> 076: 0.425829    0.875433    3.434496    0.342446    0.084819    0.016813    0.601816    
#> 077: 0.444463    0.876349    3.438029    0.325324    0.092223    0.015972    0.606954    
#> 078: 0.435434    0.886866    3.433632    0.309057    0.097835    0.016437    0.601071    
#> 079: 0.419162    0.881381    3.437503    0.293604    0.095817    0.019335    0.622693    
#> 080: 0.422103    0.888021    3.423521    0.279670    0.102620    0.018665    0.632115    
#> 081: 0.403423    0.902508    3.420705    0.265687    0.097489    0.017732    0.620440    
#> 082: 0.422392    0.873343    3.435104    0.264247    0.095418    0.016845    0.623291    
#> 083: 0.417665    0.897685    3.438979    0.262515    0.091662    0.018087    0.632219    
#> 084: 0.431259    0.882421    3.430657    0.304834    0.095596    0.017915    0.627835    
#> 085: 0.412241    0.894663    3.438447    0.291419    0.100451    0.017033    0.640240    
#> 086: 0.415272    0.890209    3.432841    0.276848    0.095428    0.018189    0.613535    
#> 087: 0.420178    0.905109    3.420161    0.276838    0.090657    0.017733    0.613456    
#> 088: 0.379998    0.902048    3.421861    0.309510    0.086124    0.017169    0.624328    
#> 089: 0.404939    0.905769    3.414023    0.340288    0.081818    0.018438    0.613789    
#> 090: 0.380957    0.902544    3.408437    0.333548    0.084581    0.018721    0.604740    
#> 091: 0.374947    0.904988    3.396154    0.316871    0.089272    0.018744    0.614214    
#> 092: 0.364776    0.921787    3.404977    0.301027    0.084809    0.019303    0.617227    
#> 093: 0.341448    0.901060    3.395990    0.316613    0.089751    0.018337    0.630018    
#> 094: 0.370568    0.912591    3.400628    0.326860    0.085263    0.018019    0.622760    
#> 095: 0.364490    0.924099    3.414999    0.353586    0.081000    0.018616    0.621889    
#> 096: 0.360527    0.907628    3.411848    0.370608    0.076950    0.022479    0.608324    
#> 097: 0.390860    0.926508    3.410506    0.352078    0.076753    0.021355    0.600506    
#> 098: 0.404989    0.926869    3.415940    0.334474    0.072915    0.020288    0.603840    
#> 099: 0.387964    0.906769    3.413533    0.317750    0.069269    0.019273    0.608469    
#> 100: 0.389871    0.913361    3.416593    0.301863    0.071664    0.019216    0.595428    
#> 101: 0.395264    0.903709    3.403544    0.299952    0.078974    0.018255    0.590335    
#> 102: 0.395732    0.898948    3.414200    0.311701    0.094582    0.017898    0.598095    
#> 103: 0.396264    0.896682    3.415550    0.304933    0.089853    0.017003    0.608221    
#> 104: 0.377573    0.894202    3.418208    0.310787    0.085361    0.016153    0.619266    
#> 105: 0.397052    0.884682    3.422005    0.315904    0.108075    0.015345    0.604299    
#> 106: 0.415017    0.890005    3.425116    0.300109    0.102671    0.014578    0.617090    
#> 107: 0.431260    0.903379    3.430528    0.312650    0.097537    0.017098    0.618919    
#> 108: 0.428911    0.896599    3.436962    0.297017    0.092661    0.017787    0.613958    
#> 109: 0.420126    0.885061    3.445483    0.282166    0.088028    0.016897    0.623557    
#> 110: 0.426007    0.885821    3.427035    0.268058    0.102589    0.016052    0.617967    
#> 111: 0.422239    0.889596    3.433060    0.260895    0.097460    0.015250    0.598282    
#> 112: 0.401073    0.876646    3.417351    0.252423    0.115436    0.014487    0.603960    
#> 113: 0.416890    0.920646    3.428163    0.325001    0.109664    0.016080    0.602403    
#> 114: 0.422485    0.900999    3.424298    0.308751    0.104181    0.015451    0.603086    
#> 115: 0.412665    0.865382    3.418869    0.293314    0.103998    0.014678    0.621654    
#> 116: 0.409742    0.882525    3.424704    0.311391    0.098799    0.013944    0.609290    
#> 117: 0.416691    0.898161    3.432987    0.295822    0.100473    0.013247    0.612806    
#> 118: 0.441088    0.884406    3.431813    0.304974    0.095449    0.015118    0.605797    
#> 119: 0.438320    0.891666    3.425254    0.306878    0.096658    0.018203    0.599931    
#> 120: 0.392615    0.886726    3.420958    0.291534    0.091825    0.017293    0.608394    
#> 121: 0.391541    0.916395    3.420885    0.276958    0.094448    0.016497    0.612566    
#> 122: 0.429931    0.879570    3.427417    0.348585    0.089726    0.018613    0.596611    
#> 123: 0.438177    0.910956    3.424832    0.353223    0.087428    0.020008    0.604484    
#> 124: 0.412919    0.922853    3.417836    0.335562    0.084702    0.021088    0.605251    
#> 125: 0.419909    0.916306    3.416665    0.335311    0.080467    0.020158    0.601362    
#> 126: 0.410359    0.922215    3.406734    0.336465    0.076443    0.021622    0.604419    
#> 127: 0.418531    0.897797    3.405579    0.380159    0.081901    0.020541    0.613535    
#> 128: 0.369276    0.908044    3.410416    0.361151    0.091327    0.019514    0.608284    
#> 129: 0.385707    0.904569    3.412057    0.343094    0.107673    0.018538    0.617855    
#> 130: 0.421584    0.910295    3.409408    0.378979    0.102289    0.021246    0.599317    
#> 131: 0.404528    0.898191    3.406947    0.367007    0.097175    0.022739    0.606582    
#> 132: 0.370721    0.917345    3.396945    0.348657    0.092316    0.021602    0.603352    
#> 133: 0.374014    0.899692    3.405166    0.360725    0.090338    0.021750    0.586240    
#> 134: 0.388409    0.872680    3.419843    0.349892    0.085821    0.023238    0.590482    
#> 135: 0.425295    0.878470    3.429494    0.334705    0.084128    0.022076    0.586511    
#> 136: 0.421880    0.875661    3.425117    0.352708    0.079921    0.021392    0.589708    
#> 137: 0.417478    0.885449    3.424584    0.340387    0.075925    0.022630    0.598740    
#> 138: 0.405826    0.885230    3.421808    0.323367    0.072809    0.021499    0.594820    
#> 139: 0.413231    0.879728    3.432748    0.315672    0.085172    0.022876    0.614306    
#> 140: 0.413270    0.901622    3.430881    0.299888    0.080914    0.023450    0.633115    
#> 141: 0.391381    0.877578    3.421268    0.284894    0.082484    0.022277    0.626033    
#> 142: 0.397677    0.877195    3.432916    0.284301    0.079889    0.021163    0.623101    
#> 143: 0.384195    0.889639    3.425023    0.270086    0.075895    0.020495    0.624384    
#> 144: 0.433725    0.888136    3.429993    0.278940    0.073149    0.019470    0.595925    
#> 145: 0.393192    0.882973    3.417139    0.302656    0.091554    0.018497    0.599878    
#> 146: 0.393757    0.892516    3.420514    0.317641    0.086977    0.019297    0.596500    
#> 147: 0.378380    0.888539    3.411846    0.339946    0.082628    0.020546    0.591465    
#> 148: 0.383126    0.897183    3.422217    0.322949    0.091222    0.019519    0.604556    
#> 149: 0.407994    0.885435    3.420261    0.306801    0.086846    0.018543    0.586905    
#> 150: 0.390230    0.885714    3.403354    0.291461    0.091828    0.017616    0.600192    
#> 151: 0.360268    0.928166    3.405990    0.276888    0.105149    0.016735    0.594019    
#> 152: 0.351548    0.916192    3.413112    0.300978    0.096528    0.018460    0.584634    
#> 153: 0.373787    0.913916    3.416105    0.314378    0.092467    0.017139    0.600337    
#> 154: 0.399883    0.905336    3.413203    0.334084    0.088581    0.017594    0.608203    
#> 155: 0.370234    0.895316    3.409540    0.325001    0.092978    0.017464    0.603615    
#> 156: 0.392127    0.889168    3.413743    0.321642    0.094080    0.017644    0.607287    
#> 157: 0.396529    0.890331    3.419864    0.362321    0.093819    0.021277    0.607713    
#> 158: 0.420484    0.894091    3.424888    0.341119    0.096200    0.019939    0.600101    
#> 159: 0.399252    0.897343    3.421328    0.387888    0.080008    0.019874    0.619053    
#> 160: 0.413877    0.872598    3.422211    0.401992    0.079774    0.020102    0.602727    
#> 161: 0.415424    0.880697    3.415767    0.382489    0.093840    0.020418    0.601348    
#> 162: 0.368264    0.895606    3.406942    0.355771    0.093730    0.020692    0.627962    
#> 163: 0.424786    0.907584    3.407490    0.328772    0.082010    0.021569    0.645237    
#> 164: 0.412760    0.903565    3.416104    0.353854    0.087661    0.021532    0.609987    
#> 165: 0.426437    0.874708    3.427268    0.344096    0.094797    0.018317    0.614602    
#> 166: 0.455997    0.901610    3.429600    0.315041    0.097190    0.017176    0.624317    
#> 167: 0.449959    0.910633    3.432776    0.310381    0.073907    0.018263    0.642997    
#> 168: 0.426276    0.900754    3.433693    0.272415    0.077481    0.018026    0.619505    
#> 169: 0.431914    0.918810    3.426946    0.246665    0.090299    0.018174    0.631746    
#> 170: 0.417291    0.905477    3.425575    0.290575    0.083887    0.016063    0.600689    
#> 171: 0.381888    0.893461    3.418136    0.265242    0.095873    0.013286    0.599321    
#> 172: 0.375061    0.901713    3.410502    0.247508    0.080673    0.013226    0.601352    
#> 173: 0.386841    0.915346    3.409475    0.301231    0.080666    0.020181    0.589692    
#> 174: 0.398467    0.894579    3.422469    0.302177    0.083374    0.020079    0.610867    
#> 175: 0.407613    0.915003    3.419925    0.309004    0.083657    0.024023    0.607984    
#> 176: 0.417867    0.919729    3.425841    0.334534    0.082078    0.023028    0.597855    
#> 177: 0.443991    0.892980    3.433999    0.312558    0.081873    0.020098    0.599946    
#> 178: 0.457965    0.869419    3.443945    0.308252    0.074116    0.018318    0.599155    
#> 179: 0.477905    0.889012    3.444245    0.297553    0.088160    0.015289    0.612691    
#> 180: 0.447467    0.889815    3.445702    0.290970    0.095747    0.016541    0.605933    
#> 181: 0.427225    0.906639    3.424248    0.298958    0.105109    0.014864    0.598374    
#> 182: 0.392379    0.898963    3.410277    0.283791    0.101472    0.013357    0.611844    
#> 183: 0.385903    0.924714    3.405491    0.311904    0.087235    0.014139    0.626830    
#> 184: 0.365683    0.910573    3.402669    0.296661    0.083117    0.015626    0.623440    
#> 185: 0.363187    0.921571    3.398197    0.286471    0.082200    0.017274    0.618951    
#> 186: 0.373946    0.923255    3.407652    0.283839    0.090879    0.014669    0.615885    
#> 187: 0.373142    0.910698    3.410056    0.297959    0.080703    0.017753    0.613836    
#> 188: 0.337675    0.917949    3.407745    0.279053    0.077360    0.019484    0.603565    
#> 189: 0.376019    0.924664    3.414802    0.342725    0.093404    0.017954    0.610282    
#> 190: 0.395635    0.913291    3.417719    0.309780    0.081304    0.017639    0.589153    
#> 191: 0.395535    0.906984    3.421832    0.330768    0.074348    0.017282    0.584167    
#> 192: 0.378885    0.912334    3.413971    0.301999    0.075572    0.016427    0.593268    
#> 193: 0.411632    0.922228    3.423404    0.311289    0.089841    0.016949    0.595384    
#> 194: 0.375339    0.896580    3.414995    0.309719    0.087465    0.014398    0.605265    
#> 195: 0.368753    0.905156    3.402904    0.306921    0.089858    0.013937    0.602401    
#> 196: 0.365154    0.911134    3.405338    0.323603    0.094279    0.016818    0.607970    
#> 197: 0.383242    0.904900    3.422545    0.312392    0.083743    0.017416    0.618014    
#> 198: 0.429373    0.895934    3.426790    0.319675    0.078680    0.019328    0.591431    
#> 199: 0.397087    0.891003    3.418536    0.366236    0.083330    0.019949    0.596947    
#> 200: 0.391495    0.880765    3.430002    0.311646    0.088694    0.019207    0.615222    
#> 201: 0.392396    0.878660    3.431245    0.290483    0.086142    0.019995    0.615855    
#> 202: 0.397722    0.883292    3.429504    0.302637    0.082306    0.020550    0.613904    
#> 203: 0.406635    0.883400    3.427157    0.305415    0.082364    0.020237    0.615508    
#> 204: 0.409570    0.881278    3.428445    0.316415    0.082977    0.020391    0.613727    
#> 205: 0.409633    0.888094    3.428478    0.320738    0.085538    0.020432    0.615078    
#> 206: 0.408416    0.892433    3.427237    0.326900    0.086752    0.020464    0.615819    
#> 207: 0.407528    0.892976    3.425086    0.327735    0.085103    0.020392    0.615729    
#> 208: 0.407530    0.893897    3.424497    0.326254    0.084220    0.020414    0.614015    
#> 209: 0.408900    0.892186    3.424113    0.326425    0.084230    0.020249    0.611904    
#> 210: 0.411256    0.890295    3.424955    0.325772    0.084182    0.020219    0.610884    
#> 211: 0.413743    0.890141    3.425310    0.321662    0.083428    0.019980    0.610086    
#> 212: 0.414879    0.890388    3.425646    0.318819    0.082262    0.019878    0.610281    
#> 213: 0.417012    0.888952    3.426126    0.318785    0.081043    0.020031    0.611459    
#> 214: 0.418040    0.888443    3.426988    0.320977    0.080811    0.020188    0.611298    
#> 215: 0.416869    0.887846    3.427170    0.321017    0.080833    0.020289    0.611755    
#> 216: 0.417680    0.886870    3.427337    0.323181    0.081246    0.020277    0.613076    
#> 217: 0.419682    0.886949    3.427657    0.323490    0.081119    0.020252    0.613265    
#> 218: 0.420180    0.887628    3.426976    0.324276    0.080953    0.020214    0.612939    
#> 219: 0.417832    0.887243    3.425915    0.323681    0.081393    0.020093    0.612856    
#> 220: 0.415160    0.887316    3.425346    0.322575    0.081752    0.020037    0.613462    
#> 221: 0.413377    0.887412    3.424852    0.322098    0.082184    0.019930    0.613123    
#> 222: 0.412613    0.887331    3.424260    0.322258    0.082863    0.019778    0.613146    
#> 223: 0.413319    0.887694    3.424186    0.323265    0.083455    0.019736    0.613026    
#> 224: 0.414425    0.888682    3.424324    0.322054    0.084134    0.019651    0.613414    
#> 225: 0.412763    0.887862    3.424463    0.319723    0.084409    0.019598    0.613913    
#> 226: 0.413148    0.887327    3.424482    0.319006    0.084534    0.019469    0.614206    
#> 227: 0.412360    0.887294    3.424385    0.315919    0.084703    0.019322    0.614728    
#> 228: 0.411387    0.887719    3.423968    0.313394    0.084831    0.019192    0.614801    
#> 229: 0.410596    0.887766    3.423888    0.312213    0.084731    0.019071    0.614748    
#> 230: 0.411456    0.887324    3.424059    0.312106    0.085004    0.018890    0.614997    
#> 231: 0.412198    0.888019    3.424314    0.311332    0.085598    0.018799    0.614824    
#> 232: 0.412291    0.888229    3.424726    0.309982    0.086107    0.018585    0.614773    
#> 233: 0.412436    0.887347    3.424846    0.309996    0.086374    0.018483    0.615014    
#> 234: 0.411713    0.887255    3.424599    0.309172    0.086501    0.018432    0.615062    
#> 235: 0.410911    0.886982    3.424472    0.307361    0.086267    0.018284    0.615564    
#> 236: 0.410462    0.887302    3.424316    0.306079    0.086360    0.018089    0.616064    
#> 237: 0.410538    0.887652    3.424239    0.305958    0.086747    0.018003    0.616344    
#> 238: 0.410855    0.888107    3.424113    0.305721    0.086822    0.017974    0.616789    
#> 239: 0.410705    0.888676    3.423780    0.305392    0.086595    0.017993    0.617117    
#> 240: 0.411414    0.888468    3.424120    0.305707    0.086534    0.018030    0.617348    
#> 241: 0.411760    0.887263    3.424569    0.306032    0.086413    0.018010    0.617552    
#> 242: 0.411858    0.886644    3.424507    0.306622    0.085963    0.018012    0.618213    
#> 243: 0.411530    0.886932    3.424504    0.306051    0.085508    0.018093    0.619017    
#> 244: 0.411364    0.887252    3.424646    0.306804    0.085530    0.018134    0.618997    
#> 245: 0.411227    0.887039    3.424652    0.307271    0.085475    0.018163    0.619093    
#> 246: 0.411057    0.886887    3.424470    0.307416    0.085599    0.018170    0.619056    
#> 247: 0.410924    0.886924    3.424591    0.307209    0.085559    0.018223    0.619324    
#> 248: 0.410549    0.887371    3.424682    0.307018    0.085636    0.018243    0.619269    
#> 249: 0.409754    0.887667    3.424793    0.306615    0.085543    0.018271    0.619246    
#> 250: 0.410249    0.888001    3.424926    0.306501    0.085308    0.018333    0.619636    
#> 251: 0.410760    0.888457    3.425125    0.306949    0.085209    0.018301    0.619836    
#> 252: 0.411375    0.888924    3.425502    0.306253    0.085585    0.018241    0.620018    
#> 253: 0.411944    0.889305    3.425604    0.306110    0.085822    0.018157    0.619873    
#> 254: 0.411974    0.889907    3.425472    0.306011    0.085991    0.018114    0.619985    
#> 255: 0.411835    0.890276    3.425481    0.305941    0.086099    0.018136    0.619903    
#> 256: 0.411947    0.890413    3.425450    0.305412    0.086181    0.018119    0.620015    
#> 257: 0.411834    0.890205    3.425458    0.304796    0.086221    0.018060    0.620338    
#> 258: 0.411685    0.890230    3.425388    0.304759    0.086134    0.017998    0.620610    
#> 259: 0.411889    0.890167    3.425387    0.304886    0.086463    0.018002    0.620524    
#> 260: 0.412220    0.890135    3.425591    0.304881    0.086731    0.017963    0.620494    
#> 261: 0.412631    0.889839    3.425875    0.305061    0.087058    0.017973    0.620327    
#> 262: 0.412741    0.889830    3.426007    0.304994    0.087441    0.017992    0.620197    
#> 263: 0.412543    0.889919    3.426089    0.304838    0.087599    0.018023    0.620029    
#> 264: 0.412073    0.890230    3.425789    0.304866    0.087723    0.018021    0.620108    
#> 265: 0.411888    0.890427    3.425634    0.305420    0.087858    0.018025    0.619976    
#> 266: 0.411997    0.890593    3.425631    0.305492    0.087839    0.018002    0.619949    
#> 267: 0.411925    0.890359    3.425681    0.305693    0.087900    0.017963    0.619749    
#> 268: 0.411934    0.890215    3.425594    0.306624    0.087802    0.017969    0.619750    
#> 269: 0.412299    0.890315    3.425519    0.307142    0.087848    0.018011    0.619596    
#> 270: 0.412509    0.890730    3.425388    0.307448    0.087853    0.018005    0.619433    
#> 271: 0.412273    0.891116    3.425197    0.307640    0.087882    0.018017    0.619884    
#> 272: 0.412127    0.891216    3.425058    0.307735    0.087922    0.018062    0.620074    
#> 273: 0.411640    0.891545    3.425091    0.308160    0.087956    0.018111    0.620409    
#> 274: 0.411814    0.891568    3.425142    0.308032    0.088006    0.018106    0.620456    
#> 275: 0.411721    0.891676    3.424961    0.307551    0.088066    0.018108    0.620411    
#> 276: 0.411947    0.891860    3.425103    0.307799    0.087989    0.018120    0.620268    
#> 277: 0.411782    0.892156    3.425127    0.307720    0.088002    0.018115    0.620203    
#> 278: 0.411908    0.892028    3.425174    0.307296    0.088150    0.018085    0.620185    
#> 279: 0.411853    0.891863    3.425215    0.307198    0.088398    0.018060    0.620276    
#> 280: 0.411704    0.892125    3.425162    0.307534    0.088395    0.018022    0.620149    
#> 281: 0.411324    0.892301    3.425091    0.307574    0.088324    0.018005    0.620027    
#> 282: 0.411109    0.892562    3.425083    0.307135    0.088284    0.017952    0.619992    
#> 283: 0.410853    0.892677    3.425127    0.307120    0.088097    0.017919    0.620351    
#> 284: 0.410923    0.892559    3.425155    0.307444    0.087981    0.017890    0.620547    
#> 285: 0.410617    0.892864    3.425016    0.307253    0.087998    0.017827    0.620587    
#> 286: 0.410335    0.892883    3.424862    0.307276    0.087930    0.017785    0.620410    
#> 287: 0.409952    0.892961    3.424717    0.307175    0.087894    0.017758    0.620250    
#> 288: 0.409924    0.892976    3.424655    0.307396    0.087884    0.017721    0.620400    
#> 289: 0.409902    0.892848    3.424641    0.306984    0.087789    0.017678    0.620411    
#> 290: 0.410178    0.892833    3.424704    0.306805    0.087765    0.017658    0.620439    
#> 291: 0.410342    0.893055    3.424784    0.307142    0.087851    0.017658    0.620179    
#> 292: 0.410343    0.893066    3.424746    0.307291    0.087807    0.017634    0.620152    
#> 293: 0.410203    0.892915    3.424712    0.307350    0.087816    0.017602    0.619986    
#> 294: 0.409999    0.892880    3.424579    0.307276    0.087789    0.017578    0.619852    
#> 295: 0.410044    0.892713    3.424515    0.306953    0.087768    0.017540    0.619704    
#> 296: 0.409863    0.892642    3.424472    0.306585    0.087710    0.017538    0.619641    
#> 297: 0.409922    0.892613    3.424549    0.306749    0.087692    0.017557    0.619582    
#> 298: 0.409948    0.892515    3.424514    0.307083    0.087595    0.017535    0.619536    
#> 299: 0.409980    0.892496    3.424499    0.307319    0.087482    0.017528    0.619490    
#> 300: 0.410156    0.892391    3.424531    0.307308    0.087537    0.017544    0.619409    
#> 301: 0.410565    0.892178    3.424527    0.307613    0.087680    0.017538    0.619282    
#> 302: 0.410525    0.892090    3.424441    0.307661    0.087795    0.017531    0.619166    
#> 303: 0.410367    0.892196    3.424370    0.307274    0.087802    0.017531    0.618907    
#> 304: 0.410434    0.892374    3.424280    0.307616    0.087740    0.017532    0.618849    
#> 305: 0.410237    0.892123    3.424228    0.307743    0.087666    0.017545    0.618768    
#> 306: 0.410046    0.892108    3.424139    0.307947    0.087585    0.017567    0.618635    
#> 307: 0.409862    0.892198    3.423999    0.307973    0.087698    0.017568    0.618651    
#> 308: 0.409417    0.892237    3.423877    0.308479    0.087780    0.017552    0.618654    
#> 309: 0.409589    0.892036    3.423870    0.308844    0.087620    0.017558    0.618806    
#> 310: 0.409792    0.891803    3.423839    0.308715    0.087649    0.017552    0.619065    
#> 311: 0.409747    0.891841    3.423778    0.308805    0.087697    0.017547    0.619098    
#> 312: 0.409514    0.891822    3.423644    0.308943    0.087609    0.017533    0.619073    
#> 313: 0.409269    0.891699    3.423484    0.308879    0.087605    0.017532    0.619174    
#> 314: 0.408899    0.891886    3.423316    0.308779    0.087709    0.017558    0.619145    
#> 315: 0.408545    0.892081    3.423209    0.308931    0.087743    0.017548    0.619071    
#> 316: 0.408592    0.892246    3.423107    0.308844    0.087735    0.017542    0.619081    
#> 317: 0.408993    0.892279    3.423240    0.309322    0.087628    0.017585    0.619175    
#> 318: 0.409231    0.892335    3.423202    0.309229    0.087540    0.017571    0.619241    
#> 319: 0.409337    0.892290    3.423254    0.309170    0.087580    0.017578    0.619293    
#> 320: 0.408991    0.892210    3.423146    0.309056    0.087551    0.017560    0.619460    
#> 321: 0.408712    0.892387    3.423035    0.308704    0.087580    0.017525    0.619586    
#> 322: 0.408654    0.892563    3.422854    0.308679    0.087578    0.017518    0.619605    
#> 323: 0.408160    0.892659    3.422701    0.308530    0.087583    0.017472    0.619562    
#> 324: 0.407915    0.892665    3.422652    0.308782    0.087702    0.017445    0.619390    
#> 325: 0.407733    0.892734    3.422590    0.308674    0.087802    0.017429    0.619241    
#> 326: 0.407444    0.892573    3.422521    0.308421    0.087840    0.017410    0.619079    
#> 327: 0.407538    0.892548    3.422479    0.308319    0.087994    0.017390    0.618993    
#> 328: 0.407661    0.892630    3.422434    0.308357    0.088070    0.017373    0.618904    
#> 329: 0.407762    0.892747    3.422430    0.308442    0.088033    0.017354    0.618698    
#> 330: 0.407449    0.892870    3.422418    0.308695    0.087987    0.017354    0.618642    
#> 331: 0.407355    0.893014    3.422343    0.308828    0.087967    0.017355    0.618495    
#> 332: 0.407362    0.893052    3.422358    0.308902    0.087848    0.017318    0.618505    
#> 333: 0.406997    0.893153    3.422209    0.308852    0.087913    0.017290    0.618535    
#> 334: 0.406826    0.893301    3.422007    0.308937    0.087934    0.017272    0.618616    
#> 335: 0.406773    0.893448    3.421850    0.309107    0.087996    0.017262    0.618560    
#> 336: 0.406462    0.893733    3.421694    0.309379    0.088090    0.017240    0.618570    
#> 337: 0.406128    0.894193    3.421468    0.309296    0.088112    0.017221    0.618660    
#> 338: 0.405967    0.894511    3.421368    0.309385    0.088184    0.017183    0.618778    
#> 339: 0.405674    0.894712    3.421232    0.309471    0.088207    0.017165    0.618760    
#> 340: 0.405454    0.894564    3.421156    0.309353    0.088264    0.017144    0.618756    
#> 341: 0.405530    0.894579    3.421154    0.309302    0.088332    0.017136    0.618771    
#> 342: 0.405317    0.894485    3.421119    0.309207    0.088407    0.017110    0.618803    
#> 343: 0.404871    0.894540    3.421020    0.309182    0.088443    0.017107    0.618715    
#> 344: 0.404682    0.894620    3.420945    0.309326    0.088499    0.017103    0.618630    
#> 345: 0.404698    0.894569    3.420993    0.309335    0.088490    0.017092    0.618611    
#> 346: 0.404674    0.894658    3.420838    0.309425    0.088502    0.017089    0.618520    
#> 347: 0.404614    0.894585    3.420784    0.309545    0.088497    0.017093    0.618543    
#> 348: 0.404558    0.894602    3.420748    0.309603    0.088527    0.017093    0.618479    
#> 349: 0.404557    0.894463    3.420812    0.309639    0.088583    0.017097    0.618458    
#> 350: 0.404610    0.894310    3.420824    0.309540    0.088593    0.017079    0.618432    
#> 351: 0.404620    0.894415    3.420791    0.309152    0.088606    0.017060    0.618515    
#> 352: 0.404310    0.894630    3.420785    0.308783    0.088635    0.017047    0.618772    
#> 353: 0.404467    0.894791    3.420791    0.308817    0.088593    0.017038    0.618748    
#> 354: 0.404303    0.894794    3.420702    0.308677    0.088569    0.017033    0.618713    
#> 355: 0.404497    0.894739    3.420671    0.308600    0.088666    0.017032    0.618818    
#> 356: 0.404408    0.894810    3.420653    0.308435    0.088691    0.017022    0.618981    
#> 357: 0.404400    0.894956    3.420602    0.308442    0.088698    0.016999    0.618993    
#> 358: 0.404248    0.894948    3.420575    0.308313    0.088754    0.016987    0.618834    
#> 359: 0.403984    0.895092    3.420501    0.308310    0.088815    0.016986    0.618687    
#> 360: 0.403948    0.895213    3.420371    0.308350    0.088805    0.016983    0.618592    
#> 361: 0.403973    0.895199    3.420308    0.308378    0.088869    0.016983    0.618408    
#> 362: 0.403957    0.895222    3.420281    0.308301    0.088841    0.016982    0.618251    
#> 363: 0.403831    0.895126    3.420232    0.308227    0.088810    0.016961    0.618115    
#> 364: 0.403772    0.895115    3.420186    0.308179    0.088803    0.016959    0.618131    
#> 365: 0.403713    0.895002    3.420205    0.308027    0.088684    0.016952    0.618168    
#> 366: 0.403540    0.895079    3.420104    0.307892    0.088660    0.016940    0.618234    
#> 367: 0.403478    0.895169    3.420047    0.307704    0.088682    0.016919    0.618254    
#> 368: 0.403560    0.895315    3.420055    0.307286    0.088675    0.016899    0.618362    
#> 369: 0.403638    0.895319    3.420015    0.306870    0.088707    0.016875    0.618407    
#> 370: 0.403612    0.895421    3.419979    0.306443    0.088699    0.016853    0.618427    
#> 371: 0.403475    0.895539    3.419866    0.306189    0.088742    0.016829    0.618381    
#> 372: 0.403390    0.895565    3.419824    0.306031    0.088734    0.016803    0.618375    
#> 373: 0.403229    0.895626    3.419751    0.305888    0.088764    0.016781    0.618316    
#> 374: 0.403182    0.895705    3.419743    0.305677    0.088802    0.016761    0.618195    
#> 375: 0.403164    0.895700    3.419750    0.305629    0.088853    0.016753    0.618131    
#> 376: 0.403273    0.895760    3.419794    0.305460    0.088841    0.016736    0.618032    
#> 377: 0.403183    0.895846    3.419765    0.305270    0.088870    0.016712    0.618014    
#> 378: 0.403027    0.895972    3.419668    0.305374    0.088828    0.016706    0.618006    
#> 379: 0.402864    0.895972    3.419584    0.305325    0.088815    0.016691    0.617959    
#> 380: 0.402673    0.895914    3.419562    0.305272    0.088747    0.016692    0.617970    
#> 381: 0.402516    0.895879    3.419563    0.304912    0.088686    0.016682    0.618011    
#> 382: 0.402467    0.895943    3.419567    0.304988    0.088672    0.016674    0.617825    
#> 383: 0.402524    0.895913    3.419600    0.305183    0.088599    0.016705    0.617697    
#> 384: 0.402590    0.895954    3.419641    0.305261    0.088610    0.016741    0.617604    
#> 385: 0.402754    0.895994    3.419679    0.305204    0.088543    0.016763    0.617570    
#> 386: 0.402951    0.896111    3.419741    0.305226    0.088467    0.016779    0.617618    
#> 387: 0.403096    0.896169    3.419791    0.305106    0.088418    0.016790    0.617566    
#> 388: 0.403139    0.896224    3.419839    0.304917    0.088412    0.016791    0.617538    
#> 389: 0.403045    0.896085    3.419832    0.304669    0.088396    0.016791    0.617564    
#> 390: 0.402913    0.896149    3.419772    0.304506    0.088351    0.016783    0.617539    
#> 391: 0.403036    0.896133    3.419734    0.304455    0.088347    0.016784    0.617479    
#> 392: 0.403177    0.896115    3.419757    0.304598    0.088258    0.016785    0.617435    
#> 393: 0.403258    0.896103    3.419759    0.304797    0.088250    0.016778    0.617392    
#> 394: 0.403275    0.896155    3.419707    0.304826    0.088202    0.016794    0.617466    
#> 395: 0.403516    0.896224    3.419697    0.305010    0.088095    0.016808    0.617478    
#> 396: 0.403659    0.896252    3.419715    0.305205    0.087986    0.016826    0.617451    
#> 397: 0.403678    0.896113    3.419771    0.305035    0.087952    0.016832    0.617468    
#> 398: 0.403723    0.896046    3.419824    0.304740    0.087920    0.016834    0.617534    
#> 399: 0.403828    0.896023    3.419849    0.304644    0.087857    0.016829    0.617477    
#> 400: 0.403892    0.896000    3.419890    0.304406    0.087815    0.016825    0.617423    
#> 401: 0.404013    0.896012    3.419933    0.304361    0.087695    0.016834    0.617444    
#> 402: 0.404102    0.896122    3.419971    0.304365    0.087556    0.016840    0.617568    
#> 403: 0.404327    0.896110    3.420007    0.304393    0.087541    0.016831    0.617610    
#> 404: 0.404432    0.896138    3.420016    0.304468    0.087518    0.016832    0.617583    
#> 405: 0.404482    0.896198    3.420035    0.304503    0.087482    0.016830    0.617603    
#> 406: 0.404617    0.896252    3.420023    0.304344    0.087492    0.016831    0.617690    
#> 407: 0.404615    0.896270    3.420071    0.304291    0.087477    0.016846    0.617741    
#> 408: 0.404644    0.896274    3.420112    0.304138    0.087508    0.016841    0.617749    
#> 409: 0.404583    0.896242    3.420095    0.304036    0.087545    0.016838    0.617702    
#> 410: 0.404477    0.896228    3.420050    0.304074    0.087548    0.016849    0.617721    
#> 411: 0.404454    0.896138    3.420004    0.304222    0.087551    0.016857    0.617786    
#> 412: 0.404416    0.896181    3.419953    0.304414    0.087543    0.016877    0.617744    
#> 413: 0.404495    0.896236    3.419919    0.304547    0.087525    0.016894    0.617706    
#> 414: 0.404408    0.896245    3.419927    0.304631    0.087476    0.016900    0.617649    
#> 415: 0.404483    0.896287    3.419906    0.304685    0.087416    0.016925    0.617574    
#> 416: 0.404593    0.896345    3.419908    0.304689    0.087389    0.016940    0.617477    
#> 417: 0.404648    0.896369    3.419887    0.304676    0.087371    0.016954    0.617445    
#> 418: 0.404555    0.896386    3.419897    0.304652    0.087399    0.016971    0.617375    
#> 419: 0.404617    0.896400    3.419888    0.304748    0.087403    0.016973    0.617298    
#> 420: 0.404598    0.896369    3.419898    0.304826    0.087388    0.016979    0.617160    
#> 421: 0.404615    0.896355    3.419979    0.304654    0.087420    0.016990    0.617136    
#> 422: 0.404901    0.896263    3.420033    0.304570    0.087419    0.017006    0.617154    
#> 423: 0.405054    0.896166    3.420050    0.304679    0.087445    0.017007    0.617175    
#> 424: 0.405016    0.896125    3.420013    0.304866    0.087441    0.017016    0.617153    
#> 425: 0.404993    0.896197    3.419961    0.304879    0.087391    0.017033    0.617160    
#> 426: 0.405068    0.896297    3.419921    0.304920    0.087430    0.017023    0.617127    
#> 427: 0.404929    0.896305    3.419931    0.304894    0.087424    0.017019    0.617105    
#> 428: 0.404832    0.896361    3.419927    0.304846    0.087383    0.017021    0.617060    
#> 429: 0.404751    0.896393    3.419936    0.304773    0.087332    0.017031    0.617029    
#> 430: 0.404727    0.896450    3.419918    0.304894    0.087288    0.017047    0.616948    
#> 431: 0.404667    0.896434    3.419856    0.305010    0.087197    0.017038    0.616854    
#> 432: 0.404437    0.896496    3.419799    0.305084    0.087139    0.017045    0.616737    
#> 433: 0.404375    0.896598    3.419794    0.305063    0.087109    0.017054    0.616710    
#> 434: 0.404184    0.896554    3.419767    0.304948    0.087083    0.017049    0.616646    
#> 435: 0.404280    0.896530    3.419752    0.305041    0.087066    0.017059    0.616540    
#> 436: 0.404350    0.896420    3.419805    0.305144    0.087037    0.017066    0.616515    
#> 437: 0.404325    0.896382    3.419783    0.305100    0.087029    0.017054    0.616499    
#> 438: 0.404247    0.896478    3.419736    0.305111    0.087057    0.017036    0.616433    
#> 439: 0.404275    0.896525    3.419740    0.305228    0.087021    0.017039    0.616373    
#> 440: 0.404278    0.896571    3.419771    0.305321    0.087001    0.017046    0.616374    
#> 441: 0.404288    0.896547    3.419770    0.305420    0.087019    0.017061    0.616262    
#> 442: 0.404157    0.896590    3.419759    0.305598    0.087067    0.017073    0.616146    
#> 443: 0.403975    0.896735    3.419645    0.305772    0.087101    0.017079    0.616050    
#> 444: 0.403769    0.896851    3.419514    0.305965    0.087053    0.017083    0.616024    
#> 445: 0.403548    0.896940    3.419436    0.306236    0.087101    0.017083    0.616073    
#> 446: 0.403425    0.896983    3.419399    0.306270    0.087076    0.017090    0.616055    
#> 447: 0.403515    0.897025    3.419372    0.306426    0.087082    0.017089    0.616038    
#> 448: 0.403464    0.897028    3.419379    0.306318    0.087040    0.017103    0.615986    
#> 449: 0.403618    0.897059    3.419464    0.306376    0.087020    0.017120    0.615940    
#> 450: 0.403670    0.897022    3.419503    0.306434    0.086916    0.017123    0.615929    
#> 451: 0.403739    0.896971    3.419523    0.306478    0.086836    0.017127    0.615917    
#> 452: 0.403737    0.896994    3.419499    0.306424    0.086803    0.017131    0.615863    
#> 453: 0.403724    0.896999    3.419467    0.306651    0.086747    0.017134    0.615744    
#> 454: 0.403633    0.897120    3.419389    0.306955    0.086693    0.017142    0.615649    
#> 455: 0.403509    0.897156    3.419357    0.307016    0.086667    0.017146    0.615624    
#> 456: 0.403406    0.897121    3.419326    0.307057    0.086604    0.017149    0.615640    
#> 457: 0.403263    0.897140    3.419309    0.307047    0.086539    0.017146    0.615576    
#> 458: 0.403107    0.897281    3.419277    0.306993    0.086538    0.017142    0.615528    
#> 459: 0.402983    0.897435    3.419242    0.306891    0.086556    0.017132    0.615556    
#> 460: 0.402831    0.897465    3.419190    0.307003    0.086514    0.017134    0.615508    
#> 461: 0.402746    0.897529    3.419164    0.306909    0.086501    0.017125    0.615461    
#> 462: 0.402634    0.897583    3.419159    0.306826    0.086525    0.017109    0.615428    
#> 463: 0.402624    0.897630    3.419179    0.306881    0.086530    0.017101    0.615427    
#> 464: 0.402672    0.897707    3.419138    0.306995    0.086550    0.017097    0.615398    
#> 465: 0.402742    0.897582    3.419154    0.307108    0.086559    0.017099    0.615366    
#> 466: 0.402714    0.897571    3.419141    0.306989    0.086525    0.017095    0.615376    
#> 467: 0.402700    0.897549    3.419156    0.307079    0.086500    0.017091    0.615266    
#> 468: 0.402808    0.897534    3.419188    0.307196    0.086486    0.017095    0.615141    
#> 469: 0.402815    0.897576    3.419216    0.307105    0.086467    0.017105    0.615112    
#> 470: 0.402721    0.897618    3.419182    0.307045    0.086477    0.017113    0.615094    
#> 471: 0.402668    0.897607    3.419178    0.306912    0.086475    0.017115    0.615091    
#> 472: 0.402629    0.897585    3.419193    0.306926    0.086486    0.017118    0.615070    
#> 473: 0.402513    0.897655    3.419149    0.306930    0.086453    0.017117    0.615021    
#> 474: 0.402389    0.897734    3.419069    0.306809    0.086461    0.017121    0.615030    
#> 475: 0.402364    0.897842    3.419030    0.306765    0.086442    0.017118    0.615065    
#> 476: 0.402248    0.897875    3.418983    0.306957    0.086451    0.017116    0.615068    
#> 477: 0.402122    0.897875    3.418983    0.307053    0.086509    0.017119    0.614981    
#> 478: 0.402068    0.897918    3.418962    0.307145    0.086522    0.017118    0.614971    
#> 479: 0.402100    0.897981    3.418949    0.307311    0.086532    0.017119    0.614900    
#> 480: 0.402096    0.897954    3.418979    0.307312    0.086506    0.017126    0.614887    
#> 481: 0.402167    0.897989    3.418999    0.307421    0.086473    0.017132    0.614862    
#> 482: 0.402251    0.898026    3.418990    0.307657    0.086401    0.017151    0.614833    
#> 483: 0.402239    0.898015    3.418973    0.307862    0.086346    0.017168    0.614755    
#> 484: 0.402264    0.897910    3.418991    0.308023    0.086328    0.017168    0.614712    
#> 485: 0.402310    0.897915    3.419008    0.308066    0.086327    0.017168    0.614732    
#> 486: 0.402328    0.897913    3.419014    0.308021    0.086330    0.017157    0.614712    
#> 487: 0.402482    0.897874    3.419056    0.308011    0.086375    0.017154    0.614695    
#> 488: 0.402605    0.897840    3.419102    0.308025    0.086351    0.017150    0.614683    
#> 489: 0.402779    0.897843    3.419128    0.308073    0.086322    0.017150    0.614692    
#> 490: 0.402854    0.897835    3.419179    0.308004    0.086291    0.017162    0.614672    
#> 491: 0.402856    0.897920    3.419211    0.307889    0.086274    0.017163    0.614694    
#> 492: 0.402949    0.898012    3.419221    0.307877    0.086257    0.017179    0.614772    
#> 493: 0.403024    0.897995    3.419243    0.308016    0.086202    0.017209    0.614730    
#> 494: 0.403153    0.897973    3.419252    0.307979    0.086145    0.017218    0.614738    
#> 495: 0.403208    0.898000    3.419259    0.307976    0.086070    0.017223    0.614762    
#> 496: 0.403208    0.898137    3.419239    0.307813    0.086054    0.017222    0.614820    
#> 497: 0.403036    0.898198    3.419221    0.307645    0.086034    0.017215    0.614880    
#> 498: 0.403018    0.898229    3.419193    0.307511    0.086017    0.017218    0.614851    
#> 499: 0.403063    0.898357    3.419171    0.307450    0.086003    0.017222    0.614799    
#> 500: 0.403145    0.898361    3.419188    0.307361    0.085973    0.017215    0.614795    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.298546    0.973696    3.445037    0.392401    0.090277    0.016800    1.863576    
#> 002: 0.383341    1.056657    3.464534    0.372781    0.085763    0.018006    1.168121    
#> 003: 0.521327    1.046431    3.479230    0.354142    0.086364    0.017624    0.965203    
#> 004: 0.524104    1.088074    3.481402    0.447828    0.088090    0.020252    0.839734    
#> 005: 0.595764    1.081117    3.469356    0.488140    0.083685    0.019239    0.819096    
#> 006: 0.551938    1.068037    3.470153    0.515508    0.079501    0.020867    0.766910    
#> 007: 0.498261    1.081104    3.463444    0.512599    0.075526    0.024779    0.759986    
#> 008: 0.510414    1.095427    3.448374    0.486969    0.071749    0.031602    0.740600    
#> 009: 0.491038    1.075921    3.445926    0.567858    0.078978    0.030022    0.728636    
#> 010: 0.487381    1.076100    3.441866    0.605219    0.075029    0.028521    0.759114    
#> 011: 0.558180    1.079385    3.459020    0.651592    0.081483    0.027173    0.746523    
#> 012: 0.514589    1.095520    3.441125    0.669361    0.077409    0.025814    0.733379    
#> 013: 0.477370    1.100527    3.427525    0.635893    0.073538    0.024523    0.741552    
#> 014: 0.543615    1.092441    3.452271    0.627695    0.076787    0.024198    0.742770    
#> 015: 0.570855    1.091678    3.468491    0.655027    0.072947    0.030369    0.722828    
#> 016: 0.571424    1.088964    3.472737    0.656837    0.069300    0.035765    0.739821    
#> 017: 0.543295    1.088321    3.471440    0.623995    0.065835    0.033976    0.714344    
#> 018: 0.576702    1.093622    3.455183    0.700115    0.065210    0.034086    0.713941    
#> 019: 0.474624    1.095246    3.449903    0.665110    0.061949    0.032381    0.727876    
#> 020: 0.532997    1.104599    3.458383    0.647505    0.061707    0.032227    0.747656    
#> 021: 0.524779    1.074575    3.466700    0.615129    0.058621    0.034640    0.719778    
#> 022: 0.573360    1.095360    3.481691    0.584373    0.055690    0.037822    0.702592    
#> 023: 0.639912    1.090192    3.485142    0.627488    0.052906    0.040218    0.722946    
#> 024: 0.585959    1.111657    3.476535    0.610332    0.050261    0.038207    0.707805    
#> 025: 0.609517    1.088824    3.473268    0.580302    0.047747    0.038449    0.702178    
#> 026: 0.572688    1.104046    3.473242    0.551287    0.045360    0.044818    0.713435    
#> 027: 0.533311    1.112822    3.450902    0.601598    0.043092    0.049573    0.739435    
#> 028: 0.545899    1.110898    3.440477    0.709505    0.040938    0.047466    0.717526    
#> 029: 0.585665    1.095226    3.452066    0.737816    0.038891    0.050079    0.723176    
#> 030: 0.597016    1.128225    3.446745    0.774209    0.038859    0.053459    0.713670    
#> 031: 0.534710    1.104702    3.457793    0.735498    0.050310    0.050786    0.722775    
#> 032: 0.521522    1.104522    3.453428    0.698723    0.047794    0.048473    0.711013    
#> 033: 0.500342    1.096897    3.447125    0.663787    0.045405    0.047810    0.722307    
#> 034: 0.517362    1.105537    3.459479    0.630598    0.043134    0.050076    0.714108    
#> 035: 0.519973    1.083776    3.452831    0.599068    0.041014    0.047878    0.714543    
#> 036: 0.534355    1.092111    3.463417    0.569115    0.038963    0.051709    0.706221    
#> 037: 0.557262    1.093820    3.454729    0.568141    0.037015    0.050103    0.734481    
#> 038: 0.581248    1.096978    3.461457    0.630769    0.035164    0.047598    0.728975    
#> 039: 0.586031    1.100147    3.477044    0.668040    0.039380    0.053821    0.721821    
#> 040: 0.534657    1.096807    3.468138    0.651181    0.037411    0.051130    0.733404    
#> 041: 0.493664    1.076630    3.458082    0.618622    0.035541    0.052984    0.726073    
#> 042: 0.542321    1.079202    3.456826    0.587691    0.033764    0.050335    0.712098    
#> 043: 0.541761    1.094986    3.450602    0.608139    0.032854    0.048659    0.718937    
#> 044: 0.473376    1.105754    3.446514    0.577732    0.032764    0.049745    0.721346    
#> 045: 0.500293    1.113820    3.440405    0.567055    0.031126    0.047267    0.731809    
#> 046: 0.502875    1.099346    3.445736    0.557612    0.035039    0.052229    0.741069    
#> 047: 0.511440    1.097339    3.461458    0.529731    0.033287    0.049818    0.718555    
#> 048: 0.526493    1.085847    3.456486    0.604899    0.044827    0.047327    0.729006    
#> 049: 0.499409    1.083096    3.463910    0.574654    0.051182    0.044960    0.730941    
#> 050: 0.571740    1.057295    3.471477    0.595938    0.051511    0.042712    0.744263    
#> 051: 0.528284    1.074224    3.457306    0.613001    0.051367    0.042575    0.741261    
#> 052: 0.564277    1.095549    3.462970    0.666265    0.048799    0.040447    0.717613    
#> 053: 0.579341    1.098110    3.457337    0.755515    0.050244    0.038424    0.704261    
#> 054: 0.482486    1.103643    3.446514    0.717739    0.052069    0.046020    0.727707    
#> 055: 0.512336    1.109914    3.443349    0.684822    0.049466    0.052497    0.721339    
#> 056: 0.544655    1.087122    3.452015    0.650581    0.046993    0.056789    0.718584    
#> 057: 0.554278    1.093436    3.464256    0.677163    0.044643    0.054612    0.709243    
#> 058: 0.547894    1.102780    3.449199    0.673147    0.042411    0.051881    0.710135    
#> 059: 0.560019    1.069356    3.454670    0.653826    0.041280    0.049287    0.732782    
#> 060: 0.585649    1.048654    3.474345    0.621135    0.040246    0.046823    0.732496    
#> 061: 0.643292    1.040813    3.494012    0.697103    0.047861    0.044482    0.741808    
#> 062: 0.591752    1.048423    3.497262    0.686392    0.056667    0.046211    0.756751    
#> 063: 0.671334    1.043295    3.493569    0.673930    0.053834    0.043900    0.743374    
#> 064: 0.574506    1.059201    3.486294    0.640233    0.051142    0.047983    0.745366    
#> 065: 0.585158    1.049574    3.466805    0.608222    0.048585    0.047214    0.745153    
#> 066: 0.614388    1.064215    3.489561    0.577811    0.046156    0.052205    0.736578    
#> 067: 0.585662    1.073563    3.467212    0.583232    0.043848    0.050876    0.693417    
#> 068: 0.528240    1.086145    3.480232    0.604837    0.048125    0.048332    0.714262    
#> 069: 0.580610    1.082307    3.460757    0.661611    0.046295    0.045915    0.711177    
#> 070: 0.541006    1.080332    3.469951    0.628531    0.043980    0.051633    0.707444    
#> 071: 0.571024    1.116013    3.445572    0.691897    0.043851    0.049051    0.720190    
#> 072: 0.498915    1.100553    3.454237    0.657302    0.041659    0.051681    0.730604    
#> 073: 0.581574    1.094657    3.472699    0.745757    0.039576    0.052212    0.722252    
#> 074: 0.562773    1.093702    3.452646    0.708469    0.037597    0.049601    0.730516    
#> 075: 0.568978    1.083568    3.479933    0.673046    0.035717    0.047121    0.731536    
#> 076: 0.672675    1.083113    3.488499    0.773179    0.033931    0.050758    0.720217    
#> 077: 0.664744    1.069603    3.505198    0.753062    0.032235    0.052962    0.723286    
#> 078: 0.593646    1.072817    3.477077    0.715409    0.030623    0.053855    0.717978    
#> 079: 0.574001    1.077762    3.476450    0.679639    0.029991    0.051162    0.729420    
#> 080: 0.622485    1.073521    3.479455    0.726381    0.033498    0.048641    0.729677    
#> 081: 0.627839    1.077932    3.477213    0.766929    0.031823    0.052791    0.710835    
#> 082: 0.586560    1.068203    3.471785    0.728582    0.030812    0.052776    0.717369    
#> 083: 0.546788    1.070939    3.470263    0.692153    0.029271    0.051288    0.740643    
#> 084: 0.533831    1.078218    3.461866    0.657545    0.027808    0.051402    0.730089    
#> 085: 0.547298    1.072605    3.480778    0.624668    0.029462    0.048831    0.715633    
#> 086: 0.562416    1.072026    3.459678    0.593435    0.029160    0.046390    0.719671    
#> 087: 0.601150    1.066476    3.456372    0.733884    0.027702    0.046807    0.708140    
#> 088: 0.524086    1.069780    3.457703    0.697189    0.026317    0.045741    0.717448    
#> 089: 0.574064    1.079703    3.448322    0.749761    0.030684    0.043454    0.699993    
#> 090: 0.516843    1.084327    3.449908    0.712273    0.033543    0.043285    0.710165    
#> 091: 0.524628    1.083503    3.445253    0.676659    0.031866    0.046669    0.718299    
#> 092: 0.517064    1.085307    3.451496    0.642826    0.030272    0.048400    0.713348    
#> 093: 0.520136    1.074096    3.457234    0.610685    0.036668    0.047554    0.731461    
#> 094: 0.584702    1.079837    3.465856    0.649177    0.038922    0.051962    0.727788    
#> 095: 0.590060    1.060518    3.490375    0.616719    0.036976    0.049364    0.744160    
#> 096: 0.538647    1.073210    3.470339    0.585883    0.035294    0.046896    0.728888    
#> 097: 0.607416    1.077690    3.475446    0.651948    0.033529    0.044749    0.718758    
#> 098: 0.583619    1.075540    3.489879    0.619351    0.032082    0.048806    0.742412    
#> 099: 0.585818    1.056380    3.479029    0.631485    0.034992    0.046366    0.726269    
#> 100: 0.591026    1.050096    3.472866    0.599911    0.039691    0.044048    0.710752    
#> 101: 0.548549    1.038569    3.449025    0.569915    0.037771    0.041845    0.729080    
#> 102: 0.532492    1.036502    3.462229    0.541420    0.035883    0.042184    0.740149    
#> 103: 0.563498    1.040849    3.470555    0.611892    0.034089    0.047067    0.737498    
#> 104: 0.527629    1.048171    3.481280    0.581297    0.032384    0.048443    0.758469    
#> 105: 0.551989    1.068545    3.490829    0.552232    0.036225    0.046021    0.751740    
#> 106: 0.581710    1.064640    3.480463    0.539831    0.035791    0.043720    0.733536    
#> 107: 0.552350    1.071492    3.476470    0.530173    0.039051    0.043611    0.732293    
#> 108: 0.546104    1.073661    3.485742    0.547976    0.037099    0.048659    0.746197    
#> 109: 0.573189    1.081223    3.477202    0.613167    0.035244    0.048929    0.727028    
#> 110: 0.576584    1.071390    3.471972    0.598377    0.033482    0.046483    0.734986    
#> 111: 0.560005    1.081469    3.472237    0.568458    0.031808    0.044844    0.716509    
#> 112: 0.519619    1.055708    3.453704    0.599355    0.035002    0.042602    0.724216    
#> 113: 0.516847    1.070088    3.455090    0.569387    0.033252    0.046980    0.717470    
#> 114: 0.497859    1.089243    3.461186    0.540918    0.031589    0.044631    0.712634    
#> 115: 0.562942    1.061474    3.466781    0.513872    0.033305    0.046287    0.729439    
#> 116: 0.574159    1.072102    3.467193    0.525339    0.035087    0.050469    0.711908    
#> 117: 0.521973    1.085604    3.476544    0.499839    0.038022    0.047946    0.722911    
#> 118: 0.571142    1.082042    3.468007    0.547675    0.037492    0.050105    0.725617    
#> 119: 0.585597    1.077824    3.467260    0.563453    0.035617    0.047600    0.742353    
#> 120: 0.523544    1.075535    3.467104    0.535281    0.039903    0.050744    0.730312    
#> 121: 0.556522    1.115307    3.465589    0.530739    0.046981    0.052050    0.720013    
#> 122: 0.556924    1.092599    3.467711    0.565342    0.044632    0.049447    0.713010    
#> 123: 0.570821    1.112710    3.453990    0.628948    0.045321    0.046975    0.729907    
#> 124: 0.555956    1.134426    3.458537    0.724836    0.043055    0.044626    0.734146    
#> 125: 0.523541    1.120552    3.452221    0.688594    0.040902    0.042395    0.725943    
#> 126: 0.510087    1.135776    3.427026    0.654165    0.040589    0.040275    0.745380    
#> 127: 0.528025    1.112137    3.442372    0.621456    0.038560    0.038261    0.756636    
#> 128: 0.540797    1.065735    3.474821    0.590383    0.036632    0.036348    0.744973    
#> 129: 0.576575    1.080737    3.472788    0.620183    0.044873    0.041283    0.733435    
#> 130: 0.617938    1.073237    3.468366    0.617567    0.042630    0.040955    0.724934    
#> 131: 0.594544    1.077739    3.457732    0.618788    0.048367    0.046472    0.708153    
#> 132: 0.494774    1.091198    3.447689    0.587848    0.051690    0.050518    0.719875    
#> 133: 0.508786    1.084434    3.447378    0.599373    0.051225    0.047992    0.716261    
#> 134: 0.536783    1.068453    3.477682    0.653577    0.048664    0.053471    0.701874    
#> 135: 0.563654    1.054091    3.485457    0.620899    0.046230    0.050798    0.724008    
#> 136: 0.600215    1.057386    3.487349    0.589854    0.043919    0.049055    0.713183    
#> 137: 0.595851    1.060048    3.479253    0.560361    0.041723    0.051412    0.731808    
#> 138: 0.562615    1.076699    3.471722    0.545575    0.039637    0.050543    0.737100    
#> 139: 0.555043    1.083605    3.481632    0.599153    0.041578    0.049615    0.737605    
#> 140: 0.530485    1.099429    3.469215    0.569195    0.039500    0.051118    0.739848    
#> 141: 0.515876    1.069268    3.472171    0.540736    0.037525    0.048562    0.739415    
#> 142: 0.525754    1.049593    3.480240    0.513699    0.036627    0.046471    0.742914    
#> 143: 0.553992    1.057959    3.469020    0.580830    0.035901    0.044148    0.733215    
#> 144: 0.619264    1.064566    3.479298    0.626723    0.034106    0.041940    0.716587    
#> 145: 0.574296    1.071496    3.460604    0.696843    0.032401    0.039843    0.717759    
#> 146: 0.575191    1.073668    3.482961    0.680533    0.030781    0.044378    0.734596    
#> 147: 0.561934    1.069451    3.471367    0.670150    0.033005    0.047318    0.700235    
#> 148: 0.556799    1.087958    3.477266    0.645601    0.031443    0.044952    0.718684    
#> 149: 0.562678    1.068878    3.472983    0.658645    0.036981    0.046157    0.700452    
#> 150: 0.628641    1.071480    3.463664    0.842651    0.038739    0.044089    0.714950    
#> 151: 0.606345    1.093232    3.460685    0.987075    0.040360    0.045887    0.711938    
#> 152: 0.639189    1.092046    3.454706    1.176969    0.032936    0.039527    0.709225    
#> 153: 0.637299    1.106695    3.458504    1.239032    0.042018    0.041208    0.719197    
#> 154: 0.642287    1.100484    3.459593    1.199122    0.046572    0.043323    0.712553    
#> 155: 0.581044    1.088017    3.452690    0.852727    0.045111    0.044094    0.711893    
#> 156: 0.599940    1.092331    3.456400    0.809173    0.040653    0.046231    0.733409    
#> 157: 0.543405    1.078555    3.466359    0.682787    0.046648    0.046428    0.735330    
#> 158: 0.548079    1.106441    3.449451    0.657893    0.040122    0.043662    0.721225    
#> 159: 0.503423    1.126045    3.461160    0.553769    0.037536    0.046925    0.729545    
#> 160: 0.551294    1.094042    3.468128    0.720083    0.042732    0.048070    0.716317    
#> 161: 0.549573    1.089237    3.461257    0.551762    0.034220    0.050190    0.740037    
#> 162: 0.569262    1.095360    3.448744    0.694703    0.037169    0.048663    0.719825    
#> 163: 0.563944    1.099776    3.441288    0.665893    0.039152    0.048830    0.710429    
#> 164: 0.572917    1.090672    3.462031    0.591209    0.031215    0.049354    0.716163    
#> 165: 0.550041    1.089632    3.461266    0.570688    0.038134    0.047733    0.715773    
#> 166: 0.613196    1.109539    3.464311    0.684988    0.045186    0.045434    0.721804    
#> 167: 0.580846    1.127738    3.470290    0.601655    0.040487    0.052033    0.727402    
#> 168: 0.575152    1.124733    3.472414    0.666086    0.044121    0.053704    0.707791    
#> 169: 0.574338    1.141762    3.451886    0.651295    0.046841    0.052196    0.725982    
#> 170: 0.547945    1.118316    3.450770    0.631251    0.041108    0.051850    0.727270    
#> 171: 0.533774    1.112663    3.450239    0.671945    0.039469    0.045383    0.703167    
#> 172: 0.538215    1.129643    3.450038    0.789142    0.042258    0.047938    0.687031    
#> 173: 0.512053    1.138360    3.425178    0.743670    0.037779    0.039259    0.700546    
#> 174: 0.545232    1.127489    3.438376    0.788913    0.034845    0.037616    0.722413    
#> 175: 0.547514    1.120134    3.429673    0.818033    0.036139    0.039268    0.725168    
#> 176: 0.483862    1.129780    3.428769    0.621027    0.037062    0.032844    0.739580    
#> 177: 0.463462    1.115905    3.447649    0.498836    0.041158    0.030349    0.743635    
#> 178: 0.504958    1.101559    3.447270    0.544304    0.038848    0.039260    0.721294    
#> 179: 0.496084    1.117515    3.448017    0.442864    0.045426    0.045605    0.745520    
#> 180: 0.519113    1.106047    3.462901    0.516598    0.043087    0.041495    0.731298    
#> 181: 0.536358    1.077941    3.450102    0.493265    0.033207    0.043675    0.727890    
#> 182: 0.495082    1.082924    3.450124    0.499811    0.036608    0.044092    0.749816    
#> 183: 0.569329    1.095635    3.454155    0.594520    0.037405    0.039978    0.734101    
#> 184: 0.561071    1.070869    3.467004    0.573160    0.029594    0.045565    0.719217    
#> 185: 0.515584    1.084552    3.465762    0.513226    0.026511    0.051258    0.737152    
#> 186: 0.529580    1.094655    3.468691    0.519567    0.029471    0.059956    0.735854    
#> 187: 0.549360    1.095690    3.474198    0.501032    0.028738    0.053530    0.754350    
#> 188: 0.570853    1.101987    3.468859    0.578815    0.035740    0.047080    0.726657    
#> 189: 0.527542    1.112259    3.466176    0.483470    0.041096    0.046874    0.741805    
#> 190: 0.550650    1.106531    3.470902    0.537167    0.034569    0.050670    0.727646    
#> 191: 0.537374    1.100723    3.458747    0.548902    0.031833    0.042020    0.745697    
#> 192: 0.476278    1.081543    3.458839    0.449246    0.032967    0.046019    0.734524    
#> 193: 0.535611    1.099579    3.461950    0.489593    0.035019    0.039150    0.726341    
#> 194: 0.498216    1.118196    3.449859    0.467433    0.049793    0.030254    0.731574    
#> 195: 0.437303    1.121170    3.430834    0.434700    0.044515    0.026240    0.739936    
#> 196: 0.460828    1.115447    3.443383    0.520055    0.044887    0.028406    0.742476    
#> 197: 0.484507    1.126904    3.464758    0.576416    0.047193    0.031220    0.748253    
#> 198: 0.538283    1.111304    3.460376    0.587735    0.039978    0.034192    0.733738    
#> 199: 0.521223    1.094681    3.454037    0.561852    0.048477    0.028120    0.726261    
#> 200: 0.521397    1.096420    3.459413    0.509285    0.051645    0.033703    0.725727    
#> 201: 0.520708    1.095132    3.463043    0.527764    0.050805    0.033936    0.729504    
#> 202: 0.525955    1.093665    3.468794    0.537690    0.048591    0.031938    0.734312    
#> 203: 0.540951    1.091811    3.465630    0.549770    0.048097    0.030528    0.742300    
#> 204: 0.548676    1.087476    3.468571    0.555167    0.048682    0.030879    0.743720    
#> 205: 0.552883    1.092495    3.468321    0.555750    0.048841    0.032056    0.746402    
#> 206: 0.554798    1.095575    3.469352    0.576343    0.047937    0.033130    0.746293    
#> 207: 0.555278    1.093219    3.468177    0.586957    0.047726    0.033568    0.745161    
#> 208: 0.557194    1.092468    3.467287    0.600566    0.046066    0.034324    0.741269    
#> 209: 0.556349    1.089234    3.466323    0.609011    0.045402    0.035001    0.740175    
#> 210: 0.558812    1.087002    3.465903    0.611340    0.044837    0.035156    0.738360    
#> 211: 0.562238    1.086008    3.467530    0.610123    0.044488    0.035435    0.737312    
#> 212: 0.566218    1.084517    3.469129    0.605286    0.044542    0.035501    0.736130    
#> 213: 0.569242    1.080706    3.470549    0.602927    0.045013    0.036099    0.735933    
#> 214: 0.573082    1.079148    3.471783    0.604724    0.045126    0.037047    0.734658    
#> 215: 0.572826    1.078697    3.473551    0.596416    0.045007    0.037877    0.735287    
#> 216: 0.575050    1.076859    3.474373    0.590627    0.044806    0.038057    0.735875    
#> 217: 0.575505    1.078118    3.474701    0.590038    0.044519    0.038170    0.735167    
#> 218: 0.574896    1.079370    3.473854    0.589828    0.044164    0.038259    0.733908    
#> 219: 0.572030    1.080049    3.472515    0.585424    0.043671    0.038782    0.734055    
#> 220: 0.568640    1.081279    3.471586    0.586531    0.043506    0.039237    0.733203    
#> 221: 0.565970    1.082172    3.470591    0.585384    0.043340    0.039458    0.732240    
#> 222: 0.565480    1.082415    3.469912    0.585039    0.043141    0.039733    0.731448    
#> 223: 0.564933    1.083064    3.469507    0.585115    0.042682    0.040012    0.731500    
#> 224: 0.565627    1.084314    3.469225    0.587431    0.042762    0.039918    0.731140    
#> 225: 0.563851    1.083231    3.469409    0.585605    0.042474    0.040385    0.731986    
#> 226: 0.560908    1.082153    3.468438    0.582377    0.042358    0.040573    0.732809    
#> 227: 0.559552    1.082310    3.468320    0.577571    0.042297    0.040667    0.733397    
#> 228: 0.557319    1.083284    3.467320    0.574547    0.042573    0.040579    0.733445    
#> 229: 0.554868    1.083421    3.466838    0.572914    0.042895    0.040589    0.732795    
#> 230: 0.554146    1.083480    3.466309    0.572635    0.043086    0.040528    0.732372    
#> 231: 0.554163    1.083640    3.466158    0.575920    0.043168    0.040659    0.731746    
#> 232: 0.552544    1.083788    3.465919    0.574590    0.043153    0.040673    0.731120    
#> 233: 0.551208    1.082956    3.465897    0.575816    0.042974    0.040731    0.730971    
#> 234: 0.549362    1.082676    3.465693    0.573977    0.043093    0.040762    0.731020    
#> 235: 0.548782    1.082614    3.465452    0.573151    0.043115    0.040625    0.731155    
#> 236: 0.547786    1.083307    3.464714    0.574271    0.043200    0.040610    0.731566    
#> 237: 0.547518    1.083732    3.464483    0.573885    0.043346    0.040716    0.731494    
#> 238: 0.547579    1.084100    3.464406    0.572820    0.043508    0.040947    0.732223    
#> 239: 0.547120    1.084879    3.463922    0.575338    0.043720    0.041276    0.732050    
#> 240: 0.546506    1.085407    3.463546    0.576873    0.043939    0.041541    0.731750    
#> 241: 0.545009    1.085454    3.463126    0.578056    0.043954    0.041730    0.731870    
#> 242: 0.544507    1.085645    3.462520    0.580384    0.044160    0.041688    0.732291    
#> 243: 0.542996    1.086486    3.462033    0.580094    0.044517    0.041687    0.732400    
#> 244: 0.542698    1.086375    3.462306    0.579767    0.044595    0.041740    0.732061    
#> 245: 0.543650    1.085916    3.462626    0.580055    0.044660    0.041879    0.732113    
#> 246: 0.544140    1.085774    3.462941    0.578927    0.044599    0.042002    0.732552    
#> 247: 0.544611    1.085238    3.463045    0.580507    0.044481    0.042172    0.732471    
#> 248: 0.544036    1.085303    3.462907    0.581797    0.044259    0.042252    0.732050    
#> 249: 0.543713    1.085232    3.462991    0.581721    0.043861    0.042522    0.732383    
#> 250: 0.544618    1.085399    3.463116    0.583921    0.043776    0.042719    0.732155    
#> 251: 0.544906    1.085570    3.463521    0.584634    0.043614    0.042793    0.732400    
#> 252: 0.545172    1.085605    3.464002    0.583240    0.043517    0.042875    0.732825    
#> 253: 0.544585    1.085608    3.463919    0.583196    0.043481    0.042879    0.732823    
#> 254: 0.544540    1.085995    3.463720    0.583989    0.043502    0.042700    0.732685    
#> 255: 0.545387    1.086363    3.463811    0.584640    0.043377    0.042671    0.732471    
#> 256: 0.545100    1.086310    3.463842    0.583940    0.043225    0.042535    0.732520    
#> 257: 0.544296    1.086185    3.463702    0.581538    0.043174    0.042424    0.732504    
#> 258: 0.544228    1.085692    3.463830    0.580957    0.043066    0.042404    0.732320    
#> 259: 0.544118    1.085389    3.463934    0.579539    0.043052    0.042465    0.732160    
#> 260: 0.544047    1.085349    3.464071    0.578846    0.042879    0.042565    0.732077    
#> 261: 0.544459    1.085119    3.464154    0.579368    0.042762    0.042553    0.732180    
#> 262: 0.544446    1.085042    3.464123    0.580023    0.042747    0.042630    0.732172    
#> 263: 0.544256    1.085119    3.464177    0.578831    0.042621    0.042721    0.732279    
#> 264: 0.544027    1.085151    3.464044    0.577881    0.042580    0.042826    0.732361    
#> 265: 0.543767    1.085233    3.463920    0.577320    0.042612    0.042768    0.732476    
#> 266: 0.544140    1.085566    3.464076    0.577876    0.042614    0.042782    0.732167    
#> 267: 0.544355    1.085639    3.464540    0.575934    0.042701    0.042807    0.732031    
#> 268: 0.545433    1.085566    3.464735    0.576756    0.042743    0.042835    0.731783    
#> 269: 0.546259    1.085538    3.464848    0.578624    0.042731    0.042839    0.731643    
#> 270: 0.546611    1.085510    3.464793    0.579741    0.042610    0.042882    0.731527    
#> 271: 0.546971    1.085281    3.464770    0.579903    0.042558    0.042891    0.731389    
#> 272: 0.547639    1.085458    3.464694    0.579121    0.042509    0.042934    0.731567    
#> 273: 0.548099    1.085898    3.464918    0.578582    0.042655    0.042887    0.731848    
#> 274: 0.548436    1.086178    3.465019    0.577819    0.042564    0.042752    0.732021    
#> 275: 0.548695    1.086351    3.465019    0.577420    0.042514    0.042689    0.731933    
#> 276: 0.548660    1.086569    3.465089    0.576213    0.042474    0.042799    0.731795    
#> 277: 0.548060    1.086762    3.465233    0.575160    0.042403    0.042831    0.731874    
#> 278: 0.548168    1.086672    3.465459    0.575087    0.042422    0.042785    0.731890    
#> 279: 0.548384    1.086428    3.465580    0.576105    0.042481    0.042886    0.731992    
#> 280: 0.548385    1.086502    3.465582    0.575417    0.042458    0.042864    0.731865    
#> 281: 0.547922    1.086678    3.465493    0.575774    0.042397    0.042794    0.731760    
#> 282: 0.548124    1.087024    3.465635    0.576775    0.042412    0.042899    0.731588    
#> 283: 0.547998    1.087301    3.465723    0.576128    0.042395    0.043112    0.731773    
#> 284: 0.547767    1.087178    3.465835    0.575518    0.042189    0.043259    0.731617    
#> 285: 0.547522    1.087426    3.465779    0.576191    0.042076    0.043348    0.731596    
#> 286: 0.546958    1.087611    3.465472    0.576501    0.042050    0.043445    0.731475    
#> 287: 0.546119    1.087898    3.465201    0.575637    0.042003    0.043583    0.731253    
#> 288: 0.546173    1.087878    3.465179    0.576250    0.041994    0.043627    0.731231    
#> 289: 0.546614    1.087673    3.465145    0.577166    0.041995    0.043668    0.731179    
#> 290: 0.546666    1.087621    3.465196    0.577420    0.042001    0.043586    0.731213    
#> 291: 0.546704    1.087887    3.465066    0.577382    0.041971    0.043498    0.730916    
#> 292: 0.546326    1.088158    3.464882    0.576937    0.041912    0.043422    0.730669    
#> 293: 0.545990    1.088500    3.464636    0.577476    0.041886    0.043406    0.730406    
#> 294: 0.545407    1.088832    3.464250    0.576960    0.041865    0.043372    0.730310    
#> 295: 0.544940    1.088761    3.464012    0.577262    0.041775    0.043408    0.730161    
#> 296: 0.544799    1.088686    3.463871    0.578067    0.041672    0.043427    0.730113    
#> 297: 0.544750    1.088804    3.463765    0.578226    0.041650    0.043472    0.730109    
#> 298: 0.544340    1.088770    3.463591    0.578569    0.041620    0.043483    0.729932    
#> 299: 0.544282    1.088986    3.463480    0.579145    0.041556    0.043552    0.729725    
#> 300: 0.544274    1.088987    3.463435    0.578910    0.041589    0.043511    0.729440    
#> 301: 0.544228    1.088940    3.463289    0.579985    0.041533    0.043474    0.729355    
#> 302: 0.544444    1.089024    3.463136    0.581428    0.041413    0.043498    0.729251    
#> 303: 0.543986    1.089277    3.462940    0.581816    0.041320    0.043525    0.729089    
#> 304: 0.543240    1.089629    3.462705    0.581957    0.041287    0.043561    0.728990    
#> 305: 0.543092    1.089565    3.462485    0.583094    0.041308    0.043605    0.728723    
#> 306: 0.543093    1.089538    3.462303    0.583985    0.041349    0.043594    0.728509    
#> 307: 0.542685    1.089570    3.462100    0.584072    0.041443    0.043608    0.728540    
#> 308: 0.542382    1.089584    3.462074    0.584778    0.041528    0.043655    0.728507    
#> 309: 0.542426    1.089349    3.462155    0.585816    0.041471    0.043645    0.728849    
#> 310: 0.542592    1.089190    3.462096    0.586026    0.041424    0.043662    0.729039    
#> 311: 0.543318    1.089115    3.462220    0.586749    0.041362    0.043791    0.728983    
#> 312: 0.543237    1.088978    3.462183    0.587908    0.041357    0.043750    0.729089    
#> 313: 0.543270    1.088747    3.462148    0.588452    0.041383    0.043691    0.729286    
#> 314: 0.543204    1.088604    3.462009    0.589632    0.041428    0.043676    0.729305    
#> 315: 0.543274    1.088603    3.461949    0.590762    0.041459    0.043652    0.729181    
#> 316: 0.543273    1.088705    3.461773    0.592183    0.041530    0.043605    0.729038    
#> 317: 0.543525    1.088762    3.461714    0.593138    0.041554    0.043559    0.728924    
#> 318: 0.543373    1.088848    3.461593    0.592842    0.041595    0.043570    0.728709    
#> 319: 0.543598    1.088809    3.461588    0.593158    0.041680    0.043528    0.728678    
#> 320: 0.543287    1.088783    3.461618    0.593748    0.041757    0.043481    0.728656    
#> 321: 0.543290    1.088654    3.461593    0.593411    0.041751    0.043441    0.728869    
#> 322: 0.543936    1.088544    3.461637    0.594419    0.041651    0.043483    0.728965    
#> 323: 0.543698    1.088674    3.461515    0.595437    0.041703    0.043466    0.728988    
#> 324: 0.543580    1.088829    3.461445    0.596292    0.041750    0.043437    0.729087    
#> 325: 0.543595    1.089017    3.461224    0.597212    0.041775    0.043441    0.729062    
#> 326: 0.543293    1.089069    3.460990    0.597827    0.041861    0.043421    0.729095    
#> 327: 0.543331    1.089247    3.460892    0.598456    0.041888    0.043372    0.728980    
#> 328: 0.543496    1.089320    3.460877    0.599188    0.041846    0.043398    0.728884    
#> 329: 0.543739    1.089426    3.460927    0.600025    0.041793    0.043390    0.728741    
#> 330: 0.543992    1.089285    3.460998    0.600842    0.041681    0.043409    0.728814    
#> 331: 0.544546    1.089326    3.461154    0.600868    0.041586    0.043441    0.728905    
#> 332: 0.544909    1.089084    3.461318    0.601606    0.041451    0.043502    0.728974    
#> 333: 0.545000    1.088971    3.461307    0.601818    0.041412    0.043573    0.729015    
#> 334: 0.544833    1.088831    3.461210    0.602023    0.041330    0.043582    0.728853    
#> 335: 0.544651    1.088792    3.461114    0.601589    0.041293    0.043605    0.728894    
#> 336: 0.544390    1.088916    3.461074    0.601909    0.041288    0.043644    0.728919    
#> 337: 0.544006    1.089018    3.460953    0.601559    0.041261    0.043684    0.728934    
#> 338: 0.543871    1.089158    3.460916    0.601297    0.041227    0.043694    0.729094    
#> 339: 0.543764    1.089245    3.460892    0.601150    0.041218    0.043710    0.729139    
#> 340: 0.543858    1.089045    3.460923    0.601099    0.041203    0.043722    0.729154    
#> 341: 0.543950    1.088965    3.460989    0.601034    0.041176    0.043783    0.729178    
#> 342: 0.543525    1.088749    3.460975    0.600377    0.041154    0.043812    0.729189    
#> 343: 0.543229    1.088748    3.460904    0.600648    0.041214    0.043854    0.729022    
#> 344: 0.543566    1.088635    3.460904    0.601653    0.041173    0.043891    0.729081    
#> 345: 0.543814    1.088560    3.460919    0.601731    0.041137    0.043939    0.729002    
#> 346: 0.543773    1.088504    3.460914    0.601308    0.041115    0.043926    0.729015    
#> 347: 0.543936    1.088252    3.460963    0.600978    0.041121    0.044001    0.729130    
#> 348: 0.543775    1.088311    3.460958    0.600995    0.041135    0.044029    0.729393    
#> 349: 0.543393    1.088252    3.460920    0.600869    0.041141    0.044091    0.729406    
#> 350: 0.543086    1.088150    3.460860    0.600562    0.041184    0.044063    0.729494    
#> 351: 0.542992    1.088356    3.460827    0.600667    0.041279    0.044034    0.729560    
#> 352: 0.542619    1.088573    3.460740    0.599971    0.041390    0.044013    0.729793    
#> 353: 0.542553    1.088817    3.460698    0.599815    0.041458    0.044046    0.729930    
#> 354: 0.542250    1.088921    3.460615    0.599323    0.041432    0.044103    0.729997    
#> 355: 0.542709    1.088787    3.460620    0.599308    0.041382    0.044142    0.730027    
#> 356: 0.542847    1.088744    3.460627    0.599661    0.041399    0.044142    0.730040    
#> 357: 0.543026    1.088777    3.460632    0.600066    0.041381    0.044160    0.729949    
#> 358: 0.542963    1.088776    3.460660    0.599946    0.041256    0.044186    0.729850    
#> 359: 0.542855    1.088842    3.460601    0.599508    0.041266    0.044178    0.729676    
#> 360: 0.542425    1.088793    3.460455    0.598808    0.041261    0.044134    0.729656    
#> 361: 0.542514    1.088830    3.460486    0.598535    0.041289    0.044130    0.729542    
#> 362: 0.542635    1.088810    3.460472    0.598419    0.041314    0.044086    0.729327    
#> 363: 0.542830    1.088680    3.460570    0.598314    0.041288    0.044122    0.729161    
#> 364: 0.542963    1.088545    3.460638    0.598618    0.041254    0.044109    0.729182    
#> 365: 0.542934    1.088411    3.460745    0.598321    0.041259    0.044152    0.729264    
#> 366: 0.542983    1.088380    3.460689    0.597977    0.041270    0.044220    0.729284    
#> 367: 0.542785    1.088449    3.460596    0.597362    0.041283    0.044208    0.729273    
#> 368: 0.542815    1.088507    3.460516    0.597229    0.041260    0.044210    0.729144    
#> 369: 0.542646    1.088477    3.460501    0.596800    0.041260    0.044192    0.729173    
#> 370: 0.542504    1.088509    3.460455    0.596818    0.041277    0.044211    0.729186    
#> 371: 0.542003    1.088598    3.460269    0.596744    0.041317    0.044200    0.729253    
#> 372: 0.541924    1.088658    3.460173    0.597192    0.041353    0.044179    0.729380    
#> 373: 0.541466    1.088861    3.460060    0.596833    0.041395    0.044147    0.729548    
#> 374: 0.541432    1.088932    3.460050    0.596418    0.041413    0.044151    0.729605    
#> 375: 0.541273    1.088909    3.460080    0.595870    0.041430    0.044181    0.729645    
#> 376: 0.541350    1.088963    3.460092    0.595987    0.041499    0.044190    0.729591    
#> 377: 0.541289    1.089018    3.460088    0.595408    0.041566    0.044143    0.729571    
#> 378: 0.541139    1.088973    3.460090    0.594789    0.041528    0.044114    0.729526    
#> 379: 0.540966    1.088835    3.460102    0.594106    0.041525    0.044105    0.729438    
#> 380: 0.540751    1.088751    3.460131    0.593556    0.041530    0.044103    0.729467    
#> 381: 0.540622    1.088606    3.460166    0.593226    0.041514    0.044076    0.729437    
#> 382: 0.540615    1.088528    3.460195    0.592870    0.041466    0.044085    0.729368    
#> 383: 0.540921    1.088365    3.460224    0.593200    0.041404    0.044087    0.729268    
#> 384: 0.540884    1.088370    3.460213    0.593448    0.041441    0.044089    0.729163    
#> 385: 0.541081    1.088402    3.460221    0.593575    0.041436    0.044152    0.729025    
#> 386: 0.541288    1.088547    3.460274    0.593526    0.041455    0.044169    0.728979    
#> 387: 0.541462    1.088597    3.460376    0.593526    0.041445    0.044175    0.728922    
#> 388: 0.541644    1.088682    3.460434    0.593745    0.041455    0.044204    0.728929    
#> 389: 0.541671    1.088605    3.460386    0.593724    0.041413    0.044200    0.729031    
#> 390: 0.541356    1.088662    3.460320    0.593077    0.041373    0.044196    0.729082    
#> 391: 0.541413    1.088654    3.460279    0.593298    0.041381    0.044216    0.728936    
#> 392: 0.541539    1.088608    3.460344    0.593775    0.041377    0.044194    0.728986    
#> 393: 0.541774    1.088475    3.460370    0.594224    0.041376    0.044187    0.728945    
#> 394: 0.542005    1.088413    3.460407    0.594927    0.041395    0.044176    0.728940    
#> 395: 0.542503    1.088481    3.460429    0.596149    0.041425    0.044198    0.728966    
#> 396: 0.542897    1.088520    3.460484    0.597397    0.041415    0.044218    0.728955    
#> 397: 0.543163    1.088462    3.460536    0.598175    0.041410    0.044237    0.729017    
#> 398: 0.543590    1.088360    3.460589    0.598564    0.041387    0.044243    0.729089    
#> 399: 0.543724    1.088316    3.460676    0.598613    0.041381    0.044247    0.729036    
#> 400: 0.543979    1.088387    3.460689    0.598552    0.041351    0.044245    0.729029    
#> 401: 0.544228    1.088457    3.460713    0.598086    0.041342    0.044252    0.729058    
#> 402: 0.544277    1.088521    3.460751    0.597887    0.041311    0.044254    0.729038    
#> 403: 0.544597    1.088542    3.460790    0.598240    0.041307    0.044267    0.728912    
#> 404: 0.544745    1.088602    3.460736    0.598734    0.041288    0.044251    0.728807    
#> 405: 0.544492    1.088651    3.460715    0.598194    0.041244    0.044269    0.728781    
#> 406: 0.544344    1.088694    3.460651    0.598397    0.041230    0.044278    0.728826    
#> 407: 0.544319    1.088722    3.460645    0.598702    0.041229    0.044243    0.728902    
#> 408: 0.544272    1.088880    3.460594    0.598476    0.041252    0.044215    0.728877    
#> 409: 0.544092    1.088933    3.460562    0.598858    0.041221    0.044201    0.728854    
#> 410: 0.543933    1.089087    3.460469    0.599506    0.041237    0.044165    0.728852    
#> 411: 0.544067    1.089007    3.460465    0.600605    0.041238    0.044127    0.728856    
#> 412: 0.544083    1.089039    3.460429    0.601279    0.041237    0.044110    0.728825    
#> 413: 0.544284    1.089051    3.460395    0.602298    0.041245    0.044098    0.728727    
#> 414: 0.544264    1.089024    3.460394    0.603084    0.041272    0.044074    0.728765    
#> 415: 0.544526    1.088910    3.460422    0.603566    0.041299    0.044072    0.728761    
#> 416: 0.544787    1.088925    3.460528    0.603583    0.041320    0.044080    0.728750    
#> 417: 0.545004    1.088855    3.460604    0.603613    0.041300    0.044057    0.728780    
#> 418: 0.544795    1.088897    3.460585    0.603118    0.041331    0.043995    0.728766    
#> 419: 0.544541    1.088955    3.460573    0.602399    0.041346    0.043934    0.728776    
#> 420: 0.544582    1.089014    3.460538    0.602271    0.041404    0.043888    0.728707    
#> 421: 0.544427    1.089019    3.460527    0.602201    0.041454    0.043840    0.728650    
#> 422: 0.544656    1.089047    3.460508    0.602975    0.041482    0.043819    0.728584    
#> 423: 0.544690    1.089042    3.460500    0.603021    0.041497    0.043794    0.728471    
#> 424: 0.544459    1.089020    3.460378    0.602689    0.041493    0.043747    0.728433    
#> 425: 0.544436    1.089122    3.460300    0.602619    0.041499    0.043713    0.728497    
#> 426: 0.544485    1.089255    3.460264    0.602836    0.041547    0.043680    0.728448    
#> 427: 0.544313    1.089367    3.460223    0.603306    0.041553    0.043687    0.728447    
#> 428: 0.544209    1.089443    3.460196    0.603719    0.041523    0.043677    0.728524    
#> 429: 0.544140    1.089506    3.460176    0.603967    0.041513    0.043708    0.728524    
#> 430: 0.544086    1.089620    3.460090    0.604344    0.041483    0.043755    0.728531    
#> 431: 0.544062    1.089691    3.459989    0.604787    0.041473    0.043762    0.728413    
#> 432: 0.543866    1.089775    3.459943    0.604721    0.041479    0.043793    0.728346    
#> 433: 0.543763    1.089898    3.459950    0.604537    0.041473    0.043808    0.728369    
#> 434: 0.543557    1.089870    3.459916    0.604324    0.041475    0.043845    0.728263    
#> 435: 0.543446    1.089892    3.459888    0.604079    0.041489    0.043857    0.728156    
#> 436: 0.543385    1.089906    3.459879    0.604079    0.041465    0.043884    0.728138    
#> 437: 0.543461    1.089906    3.459854    0.604191    0.041447    0.043887    0.728056    
#> 438: 0.543362    1.090054    3.459857    0.604120    0.041436    0.043889    0.728005    
#> 439: 0.543443    1.090141    3.459845    0.604212    0.041421    0.043885    0.727855    
#> 440: 0.543443    1.090178    3.459865    0.603877    0.041427    0.043883    0.727848    
#> 441: 0.543613    1.090172    3.459872    0.604047    0.041458    0.043866    0.727801    
#> 442: 0.543342    1.090198    3.459858    0.603968    0.041494    0.043853    0.727746    
#> 443: 0.543184    1.090321    3.459781    0.603961    0.041452    0.043884    0.727728    
#> 444: 0.543057    1.090361    3.459735    0.603716    0.041425    0.043914    0.727725    
#> 445: 0.543030    1.090446    3.459692    0.603609    0.041384    0.043921    0.727710    
#> 446: 0.542802    1.090510    3.459616    0.603421    0.041340    0.043941    0.727671    
#> 447: 0.542804    1.090611    3.459564    0.603080    0.041315    0.043976    0.727685    
#> 448: 0.542615    1.090617    3.459527    0.602901    0.041304    0.044019    0.727690    
#> 449: 0.542509    1.090700    3.459553    0.602678    0.041279    0.044038    0.727726    
#> 450: 0.542352    1.090702    3.459569    0.602373    0.041235    0.044070    0.727728    
#> 451: 0.542303    1.090755    3.459580    0.601996    0.041216    0.044082    0.727830    
#> 452: 0.542314    1.090784    3.459580    0.601780    0.041192    0.044083    0.727884    
#> 453: 0.542239    1.090814    3.459544    0.601609    0.041206    0.044069    0.727863    
#> 454: 0.542135    1.090952    3.459508    0.601210    0.041222    0.044095    0.727833    
#> 455: 0.541984    1.091037    3.459397    0.601346    0.041244    0.044101    0.727815    
#> 456: 0.541832    1.091065    3.459357    0.601537    0.041286    0.044145    0.727868    
#> 457: 0.541788    1.091058    3.459339    0.601610    0.041311    0.044169    0.727828    
#> 458: 0.541615    1.091162    3.459308    0.601412    0.041304    0.044166    0.727825    
#> 459: 0.541311    1.091329    3.459258    0.601407    0.041283    0.044159    0.727918    
#> 460: 0.541073    1.091473    3.459158    0.601583    0.041303    0.044159    0.727923    
#> 461: 0.540977    1.091625    3.459138    0.601822    0.041308    0.044210    0.727909    
#> 462: 0.540926    1.091779    3.459087    0.602084    0.041295    0.044250    0.727854    
#> 463: 0.541065    1.091860    3.459118    0.602601    0.041284    0.044268    0.727919    
#> 464: 0.541280    1.091909    3.459110    0.602781    0.041253    0.044277    0.727897    
#> 465: 0.541409    1.091845    3.459124    0.603106    0.041226    0.044272    0.727860    
#> 466: 0.541458    1.091889    3.459075    0.603477    0.041224    0.044246    0.727862    
#> 467: 0.541356    1.091905    3.459076    0.603691    0.041217    0.044234    0.727804    
#> 468: 0.541444    1.091960    3.459155    0.603468    0.041180    0.044252    0.727868    
#> 469: 0.541529    1.092077    3.459200    0.603533    0.041150    0.044313    0.727946    
#> 470: 0.541518    1.092099    3.459168    0.603483    0.041133    0.044363    0.727945    
#> 471: 0.541439    1.092117    3.459178    0.603530    0.041129    0.044340    0.727924    
#> 472: 0.541487    1.092068    3.459203    0.603418    0.041124    0.044344    0.727907    
#> 473: 0.541373    1.092065    3.459206    0.603342    0.041115    0.044357    0.727840    
#> 474: 0.541258    1.092076    3.459168    0.603334    0.041149    0.044360    0.727822    
#> 475: 0.541254    1.092188    3.459172    0.603159    0.041164    0.044363    0.727784    
#> 476: 0.541185    1.092152    3.459147    0.602939    0.041153    0.044359    0.727813    
#> 477: 0.541146    1.092118    3.459153    0.602822    0.041136    0.044371    0.727752    
#> 478: 0.541151    1.092070    3.459148    0.602949    0.041110    0.044375    0.727767    
#> 479: 0.541295    1.092092    3.459132    0.603491    0.041095    0.044386    0.727762    
#> 480: 0.541331    1.092150    3.459074    0.603838    0.041097    0.044406    0.727765    
#> 481: 0.541259    1.092191    3.459016    0.604234    0.041066    0.044430    0.727739    
#> 482: 0.541194    1.092292    3.458924    0.604398    0.041038    0.044444    0.727751    
#> 483: 0.540996    1.092354    3.458864    0.604631    0.041042    0.044430    0.727717    
#> 484: 0.540931    1.092273    3.458829    0.604918    0.041017    0.044429    0.727747    
#> 485: 0.540954    1.092295    3.458816    0.604959    0.041006    0.044445    0.727793    
#> 486: 0.540982    1.092365    3.458812    0.605053    0.040963    0.044444    0.727764    
#> 487: 0.541262    1.092390    3.458900    0.605169    0.040933    0.044477    0.727678    
#> 488: 0.541411    1.092367    3.458932    0.605555    0.040886    0.044510    0.727593    
#> 489: 0.541547    1.092284    3.458915    0.605847    0.040862    0.044537    0.727595    
#> 490: 0.541543    1.092269    3.458926    0.605916    0.040845    0.044547    0.727560    
#> 491: 0.541564    1.092276    3.458985    0.605767    0.040824    0.044590    0.727589    
#> 492: 0.541472    1.092298    3.458996    0.605658    0.040803    0.044566    0.727632    
#> 493: 0.541342    1.092346    3.458996    0.605456    0.040814    0.044611    0.727661    
#> 494: 0.541404    1.092424    3.458956    0.605609    0.040836    0.044635    0.727598    
#> 495: 0.541559    1.092504    3.458935    0.606032    0.040822    0.044666    0.727516    
#> 496: 0.541630    1.092558    3.458887    0.606272    0.040799    0.044689    0.727499    
#> 497: 0.541586    1.092540    3.458821    0.606467    0.040776    0.044697    0.727578    
#> 498: 0.541580    1.092537    3.458797    0.606766    0.040741    0.044714    0.727521    
#> 499: 0.541745    1.092623    3.458794    0.607019    0.040745    0.044712    0.727420    
#> 500: 0.541887    1.092627    3.458762    0.607475    0.040727    0.044711    0.727385    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.303135    0.959290    3.454244    0.392401    0.089164    0.016800    1.716505    
#> 002: 0.298884    1.016297    3.481405    0.372781    0.084705    0.015960    1.121685    
#> 003: 0.411168    0.982000    3.499483    0.354142    0.091730    0.015162    0.854520    
#> 004: 0.359150    1.011415    3.503615    0.336435    0.108964    0.014404    0.739170    
#> 005: 0.403626    1.035823    3.489075    0.320397    0.109573    0.013684    0.718972    
#> 006: 0.372422    1.044719    3.479041    0.304842    0.104094    0.013000    0.650562    
#> 007: 0.360340    1.057803    3.471004    0.297687    0.107360    0.012350    0.658478    
#> 008: 0.349999    1.026741    3.471419    0.340730    0.110488    0.012641    0.652988    
#> 009: 0.329319    1.007710    3.474642    0.323693    0.111784    0.013364    0.667501    
#> 010: 0.346293    1.022372    3.476535    0.347015    0.113943    0.015036    0.674139    
#> 011: 0.409069    1.039915    3.479087    0.441880    0.109628    0.015620    0.650443    
#> 012: 0.359889    1.025962    3.464162    0.430100    0.104147    0.016835    0.646241    
#> 013: 0.367001    1.040867    3.466845    0.408595    0.102851    0.019181    0.630728    
#> 014: 0.387502    1.035118    3.474351    0.494517    0.113404    0.018222    0.627944    
#> 015: 0.394022    1.032693    3.491759    0.469791    0.109781    0.017311    0.618946    
#> 016: 0.394614    1.041339    3.491689    0.472630    0.130292    0.019013    0.621231    
#> 017: 0.389275    1.044890    3.483056    0.448998    0.124938    0.018062    0.611967    
#> 018: 0.392270    1.059682    3.474872    0.426548    0.134630    0.017159    0.625957    
#> 019: 0.357893    1.044144    3.468343    0.437494    0.127898    0.016301    0.632395    
#> 020: 0.397506    1.052636    3.484480    0.430218    0.121504    0.016293    0.622729    
#> 021: 0.415282    1.034789    3.495235    0.408707    0.119670    0.015478    0.622739    
#> 022: 0.416118    1.038765    3.495611    0.411204    0.120889    0.014704    0.624693    
#> 023: 0.499211    1.025581    3.509722    0.393314    0.119268    0.014218    0.656334    
#> 024: 0.463926    1.038495    3.497158    0.426885    0.113305    0.015936    0.638898    
#> 025: 0.415476    1.031904    3.486398    0.405541    0.111556    0.016511    0.630566    
#> 026: 0.393178    1.069470    3.477801    0.385264    0.105978    0.017284    0.632711    
#> 027: 0.380117    1.076867    3.475750    0.366001    0.127153    0.016420    0.643433    
#> 028: 0.410724    1.064874    3.472087    0.352941    0.120796    0.016157    0.634195    
#> 029: 0.422287    1.043974    3.474513    0.355706    0.119895    0.015916    0.651176    
#> 030: 0.405977    1.052635    3.475473    0.388590    0.122979    0.017568    0.632354    
#> 031: 0.378557    1.039731    3.479629    0.369160    0.134571    0.016689    0.627776    
#> 032: 0.378676    1.017833    3.489275    0.376811    0.127843    0.015855    0.637390    
#> 033: 0.381818    1.028454    3.487179    0.387918    0.121451    0.020677    0.633484    
#> 034: 0.424310    1.042283    3.502136    0.369844    0.115378    0.021167    0.652907    
#> 035: 0.383940    1.029120    3.486647    0.407720    0.109609    0.020109    0.636493    
#> 036: 0.426860    1.024748    3.494925    0.387334    0.117781    0.019285    0.632457    
#> 037: 0.417566    1.032631    3.502326    0.367968    0.124313    0.018321    0.631946    
#> 038: 0.454289    1.033394    3.498052    0.379357    0.118097    0.017405    0.626480    
#> 039: 0.423143    1.039034    3.506508    0.360389    0.143825    0.016922    0.624007    
#> 040: 0.453722    1.040369    3.516629    0.347826    0.136634    0.016076    0.650029    
#> 041: 0.394674    1.030344    3.499039    0.330434    0.129802    0.020090    0.633076    
#> 042: 0.456398    1.038132    3.497387    0.379740    0.123312    0.019086    0.623379    
#> 043: 0.388416    1.045810    3.484618    0.378614    0.117146    0.018700    0.620966    
#> 044: 0.382488    1.042600    3.485632    0.359683    0.122253    0.017765    0.632628    
#> 045: 0.388527    1.063320    3.477534    0.341699    0.116140    0.016877    0.630597    
#> 046: 0.388231    1.030980    3.485921    0.389524    0.134119    0.016033    0.627636    
#> 047: 0.397496    1.032427    3.480597    0.370048    0.127413    0.015232    0.633397    
#> 048: 0.418164    1.034350    3.496403    0.351546    0.121042    0.015290    0.631764    
#> 049: 0.415560    1.023090    3.502684    0.333968    0.114990    0.017660    0.631165    
#> 050: 0.472578    0.989859    3.509788    0.351741    0.117969    0.017081    0.666839    
#> 051: 0.459831    1.024840    3.508783    0.335822    0.123150    0.017487    0.661569    
#> 052: 0.467559    1.026058    3.513847    0.319031    0.122381    0.016613    0.638524    
#> 053: 0.450789    1.014989    3.504071    0.372045    0.124740    0.015782    0.652368    
#> 054: 0.399896    1.018099    3.506192    0.353442    0.120871    0.014993    0.666494    
#> 055: 0.411998    1.019866    3.498909    0.413790    0.114827    0.014243    0.655389    
#> 056: 0.421052    0.999022    3.492700    0.468555    0.131002    0.014933    0.657157    
#> 057: 0.408435    1.027105    3.493425    0.445127    0.124452    0.014186    0.644981    
#> 058: 0.420121    1.027422    3.492733    0.422871    0.118230    0.013477    0.642332    
#> 059: 0.413334    0.985679    3.505781    0.401727    0.122969    0.017907    0.652709    
#> 060: 0.398312    0.996376    3.499759    0.381641    0.116820    0.017829    0.655443    
#> 061: 0.423633    1.008867    3.505887    0.376478    0.110979    0.018420    0.665143    
#> 062: 0.458580    1.020199    3.517943    0.357654    0.121853    0.017499    0.660464    
#> 063: 0.471669    1.004777    3.509042    0.413639    0.119792    0.021707    0.652625    
#> 064: 0.411443    0.999560    3.511008    0.392957    0.113803    0.021001    0.651893    
#> 065: 0.440655    1.007682    3.496289    0.373309    0.108113    0.019951    0.648794    
#> 066: 0.452115    1.026059    3.500088    0.431176    0.120293    0.018953    0.631027    
#> 067: 0.428740    1.027820    3.488380    0.414014    0.132474    0.018005    0.626130    
#> 068: 0.374117    1.032697    3.494707    0.424780    0.136617    0.018840    0.633623    
#> 069: 0.380321    1.043929    3.483509    0.450006    0.129786    0.020170    0.632168    
#> 070: 0.409847    1.015588    3.492200    0.427506    0.123297    0.019161    0.642732    
#> 071: 0.382282    1.029800    3.482967    0.406130    0.117132    0.019130    0.649006    
#> 072: 0.372456    1.022980    3.483377    0.417958    0.111276    0.022305    0.632840    
#> 073: 0.393755    1.046881    3.486613    0.452000    0.108373    0.024014    0.617984    
#> 074: 0.380053    1.034044    3.475358    0.459614    0.115789    0.022813    0.627958    
#> 075: 0.412729    1.002931    3.505259    0.436633    0.123234    0.022705    0.631680    
#> 076: 0.440340    1.030953    3.517354    0.414802    0.117072    0.023776    0.639065    
#> 077: 0.464421    0.995525    3.520314    0.406903    0.111219    0.022587    0.642855    
#> 078: 0.465232    0.987744    3.516112    0.401135    0.107629    0.021458    0.631367    
#> 079: 0.443466    1.018629    3.501058    0.401295    0.124582    0.021073    0.629967    
#> 080: 0.452086    1.012420    3.503868    0.432544    0.127019    0.027882    0.637529    
#> 081: 0.429866    1.036357    3.500362    0.450483    0.120668    0.026488    0.619058    
#> 082: 0.440227    1.013744    3.508989    0.427959    0.114635    0.025164    0.630011    
#> 083: 0.432437    1.034894    3.511575    0.406561    0.108903    0.023906    0.642927    
#> 084: 0.405433    1.027899    3.499740    0.386233    0.114657    0.022710    0.648078    
#> 085: 0.425529    1.037992    3.512667    0.366921    0.114471    0.021575    0.654832    
#> 086: 0.436139    1.046693    3.506639    0.359163    0.139481    0.020496    0.631411    
#> 087: 0.366996    1.041172    3.478691    0.408446    0.132507    0.019471    0.638999    
#> 088: 0.332195    1.041938    3.479917    0.409271    0.125882    0.018498    0.648370    
#> 089: 0.358115    1.049978    3.469041    0.413973    0.133186    0.017573    0.635863    
#> 090: 0.380306    1.030393    3.465088    0.414505    0.131922    0.016694    0.631507    
#> 091: 0.376214    1.029968    3.464130    0.419559    0.125326    0.015860    0.634937    
#> 092: 0.363153    1.051466    3.452576    0.491493    0.119059    0.018071    0.635154    
#> 093: 0.328984    1.052417    3.459381    0.466918    0.115329    0.019337    0.646283    
#> 094: 0.343825    1.078203    3.459181    0.443573    0.121440    0.018370    0.640571    
#> 095: 0.366534    1.057578    3.467696    0.421394    0.125838    0.017451    0.633262    
#> 096: 0.330148    1.065561    3.465170    0.400324    0.143468    0.016579    0.625060    
#> 097: 0.370930    1.059588    3.472766    0.380308    0.136294    0.015750    0.621609    
#> 098: 0.395498    1.068574    3.485950    0.361293    0.135269    0.015113    0.638027    
#> 099: 0.388101    1.031820    3.479813    0.394433    0.130815    0.015075    0.625416    
#> 100: 0.373540    1.053954    3.478887    0.374711    0.124275    0.014322    0.639557    
#> 101: 0.347867    1.044915    3.468782    0.355975    0.132338    0.013605    0.636771    
#> 102: 0.367319    1.057980    3.462627    0.338177    0.137675    0.012925    0.640625    
#> 103: 0.382645    1.041142    3.475628    0.323638    0.130791    0.012279    0.639890    
#> 104: 0.376091    1.035851    3.492176    0.315383    0.125166    0.012638    0.642776    
#> 105: 0.400395    1.020489    3.497916    0.309671    0.126958    0.012613    0.650301    
#> 106: 0.429436    1.013114    3.495317    0.371199    0.130802    0.013360    0.628206    
#> 107: 0.457184    1.020051    3.503766    0.352639    0.126602    0.018267    0.637762    
#> 108: 0.459328    0.993156    3.519577    0.362088    0.120272    0.017716    0.632948    
#> 109: 0.443725    1.009375    3.516050    0.394943    0.114259    0.016830    0.637356    
#> 110: 0.465338    1.009733    3.510068    0.375196    0.108546    0.015989    0.629836    
#> 111: 0.464819    1.010628    3.509465    0.356436    0.103118    0.018692    0.621915    
#> 112: 0.431345    1.007464    3.500452    0.365989    0.097962    0.022089    0.642605    
#> 113: 0.413464    1.042094    3.492251    0.387206    0.094492    0.020985    0.638139    
#> 114: 0.430862    1.017896    3.503512    0.367845    0.105107    0.020243    0.637239    
#> 115: 0.418767    1.012444    3.496963    0.349453    0.099851    0.019231    0.663970    
#> 116: 0.420329    1.023860    3.502001    0.343735    0.127429    0.018269    0.654892    
#> 117: 0.405304    1.062499    3.495069    0.351059    0.127252    0.017356    0.658782    
#> 118: 0.438725    1.031633    3.502310    0.378434    0.120889    0.019056    0.635214    
#> 119: 0.416188    1.052347    3.485108    0.397162    0.114845    0.022077    0.645904    
#> 120: 0.370807    1.029495    3.488968    0.377304    0.109102    0.022715    0.642508    
#> 121: 0.367080    1.056801    3.490156    0.358438    0.103647    0.021579    0.653510    
#> 122: 0.405109    1.029198    3.497562    0.359071    0.134581    0.020500    0.628998    
#> 123: 0.444981    1.047729    3.490808    0.396618    0.127852    0.019475    0.624090    
#> 124: 0.424652    1.068219    3.489677    0.376787    0.121459    0.020665    0.630322    
#> 125: 0.436541    1.068883    3.491342    0.362349    0.115386    0.019857    0.628449    
#> 126: 0.405631    1.076219    3.469987    0.344232    0.109617    0.018864    0.649743    
#> 127: 0.405904    1.043256    3.480766    0.384806    0.104136    0.018398    0.623587    
#> 128: 0.382792    1.045757    3.487914    0.365566    0.112207    0.020120    0.627421    
#> 129: 0.401930    1.036529    3.484387    0.385984    0.106597    0.019114    0.623994    
#> 130: 0.438251    1.026758    3.486532    0.416445    0.110562    0.018158    0.619398    
#> 131: 0.416110    1.029665    3.483195    0.423261    0.125745    0.018851    0.627775    
#> 132: 0.376889    1.056727    3.469316    0.402098    0.137008    0.017908    0.644224    
#> 133: 0.392847    1.040534    3.486188    0.410146    0.130157    0.019764    0.615996    
#> 134: 0.410691    1.017070    3.509825    0.422280    0.131957    0.023334    0.603688    
#> 135: 0.419141    1.009321    3.508950    0.401166    0.125359    0.023421    0.627853    
#> 136: 0.442529    1.006172    3.508636    0.402839    0.119091    0.022250    0.617614    
#> 137: 0.470075    1.007901    3.505136    0.395050    0.113136    0.021138    0.635959    
#> 138: 0.448017    1.014263    3.508734    0.375297    0.111904    0.021334    0.630520    
#> 139: 0.437134    1.031197    3.508407    0.403065    0.106309    0.023978    0.644161    
#> 140: 0.439006    1.013988    3.514166    0.382912    0.112236    0.022779    0.644228    
#> 141: 0.427268    1.003296    3.508876    0.363767    0.122756    0.021640    0.645468    
#> 142: 0.457097    1.014016    3.522029    0.345578    0.119533    0.021158    0.645094    
#> 143: 0.422135    1.042716    3.501179    0.382051    0.115702    0.020100    0.647779    
#> 144: 0.462860    1.035112    3.514623    0.380312    0.109916    0.021164    0.636189    
#> 145: 0.409738    1.045682    3.488415    0.367886    0.114019    0.020106    0.619379    
#> 146: 0.391412    1.050019    3.481849    0.358059    0.108318    0.021014    0.636447    
#> 147: 0.349898    1.040025    3.472519    0.384485    0.110628    0.019964    0.616422    
#> 148: 0.366368    1.051256    3.481874    0.429894    0.112942    0.020249    0.627611    
#> 149: 0.397919    1.043118    3.478964    0.444650    0.113212    0.020045    0.615283    
#> 150: 0.412016    1.040806    3.477341    0.483939    0.117686    0.019042    0.628183    
#> 151: 0.393810    1.047170    3.484375    0.459742    0.111801    0.018090    0.620597    
#> 152: 0.376145    1.055516    3.488628    0.485102    0.111826    0.019153    0.616838    
#> 153: 0.404939    1.032757    3.506577    0.431385    0.102566    0.023816    0.632170    
#> 154: 0.442868    1.040643    3.499038    0.433192    0.098529    0.023939    0.626937    
#> 155: 0.377856    1.027507    3.484488    0.352485    0.119388    0.020212    0.630790    
#> 156: 0.392284    1.025811    3.495030    0.341667    0.121545    0.018306    0.635964    
#> 157: 0.403237    1.038224    3.501846    0.322335    0.124466    0.015445    0.649301    
#> 158: 0.438262    1.037150    3.498385    0.337402    0.136072    0.018048    0.627088    
#> 159: 0.387968    1.036001    3.505499    0.312723    0.134469    0.017593    0.643003    
#> 160: 0.430801    0.997389    3.521653    0.363233    0.123417    0.021146    0.637606    
#> 161: 0.441927    1.003597    3.520386    0.318834    0.103985    0.024211    0.652781    
#> 162: 0.429921    1.014958    3.503582    0.353378    0.108526    0.022717    0.660644    
#> 163: 0.468969    1.019108    3.500104    0.371646    0.122393    0.021288    0.642172    
#> 164: 0.449719    1.025615    3.501238    0.433345    0.115517    0.020523    0.631062    
#> 165: 0.441784    1.026904    3.505355    0.379865    0.114358    0.020645    0.637134    
#> 166: 0.434162    1.043735    3.502359    0.338113    0.101872    0.020126    0.653489    
#> 167: 0.443543    1.055167    3.515369    0.331337    0.110414    0.018465    0.667370    
#> 168: 0.482372    1.029348    3.507897    0.334269    0.121953    0.017267    0.645522    
#> 169: 0.467286    1.057394    3.507949    0.372344    0.125336    0.015251    0.651110    
#> 170: 0.465574    1.041074    3.505781    0.394346    0.127675    0.014608    0.631356    
#> 171: 0.423925    1.023199    3.498540    0.388177    0.118071    0.017587    0.619677    
#> 172: 0.386813    1.050225    3.488806    0.400376    0.120137    0.016212    0.623647    
#> 173: 0.410357    1.057032    3.481899    0.329574    0.118644    0.015523    0.628500    
#> 174: 0.402506    1.050052    3.494327    0.370680    0.115740    0.014785    0.632513    
#> 175: 0.422631    1.046154    3.485273    0.449811    0.107988    0.015389    0.625577    
#> 176: 0.394299    1.063761    3.486765    0.412027    0.119018    0.016395    0.614832    
#> 177: 0.430939    1.039954    3.489650    0.407967    0.104795    0.014717    0.639712    
#> 178: 0.425876    1.019970    3.484644    0.447051    0.111137    0.015853    0.623888    
#> 179: 0.438323    1.059184    3.481221    0.415091    0.122813    0.016388    0.646141    
#> 180: 0.390466    1.054686    3.481095    0.421459    0.110501    0.016654    0.634203    
#> 181: 0.402932    1.050955    3.472994    0.403130    0.110091    0.013206    0.641730    
#> 182: 0.369371    1.068530    3.464942    0.360853    0.111992    0.016296    0.640025    
#> 183: 0.363356    1.060164    3.463564    0.381137    0.129883    0.014725    0.648166    
#> 184: 0.352370    1.056797    3.464619    0.384969    0.123547    0.014295    0.642194    
#> 185: 0.371242    1.047345    3.475275    0.430759    0.124853    0.017607    0.641664    
#> 186: 0.352944    1.071358    3.473361    0.401452    0.109610    0.017425    0.634317    
#> 187: 0.397132    1.031870    3.494013    0.390725    0.118224    0.017409    0.622349    
#> 188: 0.376333    1.057541    3.486399    0.355969    0.123889    0.016101    0.630329    
#> 189: 0.386500    1.063499    3.489253    0.381593    0.106091    0.015986    0.647827    
#> 190: 0.383659    1.037238    3.490922    0.413001    0.103018    0.015211    0.632688    
#> 191: 0.358515    1.048504    3.472309    0.338787    0.107502    0.014371    0.619944    
#> 192: 0.377662    1.059205    3.476886    0.352648    0.111203    0.015693    0.606085    
#> 193: 0.397017    1.059002    3.490769    0.340500    0.108328    0.015731    0.612135    
#> 194: 0.387760    1.046039    3.478433    0.335475    0.118605    0.012959    0.617319    
#> 195: 0.382893    1.029344    3.484272    0.350877    0.115660    0.017114    0.614403    
#> 196: 0.353949    1.037566    3.491633    0.333324    0.112506    0.015773    0.626555    
#> 197: 0.358495    1.041994    3.502948    0.338825    0.122460    0.016299    0.662317    
#> 198: 0.408644    1.014016    3.496908    0.358353    0.115286    0.017566    0.631379    
#> 199: 0.400533    1.014885    3.496516    0.420009    0.121342    0.018550    0.635436    
#> 200: 0.418334    1.002992    3.503003    0.420192    0.124831    0.025173    0.641704    
#> 201: 0.419669    1.001727    3.508948    0.421019    0.119563    0.028345    0.629668    
#> 202: 0.407592    1.011881    3.502922    0.410079    0.109367    0.027651    0.631269    
#> 203: 0.412461    1.018834    3.499079    0.406965    0.107763    0.026756    0.634679    
#> 204: 0.413770    1.019833    3.496814    0.401545    0.102174    0.025613    0.637489    
#> 205: 0.414294    1.027428    3.496800    0.392987    0.098842    0.025524    0.641916    
#> 206: 0.413898    1.032100    3.497391    0.382233    0.099252    0.025788    0.641715    
#> 207: 0.416053    1.034026    3.496531    0.385432    0.100391    0.026007    0.638613    
#> 208: 0.418387    1.035047    3.496427    0.388478    0.100968    0.025943    0.636120    
#> 209: 0.420564    1.032996    3.496449    0.388110    0.101528    0.025824    0.634234    
#> 210: 0.422744    1.032112    3.496979    0.386552    0.100268    0.025463    0.633765    
#> 211: 0.425224    1.032387    3.498021    0.386309    0.101144    0.025350    0.633141    
#> 212: 0.426400    1.032119    3.498171    0.388546    0.102515    0.024845    0.632003    
#> 213: 0.429043    1.030022    3.499712    0.390092    0.103921    0.024398    0.633028    
#> 214: 0.430744    1.028796    3.500232    0.383909    0.106049    0.024002    0.633201    
#> 215: 0.431676    1.028640    3.501006    0.379898    0.107127    0.023715    0.633501    
#> 216: 0.433245    1.027030    3.501979    0.376736    0.108414    0.023577    0.634843    
#> 217: 0.433915    1.026771    3.502572    0.375298    0.108768    0.023180    0.634982    
#> 218: 0.433356    1.026811    3.502338    0.375595    0.109465    0.022947    0.634176    
#> 219: 0.430603    1.026585    3.501474    0.374012    0.109247    0.022748    0.633762    
#> 220: 0.428974    1.026976    3.501135    0.375339    0.109463    0.022770    0.632888    
#> 221: 0.427344    1.027354    3.500627    0.375224    0.109495    0.022750    0.632491    
#> 222: 0.427171    1.027295    3.500523    0.374806    0.109512    0.022852    0.632560    
#> 223: 0.428567    1.026796    3.500690    0.373792    0.109352    0.022873    0.632286    
#> 224: 0.430080    1.027876    3.500682    0.374301    0.109457    0.022822    0.632106    
#> 225: 0.429735    1.026528    3.500732    0.373779    0.108714    0.022785    0.632769    
#> 226: 0.429093    1.026291    3.500471    0.372498    0.108587    0.022644    0.632999    
#> 227: 0.428519    1.026206    3.500302    0.370760    0.108228    0.022480    0.633238    
#> 228: 0.427164    1.026769    3.499528    0.369363    0.108303    0.022321    0.632930    
#> 229: 0.425639    1.027008    3.499119    0.368602    0.108467    0.022098    0.632955    
#> 230: 0.425247    1.027401    3.498741    0.369757    0.108247    0.021929    0.632883    
#> 231: 0.424960    1.027983    3.498695    0.370844    0.108236    0.021790    0.632789    
#> 232: 0.423784    1.028404    3.498506    0.370502    0.108612    0.021633    0.632613    
#> 233: 0.421746    1.028172    3.498058    0.370076    0.108736    0.021474    0.632756    
#> 234: 0.420764    1.028428    3.497520    0.369510    0.108766    0.021417    0.632705    
#> 235: 0.419539    1.029354    3.496931    0.370157    0.108859    0.021312    0.632484    
#> 236: 0.418462    1.030256    3.496401    0.369803    0.109015    0.021303    0.632637    
#> 237: 0.417809    1.030741    3.495955    0.369697    0.108954    0.021233    0.633024    
#> 238: 0.418089    1.030706    3.495774    0.367849    0.108780    0.021205    0.633737    
#> 239: 0.416476    1.031412    3.495315    0.367501    0.108987    0.021209    0.633746    
#> 240: 0.416047    1.031214    3.495384    0.367161    0.108981    0.021145    0.633691    
#> 241: 0.415660    1.030535    3.495403    0.366607    0.109214    0.021112    0.633567    
#> 242: 0.415882    1.029760    3.495317    0.367276    0.109010    0.021079    0.633637    
#> 243: 0.415707    1.030041    3.495229    0.368694    0.109078    0.021038    0.633460    
#> 244: 0.415526    1.030070    3.495513    0.369783    0.109253    0.020965    0.633469    
#> 245: 0.415496    1.029294    3.495651    0.370197    0.109539    0.020883    0.633684    
#> 246: 0.415610    1.028862    3.495698    0.369819    0.109992    0.020744    0.633839    
#> 247: 0.415589    1.028606    3.495825    0.369689    0.110662    0.020634    0.634344    
#> 248: 0.415594    1.029119    3.495722    0.370276    0.110977    0.020529    0.634415    
#> 249: 0.414673    1.029523    3.495632    0.370740    0.111256    0.020448    0.634614    
#> 250: 0.415118    1.030005    3.495760    0.372294    0.111729    0.020410    0.634847    
#> 251: 0.415635    1.030642    3.495986    0.373388    0.111926    0.020355    0.634854    
#> 252: 0.416516    1.031041    3.496288    0.374095    0.111807    0.020327    0.634945    
#> 253: 0.416417    1.031199    3.496256    0.375075    0.111736    0.020365    0.635105    
#> 254: 0.416508    1.031612    3.496230    0.375898    0.111783    0.020364    0.634980    
#> 255: 0.416146    1.032037    3.496065    0.377092    0.111896    0.020398    0.635045    
#> 256: 0.415901    1.032396    3.495843    0.377899    0.111770    0.020425    0.635221    
#> 257: 0.415122    1.032318    3.495692    0.377880    0.111799    0.020433    0.635322    
#> 258: 0.414549    1.032263    3.495593    0.378544    0.111893    0.020361    0.635476    
#> 259: 0.414282    1.032287    3.495557    0.379352    0.111699    0.020308    0.635565    
#> 260: 0.414128    1.032528    3.495654    0.379638    0.111632    0.020288    0.635417    
#> 261: 0.414432    1.032366    3.495838    0.379582    0.111651    0.020260    0.635631    
#> 262: 0.414559    1.032375    3.495964    0.379252    0.111439    0.020195    0.635554    
#> 263: 0.414411    1.032535    3.495942    0.378792    0.111347    0.020172    0.635778    
#> 264: 0.414575    1.032923    3.495948    0.379190    0.111412    0.020154    0.636050    
#> 265: 0.414351    1.033000    3.496112    0.378367    0.111390    0.020126    0.636307    
#> 266: 0.414345    1.032712    3.496233    0.378015    0.111473    0.020091    0.636155    
#> 267: 0.414372    1.032620    3.496369    0.378196    0.111326    0.020080    0.636008    
#> 268: 0.414456    1.032262    3.496352    0.378165    0.111063    0.020101    0.635822    
#> 269: 0.414833    1.032328    3.496428    0.377834    0.111150    0.020118    0.635693    
#> 270: 0.414949    1.032548    3.496437    0.377302    0.111187    0.020148    0.635333    
#> 271: 0.414992    1.032630    3.496410    0.378101    0.111346    0.020183    0.635407    
#> 272: 0.415293    1.032493    3.496386    0.378609    0.111240    0.020226    0.635405    
#> 273: 0.415170    1.032511    3.496371    0.378599    0.111132    0.020206    0.635486    
#> 274: 0.415033    1.032581    3.496508    0.378637    0.111144    0.020180    0.635434    
#> 275: 0.414791    1.032604    3.496434    0.378076    0.110895    0.020164    0.635362    
#> 276: 0.414509    1.032701    3.496494    0.378196    0.110898    0.020179    0.635039    
#> 277: 0.414379    1.032900    3.496621    0.378726    0.110935    0.020192    0.635108    
#> 278: 0.414401    1.032855    3.496743    0.378960    0.110772    0.020162    0.635099    
#> 279: 0.414329    1.032639    3.496767    0.380142    0.110716    0.020123    0.635300    
#> 280: 0.413978    1.032623    3.496698    0.380486    0.110845    0.020059    0.635158    
#> 281: 0.413186    1.032764    3.496508    0.380755    0.110813    0.019986    0.635056    
#> 282: 0.412981    1.033144    3.496510    0.380602    0.111019    0.019922    0.635227    
#> 283: 0.412728    1.033169    3.496458    0.381121    0.111378    0.019859    0.635831    
#> 284: 0.412468    1.033008    3.496399    0.380841    0.111622    0.019810    0.636005    
#> 285: 0.412195    1.033082    3.496254    0.380911    0.111768    0.019739    0.636167    
#> 286: 0.411601    1.033235    3.495951    0.381105    0.112129    0.019717    0.636097    
#> 287: 0.410919    1.033613    3.495541    0.380767    0.112297    0.019731    0.636263    
#> 288: 0.410678    1.033727    3.495296    0.380540    0.112478    0.019696    0.636301    
#> 289: 0.410618    1.033937    3.495232    0.379960    0.112507    0.019703    0.636275    
#> 290: 0.410706    1.034107    3.495147    0.379677    0.112566    0.019666    0.636305    
#> 291: 0.410783    1.034339    3.495189    0.379271    0.112627    0.019599    0.636259    
#> 292: 0.410609    1.034419    3.495096    0.379213    0.112647    0.019578    0.636172    
#> 293: 0.410218    1.034438    3.494943    0.379072    0.112443    0.019539    0.636208    
#> 294: 0.409643    1.034593    3.494737    0.379303    0.112442    0.019508    0.636175    
#> 295: 0.409293    1.034364    3.494534    0.378825    0.112438    0.019484    0.636019    
#> 296: 0.408959    1.034452    3.494311    0.378375    0.112365    0.019466    0.636033    
#> 297: 0.408585    1.034775    3.494109    0.378363    0.112372    0.019467    0.636086    
#> 298: 0.408184    1.035009    3.493862    0.378943    0.112402    0.019482    0.635992    
#> 299: 0.407628    1.035188    3.493525    0.378850    0.112439    0.019464    0.635888    
#> 300: 0.407424    1.035262    3.493408    0.378852    0.112418    0.019416    0.635731    
#> 301: 0.407231    1.035182    3.493228    0.379044    0.112281    0.019388    0.635651    
#> 302: 0.407155    1.035180    3.493042    0.379942    0.112304    0.019369    0.635537    
#> 303: 0.407066    1.035319    3.492922    0.380644    0.112288    0.019402    0.635250    
#> 304: 0.406935    1.035562    3.492760    0.381560    0.112321    0.019458    0.634984    
#> 305: 0.406597    1.035510    3.492588    0.382044    0.112235    0.019478    0.634797    
#> 306: 0.406128    1.035537    3.492389    0.382331    0.112098    0.019490    0.634787    
#> 307: 0.405930    1.035517    3.492146    0.382266    0.112036    0.019465    0.634908    
#> 308: 0.405354    1.035565    3.491962    0.382097    0.111929    0.019453    0.635025    
#> 309: 0.404895    1.035468    3.491845    0.381743    0.111965    0.019444    0.635212    
#> 310: 0.404804    1.035352    3.491766    0.381602    0.111899    0.019443    0.635246    
#> 311: 0.404757    1.035441    3.491719    0.381696    0.111846    0.019423    0.635205    
#> 312: 0.404274    1.035529    3.491567    0.381412    0.111950    0.019372    0.635191    
#> 313: 0.403900    1.035321    3.491428    0.381212    0.111923    0.019347    0.635371    
#> 314: 0.403529    1.035450    3.491257    0.381383    0.111970    0.019318    0.635361    
#> 315: 0.403017    1.035659    3.491074    0.381819    0.112174    0.019268    0.635329    
#> 316: 0.403022    1.035817    3.490985    0.381940    0.112390    0.019235    0.635295    
#> 317: 0.403216    1.035740    3.491015    0.381969    0.112481    0.019190    0.635284    
#> 318: 0.403367    1.035847    3.491035    0.381847    0.112506    0.019155    0.635214    
#> 319: 0.403598    1.035877    3.491159    0.381660    0.112519    0.019168    0.635153    
#> 320: 0.403535    1.035732    3.491185    0.381476    0.112651    0.019175    0.635113    
#> 321: 0.403245    1.035850    3.491138    0.381061    0.112784    0.019147    0.635248    
#> 322: 0.403374    1.035890    3.491133    0.380491    0.112809    0.019109    0.635210    
#> 323: 0.403235    1.035803    3.491167    0.380049    0.112956    0.019092    0.635167    
#> 324: 0.403348    1.035747    3.491220    0.379752    0.112965    0.019059    0.635030    
#> 325: 0.403436    1.035786    3.491127    0.379589    0.112958    0.019026    0.634997    
#> 326: 0.403275    1.035743    3.490995    0.379569    0.112938    0.019003    0.634930    
#> 327: 0.403208    1.035838    3.490924    0.379400    0.112921    0.018984    0.634974    
#> 328: 0.403149    1.036052    3.490831    0.379862    0.112883    0.018968    0.634929    
#> 329: 0.403186    1.036085    3.490727    0.380290    0.113037    0.018925    0.634751    
#> 330: 0.402820    1.036120    3.490649    0.380991    0.113059    0.018899    0.634677    
#> 331: 0.402824    1.036377    3.490613    0.381178    0.113054    0.018906    0.634562    
#> 332: 0.402799    1.036527    3.490688    0.381310    0.113033    0.018916    0.634563    
#> 333: 0.402656    1.036509    3.490637    0.381668    0.112942    0.018906    0.634610    
#> 334: 0.402429    1.036509    3.490485    0.381607    0.112858    0.018897    0.634594    
#> 335: 0.402296    1.036436    3.490354    0.381088    0.112705    0.018911    0.634564    
#> 336: 0.401973    1.036570    3.490264    0.380753    0.112666    0.018929    0.634631    
#> 337: 0.401660    1.036866    3.490141    0.380677    0.112668    0.018942    0.634728    
#> 338: 0.401575    1.036952    3.490125    0.381040    0.112693    0.018917    0.634732    
#> 339: 0.401373    1.037050    3.490043    0.381233    0.112845    0.018883    0.634684    
#> 340: 0.401409    1.036968    3.489946    0.381954    0.113043    0.018857    0.634602    
#> 341: 0.401348    1.037019    3.489881    0.382484    0.113229    0.018829    0.634526    
#> 342: 0.401142    1.036949    3.489820    0.382735    0.113281    0.018803    0.634453    
#> 343: 0.400936    1.037039    3.489683    0.383176    0.113321    0.018778    0.634426    
#> 344: 0.400952    1.036998    3.489632    0.383628    0.113299    0.018789    0.634421    
#> 345: 0.400994    1.036940    3.489691    0.383738    0.113332    0.018760    0.634385    
#> 346: 0.400908    1.037013    3.489577    0.383973    0.113521    0.018707    0.634378    
#> 347: 0.400906    1.036931    3.489530    0.383923    0.113684    0.018679    0.634400    
#> 348: 0.400806    1.036901    3.489411    0.383961    0.113720    0.018656    0.634440    
#> 349: 0.400689    1.036863    3.489367    0.383762    0.113633    0.018665    0.634461    
#> 350: 0.400423    1.036788    3.489274    0.383659    0.113605    0.018668    0.634457    
#> 351: 0.400335    1.036990    3.489191    0.383881    0.113568    0.018668    0.634490    
#> 352: 0.400051    1.037219    3.489066    0.383976    0.113577    0.018696    0.634543    
#> 353: 0.399775    1.037522    3.488945    0.384216    0.113615    0.018682    0.634580    
#> 354: 0.399566    1.037676    3.488796    0.384083    0.113591    0.018680    0.634521    
#> 355: 0.399563    1.037688    3.488750    0.384237    0.113588    0.018689    0.634532    
#> 356: 0.399677    1.037663    3.488759    0.384182    0.113605    0.018680    0.634627    
#> 357: 0.399940    1.037611    3.488810    0.384437    0.113573    0.018681    0.634532    
#> 358: 0.399901    1.037612    3.488789    0.384456    0.113663    0.018685    0.634458    
#> 359: 0.399806    1.037639    3.488747    0.384088    0.113706    0.018666    0.634423    
#> 360: 0.399633    1.037735    3.488642    0.383661    0.113770    0.018646    0.634345    
#> 361: 0.399417    1.037772    3.488546    0.383750    0.113825    0.018624    0.634223    
#> 362: 0.399364    1.037780    3.488495    0.383973    0.113946    0.018609    0.634020    
#> 363: 0.399303    1.037724    3.488469    0.384218    0.114010    0.018585    0.633845    
#> 364: 0.399264    1.037719    3.488425    0.384289    0.114119    0.018570    0.633879    
#> 365: 0.399094    1.037645    3.488391    0.384195    0.114181    0.018565    0.633963    
#> 366: 0.398988    1.037672    3.488324    0.384155    0.114153    0.018577    0.634047    
#> 367: 0.398788    1.037735    3.488206    0.383959    0.114103    0.018546    0.634025    
#> 368: 0.398839    1.037810    3.488151    0.384043    0.113978    0.018547    0.633970    
#> 369: 0.398739    1.037868    3.488111    0.384124    0.113896    0.018526    0.634060    
#> 370: 0.398626    1.037982    3.488058    0.383917    0.113855    0.018539    0.634016    
#> 371: 0.398303    1.038083    3.487905    0.383468    0.113882    0.018520    0.633960    
#> 372: 0.397972    1.038215    3.487813    0.382934    0.114008    0.018502    0.634073    
#> 373: 0.397608    1.038453    3.487698    0.382521    0.113955    0.018478    0.634208    
#> 374: 0.397510    1.038512    3.487598    0.382269    0.113921    0.018467    0.634193    
#> 375: 0.397435    1.038602    3.487557    0.382323    0.113907    0.018464    0.634223    
#> 376: 0.397459    1.038676    3.487575    0.381964    0.113807    0.018462    0.634158    
#> 377: 0.397292    1.038767    3.487535    0.382020    0.113806    0.018441    0.634103    
#> 378: 0.396915    1.038866    3.487426    0.382043    0.113812    0.018452    0.634103    
#> 379: 0.396590    1.038914    3.487337    0.382263    0.113744    0.018434    0.634088    
#> 380: 0.396445    1.038882    3.487308    0.382178    0.113762    0.018408    0.634105    
#> 381: 0.396274    1.038935    3.487259    0.382311    0.113842    0.018384    0.634126    
#> 382: 0.396214    1.039056    3.487191    0.382348    0.113861    0.018357    0.634045    
#> 383: 0.396198    1.039098    3.487196    0.382418    0.113959    0.018342    0.634047    
#> 384: 0.396023    1.039033    3.487188    0.382438    0.113947    0.018348    0.634092    
#> 385: 0.395994    1.038980    3.487162    0.382552    0.113920    0.018364    0.634089    
#> 386: 0.396183    1.039071    3.487160    0.382635    0.113902    0.018375    0.634106    
#> 387: 0.396359    1.039171    3.487215    0.382761    0.113867    0.018382    0.634135    
#> 388: 0.396450    1.039203    3.487207    0.383110    0.113871    0.018383    0.634140    
#> 389: 0.396394    1.039165    3.487182    0.383224    0.113971    0.018377    0.634087    
#> 390: 0.396411    1.039215    3.487212    0.383369    0.113980    0.018372    0.634040    
#> 391: 0.396601    1.039167    3.487256    0.383438    0.113890    0.018385    0.634004    
#> 392: 0.396850    1.039135    3.487359    0.383283    0.113841    0.018397    0.633999    
#> 393: 0.396893    1.039032    3.487350    0.383270    0.113822    0.018413    0.633990    
#> 394: 0.396955    1.039044    3.487364    0.383519    0.113794    0.018419    0.633907    
#> 395: 0.397181    1.039102    3.487390    0.383664    0.113844    0.018430    0.633834    
#> 396: 0.397309    1.039057    3.487438    0.383767    0.113823    0.018435    0.633777    
#> 397: 0.397476    1.039016    3.487494    0.383989    0.113843    0.018453    0.633734    
#> 398: 0.397766    1.038886    3.487580    0.384110    0.113801    0.018469    0.633727    
#> 399: 0.398003    1.038829    3.487649    0.384259    0.113807    0.018477    0.633649    
#> 400: 0.398182    1.038790    3.487709    0.384166    0.113832    0.018460    0.633585    
#> 401: 0.398372    1.038791    3.487733    0.384168    0.113892    0.018440    0.633647    
#> 402: 0.398598    1.038920    3.487769    0.384187    0.114025    0.018415    0.633621    
#> 403: 0.398773    1.038918    3.487808    0.384317    0.114157    0.018385    0.633556    
#> 404: 0.398760    1.038919    3.487738    0.384555    0.114210    0.018362    0.633470    
#> 405: 0.398532    1.038909    3.487742    0.384387    0.114186    0.018348    0.633479    
#> 406: 0.398639    1.038803    3.487758    0.384746    0.114121    0.018342    0.633536    
#> 407: 0.398799    1.038671    3.487832    0.384878    0.114079    0.018341    0.633606    
#> 408: 0.399149    1.038594    3.487905    0.385116    0.114083    0.018337    0.633637    
#> 409: 0.399364    1.038451    3.487909    0.385476    0.114006    0.018340    0.633630    
#> 410: 0.399379    1.038422    3.487846    0.385923    0.113966    0.018335    0.633705    
#> 411: 0.399401    1.038230    3.487862    0.385964    0.113958    0.018342    0.633777    
#> 412: 0.399429    1.038301    3.487790    0.386073    0.113959    0.018339    0.633810    
#> 413: 0.399436    1.038394    3.487743    0.386348    0.113902    0.018348    0.633830    
#> 414: 0.399315    1.038410    3.487752    0.386277    0.113791    0.018358    0.633752    
#> 415: 0.399429    1.038438    3.487756    0.386065    0.113799    0.018359    0.633765    
#> 416: 0.399543    1.038449    3.487750    0.386100    0.113731    0.018374    0.633672    
#> 417: 0.399652    1.038453    3.487752    0.386124    0.113727    0.018378    0.633640    
#> 418: 0.399501    1.038498    3.487748    0.385942    0.113681    0.018393    0.633557    
#> 419: 0.399493    1.038573    3.487743    0.385566    0.113677    0.018392    0.633559    
#> 420: 0.399414    1.038603    3.487720    0.385477    0.113724    0.018389    0.633460    
#> 421: 0.399351    1.038651    3.487700    0.385289    0.113702    0.018385    0.633389    
#> 422: 0.399466    1.038646    3.487694    0.385148    0.113735    0.018373    0.633351    
#> 423: 0.399586    1.038532    3.487712    0.385163    0.113791    0.018373    0.633303    
#> 424: 0.399496    1.038492    3.487658    0.384840    0.113840    0.018347    0.633255    
#> 425: 0.399417    1.038496    3.487610    0.384615    0.113842    0.018325    0.633279    
#> 426: 0.399387    1.038586    3.487614    0.384329    0.113849    0.018313    0.633251    
#> 427: 0.399182    1.038575    3.487608    0.384359    0.113803    0.018294    0.633225    
#> 428: 0.399263    1.038610    3.487673    0.384368    0.113849    0.018286    0.633212    
#> 429: 0.399324    1.038657    3.487719    0.384526    0.113871    0.018276    0.633165    
#> 430: 0.399316    1.038662    3.487713    0.384453    0.113927    0.018265    0.633127    
#> 431: 0.399283    1.038613    3.487692    0.384415    0.114068    0.018236    0.633069    
#> 432: 0.399222    1.038628    3.487718    0.384545    0.114197    0.018218    0.633003    
#> 433: 0.399192    1.038740    3.487697    0.384564    0.114167    0.018212    0.633031    
#> 434: 0.399144    1.038704    3.487702    0.384540    0.114198    0.018201    0.633008    
#> 435: 0.399162    1.038715    3.487688    0.384527    0.114275    0.018198    0.633016    
#> 436: 0.399144    1.038704    3.487737    0.384609    0.114409    0.018180    0.633052    
#> 437: 0.399184    1.038560    3.487733    0.384580    0.114489    0.018154    0.633069    
#> 438: 0.399203    1.038618    3.487706    0.384511    0.114449    0.018151    0.633113    
#> 439: 0.399168    1.038761    3.487668    0.384263    0.114500    0.018149    0.633077    
#> 440: 0.399145    1.038772    3.487688    0.384097    0.114513    0.018138    0.633031    
#> 441: 0.399154    1.038710    3.487712    0.383874    0.114549    0.018139    0.632996    
#> 442: 0.399089    1.038716    3.487755    0.383694    0.114577    0.018148    0.632975    
#> 443: 0.399106    1.038729    3.487732    0.383351    0.114551    0.018143    0.632992    
#> 444: 0.399028    1.038825    3.487697    0.382952    0.114523    0.018131    0.633000    
#> 445: 0.398865    1.038862    3.487684    0.382690    0.114487    0.018126    0.633011    
#> 446: 0.398699    1.038906    3.487648    0.382482    0.114497    0.018114    0.632944    
#> 447: 0.398733    1.038987    3.487690    0.382270    0.114485    0.018121    0.632906    
#> 448: 0.398774    1.038970    3.487729    0.382100    0.114462    0.018138    0.632816    
#> 449: 0.398932    1.038997    3.487842    0.381947    0.114449    0.018153    0.632807    
#> 450: 0.398964    1.038976    3.487869    0.381869    0.114486    0.018160    0.632848    
#> 451: 0.399067    1.038960    3.487873    0.381701    0.114528    0.018150    0.632882    
#> 452: 0.399160    1.039008    3.487900    0.381613    0.114514    0.018141    0.632892    
#> 453: 0.399175    1.039014    3.487881    0.381484    0.114485    0.018128    0.632835    
#> 454: 0.399107    1.039132    3.487854    0.381603    0.114438    0.018120    0.632822    
#> 455: 0.399121    1.039196    3.487814    0.381767    0.114390    0.018115    0.632802    
#> 456: 0.399012    1.039196    3.487775    0.381850    0.114409    0.018112    0.632820    
#> 457: 0.398916    1.039157    3.487750    0.381927    0.114486    0.018103    0.632802    
#> 458: 0.398801    1.039293    3.487738    0.382004    0.114520    0.018098    0.632818    
#> 459: 0.398649    1.039414    3.487706    0.381799    0.114541    0.018087    0.632851    
#> 460: 0.398567    1.039526    3.487648    0.381711    0.114605    0.018080    0.632856    
#> 461: 0.398531    1.039581    3.487659    0.381525    0.114667    0.018072    0.632831    
#> 462: 0.398450    1.039647    3.487641    0.381391    0.114691    0.018060    0.632766    
#> 463: 0.398449    1.039768    3.487674    0.381237    0.114716    0.018051    0.632743    
#> 464: 0.398503    1.039795    3.487707    0.381020    0.114681    0.018054    0.632667    
#> 465: 0.398616    1.039674    3.487745    0.380839    0.114633    0.018042    0.632675    
#> 466: 0.398761    1.039689    3.487756    0.380781    0.114658    0.018044    0.632625    
#> 467: 0.398728    1.039644    3.487818    0.380842    0.114685    0.018049    0.632520    
#> 468: 0.398834    1.039674    3.487883    0.381103    0.114599    0.018056    0.632539    
#> 469: 0.398967    1.039714    3.487942    0.381130    0.114563    0.018072    0.632532    
#> 470: 0.398958    1.039702    3.487958    0.381194    0.114491    0.018085    0.632515    
#> 471: 0.398991    1.039687    3.487959    0.381389    0.114485    0.018097    0.632474    
#> 472: 0.399054    1.039640    3.487956    0.381444    0.114461    0.018091    0.632430    
#> 473: 0.399008    1.039635    3.487954    0.381416    0.114481    0.018094    0.632392    
#> 474: 0.399065    1.039579    3.487995    0.381385    0.114513    0.018107    0.632408    
#> 475: 0.399190    1.039630    3.488029    0.381308    0.114582    0.018113    0.632443    
#> 476: 0.399227    1.039570    3.488064    0.381295    0.114580    0.018119    0.632506    
#> 477: 0.399315    1.039544    3.488133    0.381278    0.114535    0.018126    0.632487    
#> 478: 0.399356    1.039581    3.488169    0.381273    0.114543    0.018129    0.632574    
#> 479: 0.399527    1.039585    3.488221    0.381370    0.114543    0.018129    0.632650    
#> 480: 0.399576    1.039599    3.488250    0.381372    0.114599    0.018125    0.632684    
#> 481: 0.399567    1.039538    3.488263    0.381328    0.114615    0.018134    0.632684    
#> 482: 0.399678    1.039523    3.488237    0.381522    0.114641    0.018133    0.632682    
#> 483: 0.399561    1.039468    3.488224    0.381495    0.114764    0.018130    0.632629    
#> 484: 0.399660    1.039326    3.488246    0.381432    0.114823    0.018129    0.632573    
#> 485: 0.399597    1.039312    3.488255    0.381419    0.114832    0.018125    0.632573    
#> 486: 0.399627    1.039322    3.488274    0.381406    0.114822    0.018123    0.632489    
#> 487: 0.399863    1.039319    3.488341    0.381585    0.114865    0.018125    0.632461    
#> 488: 0.399981    1.039268    3.488388    0.381768    0.114882    0.018123    0.632410    
#> 489: 0.400171    1.039204    3.488385    0.381825    0.114901    0.018129    0.632437    
#> 490: 0.400316    1.039155    3.488467    0.381823    0.114893    0.018139    0.632465    
#> 491: 0.400425    1.039131    3.488551    0.381755    0.114856    0.018139    0.632463    
#> 492: 0.400462    1.039158    3.488601    0.381748    0.114845    0.018152    0.632533    
#> 493: 0.400539    1.039117    3.488625    0.381716    0.114830    0.018150    0.632548    
#> 494: 0.400773    1.039107    3.488646    0.381800    0.114820    0.018149    0.632510    
#> 495: 0.400881    1.039081    3.488679    0.381629    0.114824    0.018152    0.632501    
#> 496: 0.400920    1.039157    3.488664    0.381533    0.114775    0.018151    0.632532    
#> 497: 0.400845    1.039178    3.488665    0.381490    0.114747    0.018148    0.632578    
#> 498: 0.400789    1.039175    3.488660    0.381436    0.114742    0.018137    0.632524    
#> 499: 0.400761    1.039217    3.488619    0.381456    0.114784    0.018115    0.632473    
#> 500: 0.400754    1.039179    3.488607    0.381313    0.114813    0.018093    0.632458    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.317986    0.979129    3.445311    0.392401    0.080285    0.016800    1.728546    
#> 002: 0.474491    1.102234    3.455717    0.372781    0.076271    0.015960    1.134441    
#> 003: 0.680770    1.044800    3.479677    0.354142    0.072457    0.015162    0.835715    
#> 004: 0.710783    1.097131    3.492651    0.336435    0.068835    0.014404    0.748576    
#> 005: 0.783614    1.088051    3.494612    0.364316    0.065393    0.013684    0.717929    
#> 006: 0.739095    1.108933    3.486996    0.432910    0.062123    0.013000    0.660073    
#> 007: 0.696723    1.119410    3.476911    0.437698    0.059017    0.015035    0.674536    
#> 008: 0.673953    1.099146    3.472386    0.417043    0.056066    0.017697    0.692297    
#> 009: 0.652822    1.105864    3.466728    0.425106    0.053263    0.016812    0.675258    
#> 010: 0.678966    1.095450    3.470466    0.421502    0.050600    0.015972    0.694290    
#> 011: 0.727421    1.102142    3.477206    0.402274    0.048070    0.016335    0.696872    
#> 012: 0.749899    1.079714    3.479654    0.382160    0.045666    0.017488    0.685100    
#> 013: 0.687910    1.081196    3.472119    0.363052    0.043383    0.016614    0.679018    
#> 014: 0.716745    1.093639    3.482072    0.367434    0.041214    0.015783    0.680223    
#> 015: 0.744428    1.102412    3.498887    0.375409    0.039153    0.014994    0.666474    
#> 016: 0.699167    1.115946    3.493047    0.356639    0.037195    0.014244    0.687350    
#> 017: 0.727919    1.096330    3.488830    0.446998    0.035336    0.015387    0.663582    
#> 018: 0.744227    1.106385    3.482134    0.454420    0.034578    0.015152    0.671876    
#> 019: 0.718968    1.097953    3.482341    0.442424    0.032849    0.017871    0.648774    
#> 020: 0.760046    1.102040    3.484292    0.421600    0.031207    0.019329    0.671633    
#> 021: 0.759294    1.095951    3.499680    0.436365    0.029646    0.020551    0.653121    
#> 022: 0.744725    1.093156    3.504660    0.441952    0.031982    0.019524    0.648932    
#> 023: 0.833171    1.096505    3.509879    0.482713    0.030382    0.019799    0.674391    
#> 024: 0.830784    1.106750    3.509312    0.485065    0.028863    0.023404    0.670989    
#> 025: 0.808912    1.080708    3.497975    0.471065    0.027420    0.022234    0.671285    
#> 026: 0.776645    1.114073    3.494292    0.448424    0.034310    0.021122    0.683872    
#> 027: 0.751705    1.118789    3.487006    0.426003    0.034251    0.020066    0.682898    
#> 028: 0.796032    1.093026    3.501010    0.451172    0.033830    0.019063    0.670023    
#> 029: 0.810052    1.098119    3.496523    0.452523    0.032138    0.018110    0.670133    
#> 030: 0.816788    1.104482    3.502492    0.480912    0.030805    0.020194    0.675974    
#> 031: 0.742689    1.081780    3.504983    0.456866    0.029876    0.019693    0.651141    
#> 032: 0.754769    1.093832    3.500365    0.477554    0.032095    0.019397    0.641726    
#> 033: 0.733239    1.116078    3.486904    0.462340    0.032060    0.018427    0.661658    
#> 034: 0.757950    1.117341    3.481448    0.466740    0.030457    0.021563    0.651151    
#> 035: 0.717254    1.093465    3.479277    0.443403    0.028935    0.020485    0.638218    
#> 036: 0.728979    1.099542    3.479448    0.454200    0.030200    0.019734    0.655293    
#> 037: 0.731514    1.113175    3.488044    0.480906    0.030990    0.020973    0.657309    
#> 038: 0.803547    1.096249    3.488892    0.567373    0.034130    0.023457    0.653485    
#> 039: 0.758266    1.088023    3.495818    0.539004    0.032423    0.023594    0.665426    
#> 040: 0.766975    1.081729    3.508031    0.512054    0.030802    0.024374    0.665482    
#> 041: 0.747635    1.078096    3.496401    0.486451    0.029262    0.023155    0.670901    
#> 042: 0.784808    1.067571    3.495751    0.462129    0.027799    0.021998    0.653307    
#> 043: 0.750067    1.088194    3.495171    0.439022    0.026409    0.021390    0.657926    
#> 044: 0.702970    1.092143    3.487251    0.446418    0.025088    0.020321    0.671383    
#> 045: 0.744683    1.099711    3.475183    0.500422    0.025002    0.019948    0.651992    
#> 046: 0.739442    1.095751    3.488470    0.503342    0.023752    0.022732    0.665931    
#> 047: 0.774631    1.092027    3.482066    0.499485    0.030811    0.023480    0.664140    
#> 048: 0.751642    1.087205    3.482413    0.541414    0.033963    0.024113    0.665843    
#> 049: 0.739627    1.083519    3.493889    0.514344    0.032265    0.022977    0.675781    
#> 050: 0.766851    1.072109    3.495554    0.488626    0.030652    0.022097    0.678758    
#> 051: 0.809125    1.096782    3.485020    0.620408    0.029119    0.027187    0.685475    
#> 052: 0.824330    1.098875    3.500030    0.616846    0.032990    0.025828    0.663004    
#> 053: 0.778468    1.099922    3.489704    0.586004    0.034142    0.024536    0.659199    
#> 054: 0.745135    1.096088    3.493993    0.556704    0.044651    0.023309    0.673818    
#> 055: 0.748275    1.093417    3.492538    0.528869    0.042419    0.022144    0.671353    
#> 056: 0.757090    1.083300    3.487791    0.502425    0.040298    0.021037    0.682090    
#> 057: 0.746164    1.081418    3.494058    0.522290    0.038283    0.021580    0.678438    
#> 058: 0.739466    1.105942    3.479742    0.506943    0.036369    0.020501    0.676027    
#> 059: 0.759766    1.078823    3.484775    0.534289    0.034550    0.020794    0.679582    
#> 060: 0.722504    1.082035    3.486321    0.548265    0.040608    0.023039    0.659426    
#> 061: 0.806418    1.089831    3.500202    0.599036    0.038577    0.022060    0.671996    
#> 062: 0.756644    1.110334    3.490584    0.569084    0.048188    0.020957    0.674739    
#> 063: 0.782352    1.086544    3.492392    0.540630    0.045778    0.020517    0.693326    
#> 064: 0.779047    1.112851    3.500739    0.513598    0.043489    0.024675    0.669044    
#> 065: 0.780049    1.102773    3.478430    0.487918    0.041315    0.023441    0.673122    
#> 066: 0.758369    1.117986    3.481099    0.463522    0.039249    0.024365    0.679828    
#> 067: 0.731431    1.109387    3.481023    0.440346    0.037287    0.028918    0.677522    
#> 068: 0.711779    1.094895    3.499602    0.418329    0.035422    0.027472    0.681731    
#> 069: 0.765961    1.112193    3.498780    0.439537    0.033651    0.026098    0.673198    
#> 070: 0.742807    1.116455    3.488135    0.505448    0.034823    0.024793    0.673165    
#> 071: 0.734642    1.130187    3.468046    0.508294    0.037908    0.025268    0.672516    
#> 072: 0.694424    1.096551    3.475276    0.482879    0.036013    0.024004    0.664980    
#> 073: 0.760517    1.099316    3.494583    0.501617    0.034212    0.026728    0.672235    
#> 074: 0.727259    1.096683    3.478827    0.476536    0.032502    0.025392    0.673342    
#> 075: 0.741945    1.087028    3.494758    0.531767    0.030877    0.024122    0.673751    
#> 076: 0.761144    1.102126    3.494319    0.505178    0.029333    0.022916    0.661743    
#> 077: 0.808526    1.095916    3.495799    0.519027    0.027866    0.021770    0.664976    
#> 078: 0.802909    1.094577    3.508305    0.538261    0.026473    0.022622    0.663287    
#> 079: 0.793825    1.104088    3.495125    0.564327    0.025149    0.021491    0.682677    
#> 080: 0.790296    1.098712    3.497800    0.582536    0.027069    0.020416    0.679733    
#> 081: 0.781567    1.090694    3.494539    0.571136    0.025715    0.020688    0.665699    
#> 082: 0.773246    1.069963    3.504451    0.552268    0.024429    0.021771    0.686131    
#> 083: 0.789910    1.082927    3.503554    0.533112    0.023208    0.022663    0.685027    
#> 084: 0.791733    1.099859    3.492348    0.573023    0.022057    0.024367    0.684544    
#> 085: 0.763843    1.101914    3.507450    0.544372    0.024423    0.025252    0.673646    
#> 086: 0.743543    1.104117    3.493745    0.517153    0.023202    0.023990    0.675365    
#> 087: 0.749798    1.102217    3.491259    0.491295    0.026631    0.022790    0.663271    
#> 088: 0.701703    1.088248    3.494459    0.466731    0.027720    0.023383    0.675207    
#> 089: 0.749036    1.082721    3.490195    0.443394    0.026334    0.024986    0.677778    
#> 090: 0.742025    1.080837    3.488776    0.470638    0.025060    0.024133    0.677314    
#> 091: 0.730011    1.093063    3.466527    0.509570    0.025767    0.025618    0.686368    
#> 092: 0.719935    1.123719    3.464951    0.489761    0.024478    0.024885    0.675552    
#> 093: 0.647299    1.119419    3.458515    0.470063    0.023254    0.027238    0.690104    
#> 094: 0.720061    1.118231    3.468051    0.486694    0.022092    0.029678    0.683631    
#> 095: 0.739405    1.120430    3.490006    0.531181    0.025983    0.031834    0.666785    
#> 096: 0.747775    1.114519    3.483635    0.570283    0.025521    0.031084    0.664485    
#> 097: 0.776742    1.109515    3.477033    0.576920    0.024244    0.029530    0.655572    
#> 098: 0.771143    1.106321    3.480935    0.548074    0.023032    0.028053    0.657382    
#> 099: 0.716520    1.097213    3.470938    0.520670    0.025101    0.026651    0.659578    
#> 100: 0.712837    1.097977    3.476020    0.508899    0.026746    0.025318    0.668834    
#> 101: 0.714055    1.083651    3.472711    0.495256    0.025409    0.024052    0.663631    
#> 102: 0.699603    1.076997    3.479626    0.470493    0.024138    0.024340    0.678524    
#> 103: 0.743953    1.082988    3.490121    0.477685    0.022931    0.023123    0.673301    
#> 104: 0.745100    1.098950    3.497275    0.530341    0.024126    0.026806    0.669104    
#> 105: 0.765422    1.103646    3.494442    0.503824    0.023768    0.027133    0.681199    
#> 106: 0.811460    1.101398    3.500055    0.493466    0.022579    0.027733    0.677258    
#> 107: 0.814864    1.110628    3.514377    0.570189    0.021450    0.026346    0.694143    
#> 108: 0.794851    1.109125    3.509323    0.541680    0.020378    0.025670    0.690807    
#> 109: 0.749326    1.106239    3.501315    0.514596    0.019359    0.024387    0.699822    
#> 110: 0.791455    1.109034    3.492328    0.517229    0.018391    0.026062    0.687889    
#> 111: 0.782892    1.109901    3.496934    0.491367    0.020724    0.026693    0.668658    
#> 112: 0.724133    1.097112    3.477472    0.479578    0.020458    0.025649    0.659218    
#> 113: 0.744247    1.108720    3.485286    0.492857    0.021946    0.027068    0.641375    
#> 114: 0.751716    1.116684    3.486768    0.513006    0.028148    0.026251    0.655832    
#> 115: 0.750085    1.082517    3.487310    0.492430    0.026741    0.025281    0.685600    
#> 116: 0.754970    1.098098    3.486593    0.585377    0.025404    0.028786    0.687572    
#> 117: 0.681190    1.131677    3.482803    0.556108    0.025335    0.029367    0.680764    
#> 118: 0.731080    1.130314    3.477464    0.553991    0.024869    0.027898    0.677449    
#> 119: 0.775437    1.107190    3.489518    0.618349    0.027334    0.026504    0.676357    
#> 120: 0.740063    1.111195    3.482859    0.587432    0.030959    0.025178    0.673400    
#> 121: 0.731338    1.132010    3.483163    0.558060    0.037407    0.023919    0.672832    
#> 122: 0.732212    1.109081    3.483776    0.530157    0.035536    0.022723    0.670411    
#> 123: 0.762413    1.125382    3.479194    0.521597    0.037895    0.021587    0.686280    
#> 124: 0.752690    1.139044    3.481915    0.549988    0.038275    0.020508    0.686320    
#> 125: 0.748058    1.129496    3.479812    0.522489    0.038847    0.022624    0.690514    
#> 126: 0.775330    1.120041    3.483428    0.582328    0.036904    0.025092    0.699634    
#> 127: 0.788275    1.101476    3.484465    0.553211    0.035059    0.023837    0.700869    
#> 128: 0.795830    1.108978    3.496091    0.597615    0.033306    0.022645    0.701373    
#> 129: 0.751760    1.128672    3.497017    0.567735    0.036373    0.021513    0.695320    
#> 130: 0.785779    1.120338    3.498749    0.539348    0.034555    0.020438    0.685263    
#> 131: 0.745287    1.120066    3.482850    0.512381    0.042921    0.021589    0.668555    
#> 132: 0.712496    1.113284    3.483391    0.486762    0.040775    0.022009    0.661002    
#> 133: 0.720419    1.091533    3.487478    0.462423    0.038737    0.021139    0.680339    
#> 134: 0.740819    1.067523    3.505141    0.439302    0.036800    0.020978    0.668813    
#> 135: 0.719670    1.077269    3.499480    0.417337    0.034960    0.020011    0.680436    
#> 136: 0.745536    1.066621    3.507053    0.396470    0.040619    0.019010    0.680642    
#> 137: 0.797587    1.079198    3.501375    0.380099    0.038588    0.019870    0.692511    
#> 138: 0.755460    1.092679    3.495297    0.379446    0.036658    0.018876    0.689457    
#> 139: 0.776052    1.108797    3.497411    0.404227    0.037384    0.017932    0.687621    
#> 140: 0.752298    1.106913    3.497407    0.421909    0.035515    0.017182    0.685763    
#> 141: 0.745231    1.089162    3.493066    0.459556    0.033739    0.016964    0.677395    
#> 142: 0.748723    1.070607    3.501374    0.459081    0.032052    0.018239    0.690274    
#> 143: 0.735427    1.083281    3.495609    0.436127    0.030450    0.023768    0.680364    
#> 144: 0.796511    1.090988    3.500888    0.477523    0.028927    0.022666    0.655736    
#> 145: 0.711135    1.099925    3.489580    0.488088    0.027481    0.022273    0.660467    
#> 146: 0.748260    1.098590    3.495912    0.537785    0.026107    0.023196    0.661570    
#> 147: 0.693472    1.101770    3.474543    0.510896    0.024802    0.022036    0.652429    
#> 148: 0.718061    1.111374    3.487328    0.485351    0.026250    0.020934    0.657017    
#> 149: 0.736300    1.097930    3.489749    0.461083    0.024938    0.020974    0.688183    
#> 150: 0.759718    1.095832    3.485836    0.441455    0.023691    0.022321    0.694922    
#> 151: 0.716867    1.110192    3.482252    0.460118    0.022853    0.024170    0.676734    
#> 152: 0.731940    1.115705    3.480170    0.434374    0.023689    0.023831    0.676942    
#> 153: 0.714674    1.128249    3.482470    0.458426    0.025448    0.020339    0.682234    
#> 154: 0.768616    1.114014    3.491663    0.460569    0.020875    0.017844    0.693289    
#> 155: 0.739088    1.094353    3.485253    0.514764    0.021433    0.018227    0.678782    
#> 156: 0.713328    1.106474    3.493618    0.421710    0.019830    0.023040    0.681731    
#> 157: 0.762805    1.084881    3.502415    0.441812    0.027645    0.024183    0.672140    
#> 158: 0.779091    1.110073    3.491711    0.443568    0.024665    0.021857    0.652091    
#> 159: 0.737363    1.107670    3.497961    0.374581    0.021561    0.023138    0.668762    
#> 160: 0.808597    1.088916    3.506362    0.466061    0.026647    0.022903    0.664001    
#> 161: 0.779425    1.086410    3.503348    0.489354    0.031999    0.021360    0.672135    
#> 162: 0.722090    1.103298    3.496271    0.468083    0.032855    0.020044    0.685187    
#> 163: 0.737976    1.088971    3.483195    0.425287    0.032986    0.017332    0.676900    
#> 164: 0.792305    1.090884    3.497790    0.357334    0.028696    0.015110    0.680845    
#> 165: 0.779200    1.088159    3.505504    0.421889    0.027073    0.019803    0.674729    
#> 166: 0.787220    1.108115    3.497878    0.443686    0.027864    0.021453    0.664208    
#> 167: 0.787125    1.115073    3.502083    0.461608    0.023386    0.025151    0.684207    
#> 168: 0.787533    1.119557    3.494623    0.487801    0.027595    0.023903    0.655316    
#> 169: 0.753849    1.137979    3.481225    0.495613    0.022790    0.022636    0.664594    
#> 170: 0.755812    1.103231    3.490257    0.479628    0.025194    0.022399    0.651284    
#> 171: 0.751517    1.107053    3.488272    0.474527    0.020602    0.020916    0.653248    
#> 172: 0.690544    1.123907    3.478868    0.458823    0.023437    0.019627    0.664761    
#> 173: 0.663710    1.139935    3.453425    0.448249    0.023873    0.021130    0.671019    
#> 174: 0.696280    1.138820    3.463441    0.463834    0.022455    0.022175    0.687814    
#> 175: 0.714525    1.133431    3.468629    0.440480    0.023920    0.018416    0.689803    
#> 176: 0.709645    1.148505    3.483530    0.452371    0.019850    0.016563    0.682407    
#> 177: 0.751457    1.140139    3.493423    0.499923    0.017899    0.015638    0.689141    
#> 178: 0.752369    1.109226    3.496371    0.380290    0.019063    0.015370    0.688351    
#> 179: 0.800917    1.120241    3.490079    0.488016    0.025586    0.020282    0.682260    
#> 180: 0.745646    1.107826    3.494164    0.403674    0.024752    0.023503    0.684098    
#> 181: 0.732421    1.096972    3.470333    0.430337    0.032335    0.020699    0.672215    
#> 182: 0.714358    1.101616    3.466958    0.457340    0.033149    0.020210    0.668331    
#> 183: 0.699738    1.123632    3.467272    0.428117    0.027931    0.022779    0.676397    
#> 184: 0.727029    1.114519    3.480889    0.498298    0.029154    0.020275    0.653635    
#> 185: 0.690704    1.135081    3.475961    0.402675    0.027710    0.017603    0.680423    
#> 186: 0.694436    1.136288    3.481920    0.390992    0.034085    0.016941    0.710009    
#> 187: 0.725337    1.102364    3.486043    0.418855    0.036234    0.016855    0.686600    
#> 188: 0.738768    1.108155    3.500116    0.457837    0.032363    0.019270    0.692815    
#> 189: 0.803765    1.099159    3.510998    0.449537    0.039159    0.018773    0.692271    
#> 190: 0.764853    1.105015    3.505536    0.389642    0.030749    0.020463    0.662202    
#> 191: 0.755409    1.117904    3.496261    0.425240    0.030892    0.019081    0.659861    
#> 192: 0.708809    1.106668    3.494956    0.421794    0.023410    0.020875    0.682014    
#> 193: 0.775072    1.115097    3.494270    0.495824    0.020279    0.021687    0.672948    
#> 194: 0.761080    1.111405    3.485954    0.456555    0.026965    0.022967    0.679865    
#> 195: 0.702469    1.117849    3.480029    0.465689    0.032170    0.020219    0.661982    
#> 196: 0.767277    1.108741    3.497180    0.528651    0.036403    0.020625    0.657231    
#> 197: 0.722100    1.110562    3.501432    0.454980    0.029207    0.021564    0.663174    
#> 198: 0.835067    1.082814    3.504182    0.540213    0.019737    0.024281    0.662076    
#> 199: 0.773956    1.082179    3.496871    0.481443    0.020401    0.025045    0.667620    
#> 200: 0.773575    1.089730    3.505772    0.491086    0.020414    0.026070    0.690414    
#> 201: 0.753843    1.083713    3.505501    0.450048    0.019110    0.027131    0.686021    
#> 202: 0.740656    1.083235    3.502146    0.456463    0.019035    0.027088    0.683708    
#> 203: 0.760584    1.086079    3.499199    0.471388    0.018972    0.026358    0.679551    
#> 204: 0.765001    1.083532    3.501327    0.475400    0.019043    0.026950    0.677909    
#> 205: 0.768610    1.086678    3.500224    0.486254    0.019702    0.027499    0.678871    
#> 206: 0.775428    1.089785    3.499863    0.514546    0.019518    0.027417    0.679991    
#> 207: 0.774690    1.090118    3.498817    0.508946    0.019056    0.027020    0.680344    
#> 208: 0.771614    1.091038    3.497909    0.494585    0.018658    0.026124    0.680044    
#> 209: 0.773953    1.090279    3.497372    0.497462    0.018618    0.025517    0.678693    
#> 210: 0.776856    1.090148    3.498099    0.497775    0.018782    0.024890    0.676370    
#> 211: 0.781838    1.090716    3.499271    0.500854    0.018972    0.024618    0.675086    
#> 212: 0.782570    1.090731    3.499971    0.496130    0.018883    0.024517    0.674728    
#> 213: 0.782166    1.089199    3.500184    0.494882    0.018729    0.024653    0.674699    
#> 214: 0.781795    1.088468    3.500190    0.498304    0.018566    0.024755    0.674641    
#> 215: 0.780832    1.088289    3.499816    0.497085    0.018254    0.025098    0.675768    
#> 216: 0.784342    1.087343    3.499906    0.500526    0.018302    0.025158    0.676912    
#> 217: 0.784963    1.087846    3.500209    0.503792    0.018230    0.025020    0.676499    
#> 218: 0.786156    1.088989    3.500093    0.503694    0.018518    0.024966    0.676321    
#> 219: 0.786350    1.089231    3.499398    0.501857    0.018838    0.024713    0.676891    
#> 220: 0.781887    1.089642    3.498506    0.497994    0.019146    0.024623    0.677381    
#> 221: 0.779141    1.089650    3.498020    0.492234    0.019454    0.024541    0.676921    
#> 222: 0.777544    1.089881    3.497386    0.494239    0.019602    0.024477    0.676039    
#> 223: 0.776826    1.090009    3.497018    0.496061    0.019613    0.024617    0.675354    
#> 224: 0.777062    1.090456    3.496835    0.498679    0.019741    0.024642    0.674923    
#> 225: 0.775803    1.090076    3.496526    0.501022    0.019847    0.024600    0.675035    
#> 226: 0.776226    1.089116    3.496565    0.505558    0.019751    0.024597    0.674859    
#> 227: 0.776447    1.088753    3.496615    0.507333    0.019863    0.024642    0.674196    
#> 228: 0.775028    1.089431    3.496264    0.506327    0.020086    0.024562    0.674186    
#> 229: 0.773410    1.089572    3.496067    0.505439    0.020180    0.024490    0.674127    
#> 230: 0.772857    1.089360    3.496209    0.502408    0.020359    0.024468    0.674043    
#> 231: 0.772783    1.089223    3.496612    0.499245    0.020444    0.024426    0.673724    
#> 232: 0.771487    1.088800    3.496651    0.498005    0.020436    0.024269    0.673770    
#> 233: 0.771421    1.088053    3.496859    0.499588    0.020385    0.024176    0.673616    
#> 234: 0.771329    1.087936    3.496810    0.497615    0.020500    0.024088    0.673480    
#> 235: 0.770912    1.087702    3.496449    0.497627    0.020424    0.024136    0.673146    
#> 236: 0.769733    1.087954    3.495952    0.496370    0.020346    0.024139    0.673170    
#> 237: 0.770889    1.087952    3.495825    0.496944    0.020327    0.024095    0.673634    
#> 238: 0.771903    1.087913    3.496136    0.498546    0.020503    0.024095    0.673907    
#> 239: 0.772960    1.088546    3.496113    0.501138    0.020634    0.024091    0.674000    
#> 240: 0.772989    1.088816    3.496218    0.502074    0.020787    0.024110    0.674083    
#> 241: 0.773784    1.088675    3.496284    0.503368    0.020864    0.024077    0.674269    
#> 242: 0.772687    1.088951    3.495960    0.502839    0.021086    0.024104    0.674426    
#> 243: 0.771975    1.089409    3.495941    0.502132    0.021265    0.024180    0.674729    
#> 244: 0.771749    1.089297    3.496229    0.501558    0.021388    0.024242    0.674908    
#> 245: 0.771638    1.088912    3.496340    0.500290    0.021406    0.024098    0.675481    
#> 246: 0.771826    1.089020    3.496269    0.500030    0.021365    0.024076    0.675569    
#> 247: 0.772181    1.088896    3.496281    0.502025    0.021388    0.024090    0.675261    
#> 248: 0.772262    1.088945    3.496298    0.503385    0.021414    0.024073    0.674789    
#> 249: 0.771746    1.089052    3.496185    0.503198    0.021404    0.024035    0.674777    
#> 250: 0.772111    1.089395    3.496238    0.504227    0.021493    0.024106    0.674616    
#> 251: 0.772126    1.089749    3.496490    0.504589    0.021507    0.024138    0.674577    
#> 252: 0.773128    1.089993    3.496935    0.506223    0.021540    0.024143    0.674482    
#> 253: 0.773134    1.090113    3.496940    0.506053    0.021628    0.024179    0.674333    
#> 254: 0.773074    1.090747    3.496944    0.505803    0.021669    0.024200    0.674201    
#> 255: 0.772343    1.091207    3.496829    0.504960    0.021628    0.024234    0.674328    
#> 256: 0.772304    1.091282    3.496579    0.505269    0.021613    0.024221    0.674236    
#> 257: 0.771881    1.091308    3.496454    0.504231    0.021691    0.024196    0.674146    
#> 258: 0.771280    1.091022    3.496405    0.503769    0.021631    0.024132    0.674292    
#> 259: 0.770938    1.090664    3.496519    0.502405    0.021660    0.024068    0.674684    
#> 260: 0.770908    1.090769    3.496582    0.501323    0.021753    0.023991    0.674652    
#> 261: 0.771046    1.090508    3.496753    0.501227    0.021867    0.023903    0.674561    
#> 262: 0.770911    1.090359    3.496844    0.501603    0.021920    0.023824    0.674593    
#> 263: 0.770534    1.090418    3.496911    0.501331    0.021905    0.023786    0.674404    
#> 264: 0.770437    1.090384    3.496854    0.501728    0.021909    0.023809    0.674234    
#> 265: 0.770847    1.090331    3.496787    0.502351    0.021865    0.023861    0.674145    
#> 266: 0.771165    1.090580    3.496676    0.503056    0.021849    0.023852    0.674213    
#> 267: 0.771225    1.090833    3.496736    0.504244    0.021848    0.023903    0.674168    
#> 268: 0.771653    1.090578    3.496853    0.504326    0.021866    0.023962    0.674181    
#> 269: 0.772312    1.090286    3.497061    0.504238    0.021878    0.023967    0.673957    
#> 270: 0.772957    1.090211    3.497062    0.504952    0.021887    0.023974    0.673682    
#> 271: 0.773212    1.090116    3.497224    0.504973    0.021929    0.024001    0.673613    
#> 272: 0.773705    1.090007    3.497459    0.503950    0.021996    0.023968    0.673909    
#> 273: 0.773716    1.090369    3.497380    0.503347    0.022065    0.023963    0.674231    
#> 274: 0.773074    1.090632    3.497284    0.501919    0.022045    0.023871    0.674206    
#> 275: 0.772552    1.090782    3.497151    0.500945    0.022093    0.023782    0.674123    
#> 276: 0.772369    1.090943    3.497200    0.500621    0.022202    0.023679    0.674042    
#> 277: 0.772336    1.091092    3.497327    0.500442    0.022198    0.023662    0.674011    
#> 278: 0.773041    1.091109    3.497542    0.500591    0.022214    0.023652    0.673880    
#> 279: 0.773366    1.091095    3.497641    0.501010    0.022276    0.023630    0.673964    
#> 280: 0.773514    1.091251    3.497646    0.501339    0.022263    0.023590    0.673914    
#> 281: 0.773441    1.091368    3.497716    0.501816    0.022254    0.023571    0.673807    
#> 282: 0.774143    1.091602    3.497688    0.503392    0.022257    0.023590    0.673747    
#> 283: 0.773871    1.091748    3.497696    0.503530    0.022305    0.023638    0.673925    
#> 284: 0.773556    1.091708    3.497569    0.503162    0.022334    0.023634    0.673792    
#> 285: 0.773020    1.091708    3.497280    0.503163    0.022333    0.023642    0.673834    
#> 286: 0.772870    1.091875    3.497023    0.503395    0.022414    0.023668    0.673721    
#> 287: 0.772068    1.092127    3.496681    0.503151    0.022479    0.023642    0.673753    
#> 288: 0.771930    1.092158    3.496576    0.503416    0.022563    0.023638    0.674077    
#> 289: 0.772493    1.092200    3.496487    0.504449    0.022619    0.023639    0.674428    
#> 290: 0.772625    1.092275    3.496532    0.505401    0.022597    0.023659    0.674877    
#> 291: 0.773209    1.092497    3.496733    0.506543    0.022574    0.023654    0.674883    
#> 292: 0.773222    1.092687    3.496623    0.506933    0.022584    0.023594    0.674848    
#> 293: 0.773209    1.092847    3.496475    0.507787    0.022574    0.023600    0.674962    
#> 294: 0.773097    1.093091    3.496284    0.508960    0.022627    0.023623    0.675084    
#> 295: 0.773002    1.093056    3.496091    0.509920    0.022664    0.023626    0.674995    
#> 296: 0.772348    1.092963    3.496017    0.509492    0.022640    0.023627    0.675094    
#> 297: 0.771945    1.093038    3.495914    0.509345    0.022636    0.023636    0.675128    
#> 298: 0.772188    1.092891    3.495972    0.508758    0.022621    0.023644    0.675027    
#> 299: 0.772288    1.092983    3.495934    0.508297    0.022599    0.023635    0.674881    
#> 300: 0.772806    1.092965    3.496056    0.508643    0.022598    0.023660    0.674718    
#> 301: 0.773160    1.092787    3.496123    0.507824    0.022590    0.023647    0.674724    
#> 302: 0.773374    1.092644    3.496094    0.507353    0.022613    0.023641    0.674630    
#> 303: 0.773532    1.092621    3.496007    0.507241    0.022580    0.023646    0.674617    
#> 304: 0.773636    1.092693    3.495895    0.507566    0.022561    0.023644    0.674669    
#> 305: 0.773445    1.092497    3.495812    0.507492    0.022523    0.023660    0.674748    
#> 306: 0.772930    1.092395    3.495700    0.507269    0.022529    0.023689    0.674773    
#> 307: 0.772207    1.092278    3.495504    0.506550    0.022533    0.023713    0.674904    
#> 308: 0.771585    1.092272    3.495371    0.506382    0.022562    0.023729    0.675093    
#> 309: 0.771265    1.092248    3.495276    0.506626    0.022562    0.023711    0.675262    
#> 310: 0.771158    1.092274    3.495074    0.506585    0.022633    0.023638    0.675231    
#> 311: 0.770754    1.092307    3.494980    0.506556    0.022671    0.023609    0.675256    
#> 312: 0.770615    1.092356    3.494849    0.507620    0.022715    0.023589    0.675258    
#> 313: 0.770552    1.092229    3.494745    0.507903    0.022766    0.023576    0.675232    
#> 314: 0.770106    1.092261    3.494636    0.507782    0.022774    0.023562    0.675238    
#> 315: 0.769492    1.092394    3.494483    0.507659    0.022771    0.023547    0.675138    
#> 316: 0.769136    1.092500    3.494368    0.507617    0.022763    0.023527    0.675025    
#> 317: 0.768964    1.092621    3.494396    0.506873    0.022809    0.023540    0.675107    
#> 318: 0.768793    1.092789    3.494334    0.506881    0.022813    0.023580    0.674921    
#> 319: 0.768525    1.092827    3.494321    0.506647    0.022836    0.023615    0.674888    
#> 320: 0.768109    1.092872    3.494264    0.506613    0.022835    0.023640    0.674971    
#> 321: 0.768065    1.092987    3.494189    0.506862    0.022849    0.023639    0.675026    
#> 322: 0.768023    1.093079    3.494079    0.506810    0.022853    0.023604    0.675086    
#> 323: 0.767519    1.093189    3.493967    0.506522    0.022830    0.023580    0.675154    
#> 324: 0.767108    1.093320    3.493944    0.506143    0.022798    0.023577    0.675178    
#> 325: 0.767038    1.093550    3.493929    0.506113    0.022813    0.023599    0.675081    
#> 326: 0.767059    1.093475    3.493930    0.505916    0.022859    0.023607    0.674999    
#> 327: 0.767180    1.093457    3.493951    0.506274    0.022891    0.023626    0.674888    
#> 328: 0.767343    1.093510    3.493945    0.506260    0.022916    0.023622    0.674711    
#> 329: 0.767208    1.093600    3.493962    0.506463    0.022910    0.023627    0.674566    
#> 330: 0.767109    1.093636    3.493993    0.506215    0.022937    0.023634    0.674548    
#> 331: 0.767136    1.093903    3.494019    0.506112    0.022980    0.023610    0.674601    
#> 332: 0.767021    1.093955    3.493990    0.506056    0.022962    0.023639    0.674512    
#> 333: 0.766823    1.093942    3.493926    0.505852    0.022937    0.023649    0.674460    
#> 334: 0.766549    1.093848    3.493745    0.506038    0.022870    0.023664    0.674397    
#> 335: 0.766343    1.093941    3.493591    0.506528    0.022855    0.023642    0.674302    
#> 336: 0.765930    1.094193    3.493484    0.506652    0.022827    0.023651    0.674291    
#> 337: 0.765555    1.094439    3.493306    0.506785    0.022794    0.023671    0.674285    
#> 338: 0.765276    1.094625    3.493196    0.506674    0.022786    0.023665    0.674244    
#> 339: 0.764789    1.094775    3.493046    0.506044    0.022795    0.023669    0.674189    
#> 340: 0.764369    1.094800    3.493017    0.505363    0.022870    0.023643    0.674098    
#> 341: 0.764038    1.094813    3.492991    0.504567    0.022918    0.023595    0.674198    
#> 342: 0.763802    1.094829    3.492975    0.503984    0.022973    0.023587    0.674134    
#> 343: 0.763431    1.094864    3.492927    0.503549    0.023003    0.023583    0.674132    
#> 344: 0.763356    1.094803    3.492926    0.503508    0.023019    0.023580    0.674166    
#> 345: 0.763075    1.094841    3.492892    0.502959    0.023080    0.023559    0.674206    
#> 346: 0.762827    1.094915    3.492796    0.502643    0.023076    0.023536    0.674194    
#> 347: 0.762638    1.094871    3.492735    0.502427    0.023105    0.023521    0.674202    
#> 348: 0.762520    1.094956    3.492730    0.502040    0.023152    0.023510    0.674191    
#> 349: 0.762440    1.094971    3.492700    0.502133    0.023156    0.023535    0.674086    
#> 350: 0.762099    1.094957    3.492618    0.502244    0.023134    0.023554    0.673996    
#> 351: 0.762152    1.095067    3.492591    0.502087    0.023136    0.023547    0.673988    
#> 352: 0.761853    1.095149    3.492598    0.501617    0.023152    0.023519    0.674164    
#> 353: 0.761779    1.095285    3.492607    0.501234    0.023193    0.023491    0.674232    
#> 354: 0.761863    1.095349    3.492539    0.501023    0.023228    0.023472    0.674168    
#> 355: 0.762123    1.095300    3.492552    0.500637    0.023262    0.023453    0.674210    
#> 356: 0.762264    1.095227    3.492629    0.500097    0.023326    0.023454    0.674412    
#> 357: 0.762376    1.095388    3.492670    0.500113    0.023370    0.023463    0.674510    
#> 358: 0.762502    1.095490    3.492690    0.499877    0.023368    0.023476    0.674563    
#> 359: 0.762394    1.095630    3.492613    0.499666    0.023384    0.023481    0.674500    
#> 360: 0.762140    1.095726    3.492522    0.499600    0.023398    0.023466    0.674381    
#> 361: 0.761813    1.095831    3.492416    0.499049    0.023408    0.023444    0.674274    
#> 362: 0.761834    1.095880    3.492402    0.498641    0.023415    0.023422    0.674219    
#> 363: 0.761803    1.095863    3.492391    0.498778    0.023384    0.023435    0.674103    
#> 364: 0.761810    1.095872    3.492331    0.499309    0.023345    0.023462    0.674072    
#> 365: 0.761704    1.095796    3.492285    0.499608    0.023290    0.023465    0.674239    
#> 366: 0.761696    1.095763    3.492159    0.499881    0.023241    0.023481    0.674369    
#> 367: 0.761600    1.095795    3.492079    0.500029    0.023209    0.023466    0.674309    
#> 368: 0.761366    1.095890    3.491962    0.500296    0.023199    0.023470    0.674220    
#> 369: 0.761056    1.095939    3.491859    0.500885    0.023218    0.023466    0.674288    
#> 370: 0.760879    1.096088    3.491809    0.500908    0.023244    0.023450    0.674371    
#> 371: 0.760865    1.096174    3.491672    0.501155    0.023249    0.023425    0.674341    
#> 372: 0.760705    1.096271    3.491592    0.501411    0.023230    0.023416    0.674287    
#> 373: 0.760192    1.096451    3.491448    0.501234    0.023255    0.023414    0.674316    
#> 374: 0.759983    1.096459    3.491414    0.501128    0.023255    0.023421    0.674278    
#> 375: 0.759679    1.096419    3.491388    0.500783    0.023249    0.023412    0.674331    
#> 376: 0.759633    1.096429    3.491380    0.500560    0.023252    0.023398    0.674330    
#> 377: 0.759705    1.096541    3.491383    0.500442    0.023263    0.023403    0.674382    
#> 378: 0.759772    1.096533    3.491321    0.500553    0.023285    0.023404    0.674355    
#> 379: 0.759773    1.096411    3.491344    0.500426    0.023324    0.023402    0.674357    
#> 380: 0.759591    1.096388    3.491275    0.500556    0.023370    0.023382    0.674246    
#> 381: 0.759224    1.096328    3.491221    0.500552    0.023412    0.023338    0.674235    
#> 382: 0.759010    1.096269    3.491166    0.500388    0.023449    0.023324    0.674147    
#> 383: 0.759036    1.096194    3.491155    0.500394    0.023480    0.023299    0.674059    
#> 384: 0.758800    1.096218    3.491170    0.500129    0.023479    0.023290    0.674115    
#> 385: 0.758702    1.096223    3.491192    0.499775    0.023483    0.023294    0.674046    
#> 386: 0.758807    1.096305    3.491261    0.499540    0.023508    0.023302    0.674050    
#> 387: 0.759022    1.096315    3.491343    0.499422    0.023545    0.023296    0.673987    
#> 388: 0.759173    1.096300    3.491392    0.499715    0.023540    0.023299    0.673912    
#> 389: 0.759191    1.096112    3.491411    0.500060    0.023534    0.023286    0.673906    
#> 390: 0.759134    1.096083    3.491397    0.499883    0.023542    0.023267    0.673914    
#> 391: 0.759256    1.096049    3.491380    0.499881    0.023540    0.023264    0.673928    
#> 392: 0.759441    1.096002    3.491473    0.500121    0.023543    0.023296    0.673938    
#> 393: 0.759509    1.096003    3.491445    0.500332    0.023539    0.023300    0.673902    
#> 394: 0.759533    1.096006    3.491399    0.500121    0.023515    0.023313    0.673935    
#> 395: 0.759832    1.096053    3.491429    0.500186    0.023510    0.023307    0.673956    
#> 396: 0.759968    1.096144    3.491421    0.500482    0.023502    0.023316    0.673990    
#> 397: 0.759997    1.096202    3.491418    0.500639    0.023500    0.023302    0.674009    
#> 398: 0.760112    1.096162    3.491515    0.500546    0.023507    0.023291    0.674038    
#> 399: 0.760173    1.096150    3.491556    0.500652    0.023520    0.023286    0.673967    
#> 400: 0.760163    1.096232    3.491531    0.500985    0.023546    0.023282    0.673950    
#> 401: 0.760221    1.096333    3.491489    0.501261    0.023566    0.023283    0.674054    
#> 402: 0.760306    1.096375    3.491495    0.501587    0.023566    0.023303    0.674114    
#> 403: 0.760438    1.096393    3.491449    0.501917    0.023576    0.023328    0.674134    
#> 404: 0.760477    1.096497    3.491377    0.502010    0.023592    0.023339    0.674116    
#> 405: 0.760595    1.096553    3.491404    0.502453    0.023601    0.023354    0.674152    
#> 406: 0.760609    1.096628    3.491323    0.502472    0.023605    0.023343    0.674246    
#> 407: 0.760471    1.096774    3.491287    0.502438    0.023587    0.023322    0.674280    
#> 408: 0.760620    1.096914    3.491287    0.502149    0.023534    0.023320    0.674429    
#> 409: 0.760498    1.097018    3.491288    0.501647    0.023525    0.023318    0.674453    
#> 410: 0.760304    1.097072    3.491213    0.501544    0.023544    0.023300    0.674467    
#> 411: 0.760291    1.096995    3.491189    0.501534    0.023574    0.023279    0.674473    
#> 412: 0.760186    1.096994    3.491138    0.501168    0.023596    0.023264    0.674444    
#> 413: 0.759937    1.096977    3.491094    0.500719    0.023622    0.023250    0.674419    
#> 414: 0.759776    1.096970    3.491020    0.500799    0.023615    0.023249    0.674341    
#> 415: 0.759739    1.096986    3.490970    0.500728    0.023591    0.023245    0.674283    
#> 416: 0.759674    1.097052    3.490975    0.500480    0.023590    0.023254    0.674233    
#> 417: 0.759672    1.097028    3.490959    0.500612    0.023602    0.023259    0.674180    
#> 418: 0.759356    1.097097    3.490962    0.500472    0.023636    0.023258    0.674152    
#> 419: 0.759325    1.097194    3.490918    0.500699    0.023648    0.023265    0.674090    
#> 420: 0.759364    1.097207    3.490920    0.500696    0.023632    0.023268    0.674114    
#> 421: 0.759279    1.097246    3.490978    0.500461    0.023633    0.023273    0.674095    
#> 422: 0.759388    1.097170    3.491037    0.500591    0.023653    0.023279    0.674035    
#> 423: 0.759554    1.097132    3.491072    0.500398    0.023672    0.023257    0.673947    
#> 424: 0.759508    1.097096    3.491056    0.500498    0.023686    0.023253    0.673852    
#> 425: 0.759501    1.097106    3.491040    0.500815    0.023731    0.023255    0.673906    
#> 426: 0.759457    1.097228    3.490972    0.500942    0.023727    0.023246    0.673867    
#> 427: 0.759394    1.097223    3.490963    0.501011    0.023709    0.023242    0.673795    
#> 428: 0.759196    1.097221    3.490983    0.500823    0.023677    0.023244    0.673923    
#> 429: 0.759102    1.097248    3.490992    0.500634    0.023671    0.023231    0.673940    
#> 430: 0.758964    1.097284    3.490971    0.500255    0.023651    0.023223    0.673937    
#> 431: 0.758870    1.097313    3.490953    0.499985    0.023629    0.023207    0.673889    
#> 432: 0.758784    1.097380    3.490918    0.500056    0.023642    0.023195    0.673913    
#> 433: 0.758837    1.097487    3.490919    0.500214    0.023661    0.023186    0.673948    
#> 434: 0.758798    1.097457    3.490923    0.500358    0.023655    0.023179    0.673926    
#> 435: 0.758840    1.097469    3.490928    0.500494    0.023662    0.023177    0.673855    
#> 436: 0.758845    1.097462    3.490945    0.500369    0.023677    0.023181    0.673823    
#> 437: 0.759007    1.097464    3.491006    0.500315    0.023693    0.023183    0.673857    
#> 438: 0.759059    1.097619    3.491012    0.500244    0.023728    0.023176    0.673792    
#> 439: 0.759207    1.097642    3.491011    0.500266    0.023722    0.023169    0.673671    
#> 440: 0.759101    1.097670    3.491035    0.499961    0.023740    0.023155    0.673667    
#> 441: 0.759061    1.097672    3.491048    0.499881    0.023747    0.023161    0.673635    
#> 442: 0.759014    1.097749    3.491056    0.499816    0.023756    0.023153    0.673580    
#> 443: 0.759154    1.097857    3.491022    0.500222    0.023744    0.023172    0.673579    
#> 444: 0.759293    1.097915    3.490954    0.500634    0.023747    0.023198    0.673554    
#> 445: 0.759442    1.097943    3.490937    0.501004    0.023773    0.023222    0.673535    
#> 446: 0.759388    1.097936    3.490932    0.501125    0.023793    0.023237    0.673540    
#> 447: 0.759513    1.097903    3.490959    0.501167    0.023787    0.023248    0.673550    
#> 448: 0.759476    1.097910    3.490994    0.500969    0.023789    0.023274    0.673592    
#> 449: 0.759543    1.097978    3.491087    0.500560    0.023793    0.023277    0.673593    
#> 450: 0.759552    1.098001    3.491130    0.500344    0.023795    0.023276    0.673586    
#> 451: 0.759698    1.098011    3.491125    0.500556    0.023800    0.023269    0.673598    
#> 452: 0.759636    1.098001    3.491107    0.500453    0.023819    0.023260    0.673553    
#> 453: 0.759621    1.098043    3.491103    0.500434    0.023838    0.023252    0.673457    
#> 454: 0.759553    1.098170    3.491076    0.500428    0.023842    0.023247    0.673421    
#> 455: 0.759514    1.098232    3.491061    0.500574    0.023832    0.023235    0.673371    
#> 456: 0.759413    1.098191    3.491057    0.500590    0.023813    0.023229    0.673400    
#> 457: 0.759432    1.098173    3.491085    0.500697    0.023800    0.023218    0.673398    
#> 458: 0.759456    1.098202    3.491119    0.500824    0.023815    0.023214    0.673407    
#> 459: 0.759290    1.098240    3.491091    0.500885    0.023814    0.023213    0.673440    
#> 460: 0.759030    1.098270    3.490999    0.500641    0.023806    0.023206    0.673424    
#> 461: 0.758807    1.098343    3.490968    0.500376    0.023802    0.023201    0.673422    
#> 462: 0.758681    1.098464    3.490980    0.500267    0.023801    0.023207    0.673447    
#> 463: 0.758627    1.098557    3.491025    0.499862    0.023801    0.023218    0.673492    
#> 464: 0.758833    1.098595    3.491033    0.499654    0.023794    0.023229    0.673546    
#> 465: 0.758895    1.098538    3.491048    0.499479    0.023773    0.023233    0.673481    
#> 466: 0.758907    1.098549    3.491001    0.499378    0.023751    0.023225    0.673447    
#> 467: 0.758718    1.098598    3.491015    0.499004    0.023746    0.023234    0.673390    
#> 468: 0.758938    1.098591    3.491074    0.499099    0.023749    0.023217    0.673429    
#> 469: 0.759134    1.098639    3.491152    0.499461    0.023741    0.023212    0.673579    
#> 470: 0.759365    1.098656    3.491183    0.499877    0.023747    0.023216    0.673634    
#> 471: 0.759397    1.098623    3.491188    0.499936    0.023733    0.023219    0.673675    
#> 472: 0.759393    1.098598    3.491204    0.499894    0.023734    0.023220    0.673755    
#> 473: 0.759388    1.098624    3.491219    0.499651    0.023708    0.023222    0.673782    
#> 474: 0.759349    1.098620    3.491200    0.499591    0.023692    0.023212    0.673795    
#> 475: 0.759386    1.098658    3.491215    0.499604    0.023675    0.023207    0.673751    
#> 476: 0.759591    1.098603    3.491222    0.499821    0.023670    0.023195    0.673774    
#> 477: 0.759445    1.098588    3.491240    0.499528    0.023667    0.023192    0.673740    
#> 478: 0.759389    1.098556    3.491262    0.499372    0.023640    0.023180    0.673806    
#> 479: 0.759356    1.098571    3.491279    0.499194    0.023626    0.023189    0.673844    
#> 480: 0.759340    1.098561    3.491284    0.498906    0.023638    0.023189    0.673858    
#> 481: 0.759281    1.098547    3.491281    0.498601    0.023660    0.023178    0.673809    
#> 482: 0.759352    1.098512    3.491268    0.498647    0.023686    0.023167    0.673815    
#> 483: 0.759374    1.098493    3.491319    0.498693    0.023710    0.023165    0.673776    
#> 484: 0.759396    1.098388    3.491350    0.498609    0.023714    0.023160    0.673833    
#> 485: 0.759583    1.098361    3.491423    0.498624    0.023716    0.023161    0.673811    
#> 486: 0.759601    1.098368    3.491497    0.498446    0.023716    0.023164    0.673787    
#> 487: 0.759854    1.098343    3.491608    0.498448    0.023721    0.023172    0.673832    
#> 488: 0.759875    1.098260    3.491668    0.498580    0.023717    0.023186    0.673874    
#> 489: 0.760022    1.098209    3.491688    0.498638    0.023715    0.023186    0.673917    
#> 490: 0.760226    1.098239    3.491752    0.498859    0.023728    0.023180    0.673924    
#> 491: 0.760352    1.098274    3.491797    0.498853    0.023740    0.023180    0.673907    
#> 492: 0.760353    1.098342    3.491772    0.498870    0.023762    0.023182    0.673931    
#> 493: 0.760289    1.098365    3.491789    0.498637    0.023788    0.023177    0.673956    
#> 494: 0.760216    1.098423    3.491763    0.498366    0.023822    0.023157    0.673925    
#> 495: 0.760271    1.098511    3.491760    0.498293    0.023840    0.023150    0.673855    
#> 496: 0.760361    1.098596    3.491716    0.498192    0.023852    0.023137    0.673813    
#> 497: 0.760361    1.098626    3.491687    0.498456    0.023873    0.023134    0.673768    
#> 498: 0.760322    1.098654    3.491653    0.498304    0.023899    0.023114    0.673740    
#> 499: 0.760232    1.098720    3.491611    0.498211    0.023920    0.023103    0.673693    
#> 500: 0.760228    1.098709    3.491573    0.498061    0.023930    0.023092    0.673638    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.329069    0.970605    3.445320    0.392401    0.073447    0.016800    1.731979    
#> 002: 0.445161    0.996207    3.450039    0.372781    0.069774    0.015960    1.181566    
#> 003: 0.628627    0.928412    3.446932    0.354142    0.066286    0.015162    0.942036    
#> 004: 0.594041    0.952758    3.462188    0.336435    0.062971    0.014404    0.850163    
#> 005: 0.676753    0.950120    3.466238    0.319613    0.074782    0.013684    0.801869    
#> 006: 0.662771    0.947914    3.447158    0.349371    0.085636    0.013000    0.730547    
#> 007: 0.608629    0.955114    3.450452    0.331903    0.081354    0.012350    0.744589    
#> 008: 0.592046    0.941160    3.447019    0.376844    0.077286    0.012535    0.746959    
#> 009: 0.577524    0.934165    3.434891    0.388852    0.081970    0.012486    0.740311    
#> 010: 0.571398    0.936733    3.436873    0.369410    0.079400    0.011862    0.753176    
#> 011: 0.692911    0.949964    3.455998    0.350939    0.075430    0.011269    0.751274    
#> 012: 0.699366    0.941732    3.455326    0.359558    0.076857    0.010705    0.736117    
#> 013: 0.607654    0.943994    3.446598    0.367533    0.074639    0.011245    0.739284    
#> 014: 0.649087    0.954992    3.450634    0.349157    0.104838    0.010683    0.756457    
#> 015: 0.667490    0.957439    3.465477    0.331699    0.103387    0.010149    0.722934    
#> 016: 0.626958    0.961096    3.470023    0.341893    0.102504    0.009641    0.739992    
#> 017: 0.662715    0.959303    3.468193    0.345180    0.101157    0.009159    0.734396    
#> 018: 0.679476    0.961586    3.456415    0.421341    0.105331    0.008701    0.744533    
#> 019: 0.651203    0.943992    3.456004    0.400274    0.100064    0.008266    0.729328    
#> 020: 0.637788    0.974288    3.459989    0.380261    0.095061    0.007853    0.747521    
#> 021: 0.687401    0.962856    3.464432    0.361248    0.090308    0.007460    0.733361    
#> 022: 0.639069    0.961064    3.469984    0.343185    0.102369    0.007087    0.721496    
#> 023: 0.729842    0.947499    3.478435    0.367068    0.101719    0.007124    0.742175    
#> 024: 0.692730    0.966165    3.470895    0.412053    0.096633    0.008398    0.738501    
#> 025: 0.685867    0.944963    3.468572    0.391450    0.091802    0.007978    0.772263    
#> 026: 0.641059    0.971087    3.457600    0.371878    0.087212    0.008008    0.752646    
#> 027: 0.614810    0.992367    3.451039    0.385648    0.091486    0.008573    0.767480    
#> 028: 0.683272    0.954990    3.462767    0.389545    0.087073    0.010420    0.736064    
#> 029: 0.712728    0.942275    3.459100    0.419605    0.091341    0.010663    0.738533    
#> 030: 0.696106    0.969917    3.465032    0.430122    0.086774    0.010130    0.716101    
#> 031: 0.674660    0.940815    3.468074    0.439789    0.082435    0.010802    0.713273    
#> 032: 0.642825    0.921579    3.471404    0.417800    0.078314    0.011233    0.721447    
#> 033: 0.625050    0.951609    3.457577    0.396910    0.084532    0.010890    0.721353    
#> 034: 0.674370    0.967705    3.461320    0.377064    0.083523    0.010454    0.718620    
#> 035: 0.647447    0.941590    3.461147    0.365021    0.079347    0.012889    0.699916    
#> 036: 0.652773    0.963507    3.460279    0.395095    0.083480    0.012599    0.709770    
#> 037: 0.669912    0.953985    3.464925    0.375340    0.084579    0.011969    0.708019    
#> 038: 0.656939    0.943955    3.461330    0.356573    0.086493    0.011371    0.710658    
#> 039: 0.678394    0.943452    3.465013    0.338744    0.087458    0.010802    0.711266    
#> 040: 0.658351    0.973811    3.467794    0.376442    0.083085    0.011025    0.731101    
#> 041: 0.630008    0.968313    3.453995    0.444747    0.078931    0.010714    0.714522    
#> 042: 0.659429    0.957867    3.452258    0.422510    0.076653    0.010178    0.703904    
#> 043: 0.615725    0.970627    3.439642    0.421598    0.075173    0.012378    0.708703    
#> 044: 0.602031    0.970218    3.440471    0.400518    0.085651    0.012233    0.703818    
#> 045: 0.621249    0.995196    3.439027    0.413957    0.081369    0.011621    0.709167    
#> 046: 0.611711    0.959655    3.447969    0.410624    0.080378    0.012980    0.717630    
#> 047: 0.637480    0.960934    3.448902    0.395472    0.090718    0.013340    0.715335    
#> 048: 0.647438    0.955977    3.447560    0.415453    0.088975    0.012673    0.724632    
#> 049: 0.638519    0.955882    3.455399    0.439740    0.093410    0.012040    0.708572    
#> 050: 0.714166    0.930283    3.463216    0.417753    0.088739    0.011809    0.729584    
#> 051: 0.632727    0.952940    3.455455    0.398687    0.102559    0.012348    0.736815    
#> 052: 0.707969    0.956441    3.467579    0.428476    0.102898    0.011731    0.721083    
#> 053: 0.689918    0.940923    3.464141    0.407052    0.106643    0.011144    0.717981    
#> 054: 0.640155    0.951734    3.458241    0.386700    0.101311    0.010928    0.743381    
#> 055: 0.664048    0.950460    3.460182    0.367365    0.096246    0.011446    0.726551    
#> 056: 0.645335    0.944329    3.454533    0.348997    0.095409    0.012288    0.736279    
#> 057: 0.650530    0.942029    3.465572    0.331547    0.090638    0.011673    0.733590    
#> 058: 0.669219    0.948004    3.459948    0.314969    0.086106    0.012045    0.731473    
#> 059: 0.641400    0.911327    3.477196    0.355864    0.081801    0.013944    0.739652    
#> 060: 0.644870    0.907706    3.465891    0.338071    0.092310    0.013247    0.731631    
#> 061: 0.708792    0.942975    3.471436    0.337563    0.091310    0.012585    0.763859    
#> 062: 0.684015    0.974941    3.477520    0.320685    0.086744    0.012281    0.750692    
#> 063: 0.704672    0.941062    3.475776    0.347208    0.084435    0.011667    0.754754    
#> 064: 0.700889    0.952728    3.469386    0.375788    0.099073    0.011084    0.728481    
#> 065: 0.705766    0.923694    3.466721    0.375373    0.094119    0.010530    0.733827    
#> 066: 0.715760    0.933287    3.475332    0.381283    0.089413    0.010003    0.735621    
#> 067: 0.696828    0.910093    3.465419    0.362218    0.092325    0.009503    0.747471    
#> 068: 0.651476    0.939605    3.473181    0.354070    0.088087    0.009028    0.736978    
#> 069: 0.664428    0.960528    3.467049    0.360356    0.106192    0.009956    0.735640    
#> 070: 0.659363    0.965226    3.470952    0.370646    0.101490    0.009967    0.728361    
#> 071: 0.646390    0.961016    3.453408    0.365276    0.096416    0.009469    0.736128    
#> 072: 0.635496    0.933298    3.453176    0.433410    0.091595    0.008995    0.731318    
#> 073: 0.653975    0.954425    3.460060    0.426389    0.095137    0.008631    0.705601    
#> 074: 0.650612    0.955043    3.454037    0.405069    0.093021    0.009700    0.704624    
#> 075: 0.624978    0.940309    3.474100    0.384816    0.088370    0.009267    0.723046    
#> 076: 0.681914    0.968826    3.476025    0.400825    0.083951    0.011165    0.729800    
#> 077: 0.698668    0.949947    3.465160    0.414610    0.090217    0.010606    0.714129    
#> 078: 0.637260    0.954832    3.467745    0.393879    0.089120    0.010076    0.712081    
#> 079: 0.681085    0.968290    3.474220    0.377373    0.108972    0.010892    0.731663    
#> 080: 0.691423    0.938849    3.479130    0.396278    0.103523    0.013413    0.736018    
#> 081: 0.693094    0.950764    3.471526    0.403118    0.098347    0.015390    0.730287    
#> 082: 0.665140    0.944991    3.471079    0.390381    0.099031    0.014621    0.750638    
#> 083: 0.688683    0.972220    3.470684    0.398021    0.094079    0.013890    0.740142    
#> 084: 0.641513    0.947442    3.464089    0.378120    0.098131    0.013195    0.730609    
#> 085: 0.665032    0.950975    3.477338    0.359214    0.093224    0.012535    0.730183    
#> 086: 0.684300    0.964793    3.467789    0.394248    0.090982    0.011909    0.721210    
#> 087: 0.640175    0.963623    3.456451    0.374535    0.090853    0.011313    0.716599    
#> 088: 0.569361    0.955948    3.458598    0.355809    0.098408    0.010748    0.753783    
#> 089: 0.606136    0.970312    3.447128    0.338018    0.103482    0.010210    0.756256    
#> 090: 0.594844    0.973414    3.448647    0.325326    0.115436    0.009700    0.761280    
#> 091: 0.613134    0.954227    3.439136    0.383103    0.109665    0.009215    0.740304    
#> 092: 0.585601    0.988390    3.427660    0.363947    0.104181    0.009811    0.762682    
#> 093: 0.578530    0.991151    3.427450    0.346994    0.098972    0.012669    0.733383    
#> 094: 0.603624    0.995918    3.433950    0.329644    0.113918    0.012036    0.717594    
#> 095: 0.635467    0.981554    3.451574    0.313162    0.108222    0.011434    0.717100    
#> 096: 0.580010    0.980293    3.449360    0.297504    0.109970    0.010862    0.715291    
#> 097: 0.638565    0.997979    3.444588    0.341657    0.108107    0.010319    0.708877    
#> 098: 0.634226    1.006810    3.449719    0.354045    0.102701    0.009803    0.718112    
#> 099: 0.651108    0.958829    3.442097    0.336343    0.097566    0.009313    0.725295    
#> 100: 0.624863    0.975925    3.442044    0.336384    0.092688    0.008848    0.720416    
#> 101: 0.602850    0.985784    3.434919    0.319565    0.088053    0.008405    0.714130    
#> 102: 0.598501    0.967420    3.429327    0.338288    0.083651    0.007985    0.733389    
#> 103: 0.625197    0.981879    3.444049    0.364215    0.098788    0.007586    0.718176    
#> 104: 0.604946    0.989067    3.440208    0.446635    0.103547    0.008012    0.723625    
#> 105: 0.595888    0.972526    3.432690    0.424304    0.098370    0.007831    0.739123    
#> 106: 0.613555    0.976015    3.437255    0.403088    0.093451    0.008047    0.725469    
#> 107: 0.653217    0.978209    3.443058    0.382934    0.088779    0.008539    0.738195    
#> 108: 0.617027    0.975449    3.445968    0.363787    0.092636    0.008112    0.740089    
#> 109: 0.608060    0.986923    3.453983    0.345598    0.093179    0.007707    0.729790    
#> 110: 0.650560    0.965478    3.439493    0.347858    0.101349    0.007569    0.715995    
#> 111: 0.620588    0.961272    3.449670    0.378268    0.096282    0.007190    0.726641    
#> 112: 0.621966    0.947166    3.443539    0.359355    0.092625    0.007007    0.734700    
#> 113: 0.614401    0.981651    3.444071    0.351811    0.108777    0.006657    0.707007    
#> 114: 0.635270    0.963749    3.454036    0.334220    0.104255    0.006608    0.711485    
#> 115: 0.666537    0.926593    3.462669    0.332391    0.103487    0.006487    0.730810    
#> 116: 0.674531    0.956499    3.469180    0.315771    0.098313    0.008314    0.750764    
#> 117: 0.647954    0.980595    3.466136    0.392089    0.093397    0.009002    0.743971    
#> 118: 0.673518    0.954450    3.465302    0.372485    0.088728    0.008552    0.728503    
#> 119: 0.658595    0.962579    3.461074    0.353860    0.084291    0.008124    0.741470    
#> 120: 0.642208    0.932781    3.454236    0.379331    0.080077    0.007718    0.753970    
#> 121: 0.664954    0.968919    3.459462    0.360364    0.082150    0.007332    0.751815    
#> 122: 0.636319    0.951416    3.464522    0.348455    0.107112    0.006966    0.756753    
#> 123: 0.722883    0.973949    3.464588    0.368651    0.101756    0.006617    0.767111    
#> 124: 0.690316    0.992792    3.458372    0.350218    0.096669    0.006287    0.756097    
#> 125: 0.654300    0.997713    3.450539    0.332707    0.091835    0.006537    0.737123    
#> 126: 0.645216    1.008842    3.443593    0.316072    0.090919    0.006211    0.755990    
#> 127: 0.652720    0.982372    3.439586    0.381557    0.086373    0.005900    0.737407    
#> 128: 0.631614    0.964709    3.445134    0.362479    0.095502    0.005605    0.723650    
#> 129: 0.620197    0.983535    3.448513    0.344355    0.113078    0.005325    0.733879    
#> 130: 0.646723    0.987234    3.445768    0.327137    0.120235    0.005059    0.730867    
#> 131: 0.632036    0.958386    3.442301    0.315545    0.114223    0.004806    0.745612    
#> 132: 0.582759    0.964070    3.436612    0.299768    0.108512    0.004905    0.764261    
#> 133: 0.614421    0.972351    3.434841    0.405644    0.103086    0.005747    0.750838    
#> 134: 0.668864    0.961204    3.449833    0.451710    0.098924    0.005871    0.731170    
#> 135: 0.635552    0.964724    3.444443    0.429125    0.119629    0.006659    0.716479    
#> 136: 0.653818    0.948938    3.448598    0.426405    0.113648    0.006327    0.721045    
#> 137: 0.700127    0.946962    3.458484    0.446514    0.113289    0.006010    0.730185    
#> 138: 0.677656    0.953112    3.459995    0.440493    0.107625    0.005710    0.721605    
#> 139: 0.662685    0.947684    3.460389    0.418468    0.103924    0.005424    0.726630    
#> 140: 0.648357    0.973132    3.466451    0.397545    0.107622    0.006621    0.754447    
#> 141: 0.657872    0.925381    3.469948    0.377667    0.126976    0.006448    0.741193    
#> 142: 0.652628    0.919424    3.467186    0.358784    0.123375    0.006535    0.739083    
#> 143: 0.606895    0.961388    3.461108    0.340845    0.117206    0.007424    0.743903    
#> 144: 0.669057    0.968025    3.473878    0.341583    0.111346    0.007053    0.731475    
#> 145: 0.681314    0.964439    3.464787    0.334014    0.105779    0.006700    0.717142    
#> 146: 0.655428    0.973627    3.470102    0.317313    0.100490    0.006365    0.739675    
#> 147: 0.619630    0.961715    3.455425    0.301447    0.095465    0.006443    0.727071    
#> 148: 0.626946    0.983506    3.463657    0.309598    0.092766    0.007604    0.713292    
#> 149: 0.632825    0.956662    3.458414    0.389331    0.089573    0.008412    0.729047    
#> 150: 0.685443    0.949063    3.459616    0.388604    0.095743    0.009171    0.734623    
#> 151: 0.628346    0.970450    3.451531    0.369174    0.100384    0.008713    0.730386    
#> 152: 0.611427    0.964577    3.456012    0.287368    0.096062    0.005510    0.731003    
#> 153: 0.610828    0.949207    3.458509    0.284928    0.068037    0.004918    0.746200    
#> 154: 0.643757    0.943427    3.464997    0.287852    0.086615    0.005378    0.750867    
#> 155: 0.628440    0.948916    3.459847    0.280490    0.104649    0.004935    0.751238    
#> 156: 0.676664    0.937536    3.473159    0.315048    0.114456    0.004611    0.739629    
#> 157: 0.699978    0.921934    3.473347    0.400861    0.127527    0.004796    0.737420    
#> 158: 0.689966    0.935482    3.471047    0.316302    0.107432    0.003680    0.736796    
#> 159: 0.635849    0.955926    3.468122    0.317927    0.121554    0.003931    0.735605    
#> 160: 0.662473    0.906986    3.474057    0.304450    0.124129    0.004548    0.755250    
#> 161: 0.683666    0.939167    3.468238    0.304469    0.116427    0.004301    0.742859    
#> 162: 0.645486    0.943230    3.452850    0.331577    0.110720    0.003176    0.751332    
#> 163: 0.663039    0.952130    3.457187    0.333369    0.145774    0.003312    0.732048    
#> 164: 0.662839    0.947907    3.457997    0.370627    0.120858    0.002750    0.735083    
#> 165: 0.682691    0.935013    3.466765    0.331011    0.128967    0.003291    0.732860    
#> 166: 0.711332    0.976295    3.462576    0.418831    0.127059    0.003385    0.730334    
#> 167: 0.675669    0.953681    3.464282    0.427133    0.122278    0.003786    0.747659    
#> 168: 0.708131    0.971631    3.468929    0.401542    0.104755    0.003062    0.745424    
#> 169: 0.713914    1.001710    3.460347    0.425640    0.125610    0.002972    0.751896    
#> 170: 0.679720    0.977928    3.458447    0.453727    0.125797    0.002917    0.735847    
#> 171: 0.644353    0.959180    3.459228    0.354922    0.121256    0.003086    0.717369    
#> 172: 0.603616    0.994903    3.454321    0.286459    0.130549    0.003134    0.717168    
#> 173: 0.605485    0.981611    3.441782    0.284447    0.099434    0.003192    0.732112    
#> 174: 0.647709    0.963234    3.445747    0.392819    0.096758    0.004633    0.733927    
#> 175: 0.646149    0.972387    3.441390    0.359313    0.102405    0.003589    0.739333    
#> 176: 0.643420    0.995578    3.442871    0.360407    0.111161    0.003381    0.726205    
#> 177: 0.673695    0.977361    3.448631    0.343449    0.089952    0.003145    0.731003    
#> 178: 0.633669    0.967503    3.445617    0.345427    0.102745    0.002862    0.733904    
#> 179: 0.672019    0.995910    3.439886    0.408951    0.091706    0.004194    0.737801    
#> 180: 0.636140    0.976128    3.447607    0.406546    0.113403    0.004385    0.738468    
#> 181: 0.617793    0.992216    3.432372    0.356570    0.088381    0.003932    0.758989    
#> 182: 0.561493    0.983034    3.427177    0.364695    0.082623    0.005167    0.773549    
#> 183: 0.571634    1.001182    3.426864    0.321221    0.086893    0.005767    0.739805    
#> 184: 0.605117    0.970596    3.431338    0.365828    0.102799    0.005330    0.724111    
#> 185: 0.585595    1.004421    3.431358    0.307245    0.123022    0.004377    0.718440    
#> 186: 0.588171    1.000079    3.440671    0.321572    0.120687    0.004729    0.732306    
#> 187: 0.624643    0.970201    3.447256    0.382171    0.099123    0.004700    0.739340    
#> 188: 0.571062    0.998948    3.442495    0.337045    0.108815    0.004838    0.757646    
#> 189: 0.632358    1.003066    3.454928    0.303832    0.086522    0.005822    0.760133    
#> 190: 0.634829    0.967099    3.464014    0.369789    0.087434    0.005132    0.732917    
#> 191: 0.581334    0.982046    3.444741    0.292006    0.078652    0.004965    0.735352    
#> 192: 0.607932    0.977105    3.448894    0.304131    0.088200    0.005580    0.735797    
#> 193: 0.656322    0.989081    3.449711    0.302111    0.094954    0.004671    0.733665    
#> 194: 0.619905    0.992734    3.442895    0.360180    0.084328    0.005616    0.728374    
#> 195: 0.593106    0.982161    3.434658    0.388490    0.083619    0.008502    0.712640    
#> 196: 0.642517    0.968764    3.448534    0.355857    0.079798    0.007297    0.746386    
#> 197: 0.602527    0.967079    3.466829    0.286384    0.094941    0.008277    0.759167    
#> 198: 0.656503    0.938972    3.458499    0.289191    0.108287    0.008770    0.738836    
#> 199: 0.599169    0.965787    3.448787    0.328651    0.098868    0.008898    0.718869    
#> 200: 0.630905    0.962595    3.456330    0.369495    0.083472    0.009945    0.717981    
#> 201: 0.642463    0.958711    3.458812    0.394584    0.085589    0.009651    0.718818    
#> 202: 0.642597    0.962770    3.457660    0.391972    0.082657    0.009783    0.722230    
#> 203: 0.650314    0.961606    3.454765    0.384205    0.081739    0.010181    0.726247    
#> 204: 0.647789    0.959073    3.454931    0.387006    0.087250    0.009882    0.728720    
#> 205: 0.646170    0.962129    3.454830    0.378757    0.085234    0.010126    0.733253    
#> 206: 0.647111    0.966658    3.456081    0.387856    0.083409    0.010384    0.733543    
#> 207: 0.644779    0.968954    3.454083    0.387315    0.083793    0.010556    0.732243    
#> 208: 0.641975    0.971070    3.452884    0.387578    0.084709    0.010441    0.729857    
#> 209: 0.644364    0.969018    3.452277    0.385574    0.084562    0.010320    0.728420    
#> 210: 0.646628    0.966412    3.452432    0.384795    0.085288    0.010196    0.728168    
#> 211: 0.648863    0.965894    3.453428    0.379480    0.085054    0.009998    0.727888    
#> 212: 0.651952    0.965342    3.453786    0.376048    0.085035    0.009878    0.728148    
#> 213: 0.655842    0.963195    3.454670    0.375412    0.085834    0.009726    0.729812    
#> 214: 0.658662    0.962894    3.455471    0.372319    0.086579    0.009478    0.730850    
#> 215: 0.658246    0.962662    3.455928    0.372565    0.088095    0.009323    0.730603    
#> 216: 0.658267    0.960990    3.456167    0.368976    0.088874    0.009241    0.731303    
#> 217: 0.657193    0.961284    3.456367    0.367153    0.089308    0.009153    0.730724    
#> 218: 0.657048    0.962243    3.455648    0.366512    0.089726    0.009000    0.730847    
#> 219: 0.656474    0.961751    3.454833    0.369154    0.090353    0.008844    0.730983    
#> 220: 0.652978    0.962210    3.454548    0.368631    0.090590    0.008771    0.730999    
#> 221: 0.650935    0.962483    3.454046    0.369996    0.091460    0.008680    0.729907    
#> 222: 0.651531    0.962361    3.453854    0.371606    0.092077    0.008625    0.729946    
#> 223: 0.652820    0.961798    3.453829    0.371296    0.092372    0.008507    0.730262    
#> 224: 0.655404    0.962082    3.454291    0.370294    0.092351    0.008414    0.730564    
#> 225: 0.655604    0.959676    3.455018    0.371388    0.092680    0.008412    0.730338    
#> 226: 0.656130    0.957977    3.455307    0.370798    0.092756    0.008375    0.730648    
#> 227: 0.656172    0.957790    3.455617    0.368564    0.093111    0.008318    0.730761    
#> 228: 0.656671    0.958210    3.455260    0.370078    0.093138    0.008273    0.730698    
#> 229: 0.655911    0.957487    3.455120    0.369241    0.092966    0.008276    0.730413    
#> 230: 0.656821    0.956910    3.455200    0.369638    0.092988    0.008259    0.730137    
#> 231: 0.656865    0.957730    3.455242    0.370869    0.093462    0.008256    0.729551    
#> 232: 0.655948    0.958051    3.455224    0.368752    0.093284    0.008285    0.729739    
#> 233: 0.655728    0.957540    3.455152    0.369212    0.093634    0.008259    0.729879    
#> 234: 0.654238    0.958140    3.455163    0.369785    0.093705    0.008235    0.729899    
#> 235: 0.653685    0.958086    3.454837    0.370780    0.093839    0.008237    0.729410    
#> 236: 0.652676    0.958463    3.454684    0.370273    0.094067    0.008189    0.729358    
#> 237: 0.653454    0.958755    3.454701    0.371852    0.094063    0.008203    0.730011    
#> 238: 0.653832    0.958722    3.454620    0.372693    0.093787    0.008225    0.730485    
#> 239: 0.653411    0.958977    3.454553    0.371861    0.093659    0.008138    0.730532    
#> 240: 0.652753    0.958676    3.454426    0.370003    0.093527    0.008082    0.730594    
#> 241: 0.653067    0.957740    3.454796    0.368962    0.093364    0.008120    0.730335    
#> 242: 0.653133    0.957085    3.454882    0.368359    0.093459    0.008198    0.730583    
#> 243: 0.652883    0.957226    3.454813    0.367750    0.093279    0.008305    0.730841    
#> 244: 0.652520    0.957338    3.454851    0.368807    0.093323    0.008416    0.730791    
#> 245: 0.651421    0.957391    3.454709    0.368817    0.093294    0.008448    0.731355    
#> 246: 0.651152    0.957180    3.454773    0.369272    0.093056    0.008450    0.731493    
#> 247: 0.651352    0.956600    3.455191    0.368433    0.093070    0.008463    0.731379    
#> 248: 0.651216    0.957024    3.455288    0.367751    0.093309    0.008443    0.731213    
#> 249: 0.651021    0.957116    3.455450    0.367366    0.093362    0.008429    0.731007    
#> 250: 0.651716    0.957409    3.455606    0.367455    0.093078    0.008464    0.730923    
#> 251: 0.651953    0.957585    3.455886    0.367986    0.093116    0.008493    0.731034    
#> 252: 0.652431    0.957844    3.456081    0.368563    0.092971    0.008506    0.731036    
#> 253: 0.652092    0.958094    3.456044    0.368841    0.092683    0.008534    0.731000    
#> 254: 0.652648    0.958435    3.456110    0.368458    0.092468    0.008528    0.731304    
#> 255: 0.652156    0.958673    3.456096    0.368295    0.092273    0.008531    0.731718    
#> 256: 0.652162    0.958504    3.456048    0.367886    0.092198    0.008535    0.731811    
#> 257: 0.651728    0.958378    3.456014    0.367784    0.092280    0.008557    0.731932    
#> 258: 0.650861    0.957946    3.455980    0.366121    0.092118    0.008569    0.732067    
#> 259: 0.650361    0.957912    3.455918    0.366093    0.091960    0.008608    0.731858    
#> 260: 0.649947    0.958410    3.455873    0.367834    0.091981    0.008634    0.731623    
#> 261: 0.650375    0.958608    3.455923    0.370183    0.091769    0.008633    0.731509    
#> 262: 0.650631    0.959008    3.455855    0.370270    0.091566    0.008636    0.731362    
#> 263: 0.650962    0.959357    3.455841    0.370869    0.091844    0.008641    0.731441    
#> 264: 0.650626    0.959364    3.455793    0.371192    0.091964    0.008622    0.731553    
#> 265: 0.650561    0.959495    3.455785    0.370345    0.091786    0.008631    0.731784    
#> 266: 0.651124    0.959731    3.455865    0.370155    0.091768    0.008611    0.731957    
#> 267: 0.650774    0.959670    3.455959    0.369689    0.091826    0.008614    0.732100    
#> 268: 0.650981    0.959497    3.455855    0.369556    0.092011    0.008585    0.732262    
#> 269: 0.651702    0.959492    3.455910    0.369131    0.092238    0.008571    0.732411    
#> 270: 0.651835    0.959708    3.455735    0.368710    0.092498    0.008561    0.732349    
#> 271: 0.651802    0.959775    3.455557    0.369442    0.092383    0.008578    0.732306    
#> 272: 0.651525    0.959852    3.455310    0.370333    0.092329    0.008604    0.732561    
#> 273: 0.650831    0.960475    3.455123    0.370704    0.092236    0.008620    0.732351    
#> 274: 0.650307    0.960842    3.454955    0.371859    0.092415    0.008650    0.732234    
#> 275: 0.649591    0.961264    3.454612    0.372724    0.092326    0.008685    0.732241    
#> 276: 0.649179    0.961544    3.454630    0.373156    0.092215    0.008710    0.732283    
#> 277: 0.648820    0.961822    3.454725    0.373052    0.092130    0.008754    0.732140    
#> 278: 0.648874    0.961732    3.454818    0.373095    0.092107    0.008779    0.732030    
#> 279: 0.648609    0.961617    3.454832    0.372859    0.092142    0.008809    0.732018    
#> 280: 0.648583    0.961701    3.454844    0.372784    0.092002    0.008827    0.731864    
#> 281: 0.648738    0.961849    3.454938    0.372147    0.091997    0.008811    0.731789    
#> 282: 0.648613    0.962092    3.454949    0.371761    0.091832    0.008821    0.731706    
#> 283: 0.648388    0.962124    3.454964    0.371824    0.091889    0.008847    0.731844    
#> 284: 0.648228    0.961888    3.454950    0.371536    0.091976    0.008870    0.731767    
#> 285: 0.648373    0.962090    3.454784    0.372034    0.092100    0.008901    0.731594    
#> 286: 0.648019    0.962396    3.454588    0.372331    0.092011    0.008956    0.731568    
#> 287: 0.647948    0.962541    3.454490    0.372505    0.091912    0.008986    0.731605    
#> 288: 0.648392    0.962419    3.454550    0.372701    0.091924    0.009057    0.731610    
#> 289: 0.648987    0.962106    3.454708    0.372750    0.091810    0.009105    0.731812    
#> 290: 0.649327    0.962032    3.454770    0.372735    0.091928    0.009122    0.731823    
#> 291: 0.649918    0.962119    3.454967    0.372113    0.091924    0.009122    0.731878    
#> 292: 0.650166    0.961886    3.455119    0.371785    0.091965    0.009111    0.732043    
#> 293: 0.649987    0.961646    3.455143    0.371048    0.091989    0.009094    0.732040    
#> 294: 0.649942    0.961492    3.455163    0.370612    0.091954    0.009067    0.732151    
#> 295: 0.649972    0.961019    3.455209    0.370754    0.091979    0.009042    0.732027    
#> 296: 0.650518    0.960746    3.455298    0.371494    0.092009    0.009031    0.732046    
#> 297: 0.650942    0.960886    3.455285    0.372239    0.092057    0.009029    0.732018    
#> 298: 0.650976    0.960765    3.455311    0.372950    0.092028    0.009028    0.731785    
#> 299: 0.651174    0.960947    3.455296    0.373238    0.092093    0.009025    0.731469    
#> 300: 0.651264    0.960759    3.455375    0.372986    0.091866    0.009040    0.731074    
#> 301: 0.651386    0.960717    3.455336    0.373097    0.091761    0.009045    0.731070    
#> 302: 0.651525    0.960985    3.455258    0.372953    0.091753    0.009041    0.730847    
#> 303: 0.651540    0.961310    3.455209    0.372791    0.091718    0.009027    0.730608    
#> 304: 0.651458    0.961620    3.455059    0.372171    0.091878    0.009021    0.730571    
#> 305: 0.651461    0.961376    3.455080    0.371811    0.091939    0.009013    0.730496    
#> 306: 0.651588    0.961135    3.455083    0.371965    0.091812    0.009030    0.730438    
#> 307: 0.651511    0.960938    3.455037    0.372381    0.091538    0.009056    0.730506    
#> 308: 0.651205    0.960827    3.454958    0.372330    0.091418    0.009060    0.730701    
#> 309: 0.651308    0.960595    3.454927    0.372687    0.091267    0.009082    0.730888    
#> 310: 0.651295    0.960436    3.454814    0.373253    0.091087    0.009103    0.731006    
#> 311: 0.651211    0.960439    3.454808    0.373642    0.090937    0.009127    0.730862    
#> 312: 0.651156    0.960407    3.454776    0.373912    0.090865    0.009137    0.730781    
#> 313: 0.651124    0.960288    3.454693    0.374294    0.090950    0.009150    0.730730    
#> 314: 0.650655    0.960619    3.454574    0.374065    0.090973    0.009161    0.730572    
#> 315: 0.650242    0.960674    3.454509    0.373923    0.091030    0.009174    0.730470    
#> 316: 0.649987    0.960764    3.454461    0.373494    0.091037    0.009177    0.730506    
#> 317: 0.650080    0.960739    3.454527    0.373478    0.091182    0.009167    0.730533    
#> 318: 0.650352    0.960787    3.454543    0.373878    0.091278    0.009162    0.730509    
#> 319: 0.650530    0.960666    3.454624    0.374030    0.091282    0.009163    0.730501    
#> 320: 0.650332    0.960434    3.454618    0.374214    0.091319    0.009161    0.730548    
#> 321: 0.650037    0.960494    3.454524    0.374534    0.091478    0.009171    0.730443    
#> 322: 0.649751    0.960521    3.454363    0.374753    0.091626    0.009167    0.730381    
#> 323: 0.649142    0.960577    3.454216    0.374888    0.091547    0.009183    0.730416    
#> 324: 0.649048    0.960792    3.454149    0.374671    0.091589    0.009190    0.730246    
#> 325: 0.648880    0.961041    3.454063    0.374468    0.091569    0.009185    0.730180    
#> 326: 0.648839    0.960985    3.454004    0.374365    0.091620    0.009177    0.730082    
#> 327: 0.649082    0.960976    3.454043    0.373959    0.091693    0.009170    0.730116    
#> 328: 0.649355    0.961023    3.454024    0.373323    0.091672    0.009168    0.730105    
#> 329: 0.649468    0.961095    3.454054    0.372976    0.091682    0.009148    0.730208    
#> 330: 0.649201    0.961167    3.454039    0.372497    0.091654    0.009149    0.730370    
#> 331: 0.649062    0.961393    3.453987    0.372070    0.091643    0.009145    0.730377    
#> 332: 0.648818    0.961418    3.453930    0.371555    0.091710    0.009152    0.730375    
#> 333: 0.648524    0.961513    3.453812    0.371027    0.091732    0.009158    0.730350    
#> 334: 0.648267    0.961610    3.453666    0.370970    0.091810    0.009145    0.730316    
#> 335: 0.647861    0.961859    3.453496    0.370533    0.091782    0.009150    0.730217    
#> 336: 0.647550    0.962138    3.453421    0.370452    0.091639    0.009169    0.730153    
#> 337: 0.647284    0.962591    3.453294    0.370234    0.091584    0.009163    0.730179    
#> 338: 0.647108    0.962743    3.453236    0.369849    0.091515    0.009159    0.730133    
#> 339: 0.646864    0.962819    3.453152    0.369785    0.091573    0.009142    0.729998    
#> 340: 0.646805    0.962705    3.453136    0.369502    0.091606    0.009134    0.730056    
#> 341: 0.646865    0.962667    3.453188    0.369531    0.091669    0.009128    0.730142    
#> 342: 0.646770    0.962506    3.453198    0.369222    0.091681    0.009142    0.730123    
#> 343: 0.646332    0.962501    3.453217    0.369096    0.091591    0.009144    0.730105    
#> 344: 0.646089    0.962595    3.453201    0.369196    0.091764    0.009159    0.730061    
#> 345: 0.646030    0.962603    3.453214    0.369158    0.091816    0.009166    0.730024    
#> 346: 0.645818    0.962767    3.453102    0.369266    0.091841    0.009155    0.729938    
#> 347: 0.645865    0.962782    3.452975    0.369494    0.091832    0.009145    0.730039    
#> 348: 0.645679    0.962807    3.452891    0.369631    0.091778    0.009144    0.730059    
#> 349: 0.645573    0.962715    3.452841    0.369633    0.091832    0.009141    0.730160    
#> 350: 0.645469    0.962601    3.452798    0.369914    0.091876    0.009131    0.730214    
#> 351: 0.645371    0.962774    3.452770    0.369815    0.091833    0.009126    0.730211    
#> 352: 0.645116    0.962824    3.452768    0.369518    0.091792    0.009124    0.730339    
#> 353: 0.645252    0.962825    3.452802    0.369131    0.091803    0.009127    0.730354    
#> 354: 0.645197    0.962798    3.452743    0.368923    0.091805    0.009120    0.730387    
#> 355: 0.645344    0.962686    3.452685    0.368995    0.091901    0.009109    0.730430    
#> 356: 0.645288    0.962651    3.452704    0.369019    0.091860    0.009113    0.730511    
#> 357: 0.645413    0.962683    3.452696    0.368970    0.091859    0.009106    0.730482    
#> 358: 0.645392    0.962774    3.452693    0.369412    0.091987    0.009100    0.730290    
#> 359: 0.645371    0.962844    3.452664    0.369281    0.092002    0.009098    0.730237    
#> 360: 0.645145    0.962799    3.452608    0.369036    0.091985    0.009107    0.730158    
#> 361: 0.645182    0.962781    3.452596    0.368723    0.092097    0.009099    0.730039    
#> 362: 0.645353    0.962769    3.452575    0.368751    0.092157    0.009086    0.729956    
#> 363: 0.645418    0.962679    3.452630    0.368412    0.092293    0.009079    0.729840    
#> 364: 0.645517    0.962666    3.452654    0.368273    0.092325    0.009067    0.729870    
#> 365: 0.645479    0.962659    3.452681    0.368073    0.092426    0.009074    0.729824    
#> 366: 0.645511    0.962734    3.452611    0.368202    0.092354    0.009077    0.729885    
#> 367: 0.645456    0.962819    3.452578    0.368338    0.092279    0.009079    0.729848    
#> 368: 0.645579    0.962967    3.452546    0.368393    0.092374    0.009090    0.729727    
#> 369: 0.645533    0.963016    3.452525    0.368084    0.092414    0.009094    0.729783    
#> 370: 0.645535    0.963088    3.452532    0.367971    0.092467    0.009099    0.729756    
#> 371: 0.645431    0.963087    3.452472    0.367855    0.092483    0.009095    0.729710    
#> 372: 0.645330    0.963137    3.452448    0.368098    0.092527    0.009090    0.729695    
#> 373: 0.645173    0.963227    3.452389    0.368183    0.092554    0.009085    0.729644    
#> 374: 0.645195    0.963328    3.452317    0.368774    0.092565    0.009098    0.729517    
#> 375: 0.645038    0.963333    3.452272    0.368988    0.092596    0.009111    0.729479    
#> 376: 0.644928    0.963453    3.452235    0.369003    0.092634    0.009123    0.729490    
#> 377: 0.644611    0.963647    3.452208    0.368862    0.092674    0.009137    0.729502    
#> 378: 0.644465    0.963697    3.452142    0.368542    0.092634    0.009145    0.729715    
#> 379: 0.644230    0.963596    3.452120    0.368160    0.092570    0.009145    0.729747    
#> 380: 0.644012    0.963567    3.452076    0.367904    0.092588    0.009137    0.729771    
#> 381: 0.643563    0.963618    3.451984    0.367945    0.092534    0.009132    0.729755    
#> 382: 0.643542    0.963560    3.451999    0.367974    0.092526    0.009125    0.729701    
#> 383: 0.643510    0.963529    3.452008    0.367696    0.092596    0.009110    0.729622    
#> 384: 0.643287    0.963569    3.452027    0.367577    0.092728    0.009096    0.729588    
#> 385: 0.643267    0.963556    3.452058    0.367033    0.092788    0.009087    0.729629    
#> 386: 0.643420    0.963671    3.452139    0.366724    0.092931    0.009081    0.729776    
#> 387: 0.643701    0.963784    3.452207    0.366577    0.092939    0.009079    0.729874    
#> 388: 0.643871    0.963799    3.452232    0.366568    0.093026    0.009073    0.729976    
#> 389: 0.644091    0.963496    3.452293    0.366687    0.093093    0.009062    0.730063    
#> 390: 0.644145    0.963429    3.452338    0.366649    0.093030    0.009059    0.730168    
#> 391: 0.644229    0.963307    3.452396    0.366529    0.092989    0.009057    0.730181    
#> 392: 0.644362    0.963287    3.452508    0.366459    0.093016    0.009060    0.730182    
#> 393: 0.644262    0.963221    3.452466    0.366155    0.093095    0.009058    0.730079    
#> 394: 0.644239    0.963220    3.452452    0.365979    0.093048    0.009045    0.730036    
#> 395: 0.644538    0.963261    3.452536    0.366102    0.093095    0.009039    0.730061    
#> 396: 0.644705    0.963337    3.452569    0.366268    0.093133    0.009038    0.729973    
#> 397: 0.644735    0.963343    3.452590    0.366172    0.093175    0.009043    0.729924    
#> 398: 0.644907    0.963304    3.452653    0.366175    0.093150    0.009065    0.729916    
#> 399: 0.645087    0.963295    3.452748    0.366309    0.093086    0.009077    0.729799    
#> 400: 0.645248    0.963275    3.452825    0.366067    0.093052    0.009082    0.729790    
#> 401: 0.645343    0.963214    3.452854    0.366040    0.093054    0.009088    0.729800    
#> 402: 0.645358    0.963321    3.452859    0.365595    0.093045    0.009095    0.729816    
#> 403: 0.645384    0.963403    3.452823    0.365330    0.092986    0.009098    0.729789    
#> 404: 0.645369    0.963507    3.452728    0.365268    0.092997    0.009089    0.729724    
#> 405: 0.645208    0.963567    3.452693    0.365390    0.093019    0.009077    0.729765    
#> 406: 0.645302    0.963616    3.452670    0.365458    0.093118    0.009070    0.729818    
#> 407: 0.645257    0.963684    3.452649    0.365143    0.093202    0.009055    0.729936    
#> 408: 0.645298    0.963715    3.452625    0.365004    0.093256    0.009049    0.730015    
#> 409: 0.645179    0.963572    3.452595    0.364685    0.093258    0.009027    0.730061    
#> 410: 0.645171    0.963583    3.452539    0.364608    0.093296    0.009021    0.730079    
#> 411: 0.645040    0.963456    3.452480    0.364334    0.093173    0.009012    0.730213    
#> 412: 0.645058    0.963643    3.452433    0.364658    0.093161    0.009010    0.730271    
#> 413: 0.645054    0.963688    3.452400    0.364989    0.093181    0.008997    0.730266    
#> 414: 0.644829    0.963734    3.452408    0.365058    0.093175    0.008992    0.730266    
#> 415: 0.644946    0.963804    3.452384    0.365172    0.093157    0.008978    0.730342    
#> 416: 0.645112    0.963862    3.452400    0.365405    0.093221    0.008970    0.730331    
#> 417: 0.645309    0.963825    3.452394    0.365636    0.093215    0.008969    0.730321    
#> 418: 0.645097    0.963831    3.452407    0.365527    0.093185    0.008970    0.730342    
#> 419: 0.645276    0.963904    3.452411    0.365652    0.093191    0.008969    0.730347    
#> 420: 0.645334    0.963878    3.452438    0.365350    0.093149    0.008968    0.730352    
#> 421: 0.645372    0.963875    3.452516    0.365250    0.093154    0.008972    0.730278    
#> 422: 0.645500    0.963819    3.452588    0.364857    0.093152    0.008976    0.730313    
#> 423: 0.645734    0.963851    3.452650    0.364762    0.093197    0.008982    0.730309    
#> 424: 0.645579    0.963828    3.452662    0.364665    0.093152    0.008977    0.730313    
#> 425: 0.645816    0.963821    3.452654    0.364867    0.093148    0.008966    0.730323    
#> 426: 0.645849    0.963928    3.452642    0.365045    0.093173    0.008964    0.730311    
#> 427: 0.645689    0.963937    3.452635    0.364941    0.093099    0.008962    0.730321    
#> 428: 0.645465    0.964027    3.452624    0.364824    0.093160    0.008957    0.730339    
#> 429: 0.645486    0.964021    3.452655    0.364763    0.093167    0.008954    0.730337    
#> 430: 0.645531    0.964050    3.452658    0.364766    0.093290    0.008948    0.730306    
#> 431: 0.645382    0.964055    3.452613    0.364661    0.093337    0.008944    0.730226    
#> 432: 0.645342    0.964121    3.452618    0.364530    0.093421    0.008943    0.730206    
#> 433: 0.645520    0.964214    3.452683    0.364381    0.093477    0.008941    0.730204    
#> 434: 0.645465    0.964119    3.452730    0.364089    0.093481    0.008933    0.730176    
#> 435: 0.645668    0.964099    3.452726    0.364142    0.093435    0.008932    0.730075    
#> 436: 0.645806    0.963990    3.452781    0.364011    0.093393    0.008933    0.730087    
#> 437: 0.645837    0.963952    3.452770    0.363876    0.093440    0.008934    0.730101    
#> 438: 0.645945    0.964053    3.452832    0.363742    0.093367    0.008931    0.730058    
#> 439: 0.646017    0.964138    3.452851    0.363538    0.093387    0.008926    0.729995    
#> 440: 0.645823    0.964216    3.452841    0.363586    0.093331    0.008916    0.730050    
#> 441: 0.645852    0.964207    3.452863    0.363383    0.093350    0.008906    0.730014    
#> 442: 0.645741    0.964230    3.452887    0.363134    0.093374    0.008899    0.729974    
#> 443: 0.645729    0.964269    3.452876    0.363151    0.093362    0.008903    0.729950    
#> 444: 0.645532    0.964331    3.452827    0.363238    0.093366    0.008912    0.729897    
#> 445: 0.645336    0.964443    3.452778    0.362907    0.093271    0.008921    0.729938    
#> 446: 0.645130    0.964550    3.452726    0.362606    0.093320    0.008932    0.729916    
#> 447: 0.645098    0.964564    3.452704    0.362492    0.093304    0.008941    0.729903    
#> 448: 0.645036    0.964556    3.452729    0.362593    0.093306    0.008951    0.729808    
#> 449: 0.645105    0.964604    3.452815    0.362774    0.093366    0.008961    0.729808    
#> 450: 0.645077    0.964556    3.452803    0.362870    0.093337    0.008961    0.729881    
#> 451: 0.645038    0.964565    3.452748    0.362692    0.093334    0.008958    0.729905    
#> 452: 0.644973    0.964609    3.452705    0.362637    0.093303    0.008952    0.729875    
#> 453: 0.644874    0.964661    3.452692    0.362704    0.093276    0.008947    0.729848    
#> 454: 0.644795    0.964734    3.452656    0.362795    0.093253    0.008947    0.729823    
#> 455: 0.644889    0.964730    3.452640    0.362739    0.093209    0.008951    0.729836    
#> 456: 0.644883    0.964632    3.452642    0.362549    0.093217    0.008961    0.729841    
#> 457: 0.644816    0.964608    3.452641    0.362619    0.093180    0.008957    0.729787    
#> 458: 0.644683    0.964722    3.452654    0.362524    0.093146    0.008951    0.729761    
#> 459: 0.644589    0.964887    3.452646    0.362817    0.093232    0.008948    0.729676    
#> 460: 0.644411    0.964958    3.452588    0.362863    0.093305    0.008943    0.729600    
#> 461: 0.644254    0.965012    3.452580    0.362813    0.093326    0.008943    0.729593    
#> 462: 0.644120    0.965063    3.452585    0.363062    0.093308    0.008945    0.729498    
#> 463: 0.644230    0.965128    3.452625    0.363251    0.093243    0.008946    0.729514    
#> 464: 0.644355    0.965162    3.452645    0.363207    0.093222    0.008949    0.729476    
#> 465: 0.644526    0.965037    3.452662    0.363317    0.093252    0.008951    0.729444    
#> 466: 0.644663    0.965051    3.452647    0.363497    0.093305    0.008950    0.729403    
#> 467: 0.644735    0.964993    3.452676    0.363643    0.093279    0.008952    0.729355    
#> 468: 0.644908    0.964958    3.452703    0.363845    0.093303    0.008944    0.729365    
#> 469: 0.644929    0.964981    3.452734    0.363663    0.093317    0.008940    0.729419    
#> 470: 0.644865    0.964928    3.452712    0.363690    0.093313    0.008947    0.729414    
#> 471: 0.644727    0.964912    3.452688    0.363440    0.093301    0.008953    0.729340    
#> 472: 0.644624    0.964869    3.452692    0.363417    0.093267    0.008953    0.729299    
#> 473: 0.644569    0.964886    3.452700    0.363461    0.093233    0.008958    0.729189    
#> 474: 0.644495    0.964827    3.452708    0.363444    0.093276    0.008961    0.729259    
#> 475: 0.644500    0.964972    3.452696    0.363330    0.093258    0.008960    0.729277    
#> 476: 0.644526    0.964925    3.452682    0.363248    0.093317    0.008961    0.729311    
#> 477: 0.644569    0.964844    3.452733    0.363053    0.093334    0.008961    0.729262    
#> 478: 0.644559    0.964801    3.452748    0.362902    0.093349    0.008960    0.729295    
#> 479: 0.644599    0.964817    3.452745    0.362829    0.093373    0.008962    0.729285    
#> 480: 0.644627    0.964804    3.452750    0.362968    0.093312    0.008970    0.729353    
#> 481: 0.644561    0.964813    3.452741    0.363001    0.093281    0.008968    0.729357    
#> 482: 0.644605    0.964791    3.452733    0.362915    0.093277    0.008972    0.729457    
#> 483: 0.644626    0.964751    3.452740    0.362631    0.093225    0.008965    0.729470    
#> 484: 0.644607    0.964590    3.452800    0.362332    0.093233    0.008965    0.729468    
#> 485: 0.644624    0.964546    3.452846    0.362046    0.093319    0.008959    0.729456    
#> 486: 0.644774    0.964592    3.452907    0.362059    0.093276    0.008964    0.729481    
#> 487: 0.644954    0.964699    3.452994    0.361845    0.093217    0.008963    0.729505    
#> 488: 0.645000    0.964670    3.453056    0.361645    0.093241    0.008964    0.729519    
#> 489: 0.645106    0.964611    3.453089    0.361529    0.093277    0.008970    0.729511    
#> 490: 0.645268    0.964603    3.453139    0.361476    0.093273    0.008966    0.729559    
#> 491: 0.645287    0.964719    3.453175    0.361394    0.093283    0.008967    0.729548    
#> 492: 0.645244    0.964744    3.453176    0.361304    0.093299    0.008972    0.729568    
#> 493: 0.645107    0.964713    3.453189    0.361327    0.093324    0.008972    0.729540    
#> 494: 0.645198    0.964726    3.453160    0.361229    0.093262    0.008972    0.729478    
#> 495: 0.645214    0.964729    3.453157    0.361215    0.093207    0.008974    0.729434    
#> 496: 0.645398    0.964739    3.453167    0.361254    0.093173    0.008980    0.729398    
#> 497: 0.645429    0.964725    3.453195    0.361296    0.093088    0.008989    0.729446    
#> 498: 0.645566    0.964622    3.453214    0.361429    0.093079    0.008990    0.729440    
#> 499: 0.645633    0.964663    3.453229    0.361613    0.093090    0.008991    0.729387    
#> 500: 0.645660    0.964609    3.453217    0.361676    0.093002    0.008992    0.729332    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.300041    0.985777    3.446091    0.392401    0.082141    0.016800    1.708126    
#> 002: 0.394794    1.111756    3.469373    0.372781    0.078034    0.015960    1.074867    
#> 003: 0.597324    1.094890    3.522962    0.354142    0.074133    0.015162    0.828535    
#> 004: 0.627191    1.135052    3.546088    0.336435    0.070426    0.014404    0.755736    
#> 005: 0.661252    1.164168    3.538429    0.319613    0.066905    0.013684    0.709839    
#> 006: 0.662133    1.143696    3.533922    0.303633    0.063559    0.013000    0.668344    
#> 007: 0.610272    1.165282    3.526287    0.316364    0.060382    0.012350    0.661746    
#> 008: 0.599863    1.165363    3.522050    0.316108    0.057362    0.013376    0.658424    
#> 009: 0.573177    1.162074    3.513633    0.316416    0.054494    0.014457    0.661773    
#> 010: 0.582196    1.161773    3.516495    0.341027    0.051770    0.019598    0.666934    
#> 011: 0.647311    1.151923    3.527990    0.359698    0.049181    0.018618    0.676326    
#> 012: 0.652186    1.163162    3.520625    0.341713    0.046722    0.017687    0.652102    
#> 013: 0.580275    1.169190    3.519354    0.349758    0.044386    0.022127    0.664037    
#> 014: 0.682014    1.171519    3.539171    0.332270    0.042167    0.021020    0.675110    
#> 015: 0.668241    1.174217    3.546004    0.336955    0.040058    0.019969    0.630693    
#> 016: 0.677552    1.172431    3.552740    0.320987    0.038055    0.020581    0.648270    
#> 017: 0.692003    1.156210    3.551064    0.367384    0.036153    0.020913    0.634339    
#> 018: 0.662500    1.168536    3.537416    0.363737    0.034345    0.019867    0.652382    
#> 019: 0.618414    1.168603    3.531275    0.345550    0.032628    0.018874    0.646789    
#> 020: 0.627166    1.171873    3.539132    0.328272    0.030996    0.017930    0.649808    
#> 021: 0.659157    1.157941    3.552271    0.311859    0.029447    0.017034    0.646186    
#> 022: 0.661821    1.144276    3.556499    0.310005    0.027974    0.016182    0.665046    
#> 023: 0.771089    1.160585    3.574354    0.380093    0.026735    0.016210    0.669352    
#> 024: 0.759930    1.174999    3.565280    0.362495    0.025399    0.015670    0.662164    
#> 025: 0.707402    1.156005    3.562223    0.344371    0.024129    0.017802    0.642783    
#> 026: 0.669008    1.158775    3.546913    0.327152    0.022922    0.018757    0.648615    
#> 027: 0.648970    1.184605    3.540756    0.407423    0.021776    0.019367    0.660980    
#> 028: 0.722341    1.173409    3.552280    0.387052    0.020687    0.020111    0.646876    
#> 029: 0.672611    1.175053    3.530134    0.394237    0.019653    0.020540    0.658826    
#> 030: 0.666674    1.192297    3.529507    0.374525    0.018670    0.021048    0.667252    
#> 031: 0.667669    1.169452    3.535554    0.418126    0.017737    0.019996    0.649614    
#> 032: 0.636328    1.160925    3.531651    0.397220    0.019946    0.018996    0.644526    
#> 033: 0.572523    1.186941    3.516461    0.377359    0.026311    0.018046    0.652341    
#> 034: 0.625468    1.191066    3.525388    0.358491    0.024995    0.017144    0.639670    
#> 035: 0.622190    1.164477    3.524538    0.342853    0.023746    0.016286    0.634702    
#> 036: 0.628168    1.181936    3.521622    0.350781    0.023676    0.015472    0.658534    
#> 037: 0.620543    1.188533    3.530977    0.333242    0.032905    0.014699    0.671904    
#> 038: 0.646695    1.196815    3.514313    0.369956    0.033496    0.013964    0.666062    
#> 039: 0.619597    1.195555    3.516764    0.351458    0.032276    0.013265    0.663495    
#> 040: 0.627483    1.195786    3.531065    0.423330    0.030662    0.012724    0.675440    
#> 041: 0.613090    1.178479    3.523497    0.436659    0.029129    0.012244    0.670939    
#> 042: 0.678413    1.164893    3.532571    0.414826    0.029553    0.014915    0.655215    
#> 043: 0.621470    1.183501    3.519268    0.394084    0.028200    0.014191    0.658964    
#> 044: 0.601164    1.184045    3.523749    0.374380    0.026961    0.013482    0.654116    
#> 045: 0.581069    1.214830    3.505338    0.365397    0.032971    0.013592    0.651551    
#> 046: 0.605242    1.191753    3.516421    0.347127    0.031322    0.012912    0.654409    
#> 047: 0.597586    1.194042    3.512120    0.333735    0.029756    0.012763    0.659637    
#> 048: 0.638788    1.189933    3.515272    0.359814    0.028268    0.019329    0.665832    
#> 049: 0.624107    1.187007    3.529629    0.341824    0.026855    0.019896    0.656114    
#> 050: 0.676292    1.158145    3.541498    0.404290    0.025512    0.021324    0.677886    
#> 051: 0.652401    1.180467    3.530315    0.384075    0.024237    0.020258    0.664675    
#> 052: 0.672998    1.195008    3.541517    0.418087    0.024987    0.019245    0.648415    
#> 053: 0.675423    1.169611    3.546897    0.397182    0.023737    0.018283    0.648454    
#> 054: 0.629974    1.166689    3.544181    0.377323    0.022550    0.019820    0.669503    
#> 055: 0.653183    1.166367    3.544795    0.358457    0.021423    0.018829    0.663361    
#> 056: 0.675197    1.159317    3.548091    0.340534    0.022464    0.017888    0.662193    
#> 057: 0.696850    1.166409    3.555675    0.365066    0.021341    0.017947    0.675485    
#> 058: 0.690955    1.175343    3.540503    0.346813    0.020274    0.017723    0.667758    
#> 059: 0.666665    1.152290    3.541446    0.367690    0.026541    0.016836    0.666419    
#> 060: 0.652823    1.134509    3.548468    0.349306    0.025214    0.018097    0.683987    
#> 061: 0.688244    1.128553    3.558227    0.331840    0.023953    0.020506    0.676072    
#> 062: 0.697807    1.150918    3.565325    0.341748    0.022755    0.025242    0.663482    
#> 063: 0.735183    1.142323    3.558868    0.332963    0.021617    0.029464    0.678980    
#> 064: 0.724864    1.137498    3.570796    0.316315    0.020537    0.029208    0.686315    
#> 065: 0.708302    1.126026    3.561782    0.300499    0.019510    0.030505    0.680437    
#> 066: 0.699695    1.132535    3.565800    0.319342    0.018534    0.030749    0.653555    
#> 067: 0.674608    1.157958    3.550868    0.327888    0.017608    0.029212    0.657159    
#> 068: 0.651477    1.166946    3.552749    0.311493    0.016727    0.027751    0.652681    
#> 069: 0.634966    1.173481    3.532909    0.295919    0.015891    0.026363    0.671336    
#> 070: 0.646371    1.172688    3.538418    0.343806    0.017055    0.025045    0.654804    
#> 071: 0.625466    1.188811    3.516214    0.380156    0.017678    0.023793    0.686552    
#> 072: 0.598887    1.173471    3.514902    0.401588    0.017772    0.022603    0.660366    
#> 073: 0.657501    1.176164    3.538248    0.450279    0.016883    0.022181    0.629861    
#> 074: 0.676863    1.168379    3.533872    0.427765    0.016039    0.021072    0.644519    
#> 075: 0.684789    1.155070    3.559409    0.406377    0.016268    0.024850    0.640890    
#> 076: 0.720511    1.162294    3.574618    0.386058    0.015455    0.028675    0.662030    
#> 077: 0.729462    1.162399    3.564931    0.367371    0.014682    0.027241    0.661434    
#> 078: 0.696959    1.154240    3.562511    0.349003    0.013948    0.025879    0.664051    
#> 079: 0.663422    1.158142    3.542172    0.331552    0.016808    0.024585    0.668673    
#> 080: 0.675909    1.153445    3.546371    0.387419    0.020918    0.023356    0.665934    
#> 081: 0.665211    1.148919    3.542540    0.410051    0.019872    0.022188    0.657119    
#> 082: 0.636794    1.149090    3.543398    0.389548    0.018879    0.021079    0.664110    
#> 083: 0.702994    1.145033    3.552809    0.370071    0.017935    0.021489    0.662494    
#> 084: 0.632813    1.165095    3.533941    0.351567    0.017038    0.020414    0.660456    
#> 085: 0.636992    1.155934    3.540239    0.333989    0.016307    0.019393    0.667799    
#> 086: 0.598603    1.161490    3.531563    0.317290    0.016583    0.018903    0.665694    
#> 087: 0.635829    1.165120    3.537429    0.336503    0.015754    0.021181    0.682294    
#> 088: 0.600505    1.153289    3.544951    0.319678    0.014966    0.020533    0.680100    
#> 089: 0.644999    1.159147    3.534495    0.303694    0.014218    0.019734    0.656576    
#> 090: 0.633952    1.171625    3.523754    0.305983    0.015610    0.019975    0.654105    
#> 091: 0.601587    1.156544    3.517918    0.336289    0.014829    0.018976    0.654100    
#> 092: 0.596663    1.166501    3.515537    0.332359    0.014088    0.021399    0.655650    
#> 093: 0.592070    1.156274    3.519714    0.329705    0.013383    0.020329    0.663652    
#> 094: 0.661355    1.157590    3.534273    0.403203    0.012714    0.019313    0.660381    
#> 095: 0.646910    1.161412    3.544714    0.383043    0.014340    0.019855    0.649209    
#> 096: 0.628277    1.160333    3.546758    0.363891    0.016679    0.019668    0.650780    
#> 097: 0.685075    1.168464    3.545541    0.395160    0.015845    0.020284    0.664877    
#> 098: 0.707595    1.176544    3.561204    0.392963    0.015052    0.019270    0.679163    
#> 099: 0.696577    1.155584    3.543158    0.381164    0.014300    0.021976    0.659870    
#> 100: 0.655540    1.146263    3.541947    0.362105    0.013585    0.021204    0.657042    
#> 101: 0.609780    1.139734    3.521521    0.344000    0.012906    0.020143    0.645071    
#> 102: 0.596221    1.137369    3.511623    0.326800    0.012260    0.020334    0.657119    
#> 103: 0.640834    1.137651    3.531659    0.367669    0.011647    0.021413    0.659761    
#> 104: 0.638489    1.143539    3.545003    0.420732    0.013189    0.022589    0.664472    
#> 105: 0.648787    1.142230    3.550056    0.399695    0.013516    0.021460    0.658199    
#> 106: 0.692741    1.156050    3.547213    0.379710    0.014748    0.024313    0.658151    
#> 107: 0.710092    1.163349    3.555316    0.360725    0.014239    0.029162    0.652040    
#> 108: 0.696014    1.160816    3.557462    0.342689    0.013947    0.027704    0.672145    
#> 109: 0.657907    1.167510    3.559804    0.368710    0.016640    0.026318    0.669464    
#> 110: 0.652883    1.170798    3.528040    0.350275    0.015808    0.025002    0.651548    
#> 111: 0.656937    1.181765    3.537400    0.333713    0.015018    0.023752    0.655188    
#> 112: 0.663127    1.158053    3.529166    0.348024    0.014267    0.022565    0.648102    
#> 113: 0.668868    1.168743    3.539541    0.342221    0.015811    0.022709    0.641304    
#> 114: 0.681719    1.179391    3.538117    0.362086    0.015020    0.023022    0.649240    
#> 115: 0.671182    1.152227    3.538008    0.343982    0.016682    0.021871    0.661588    
#> 116: 0.662452    1.168133    3.532413    0.326783    0.015847    0.024617    0.655355    
#> 117: 0.650571    1.181401    3.542276    0.349041    0.015695    0.023386    0.658706    
#> 118: 0.671816    1.181890    3.537603    0.331589    0.018306    0.022217    0.642109    
#> 119: 0.666172    1.165752    3.539432    0.355257    0.017390    0.022658    0.647813    
#> 120: 0.600458    1.167015    3.523663    0.337494    0.017088    0.022774    0.643757    
#> 121: 0.613174    1.172058    3.535533    0.320619    0.016890    0.024044    0.662304    
#> 122: 0.644900    1.169189    3.536242    0.366939    0.020123    0.023704    0.665964    
#> 123: 0.640989    1.187198    3.525355    0.361328    0.020106    0.023885    0.656590    
#> 124: 0.642482    1.210241    3.527930    0.343262    0.022332    0.022991    0.654055    
#> 125: 0.675480    1.212137    3.529968    0.326099    0.021215    0.023006    0.652722    
#> 126: 0.653135    1.206099    3.523644    0.316885    0.020155    0.024473    0.664503    
#> 127: 0.682202    1.199234    3.522457    0.314666    0.019147    0.027209    0.672636    
#> 128: 0.630539    1.192690    3.541288    0.298932    0.020467    0.025848    0.650158    
#> 129: 0.686497    1.193651    3.555350    0.283986    0.019444    0.024556    0.669128    
#> 130: 0.677110    1.204529    3.545356    0.286495    0.018865    0.023328    0.640176    
#> 131: 0.671199    1.200928    3.535764    0.304075    0.017922    0.022162    0.646178    
#> 132: 0.627270    1.186492    3.515869    0.312822    0.020268    0.021053    0.652010    
#> 133: 0.661012    1.187390    3.526298    0.412544    0.021347    0.022345    0.649072    
#> 134: 0.681819    1.164156    3.549218    0.429034    0.022860    0.021228    0.638388    
#> 135: 0.667845    1.155868    3.552614    0.407583    0.022283    0.021710    0.637245    
#> 136: 0.695706    1.145957    3.551586    0.414450    0.023053    0.022364    0.643207    
#> 137: 0.715927    1.147792    3.553014    0.409695    0.022787    0.021246    0.658652    
#> 138: 0.674293    1.156347    3.546000    0.448968    0.027006    0.021919    0.650139    
#> 139: 0.704768    1.176535    3.555169    0.426519    0.025656    0.020823    0.663339    
#> 140: 0.616215    1.176266    3.542189    0.405193    0.034229    0.021659    0.681459    
#> 141: 0.605725    1.153878    3.534424    0.395324    0.033734    0.020576    0.663700    
#> 142: 0.665896    1.151040    3.544531    0.375558    0.032048    0.019547    0.656207    
#> 143: 0.602182    1.168020    3.548002    0.356780    0.030445    0.022587    0.663984    
#> 144: 0.680697    1.168045    3.553669    0.338941    0.028923    0.021458    0.644941    
#> 145: 0.629664    1.187270    3.542437    0.321994    0.027477    0.022653    0.664854    
#> 146: 0.650193    1.171748    3.555692    0.316122    0.026103    0.022063    0.666171    
#> 147: 0.635369    1.164314    3.536087    0.330302    0.024798    0.021113    0.659717    
#> 148: 0.642644    1.180710    3.535744    0.344229    0.023558    0.025672    0.647714    
#> 149: 0.646697    1.183747    3.523984    0.409938    0.022380    0.024388    0.648300    
#> 150: 0.623622    1.169829    3.506650    0.389441    0.021261    0.023169    0.672156    
#> 151: 0.583907    1.187330    3.506697    0.373840    0.020198    0.022010    0.642064    
#> 152: 0.645692    1.194913    3.528899    0.384512    0.019609    0.020952    0.646234    
#> 153: 0.614563    1.205560    3.532757    0.358217    0.021392    0.020583    0.644189    
#> 154: 0.668843    1.198504    3.537329    0.351808    0.021104    0.020792    0.657683    
#> 155: 0.638093    1.166146    3.533375    0.307743    0.023362    0.015559    0.659848    
#> 156: 0.644485    1.190359    3.537353    0.382734    0.029839    0.016863    0.648435    
#> 157: 0.707126    1.181733    3.555823    0.388225    0.033420    0.016785    0.662128    
#> 158: 0.677392    1.193530    3.540858    0.346971    0.032865    0.017303    0.665751    
#> 159: 0.619579    1.194874    3.543721    0.306760    0.024981    0.015947    0.673083    
#> 160: 0.647086    1.162044    3.547445    0.278248    0.023644    0.011344    0.685641    
#> 161: 0.616720    1.164957    3.535823    0.300303    0.027697    0.011110    0.675818    
#> 162: 0.616618    1.182354    3.524565    0.331640    0.027787    0.010712    0.663270    
#> 163: 0.648781    1.162982    3.525223    0.356736    0.028536    0.010572    0.658846    
#> 164: 0.687619    1.179964    3.540259    0.354820    0.029121    0.013231    0.651740    
#> 165: 0.709204    1.165927    3.554812    0.324604    0.024990    0.015710    0.660106    
#> 166: 0.734748    1.198644    3.543997    0.412526    0.024195    0.017733    0.661807    
#> 167: 0.723401    1.203997    3.559060    0.355202    0.024513    0.015048    0.681733    
#> 168: 0.725377    1.201814    3.554283    0.419285    0.028515    0.011755    0.649898    
#> 169: 0.677228    1.208524    3.537601    0.423393    0.030525    0.010592    0.662891    
#> 170: 0.649303    1.178323    3.532613    0.412765    0.027488    0.010828    0.663404    
#> 171: 0.606437    1.189997    3.522784    0.425425    0.022467    0.012260    0.647377    
#> 172: 0.587968    1.201285    3.518738    0.339938    0.022422    0.014751    0.650142    
#> 173: 0.621882    1.221820    3.510821    0.364592    0.024645    0.018207    0.657795    
#> 174: 0.646534    1.197755    3.531500    0.360527    0.023168    0.021674    0.659772    
#> 175: 0.612469    1.195318    3.511425    0.348855    0.027876    0.025935    0.663169    
#> 176: 0.587330    1.199070    3.528113    0.348059    0.019323    0.020771    0.649089    
#> 177: 0.627636    1.199496    3.534557    0.375144    0.018825    0.022555    0.632220    
#> 178: 0.664894    1.178375    3.535935    0.301887    0.021917    0.021265    0.644818    
#> 179: 0.697704    1.184225    3.539411    0.419749    0.023019    0.019935    0.665265    
#> 180: 0.670653    1.191575    3.533665    0.402982    0.020736    0.021372    0.652403    
#> 181: 0.673613    1.166390    3.521688    0.335506    0.013839    0.020907    0.648551    
#> 182: 0.603028    1.176470    3.513123    0.354758    0.016373    0.023410    0.674404    
#> 183: 0.622789    1.189566    3.518303    0.302315    0.019787    0.020940    0.666631    
#> 184: 0.636173    1.178029    3.525643    0.337770    0.017482    0.019739    0.671741    
#> 185: 0.597124    1.175694    3.522870    0.313912    0.017148    0.021583    0.665838    
#> 186: 0.585461    1.193074    3.515193    0.332556    0.010710    0.027863    0.673641    
#> 187: 0.629172    1.194915    3.517607    0.391867    0.012050    0.022238    0.651741    
#> 188: 0.594107    1.204704    3.517254    0.391332    0.015098    0.018265    0.648053    
#> 189: 0.618472    1.209866    3.527640    0.371343    0.017051    0.016530    0.676375    
#> 190: 0.631835    1.195218    3.537147    0.345273    0.015871    0.015569    0.664585    
#> 191: 0.612735    1.196695    3.522246    0.326238    0.019478    0.014699    0.650733    
#> 192: 0.600528    1.204506    3.513079    0.370766    0.021756    0.017297    0.654268    
#> 193: 0.638218    1.219511    3.517636    0.377067    0.020165    0.017701    0.661994    
#> 194: 0.605406    1.199866    3.506400    0.351517    0.018185    0.017890    0.670489    
#> 195: 0.589715    1.210454    3.510577    0.355107    0.022051    0.020566    0.663261    
#> 196: 0.613293    1.188333    3.529537    0.343661    0.026342    0.016269    0.664905    
#> 197: 0.610120    1.199555    3.541594    0.353122    0.025332    0.017442    0.680770    
#> 198: 0.660528    1.175897    3.530827    0.301544    0.020207    0.022252    0.654838    
#> 199: 0.643183    1.185714    3.534511    0.329877    0.018257    0.022370    0.659608    
#> 200: 0.663816    1.178954    3.536410    0.385408    0.019814    0.020073    0.650692    
#> 201: 0.660033    1.170388    3.539868    0.397873    0.017677    0.020759    0.647833    
#> 202: 0.665373    1.168316    3.540634    0.404199    0.016996    0.020258    0.649073    
#> 203: 0.670906    1.165501    3.540393    0.398571    0.016426    0.020363    0.651097    
#> 204: 0.668979    1.158607    3.542641    0.391559    0.016060    0.020985    0.657560    
#> 205: 0.666927    1.159749    3.541574    0.386230    0.015211    0.021865    0.662497    
#> 206: 0.667372    1.161509    3.542597    0.396849    0.014857    0.021629    0.662005    
#> 207: 0.669001    1.160546    3.541644    0.394852    0.014591    0.021440    0.660504    
#> 208: 0.667316    1.159403    3.541459    0.387664    0.014637    0.021431    0.658577    
#> 209: 0.669207    1.157465    3.541343    0.385471    0.015026    0.021135    0.656707    
#> 210: 0.670859    1.156693    3.541464    0.379958    0.014578    0.021010    0.656537    
#> 211: 0.669625    1.156742    3.541490    0.374403    0.014513    0.020727    0.656919    
#> 212: 0.670776    1.156176    3.542053    0.367561    0.014686    0.020693    0.657007    
#> 213: 0.673045    1.153837    3.543286    0.361298    0.015420    0.020400    0.657731    
#> 214: 0.675127    1.152565    3.544075    0.363063    0.015613    0.020216    0.657815    
#> 215: 0.676308    1.152048    3.545314    0.362249    0.015753    0.020013    0.658636    
#> 216: 0.680467    1.151119    3.546141    0.361591    0.016089    0.019942    0.658360    
#> 217: 0.681262    1.150743    3.546807    0.359291    0.016268    0.019998    0.656904    
#> 218: 0.680949    1.150840    3.546972    0.360857    0.016306    0.020081    0.656042    
#> 219: 0.680980    1.150580    3.546713    0.364965    0.016278    0.020125    0.655800    
#> 220: 0.679829    1.150943    3.546251    0.364538    0.016288    0.020254    0.656306    
#> 221: 0.678534    1.151109    3.545962    0.364322    0.016342    0.020071    0.656145    
#> 222: 0.676891    1.151076    3.545163    0.365805    0.016433    0.019871    0.655799    
#> 223: 0.677855    1.151170    3.544919    0.366436    0.016452    0.019593    0.655767    
#> 224: 0.678743    1.151008    3.544912    0.367708    0.016414    0.019578    0.655223    
#> 225: 0.677739    1.150396    3.544949    0.369745    0.016524    0.019561    0.655082    
#> 226: 0.676125    1.149648    3.544391    0.369237    0.016737    0.019514    0.655033    
#> 227: 0.674925    1.149774    3.544548    0.370082    0.016652    0.019595    0.654349    
#> 228: 0.675748    1.150643    3.544184    0.373411    0.016771    0.019690    0.653600    
#> 229: 0.675377    1.150539    3.544108    0.373445    0.016820    0.019665    0.653159    
#> 230: 0.675543    1.149984    3.543976    0.374075    0.016950    0.019708    0.652995    
#> 231: 0.675169    1.150332    3.543827    0.375048    0.017160    0.019748    0.652846    
#> 232: 0.673902    1.150278    3.543905    0.374559    0.017261    0.019808    0.652790    
#> 233: 0.673347    1.149843    3.543908    0.375151    0.017277    0.019894    0.652955    
#> 234: 0.672095    1.150102    3.543774    0.374336    0.017176    0.020036    0.652983    
#> 235: 0.670956    1.150373    3.543428    0.375004    0.017140    0.020092    0.653089    
#> 236: 0.671377    1.150933    3.543164    0.374620    0.017099    0.020114    0.653505    
#> 237: 0.672450    1.151046    3.543370    0.375502    0.017098    0.020253    0.654238    
#> 238: 0.672465    1.151178    3.543206    0.375854    0.017010    0.020318    0.654497    
#> 239: 0.672401    1.151533    3.543037    0.376350    0.016974    0.020266    0.654509    
#> 240: 0.672412    1.151714    3.543095    0.374561    0.016886    0.020244    0.654768    
#> 241: 0.672417    1.151520    3.543155    0.373655    0.016784    0.020154    0.655236    
#> 242: 0.671734    1.151330    3.542927    0.372624    0.016787    0.020118    0.655977    
#> 243: 0.671538    1.151528    3.543165    0.371694    0.016758    0.020163    0.656400    
#> 244: 0.671484    1.151329    3.543217    0.373671    0.016798    0.020220    0.656422    
#> 245: 0.671831    1.151209    3.543331    0.374381    0.016780    0.020399    0.656522    
#> 246: 0.671265    1.151371    3.543085    0.374948    0.016821    0.020524    0.656437    
#> 247: 0.670861    1.151401    3.543054    0.373771    0.016863    0.020517    0.656403    
#> 248: 0.670232    1.151714    3.542740    0.373277    0.016906    0.020580    0.656085    
#> 249: 0.669350    1.151928    3.542480    0.372611    0.017025    0.020607    0.656029    
#> 250: 0.669909    1.152217    3.542650    0.372171    0.017141    0.020725    0.655975    
#> 251: 0.670054    1.152486    3.542899    0.372309    0.017246    0.020774    0.655859    
#> 252: 0.670471    1.152719    3.543310    0.371205    0.017259    0.020835    0.655737    
#> 253: 0.670904    1.153064    3.543535    0.370596    0.017225    0.020895    0.655977    
#> 254: 0.671760    1.153189    3.543835    0.370811    0.017212    0.020937    0.656141    
#> 255: 0.671930    1.153133    3.544111    0.370664    0.017131    0.021070    0.656254    
#> 256: 0.672268    1.152843    3.544333    0.369511    0.017051    0.021118    0.656256    
#> 257: 0.671802    1.152512    3.544337    0.369367    0.016966    0.021124    0.656380    
#> 258: 0.671618    1.152446    3.544291    0.369237    0.017020    0.021085    0.656014    
#> 259: 0.671725    1.152316    3.544194    0.368600    0.017023    0.021105    0.655871    
#> 260: 0.671503    1.152454    3.544210    0.368949    0.017023    0.021141    0.655722    
#> 261: 0.671916    1.152428    3.544309    0.370562    0.017012    0.021164    0.655320    
#> 262: 0.672134    1.152288    3.544396    0.370556    0.017006    0.021165    0.655309    
#> 263: 0.672115    1.152347    3.544323    0.370082    0.016938    0.021161    0.655489    
#> 264: 0.671448    1.152462    3.544149    0.369891    0.016987    0.021142    0.655600    
#> 265: 0.671443    1.152542    3.544177    0.369872    0.017026    0.021115    0.655714    
#> 266: 0.671489    1.152746    3.544306    0.369108    0.017044    0.021133    0.655782    
#> 267: 0.671470    1.152876    3.544491    0.368980    0.017023    0.021181    0.655776    
#> 268: 0.671103    1.152829    3.544387    0.368891    0.016966    0.021177    0.655770    
#> 269: 0.672271    1.152573    3.544524    0.368929    0.016929    0.021203    0.655697    
#> 270: 0.672338    1.152533    3.544457    0.369341    0.016910    0.021161    0.655442    
#> 271: 0.672510    1.152491    3.544417    0.369878    0.016849    0.021137    0.655350    
#> 272: 0.672656    1.152288    3.544535    0.369495    0.016795    0.021125    0.655449    
#> 273: 0.672542    1.152295    3.544633    0.369434    0.016804    0.021097    0.655518    
#> 274: 0.672558    1.152236    3.544750    0.368990    0.016772    0.021071    0.655293    
#> 275: 0.672557    1.152218    3.544743    0.368529    0.016673    0.021037    0.655158    
#> 276: 0.672466    1.152365    3.544861    0.367825    0.016599    0.021040    0.655038    
#> 277: 0.672202    1.152454    3.545034    0.367391    0.016538    0.021051    0.655096    
#> 278: 0.671918    1.152645    3.545017    0.367658    0.016495    0.021070    0.654826    
#> 279: 0.671605    1.152741    3.545042    0.367694    0.016511    0.021075    0.654830    
#> 280: 0.671404    1.153106    3.545015    0.367159    0.016602    0.021049    0.654721    
#> 281: 0.671025    1.153288    3.545041    0.366348    0.016674    0.021054    0.654607    
#> 282: 0.670739    1.153493    3.545100    0.365267    0.016648    0.020982    0.654736    
#> 283: 0.670342    1.153780    3.545129    0.364314    0.016674    0.020952    0.655195    
#> 284: 0.670418    1.153779    3.545149    0.363965    0.016681    0.020876    0.655114    
#> 285: 0.670250    1.153987    3.544983    0.364005    0.016709    0.020798    0.655089    
#> 286: 0.669981    1.154228    3.544950    0.363739    0.016783    0.020771    0.654923    
#> 287: 0.669611    1.154484    3.544813    0.363450    0.016859    0.020744    0.654885    
#> 288: 0.669518    1.154646    3.544785    0.363453    0.016938    0.020734    0.654865    
#> 289: 0.669545    1.154832    3.544746    0.363646    0.016952    0.020737    0.654818    
#> 290: 0.669557    1.155003    3.544695    0.364219    0.016935    0.020784    0.654983    
#> 291: 0.669227    1.155207    3.544639    0.364518    0.016959    0.020812    0.654908    
#> 292: 0.669096    1.155162    3.544592    0.364524    0.016948    0.020840    0.654854    
#> 293: 0.669013    1.155184    3.544482    0.363963    0.016900    0.020829    0.654865    
#> 294: 0.668825    1.155271    3.544403    0.363310    0.016881    0.020852    0.654942    
#> 295: 0.669139    1.155022    3.544494    0.362973    0.016856    0.020838    0.654876    
#> 296: 0.669353    1.154796    3.544589    0.363319    0.016857    0.020809    0.654916    
#> 297: 0.669579    1.154804    3.544579    0.363068    0.016888    0.020795    0.654887    
#> 298: 0.669736    1.154748    3.544606    0.363220    0.016891    0.020833    0.654852    
#> 299: 0.669878    1.154814    3.544530    0.363437    0.016876    0.020857    0.654827    
#> 300: 0.670366    1.154815    3.544661    0.363464    0.016873    0.020875    0.654753    
#> 301: 0.670684    1.154708    3.544627    0.364060    0.016837    0.020851    0.654901    
#> 302: 0.670780    1.154793    3.544567    0.364538    0.016818    0.020862    0.654790    
#> 303: 0.670210    1.154914    3.544459    0.364368    0.016822    0.020872    0.654622    
#> 304: 0.669905    1.155228    3.544297    0.363859    0.016831    0.020877    0.654463    
#> 305: 0.669519    1.155263    3.544265    0.363361    0.016819    0.020890    0.654432    
#> 306: 0.669147    1.155382    3.544160    0.362649    0.016805    0.020895    0.654510    
#> 307: 0.668805    1.155430    3.544016    0.362796    0.016780    0.020866    0.654714    
#> 308: 0.668185    1.155462    3.543909    0.362749    0.016762    0.020821    0.654903    
#> 309: 0.667742    1.155464    3.543717    0.362891    0.016779    0.020780    0.655043    
#> 310: 0.667934    1.155479    3.543609    0.363734    0.016780    0.020765    0.655114    
#> 311: 0.667760    1.155629    3.543490    0.363884    0.016790    0.020759    0.654908    
#> 312: 0.667563    1.155653    3.543396    0.364163    0.016795    0.020792    0.654777    
#> 313: 0.667488    1.155611    3.543238    0.364517    0.016794    0.020812    0.654878    
#> 314: 0.667084    1.155616    3.543107    0.364898    0.016771    0.020818    0.654868    
#> 315: 0.666735    1.155576    3.543069    0.365191    0.016753    0.020809    0.654733    
#> 316: 0.666583    1.155629    3.543049    0.364737    0.016750    0.020795    0.654679    
#> 317: 0.666607    1.155618    3.543069    0.364774    0.016779    0.020795    0.654682    
#> 318: 0.666590    1.155639    3.542959    0.365315    0.016771    0.020779    0.654648    
#> 319: 0.666466    1.155582    3.542976    0.365837    0.016776    0.020785    0.654694    
#> 320: 0.666239    1.155572    3.542946    0.366105    0.016791    0.020815    0.654683    
#> 321: 0.666015    1.155630    3.542842    0.366211    0.016805    0.020828    0.654658    
#> 322: 0.665842    1.155611    3.542732    0.366616    0.016790    0.020849    0.654639    
#> 323: 0.665462    1.155565    3.542639    0.366854    0.016814    0.020847    0.654559    
#> 324: 0.665402    1.155614    3.542665    0.366951    0.016856    0.020823    0.654507    
#> 325: 0.665379    1.155659    3.542714    0.366499    0.016882    0.020819    0.654514    
#> 326: 0.665506    1.155429    3.542782    0.366079    0.016905    0.020811    0.654566    
#> 327: 0.665600    1.155348    3.542917    0.365897    0.016915    0.020803    0.654629    
#> 328: 0.665496    1.155418    3.542954    0.365433    0.016907    0.020799    0.654608    
#> 329: 0.665556    1.155417    3.543047    0.365396    0.016898    0.020825    0.654571    
#> 330: 0.665336    1.155431    3.543112    0.364785    0.016868    0.020868    0.654484    
#> 331: 0.665162    1.155527    3.543148    0.364096    0.016850    0.020928    0.654509    
#> 332: 0.665104    1.155417    3.543195    0.363356    0.016847    0.020960    0.654707    
#> 333: 0.665194    1.155289    3.543207    0.362891    0.016844    0.020941    0.654888    
#> 334: 0.665298    1.155173    3.543187    0.363058    0.016840    0.020925    0.654811    
#> 335: 0.665203    1.155137    3.543188    0.362987    0.016804    0.020915    0.654836    
#> 336: 0.664954    1.155154    3.543132    0.362681    0.016800    0.020900    0.654880    
#> 337: 0.664597    1.155224    3.543017    0.362369    0.016768    0.020878    0.654913    
#> 338: 0.664338    1.155407    3.542987    0.362198    0.016785    0.020852    0.654902    
#> 339: 0.664184    1.155658    3.542870    0.362252    0.016815    0.020840    0.654855    
#> 340: 0.663960    1.155790    3.542835    0.362069    0.016817    0.020843    0.654748    
#> 341: 0.664096    1.155833    3.542920    0.362092    0.016850    0.020855    0.654600    
#> 342: 0.663750    1.155775    3.542882    0.361945    0.016821    0.020851    0.654586    
#> 343: 0.663639    1.155771    3.542901    0.361735    0.016799    0.020828    0.654601    
#> 344: 0.663746    1.155778    3.542949    0.361313    0.016781    0.020842    0.654746    
#> 345: 0.663665    1.155759    3.543021    0.361209    0.016756    0.020840    0.654732    
#> 346: 0.663357    1.155800    3.542903    0.360780    0.016753    0.020841    0.654769    
#> 347: 0.663396    1.155740    3.542804    0.361042    0.016764    0.020855    0.654856    
#> 348: 0.663127    1.155767    3.542763    0.360941    0.016778    0.020893    0.654858    
#> 349: 0.662999    1.155835    3.542748    0.361034    0.016780    0.020940    0.654916    
#> 350: 0.663012    1.155911    3.542684    0.361654    0.016766    0.020957    0.654959    
#> 351: 0.663136    1.156075    3.542652    0.361876    0.016759    0.020981    0.654974    
#> 352: 0.663007    1.156136    3.542677    0.361598    0.016753    0.021020    0.655054    
#> 353: 0.662970    1.156319    3.542698    0.361283    0.016746    0.021079    0.655019    
#> 354: 0.662778    1.156507    3.542575    0.360835    0.016728    0.021114    0.655084    
#> 355: 0.663304    1.156499    3.542593    0.361211    0.016704    0.021117    0.655081    
#> 356: 0.663346    1.156436    3.542618    0.360689    0.016688    0.021121    0.655307    
#> 357: 0.663511    1.156445    3.542654    0.360451    0.016669    0.021116    0.655308    
#> 358: 0.663473    1.156449    3.542708    0.360326    0.016700    0.021116    0.655162    
#> 359: 0.663466    1.156480    3.542715    0.360243    0.016684    0.021110    0.655199    
#> 360: 0.663122    1.156564    3.542552    0.360022    0.016656    0.021098    0.655166    
#> 361: 0.662839    1.156590    3.542431    0.359863    0.016604    0.021098    0.655177    
#> 362: 0.662890    1.156650    3.542346    0.359873    0.016562    0.021108    0.655092    
#> 363: 0.662803    1.156584    3.542370    0.359347    0.016534    0.021092    0.655050    
#> 364: 0.662756    1.156649    3.542329    0.359402    0.016537    0.021064    0.655032    
#> 365: 0.662880    1.156626    3.542342    0.359611    0.016539    0.021033    0.655130    
#> 366: 0.662948    1.156621    3.542267    0.359413    0.016533    0.020999    0.655254    
#> 367: 0.662959    1.156646    3.542210    0.359762    0.016514    0.020989    0.655275    
#> 368: 0.663215    1.156686    3.542174    0.360092    0.016486    0.021003    0.655224    
#> 369: 0.663163    1.156772    3.542105    0.360200    0.016475    0.021012    0.655160    
#> 370: 0.663161    1.156894    3.542084    0.360262    0.016468    0.021038    0.655164    
#> 371: 0.662893    1.157033    3.541966    0.360254    0.016504    0.021019    0.655064    
#> 372: 0.662819    1.157120    3.541913    0.360456    0.016512    0.021025    0.654899    
#> 373: 0.662539    1.157237    3.541787    0.360555    0.016488    0.021031    0.654950    
#> 374: 0.662398    1.157307    3.541699    0.360837    0.016450    0.021039    0.654949    
#> 375: 0.662381    1.157273    3.541732    0.360811    0.016437    0.021052    0.654928    
#> 376: 0.662563    1.157269    3.541781    0.360934    0.016417    0.021059    0.654913    
#> 377: 0.662788    1.157254    3.541839    0.360873    0.016405    0.021076    0.654904    
#> 378: 0.662444    1.157280    3.541824    0.360599    0.016406    0.021094    0.654921    
#> 379: 0.662483    1.157190    3.541921    0.360225    0.016393    0.021097    0.654979    
#> 380: 0.662485    1.157140    3.541979    0.360089    0.016379    0.021098    0.654982    
#> 381: 0.662317    1.157060    3.541967    0.359922    0.016379    0.021084    0.654954    
#> 382: 0.662297    1.156987    3.541932    0.360127    0.016365    0.021067    0.654978    
#> 383: 0.662223    1.156924    3.541907    0.360128    0.016362    0.021058    0.654973    
#> 384: 0.662110    1.156853    3.541944    0.360414    0.016335    0.021102    0.654984    
#> 385: 0.662038    1.156819    3.541981    0.360316    0.016310    0.021132    0.654944    
#> 386: 0.662205    1.156852    3.542071    0.360182    0.016303    0.021171    0.654952    
#> 387: 0.662508    1.156884    3.542174    0.359968    0.016288    0.021181    0.655000    
#> 388: 0.662498    1.156905    3.542237    0.359647    0.016265    0.021182    0.655088    
#> 389: 0.662632    1.156817    3.542265    0.359777    0.016283    0.021186    0.655094    
#> 390: 0.662357    1.156878    3.542228    0.359455    0.016295    0.021190    0.655153    
#> 391: 0.662252    1.156879    3.542231    0.359412    0.016294    0.021187    0.655072    
#> 392: 0.662243    1.156835    3.542297    0.359591    0.016299    0.021185    0.655048    
#> 393: 0.661985    1.156878    3.542224    0.359373    0.016293    0.021202    0.655004    
#> 394: 0.661963    1.156911    3.542203    0.359599    0.016275    0.021194    0.654915    
#> 395: 0.662264    1.157007    3.542262    0.359697    0.016272    0.021212    0.654906    
#> 396: 0.662395    1.157159    3.542283    0.359626    0.016296    0.021221    0.654885    
#> 397: 0.662339    1.157207    3.542266    0.359474    0.016302    0.021217    0.654889    
#> 398: 0.662371    1.157260    3.542276    0.359489    0.016310    0.021209    0.654905    
#> 399: 0.662379    1.157324    3.542302    0.359421    0.016319    0.021200    0.654932    
#> 400: 0.662430    1.157430    3.542292    0.359255    0.016312    0.021203    0.654933    
#> 401: 0.662272    1.157567    3.542207    0.359317    0.016337    0.021226    0.654865    
#> 402: 0.662189    1.157720    3.542164    0.359155    0.016363    0.021233    0.654842    
#> 403: 0.662302    1.157746    3.542172    0.359110    0.016367    0.021221    0.654846    
#> 404: 0.662380    1.157802    3.542112    0.359285    0.016356    0.021217    0.654897    
#> 405: 0.662427    1.157812    3.542124    0.359706    0.016317    0.021231    0.654957    
#> 406: 0.662490    1.157787    3.542061    0.360116    0.016284    0.021263    0.655022    
#> 407: 0.662451    1.157799    3.542084    0.360125    0.016278    0.021299    0.655023    
#> 408: 0.662557    1.157865    3.542091    0.360290    0.016293    0.021319    0.655061    
#> 409: 0.662594    1.157894    3.542057    0.360214    0.016280    0.021328    0.655076    
#> 410: 0.662577    1.157924    3.542004    0.360431    0.016263    0.021315    0.655089    
#> 411: 0.662654    1.157819    3.541988    0.360633    0.016246    0.021309    0.655099    
#> 412: 0.662667    1.157815    3.542001    0.360743    0.016241    0.021307    0.655066    
#> 413: 0.662631    1.157761    3.541972    0.360926    0.016236    0.021308    0.655078    
#> 414: 0.662502    1.157734    3.541963    0.361065    0.016216    0.021300    0.655128    
#> 415: 0.662606    1.157722    3.541963    0.361208    0.016193    0.021300    0.655085    
#> 416: 0.662793    1.157740    3.541995    0.361111    0.016170    0.021303    0.655073    
#> 417: 0.662771    1.157724    3.542018    0.360843    0.016157    0.021301    0.655097    
#> 418: 0.662749    1.157736    3.542083    0.360619    0.016145    0.021310    0.655102    
#> 419: 0.662838    1.157813    3.542125    0.360625    0.016136    0.021325    0.655121    
#> 420: 0.662859    1.157865    3.542126    0.360605    0.016134    0.021323    0.655081    
#> 421: 0.662888    1.157860    3.542145    0.360648    0.016115    0.021327    0.655053    
#> 422: 0.663052    1.157726    3.542190    0.360561    0.016110    0.021323    0.655092    
#> 423: 0.663273    1.157601    3.542236    0.360564    0.016106    0.021323    0.655036    
#> 424: 0.663232    1.157546    3.542193    0.360537    0.016119    0.021310    0.655038    
#> 425: 0.663463    1.157534    3.542198    0.360944    0.016139    0.021318    0.655074    
#> 426: 0.663616    1.157570    3.542196    0.361081    0.016151    0.021339    0.655012    
#> 427: 0.663709    1.157568    3.542253    0.361304    0.016148    0.021339    0.654943    
#> 428: 0.663798    1.157545    3.542351    0.361300    0.016140    0.021332    0.654929    
#> 429: 0.663834    1.157559    3.542389    0.361335    0.016138    0.021329    0.654965    
#> 430: 0.663878    1.157596    3.542392    0.361384    0.016122    0.021317    0.655020    
#> 431: 0.663858    1.157631    3.542389    0.361023    0.016101    0.021307    0.655026    
#> 432: 0.663694    1.157649    3.542377    0.360637    0.016091    0.021313    0.655037    
#> 433: 0.663618    1.157709    3.542366    0.360576    0.016081    0.021311    0.655050    
#> 434: 0.663584    1.157702    3.542370    0.360284    0.016089    0.021291    0.655138    
#> 435: 0.663754    1.157680    3.542389    0.360265    0.016093    0.021269    0.655143    
#> 436: 0.663741    1.157610    3.542463    0.360085    0.016112    0.021242    0.655130    
#> 437: 0.663880    1.157561    3.542485    0.359911    0.016115    0.021221    0.655158    
#> 438: 0.663834    1.157655    3.542463    0.359702    0.016111    0.021197    0.655181    
#> 439: 0.663871    1.157689    3.542455    0.359575    0.016117    0.021181    0.655197    
#> 440: 0.663721    1.157728    3.542495    0.359508    0.016120    0.021181    0.655237    
#> 441: 0.663692    1.157711    3.542543    0.359398    0.016123    0.021179    0.655229    
#> 442: 0.663456    1.157744    3.542560    0.359297    0.016133    0.021168    0.655212    
#> 443: 0.663424    1.157803    3.542500    0.359423    0.016137    0.021147    0.655181    
#> 444: 0.663248    1.157835    3.542414    0.359418    0.016149    0.021135    0.655183    
#> 445: 0.663050    1.157867    3.542375    0.359342    0.016152    0.021148    0.655280    
#> 446: 0.662857    1.157961    3.542349    0.359253    0.016169    0.021137    0.655308    
#> 447: 0.663041    1.158054    3.542370    0.359318    0.016185    0.021134    0.655301    
#> 448: 0.663052    1.158115    3.542386    0.359529    0.016178    0.021149    0.655231    
#> 449: 0.663040    1.158178    3.542438    0.359823    0.016172    0.021158    0.655254    
#> 450: 0.663122    1.158211    3.542402    0.360293    0.016178    0.021170    0.655223    
#> 451: 0.663058    1.158320    3.542373    0.360314    0.016196    0.021165    0.655231    
#> 452: 0.663058    1.158371    3.542337    0.360470    0.016194    0.021164    0.655280    
#> 453: 0.662930    1.158436    3.542275    0.360636    0.016184    0.021168    0.655241    
#> 454: 0.662764    1.158535    3.542210    0.360598    0.016175    0.021182    0.655245    
#> 455: 0.662562    1.158615    3.542146    0.360555    0.016179    0.021197    0.655273    
#> 456: 0.662316    1.158680    3.542094    0.360175    0.016177    0.021190    0.655303    
#> 457: 0.662284    1.158707    3.542124    0.360132    0.016174    0.021186    0.655245    
#> 458: 0.662359    1.158766    3.542166    0.359952    0.016179    0.021170    0.655220    
#> 459: 0.662330    1.158844    3.542136    0.360038    0.016181    0.021156    0.655169    
#> 460: 0.662224    1.158888    3.542078    0.360095    0.016183    0.021146    0.655173    
#> 461: 0.662078    1.158924    3.542030    0.360141    0.016189    0.021135    0.655191    
#> 462: 0.661961    1.159014    3.542002    0.360399    0.016190    0.021128    0.655176    
#> 463: 0.661870    1.159036    3.541991    0.360521    0.016195    0.021136    0.655111    
#> 464: 0.661797    1.159105    3.541901    0.360725    0.016186    0.021141    0.655064    
#> 465: 0.661734    1.159069    3.541848    0.360995    0.016182    0.021135    0.654984    
#> 466: 0.661805    1.159098    3.541782    0.361162    0.016172    0.021137    0.654963    
#> 467: 0.661769    1.159106    3.541794    0.361146    0.016168    0.021125    0.654931    
#> 468: 0.662001    1.159071    3.541885    0.361005    0.016159    0.021130    0.654956    
#> 469: 0.662138    1.159039    3.541965    0.360778    0.016160    0.021135    0.655021    
#> 470: 0.661989    1.159062    3.541922    0.360628    0.016160    0.021126    0.655156    
#> 471: 0.661814    1.159099    3.541871    0.360299    0.016159    0.021122    0.655191    
#> 472: 0.661699    1.159119    3.541855    0.360086    0.016154    0.021108    0.655270    
#> 473: 0.661603    1.159186    3.541821    0.360196    0.016164    0.021091    0.655279    
#> 474: 0.661477    1.159261    3.541750    0.360410    0.016153    0.021090    0.655274    
#> 475: 0.661433    1.159405    3.541720    0.360500    0.016158    0.021092    0.655267    
#> 476: 0.661327    1.159435    3.541713    0.360406    0.016154    0.021095    0.655251    
#> 477: 0.661297    1.159472    3.541741    0.360300    0.016146    0.021101    0.655188    
#> 478: 0.661294    1.159519    3.541742    0.360350    0.016158    0.021113    0.655138    
#> 479: 0.661294    1.159638    3.541694    0.360369    0.016172    0.021110    0.655127    
#> 480: 0.661224    1.159747    3.541674    0.360423    0.016195    0.021123    0.655064    
#> 481: 0.661169    1.159800    3.541648    0.360564    0.016196    0.021125    0.654985    
#> 482: 0.661227    1.159808    3.541611    0.360633    0.016195    0.021114    0.654974    
#> 483: 0.661097    1.159808    3.541611    0.360483    0.016214    0.021103    0.654951    
#> 484: 0.661086    1.159768    3.541643    0.360329    0.016231    0.021112    0.654923    
#> 485: 0.661156    1.159801    3.541691    0.360090    0.016225    0.021109    0.654943    
#> 486: 0.661140    1.159804    3.541740    0.360106    0.016217    0.021107    0.654952    
#> 487: 0.661384    1.159843    3.541826    0.360234    0.016219    0.021105    0.654972    
#> 488: 0.661466    1.159824    3.541870    0.360354    0.016215    0.021095    0.654947    
#> 489: 0.661604    1.159783    3.541854    0.360432    0.016209    0.021089    0.654946    
#> 490: 0.661645    1.159839    3.541868    0.360549    0.016205    0.021081    0.654928    
#> 491: 0.661757    1.159911    3.541894    0.360580    0.016194    0.021080    0.654907    
#> 492: 0.661731    1.160019    3.541872    0.360667    0.016203    0.021095    0.654925    
#> 493: 0.661695    1.160058    3.541857    0.360618    0.016214    0.021096    0.654997    
#> 494: 0.661761    1.160149    3.541794    0.360573    0.016213    0.021087    0.655021    
#> 495: 0.661792    1.160207    3.541779    0.360656    0.016217    0.021075    0.655000    
#> 496: 0.661758    1.160324    3.541706    0.360772    0.016212    0.021059    0.654999    
#> 497: 0.661600    1.160352    3.541679    0.360902    0.016212    0.021051    0.655058    
#> 498: 0.661612    1.160422    3.541642    0.361111    0.016222    0.021053    0.655050    
#> 499: 0.661653    1.160487    3.541627    0.361129    0.016231    0.021042    0.654998    
#> 500: 0.661629    1.160519    3.541606    0.361217    0.016244    0.021027    0.654968    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.273181    0.982858    3.449411    0.392401    0.080265    0.016800    1.613820    
#> 002: 0.229251    1.065834    3.472790    0.372781    0.076252    0.016014    1.053533    
#> 003: 0.299680    1.047975    3.491174    0.354142    0.072439    0.015213    0.861501    
#> 004: 0.251193    1.083986    3.491424    0.336435    0.069779    0.014453    0.814911    
#> 005: 0.284933    1.089030    3.478659    0.319613    0.066290    0.013730    0.793099    
#> 006: 0.275739    1.092524    3.467181    0.303633    0.065339    0.017975    0.771889    
#> 007: 0.201001    1.108487    3.459360    0.288451    0.064642    0.017077    0.762190    
#> 008: 0.191888    1.105087    3.448755    0.274029    0.071486    0.018295    0.745432    
#> 009: 0.173105    1.094870    3.450580    0.260327    0.067912    0.018630    0.737972    
#> 010: 0.195819    1.099254    3.448482    0.247311    0.064740    0.020053    0.738452    
#> 011: 0.253091    1.097364    3.461291    0.234945    0.065150    0.023254    0.742483    
#> 012: 0.262040    1.097511    3.462066    0.223198    0.065926    0.023719    0.715544    
#> 013: 0.220957    1.100441    3.464650    0.212038    0.062630    0.023944    0.719885    
#> 014: 0.272792    1.096757    3.472330    0.201436    0.067939    0.022747    0.721672    
#> 015: 0.277985    1.094627    3.495637    0.191364    0.064542    0.024262    0.714157    
#> 016: 0.288116    1.100337    3.495008    0.181796    0.061315    0.026186    0.730102    
#> 017: 0.264908    1.120421    3.487128    0.172706    0.063033    0.029045    0.703885    
#> 018: 0.231881    1.128861    3.459680    0.164071    0.063248    0.027861    0.708866    
#> 019: 0.197723    1.115328    3.458933    0.155867    0.060085    0.030605    0.705329    
#> 020: 0.212924    1.120198    3.443062    0.148074    0.066005    0.029075    0.728319    
#> 021: 0.221110    1.088052    3.466329    0.140670    0.062705    0.027851    0.711308    
#> 022: 0.234465    1.089973    3.481487    0.133637    0.059570    0.027554    0.693339    
#> 023: 0.289299    1.114209    3.482407    0.126955    0.056591    0.027129    0.704500    
#> 024: 0.293789    1.128329    3.478647    0.127145    0.053761    0.027552    0.715756    
#> 025: 0.273564    1.094236    3.481628    0.133832    0.051073    0.028566    0.716243    
#> 026: 0.246761    1.120577    3.460505    0.127141    0.048520    0.027137    0.727821    
#> 027: 0.232577    1.126840    3.461125    0.137123    0.047689    0.033768    0.718378    
#> 028: 0.238805    1.122375    3.464046    0.156946    0.045305    0.035846    0.713205    
#> 029: 0.267669    1.108624    3.462330    0.160226    0.043040    0.037658    0.729362    
#> 030: 0.252889    1.138465    3.450565    0.186693    0.040888    0.038375    0.738382    
#> 031: 0.242616    1.123486    3.467019    0.177359    0.038843    0.039015    0.739359    
#> 032: 0.189718    1.113432    3.468871    0.168491    0.046857    0.038987    0.733877    
#> 033: 0.182196    1.127009    3.454660    0.160066    0.048873    0.041274    0.737395    
#> 034: 0.218375    1.139545    3.458903    0.152063    0.058071    0.039211    0.712422    
#> 035: 0.208049    1.108159    3.465309    0.144460    0.055167    0.037250    0.686723    
#> 036: 0.231433    1.140908    3.467271    0.137237    0.057724    0.035388    0.702496    
#> 037: 0.215057    1.132098    3.455965    0.131373    0.057964    0.033618    0.713566    
#> 038: 0.247456    1.120252    3.455477    0.124804    0.055066    0.031937    0.714219    
#> 039: 0.269049    1.123356    3.475180    0.118564    0.064963    0.030340    0.702796    
#> 040: 0.256916    1.105694    3.488457    0.112636    0.061715    0.028823    0.715461    
#> 041: 0.245374    1.089241    3.482353    0.107004    0.058629    0.027382    0.725311    
#> 042: 0.277232    1.083484    3.479013    0.137429    0.055698    0.026013    0.712298    
#> 043: 0.217887    1.104180    3.462886    0.130557    0.052913    0.026477    0.706009    
#> 044: 0.218250    1.128254    3.456564    0.124851    0.054536    0.025735    0.712211    
#> 045: 0.202163    1.161853    3.434804    0.154704    0.052614    0.024448    0.720999    
#> 046: 0.210289    1.133022    3.441161    0.146969    0.053258    0.024974    0.709418    
#> 047: 0.234709    1.140451    3.448395    0.139621    0.051918    0.029216    0.692649    
#> 048: 0.222949    1.109755    3.460472    0.132640    0.049882    0.031155    0.704835    
#> 049: 0.204750    1.121189    3.469325    0.126008    0.054152    0.029829    0.701032    
#> 050: 0.256371    1.106743    3.472329    0.151702    0.051444    0.028338    0.716090    
#> 051: 0.262751    1.118029    3.472701    0.144417    0.058873    0.026921    0.726290    
#> 052: 0.267135    1.106791    3.487621    0.137196    0.061396    0.025575    0.718823    
#> 053: 0.242963    1.105356    3.466557    0.130336    0.058327    0.024296    0.722558    
#> 054: 0.186517    1.126821    3.452035    0.123820    0.055410    0.023916    0.740142    
#> 055: 0.218167    1.114312    3.466992    0.117629    0.052640    0.024682    0.737301    
#> 056: 0.237741    1.106613    3.465908    0.111747    0.056501    0.028117    0.709098    
#> 057: 0.241194    1.107577    3.475379    0.115697    0.053676    0.028534    0.707558    
#> 058: 0.220597    1.110494    3.470945    0.122966    0.050992    0.027107    0.712090    
#> 059: 0.223588    1.077277    3.456894    0.127419    0.052520    0.025752    0.747465    
#> 060: 0.228467    1.073898    3.472152    0.121048    0.065170    0.024464    0.745928    
#> 061: 0.276590    1.082767    3.485482    0.114996    0.064423    0.023241    0.755896    
#> 062: 0.270756    1.097895    3.503674    0.109246    0.070096    0.022079    0.771849    
#> 063: 0.303520    1.067902    3.493179    0.117090    0.066591    0.020975    0.766956    
#> 064: 0.304425    1.098955    3.505122    0.111236    0.063262    0.028271    0.757895    
#> 065: 0.316167    1.063729    3.501738    0.105674    0.060098    0.034786    0.739548    
#> 066: 0.296038    1.084671    3.495110    0.100390    0.057094    0.033047    0.734450    
#> 067: 0.310779    1.087094    3.497422    0.100090    0.054239    0.031622    0.729673    
#> 068: 0.251187    1.103340    3.493603    0.110828    0.068723    0.032642    0.726016    
#> 069: 0.259956    1.107714    3.482214    0.110404    0.067236    0.036255    0.712267    
#> 070: 0.262925    1.097991    3.495217    0.116659    0.063874    0.036977    0.724353    
#> 071: 0.253969    1.109045    3.471812    0.128427    0.060680    0.035128    0.729578    
#> 072: 0.224457    1.086047    3.472845    0.150598    0.057646    0.048528    0.730871    
#> 073: 0.232739    1.105200    3.477141    0.181542    0.054764    0.046102    0.712869    
#> 074: 0.193555    1.098921    3.453633    0.172464    0.052026    0.043797    0.716603    
#> 075: 0.244854    1.088000    3.488656    0.163841    0.049424    0.041607    0.731544    
#> 076: 0.267439    1.096697    3.494174    0.155649    0.046953    0.040772    0.726016    
#> 077: 0.298770    1.086208    3.499737    0.147867    0.048759    0.038857    0.725125    
#> 078: 0.307421    1.087736    3.496565    0.141729    0.046321    0.036914    0.714219    
#> 079: 0.324121    1.102807    3.492134    0.175307    0.055671    0.035068    0.711545    
#> 080: 0.296604    1.099275    3.492896    0.166542    0.056111    0.037418    0.734718    
#> 081: 0.277731    1.111960    3.476667    0.158215    0.053306    0.038647    0.715951    
#> 082: 0.252901    1.095302    3.479651    0.150304    0.053949    0.036715    0.731251    
#> 083: 0.283863    1.105838    3.482166    0.142789    0.051251    0.034879    0.715985    
#> 084: 0.291540    1.105542    3.478433    0.135649    0.048689    0.033135    0.706869    
#> 085: 0.238461    1.129918    3.473065    0.128867    0.051823    0.031479    0.715298    
#> 086: 0.244601    1.118842    3.466824    0.122423    0.051188    0.029905    0.696877    
#> 087: 0.221934    1.106019    3.456698    0.116302    0.048628    0.028409    0.711773    
#> 088: 0.155588    1.115634    3.450914    0.110487    0.047774    0.027001    0.726582    
#> 089: 0.221730    1.136982    3.449385    0.104963    0.053027    0.029864    0.705146    
#> 090: 0.212733    1.121655    3.455905    0.099715    0.054052    0.028371    0.710912    
#> 091: 0.222097    1.110953    3.450217    0.105619    0.051349    0.028530    0.706747    
#> 092: 0.198147    1.113840    3.447631    0.108963    0.050451    0.027104    0.715784    
#> 093: 0.169552    1.107511    3.444504    0.103515    0.047929    0.032030    0.720479    
#> 094: 0.172448    1.146336    3.442206    0.098339    0.045532    0.030773    0.731927    
#> 095: 0.212024    1.128707    3.474086    0.093422    0.043256    0.044801    0.732338    
#> 096: 0.212982    1.121483    3.467057    0.121629    0.050843    0.042561    0.726638    
#> 097: 0.263935    1.111771    3.469465    0.128186    0.048301    0.040433    0.711714    
#> 098: 0.248210    1.116561    3.484798    0.121777    0.045885    0.038411    0.703797    
#> 099: 0.261464    1.105415    3.469435    0.137013    0.043591    0.036490    0.696696    
#> 100: 0.221355    1.094032    3.471933    0.130162    0.041412    0.034666    0.727251    
#> 101: 0.193227    1.103346    3.451821    0.123654    0.049370    0.032933    0.713253    
#> 102: 0.174510    1.104291    3.439004    0.127329    0.046902    0.036153    0.715519    
#> 103: 0.223385    1.116187    3.455188    0.139745    0.049916    0.034346    0.701330    
#> 104: 0.248300    1.098073    3.476935    0.141679    0.047421    0.034874    0.717198    
#> 105: 0.266317    1.109733    3.483052    0.137352    0.048579    0.033130    0.703042    
#> 106: 0.271854    1.110644    3.474779    0.161377    0.051073    0.031473    0.714148    
#> 107: 0.291849    1.108335    3.484028    0.169326    0.060673    0.030422    0.718375    
#> 108: 0.286568    1.095108    3.500494    0.160860    0.057639    0.028901    0.734265    
#> 109: 0.229584    1.102563    3.490137    0.152817    0.054757    0.030839    0.722246    
#> 110: 0.242343    1.102256    3.466631    0.145176    0.052019    0.029297    0.695530    
#> 111: 0.239756    1.116659    3.473878    0.137917    0.051652    0.027832    0.707697    
#> 112: 0.247434    1.098146    3.464891    0.131022    0.049358    0.027619    0.722878    
#> 113: 0.242939    1.128661    3.473492    0.124470    0.049794    0.031549    0.701743    
#> 114: 0.256889    1.144207    3.476446    0.123175    0.047304    0.029971    0.724433    
#> 115: 0.287479    1.099444    3.470056    0.138721    0.044939    0.030637    0.746058    
#> 116: 0.281513    1.099224    3.482673    0.131785    0.055162    0.035602    0.734548    
#> 117: 0.269631    1.103966    3.492453    0.125196    0.052404    0.033822    0.727417    
#> 118: 0.287956    1.108567    3.487437    0.118936    0.057745    0.032756    0.714219    
#> 119: 0.277496    1.105562    3.484861    0.118927    0.057846    0.031118    0.719870    
#> 120: 0.254878    1.089537    3.473456    0.112981    0.054954    0.029563    0.725510    
#> 121: 0.244671    1.132691    3.461945    0.108034    0.059910    0.028084    0.739585    
#> 122: 0.264301    1.090633    3.477902    0.102632    0.072310    0.026680    0.739808    
#> 123: 0.307179    1.108163    3.478575    0.097501    0.068694    0.025346    0.728074    
#> 124: 0.300217    1.138626    3.491647    0.106940    0.065260    0.024872    0.729525    
#> 125: 0.292482    1.124312    3.472406    0.132048    0.061997    0.025803    0.716164    
#> 126: 0.225908    1.136178    3.447970    0.125446    0.064515    0.026240    0.722856    
#> 127: 0.225323    1.134566    3.441253    0.146645    0.062735    0.025114    0.728321    
#> 128: 0.193549    1.116860    3.455199    0.139313    0.068879    0.023858    0.732598    
#> 129: 0.217538    1.125242    3.461348    0.132347    0.082663    0.022665    0.725238    
#> 130: 0.246493    1.149277    3.453769    0.125730    0.078530    0.021532    0.711801    
#> 131: 0.213828    1.121856    3.455868    0.119443    0.075456    0.020455    0.718319    
#> 132: 0.189584    1.109411    3.448825    0.113471    0.071683    0.022407    0.736151    
#> 133: 0.222173    1.111319    3.462577    0.115244    0.079559    0.021286    0.747223    
#> 134: 0.258337    1.085702    3.482004    0.115055    0.075581    0.024079    0.736113    
#> 135: 0.206063    1.103719    3.461475    0.109303    0.071802    0.022875    0.730056    
#> 136: 0.248272    1.104669    3.475948    0.103838    0.068212    0.029706    0.725913    
#> 137: 0.292442    1.075453    3.491847    0.098646    0.064801    0.032476    0.717623    
#> 138: 0.261772    1.086854    3.486100    0.093713    0.061561    0.031219    0.722118    
#> 139: 0.266947    1.111979    3.491883    0.100990    0.058483    0.031365    0.725013    
#> 140: 0.269849    1.111678    3.499213    0.096303    0.062147    0.030076    0.721927    
#> 141: 0.251485    1.080227    3.500321    0.098079    0.059040    0.030633    0.718371    
#> 142: 0.279294    1.046922    3.507264    0.118525    0.056088    0.029101    0.720336    
#> 143: 0.242942    1.085225    3.487453    0.118060    0.057072    0.027646    0.707019    
#> 144: 0.294869    1.090247    3.498271    0.136959    0.054218    0.027315    0.721150    
#> 145: 0.265310    1.103248    3.482666    0.130111    0.051507    0.025949    0.703853    
#> 146: 0.243982    1.112195    3.482455    0.123605    0.055930    0.025449    0.718947    
#> 147: 0.205725    1.103967    3.459199    0.117425    0.059528    0.030402    0.705396    
#> 148: 0.209227    1.124026    3.469893    0.125109    0.056552    0.035426    0.711910    
#> 149: 0.224866    1.116761    3.461104    0.120990    0.053724    0.037040    0.703412    
#> 150: 0.265514    1.107554    3.465927    0.131591    0.051038    0.035188    0.722334    
#> 151: 0.280023    1.120454    3.486288    0.166910    0.053824    0.033429    0.714370    
#> 152: 0.259341    1.095830    3.488184    0.150247    0.052156    0.030541    0.732326    
#> 153: 0.276631    1.110929    3.490668    0.130768    0.051638    0.028996    0.743317    
#> 154: 0.272975    1.116312    3.478919    0.100105    0.061867    0.028662    0.746701    
#> 155: 0.228386    1.091221    3.471289    0.082455    0.061756    0.030953    0.743195    
#> 156: 0.225065    1.117332    3.469601    0.075950    0.065521    0.033622    0.738599    
#> 157: 0.234703    1.101661    3.482532    0.084982    0.071774    0.030486    0.730550    
#> 158: 0.252843    1.119054    3.473351    0.090416    0.059979    0.026866    0.731492    
#> 159: 0.249996    1.133436    3.486626    0.107078    0.065357    0.026633    0.728148    
#> 160: 0.298647    1.101688    3.497854    0.105273    0.071071    0.025673    0.731339    
#> 161: 0.274117    1.099677    3.480048    0.091827    0.067646    0.023712    0.741643    
#> 162: 0.253463    1.111151    3.468241    0.080006    0.071754    0.019031    0.737364    
#> 163: 0.251490    1.111576    3.471276    0.078572    0.098883    0.021852    0.723960    
#> 164: 0.233621    1.104922    3.465552    0.079380    0.070851    0.019020    0.727134    
#> 165: 0.269799    1.119034    3.471162    0.081579    0.073123    0.019861    0.717064    
#> 166: 0.293409    1.149792    3.474455    0.081842    0.076511    0.025464    0.729848    
#> 167: 0.277894    1.131201    3.487525    0.087737    0.074800    0.031805    0.729207    
#> 168: 0.274995    1.139716    3.481031    0.108475    0.055274    0.028205    0.713932    
#> 169: 0.237839    1.155709    3.466151    0.110190    0.056066    0.027439    0.731418    
#> 170: 0.239537    1.125465    3.474377    0.101434    0.053711    0.030474    0.701221    
#> 171: 0.207112    1.114137    3.471033    0.097558    0.060071    0.026185    0.713499    
#> 172: 0.214426    1.137067    3.465190    0.092988    0.064757    0.021026    0.712268    
#> 173: 0.216657    1.151158    3.455399    0.112703    0.059173    0.019681    0.715593    
#> 174: 0.251811    1.136989    3.469081    0.129625    0.064456    0.022898    0.718763    
#> 175: 0.248780    1.126589    3.462124    0.121760    0.065928    0.022662    0.706494    
#> 176: 0.238011    1.146352    3.468365    0.115641    0.060225    0.028719    0.702283    
#> 177: 0.238104    1.123921    3.471785    0.105813    0.059594    0.026601    0.715481    
#> 178: 0.227432    1.120184    3.474734    0.081653    0.063674    0.024540    0.712642    
#> 179: 0.247685    1.135225    3.472386    0.078794    0.053784    0.023134    0.720502    
#> 180: 0.239363    1.126836    3.471659    0.087828    0.062855    0.026472    0.709645    
#> 181: 0.240511    1.117091    3.459874    0.093923    0.057340    0.024249    0.708620    
#> 182: 0.190206    1.120941    3.458032    0.097933    0.056955    0.025298    0.734402    
#> 183: 0.209106    1.118818    3.456550    0.091388    0.056616    0.026493    0.720210    
#> 184: 0.232983    1.093140    3.469058    0.083328    0.053136    0.031541    0.718589    
#> 185: 0.186860    1.131426    3.449624    0.093837    0.054996    0.025373    0.704809    
#> 186: 0.201366    1.148205    3.460837    0.079848    0.064920    0.026164    0.721520    
#> 187: 0.208034    1.095903    3.467234    0.100148    0.049326    0.023324    0.722195    
#> 188: 0.208420    1.111583    3.470748    0.089394    0.049137    0.032773    0.728010    
#> 189: 0.260314    1.102640    3.480674    0.097864    0.047567    0.033036    0.743031    
#> 190: 0.225378    1.110213    3.479516    0.102165    0.045686    0.032482    0.718257    
#> 191: 0.218104    1.121931    3.462498    0.113278    0.048021    0.030364    0.731744    
#> 192: 0.209512    1.130711    3.456309    0.108782    0.047171    0.031795    0.696563    
#> 193: 0.245117    1.120747    3.462693    0.108993    0.050387    0.034367    0.707350    
#> 194: 0.227174    1.105404    3.459819    0.089038    0.051223    0.038131    0.729670    
#> 195: 0.235010    1.116029    3.473299    0.083960    0.050514    0.034126    0.731574    
#> 196: 0.223967    1.106850    3.481706    0.087038    0.043422    0.043116    0.739223    
#> 197: 0.210629    1.105266    3.494104    0.090467    0.052124    0.040113    0.740451    
#> 198: 0.272718    1.093399    3.483070    0.104648    0.042160    0.040514    0.725953    
#> 199: 0.237170    1.093176    3.468617    0.115292    0.043799    0.042141    0.728365    
#> 200: 0.229684    1.087521    3.474247    0.148761    0.028816    0.039632    0.737199    
#> 201: 0.224720    1.077826    3.480733    0.151957    0.031762    0.037580    0.733182    
#> 202: 0.226496    1.083803    3.479077    0.147182    0.034230    0.036874    0.732457    
#> 203: 0.232429    1.085104    3.476761    0.149454    0.035521    0.036154    0.732203    
#> 204: 0.241738    1.079289    3.480691    0.148657    0.038218    0.035629    0.729422    
#> 205: 0.243053    1.084419    3.480474    0.149037    0.039896    0.035427    0.730099    
#> 206: 0.247988    1.090572    3.481773    0.150359    0.040602    0.035472    0.729953    
#> 207: 0.248981    1.091183    3.481089    0.150961    0.041004    0.035380    0.728027    
#> 208: 0.251089    1.092638    3.482055    0.147806    0.041648    0.035350    0.726855    
#> 209: 0.250324    1.092965    3.480343    0.144410    0.042877    0.034428    0.726084    
#> 210: 0.253491    1.092546    3.480574    0.141887    0.043845    0.033699    0.723634    
#> 211: 0.254897    1.091812    3.481918    0.139315    0.044590    0.033186    0.722412    
#> 212: 0.256878    1.091488    3.482390    0.135651    0.045525    0.032320    0.722248    
#> 213: 0.258917    1.088983    3.483634    0.132925    0.047097    0.032182    0.723213    
#> 214: 0.261382    1.087938    3.484670    0.131775    0.047363    0.032083    0.722613    
#> 215: 0.262456    1.088569    3.485656    0.130522    0.047655    0.032369    0.722959    
#> 216: 0.263322    1.087710    3.485962    0.129094    0.047689    0.032751    0.723667    
#> 217: 0.263809    1.088230    3.486215    0.127192    0.047817    0.032746    0.723099    
#> 218: 0.263998    1.089030    3.486300    0.125843    0.048033    0.032651    0.722413    
#> 219: 0.264125    1.089605    3.485322    0.124456    0.048335    0.032540    0.722722    
#> 220: 0.264802    1.090391    3.485748    0.125583    0.048379    0.032711    0.722459    
#> 221: 0.265952    1.090432    3.486018    0.125221    0.048266    0.032790    0.721234    
#> 222: 0.267047    1.090269    3.486064    0.124487    0.048287    0.032946    0.721164    
#> 223: 0.268986    1.090402    3.486533    0.123866    0.048512    0.032777    0.720989    
#> 224: 0.270680    1.090829    3.486709    0.123449    0.048426    0.032471    0.721273    
#> 225: 0.270716    1.090058    3.487140    0.123367    0.048542    0.032573    0.721055    
#> 226: 0.270198    1.089554    3.486545    0.122664    0.048387    0.032665    0.721210    
#> 227: 0.269042    1.089285    3.486395    0.123366    0.048033    0.032780    0.720681    
#> 228: 0.267652    1.090174    3.485898    0.124171    0.047567    0.032798    0.720939    
#> 229: 0.267205    1.089834    3.485641    0.124046    0.047073    0.032836    0.721082    
#> 230: 0.267112    1.090175    3.484951    0.123281    0.047046    0.032796    0.721777    
#> 231: 0.267455    1.090762    3.485240    0.122907    0.047131    0.032976    0.721445    
#> 232: 0.266173    1.091134    3.485069    0.122324    0.047189    0.033105    0.721184    
#> 233: 0.265221    1.090906    3.484925    0.122081    0.047007    0.033311    0.721266    
#> 234: 0.264728    1.090413    3.484864    0.122309    0.046964    0.033290    0.720802    
#> 235: 0.264043    1.089738    3.484797    0.121758    0.046988    0.033378    0.720546    
#> 236: 0.264059    1.090287    3.484372    0.122106    0.047152    0.033381    0.720774    
#> 237: 0.264618    1.090530    3.484439    0.122159    0.047100    0.033461    0.721420    
#> 238: 0.265085    1.090754    3.484320    0.122178    0.047125    0.033648    0.721945    
#> 239: 0.265202    1.091178    3.484110    0.121860    0.047114    0.033467    0.721688    
#> 240: 0.265606    1.091006    3.484469    0.121760    0.047032    0.033289    0.721328    
#> 241: 0.266078    1.090741    3.484547    0.122018    0.046985    0.033328    0.721185    
#> 242: 0.265156    1.090760    3.484124    0.122370    0.046901    0.033340    0.721424    
#> 243: 0.264063    1.091389    3.483871    0.122205    0.046806    0.033458    0.721834    
#> 244: 0.263586    1.091563    3.483936    0.122575    0.046930    0.033537    0.721680    
#> 245: 0.263974    1.091194    3.484195    0.122209    0.046924    0.033515    0.721800    
#> 246: 0.263752    1.091286    3.484065    0.121900    0.046980    0.033466    0.722031    
#> 247: 0.263496    1.091539    3.484034    0.121297    0.046905    0.033422    0.722573    
#> 248: 0.263538    1.092048    3.483834    0.121098    0.046894    0.033410    0.722511    
#> 249: 0.264099    1.091968    3.484071    0.121113    0.047074    0.033356    0.722386    
#> 250: 0.264256    1.092330    3.484032    0.120839    0.047110    0.033458    0.722715    
#> 251: 0.264432    1.092722    3.484315    0.120380    0.046975    0.033495    0.723105    
#> 252: 0.264474    1.092849    3.484529    0.120105    0.046889    0.033448    0.723391    
#> 253: 0.264753    1.092941    3.484746    0.120163    0.046776    0.033478    0.723368    
#> 254: 0.264873    1.093299    3.484837    0.120153    0.046652    0.033558    0.723314    
#> 255: 0.265177    1.093384    3.484971    0.120232    0.046440    0.033524    0.723517    
#> 256: 0.265592    1.092954    3.484991    0.120003    0.046251    0.033503    0.723740    
#> 257: 0.265383    1.092745    3.484803    0.119915    0.046286    0.033524    0.723556    
#> 258: 0.265558    1.092267    3.484935    0.119896    0.046207    0.033581    0.723422    
#> 259: 0.265709    1.092113    3.485032    0.119978    0.046246    0.033634    0.723360    
#> 260: 0.265933    1.092370    3.485271    0.119756    0.046202    0.033691    0.723208    
#> 261: 0.266422    1.092092    3.485579    0.119812    0.046010    0.033752    0.723322    
#> 262: 0.266713    1.092312    3.485703    0.119879    0.046006    0.033758    0.723474    
#> 263: 0.266503    1.092638    3.485650    0.119706    0.045938    0.033691    0.723524    
#> 264: 0.266565    1.092773    3.485638    0.119711    0.045851    0.033666    0.723543    
#> 265: 0.266466    1.092918    3.485713    0.119748    0.045768    0.033692    0.723566    
#> 266: 0.266546    1.093332    3.485653    0.119741    0.045830    0.033566    0.723457    
#> 267: 0.266524    1.093565    3.485689    0.120133    0.045817    0.033447    0.723302    
#> 268: 0.266418    1.093665    3.485581    0.120480    0.045875    0.033357    0.722960    
#> 269: 0.267120    1.093723    3.485713    0.120817    0.045908    0.033396    0.722946    
#> 270: 0.267307    1.093844    3.485723    0.120927    0.045862    0.033405    0.722521    
#> 271: 0.267255    1.093917    3.485603    0.120717    0.045813    0.033365    0.722484    
#> 272: 0.267102    1.093750    3.485448    0.120342    0.045906    0.033442    0.722686    
#> 273: 0.267344    1.094050    3.485487    0.120252    0.045921    0.033436    0.722588    
#> 274: 0.267124    1.094491    3.485362    0.120194    0.045986    0.033381    0.722269    
#> 275: 0.267085    1.094768    3.485217    0.120070    0.045949    0.033372    0.722139    
#> 276: 0.267009    1.094996    3.485223    0.120515    0.045809    0.033391    0.721989    
#> 277: 0.266966    1.095169    3.485268    0.120725    0.045738    0.033413    0.721778    
#> 278: 0.266756    1.095278    3.485213    0.121027    0.045756    0.033408    0.721440    
#> 279: 0.266331    1.095294    3.485150    0.120898    0.045764    0.033379    0.721528    
#> 280: 0.266204    1.095516    3.485049    0.120911    0.045859    0.033259    0.721271    
#> 281: 0.265635    1.095654    3.484962    0.120758    0.045913    0.033129    0.721311    
#> 282: 0.265468    1.096037    3.484922    0.120788    0.045947    0.033088    0.721263    
#> 283: 0.265400    1.096369    3.484846    0.120520    0.046188    0.033049    0.721526    
#> 284: 0.265367    1.096113    3.484814    0.120299    0.046273    0.032947    0.721432    
#> 285: 0.265683    1.096052    3.484721    0.120147    0.046382    0.032920    0.721330    
#> 286: 0.265833    1.095981    3.484706    0.119889    0.046431    0.032967    0.721167    
#> 287: 0.265948    1.096184    3.484727    0.119905    0.046461    0.032983    0.721026    
#> 288: 0.266167    1.096155    3.484732    0.120030    0.046537    0.032958    0.721061    
#> 289: 0.266087    1.096173    3.484638    0.120297    0.046546    0.032998    0.720980    
#> 290: 0.265919    1.096198    3.484647    0.120287    0.046655    0.033011    0.720879    
#> 291: 0.265936    1.096374    3.484718    0.120157    0.046707    0.032983    0.720908    
#> 292: 0.265814    1.096336    3.484631    0.120011    0.046712    0.032900    0.720844    
#> 293: 0.265802    1.096218    3.484571    0.119948    0.046674    0.032823    0.720791    
#> 294: 0.265449    1.096248    3.484379    0.119981    0.046680    0.032785    0.720740    
#> 295: 0.265535    1.096012    3.484418    0.119802    0.046638    0.032807    0.720621    
#> 296: 0.265510    1.096010    3.484453    0.119684    0.046662    0.032794    0.720765    
#> 297: 0.265640    1.096188    3.484431    0.119664    0.046839    0.032735    0.720846    
#> 298: 0.265761    1.096250    3.484329    0.119651    0.046984    0.032671    0.720922    
#> 299: 0.265952    1.096365    3.484381    0.119840    0.046951    0.032618    0.720917    
#> 300: 0.266047    1.096260    3.484498    0.120024    0.046928    0.032652    0.720987    
#> 301: 0.265794    1.096239    3.484244    0.120112    0.046823    0.032616    0.721428    
#> 302: 0.265821    1.096233    3.484208    0.120086    0.046704    0.032620    0.721548    
#> 303: 0.265508    1.096372    3.484161    0.119866    0.046675    0.032583    0.721560    
#> 304: 0.265897    1.096597    3.484085    0.119588    0.046789    0.032476    0.721615    
#> 305: 0.265983    1.096419    3.484071    0.119441    0.046926    0.032435    0.721545    
#> 306: 0.265873    1.096557    3.483900    0.119295    0.046997    0.032415    0.721516    
#> 307: 0.265911    1.096563    3.483763    0.119234    0.047022    0.032400    0.721564    
#> 308: 0.265625    1.096526    3.483655    0.119253    0.047052    0.032312    0.721719    
#> 309: 0.265646    1.096371    3.483646    0.119501    0.046952    0.032270    0.721675    
#> 310: 0.265723    1.096295    3.483504    0.119568    0.046806    0.032261    0.721700    
#> 311: 0.266035    1.096280    3.483597    0.119667    0.046693    0.032349    0.721518    
#> 312: 0.266015    1.096338    3.483447    0.119706    0.046594    0.032415    0.721471    
#> 313: 0.265894    1.096181    3.483360    0.119956    0.046536    0.032444    0.721490    
#> 314: 0.265537    1.096141    3.483130    0.120320    0.046548    0.032454    0.721392    
#> 315: 0.265092    1.096355    3.482907    0.120331    0.046649    0.032418    0.721396    
#> 316: 0.264623    1.096582    3.482752    0.120225    0.046732    0.032379    0.721391    
#> 317: 0.264505    1.096628    3.482818    0.120074    0.046902    0.032375    0.721373    
#> 318: 0.264527    1.096775    3.482766    0.120019    0.046916    0.032351    0.721087    
#> 319: 0.264627    1.096697    3.482829    0.120014    0.046984    0.032315    0.721046    
#> 320: 0.264354    1.096838    3.482714    0.120111    0.047046    0.032247    0.721001    
#> 321: 0.263947    1.097146    3.482551    0.120187    0.047181    0.032187    0.720953    
#> 322: 0.263546    1.097358    3.482320    0.120088    0.047236    0.032152    0.720879    
#> 323: 0.262989    1.097499    3.482256    0.119997    0.047287    0.032169    0.720838    
#> 324: 0.262875    1.097702    3.482215    0.119921    0.047316    0.032137    0.720875    
#> 325: 0.262575    1.097880    3.482129    0.119734    0.047292    0.032131    0.720707    
#> 326: 0.262396    1.097743    3.482061    0.119665    0.047260    0.032135    0.720880    
#> 327: 0.262192    1.097872    3.481945    0.119647    0.047283    0.032115    0.720900    
#> 328: 0.262035    1.098130    3.481806    0.119583    0.047362    0.032097    0.720805    
#> 329: 0.262021    1.098291    3.481847    0.119503    0.047374    0.032058    0.720709    
#> 330: 0.261994    1.098335    3.481885    0.119411    0.047305    0.032065    0.720705    
#> 331: 0.262319    1.098539    3.481949    0.119537    0.047324    0.032036    0.720710    
#> 332: 0.262345    1.098509    3.482017    0.119590    0.047379    0.032065    0.720740    
#> 333: 0.262065    1.098554    3.481911    0.119583    0.047453    0.032063    0.720676    
#> 334: 0.261967    1.098595    3.481707    0.119435    0.047472    0.031995    0.720721    
#> 335: 0.261501    1.098766    3.481508    0.119277    0.047430    0.031963    0.720729    
#> 336: 0.261128    1.098929    3.481298    0.119246    0.047371    0.031930    0.720929    
#> 337: 0.260847    1.099191    3.481123    0.119234    0.047322    0.031898    0.721084    
#> 338: 0.260871    1.099375    3.481097    0.119124    0.047334    0.031887    0.721119    
#> 339: 0.260672    1.099522    3.480962    0.118947    0.047374    0.031881    0.721029    
#> 340: 0.260361    1.099511    3.480859    0.118831    0.047357    0.031867    0.720995    
#> 341: 0.260263    1.099584    3.480806    0.118703    0.047391    0.031857    0.720893    
#> 342: 0.259913    1.099557    3.480747    0.118585    0.047383    0.031868    0.720831    
#> 343: 0.259507    1.099602    3.480643    0.118585    0.047352    0.031908    0.720778    
#> 344: 0.259430    1.099622    3.480620    0.118668    0.047349    0.031962    0.720800    
#> 345: 0.259498    1.099778    3.480604    0.118770    0.047359    0.031984    0.720708    
#> 346: 0.259250    1.100011    3.480321    0.118796    0.047377    0.031973    0.720621    
#> 347: 0.259004    1.100035    3.480150    0.118853    0.047435    0.031935    0.720640    
#> 348: 0.258605    1.100251    3.480050    0.118864    0.047502    0.031882    0.720749    
#> 349: 0.258520    1.100331    3.479985    0.118967    0.047544    0.031832    0.720762    
#> 350: 0.258291    1.100385    3.479900    0.119128    0.047646    0.031754    0.720699    
#> 351: 0.258113    1.100594    3.479787    0.119129    0.047743    0.031707    0.720532    
#> 352: 0.257743    1.100721    3.479752    0.119115    0.047811    0.031651    0.720656    
#> 353: 0.257704    1.100931    3.479697    0.118851    0.047888    0.031633    0.720791    
#> 354: 0.257655    1.101020    3.479587    0.118719    0.047969    0.031583    0.720733    
#> 355: 0.257974    1.100976    3.479592    0.118650    0.048086    0.031545    0.720694    
#> 356: 0.258075    1.100834    3.479692    0.118777    0.048122    0.031553    0.720627    
#> 357: 0.258152    1.100906    3.479753    0.118891    0.048078    0.031547    0.720566    
#> 358: 0.258034    1.100968    3.479725    0.118878    0.048071    0.031536    0.720469    
#> 359: 0.257821    1.101074    3.479631    0.118779    0.048053    0.031543    0.720479    
#> 360: 0.257463    1.101180    3.479402    0.118787    0.048019    0.031533    0.720402    
#> 361: 0.257251    1.101283    3.479298    0.118896    0.048065    0.031502    0.720346    
#> 362: 0.257147    1.101345    3.479115    0.118813    0.048077    0.031462    0.720244    
#> 363: 0.256939    1.101303    3.479063    0.118753    0.048041    0.031452    0.720097    
#> 364: 0.256911    1.101342    3.479061    0.118641    0.048067    0.031436    0.720126    
#> 365: 0.256719    1.101260    3.478990    0.118560    0.048101    0.031442    0.720186    
#> 366: 0.256575    1.101239    3.478887    0.118424    0.048162    0.031433    0.720272    
#> 367: 0.256459    1.101354    3.478808    0.118405    0.048182    0.031401    0.720375    
#> 368: 0.256529    1.101366    3.478771    0.118387    0.048224    0.031375    0.720265    
#> 369: 0.256402    1.101385    3.478719    0.118353    0.048253    0.031401    0.720366    
#> 370: 0.256071    1.101545    3.478590    0.118260    0.048352    0.031367    0.720579    
#> 371: 0.255681    1.101611    3.478401    0.118105    0.048378    0.031353    0.720714    
#> 372: 0.255327    1.101791    3.478227    0.118078    0.048372    0.031360    0.720782    
#> 373: 0.255066    1.101933    3.478103    0.118093    0.048308    0.031357    0.720862    
#> 374: 0.254880    1.102069    3.477973    0.118323    0.048266    0.031371    0.720855    
#> 375: 0.254723    1.102149    3.477919    0.118467    0.048226    0.031412    0.720888    
#> 376: 0.254620    1.102243    3.477890    0.118494    0.048143    0.031427    0.720756    
#> 377: 0.254378    1.102309    3.477815    0.118496    0.048089    0.031448    0.720676    
#> 378: 0.254037    1.102387    3.477663    0.118462    0.048051    0.031460    0.720628    
#> 379: 0.253676    1.102356    3.477593    0.118424    0.048033    0.031463    0.720614    
#> 380: 0.253276    1.102343    3.477502    0.118395    0.048041    0.031463    0.720629    
#> 381: 0.253045    1.102397    3.477378    0.118444    0.047997    0.031487    0.720651    
#> 382: 0.252790    1.102442    3.477255    0.118518    0.047966    0.031489    0.720572    
#> 383: 0.252675    1.102437    3.477189    0.118409    0.047921    0.031501    0.720528    
#> 384: 0.252477    1.102417    3.477122    0.118256    0.047968    0.031460    0.720557    
#> 385: 0.252553    1.102377    3.477070    0.118150    0.048038    0.031431    0.720576    
#> 386: 0.252707    1.102404    3.477180    0.118089    0.048156    0.031396    0.720549    
#> 387: 0.253064    1.102389    3.477364    0.117944    0.048225    0.031363    0.720531    
#> 388: 0.253252    1.102396    3.477414    0.117872    0.048238    0.031322    0.720452    
#> 389: 0.253180    1.102265    3.477372    0.117756    0.048242    0.031288    0.720529    
#> 390: 0.253047    1.102254    3.477310    0.117606    0.048203    0.031288    0.720586    
#> 391: 0.253140    1.102222    3.477298    0.117406    0.048171    0.031281    0.720581    
#> 392: 0.253171    1.102070    3.477368    0.117379    0.048146    0.031284    0.720720    
#> 393: 0.253141    1.101930    3.477342    0.117291    0.048131    0.031259    0.720742    
#> 394: 0.253184    1.101893    3.477339    0.117224    0.048111    0.031275    0.720729    
#> 395: 0.253313    1.101898    3.477435    0.117097    0.048167    0.031269    0.720655    
#> 396: 0.253501    1.101933    3.477517    0.116978    0.048191    0.031260    0.720578    
#> 397: 0.253578    1.101939    3.477583    0.116941    0.048197    0.031243    0.720574    
#> 398: 0.253822    1.101883    3.477700    0.117002    0.048188    0.031256    0.720520    
#> 399: 0.253980    1.101855    3.477788    0.117101    0.048224    0.031243    0.720425    
#> 400: 0.254121    1.101877    3.477832    0.117124    0.048166    0.031235    0.720460    
#> 401: 0.254200    1.101936    3.477815    0.117194    0.048177    0.031243    0.720483    
#> 402: 0.254236    1.102039    3.477852    0.117180    0.048196    0.031260    0.720439    
#> 403: 0.254419    1.102039    3.477888    0.117169    0.048144    0.031289    0.720422    
#> 404: 0.254484    1.102132    3.477814    0.117221    0.048145    0.031275    0.720365    
#> 405: 0.254371    1.102151    3.477781    0.117257    0.048120    0.031275    0.720377    
#> 406: 0.254381    1.102159    3.477732    0.117394    0.048161    0.031269    0.720370    
#> 407: 0.254426    1.102167    3.477750    0.117390    0.048182    0.031275    0.720453    
#> 408: 0.254378    1.102253    3.477714    0.117390    0.048199    0.031274    0.720474    
#> 409: 0.254245    1.102232    3.477647    0.117386    0.048222    0.031252    0.720443    
#> 410: 0.254216    1.102302    3.477573    0.117414    0.048284    0.031227    0.720443    
#> 411: 0.254219    1.102185    3.477537    0.117408    0.048258    0.031214    0.720555    
#> 412: 0.254181    1.102188    3.477483    0.117477    0.048239    0.031210    0.720550    
#> 413: 0.254071    1.102222    3.477391    0.117510    0.048206    0.031178    0.720584    
#> 414: 0.253918    1.102279    3.477336    0.117508    0.048210    0.031142    0.720561    
#> 415: 0.253910    1.102261    3.477324    0.117391    0.048220    0.031101    0.720533    
#> 416: 0.254029    1.102389    3.477321    0.117313    0.048248    0.031085    0.720440    
#> 417: 0.253992    1.102440    3.477291    0.117206    0.048257    0.031076    0.720429    
#> 418: 0.253767    1.102498    3.477269    0.117123    0.048194    0.031069    0.720345    
#> 419: 0.253687    1.102626    3.477252    0.117088    0.048195    0.031079    0.720267    
#> 420: 0.253820    1.102675    3.477221    0.116994    0.048187    0.031071    0.720214    
#> 421: 0.253854    1.102648    3.477329    0.117008    0.048137    0.031107    0.720166    
#> 422: 0.253985    1.102601    3.477413    0.116931    0.048159    0.031134    0.720127    
#> 423: 0.254143    1.102514    3.477423    0.116835    0.048197    0.031139    0.720139    
#> 424: 0.254159    1.102454    3.477402    0.116774    0.048255    0.031129    0.720211    
#> 425: 0.254255    1.102504    3.477358    0.116796    0.048310    0.031104    0.720364    
#> 426: 0.254355    1.102552    3.477391    0.116703    0.048346    0.031086    0.720362    
#> 427: 0.254449    1.102495    3.477485    0.116624    0.048331    0.031084    0.720282    
#> 428: 0.254449    1.102506    3.477560    0.116605    0.048362    0.031070    0.720261    
#> 429: 0.254448    1.102418    3.477625    0.116525    0.048352    0.031073    0.720288    
#> 430: 0.254438    1.102395    3.477624    0.116490    0.048366    0.031070    0.720344    
#> 431: 0.254192    1.102374    3.477604    0.116472    0.048410    0.031081    0.720359    
#> 432: 0.254151    1.102450    3.477634    0.116458    0.048439    0.031084    0.720444    
#> 433: 0.254369    1.102500    3.477715    0.116467    0.048484    0.031072    0.720526    
#> 434: 0.254305    1.102392    3.477724    0.116440    0.048514    0.031057    0.720514    
#> 435: 0.254405    1.102337    3.477743    0.116353    0.048564    0.031024    0.720480    
#> 436: 0.254363    1.102281    3.477799    0.116243    0.048595    0.031026    0.720481    
#> 437: 0.254426    1.102250    3.477862    0.116143    0.048656    0.031011    0.720481    
#> 438: 0.254467    1.102382    3.477873    0.116102    0.048675    0.030981    0.720557    
#> 439: 0.254580    1.102412    3.477890    0.116120    0.048711    0.030963    0.720532    
#> 440: 0.254597    1.102418    3.477961    0.116139    0.048718    0.030943    0.720520    
#> 441: 0.254649    1.102348    3.477982    0.116132    0.048758    0.030929    0.720429    
#> 442: 0.254582    1.102381    3.477996    0.116115    0.048803    0.030930    0.720374    
#> 443: 0.254530    1.102374    3.477996    0.115999    0.048774    0.030952    0.720405    
#> 444: 0.254475    1.102391    3.477927    0.115968    0.048770    0.030955    0.720436    
#> 445: 0.254435    1.102409    3.477925    0.115986    0.048765    0.030936    0.720498    
#> 446: 0.254370    1.102452    3.477911    0.116047    0.048760    0.030922    0.720482    
#> 447: 0.254408    1.102512    3.477881    0.116035    0.048744    0.030921    0.720487    
#> 448: 0.254282    1.102529    3.477886    0.116112    0.048704    0.030920    0.720399    
#> 449: 0.254254    1.102616    3.477950    0.116189    0.048721    0.030935    0.720349    
#> 450: 0.254243    1.102638    3.477924    0.116252    0.048738    0.030936    0.720294    
#> 451: 0.254335    1.102683    3.477879    0.116332    0.048774    0.030931    0.720248    
#> 452: 0.254303    1.102783    3.477824    0.116394    0.048800    0.030935    0.720191    
#> 453: 0.254224    1.102817    3.477763    0.116444    0.048776    0.030951    0.720130    
#> 454: 0.254095    1.102911    3.477696    0.116452    0.048769    0.030951    0.720027    
#> 455: 0.253961    1.102976    3.477627    0.116474    0.048726    0.030947    0.720025    
#> 456: 0.253788    1.102998    3.477534    0.116470    0.048745    0.030953    0.719996    
#> 457: 0.253709    1.103016    3.477566    0.116390    0.048762    0.030961    0.719958    
#> 458: 0.253672    1.103093    3.477545    0.116285    0.048743    0.030954    0.719956    
#> 459: 0.253505    1.103224    3.477474    0.116300    0.048741    0.030992    0.719888    
#> 460: 0.253342    1.103258    3.477358    0.116282    0.048729    0.031009    0.719849    
#> 461: 0.253148    1.103328    3.477308    0.116213    0.048703    0.031009    0.719849    
#> 462: 0.253075    1.103358    3.477338    0.116169    0.048687    0.031038    0.719803    
#> 463: 0.253108    1.103375    3.477389    0.116128    0.048677    0.031098    0.719794    
#> 464: 0.253233    1.103429    3.477396    0.116136    0.048686    0.031119    0.719721    
#> 465: 0.253287    1.103319    3.477420    0.116179    0.048687    0.031143    0.719726    
#> 466: 0.253348    1.103403    3.477372    0.116210    0.048706    0.031143    0.719680    
#> 467: 0.253328    1.103386    3.477386    0.116302    0.048703    0.031151    0.719643    
#> 468: 0.253453    1.103358    3.477400    0.116435    0.048700    0.031158    0.719668    
#> 469: 0.253531    1.103411    3.477446    0.116549    0.048715    0.031150    0.719759    
#> 470: 0.253470    1.103465    3.477390    0.116680    0.048706    0.031144    0.719739    
#> 471: 0.253374    1.103451    3.477372    0.116820    0.048694    0.031157    0.719746    
#> 472: 0.253328    1.103468    3.477360    0.116857    0.048678    0.031157    0.719741    
#> 473: 0.253359    1.103506    3.477357    0.116891    0.048690    0.031178    0.719634    
#> 474: 0.253436    1.103510    3.477380    0.116950    0.048747    0.031177    0.719613    
#> 475: 0.253421    1.103628    3.477375    0.116959    0.048767    0.031179    0.719565    
#> 476: 0.253416    1.103620    3.477365    0.116850    0.048750    0.031179    0.719582    
#> 477: 0.253317    1.103659    3.477371    0.116853    0.048764    0.031167    0.719503    
#> 478: 0.253163    1.103614    3.477366    0.116900    0.048766    0.031171    0.719559    
#> 479: 0.253208    1.103652    3.477369    0.116918    0.048762    0.031162    0.719608    
#> 480: 0.253268    1.103671    3.477404    0.116862    0.048782    0.031157    0.719629    
#> 481: 0.253363    1.103616    3.477450    0.116963    0.048802    0.031159    0.719616    
#> 482: 0.253474    1.103613    3.477441    0.117021    0.048819    0.031170    0.719576    
#> 483: 0.253422    1.103611    3.477417    0.116978    0.048826    0.031158    0.719530    
#> 484: 0.253546    1.103526    3.477443    0.116921    0.048813    0.031156    0.719558    
#> 485: 0.253611    1.103542    3.477454    0.116892    0.048848    0.031156    0.719536    
#> 486: 0.253702    1.103496    3.477520    0.116916    0.048827    0.031161    0.719552    
#> 487: 0.253910    1.103480    3.477567    0.116951    0.048803    0.031174    0.719545    
#> 488: 0.253925    1.103431    3.477611    0.117011    0.048781    0.031204    0.719500    
#> 489: 0.253981    1.103391    3.477602    0.116982    0.048773    0.031220    0.719541    
#> 490: 0.254072    1.103420    3.477625    0.116930    0.048759    0.031217    0.719555    
#> 491: 0.254194    1.103450    3.477731    0.116862    0.048731    0.031261    0.719512    
#> 492: 0.254199    1.103490    3.477749    0.116896    0.048718    0.031300    0.719479    
#> 493: 0.254207    1.103469    3.477778    0.116958    0.048678    0.031313    0.719473    
#> 494: 0.254170    1.103513    3.477730    0.117055    0.048665    0.031337    0.719386    
#> 495: 0.254144    1.103597    3.477668    0.117100    0.048666    0.031352    0.719341    
#> 496: 0.254194    1.103664    3.477627    0.117225    0.048646    0.031374    0.719282    
#> 497: 0.254033    1.103697    3.477554    0.117323    0.048611    0.031404    0.719258    
#> 498: 0.253984    1.103701    3.477487    0.117433    0.048599    0.031412    0.719208    
#> 499: 0.253875    1.103766    3.477399    0.117412    0.048612    0.031408    0.719154    
#> 500: 0.253909    1.103780    3.477364    0.117399    0.048594    0.031396    0.719086    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.301270    0.973340    3.447956    0.392401    0.084959    0.016800    1.559118    
#> 002: 0.358208    0.937805    3.470238    0.372781    0.080711    0.015960    0.990304    
#> 003: 0.393706    0.895653    3.490180    0.354142    0.076676    0.015162    0.822774    
#> 004: 0.329768    0.952581    3.460541    0.336435    0.072842    0.014404    0.753783    
#> 005: 0.359355    0.957030    3.463301    0.319613    0.069200    0.013684    0.743324    
#> 006: 0.345101    0.949676    3.452951    0.303633    0.065740    0.013000    0.681809    
#> 007: 0.301564    0.954647    3.446309    0.288451    0.065070    0.012350    0.686511    
#> 008: 0.305950    0.956850    3.434543    0.274029    0.070586    0.012082    0.674864    
#> 009: 0.286070    0.955157    3.431010    0.260327    0.071960    0.011520    0.680153    
#> 010: 0.267060    0.959821    3.424447    0.247311    0.068362    0.012190    0.691714    
#> 011: 0.315142    0.971201    3.433449    0.242533    0.064944    0.015182    0.689638    
#> 012: 0.313359    0.976601    3.418867    0.230406    0.061697    0.014423    0.685122    
#> 013: 0.260122    0.977645    3.409036    0.218886    0.059010    0.013702    0.687407    
#> 014: 0.293777    0.974476    3.427349    0.207941    0.057672    0.013017    0.698628    
#> 015: 0.311788    0.973671    3.437242    0.197933    0.054788    0.012829    0.686343    
#> 016: 0.320084    0.984250    3.442691    0.205688    0.052049    0.012188    0.726237    
#> 017: 0.323198    0.976847    3.444113    0.195403    0.049446    0.011799    0.697418    
#> 018: 0.352871    0.959608    3.434978    0.228865    0.046974    0.013577    0.704427    
#> 019: 0.302479    0.961677    3.436013    0.217422    0.050439    0.012898    0.697992    
#> 020: 0.303603    0.965072    3.441467    0.206551    0.053611    0.012253    0.698759    
#> 021: 0.323137    0.964950    3.448509    0.196223    0.050931    0.012774    0.671966    
#> 022: 0.346481    0.967830    3.454341    0.187751    0.055827    0.012135    0.671318    
#> 023: 0.383712    0.954563    3.462156    0.220162    0.054496    0.011529    0.704487    
#> 024: 0.394325    0.970059    3.464304    0.209154    0.054909    0.011310    0.729627    
#> 025: 0.362522    0.955767    3.450514    0.199239    0.055220    0.010745    0.712908    
#> 026: 0.305619    0.985900    3.442132    0.189277    0.052459    0.010207    0.727911    
#> 027: 0.282067    0.986763    3.434212    0.179813    0.058420    0.010092    0.711462    
#> 028: 0.309800    0.995755    3.433708    0.186246    0.055499    0.010081    0.694347    
#> 029: 0.328926    0.969424    3.435288    0.235438    0.064141    0.011647    0.704989    
#> 030: 0.317110    0.980663    3.433766    0.223666    0.060934    0.013816    0.691019    
#> 031: 0.309397    0.950757    3.441703    0.226775    0.057887    0.013126    0.678819    
#> 032: 0.335581    0.963850    3.445298    0.274829    0.054993    0.015400    0.669615    
#> 033: 0.312781    0.996285    3.432944    0.261088    0.052243    0.017163    0.671272    
#> 034: 0.332678    0.992630    3.438490    0.248034    0.049631    0.016305    0.672213    
#> 035: 0.279673    0.979874    3.423536    0.259533    0.047149    0.017776    0.664229    
#> 036: 0.273662    0.978571    3.418972    0.290239    0.045196    0.018701    0.665737    
#> 037: 0.261818    0.992437    3.416376    0.275727    0.044530    0.019946    0.679956    
#> 038: 0.289944    1.007623    3.410597    0.261941    0.045636    0.021569    0.685042    
#> 039: 0.308705    1.000790    3.436323    0.248844    0.043355    0.020491    0.663795    
#> 040: 0.280652    0.995079    3.435340    0.236401    0.041187    0.019466    0.678788    
#> 041: 0.275471    0.991377    3.422882    0.256359    0.039128    0.021359    0.673023    
#> 042: 0.306739    0.967295    3.431920    0.243541    0.037171    0.020291    0.674660    
#> 043: 0.291131    0.982023    3.420354    0.239870    0.035313    0.019276    0.688220    
#> 044: 0.253640    0.973753    3.423325    0.227877    0.037115    0.018338    0.669731    
#> 045: 0.259800    0.992356    3.417884    0.225235    0.035259    0.017421    0.669937    
#> 046: 0.261122    0.990724    3.416123    0.230838    0.038460    0.017590    0.669816    
#> 047: 0.258987    1.001803    3.416097    0.219296    0.036537    0.018315    0.674245    
#> 048: 0.270967    1.000811    3.421159    0.234177    0.055989    0.017399    0.679976    
#> 049: 0.260129    1.009229    3.416249    0.250330    0.054738    0.017415    0.675291    
#> 050: 0.294529    0.989623    3.421070    0.237814    0.052001    0.018001    0.693831    
#> 051: 0.298367    1.012133    3.422946    0.225923    0.050008    0.017101    0.697269    
#> 052: 0.270438    1.006017    3.426433    0.225631    0.047508    0.016246    0.681151    
#> 053: 0.287633    0.982944    3.425413    0.217051    0.054564    0.015433    0.673927    
#> 054: 0.256155    0.985171    3.422134    0.233967    0.051836    0.019743    0.691367    
#> 055: 0.256047    0.991426    3.420165    0.225119    0.049244    0.019876    0.691502    
#> 056: 0.286430    0.982065    3.422558    0.219292    0.046782    0.018882    0.683410    
#> 057: 0.304095    0.975874    3.436380    0.212716    0.051548    0.017938    0.679417    
#> 058: 0.270370    0.981572    3.419278    0.202080    0.055930    0.017041    0.681771    
#> 059: 0.275591    0.946262    3.437453    0.207354    0.053133    0.022945    0.696161    
#> 060: 0.285261    0.943113    3.445447    0.196987    0.052301    0.021798    0.718199    
#> 061: 0.329250    0.963377    3.453222    0.205906    0.050892    0.020708    0.723288    
#> 062: 0.313246    0.982137    3.449277    0.203176    0.048347    0.019672    0.719486    
#> 063: 0.332361    0.958236    3.442412    0.202041    0.050009    0.018689    0.707138    
#> 064: 0.294703    0.962410    3.440448    0.202304    0.047960    0.017754    0.703498    
#> 065: 0.308105    0.952350    3.424581    0.195383    0.047350    0.016867    0.693210    
#> 066: 0.314324    0.968967    3.432496    0.248060    0.044982    0.016023    0.668376    
#> 067: 0.305400    0.972931    3.426674    0.256088    0.045451    0.015222    0.670174    
#> 068: 0.275326    0.973383    3.435624    0.245744    0.054354    0.014461    0.684482    
#> 069: 0.299397    0.978717    3.433703    0.285003    0.051637    0.019948    0.670815    
#> 070: 0.318365    0.961449    3.446752    0.281961    0.049055    0.025076    0.678871    
#> 071: 0.298939    0.992038    3.427995    0.267863    0.046602    0.023822    0.698392    
#> 072: 0.288509    0.963254    3.428948    0.263700    0.044272    0.022631    0.682857    
#> 073: 0.277319    0.981947    3.431965    0.251166    0.042058    0.021500    0.685919    
#> 074: 0.272369    0.979427    3.428061    0.238608    0.044224    0.020425    0.683988    
#> 075: 0.293051    0.972212    3.444299    0.226677    0.049676    0.019403    0.694833    
#> 076: 0.291388    1.004895    3.423600    0.275746    0.049191    0.018433    0.685226    
#> 077: 0.327788    0.978200    3.425830    0.297022    0.049401    0.022360    0.673469    
#> 078: 0.276199    0.996080    3.420157    0.282171    0.048154    0.021242    0.679991    
#> 079: 0.291094    0.994284    3.424247    0.268062    0.045746    0.020180    0.697014    
#> 080: 0.299304    0.988522    3.423517    0.254659    0.043459    0.019171    0.708008    
#> 081: 0.282322    0.997024    3.419561    0.253591    0.041286    0.020757    0.677924    
#> 082: 0.302724    0.979285    3.440941    0.248495    0.039222    0.019719    0.693095    
#> 083: 0.326340    0.974108    3.439229    0.236070    0.043847    0.018733    0.699604    
#> 084: 0.321442    0.976649    3.435478    0.228450    0.047556    0.017797    0.678313    
#> 085: 0.303089    0.981449    3.436074    0.225611    0.045178    0.016907    0.687514    
#> 086: 0.294291    0.987410    3.424648    0.214331    0.045197    0.016061    0.673248    
#> 087: 0.262511    0.984919    3.412828    0.217365    0.046647    0.015258    0.670991    
#> 088: 0.193490    0.991968    3.405835    0.206497    0.053069    0.014495    0.695296    
#> 089: 0.244295    1.005562    3.394127    0.243591    0.057207    0.015418    0.677564    
#> 090: 0.228309    1.003643    3.398231    0.231411    0.057147    0.014647    0.684517    
#> 091: 0.195881    0.998459    3.383329    0.219841    0.059897    0.015233    0.707842    
#> 092: 0.209000    1.040882    3.375740    0.230924    0.056902    0.014716    0.706404    
#> 093: 0.204966    1.028397    3.383362    0.227554    0.054057    0.018600    0.707239    
#> 094: 0.186310    1.030556    3.377175    0.252832    0.060068    0.017670    0.701381    
#> 095: 0.205011    1.039462    3.391553    0.240190    0.057065    0.016786    0.685716    
#> 096: 0.186790    1.029635    3.394627    0.228181    0.063177    0.015947    0.685801    
#> 097: 0.227769    1.025453    3.394172    0.223778    0.061483    0.015150    0.675234    
#> 098: 0.246185    1.049117    3.400463    0.244761    0.058409    0.015024    0.682018    
#> 099: 0.214403    1.003581    3.392443    0.252895    0.056595    0.014408    0.679408    
#> 100: 0.205236    1.028211    3.387381    0.240250    0.062094    0.013688    0.681291    
#> 101: 0.190202    1.001345    3.377136    0.228238    0.058989    0.013004    0.690473    
#> 102: 0.210577    1.018584    3.376041    0.216826    0.056040    0.013350    0.704331    
#> 103: 0.243008    1.009584    3.399791    0.276333    0.053238    0.012682    0.681273    
#> 104: 0.233153    1.000003    3.414450    0.263969    0.050653    0.013389    0.678315    
#> 105: 0.264385    0.990976    3.412604    0.282335    0.054861    0.013375    0.663416    
#> 106: 0.279636    0.987277    3.412921    0.268219    0.052117    0.014383    0.669787    
#> 107: 0.284114    1.002355    3.420544    0.254808    0.051411    0.013663    0.677122    
#> 108: 0.247487    1.011766    3.409170    0.242067    0.054495    0.012980    0.683944    
#> 109: 0.231209    1.007373    3.416597    0.229964    0.057440    0.012331    0.680681    
#> 110: 0.252683    0.997525    3.406981    0.249361    0.054568    0.012720    0.684270    
#> 111: 0.253565    1.013163    3.404427    0.236893    0.051839    0.012097    0.673121    
#> 112: 0.261436    0.983051    3.404230    0.242754    0.049248    0.011492    0.688427    
#> 113: 0.280846    1.011646    3.419615    0.249938    0.046785    0.011139    0.681916    
#> 114: 0.258199    1.005790    3.412481    0.237441    0.047402    0.011298    0.688735    
#> 115: 0.306389    0.989495    3.420833    0.225569    0.046318    0.013717    0.692847    
#> 116: 0.305047    0.988378    3.425606    0.217753    0.049437    0.013985    0.671173    
#> 117: 0.273028    1.008560    3.423796    0.215389    0.049643    0.013286    0.687927    
#> 118: 0.321644    0.990064    3.431265    0.222324    0.053426    0.012621    0.660882    
#> 119: 0.322915    0.966859    3.439565    0.211208    0.050755    0.013621    0.691938    
#> 120: 0.291601    0.945945    3.432144    0.214832    0.048217    0.015076    0.690209    
#> 121: 0.322378    0.983391    3.436641    0.233553    0.062827    0.014755    0.684032    
#> 122: 0.339318    0.961952    3.448125    0.251049    0.059686    0.014092    0.685291    
#> 123: 0.344334    0.991935    3.440319    0.241995    0.056702    0.014349    0.687314    
#> 124: 0.289327    1.021599    3.422438    0.229896    0.053867    0.013632    0.704981    
#> 125: 0.298491    1.025192    3.416363    0.218401    0.065708    0.012950    0.696508    
#> 126: 0.257431    0.995385    3.408173    0.207481    0.063410    0.013775    0.683405    
#> 127: 0.287356    0.999980    3.405719    0.211787    0.060239    0.013086    0.712893    
#> 128: 0.239253    0.984327    3.421470    0.201198    0.057227    0.012814    0.702530    
#> 129: 0.278627    0.998909    3.425931    0.191138    0.054366    0.015541    0.693243    
#> 130: 0.323851    0.985620    3.434750    0.181581    0.051761    0.014764    0.672903    
#> 131: 0.307101    0.978600    3.428235    0.214860    0.062260    0.014026    0.663917    
#> 132: 0.289365    0.970700    3.422144    0.218725    0.059147    0.015579    0.684626    
#> 133: 0.282395    0.975055    3.430022    0.248097    0.056189    0.016143    0.690015    
#> 134: 0.309437    0.962484    3.438143    0.260911    0.053380    0.020290    0.681666    
#> 135: 0.306449    0.949882    3.448724    0.247865    0.050711    0.019275    0.690164    
#> 136: 0.330063    0.957327    3.446787    0.245842    0.048175    0.019676    0.663919    
#> 137: 0.347288    0.949473    3.445707    0.255497    0.045767    0.021116    0.675582    
#> 138: 0.311807    0.980697    3.436212    0.242722    0.043478    0.020739    0.680681    
#> 139: 0.313492    0.990223    3.438343    0.237454    0.047080    0.019702    0.687690    
#> 140: 0.315352    0.984707    3.436534    0.229062    0.044726    0.019497    0.701925    
#> 141: 0.280518    0.980484    3.425630    0.238062    0.042490    0.018906    0.687586    
#> 142: 0.295154    0.959406    3.441266    0.226159    0.040365    0.018718    0.684191    
#> 143: 0.283100    0.986099    3.432187    0.214851    0.044238    0.017782    0.706406    
#> 144: 0.304530    0.990953    3.433037    0.220226    0.042026    0.016893    0.678453    
#> 145: 0.282332    1.001945    3.414209    0.212176    0.039925    0.016049    0.684939    
#> 146: 0.258185    1.010783    3.421832    0.201567    0.049532    0.015246    0.694718    
#> 147: 0.237823    0.998971    3.408815    0.222140    0.053937    0.014484    0.672439    
#> 148: 0.231414    1.010054    3.414385    0.228631    0.051240    0.014750    0.676286    
#> 149: 0.271136    1.004719    3.411106    0.266247    0.048678    0.018254    0.684352    
#> 150: 0.286970    1.001524    3.408790    0.252935    0.049544    0.017342    0.678122    
#> 151: 0.234724    1.039947    3.408691    0.257204    0.049934    0.016474    0.677345    
#> 152: 0.235579    1.026631    3.403782    0.233466    0.039230    0.008623    0.682310    
#> 153: 0.240304    1.019019    3.416356    0.221257    0.042058    0.013012    0.682372    
#> 154: 0.295661    0.994999    3.426312    0.230000    0.042627    0.016945    0.685707    
#> 155: 0.299097    0.980226    3.429958    0.220986    0.030894    0.015012    0.686694    
#> 156: 0.284122    0.996517    3.423377    0.258090    0.027920    0.018966    0.694807    
#> 157: 0.288991    0.991873    3.430143    0.254672    0.027548    0.020213    0.688685    
#> 158: 0.294338    1.007340    3.427100    0.241621    0.033199    0.020002    0.676106    
#> 159: 0.262146    1.009958    3.430225    0.258803    0.039294    0.018058    0.669536    
#> 160: 0.305935    0.981423    3.442711    0.259937    0.038919    0.019959    0.670871    
#> 161: 0.305169    0.990231    3.436954    0.267735    0.034638    0.019348    0.659789    
#> 162: 0.295099    0.994610    3.418044    0.272593    0.029580    0.021311    0.667810    
#> 163: 0.292866    0.992607    3.420510    0.280292    0.035209    0.020053    0.658170    
#> 164: 0.282503    0.995378    3.410138    0.274111    0.031247    0.017449    0.664284    
#> 165: 0.275364    0.997124    3.414451    0.270776    0.039139    0.019917    0.665930    
#> 166: 0.280293    1.023760    3.412313    0.298094    0.040426    0.021595    0.659528    
#> 167: 0.291808    1.012566    3.426624    0.271025    0.048054    0.024036    0.677352    
#> 168: 0.281113    1.027196    3.414954    0.293584    0.041846    0.021146    0.662440    
#> 169: 0.291126    1.045820    3.413015    0.264693    0.038557    0.020891    0.683687    
#> 170: 0.293552    1.008654    3.420548    0.300114    0.037441    0.023786    0.676117    
#> 171: 0.318272    0.982039    3.431300    0.282152    0.036327    0.022522    0.683527    
#> 172: 0.276378    0.995253    3.421184    0.240639    0.037742    0.020040    0.661942    
#> 173: 0.267575    1.016317    3.410459    0.216440    0.038235    0.015089    0.668695    
#> 174: 0.290332    1.004232    3.430575    0.238779    0.038150    0.012566    0.666974    
#> 175: 0.292414    1.001811    3.425742    0.205048    0.037083    0.010343    0.671107    
#> 176: 0.299373    1.004880    3.430258    0.222957    0.044510    0.011069    0.670380    
#> 177: 0.290272    0.999823    3.430321    0.213113    0.055667    0.010018    0.684876    
#> 178: 0.290396    0.986904    3.430503    0.202773    0.058163    0.012228    0.690248    
#> 179: 0.312678    0.997765    3.432176    0.187447    0.052950    0.014890    0.684822    
#> 180: 0.286856    1.003592    3.428816    0.220365    0.044742    0.015536    0.677994    
#> 181: 0.295265    0.989917    3.422297    0.222260    0.038806    0.013758    0.702475    
#> 182: 0.285627    0.992583    3.408270    0.193196    0.043891    0.015048    0.712198    
#> 183: 0.267268    1.012738    3.406766    0.197708    0.045320    0.017341    0.693006    
#> 184: 0.260345    0.992771    3.411948    0.263353    0.041372    0.016525    0.683214    
#> 185: 0.238850    1.012250    3.405920    0.220127    0.042925    0.014556    0.683387    
#> 186: 0.235610    1.017324    3.413603    0.191004    0.051070    0.016375    0.686221    
#> 187: 0.259952    0.991809    3.415279    0.220866    0.042823    0.017160    0.686804    
#> 188: 0.242365    1.005763    3.407672    0.217489    0.050360    0.013398    0.697912    
#> 189: 0.272722    1.001140    3.419652    0.234337    0.052168    0.014448    0.695538    
#> 190: 0.269651    0.990335    3.424030    0.243578    0.038773    0.013755    0.674014    
#> 191: 0.241456    1.009909    3.407754    0.233136    0.043044    0.013446    0.664227    
#> 192: 0.225574    1.013288    3.404931    0.219026    0.045838    0.013239    0.682707    
#> 193: 0.258710    1.021517    3.411888    0.225113    0.042071    0.012934    0.677883    
#> 194: 0.246402    1.021632    3.401041    0.263881    0.050797    0.014355    0.695260    
#> 195: 0.242433    1.021974    3.397948    0.259274    0.043446    0.013697    0.690442    
#> 196: 0.261311    1.004228    3.416047    0.311228    0.049945    0.017102    0.674505    
#> 197: 0.255253    1.012316    3.433705    0.289161    0.042268    0.017205    0.682439    
#> 198: 0.282968    0.998820    3.420224    0.272957    0.043172    0.014926    0.670612    
#> 199: 0.258394    0.997607    3.412862    0.258264    0.040523    0.015159    0.676910    
#> 200: 0.259437    0.993295    3.411703    0.220634    0.039344    0.014618    0.689135    
#> 201: 0.263843    0.987460    3.419564    0.206673    0.039295    0.013469    0.691915    
#> 202: 0.265045    0.989023    3.418608    0.208774    0.041375    0.012721    0.693195    
#> 203: 0.273780    0.987088    3.418636    0.203860    0.043596    0.012440    0.695658    
#> 204: 0.275745    0.982757    3.422261    0.208302    0.047672    0.012262    0.696791    
#> 205: 0.279783    0.986671    3.423901    0.211798    0.048489    0.012442    0.700606    
#> 206: 0.281785    0.990193    3.425058    0.218440    0.048027    0.012926    0.699256    
#> 207: 0.278759    0.989625    3.423698    0.215576    0.047925    0.013283    0.697297    
#> 208: 0.279541    0.989972    3.423231    0.216351    0.047240    0.013647    0.694164    
#> 209: 0.283133    0.987912    3.423498    0.219223    0.046238    0.013934    0.691630    
#> 210: 0.282652    0.986996    3.424152    0.218515    0.045724    0.014192    0.690238    
#> 211: 0.286320    0.987539    3.425434    0.216455    0.045453    0.014574    0.689361    
#> 212: 0.288776    0.987229    3.426090    0.215261    0.045214    0.014601    0.689703    
#> 213: 0.292798    0.985151    3.427262    0.217476    0.045686    0.014794    0.688648    
#> 214: 0.296284    0.984573    3.427913    0.218453    0.045862    0.014880    0.688200    
#> 215: 0.297056    0.984876    3.428647    0.220080    0.045679    0.015092    0.687337    
#> 216: 0.297356    0.984555    3.428952    0.221711    0.045686    0.015439    0.687712    
#> 217: 0.297697    0.985100    3.428983    0.221221    0.045681    0.015546    0.687269    
#> 218: 0.297472    0.986090    3.428860    0.222967    0.045975    0.015492    0.686393    
#> 219: 0.296418    0.986484    3.427659    0.225286    0.045773    0.015626    0.685459    
#> 220: 0.293935    0.987380    3.426567    0.227874    0.045587    0.015922    0.684404    
#> 221: 0.291481    0.988019    3.425813    0.230423    0.045458    0.016150    0.683438    
#> 222: 0.292568    0.987177    3.425969    0.233405    0.045159    0.016554    0.682981    
#> 223: 0.293942    0.987210    3.426071    0.234797    0.044534    0.016671    0.682339    
#> 224: 0.295848    0.987621    3.426535    0.235349    0.044279    0.016637    0.682019    
#> 225: 0.295492    0.986858    3.426960    0.235664    0.044046    0.016737    0.682133    
#> 226: 0.296118    0.985974    3.426987    0.235926    0.044082    0.016723    0.682249    
#> 227: 0.295317    0.985663    3.426870    0.236096    0.044322    0.016713    0.682184    
#> 228: 0.294200    0.986520    3.426100    0.235926    0.044288    0.016792    0.682562    
#> 229: 0.294054    0.986117    3.426042    0.236805    0.044041    0.016791    0.682044    
#> 230: 0.293774    0.985640    3.425759    0.237023    0.043784    0.016787    0.681968    
#> 231: 0.293702    0.986288    3.425798    0.237455    0.043628    0.016757    0.681426    
#> 232: 0.293556    0.986627    3.426141    0.237792    0.043457    0.016758    0.681412    
#> 233: 0.293003    0.986141    3.425979    0.237125    0.043284    0.016799    0.681345    
#> 234: 0.292915    0.986113    3.426127    0.237332    0.043317    0.016826    0.681379    
#> 235: 0.293501    0.985622    3.426315    0.237697    0.043195    0.016940    0.681150    
#> 236: 0.293472    0.986024    3.426265    0.236911    0.043131    0.017006    0.680862    
#> 237: 0.294756    0.986304    3.426473    0.237311    0.042958    0.017111    0.681009    
#> 238: 0.295502    0.986563    3.426687    0.237554    0.043016    0.017281    0.681208    
#> 239: 0.294887    0.987547    3.426296    0.237339    0.043031    0.017410    0.680964    
#> 240: 0.294339    0.987594    3.426238    0.236971    0.043079    0.017451    0.680655    
#> 241: 0.294722    0.986921    3.426408    0.236786    0.043321    0.017468    0.680578    
#> 242: 0.293906    0.986756    3.426316    0.236466    0.043687    0.017497    0.680668    
#> 243: 0.293449    0.987238    3.426162    0.235514    0.044010    0.017479    0.680809    
#> 244: 0.292919    0.987152    3.426200    0.235891    0.043982    0.017519    0.680842    
#> 245: 0.292381    0.986719    3.426117    0.236058    0.044213    0.017480    0.681288    
#> 246: 0.293228    0.986297    3.426258    0.236522    0.044035    0.017454    0.681608    
#> 247: 0.293844    0.986171    3.426659    0.236482    0.044044    0.017453    0.681351    
#> 248: 0.293410    0.986611    3.426528    0.236482    0.044009    0.017384    0.681226    
#> 249: 0.292963    0.986847    3.426506    0.236340    0.044007    0.017393    0.680983    
#> 250: 0.293217    0.987157    3.426558    0.236533    0.044248    0.017429    0.680809    
#> 251: 0.293986    0.987241    3.426961    0.238085    0.044293    0.017439    0.680993    
#> 252: 0.295262    0.987232    3.427384    0.237969    0.044485    0.017429    0.681261    
#> 253: 0.295461    0.987118    3.427568    0.238332    0.044581    0.017405    0.681526    
#> 254: 0.295948    0.987269    3.427701    0.238372    0.044583    0.017381    0.681421    
#> 255: 0.295620    0.987396    3.427565    0.239438    0.044632    0.017335    0.681284    
#> 256: 0.295702    0.987513    3.427410    0.239545    0.044687    0.017318    0.681376    
#> 257: 0.295720    0.987365    3.427247    0.239834    0.044838    0.017278    0.680982    
#> 258: 0.295096    0.986993    3.427032    0.239625    0.044933    0.017215    0.680767    
#> 259: 0.294339    0.986822    3.426807    0.239691    0.044931    0.017212    0.680795    
#> 260: 0.293931    0.987105    3.426717    0.240007    0.044924    0.017192    0.680556    
#> 261: 0.294254    0.986964    3.426829    0.240661    0.044961    0.017194    0.680704    
#> 262: 0.294445    0.987139    3.426941    0.240201    0.044872    0.017180    0.680855    
#> 263: 0.293784    0.987600    3.426776    0.240220    0.044928    0.017126    0.680963    
#> 264: 0.293138    0.987867    3.426657    0.239925    0.044958    0.017103    0.681097    
#> 265: 0.293315    0.988062    3.426705    0.240079    0.044987    0.017095    0.681284    
#> 266: 0.293360    0.988286    3.426822    0.239588    0.044899    0.017047    0.681371    
#> 267: 0.293157    0.988203    3.426976    0.239112    0.044866    0.017069    0.681482    
#> 268: 0.293198    0.988021    3.426829    0.239297    0.044958    0.017084    0.681446    
#> 269: 0.293555    0.987770    3.426795    0.239326    0.045075    0.017077    0.681533    
#> 270: 0.293471    0.988082    3.426652    0.239187    0.045094    0.017075    0.681307    
#> 271: 0.293507    0.988131    3.426540    0.239635    0.045005    0.017058    0.681205    
#> 272: 0.293512    0.988066    3.426412    0.240193    0.044962    0.017066    0.681359    
#> 273: 0.293059    0.988367    3.426303    0.240028    0.045000    0.017054    0.681426    
#> 274: 0.292938    0.988566    3.426298    0.239915    0.045000    0.017018    0.681507    
#> 275: 0.292778    0.988722    3.426155    0.239859    0.045070    0.017012    0.681441    
#> 276: 0.292445    0.988966    3.426248    0.240069    0.044977    0.017007    0.681343    
#> 277: 0.292033    0.989265    3.426261    0.240405    0.044873    0.017011    0.681377    
#> 278: 0.291274    0.989443    3.426155    0.240281    0.044845    0.017000    0.681386    
#> 279: 0.290720    0.989444    3.426090    0.240251    0.044789    0.017056    0.681700    
#> 280: 0.290551    0.989498    3.426100    0.240103    0.044777    0.017099    0.681608    
#> 281: 0.289759    0.989623    3.425939    0.240242    0.044792    0.017114    0.681463    
#> 282: 0.289426    0.989711    3.425940    0.240440    0.044880    0.017205    0.681359    
#> 283: 0.289614    0.989729    3.426041    0.240637    0.044926    0.017315    0.681312    
#> 284: 0.289679    0.989557    3.426222    0.240624    0.044903    0.017384    0.681056    
#> 285: 0.289754    0.989607    3.426177    0.241162    0.044820    0.017458    0.680896    
#> 286: 0.289983    0.989602    3.426180    0.241383    0.044847    0.017504    0.680746    
#> 287: 0.289967    0.989726    3.426055    0.241581    0.044756    0.017583    0.680719    
#> 288: 0.290301    0.989653    3.426120    0.241573    0.044700    0.017614    0.680951    
#> 289: 0.290520    0.989502    3.426189    0.241330    0.044739    0.017625    0.680958    
#> 290: 0.290658    0.989479    3.426233    0.241251    0.044740    0.017587    0.681004    
#> 291: 0.290838    0.989681    3.426325    0.241069    0.044670    0.017553    0.681057    
#> 292: 0.290790    0.989674    3.426380    0.240939    0.044624    0.017516    0.681100    
#> 293: 0.290684    0.989724    3.426297    0.240967    0.044589    0.017481    0.680979    
#> 294: 0.290231    0.989900    3.426085    0.240820    0.044665    0.017450    0.681091    
#> 295: 0.290031    0.989693    3.425908    0.240549    0.044654    0.017462    0.681209    
#> 296: 0.289848    0.989601    3.425834    0.240464    0.044564    0.017463    0.681315    
#> 297: 0.289979    0.989516    3.425934    0.240560    0.044482    0.017471    0.681288    
#> 298: 0.289830    0.989321    3.425917    0.240644    0.044527    0.017441    0.681130    
#> 299: 0.290109    0.989453    3.425946    0.240893    0.044530    0.017415    0.681020    
#> 300: 0.290269    0.989330    3.426059    0.240586    0.044523    0.017384    0.680897    
#> 301: 0.290381    0.989129    3.426005    0.240210    0.044441    0.017356    0.680903    
#> 302: 0.290257    0.989213    3.425848    0.240161    0.044425    0.017331    0.680720    
#> 303: 0.289977    0.989435    3.425678    0.239834    0.044403    0.017303    0.680508    
#> 304: 0.289679    0.989738    3.425493    0.239712    0.044402    0.017285    0.680472    
#> 305: 0.289418    0.989643    3.425372    0.239549    0.044407    0.017276    0.680374    
#> 306: 0.288855    0.989640    3.425220    0.239348    0.044490    0.017258    0.680366    
#> 307: 0.288632    0.989541    3.425113    0.239131    0.044525    0.017232    0.680701    
#> 308: 0.288185    0.989524    3.425008    0.239338    0.044493    0.017222    0.680799    
#> 309: 0.288106    0.989388    3.424905    0.239205    0.044512    0.017199    0.681038    
#> 310: 0.288157    0.989213    3.424833    0.239269    0.044559    0.017189    0.681027    
#> 311: 0.288079    0.989205    3.424864    0.239133    0.044579    0.017198    0.680910    
#> 312: 0.288028    0.989157    3.424800    0.239418    0.044577    0.017193    0.680934    
#> 313: 0.287894    0.989023    3.424686    0.239872    0.044591    0.017204    0.681071    
#> 314: 0.287533    0.989182    3.424511    0.240003    0.044529    0.017190    0.681069    
#> 315: 0.287086    0.989338    3.424319    0.240192    0.044538    0.017186    0.680968    
#> 316: 0.286781    0.989535    3.424128    0.240331    0.044613    0.017186    0.680888    
#> 317: 0.286896    0.989475    3.424128    0.240633    0.044655    0.017176    0.680943    
#> 318: 0.287086    0.989559    3.424037    0.241005    0.044715    0.017185    0.680792    
#> 319: 0.287128    0.989449    3.424126    0.241113    0.044742    0.017162    0.680939    
#> 320: 0.286749    0.989511    3.424060    0.241506    0.044734    0.017144    0.681095    
#> 321: 0.286730    0.989573    3.423987    0.241717    0.044739    0.017148    0.681111    
#> 322: 0.286768    0.989795    3.423921    0.241774    0.044790    0.017133    0.680948    
#> 323: 0.286207    0.989916    3.423801    0.241685    0.044827    0.017143    0.680845    
#> 324: 0.286251    0.990120    3.423794    0.241693    0.044804    0.017141    0.680781    
#> 325: 0.286056    0.990351    3.423659    0.241539    0.044749    0.017107    0.680762    
#> 326: 0.286062    0.990350    3.423599    0.241407    0.044758    0.017088    0.680706    
#> 327: 0.286126    0.990482    3.423621    0.241348    0.044650    0.017084    0.680699    
#> 328: 0.286181    0.990521    3.423654    0.241211    0.044567    0.017091    0.680684    
#> 329: 0.286371    0.990527    3.423673    0.241398    0.044476    0.017086    0.680515    
#> 330: 0.286380    0.990456    3.423676    0.241447    0.044501    0.017052    0.680460    
#> 331: 0.286780    0.990475    3.423842    0.241343    0.044470    0.017026    0.680475    
#> 332: 0.286896    0.990348    3.423984    0.241256    0.044443    0.017032    0.680500    
#> 333: 0.286742    0.990366    3.423972    0.241130    0.044438    0.017037    0.680516    
#> 334: 0.286643    0.990309    3.423899    0.241280    0.044386    0.017019    0.680566    
#> 335: 0.286577    0.990308    3.423881    0.240930    0.044357    0.017004    0.680628    
#> 336: 0.286385    0.990393    3.423830    0.240647    0.044315    0.017020    0.680694    
#> 337: 0.286183    0.990689    3.423681    0.240299    0.044309    0.017007    0.680796    
#> 338: 0.286084    0.990801    3.423630    0.239993    0.044338    0.016996    0.680788    
#> 339: 0.285834    0.990946    3.423554    0.239923    0.044304    0.017003    0.680754    
#> 340: 0.285546    0.990949    3.423493    0.239573    0.044292    0.016995    0.680832    
#> 341: 0.285685    0.990964    3.423485    0.239391    0.044226    0.016990    0.680735    
#> 342: 0.285604    0.990867    3.423521    0.239154    0.044219    0.016996    0.680669    
#> 343: 0.285461    0.990884    3.423524    0.239244    0.044174    0.017018    0.680639    
#> 344: 0.285526    0.990909    3.423541    0.239461    0.044158    0.017028    0.680665    
#> 345: 0.285398    0.990959    3.423529    0.239552    0.044184    0.017024    0.680656    
#> 346: 0.285195    0.991131    3.423417    0.239444    0.044133    0.017003    0.680655    
#> 347: 0.285179    0.991147    3.423337    0.239280    0.044183    0.017004    0.680669    
#> 348: 0.285134    0.991269    3.423289    0.239221    0.044188    0.017001    0.680771    
#> 349: 0.285073    0.991220    3.423230    0.239246    0.044173    0.017005    0.680798    
#> 350: 0.284860    0.991131    3.423121    0.239178    0.044179    0.016998    0.680783    
#> 351: 0.284772    0.991314    3.422997    0.238925    0.044195    0.016998    0.680755    
#> 352: 0.284390    0.991517    3.422907    0.238748    0.044242    0.017005    0.680837    
#> 353: 0.284396    0.991770    3.422777    0.238824    0.044321    0.016999    0.680857    
#> 354: 0.284258    0.991851    3.422638    0.238779    0.044385    0.017013    0.680798    
#> 355: 0.284403    0.991789    3.422648    0.238685    0.044374    0.017022    0.680774    
#> 356: 0.284352    0.991713    3.422667    0.238617    0.044401    0.017026    0.680950    
#> 357: 0.284397    0.991715    3.422668    0.238892    0.044389    0.017014    0.680941    
#> 358: 0.284479    0.991796    3.422669    0.239062    0.044323    0.017025    0.680845    
#> 359: 0.284481    0.991881    3.422653    0.239184    0.044341    0.017036    0.680756    
#> 360: 0.284267    0.991941    3.422536    0.239171    0.044371    0.017019    0.680757    
#> 361: 0.284098    0.992123    3.422419    0.239063    0.044441    0.016998    0.680693    
#> 362: 0.284098    0.992192    3.422372    0.239123    0.044486    0.016960    0.680511    
#> 363: 0.284041    0.992119    3.422356    0.239004    0.044494    0.016954    0.680366    
#> 364: 0.284090    0.992160    3.422367    0.239144    0.044477    0.016946    0.680438    
#> 365: 0.284064    0.992213    3.422380    0.239234    0.044565    0.016962    0.680417    
#> 366: 0.284050    0.992306    3.422308    0.239539    0.044593    0.016983    0.680346    
#> 367: 0.284169    0.992341    3.422306    0.239843    0.044605    0.016967    0.680271    
#> 368: 0.284682    0.992310    3.422407    0.239727    0.044655    0.016952    0.680165    
#> 369: 0.284896    0.992189    3.422541    0.239420    0.044662    0.016966    0.680208    
#> 370: 0.284917    0.992151    3.422611    0.239270    0.044702    0.016957    0.680194    
#> 371: 0.284971    0.992082    3.422591    0.239090    0.044656    0.016937    0.680191    
#> 372: 0.285040    0.992025    3.422614    0.239212    0.044654    0.016927    0.680118    
#> 373: 0.284927    0.992197    3.422580    0.239287    0.044728    0.016911    0.680160    
#> 374: 0.284953    0.992185    3.422513    0.239498    0.044728    0.016884    0.680150    
#> 375: 0.284771    0.992249    3.422470    0.239673    0.044728    0.016864    0.680121    
#> 376: 0.284654    0.992342    3.422447    0.239669    0.044773    0.016867    0.680016    
#> 377: 0.284372    0.992423    3.422377    0.239737    0.044751    0.016848    0.680074    
#> 378: 0.284069    0.992390    3.422306    0.239854    0.044736    0.016843    0.680057    
#> 379: 0.283859    0.992307    3.422248    0.239844    0.044717    0.016839    0.680014    
#> 380: 0.283765    0.992293    3.422219    0.239805    0.044734    0.016814    0.679960    
#> 381: 0.283571    0.992237    3.422218    0.239621    0.044703    0.016796    0.679910    
#> 382: 0.283613    0.992180    3.422200    0.239647    0.044648    0.016803    0.679863    
#> 383: 0.283594    0.992107    3.422222    0.239532    0.044633    0.016800    0.679821    
#> 384: 0.283443    0.992039    3.422219    0.239485    0.044641    0.016794    0.679852    
#> 385: 0.283457    0.992009    3.422256    0.239375    0.044649    0.016788    0.679905    
#> 386: 0.283604    0.992169    3.422328    0.239205    0.044697    0.016786    0.679903    
#> 387: 0.283827    0.992238    3.422464    0.239181    0.044721    0.016786    0.679860    
#> 388: 0.283979    0.992220    3.422542    0.239000    0.044721    0.016784    0.679841    
#> 389: 0.283952    0.992046    3.422558    0.238800    0.044681    0.016780    0.679968    
#> 390: 0.283960    0.991929    3.422600    0.238600    0.044630    0.016785    0.680005    
#> 391: 0.284094    0.991909    3.422576    0.238517    0.044634    0.016801    0.680007    
#> 392: 0.284157    0.991956    3.422647    0.238393    0.044675    0.016796    0.680101    
#> 393: 0.283992    0.991957    3.422588    0.238159    0.044637    0.016783    0.680136    
#> 394: 0.283957    0.992033    3.422545    0.238076    0.044656    0.016777    0.680147    
#> 395: 0.284110    0.992195    3.422484    0.238068    0.044709    0.016769    0.680260    
#> 396: 0.284157    0.992254    3.422468    0.238015    0.044735    0.016779    0.680321    
#> 397: 0.284100    0.992251    3.422447    0.237783    0.044759    0.016782    0.680314    
#> 398: 0.284393    0.992101    3.422533    0.237616    0.044753    0.016789    0.680384    
#> 399: 0.284655    0.992082    3.422635    0.237591    0.044777    0.016787    0.680352    
#> 400: 0.284791    0.992055    3.422750    0.237442    0.044814    0.016779    0.680467    
#> 401: 0.284900    0.992109    3.422737    0.237430    0.044827    0.016770    0.680599    
#> 402: 0.284800    0.992198    3.422723    0.237277    0.044874    0.016763    0.680552    
#> 403: 0.284911    0.992133    3.422740    0.237324    0.044893    0.016772    0.680501    
#> 404: 0.284819    0.992178    3.422652    0.237555    0.044920    0.016759    0.680540    
#> 405: 0.284698    0.992274    3.422617    0.237655    0.044968    0.016748    0.680547    
#> 406: 0.284684    0.992267    3.422595    0.237625    0.045004    0.016752    0.680561    
#> 407: 0.284557    0.992336    3.422582    0.237553    0.045025    0.016732    0.680519    
#> 408: 0.284646    0.992418    3.422601    0.237562    0.044995    0.016724    0.680525    
#> 409: 0.284636    0.992405    3.422578    0.237492    0.044960    0.016713    0.680401    
#> 410: 0.284491    0.992411    3.422512    0.237468    0.044971    0.016724    0.680315    
#> 411: 0.284490    0.992333    3.422448    0.237450    0.044985    0.016717    0.680316    
#> 412: 0.284457    0.992403    3.422372    0.237500    0.044960    0.016725    0.680365    
#> 413: 0.284434    0.992422    3.422320    0.237765    0.044947    0.016711    0.680460    
#> 414: 0.284222    0.992404    3.422310    0.237924    0.044973    0.016710    0.680361    
#> 415: 0.284231    0.992363    3.422292    0.237972    0.044970    0.016705    0.680257    
#> 416: 0.284252    0.992406    3.422300    0.238006    0.044996    0.016694    0.680151    
#> 417: 0.284332    0.992380    3.422335    0.237995    0.045005    0.016694    0.680136    
#> 418: 0.284376    0.992271    3.422400    0.238018    0.045026    0.016686    0.680059    
#> 419: 0.284598    0.992362    3.422429    0.238213    0.045016    0.016693    0.680079    
#> 420: 0.284761    0.992417    3.422435    0.238228    0.045015    0.016695    0.680100    
#> 421: 0.284864    0.992430    3.422498    0.238314    0.045035    0.016693    0.680084    
#> 422: 0.284995    0.992366    3.422528    0.238288    0.045037    0.016690    0.680116    
#> 423: 0.285331    0.992369    3.422561    0.238524    0.045047    0.016708    0.680148    
#> 424: 0.285332    0.992343    3.422553    0.238767    0.045069    0.016708    0.680119    
#> 425: 0.285454    0.992348    3.422549    0.238925    0.045114    0.016706    0.680168    
#> 426: 0.285568    0.992347    3.422589    0.238937    0.045113    0.016695    0.680136    
#> 427: 0.285519    0.992250    3.422648    0.238939    0.045086    0.016693    0.680074    
#> 428: 0.285381    0.992265    3.422598    0.238809    0.045077    0.016695    0.680133    
#> 429: 0.285377    0.992282    3.422604    0.238666    0.045062    0.016686    0.680115    
#> 430: 0.285402    0.992331    3.422612    0.238592    0.045051    0.016676    0.680122    
#> 431: 0.285325    0.992308    3.422600    0.238539    0.045067    0.016662    0.680080    
#> 432: 0.285334    0.992347    3.422635    0.238439    0.045131    0.016653    0.680043    
#> 433: 0.285436    0.992499    3.422683    0.238233    0.045200    0.016648    0.680049    
#> 434: 0.285507    0.992440    3.422765    0.238020    0.045217    0.016657    0.680045    
#> 435: 0.285715    0.992375    3.422836    0.237953    0.045216    0.016656    0.680041    
#> 436: 0.285849    0.992244    3.422961    0.237828    0.045252    0.016663    0.680136    
#> 437: 0.285927    0.992184    3.422989    0.237735    0.045287    0.016677    0.680138    
#> 438: 0.286062    0.992257    3.423034    0.237738    0.045314    0.016673    0.680101    
#> 439: 0.286004    0.992330    3.423038    0.237675    0.045320    0.016658    0.680034    
#> 440: 0.285923    0.992365    3.423044    0.237813    0.045340    0.016646    0.679988    
#> 441: 0.285892    0.992401    3.423043    0.237825    0.045383    0.016634    0.679963    
#> 442: 0.285714    0.992486    3.423031    0.237831    0.045400    0.016620    0.679932    
#> 443: 0.285614    0.992550    3.422963    0.237807    0.045380    0.016624    0.679908    
#> 444: 0.285524    0.992652    3.422879    0.237911    0.045399    0.016629    0.679809    
#> 445: 0.285423    0.992690    3.422842    0.237981    0.045415    0.016630    0.679854    
#> 446: 0.285220    0.992731    3.422777    0.238025    0.045386    0.016627    0.679867    
#> 447: 0.285210    0.992756    3.422756    0.238172    0.045345    0.016628    0.679908    
#> 448: 0.285193    0.992841    3.422737    0.238251    0.045343    0.016629    0.679893    
#> 449: 0.285265    0.992954    3.422780    0.238179    0.045355    0.016621    0.679990    
#> 450: 0.285313    0.992966    3.422808    0.238144    0.045386    0.016607    0.680058    
#> 451: 0.285453    0.992976    3.422803    0.238084    0.045407    0.016605    0.680131    
#> 452: 0.285535    0.992973    3.422821    0.237965    0.045441    0.016604    0.680145    
#> 453: 0.285566    0.992919    3.422830    0.238060    0.045466    0.016596    0.680118    
#> 454: 0.285603    0.992951    3.422838    0.237893    0.045483    0.016584    0.680058    
#> 455: 0.285639    0.992982    3.422836    0.237790    0.045465    0.016568    0.680062    
#> 456: 0.285603    0.992952    3.422849    0.237671    0.045467    0.016572    0.680067    
#> 457: 0.285603    0.992952    3.422869    0.237650    0.045470    0.016576    0.679982    
#> 458: 0.285592    0.993064    3.422903    0.237634    0.045460    0.016579    0.680003    
#> 459: 0.285437    0.993198    3.422892    0.237693    0.045448    0.016586    0.680034    
#> 460: 0.285308    0.993166    3.422840    0.237667    0.045430    0.016589    0.679965    
#> 461: 0.285268    0.993177    3.422841    0.237525    0.045410    0.016607    0.679931    
#> 462: 0.285246    0.993181    3.422892    0.237567    0.045353    0.016628    0.679907    
#> 463: 0.285280    0.993193    3.422933    0.237671    0.045300    0.016639    0.679848    
#> 464: 0.285387    0.993204    3.422954    0.237779    0.045272    0.016651    0.679810    
#> 465: 0.285532    0.993072    3.423002    0.237869    0.045246    0.016660    0.679760    
#> 466: 0.285579    0.993067    3.422994    0.237830    0.045228    0.016658    0.679732    
#> 467: 0.285493    0.993089    3.423017    0.237888    0.045213    0.016661    0.679647    
#> 468: 0.285528    0.993128    3.423025    0.237968    0.045211    0.016657    0.679672    
#> 469: 0.285442    0.993279    3.423011    0.237904    0.045256    0.016649    0.679737    
#> 470: 0.285394    0.993355    3.422978    0.237814    0.045273    0.016654    0.679709    
#> 471: 0.285306    0.993322    3.422973    0.237674    0.045246    0.016640    0.679687    
#> 472: 0.285212    0.993300    3.422965    0.237720    0.045256    0.016635    0.679669    
#> 473: 0.285182    0.993255    3.422984    0.237836    0.045225    0.016649    0.679630    
#> 474: 0.285097    0.993210    3.422982    0.237829    0.045217    0.016653    0.679648    
#> 475: 0.285070    0.993323    3.422962    0.237865    0.045227    0.016649    0.679634    
#> 476: 0.285102    0.993315    3.422960    0.237791    0.045212    0.016643    0.679622    
#> 477: 0.285084    0.993344    3.422957    0.237738    0.045184    0.016634    0.679541    
#> 478: 0.284980    0.993333    3.422954    0.237615    0.045169    0.016622    0.679541    
#> 479: 0.285006    0.993384    3.422951    0.237521    0.045156    0.016614    0.679561    
#> 480: 0.285098    0.993365    3.422968    0.237511    0.045140    0.016617    0.679621    
#> 481: 0.285121    0.993314    3.422972    0.237512    0.045160    0.016614    0.679648    
#> 482: 0.285039    0.993280    3.422926    0.237510    0.045167    0.016622    0.679709    
#> 483: 0.284906    0.993240    3.422899    0.237433    0.045145    0.016617    0.679689    
#> 484: 0.284794    0.993128    3.422903    0.237328    0.045150    0.016606    0.679684    
#> 485: 0.284706    0.993149    3.422864    0.237169    0.045199    0.016597    0.679690    
#> 486: 0.284732    0.993159    3.422903    0.237214    0.045230    0.016595    0.679647    
#> 487: 0.284840    0.993174    3.422972    0.237209    0.045231    0.016598    0.679667    
#> 488: 0.284959    0.993145    3.423009    0.237160    0.045233    0.016603    0.679600    
#> 489: 0.285097    0.993085    3.423007    0.237191    0.045237    0.016606    0.679632    
#> 490: 0.285202    0.993060    3.423035    0.237201    0.045233    0.016602    0.679632    
#> 491: 0.285319    0.993090    3.423089    0.237221    0.045268    0.016598    0.679615    
#> 492: 0.285269    0.993129    3.423083    0.237189    0.045287    0.016583    0.679664    
#> 493: 0.285218    0.993146    3.423091    0.237209    0.045319    0.016576    0.679652    
#> 494: 0.285305    0.993203    3.423082    0.237217    0.045353    0.016571    0.679578    
#> 495: 0.285446    0.993226    3.423102    0.237263    0.045351    0.016572    0.679495    
#> 496: 0.285557    0.993250    3.423106    0.237333    0.045352    0.016577    0.679485    
#> 497: 0.285474    0.993223    3.423103    0.237362    0.045373    0.016571    0.679525    
#> 498: 0.285423    0.993117    3.423088    0.237490    0.045370    0.016573    0.679505    
#> 499: 0.285452    0.993186    3.423066    0.237549    0.045368    0.016575    0.679446    
#> 500: 0.285470    0.993127    3.423060    0.237603    0.045333    0.016587    0.679394    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.247681    0.962487    3.444624    0.392401    0.079425    0.016800    1.724887    
#> 002: 0.242459    0.983884    3.473033    0.372781    0.075453    0.015960    1.150118    
#> 003: 0.298242    0.930313    3.488704    0.354142    0.093636    0.015162    0.876260    
#> 004: 0.274652    0.962180    3.483955    0.336435    0.110766    0.014404    0.775720    
#> 005: 0.291669    0.964836    3.471234    0.319613    0.135178    0.013684    0.736804    
#> 006: 0.270110    0.961739    3.455424    0.323301    0.133501    0.013000    0.677292    
#> 007: 0.250003    0.974104    3.448851    0.310780    0.163771    0.012350    0.695645    
#> 008: 0.242805    0.971281    3.443798    0.295241    0.170147    0.011732    0.704975    
#> 009: 0.195348    0.969676    3.437407    0.280479    0.161639    0.011146    0.705841    
#> 010: 0.222472    0.973777    3.435369    0.359966    0.153557    0.010588    0.716378    
#> 011: 0.265394    0.966411    3.435797    0.357355    0.148311    0.010059    0.704027    
#> 012: 0.241352    0.960564    3.435609    0.351273    0.140895    0.009556    0.685495    
#> 013: 0.226261    0.982257    3.439236    0.333709    0.146397    0.009078    0.693253    
#> 014: 0.247621    0.992509    3.437269    0.345032    0.139078    0.008624    0.695526    
#> 015: 0.240696    0.970683    3.448667    0.360112    0.132124    0.010321    0.697105    
#> 016: 0.254640    0.979182    3.460603    0.342107    0.132148    0.009805    0.702101    
#> 017: 0.275084    0.972716    3.464905    0.385659    0.137607    0.011465    0.663497    
#> 018: 0.285816    0.958486    3.453908    0.366376    0.130727    0.010892    0.682876    
#> 019: 0.248692    0.962369    3.453353    0.348057    0.137640    0.010347    0.671935    
#> 020: 0.280541    0.975314    3.458986    0.330654    0.146027    0.009830    0.686613    
#> 021: 0.273739    0.976279    3.460647    0.328353    0.147002    0.009338    0.679655    
#> 022: 0.257159    0.988320    3.464756    0.372440    0.158970    0.008872    0.683518    
#> 023: 0.339321    0.973260    3.466953    0.414129    0.151021    0.008428    0.690216    
#> 024: 0.325746    0.966800    3.468115    0.393423    0.143470    0.008686    0.680211    
#> 025: 0.302396    0.966296    3.458267    0.386999    0.136297    0.010051    0.677515    
#> 026: 0.266008    1.001319    3.446506    0.378814    0.143383    0.012450    0.690131    
#> 027: 0.244497    1.015335    3.431940    0.387839    0.147165    0.011828    0.692524    
#> 028: 0.257943    0.997296    3.442501    0.374452    0.142068    0.012034    0.656944    
#> 029: 0.262759    0.982826    3.436361    0.395100    0.134965    0.011433    0.669584    
#> 030: 0.268310    1.001430    3.437551    0.401932    0.128217    0.011855    0.665700    
#> 031: 0.204951    0.993577    3.436401    0.381835    0.124503    0.011280    0.672102    
#> 032: 0.220937    0.960273    3.441449    0.389949    0.118278    0.013685    0.671560    
#> 033: 0.220944    0.979128    3.438112    0.424888    0.113172    0.013001    0.692200    
#> 034: 0.276661    1.000839    3.443867    0.418828    0.122324    0.012831    0.673592    
#> 035: 0.242718    0.957882    3.440157    0.423106    0.118572    0.012190    0.656124    
#> 036: 0.249759    0.987471    3.439190    0.401951    0.131230    0.011580    0.670260    
#> 037: 0.220524    1.004442    3.434765    0.381853    0.145786    0.012005    0.679637    
#> 038: 0.268843    0.980088    3.440017    0.471695    0.150200    0.011405    0.677370    
#> 039: 0.290072    0.977660    3.458553    0.448110    0.142690    0.011458    0.661485    
#> 040: 0.301419    0.967904    3.465608    0.425704    0.135556    0.011883    0.673598    
#> 041: 0.266843    0.966946    3.460611    0.404419    0.128778    0.012277    0.657916    
#> 042: 0.319249    0.966133    3.465023    0.425988    0.122339    0.012801    0.656202    
#> 043: 0.272452    0.975906    3.450827    0.404688    0.133024    0.012161    0.668006    
#> 044: 0.239180    0.994154    3.449106    0.392898    0.126373    0.011553    0.683542    
#> 045: 0.266250    1.000003    3.435149    0.394731    0.120462    0.011512    0.663239    
#> 046: 0.237936    0.973531    3.441711    0.374995    0.138997    0.011332    0.659259    
#> 047: 0.250892    0.998579    3.432232    0.364449    0.132047    0.010766    0.675678    
#> 048: 0.234576    1.000928    3.432335    0.409906    0.125445    0.010227    0.683535    
#> 049: 0.244580    0.993444    3.443346    0.389411    0.119272    0.013475    0.694157    
#> 050: 0.280763    0.952597    3.448187    0.437467    0.118588    0.012801    0.717164    
#> 051: 0.260271    0.976541    3.436884    0.437565    0.127847    0.018395    0.689840    
#> 052: 0.294252    0.988847    3.452882    0.501901    0.130730    0.017475    0.655285    
#> 053: 0.306134    0.992278    3.449146    0.476806    0.124194    0.018962    0.661417    
#> 054: 0.225317    0.970175    3.437777    0.452966    0.127446    0.018014    0.679257    
#> 055: 0.229855    0.985737    3.441072    0.430317    0.121074    0.017998    0.677438    
#> 056: 0.259378    0.977034    3.438747    0.408802    0.128051    0.017098    0.699454    
#> 057: 0.212734    0.986150    3.435108    0.402276    0.132171    0.016243    0.708306    
#> 058: 0.270464    0.990155    3.427570    0.415946    0.125562    0.015431    0.705708    
#> 059: 0.271269    0.948807    3.443815    0.452532    0.121695    0.017241    0.704047    
#> 060: 0.280163    0.956442    3.460151    0.457356    0.141810    0.016379    0.697261    
#> 061: 0.303693    0.977719    3.461533    0.480517    0.134719    0.015699    0.710107    
#> 062: 0.286129    0.985079    3.462679    0.456491    0.140631    0.017888    0.714711    
#> 063: 0.324482    0.934395    3.468548    0.433666    0.136506    0.016994    0.711398    
#> 064: 0.282856    0.957393    3.464970    0.411983    0.129681    0.016231    0.692077    
#> 065: 0.319896    0.945824    3.460405    0.391384    0.139270    0.015420    0.681978    
#> 066: 0.298077    0.988337    3.464761    0.371815    0.133858    0.014649    0.657495    
#> 067: 0.267490    0.955228    3.458127    0.358617    0.127165    0.016965    0.671450    
#> 068: 0.245650    0.954024    3.459044    0.355830    0.127966    0.018521    0.690277    
#> 069: 0.266566    0.957132    3.448265    0.412113    0.127159    0.017595    0.688774    
#> 070: 0.292934    0.950859    3.461036    0.436210    0.120801    0.016715    0.682200    
#> 071: 0.253353    0.978054    3.439996    0.414400    0.142097    0.015879    0.688336    
#> 072: 0.221786    0.953212    3.447313    0.393680    0.134992    0.015085    0.668106    
#> 073: 0.267425    0.974601    3.461467    0.398912    0.128242    0.015304    0.658254    
#> 074: 0.304042    0.944605    3.462703    0.437677    0.121830    0.014539    0.652201    
#> 075: 0.303656    0.942118    3.481160    0.415793    0.117960    0.014650    0.675441    
#> 076: 0.310913    0.953435    3.483324    0.395003    0.127906    0.015387    0.678549    
#> 077: 0.358464    0.933668    3.486172    0.448769    0.132075    0.015958    0.671586    
#> 078: 0.359149    0.958192    3.490104    0.426331    0.125471    0.017178    0.666955    
#> 079: 0.318632    0.983271    3.474065    0.472255    0.119198    0.018371    0.669288    
#> 080: 0.332919    0.975326    3.458841    0.545988    0.113238    0.017452    0.670728    
#> 081: 0.292088    0.995521    3.448263    0.518689    0.107576    0.016580    0.651408    
#> 082: 0.291129    0.967644    3.465281    0.492754    0.107017    0.015751    0.668533    
#> 083: 0.331137    0.991929    3.464157    0.479365    0.106779    0.015798    0.659971    
#> 084: 0.302509    0.980918    3.459399    0.465605    0.121639    0.017158    0.670416    
#> 085: 0.317071    0.978949    3.473859    0.446036    0.122834    0.016856    0.671451    
#> 086: 0.291578    1.002067    3.458931    0.423734    0.125263    0.016014    0.664554    
#> 087: 0.265938    0.993014    3.446448    0.402547    0.148429    0.015213    0.662908    
#> 088: 0.212330    1.001319    3.443968    0.395860    0.141007    0.015106    0.673920    
#> 089: 0.198994    1.008687    3.421923    0.389673    0.133957    0.014351    0.691397    
#> 090: 0.195978    0.991576    3.425931    0.401190    0.142449    0.013633    0.686262    
#> 091: 0.241072    0.984433    3.421018    0.513308    0.135326    0.012951    0.673563    
#> 092: 0.238906    1.001076    3.422655    0.499589    0.128560    0.012304    0.665543    
#> 093: 0.210018    0.977854    3.421046    0.474609    0.122132    0.011689    0.689104    
#> 094: 0.209428    0.995281    3.420540    0.450879    0.116026    0.012765    0.685163    
#> 095: 0.240226    1.034622    3.427518    0.433240    0.141845    0.012851    0.674602    
#> 096: 0.203216    1.021336    3.422147    0.467113    0.146439    0.012209    0.672318    
#> 097: 0.208115    1.034838    3.417626    0.443757    0.139117    0.011598    0.680934    
#> 098: 0.231735    1.042100    3.425884    0.421569    0.132161    0.011018    0.672830    
#> 099: 0.233457    1.006781    3.419545    0.426193    0.144127    0.011359    0.662835    
#> 100: 0.200259    1.011127    3.417244    0.404884    0.136921    0.010791    0.671060    
#> 101: 0.187973    1.002770    3.404962    0.412095    0.141565    0.010251    0.681195    
#> 102: 0.194615    1.003389    3.406799    0.391490    0.144400    0.009739    0.675445    
#> 103: 0.213145    1.007753    3.422712    0.422182    0.137180    0.009557    0.662998    
#> 104: 0.232226    0.999263    3.435957    0.401073    0.137941    0.009079    0.677734    
#> 105: 0.290005    0.974551    3.440479    0.464387    0.138036    0.008625    0.672638    
#> 106: 0.277852    0.965402    3.446518    0.441168    0.131134    0.008949    0.653602    
#> 107: 0.282235    0.986050    3.438935    0.465684    0.124578    0.010359    0.667965    
#> 108: 0.274352    0.971256    3.440378    0.442400    0.134245    0.009841    0.672109    
#> 109: 0.253006    0.992973    3.446153    0.420280    0.127533    0.009349    0.682890    
#> 110: 0.260848    0.987935    3.426910    0.449019    0.121783    0.009721    0.677561    
#> 111: 0.281902    0.980008    3.432220    0.437911    0.122207    0.010732    0.661396    
#> 112: 0.251624    0.972051    3.429921    0.461788    0.125655    0.012390    0.667843    
#> 113: 0.222464    1.005962    3.427230    0.438698    0.130722    0.011771    0.657767    
#> 114: 0.245594    1.013451    3.429495    0.416763    0.124186    0.011182    0.664534    
#> 115: 0.263116    0.979117    3.434620    0.395925    0.117977    0.010623    0.684604    
#> 116: 0.296340    1.004834    3.435408    0.457459    0.128730    0.010601    0.662620    
#> 117: 0.231051    1.010938    3.432207    0.434586    0.122294    0.010071    0.676254    
#> 118: 0.252095    1.003284    3.436019    0.418210    0.137021    0.009568    0.665576    
#> 119: 0.262745    1.001357    3.438570    0.488114    0.130170    0.009089    0.687005    
#> 120: 0.250677    0.982141    3.437850    0.463708    0.137657    0.009140    0.665110    
#> 121: 0.283802    0.991572    3.451172    0.440523    0.153141    0.008683    0.666515    
#> 122: 0.267350    0.963048    3.453065    0.418497    0.145484    0.008249    0.659465    
#> 123: 0.305880    0.981680    3.452931    0.397572    0.142704    0.007837    0.665976    
#> 124: 0.306226    1.006383    3.448303    0.393440    0.152550    0.008307    0.673027    
#> 125: 0.285526    1.003554    3.440466    0.373768    0.144923    0.008616    0.679143    
#> 126: 0.267556    1.006624    3.436599    0.357291    0.137677    0.010046    0.679908    
#> 127: 0.260960    0.988349    3.436983    0.339426    0.130793    0.010686    0.678907    
#> 128: 0.239335    0.993667    3.441460    0.371576    0.133443    0.011174    0.674843    
#> 129: 0.270582    1.004328    3.445759    0.448277    0.126771    0.012181    0.677495    
#> 130: 0.271899    1.002898    3.446915    0.425863    0.123903    0.012271    0.668327    
#> 131: 0.270890    0.991728    3.443931    0.428732    0.130102    0.011658    0.677819    
#> 132: 0.242564    1.005799    3.435868    0.407296    0.123597    0.011075    0.685455    
#> 133: 0.252342    0.979791    3.443689    0.388639    0.117417    0.010532    0.695654    
#> 134: 0.262653    0.956281    3.455256    0.369207    0.111546    0.012832    0.683104    
#> 135: 0.264674    0.964205    3.468665    0.350747    0.108447    0.012561    0.683469    
#> 136: 0.286617    0.969061    3.462521    0.376314    0.135656    0.011933    0.678532    
#> 137: 0.371677    0.954964    3.478871    0.440223    0.128899    0.011336    0.689973    
#> 138: 0.340939    0.976311    3.470637    0.447505    0.148727    0.013100    0.671358    
#> 139: 0.285075    0.964971    3.470703    0.425130    0.141291    0.012445    0.669151    
#> 140: 0.294572    0.963987    3.472351    0.472109    0.134226    0.014599    0.662656    
#> 141: 0.290968    0.966414    3.464107    0.462711    0.131583    0.013896    0.646205    
#> 142: 0.320005    0.950560    3.481461    0.439576    0.130275    0.013658    0.669384    
#> 143: 0.321641    0.983904    3.480137    0.417597    0.123762    0.018678    0.680776    
#> 144: 0.328409    0.968109    3.486279    0.396717    0.117574    0.017744    0.675938    
#> 145: 0.300912    0.980453    3.465717    0.376881    0.111695    0.017218    0.661386    
#> 146: 0.293629    0.967487    3.473477    0.358037    0.119446    0.016357    0.684090    
#> 147: 0.281833    0.962025    3.461067    0.340135    0.132771    0.015539    0.670124    
#> 148: 0.254312    0.965151    3.462125    0.346812    0.135343    0.014762    0.663121    
#> 149: 0.269523    0.945139    3.464158    0.360311    0.131009    0.014024    0.690219    
#> 150: 0.300237    0.939076    3.459202    0.396592    0.137967    0.013604    0.712577    
#> 151: 0.242902    0.977185    3.448133    0.376763    0.131069    0.012924    0.696503    
#> 152: 0.226172    0.961894    3.453034    0.398485    0.106947    0.012703    0.684079    
#> 153: 0.231210    0.967246    3.454552    0.399213    0.128784    0.013687    0.675406    
#> 154: 0.268717    0.987268    3.457255    0.381226    0.136030    0.012337    0.704043    
#> 155: 0.282142    0.957982    3.460682    0.375588    0.097699    0.013976    0.698295    
#> 156: 0.295444    0.971438    3.468087    0.336784    0.104659    0.016004    0.710098    
#> 157: 0.267350    0.964699    3.467709    0.303415    0.093358    0.015561    0.717631    
#> 158: 0.315729    0.975992    3.474488    0.318527    0.101868    0.017005    0.675588    
#> 159: 0.262817    0.966895    3.476105    0.320407    0.106935    0.017803    0.689438    
#> 160: 0.326072    0.924854    3.493385    0.334118    0.109355    0.020319    0.687509    
#> 161: 0.318123    0.938064    3.476611    0.328222    0.116106    0.017378    0.678592    
#> 162: 0.284328    0.979622    3.455609    0.388573    0.134655    0.014157    0.680331    
#> 163: 0.303695    0.973549    3.449940    0.460246    0.135002    0.014469    0.669953    
#> 164: 0.303770    0.986130    3.459765    0.403479    0.121915    0.015881    0.662769    
#> 165: 0.317198    0.969116    3.467744    0.356568    0.103268    0.020159    0.676066    
#> 166: 0.319633    0.992040    3.464716    0.408416    0.096026    0.021200    0.671256    
#> 167: 0.312207    0.995137    3.469560    0.391154    0.102668    0.022044    0.677494    
#> 168: 0.300482    0.989420    3.459070    0.406884    0.106542    0.018533    0.652034    
#> 169: 0.282300    1.019734    3.444714    0.405546    0.102885    0.020111    0.668365    
#> 170: 0.260654    1.003367    3.446433    0.386395    0.112201    0.017434    0.660300    
#> 171: 0.224150    0.993764    3.439152    0.391792    0.110198    0.015945    0.663482    
#> 172: 0.196619    1.014389    3.433682    0.403128    0.126761    0.014040    0.666390    
#> 173: 0.223099    1.005224    3.420456    0.372813    0.123545    0.014895    0.658029    
#> 174: 0.229686    0.990870    3.440594    0.319574    0.121795    0.013317    0.667618    
#> 175: 0.216599    0.998547    3.427562    0.385922    0.118760    0.012827    0.665574    
#> 176: 0.220593    1.013613    3.436506    0.329523    0.121107    0.011762    0.678417    
#> 177: 0.277765    0.980387    3.458159    0.393140    0.111535    0.015645    0.685830    
#> 178: 0.302068    0.980803    3.454551    0.336099    0.122144    0.013921    0.686533    
#> 179: 0.285833    1.002025    3.453834    0.330124    0.150244    0.013763    0.686795    
#> 180: 0.240289    0.973374    3.456381    0.281842    0.121946    0.011911    0.690567    
#> 181: 0.250572    0.966983    3.447739    0.295836    0.133030    0.013029    0.671948    
#> 182: 0.259092    0.986399    3.443918    0.283328    0.114033    0.017299    0.686007    
#> 183: 0.270369    1.003819    3.457451    0.265674    0.112629    0.021098    0.683101    
#> 184: 0.262346    0.976769    3.464280    0.326592    0.113059    0.017149    0.679835    
#> 185: 0.252408    0.984338    3.445878    0.348368    0.124931    0.014969    0.678793    
#> 186: 0.247265    0.978504    3.445424    0.348935    0.124344    0.014648    0.680906    
#> 187: 0.288010    0.990991    3.445494    0.431848    0.117140    0.014905    0.654903    
#> 188: 0.231828    1.012067    3.440340    0.459134    0.120710    0.010900    0.676044    
#> 189: 0.249621    1.005879    3.451320    0.433609    0.143051    0.010855    0.679230    
#> 190: 0.282951    1.000555    3.458309    0.348777    0.128620    0.013626    0.659882    
#> 191: 0.248800    1.000654    3.444128    0.380882    0.144300    0.012826    0.662955    
#> 192: 0.243384    1.001391    3.439967    0.396444    0.124231    0.012144    0.645535    
#> 193: 0.300328    1.010176    3.446422    0.435430    0.126770    0.014658    0.648704    
#> 194: 0.277226    0.998006    3.435934    0.440219    0.123975    0.012896    0.655641    
#> 195: 0.242358    1.006349    3.424596    0.412147    0.136473    0.014349    0.662298    
#> 196: 0.251890    1.003870    3.436373    0.422500    0.119193    0.012583    0.679766    
#> 197: 0.230809    1.002887    3.453655    0.332364    0.135807    0.014636    0.696938    
#> 198: 0.294252    0.978637    3.442234    0.454296    0.119599    0.016103    0.672689    
#> 199: 0.218650    0.989190    3.435552    0.388566    0.109958    0.015199    0.673654    
#> 200: 0.238311    0.994618    3.444160    0.384541    0.111709    0.013309    0.698669    
#> 201: 0.243533    0.991618    3.449117    0.380412    0.107784    0.016336    0.687523    
#> 202: 0.233475    0.989125    3.447715    0.385738    0.108454    0.015847    0.680793    
#> 203: 0.248217    0.988595    3.445735    0.387409    0.109296    0.015404    0.678729    
#> 204: 0.247555    0.986755    3.449285    0.389758    0.110512    0.015643    0.678024    
#> 205: 0.256916    0.988065    3.451713    0.392931    0.109549    0.015852    0.679584    
#> 206: 0.266654    0.989174    3.454687    0.403431    0.108217    0.016143    0.679995    
#> 207: 0.272845    0.985608    3.455569    0.402027    0.108954    0.016146    0.680767    
#> 208: 0.273339    0.984626    3.455460    0.395294    0.108601    0.015854    0.679945    
#> 209: 0.275508    0.980907    3.455296    0.402145    0.110151    0.015683    0.679293    
#> 210: 0.276059    0.979403    3.455876    0.402517    0.110310    0.015629    0.678926    
#> 211: 0.279495    0.979549    3.456022    0.407192    0.112466    0.015431    0.677281    
#> 212: 0.282583    0.979237    3.456707    0.409131    0.113428    0.015162    0.678054    
#> 213: 0.284589    0.976563    3.456977    0.404158    0.114163    0.015232    0.680334    
#> 214: 0.285874    0.975883    3.456977    0.402094    0.113475    0.015049    0.681160    
#> 215: 0.284543    0.975847    3.457260    0.400447    0.112681    0.015046    0.681386    
#> 216: 0.289837    0.973586    3.458250    0.403909    0.113876    0.015044    0.682969    
#> 217: 0.293055    0.974895    3.458360    0.408094    0.114599    0.014854    0.682512    
#> 218: 0.293222    0.975993    3.457834    0.407872    0.115671    0.014666    0.681828    
#> 219: 0.290951    0.975979    3.456957    0.408764    0.116010    0.014468    0.681858    
#> 220: 0.289204    0.976798    3.456536    0.409191    0.116140    0.014515    0.681618    
#> 221: 0.286848    0.977338    3.456252    0.408683    0.116685    0.014477    0.681153    
#> 222: 0.287778    0.977443    3.455701    0.412559    0.116742    0.014495    0.680742    
#> 223: 0.287111    0.977494    3.454988    0.415787    0.117299    0.014415    0.680005    
#> 224: 0.289447    0.977667    3.455039    0.420357    0.117588    0.014304    0.679310    
#> 225: 0.288861    0.976090    3.455244    0.421896    0.117831    0.014179    0.678822    
#> 226: 0.288860    0.975534    3.454619    0.424361    0.117928    0.014140    0.678239    
#> 227: 0.288390    0.975358    3.454354    0.426567    0.118189    0.014142    0.677192    
#> 228: 0.287032    0.976355    3.453585    0.425653    0.117815    0.014154    0.676953    
#> 229: 0.285529    0.976341    3.453097    0.426263    0.117933    0.014168    0.676656    
#> 230: 0.285119    0.976262    3.452724    0.424958    0.117972    0.014198    0.676150    
#> 231: 0.284017    0.976264    3.452593    0.424480    0.117676    0.014227    0.675676    
#> 232: 0.282791    0.976553    3.452313    0.426071    0.117782    0.014213    0.674945    
#> 233: 0.281770    0.976103    3.452130    0.428884    0.117550    0.014213    0.674995    
#> 234: 0.280025    0.976316    3.451835    0.429690    0.117106    0.014256    0.674798    
#> 235: 0.278825    0.976449    3.451452    0.429861    0.116590    0.014311    0.674522    
#> 236: 0.277581    0.976525    3.450928    0.427922    0.116009    0.014331    0.674683    
#> 237: 0.277293    0.976627    3.450871    0.426957    0.115610    0.014346    0.675284    
#> 238: 0.277712    0.976174    3.450973    0.426064    0.115603    0.014375    0.676113    
#> 239: 0.277276    0.976829    3.450931    0.425445    0.116044    0.014391    0.676203    
#> 240: 0.277402    0.976692    3.451017    0.423510    0.116022    0.014388    0.675956    
#> 241: 0.277554    0.975707    3.451222    0.423015    0.116403    0.014358    0.675765    
#> 242: 0.277506    0.975144    3.451241    0.421718    0.116484    0.014314    0.675750    
#> 243: 0.277122    0.975529    3.451172    0.420755    0.116944    0.014241    0.676070    
#> 244: 0.276470    0.975596    3.451324    0.418401    0.116945    0.014201    0.676201    
#> 245: 0.276334    0.975275    3.451250    0.416659    0.117532    0.014115    0.676464    
#> 246: 0.276518    0.975226    3.451317    0.417406    0.118160    0.014122    0.676451    
#> 247: 0.276207    0.975027    3.451279    0.416804    0.118618    0.014072    0.676522    
#> 248: 0.276545    0.974827    3.451385    0.417354    0.118691    0.014001    0.676271    
#> 249: 0.276133    0.974695    3.451501    0.416696    0.119279    0.013930    0.676207    
#> 250: 0.276479    0.974627    3.451645    0.416313    0.119862    0.013934    0.676043    
#> 251: 0.276992    0.975330    3.451841    0.415474    0.120061    0.013932    0.676207    
#> 252: 0.277679    0.975357    3.452282    0.416525    0.120274    0.013927    0.676037    
#> 253: 0.277604    0.975473    3.452499    0.415739    0.120576    0.013958    0.676249    
#> 254: 0.277807    0.975888    3.452635    0.415388    0.120713    0.013959    0.676183    
#> 255: 0.277954    0.976550    3.452761    0.414659    0.120567    0.013992    0.676439    
#> 256: 0.278162    0.976755    3.452769    0.414156    0.120732    0.014017    0.676518    
#> 257: 0.278312    0.976778    3.452819    0.413709    0.121060    0.014010    0.676427    
#> 258: 0.278209    0.976635    3.452995    0.413706    0.121019    0.013989    0.676643    
#> 259: 0.278267    0.976516    3.452984    0.412991    0.121175    0.013983    0.676729    
#> 260: 0.277954    0.976564    3.453093    0.412432    0.121263    0.013970    0.676715    
#> 261: 0.277653    0.976611    3.453072    0.412162    0.121356    0.013935    0.676637    
#> 262: 0.277643    0.976641    3.453137    0.411431    0.121182    0.013920    0.676681    
#> 263: 0.277421    0.976684    3.453181    0.410807    0.121149    0.013919    0.676799    
#> 264: 0.277031    0.976629    3.453207    0.410245    0.121678    0.013870    0.676858    
#> 265: 0.276862    0.976784    3.453202    0.410347    0.121869    0.013829    0.676885    
#> 266: 0.277408    0.976894    3.453329    0.409986    0.122020    0.013800    0.676735    
#> 267: 0.277961    0.976339    3.453650    0.411564    0.121806    0.013767    0.676804    
#> 268: 0.278794    0.975751    3.453737    0.411581    0.121778    0.013781    0.676983    
#> 269: 0.279853    0.975582    3.453929    0.411186    0.121642    0.013813    0.677233    
#> 270: 0.280194    0.975885    3.453881    0.411739    0.121591    0.013809    0.676831    
#> 271: 0.280186    0.975690    3.453891    0.412021    0.121689    0.013830    0.676637    
#> 272: 0.280655    0.975421    3.454032    0.410920    0.121678    0.013861    0.677012    
#> 273: 0.280913    0.975560    3.454274    0.410729    0.121554    0.013890    0.677198    
#> 274: 0.281201    0.975587    3.454617    0.410577    0.121349    0.013920    0.677287    
#> 275: 0.281443    0.975600    3.454651    0.409662    0.121415    0.013896    0.677181    
#> 276: 0.281512    0.975595    3.454888    0.409659    0.121300    0.013921    0.677072    
#> 277: 0.281565    0.975548    3.455097    0.408938    0.121222    0.013942    0.676837    
#> 278: 0.281548    0.975603    3.455276    0.409004    0.121313    0.013949    0.676753    
#> 279: 0.281874    0.975338    3.455385    0.410256    0.121625    0.013929    0.677062    
#> 280: 0.281787    0.975413    3.455407    0.410364    0.122026    0.013887    0.676904    
#> 281: 0.281711    0.975541    3.455421    0.411129    0.122364    0.013856    0.676785    
#> 282: 0.282035    0.975853    3.455435    0.412178    0.122519    0.013822    0.676822    
#> 283: 0.282206    0.975811    3.455503    0.413054    0.122728    0.013793    0.677049    
#> 284: 0.282354    0.975483    3.455574    0.413481    0.122756    0.013761    0.676992    
#> 285: 0.282238    0.975429    3.455493    0.413292    0.122755    0.013738    0.676803    
#> 286: 0.282018    0.975523    3.455436    0.413577    0.122919    0.013737    0.676557    
#> 287: 0.281630    0.975694    3.455244    0.413963    0.122974    0.013734    0.676521    
#> 288: 0.281805    0.975608    3.455131    0.413910    0.123095    0.013745    0.676537    
#> 289: 0.281808    0.975586    3.455093    0.413171    0.123352    0.013706    0.676494    
#> 290: 0.281651    0.975689    3.454987    0.412626    0.123450    0.013697    0.676600    
#> 291: 0.281803    0.975752    3.455163    0.412279    0.123472    0.013687    0.676506    
#> 292: 0.281967    0.975600    3.455234    0.411853    0.123546    0.013660    0.676671    
#> 293: 0.281914    0.975518    3.455208    0.411426    0.123550    0.013621    0.676738    
#> 294: 0.281560    0.975477    3.455115    0.411355    0.123632    0.013617    0.676715    
#> 295: 0.281181    0.975268    3.455003    0.411011    0.123668    0.013603    0.676696    
#> 296: 0.281055    0.975154    3.454939    0.410331    0.123717    0.013635    0.676875    
#> 297: 0.281249    0.975143    3.455002    0.409765    0.123823    0.013664    0.676759    
#> 298: 0.281492    0.975044    3.455051    0.409501    0.123775    0.013681    0.676592    
#> 299: 0.281828    0.975175    3.455070    0.409047    0.123734    0.013661    0.676404    
#> 300: 0.282067    0.974962    3.455227    0.408510    0.123800    0.013648    0.676225    
#> 301: 0.282364    0.974885    3.455284    0.407876    0.123985    0.013608    0.676184    
#> 302: 0.282486    0.975022    3.455250    0.408149    0.124079    0.013587    0.676097    
#> 303: 0.282493    0.975167    3.455211    0.408078    0.124127    0.013571    0.675936    
#> 304: 0.282581    0.975369    3.455094    0.408135    0.124156    0.013575    0.675957    
#> 305: 0.282613    0.975283    3.455007    0.408339    0.124219    0.013583    0.675930    
#> 306: 0.282220    0.975277    3.454872    0.408061    0.124241    0.013602    0.675889    
#> 307: 0.281590    0.975320    3.454688    0.407603    0.124380    0.013572    0.675923    
#> 308: 0.281218    0.975241    3.454565    0.407809    0.124413    0.013545    0.675882    
#> 309: 0.281086    0.975087    3.454509    0.408314    0.124492    0.013541    0.675881    
#> 310: 0.281159    0.974954    3.454350    0.409056    0.124649    0.013534    0.676011    
#> 311: 0.280951    0.974957    3.454239    0.409256    0.124651    0.013530    0.675942    
#> 312: 0.280816    0.974980    3.454117    0.409866    0.124621    0.013501    0.675939    
#> 313: 0.280588    0.974724    3.453951    0.410542    0.124591    0.013456    0.676131    
#> 314: 0.280147    0.974798    3.453766    0.411014    0.124596    0.013419    0.676209    
#> 315: 0.279667    0.974960    3.453592    0.411577    0.124652    0.013381    0.676268    
#> 316: 0.279686    0.975130    3.453531    0.411995    0.124599    0.013404    0.676310    
#> 317: 0.279443    0.975202    3.453496    0.411380    0.124553    0.013397    0.676660    
#> 318: 0.279406    0.975529    3.453354    0.411197    0.124490    0.013406    0.676654    
#> 319: 0.279270    0.975640    3.453280    0.410811    0.124387    0.013415    0.676571    
#> 320: 0.278790    0.975686    3.453208    0.410519    0.124233    0.013413    0.676595    
#> 321: 0.278624    0.975968    3.453073    0.410523    0.124146    0.013413    0.676571    
#> 322: 0.278631    0.976021    3.452953    0.410981    0.124132    0.013423    0.676514    
#> 323: 0.278121    0.976084    3.452836    0.411073    0.124188    0.013429    0.676460    
#> 324: 0.277854    0.976112    3.452797    0.411298    0.124156    0.013443    0.676237    
#> 325: 0.277652    0.976236    3.452681    0.411143    0.124092    0.013444    0.676164    
#> 326: 0.277599    0.976239    3.452549    0.410978    0.124023    0.013432    0.675974    
#> 327: 0.277747    0.976280    3.452501    0.411481    0.123976    0.013434    0.675922    
#> 328: 0.277759    0.976544    3.452429    0.411954    0.123955    0.013440    0.675772    
#> 329: 0.277909    0.976561    3.452422    0.412118    0.123779    0.013452    0.675674    
#> 330: 0.277766    0.976701    3.452372    0.411477    0.123824    0.013470    0.675602    
#> 331: 0.277626    0.976817    3.452308    0.410694    0.123800    0.013473    0.675473    
#> 332: 0.277572    0.976879    3.452381    0.410500    0.123667    0.013515    0.675460    
#> 333: 0.277447    0.976875    3.452312    0.410683    0.123532    0.013538    0.675391    
#> 334: 0.277141    0.976946    3.452157    0.410844    0.123512    0.013552    0.675378    
#> 335: 0.276893    0.977035    3.451969    0.411075    0.123377    0.013539    0.675222    
#> 336: 0.276152    0.977357    3.451724    0.410939    0.123167    0.013565    0.675308    
#> 337: 0.275773    0.977753    3.451513    0.411105    0.123149    0.013591    0.675406    
#> 338: 0.275439    0.977993    3.451414    0.411150    0.123162    0.013596    0.675365    
#> 339: 0.274970    0.978325    3.451241    0.410828    0.123135    0.013591    0.675371    
#> 340: 0.274685    0.978376    3.451130    0.410867    0.123133    0.013592    0.675431    
#> 341: 0.274509    0.978501    3.451056    0.410696    0.123073    0.013570    0.675420    
#> 342: 0.274284    0.978396    3.450975    0.410151    0.123195    0.013551    0.675415    
#> 343: 0.273941    0.978389    3.450889    0.409736    0.123242    0.013529    0.675393    
#> 344: 0.273887    0.978333    3.450866    0.409440    0.123243    0.013529    0.675464    
#> 345: 0.273845    0.978434    3.450846    0.409228    0.123275    0.013538    0.675507    
#> 346: 0.273746    0.978581    3.450720    0.408882    0.123257    0.013522    0.675459    
#> 347: 0.273548    0.978625    3.450613    0.408677    0.123382    0.013517    0.675514    
#> 348: 0.273245    0.978747    3.450517    0.408252    0.123523    0.013499    0.675528    
#> 349: 0.273044    0.978797    3.450481    0.407991    0.123641    0.013490    0.675459    
#> 350: 0.272864    0.978792    3.450449    0.407776    0.123577    0.013498    0.675327    
#> 351: 0.272879    0.978968    3.450382    0.407520    0.123529    0.013496    0.675375    
#> 352: 0.272658    0.979202    3.450340    0.407405    0.123519    0.013488    0.675580    
#> 353: 0.272862    0.979315    3.450325    0.407512    0.123609    0.013487    0.675588    
#> 354: 0.272908    0.979394    3.450254    0.407638    0.123654    0.013482    0.675515    
#> 355: 0.273124    0.979373    3.450201    0.407699    0.123674    0.013497    0.675526    
#> 356: 0.272921    0.979340    3.450185    0.407522    0.123698    0.013505    0.675692    
#> 357: 0.272896    0.979423    3.450180    0.407501    0.123733    0.013524    0.675611    
#> 358: 0.272910    0.979564    3.450178    0.407257    0.123701    0.013528    0.675523    
#> 359: 0.272647    0.979669    3.450121    0.406718    0.123640    0.013525    0.675520    
#> 360: 0.272391    0.979791    3.450031    0.406286    0.123675    0.013520    0.675426    
#> 361: 0.272259    0.979875    3.449947    0.406006    0.123749    0.013512    0.675351    
#> 362: 0.272242    0.979883    3.449861    0.406081    0.123785    0.013496    0.675261    
#> 363: 0.272148    0.979963    3.449782    0.406033    0.123706    0.013483    0.675156    
#> 364: 0.272122    0.979933    3.449748    0.406419    0.123662    0.013452    0.675159    
#> 365: 0.272070    0.979831    3.449787    0.406314    0.123626    0.013433    0.675126    
#> 366: 0.272055    0.979783    3.449786    0.405891    0.123605    0.013425    0.675204    
#> 367: 0.272076    0.979841    3.449875    0.405902    0.123598    0.013421    0.675147    
#> 368: 0.272291    0.979954    3.449908    0.406310    0.123623    0.013440    0.675022    
#> 369: 0.272470    0.979930    3.449944    0.406885    0.123595    0.013436    0.674945    
#> 370: 0.272558    0.980036    3.449923    0.407126    0.123581    0.013431    0.674930    
#> 371: 0.272693    0.980058    3.449809    0.407332    0.123548    0.013419    0.674933    
#> 372: 0.272497    0.980025    3.449731    0.407333    0.123566    0.013413    0.674986    
#> 373: 0.271968    0.980252    3.449571    0.407028    0.123576    0.013400    0.675069    
#> 374: 0.271764    0.980286    3.449496    0.407000    0.123504    0.013398    0.675014    
#> 375: 0.271377    0.980380    3.449419    0.406751    0.123486    0.013397    0.675047    
#> 376: 0.271070    0.980403    3.449371    0.406373    0.123413    0.013416    0.675046    
#> 377: 0.270868    0.980448    3.449343    0.406060    0.123350    0.013418    0.675054    
#> 378: 0.270644    0.980489    3.449302    0.405971    0.123375    0.013421    0.675085    
#> 379: 0.270465    0.980360    3.449288    0.405880    0.123408    0.013424    0.675057    
#> 380: 0.270340    0.980431    3.449211    0.405798    0.123437    0.013412    0.675004    
#> 381: 0.270002    0.980556    3.449105    0.405961    0.123531    0.013389    0.674993    
#> 382: 0.269679    0.980672    3.448993    0.405834    0.123571    0.013356    0.674870    
#> 383: 0.269569    0.980777    3.448943    0.405719    0.123629    0.013333    0.674898    
#> 384: 0.269399    0.980774    3.448924    0.405374    0.123588    0.013309    0.674948    
#> 385: 0.269401    0.980701    3.448929    0.405517    0.123637    0.013318    0.674906    
#> 386: 0.269550    0.980789    3.448986    0.405367    0.123707    0.013325    0.675003    
#> 387: 0.269902    0.980801    3.449050    0.405424    0.123827    0.013321    0.674994    
#> 388: 0.270085    0.980835    3.449100    0.405611    0.123903    0.013322    0.675024    
#> 389: 0.269906    0.980836    3.449058    0.405405    0.123946    0.013315    0.675131    
#> 390: 0.269650    0.980930    3.448965    0.405181    0.124108    0.013291    0.675145    
#> 391: 0.269592    0.980939    3.448929    0.405019    0.124194    0.013263    0.675199    
#> 392: 0.269503    0.980934    3.448936    0.405357    0.124206    0.013269    0.675198    
#> 393: 0.269671    0.980854    3.448984    0.405304    0.124153    0.013276    0.675169    
#> 394: 0.269836    0.980976    3.448952    0.405477    0.124128    0.013289    0.675183    
#> 395: 0.270077    0.981114    3.448972    0.405228    0.124080    0.013289    0.675263    
#> 396: 0.270117    0.981134    3.449032    0.405419    0.124019    0.013296    0.675162    
#> 397: 0.270187    0.981069    3.449132    0.405567    0.123981    0.013313    0.675169    
#> 398: 0.270467    0.980951    3.449211    0.405700    0.123959    0.013327    0.675190    
#> 399: 0.270790    0.980871    3.449323    0.406150    0.123986    0.013353    0.675078    
#> 400: 0.270858    0.980734    3.449392    0.406460    0.123956    0.013368    0.675072    
#> 401: 0.270909    0.980637    3.449462    0.406412    0.123915    0.013384    0.675123    
#> 402: 0.270933    0.980653    3.449481    0.406490    0.123899    0.013395    0.675106    
#> 403: 0.271180    0.980569    3.449536    0.406579    0.123854    0.013416    0.675035    
#> 404: 0.271140    0.980582    3.449496    0.406467    0.123872    0.013419    0.674921    
#> 405: 0.271151    0.980663    3.449503    0.406458    0.123840    0.013426    0.674861    
#> 406: 0.271071    0.980693    3.449469    0.406454    0.123815    0.013423    0.674871    
#> 407: 0.270886    0.980721    3.449451    0.406424    0.123832    0.013419    0.674800    
#> 408: 0.270895    0.980855    3.449446    0.406410    0.123776    0.013419    0.674753    
#> 409: 0.270722    0.980810    3.449376    0.406085    0.123810    0.013406    0.674681    
#> 410: 0.270627    0.980784    3.449301    0.405980    0.123850    0.013384    0.674704    
#> 411: 0.270438    0.980650    3.449237    0.406032    0.123971    0.013379    0.674748    
#> 412: 0.270269    0.980790    3.449130    0.405880    0.124047    0.013360    0.674754    
#> 413: 0.270138    0.980962    3.449013    0.405454    0.124098    0.013350    0.674835    
#> 414: 0.269905    0.981123    3.448932    0.405778    0.124098    0.013349    0.674830    
#> 415: 0.269847    0.981091    3.448866    0.405900    0.124105    0.013336    0.674806    
#> 416: 0.269780    0.981146    3.448824    0.405876    0.124119    0.013329    0.674833    
#> 417: 0.269839    0.981129    3.448795    0.406204    0.124126    0.013334    0.674787    
#> 418: 0.269804    0.981148    3.448796    0.406063    0.124119    0.013322    0.674790    
#> 419: 0.269886    0.981151    3.448799    0.406027    0.124162    0.013322    0.674674    
#> 420: 0.269811    0.981155    3.448779    0.405921    0.124188    0.013318    0.674640    
#> 421: 0.269609    0.981131    3.448789    0.405739    0.124119    0.013322    0.674622    
#> 422: 0.269667    0.981040    3.448771    0.405747    0.124059    0.013315    0.674639    
#> 423: 0.269757    0.981027    3.448738    0.405770    0.123998    0.013305    0.674639    
#> 424: 0.269619    0.981053    3.448679    0.405777    0.123979    0.013300    0.674614    
#> 425: 0.269517    0.981158    3.448631    0.406037    0.123991    0.013310    0.674601    
#> 426: 0.269428    0.981245    3.448614    0.406157    0.123980    0.013319    0.674572    
#> 427: 0.269294    0.981273    3.448586    0.406310    0.123975    0.013311    0.674511    
#> 428: 0.269174    0.981341    3.448557    0.406245    0.123885    0.013297    0.674520    
#> 429: 0.269174    0.981405    3.448545    0.406173    0.123906    0.013296    0.674463    
#> 430: 0.269145    0.981489    3.448500    0.405947    0.123840    0.013292    0.674474    
#> 431: 0.269044    0.981573    3.448430    0.405768    0.123769    0.013284    0.674469    
#> 432: 0.268951    0.981716    3.448410    0.405674    0.123815    0.013264    0.674463    
#> 433: 0.268954    0.981799    3.448430    0.405670    0.123888    0.013246    0.674485    
#> 434: 0.268845    0.981823    3.448457    0.405628    0.123921    0.013238    0.674457    
#> 435: 0.268914    0.981845    3.448433    0.405581    0.124016    0.013215    0.674415    
#> 436: 0.268968    0.981876    3.448462    0.405425    0.124218    0.013194    0.674406    
#> 437: 0.268932    0.981820    3.448438    0.405242    0.124294    0.013176    0.674387    
#> 438: 0.268972    0.981910    3.448467    0.405128    0.124385    0.013173    0.674381    
#> 439: 0.269129    0.981974    3.448488    0.405099    0.124381    0.013172    0.674330    
#> 440: 0.269049    0.982009    3.448515    0.404983    0.124445    0.013170    0.674280    
#> 441: 0.269080    0.981983    3.448538    0.404947    0.124456    0.013170    0.674241    
#> 442: 0.269029    0.982060    3.448565    0.404866    0.124350    0.013168    0.674239    
#> 443: 0.269132    0.982109    3.448586    0.404760    0.124272    0.013169    0.674234    
#> 444: 0.269107    0.982216    3.448545    0.404646    0.124254    0.013173    0.674154    
#> 445: 0.269099    0.982283    3.448519    0.404840    0.124258    0.013185    0.674134    
#> 446: 0.269016    0.982370    3.448456    0.404878    0.124270    0.013182    0.674131    
#> 447: 0.269014    0.982377    3.448410    0.405003    0.124282    0.013179    0.674051    
#> 448: 0.268995    0.982359    3.448435    0.404869    0.124289    0.013186    0.673941    
#> 449: 0.269015    0.982368    3.448545    0.404750    0.124263    0.013196    0.673983    
#> 450: 0.269086    0.982258    3.448598    0.404832    0.124345    0.013207    0.673982    
#> 451: 0.269311    0.982226    3.448611    0.405272    0.124357    0.013215    0.673990    
#> 452: 0.269449    0.982184    3.448638    0.405353    0.124460    0.013222    0.673980    
#> 453: 0.269389    0.982148    3.448630    0.405457    0.124530    0.013226    0.673896    
#> 454: 0.269353    0.982233    3.448606    0.405495    0.124538    0.013219    0.673848    
#> 455: 0.269292    0.982297    3.448581    0.405621    0.124527    0.013209    0.673826    
#> 456: 0.269254    0.982246    3.448564    0.405527    0.124534    0.013206    0.673836    
#> 457: 0.269158    0.982151    3.448579    0.405548    0.124531    0.013206    0.673772    
#> 458: 0.269148    0.982238    3.448582    0.405626    0.124586    0.013206    0.673717    
#> 459: 0.268986    0.982335    3.448576    0.405611    0.124590    0.013208    0.673739    
#> 460: 0.268819    0.982305    3.448541    0.405518    0.124556    0.013202    0.673750    
#> 461: 0.268726    0.982249    3.448539    0.405474    0.124537    0.013198    0.673739    
#> 462: 0.268736    0.982236    3.448618    0.405356    0.124521    0.013212    0.673716    
#> 463: 0.268783    0.982325    3.448658    0.405009    0.124473    0.013228    0.673705    
#> 464: 0.268820    0.982418    3.448680    0.404820    0.124425    0.013236    0.673648    
#> 465: 0.268867    0.982340    3.448707    0.404709    0.124343    0.013240    0.673637    
#> 466: 0.268941    0.982360    3.448705    0.404598    0.124317    0.013240    0.673582    
#> 467: 0.268828    0.982278    3.448725    0.404575    0.124298    0.013243    0.673511    
#> 468: 0.268987    0.982275    3.448783    0.404525    0.124268    0.013242    0.673519    
#> 469: 0.269051    0.982344    3.448803    0.404708    0.124320    0.013231    0.673562    
#> 470: 0.269028    0.982412    3.448767    0.404993    0.124376    0.013238    0.673568    
#> 471: 0.268933    0.982322    3.448744    0.405186    0.124349    0.013235    0.673555    
#> 472: 0.268894    0.982237    3.448715    0.405222    0.124389    0.013229    0.673527    
#> 473: 0.268800    0.982229    3.448677    0.405209    0.124375    0.013219    0.673478    
#> 474: 0.268724    0.982278    3.448617    0.405373    0.124336    0.013217    0.673538    
#> 475: 0.268764    0.982365    3.448623    0.405400    0.124361    0.013205    0.673527    
#> 476: 0.268774    0.982348    3.448594    0.405461    0.124309    0.013197    0.673595    
#> 477: 0.268646    0.982361    3.448578    0.405372    0.124274    0.013183    0.673616    
#> 478: 0.268521    0.982419    3.448560    0.405303    0.124291    0.013172    0.673641    
#> 479: 0.268724    0.982441    3.448611    0.405212    0.124320    0.013174    0.673699    
#> 480: 0.268759    0.982442    3.448633    0.405073    0.124432    0.013176    0.673816    
#> 481: 0.268729    0.982455    3.448616    0.405036    0.124474    0.013175    0.673836    
#> 482: 0.268702    0.982497    3.448567    0.405116    0.124459    0.013173    0.673848    
#> 483: 0.268631    0.982491    3.448528    0.405440    0.124473    0.013165    0.673810    
#> 484: 0.268548    0.982488    3.448462    0.405741    0.124411    0.013164    0.673827    
#> 485: 0.268489    0.982539    3.448418    0.406099    0.124397    0.013162    0.673827    
#> 486: 0.268416    0.982568    3.448390    0.406202    0.124423    0.013153    0.673835    
#> 487: 0.268452    0.982597    3.448403    0.406305    0.124499    0.013139    0.673815    
#> 488: 0.268312    0.982560    3.448392    0.406259    0.124493    0.013123    0.673819    
#> 489: 0.268409    0.982550    3.448347    0.406324    0.124492    0.013106    0.673867    
#> 490: 0.268604    0.982514    3.448371    0.406675    0.124546    0.013091    0.673840    
#> 491: 0.268706    0.982534    3.448489    0.406553    0.124550    0.013094    0.673790    
#> 492: 0.268815    0.982583    3.448551    0.406532    0.124542    0.013092    0.673797    
#> 493: 0.268876    0.982547    3.448608    0.406351    0.124531    0.013085    0.673851    
#> 494: 0.269050    0.982534    3.448652    0.406274    0.124604    0.013086    0.673815    
#> 495: 0.269144    0.982491    3.448682    0.406122    0.124668    0.013081    0.673809    
#> 496: 0.269350    0.982512    3.448683    0.405964    0.124723    0.013083    0.673808    
#> 497: 0.269336    0.982510    3.448690    0.406028    0.124739    0.013088    0.673771    
#> 498: 0.269375    0.982508    3.448675    0.406010    0.124774    0.013087    0.673732    
#> 499: 0.269396    0.982488    3.448662    0.405808    0.124734    0.013083    0.673755    
#> 500: 0.269394    0.982510    3.448650    0.405684    0.124694    0.013081    0.673690    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.299891    0.974257    3.452864    0.392401    0.084774    0.016800    1.667560    
#> 002: 0.441960    1.045538    3.477727    0.372781    0.080535    0.016250    1.097318    
#> 003: 0.604735    1.005778    3.491854    0.421206    0.076509    0.015438    0.845437    
#> 004: 0.661023    1.012117    3.502392    0.559570    0.072683    0.014666    0.787529    
#> 005: 0.738926    1.038539    3.493386    0.624966    0.069049    0.013932    0.720478    
#> 006: 0.697556    1.053451    3.479777    0.657801    0.065597    0.013236    0.701672    
#> 007: 0.656146    1.058322    3.482630    0.654958    0.062317    0.012574    0.734154    
#> 008: 0.678529    1.043601    3.480215    0.701591    0.059201    0.011945    0.728165    
#> 009: 0.650765    1.034426    3.470441    0.773503    0.056241    0.011348    0.735844    
#> 010: 0.691080    1.048702    3.466288    0.774911    0.053429    0.010781    0.733652    
#> 011: 0.719148    1.086944    3.463701    0.913808    0.050757    0.010242    0.710489    
#> 012: 0.675450    1.063838    3.455235    0.868118    0.048220    0.009730    0.705629    
#> 013: 0.598501    1.080182    3.443274    0.824712    0.045809    0.009243    0.724114    
#> 014: 0.670551    1.076677    3.457242    0.810678    0.043518    0.008781    0.722102    
#> 015: 0.678499    1.077723    3.471465    0.844401    0.041342    0.008342    0.695767    
#> 016: 0.691664    1.083648    3.464777    0.846946    0.039275    0.007925    0.699202    
#> 017: 0.664936    1.070483    3.481308    0.804599    0.037311    0.007529    0.689625    
#> 018: 0.702384    1.069903    3.468933    0.793482    0.035446    0.007152    0.691816    
#> 019: 0.646200    1.066524    3.468491    0.753808    0.033673    0.006795    0.676376    
#> 020: 0.667628    1.072970    3.470585    0.797045    0.031990    0.006455    0.692563    
#> 021: 0.699098    1.047730    3.478429    0.757193    0.030390    0.006132    0.690139    
#> 022: 0.771519    1.042527    3.480293    1.002662    0.028871    0.005825    0.668188    
#> 023: 0.821320    1.054297    3.496064    0.954836    0.027427    0.005534    0.687941    
#> 024: 0.799587    1.061140    3.493749    0.958151    0.026056    0.005257    0.674915    
#> 025: 0.725886    1.054366    3.488646    0.910243    0.024753    0.004995    0.696908    
#> 026: 0.656076    1.052119    3.479649    0.864731    0.023515    0.004745    0.699548    
#> 027: 0.655093    1.064371    3.470782    0.821494    0.022340    0.004508    0.691089    
#> 028: 0.776528    1.051472    3.480770    1.009521    0.021223    0.004282    0.679839    
#> 029: 0.794777    1.038436    3.476655    1.096066    0.020162    0.004068    0.690215    
#> 030: 0.798438    1.056798    3.477767    1.120118    0.019153    0.003865    0.675183    
#> 031: 0.743330    1.049717    3.483830    1.064112    0.018196    0.003671    0.686944    
#> 032: 0.768186    1.053712    3.488426    1.023503    0.017286    0.003488    0.672554    
#> 033: 0.784725    1.070243    3.482290    1.028485    0.016422    0.003314    0.664675    
#> 034: 0.864856    1.073147    3.482223    1.115082    0.015601    0.003148    0.683638    
#> 035: 0.762114    1.056707    3.481925    1.059328    0.014821    0.002990    0.678335    
#> 036: 0.788103    1.051521    3.486820    1.006362    0.014080    0.002841    0.679896    
#> 037: 0.810415    1.061752    3.487172    1.018862    0.013376    0.002699    0.700916    
#> 038: 0.697801    1.074094    3.474532    0.967919    0.012707    0.002564    0.688780    
#> 039: 0.767315    1.069559    3.480322    1.010974    0.012071    0.002436    0.681202    
#> 040: 0.774739    1.083438    3.481257    0.960425    0.011630    0.002314    0.688752    
#> 041: 0.710816    1.060359    3.483621    0.912404    0.011048    0.002198    0.694314    
#> 042: 0.750618    1.055281    3.477492    0.866784    0.010496    0.002088    0.686273    
#> 043: 0.688631    1.070929    3.466510    0.823444    0.009971    0.001984    0.673711    
#> 044: 0.698176    1.067683    3.465972    0.782272    0.009473    0.001885    0.671597    
#> 045: 0.689109    1.082883    3.463822    0.743159    0.008999    0.001790    0.665913    
#> 046: 0.712936    1.084376    3.465281    0.798732    0.008549    0.001701    0.679680    
#> 047: 0.704375    1.080265    3.464289    0.758795    0.008122    0.001616    0.676391    
#> 048: 0.686826    1.071874    3.463315    0.720855    0.007715    0.001535    0.668358    
#> 049: 0.672399    1.062154    3.471096    0.684812    0.007330    0.001458    0.669341    
#> 050: 0.734905    1.061046    3.470944    0.790280    0.008300    0.001436    0.684601    
#> 051: 0.676438    1.062872    3.472214    0.794794    0.008190    0.001364    0.693831    
#> 052: 0.732754    1.077999    3.477402    0.755054    0.007780    0.001403    0.693994    
#> 053: 0.731974    1.068851    3.477668    0.819965    0.007391    0.001333    0.686758    
#> 054: 0.663530    1.069369    3.478314    0.778967    0.007022    0.001266    0.687229    
#> 055: 0.710423    1.057674    3.478278    0.740018    0.006671    0.001203    0.689622    
#> 056: 0.718155    1.049001    3.477904    0.827945    0.006454    0.001143    0.691996    
#> 057: 0.737513    1.037217    3.479477    0.786547    0.006131    0.001085    0.699518    
#> 058: 0.733882    1.048302    3.473546    0.766361    0.005824    0.001031    0.699026    
#> 059: 0.700245    1.036125    3.476871    0.745869    0.005533    0.001150    0.699299    
#> 060: 0.716478    1.027163    3.483301    0.710996    0.005256    0.001206    0.708569    
#> 061: 0.797919    1.039884    3.483981    0.859174    0.004994    0.001146    0.698287    
#> 062: 0.759915    1.048439    3.481872    0.873544    0.004751    0.001089    0.701521    
#> 063: 0.724018    1.052731    3.475489    0.829867    0.004514    0.001175    0.695392    
#> 064: 0.695840    1.062060    3.481598    0.788374    0.004288    0.001116    0.696531    
#> 065: 0.689008    1.047290    3.481375    0.748955    0.004073    0.001061    0.686603    
#> 066: 0.734987    1.047883    3.483063    0.799431    0.003870    0.001007    0.685162    
#> 067: 0.770854    1.053811    3.481588    1.062550    0.003676    0.001005    0.680850    
#> 068: 0.752022    1.060770    3.485491    1.009422    0.003492    0.000965    0.677274    
#> 069: 0.831717    1.067998    3.478381    1.204372    0.003318    0.000918    0.678102    
#> 070: 0.788396    1.070509    3.484763    1.284962    0.003152    0.001021    0.678213    
#> 071: 0.762227    1.083127    3.476486    1.220714    0.002994    0.000970    0.678195    
#> 072: 0.716840    1.080126    3.472130    1.159678    0.002845    0.000974    0.699388    
#> 073: 0.788963    1.078720    3.480477    1.101694    0.002702    0.000925    0.680565    
#> 074: 0.742959    1.075342    3.485677    1.046610    0.002567    0.000914    0.672295    
#> 075: 0.708472    1.075407    3.490277    0.994279    0.002744    0.000869    0.672825    
#> 076: 0.731846    1.076478    3.492519    0.944565    0.002759    0.000825    0.682937    
#> 077: 0.788694    1.067033    3.490879    0.909046    0.002621    0.000784    0.681902    
#> 078: 0.779626    1.060836    3.491182    0.905526    0.002490    0.000745    0.682023    
#> 079: 0.751446    1.071798    3.497044    0.860249    0.002366    0.000914    0.694326    
#> 080: 0.744112    1.074631    3.488905    0.896177    0.002247    0.001375    0.695624    
#> 081: 0.718619    1.073348    3.485099    0.851368    0.002220    0.001306    0.685166    
#> 082: 0.754038    1.071127    3.491858    0.855131    0.003115    0.001354    0.688473    
#> 083: 0.744458    1.068921    3.492109    0.919717    0.003368    0.001389    0.689496    
#> 084: 0.804804    1.083815    3.493510    1.018532    0.003651    0.001320    0.686663    
#> 085: 0.715623    1.087667    3.501932    0.967605    0.003543    0.001254    0.704742    
#> 086: 0.744518    1.083819    3.491471    0.948194    0.003365    0.001191    0.689156    
#> 087: 0.731569    1.084916    3.486400    0.900784    0.003240    0.001131    0.682675    
#> 088: 0.732456    1.075133    3.487801    0.867652    0.003199    0.001137    0.685037    
#> 089: 0.753219    1.086081    3.479832    0.887434    0.003039    0.001080    0.675310    
#> 090: 0.762776    1.091980    3.480045    0.843062    0.002887    0.001026    0.677541    
#> 091: 0.732070    1.081703    3.471182    0.900085    0.002893    0.000975    0.683435    
#> 092: 0.677840    1.091379    3.471127    0.855081    0.002748    0.000926    0.674058    
#> 093: 0.652985    1.091506    3.473388    0.812327    0.002611    0.000879    0.683693    
#> 094: 0.686566    1.085150    3.467031    0.771710    0.002480    0.000836    0.680778    
#> 095: 0.666542    1.088630    3.467400    0.803071    0.002356    0.000794    0.692536    
#> 096: 0.677090    1.092590    3.470787    0.771329    0.002598    0.000754    0.685199    
#> 097: 0.685399    1.103667    3.466586    0.732763    0.002884    0.000716    0.673662    
#> 098: 0.737122    1.104756    3.469879    0.776863    0.003099    0.000718    0.678514    
#> 099: 0.665705    1.102220    3.466804    0.738020    0.003941    0.000778    0.688623    
#> 100: 0.675538    1.099860    3.469935    0.701119    0.003744    0.001035    0.673845    
#> 101: 0.660840    1.093359    3.460719    0.738012    0.003670    0.001062    0.666389    
#> 102: 0.685675    1.086684    3.454627    0.714652    0.003487    0.001009    0.677185    
#> 103: 0.730318    1.086492    3.460085    0.836392    0.003313    0.000959    0.689542    
#> 104: 0.739324    1.084306    3.467077    0.902160    0.003147    0.000911    0.694220    
#> 105: 0.774540    1.083253    3.462350    1.125218    0.002990    0.000865    0.703451    
#> 106: 0.727982    1.093305    3.462655    1.068957    0.002840    0.000822    0.690948    
#> 107: 0.713725    1.092467    3.468974    1.015509    0.002698    0.000781    0.697252    
#> 108: 0.700981    1.090380    3.471040    0.964734    0.002563    0.000742    0.696112    
#> 109: 0.754298    1.093925    3.474871    0.916497    0.002577    0.000705    0.680355    
#> 110: 0.691765    1.100507    3.471935    0.870672    0.002448    0.000683    0.680470    
#> 111: 0.721611    1.097921    3.472696    0.827139    0.002326    0.000649    0.678596    
#> 112: 0.659729    1.089740    3.469077    0.785782    0.002209    0.000617    0.684656    
#> 113: 0.655729    1.095973    3.467084    0.807149    0.002099    0.000586    0.688672    
#> 114: 0.692710    1.099547    3.465795    0.766792    0.001994    0.000556    0.682543    
#> 115: 0.724352    1.094049    3.465416    0.875700    0.001894    0.000529    0.665435    
#> 116: 0.727314    1.098740    3.468074    0.979378    0.001800    0.000502    0.671938    
#> 117: 0.688280    1.101822    3.469822    0.930409    0.001710    0.000477    0.687861    
#> 118: 0.710637    1.105265    3.469621    0.883888    0.001624    0.000453    0.686749    
#> 119: 0.685264    1.104564    3.469097    0.839694    0.001616    0.000532    0.691903    
#> 120: 0.680193    1.102662    3.468241    0.797709    0.001535    0.000611    0.686550    
#> 121: 0.737876    1.106210    3.466275    0.908428    0.001458    0.000581    0.680085    
#> 122: 0.720359    1.098240    3.468021    0.863006    0.001385    0.000552    0.668646    
#> 123: 0.781337    1.101250    3.467455    1.039429    0.001316    0.000524    0.684842    
#> 124: 0.732371    1.107193    3.465447    0.987457    0.001250    0.000498    0.691718    
#> 125: 0.740061    1.110886    3.465188    0.938084    0.001270    0.000473    0.687558    
#> 126: 0.686656    1.118310    3.460789    0.891180    0.001236    0.000495    0.684685    
#> 127: 0.705190    1.123632    3.458991    0.846621    0.001174    0.000471    0.696806    
#> 128: 0.711593    1.125674    3.464279    0.889605    0.001115    0.000459    0.696600    
#> 129: 0.719922    1.125341    3.464385    0.845124    0.001072    0.000436    0.711827    
#> 130: 0.775138    1.127324    3.463408    0.923576    0.001018    0.000415    0.697263    
#> 131: 0.705804    1.126745    3.463119    0.877398    0.000967    0.000394    0.693226    
#> 132: 0.630437    1.124926    3.457787    0.833528    0.000919    0.000374    0.703856    
#> 133: 0.627726    1.117958    3.459725    0.791851    0.000873    0.000355    0.702743    
#> 134: 0.669388    1.112021    3.458796    0.752259    0.000829    0.000380    0.681860    
#> 135: 0.677216    1.108646    3.460400    0.741664    0.000788    0.000419    0.693450    
#> 136: 0.631780    1.107169    3.460140    0.704581    0.000748    0.000398    0.690111    
#> 137: 0.687070    1.108513    3.460289    0.832800    0.000711    0.000378    0.688031    
#> 138: 0.718300    1.106494    3.464435    0.797634    0.000690    0.000359    0.682045    
#> 139: 0.653297    1.101653    3.467726    0.774770    0.000655    0.000346    0.683198    
#> 140: 0.719147    1.101608    3.468625    0.896323    0.000716    0.000417    0.689496    
#> 141: 0.652274    1.098976    3.470011    0.851507    0.000683    0.000396    0.706438    
#> 142: 0.683277    1.095144    3.474614    0.808932    0.000657    0.000377    0.692350    
#> 143: 0.636460    1.094157    3.473497    0.768485    0.000865    0.000389    0.685647    
#> 144: 0.716878    1.098055    3.476376    0.754735    0.000822    0.000369    0.679415    
#> 145: 0.721296    1.096024    3.477258    0.810226    0.000851    0.000351    0.684989    
#> 146: 0.698333    1.099225    3.479366    0.769715    0.000808    0.000333    0.676892    
#> 147: 0.684041    1.098039    3.479277    0.767616    0.000768    0.000317    0.681551    
#> 148: 0.703729    1.098482    3.480880    0.786020    0.000748    0.000301    0.678220    
#> 149: 0.722946    1.091346    3.481485    0.746719    0.000940    0.000286    0.707269    
#> 150: 0.758611    1.092655    3.480445    0.802355    0.001104    0.000272    0.692320    
#> 151: 0.687245    1.097590    3.480163    0.762237    0.001049    0.000258    0.692768    
#> 152: 0.745429    1.097985    3.481132    0.915473    0.001473    0.000208    0.681519    
#> 153: 0.744314    1.100888    3.481627    0.933297    0.001587    0.000174    0.682785    
#> 154: 0.777384    1.100336    3.484343    1.051234    0.001378    0.000164    0.686063    
#> 155: 0.694948    1.090683    3.483846    0.800139    0.001309    0.000173    0.688642    
#> 156: 0.732147    1.087290    3.485456    0.829470    0.001653    0.000135    0.685746    
#> 157: 0.723500    1.084340    3.486194    0.779700    0.001565    0.000164    0.696504    
#> 158: 0.765466    1.089198    3.487238    0.730208    0.001713    0.000156    0.689712    
#> 159: 0.705985    1.085086    3.487845    0.713993    0.001638    0.000114    0.679687    
#> 160: 0.754461    1.074797    3.488592    0.788983    0.001632    0.000127    0.691547    
#> 161: 0.764180    1.075220    3.488268    0.745321    0.001184    0.000173    0.690367    
#> 162: 0.748421    1.073339    3.485825    0.745447    0.001154    0.000144    0.684831    
#> 163: 0.771788    1.066962    3.485489    0.938928    0.001054    0.000136    0.674961    
#> 164: 0.770400    1.068310    3.486363    0.826128    0.001140    0.000121    0.691890    
#> 165: 0.789564    1.067698    3.488952    0.882201    0.001278    0.000110    0.685043    
#> 166: 0.877435    1.077333    3.488313    1.145719    0.001290    0.000103    0.702838    
#> 167: 0.812514    1.070926    3.488078    1.051112    0.001236    0.000103    0.688203    
#> 168: 0.786386    1.073554    3.489645    0.886099    0.001092    0.000072    0.682235    
#> 169: 0.803542    1.075358    3.488639    0.925394    0.001042    0.000060    0.685436    
#> 170: 0.779317    1.073470    3.487264    0.920460    0.000858    0.000049    0.690471    
#> 171: 0.754843    1.074859    3.487124    0.897443    0.001174    0.000057    0.673578    
#> 172: 0.775515    1.075615    3.485697    0.932476    0.001239    0.000054    0.680111    
#> 173: 0.778750    1.077879    3.484326    0.860760    0.001321    0.000051    0.688255    
#> 174: 0.774938    1.078598    3.484853    0.887426    0.001143    0.000047    0.686637    
#> 175: 0.734080    1.075745    3.485023    0.817790    0.001188    0.000043    0.679124    
#> 176: 0.779437    1.080489    3.485386    0.997359    0.000776    0.000023    0.673593    
#> 177: 0.753572    1.081040    3.486008    0.914750    0.000837    0.000023    0.680233    
#> 178: 0.758378    1.083517    3.485903    0.839979    0.001157    0.000021    0.672119    
#> 179: 0.756623    1.081950    3.485362    0.783812    0.000961    0.000020    0.678955    
#> 180: 0.719394    1.080989    3.486399    0.844766    0.000881    0.000018    0.675536    
#> 181: 0.715143    1.073549    3.484941    0.833875    0.000432    0.000015    0.682828    
#> 182: 0.705462    1.071874    3.484549    0.667693    0.000374    0.000014    0.698141    
#> 183: 0.745056    1.076773    3.484300    0.755805    0.000372    0.000012    0.691004    
#> 184: 0.738415    1.074678    3.483868    0.846735    0.000417    0.000013    0.688906    
#> 185: 0.686851    1.074913    3.482644    0.687570    0.000490    0.000013    0.685762    
#> 186: 0.689609    1.075697    3.483288    0.701421    0.000470    0.000014    0.686733    
#> 187: 0.716406    1.073299    3.483503    0.748255    0.000448    0.000013    0.678304    
#> 188: 0.688183    1.080888    3.482829    0.805236    0.000518    0.000016    0.681861    
#> 189: 0.772140    1.085760    3.483045    0.956650    0.000630    0.000015    0.682696    
#> 190: 0.831948    1.089080    3.483280    1.286883    0.000618    0.000017    0.676303    
#> 191: 0.843822    1.087314    3.483513    1.316508    0.000523    0.000013    0.678080    
#> 192: 0.783619    1.088604    3.483523    1.126263    0.000577    0.000015    0.678989    
#> 193: 0.854902    1.091474    3.483739    1.060509    0.000666    0.000014    0.683839    
#> 194: 0.780759    1.090384    3.483093    1.024265    0.000737    0.000017    0.677926    
#> 195: 0.686931    1.092902    3.482371    0.820418    0.000734    0.000016    0.696823    
#> 196: 0.698030    1.088951    3.482438    0.712617    0.000795    0.000015    0.696555    
#> 197: 0.711743    1.094560    3.483001    0.776088    0.000659    0.000016    0.696945    
#> 198: 0.718567    1.090971    3.482095    0.689622    0.000794    0.000022    0.688125    
#> 199: 0.695315    1.090051    3.482127    0.828167    0.000776    0.000019    0.680174    
#> 200: 0.672459    1.089574    3.481883    0.691354    0.000910    0.000020    0.691460    
#> 201: 0.667407    1.086415    3.481924    0.647606    0.000908    0.000021    0.691671    
#> 202: 0.673810    1.084345    3.481934    0.677480    0.000951    0.000022    0.691528    
#> 203: 0.677696    1.083930    3.481882    0.668246    0.000933    0.000023    0.688274    
#> 204: 0.691219    1.082486    3.482079    0.686140    0.000974    0.000022    0.686466    
#> 205: 0.690395    1.083624    3.482044    0.688839    0.001000    0.000022    0.685023    
#> 206: 0.698361    1.084967    3.482082    0.706261    0.000984    0.000022    0.684320    
#> 207: 0.695362    1.084870    3.482014    0.712969    0.000995    0.000022    0.684177    
#> 208: 0.703905    1.084398    3.481989    0.739960    0.001016    0.000022    0.682669    
#> 209: 0.706580    1.084093    3.481919    0.741339    0.001041    0.000022    0.682245    
#> 210: 0.710068    1.083798    3.481919    0.740493    0.001034    0.000023    0.681137    
#> 211: 0.712151    1.084171    3.481976    0.740379    0.001030    0.000023    0.681008    
#> 212: 0.714989    1.083666    3.482058    0.748473    0.001039    0.000023    0.680365    
#> 213: 0.720515    1.082713    3.482051    0.769290    0.001081    0.000023    0.679565    
#> 214: 0.725473    1.081827    3.482067    0.780694    0.001106    0.000023    0.679475    
#> 215: 0.724894    1.081436    3.482116    0.785053    0.001121    0.000023    0.678852    
#> 216: 0.727559    1.080685    3.482099    0.786885    0.001151    0.000023    0.678798    
#> 217: 0.729017    1.080445    3.482055    0.792879    0.001148    0.000023    0.679124    
#> 218: 0.731585    1.080672    3.482006    0.798158    0.001147    0.000023    0.679445    
#> 219: 0.730490    1.080607    3.481920    0.796087    0.001154    0.000023    0.680165    
#> 220: 0.729218    1.080367    3.481877    0.798223    0.001134    0.000023    0.680196    
#> 221: 0.727689    1.080119    3.481852    0.796797    0.001121    0.000023    0.680655    
#> 222: 0.726209    1.079679    3.481863    0.795934    0.001111    0.000023    0.681291    
#> 223: 0.727142    1.079455    3.481835    0.798054    0.001113    0.000023    0.681219    
#> 224: 0.729284    1.079259    3.481856    0.801284    0.001108    0.000023    0.681667    
#> 225: 0.727546    1.078678    3.481881    0.798262    0.001112    0.000023    0.682299    
#> 226: 0.726741    1.078005    3.481887    0.797124    0.001119    0.000023    0.682064    
#> 227: 0.726762    1.077677    3.481910    0.791918    0.001117    0.000023    0.682309    
#> 228: 0.725128    1.077642    3.481900    0.787578    0.001113    0.000023    0.682747    
#> 229: 0.723606    1.077507    3.481893    0.784261    0.001098    0.000023    0.683138    
#> 230: 0.724233    1.077091    3.481875    0.784934    0.001091    0.000023    0.683052    
#> 231: 0.725449    1.077007    3.481865    0.788731    0.001083    0.000023    0.682889    
#> 232: 0.724310    1.076923    3.481880    0.789964    0.001083    0.000023    0.682702    
#> 233: 0.723207    1.076924    3.481896    0.788286    0.001085    0.000022    0.683133    
#> 234: 0.723503    1.077103    3.481910    0.790191    0.001089    0.000022    0.683398    
#> 235: 0.723034    1.077071    3.481905    0.788375    0.001106    0.000022    0.683724    
#> 236: 0.721443    1.077186    3.481900    0.785939    0.001111    0.000022    0.684208    
#> 237: 0.721977    1.077008    3.481894    0.788897    0.001110    0.000022    0.684299    
#> 238: 0.721753    1.076965    3.481890    0.788939    0.001106    0.000022    0.684348    
#> 239: 0.721348    1.076896    3.481879    0.788940    0.001101    0.000022    0.684617    
#> 240: 0.721091    1.076721    3.481860    0.786198    0.001098    0.000022    0.684797    
#> 241: 0.720614    1.076608    3.481864    0.784975    0.001104    0.000022    0.684616    
#> 242: 0.721195    1.076443    3.481858    0.788871    0.001118    0.000022    0.684561    
#> 243: 0.720047    1.076480    3.481855    0.786644    0.001138    0.000022    0.684367    
#> 244: 0.719987    1.076302    3.481856    0.785410    0.001145    0.000022    0.684253    
#> 245: 0.719990    1.076193    3.481855    0.786233    0.001158    0.000022    0.684675    
#> 246: 0.720633    1.076067    3.481855    0.786626    0.001162    0.000022    0.684834    
#> 247: 0.721289    1.075885    3.481850    0.787817    0.001160    0.000022    0.685019    
#> 248: 0.721637    1.075798    3.481844    0.788122    0.001164    0.000022    0.684739    
#> 249: 0.721636    1.075801    3.481838    0.789368    0.001168    0.000022    0.684758    
#> 250: 0.722748    1.075764    3.481843    0.790322    0.001163    0.000022    0.684824    
#> 251: 0.723897    1.075787    3.481856    0.792420    0.001162    0.000022    0.684774    
#> 252: 0.724210    1.075776    3.481881    0.792645    0.001157    0.000022    0.684887    
#> 253: 0.724312    1.075797    3.481883    0.794906    0.001153    0.000022    0.684804    
#> 254: 0.724808    1.075920    3.481887    0.797127    0.001149    0.000022    0.684761    
#> 255: 0.725977    1.075997    3.481906    0.800019    0.001147    0.000022    0.684628    
#> 256: 0.726113    1.076040    3.481903    0.800485    0.001141    0.000023    0.684565    
#> 257: 0.725548    1.075966    3.481910    0.798842    0.001135    0.000023    0.684634    
#> 258: 0.725846    1.075864    3.481894    0.800042    0.001131    0.000023    0.684636    
#> 259: 0.726022    1.075918    3.481867    0.801482    0.001130    0.000023    0.684871    
#> 260: 0.726174    1.076138    3.481852    0.801303    0.001132    0.000023    0.684874    
#> 261: 0.726327    1.076297    3.481841    0.799588    0.001134    0.000023    0.684808    
#> 262: 0.725954    1.076296    3.481836    0.797560    0.001139    0.000023    0.684691    
#> 263: 0.725459    1.076317    3.481830    0.797214    0.001140    0.000023    0.684618    
#> 264: 0.724662    1.076356    3.481807    0.794976    0.001150    0.000023    0.684629    
#> 265: 0.724129    1.076377    3.481803    0.793655    0.001163    0.000023    0.684851    
#> 266: 0.723641    1.076383    3.481806    0.792207    0.001171    0.000023    0.684933    
#> 267: 0.723291    1.076399    3.481814    0.791998    0.001167    0.000023    0.685075    
#> 268: 0.723674    1.076355    3.481809    0.794530    0.001165    0.000023    0.684967    
#> 269: 0.723692    1.076330    3.481805    0.794763    0.001167    0.000023    0.684812    
#> 270: 0.724105    1.076274    3.481788    0.795570    0.001163    0.000023    0.684752    
#> 271: 0.724677    1.076317    3.481777    0.798084    0.001159    0.000023    0.684803    
#> 272: 0.725096    1.076320    3.481759    0.799685    0.001156    0.000023    0.684769    
#> 273: 0.725673    1.076241    3.481734    0.803412    0.001156    0.000023    0.684745    
#> 274: 0.725452    1.076133    3.481729    0.802149    0.001154    0.000023    0.684714    
#> 275: 0.725735    1.076130    3.481714    0.801581    0.001146    0.000023    0.684676    
#> 276: 0.725059    1.076165    3.481716    0.799523    0.001141    0.000023    0.684782    
#> 277: 0.724410    1.076171    3.481722    0.798394    0.001137    0.000023    0.684757    
#> 278: 0.724036    1.076182    3.481732    0.798313    0.001135    0.000023    0.684757    
#> 279: 0.724896    1.076154    3.481745    0.800805    0.001133    0.000023    0.684996    
#> 280: 0.724452    1.076201    3.481747    0.800724    0.001130    0.000023    0.684994    
#> 281: 0.723637    1.076187    3.481753    0.798858    0.001127    0.000023    0.685037    
#> 282: 0.723057    1.076278    3.481758    0.797879    0.001125    0.000023    0.685097    
#> 283: 0.722965    1.076354    3.481768    0.798304    0.001129    0.000023    0.685216    
#> 284: 0.722872    1.076308    3.481771    0.797833    0.001132    0.000023    0.685063    
#> 285: 0.722830    1.076280    3.481763    0.796718    0.001140    0.000023    0.685098    
#> 286: 0.723371    1.076270    3.481758    0.797409    0.001148    0.000023    0.684977    
#> 287: 0.722903    1.076261    3.481751    0.796901    0.001157    0.000024    0.684846    
#> 288: 0.723807    1.076201    3.481748    0.799194    0.001163    0.000024    0.684772    
#> 289: 0.724527    1.076171    3.481742    0.800290    0.001168    0.000024    0.684696    
#> 290: 0.724766    1.076143    3.481726    0.800223    0.001174    0.000024    0.684659    
#> 291: 0.724651    1.076211    3.481718    0.799579    0.001176    0.000024    0.684505    
#> 292: 0.725540    1.076226    3.481706    0.801768    0.001177    0.000023    0.684495    
#> 293: 0.725275    1.076248    3.481696    0.802040    0.001178    0.000023    0.684377    
#> 294: 0.725466    1.076239    3.481684    0.802848    0.001176    0.000023    0.684194    
#> 295: 0.725414    1.076201    3.481672    0.802183    0.001173    0.000023    0.684038    
#> 296: 0.725527    1.076136    3.481670    0.801480    0.001173    0.000023    0.683955    
#> 297: 0.726114    1.076139    3.481672    0.802420    0.001172    0.000023    0.683891    
#> 298: 0.726391    1.076103    3.481674    0.803217    0.001170    0.000024    0.683814    
#> 299: 0.726927    1.076076    3.481683    0.804487    0.001165    0.000024    0.683691    
#> 300: 0.727215    1.076058    3.481699    0.806506    0.001163    0.000023    0.683709    
#> 301: 0.727680    1.075953    3.481704    0.807175    0.001163    0.000023    0.683719    
#> 302: 0.727876    1.075913    3.481700    0.808090    0.001163    0.000023    0.683717    
#> 303: 0.728007    1.075902    3.481697    0.809115    0.001163    0.000023    0.683556    
#> 304: 0.727765    1.075901    3.481693    0.809601    0.001167    0.000023    0.683382    
#> 305: 0.727899    1.075843    3.481695    0.811009    0.001169    0.000023    0.683237    
#> 306: 0.727708    1.075761    3.481695    0.811339    0.001170    0.000023    0.683170    
#> 307: 0.727831    1.075678    3.481690    0.811701    0.001172    0.000023    0.683222    
#> 308: 0.727761    1.075580    3.481686    0.813517    0.001172    0.000023    0.683261    
#> 309: 0.728391    1.075463    3.481679    0.816660    0.001173    0.000023    0.683273    
#> 310: 0.728958    1.075368    3.481671    0.817691    0.001174    0.000023    0.683208    
#> 311: 0.729436    1.075310    3.481663    0.818492    0.001173    0.000023    0.683213    
#> 312: 0.729371    1.075234    3.481653    0.818829    0.001174    0.000023    0.683313    
#> 313: 0.729229    1.075218    3.481641    0.818153    0.001175    0.000023    0.683425    
#> 314: 0.728817    1.075156    3.481629    0.817837    0.001173    0.000023    0.683365    
#> 315: 0.728393    1.075100    3.481620    0.817390    0.001171    0.000023    0.683334    
#> 316: 0.728811    1.075088    3.481616    0.818940    0.001173    0.000023    0.683317    
#> 317: 0.729503    1.075087    3.481614    0.820477    0.001175    0.000023    0.683268    
#> 318: 0.729658    1.075094    3.481611    0.820352    0.001177    0.000023    0.683154    
#> 319: 0.729995    1.075100    3.481612    0.820804    0.001177    0.000023    0.683135    
#> 320: 0.729184    1.075090    3.481605    0.819715    0.001176    0.000023    0.683225    
#> 321: 0.728936    1.075064    3.481593    0.819149    0.001175    0.000023    0.683269    
#> 322: 0.729358    1.075074    3.481579    0.821114    0.001174    0.000023    0.683256    
#> 323: 0.729532    1.075063    3.481570    0.821438    0.001172    0.000023    0.683347    
#> 324: 0.729824    1.075044    3.481567    0.822364    0.001168    0.000023    0.683425    
#> 325: 0.729903    1.075078    3.481562    0.822787    0.001165    0.000023    0.683435    
#> 326: 0.729965    1.075020    3.481554    0.823587    0.001164    0.000023    0.683461    
#> 327: 0.730371    1.075023    3.481549    0.824345    0.001161    0.000023    0.683437    
#> 328: 0.730681    1.075040    3.481544    0.825125    0.001158    0.000023    0.683431    
#> 329: 0.731160    1.075045    3.481542    0.826147    0.001156    0.000023    0.683333    
#> 330: 0.731382    1.075046    3.481541    0.828357    0.001154    0.000023    0.683310    
#> 331: 0.732099    1.075067    3.481543    0.830532    0.001152    0.000023    0.683254    
#> 332: 0.732637    1.075067    3.481545    0.831578    0.001151    0.000023    0.683169    
#> 333: 0.732620    1.075041    3.481544    0.831158    0.001152    0.000023    0.683113    
#> 334: 0.732728    1.074992    3.481541    0.832045    0.001153    0.000023    0.683130    
#> 335: 0.732449    1.074961    3.481535    0.832188    0.001152    0.000023    0.683216    
#> 336: 0.732222    1.074998    3.481531    0.832521    0.001153    0.000023    0.683209    
#> 337: 0.732079    1.075022    3.481525    0.832632    0.001151    0.000023    0.683185    
#> 338: 0.732309    1.075044    3.481533    0.833578    0.001154    0.000023    0.683113    
#> 339: 0.732253    1.075042    3.481537    0.833580    0.001156    0.000023    0.683119    
#> 340: 0.731893    1.074947    3.481543    0.832874    0.001157    0.000023    0.683026    
#> 341: 0.731990    1.074902    3.481547    0.832579    0.001160    0.000023    0.682909    
#> 342: 0.731499    1.074883    3.481550    0.831650    0.001161    0.000023    0.682884    
#> 343: 0.731133    1.074848    3.481555    0.831029    0.001159    0.000023    0.682872    
#> 344: 0.731318    1.074834    3.481563    0.831149    0.001156    0.000023    0.682913    
#> 345: 0.731169    1.074823    3.481565    0.830993    0.001154    0.000023    0.682890    
#> 346: 0.731082    1.074827    3.481563    0.831646    0.001151    0.000023    0.682889    
#> 347: 0.731207    1.074815    3.481558    0.831180    0.001152    0.000023    0.682886    
#> 348: 0.730617    1.074831    3.481550    0.830415    0.001150    0.000023    0.682987    
#> 349: 0.730721    1.074831    3.481545    0.831213    0.001148    0.000023    0.682967    
#> 350: 0.730698    1.074828    3.481544    0.831189    0.001145    0.000023    0.683016    
#> 351: 0.730594    1.074861    3.481537    0.831059    0.001142    0.000023    0.683043    
#> 352: 0.730326    1.074870    3.481536    0.830678    0.001140    0.000023    0.683033    
#> 353: 0.730556    1.074920    3.481534    0.830777    0.001138    0.000023    0.682969    
#> 354: 0.730411    1.074937    3.481524    0.829651    0.001140    0.000023    0.682994    
#> 355: 0.731171    1.074904    3.481512    0.830590    0.001143    0.000023    0.683068    
#> 356: 0.730987    1.074900    3.481508    0.830289    0.001148    0.000023    0.683162    
#> 357: 0.730972    1.074867    3.481499    0.830024    0.001150    0.000023    0.683185    
#> 358: 0.730892    1.074860    3.481499    0.830058    0.001151    0.000023    0.683185    
#> 359: 0.730856    1.074857    3.481496    0.830147    0.001151    0.000023    0.683231    
#> 360: 0.730753    1.074883    3.481485    0.829315    0.001149    0.000023    0.683197    
#> 361: 0.730924    1.074895    3.481482    0.829116    0.001146    0.000023    0.683148    
#> 362: 0.731175    1.074902    3.481482    0.829379    0.001144    0.000023    0.683152    
#> 363: 0.731549    1.074849    3.481487    0.830427    0.001143    0.000023    0.683153    
#> 364: 0.731735    1.074835    3.481489    0.830618    0.001140    0.000023    0.683116    
#> 365: 0.731858    1.074796    3.481498    0.831029    0.001142    0.000023    0.683074    
#> 366: 0.731852    1.074740    3.481493    0.831018    0.001143    0.000023    0.682992    
#> 367: 0.731940    1.074716    3.481492    0.831300    0.001143    0.000023    0.682939    
#> 368: 0.731943    1.074725    3.481485    0.831341    0.001143    0.000023    0.682902    
#> 369: 0.731919    1.074728    3.481481    0.831291    0.001142    0.000023    0.682878    
#> 370: 0.731980    1.074759    3.481479    0.831853    0.001141    0.000023    0.682865    
#> 371: 0.732040    1.074781    3.481470    0.832366    0.001140    0.000023    0.682867    
#> 372: 0.732125    1.074795    3.481460    0.832578    0.001140    0.000023    0.682894    
#> 373: 0.731978    1.074836    3.481451    0.832519    0.001139    0.000023    0.682926    
#> 374: 0.732200    1.074812    3.481441    0.833216    0.001138    0.000023    0.682973    
#> 375: 0.732661    1.074762    3.481430    0.834825    0.001136    0.000023    0.682927    
#> 376: 0.732590    1.074742    3.481420    0.834753    0.001134    0.000023    0.682945    
#> 377: 0.732394    1.074740    3.481415    0.834433    0.001133    0.000023    0.682947    
#> 378: 0.732111    1.074697    3.481409    0.833495    0.001130    0.000023    0.682980    
#> 379: 0.731649    1.074658    3.481415    0.832708    0.001129    0.000023    0.683035    
#> 380: 0.731270    1.074644    3.481413    0.831698    0.001128    0.000023    0.683109    
#> 381: 0.731178    1.074612    3.481411    0.831476    0.001125    0.000023    0.683089    
#> 382: 0.731219    1.074585    3.481412    0.831810    0.001123    0.000023    0.683066    
#> 383: 0.731541    1.074547    3.481416    0.832601    0.001122    0.000023    0.683041    
#> 384: 0.731568    1.074509    3.481421    0.833298    0.001120    0.000023    0.682983    
#> 385: 0.731913    1.074490    3.481427    0.834306    0.001118    0.000023    0.682894    
#> 386: 0.732108    1.074494    3.481432    0.834592    0.001118    0.000023    0.682820    
#> 387: 0.732114    1.074481    3.481441    0.833961    0.001117    0.000023    0.682751    
#> 388: 0.732113    1.074476    3.481445    0.833479    0.001115    0.000023    0.682706    
#> 389: 0.731941    1.074433    3.481449    0.832890    0.001112    0.000022    0.682710    
#> 390: 0.731852    1.074387    3.481446    0.832432    0.001111    0.000022    0.682690    
#> 391: 0.732016    1.074358    3.481448    0.832436    0.001108    0.000022    0.682706    
#> 392: 0.732179    1.074311    3.481452    0.833263    0.001108    0.000022    0.682694    
#> 393: 0.732547    1.074258    3.481456    0.834252    0.001106    0.000022    0.682670    
#> 394: 0.733261    1.074208    3.481459    0.836444    0.001105    0.000022    0.682707    
#> 395: 0.734034    1.074184    3.481461    0.839241    0.001105    0.000022    0.682711    
#> 396: 0.734634    1.074206    3.481465    0.841988    0.001104    0.000022    0.682715    
#> 397: 0.734852    1.074219    3.481470    0.842652    0.001104    0.000022    0.682766    
#> 398: 0.734801    1.074183    3.481468    0.842841    0.001102    0.000022    0.682735    
#> 399: 0.734741    1.074162    3.481472    0.842722    0.001101    0.000022    0.682754    
#> 400: 0.734809    1.074182    3.481479    0.842162    0.001102    0.000022    0.682779    
#> 401: 0.734851    1.074203    3.481482    0.841874    0.001102    0.000022    0.682783    
#> 402: 0.734949    1.074198    3.481485    0.841919    0.001102    0.000022    0.682814    
#> 403: 0.735011    1.074207    3.481489    0.841599    0.001101    0.000022    0.682810    
#> 404: 0.735113    1.074217    3.481489    0.841779    0.001100    0.000022    0.682758    
#> 405: 0.734918    1.074201    3.481491    0.840847    0.001099    0.000022    0.682777    
#> 406: 0.734828    1.074208    3.481491    0.840269    0.001097    0.000022    0.682767    
#> 407: 0.734996    1.074216    3.481496    0.840405    0.001097    0.000022    0.682806    
#> 408: 0.734892    1.074248    3.481500    0.839569    0.001097    0.000022    0.682834    
#> 409: 0.734792    1.074249    3.481496    0.838722    0.001096    0.000022    0.682895    
#> 410: 0.734625    1.074253    3.481491    0.838446    0.001096    0.000022    0.682901    
#> 411: 0.734407    1.074227    3.481493    0.838059    0.001096    0.000022    0.682930    
#> 412: 0.734128    1.074212    3.481491    0.837653    0.001095    0.000022    0.682934    
#> 413: 0.734289    1.074197    3.481487    0.838340    0.001095    0.000022    0.682911    
#> 414: 0.734101    1.074200    3.481489    0.838465    0.001093    0.000022    0.682961    
#> 415: 0.734396    1.074183    3.481489    0.839000    0.001092    0.000022    0.682913    
#> 416: 0.734621    1.074174    3.481489    0.839416    0.001092    0.000022    0.682864    
#> 417: 0.734635    1.074127    3.481483    0.839176    0.001093    0.000022    0.682842    
#> 418: 0.734357    1.074111    3.481480    0.838543    0.001092    0.000022    0.682851    
#> 419: 0.734418    1.074102    3.481474    0.838850    0.001091    0.000022    0.682813    
#> 420: 0.734658    1.074107    3.481472    0.839117    0.001090    0.000022    0.682763    
#> 421: 0.734705    1.074113    3.481473    0.839076    0.001089    0.000022    0.682757    
#> 422: 0.734943    1.074092    3.481473    0.839245    0.001086    0.000022    0.682794    
#> 423: 0.735132    1.074064    3.481472    0.839226    0.001086    0.000022    0.682825    
#> 424: 0.734970    1.074072    3.481469    0.838659    0.001085    0.000022    0.682842    
#> 425: 0.735000    1.074086    3.481465    0.838764    0.001085    0.000022    0.682912    
#> 426: 0.735269    1.074100    3.481466    0.839759    0.001085    0.000022    0.682895    
#> 427: 0.735477    1.074093    3.481468    0.840969    0.001084    0.000022    0.682882    
#> 428: 0.735398    1.074093    3.481467    0.841334    0.001085    0.000022    0.682842    
#> 429: 0.735484    1.074085    3.481467    0.841922    0.001085    0.000022    0.682848    
#> 430: 0.735344    1.074081    3.481464    0.841790    0.001086    0.000022    0.682826    
#> 431: 0.735479    1.074095    3.481462    0.842104    0.001086    0.000022    0.682779    
#> 432: 0.735719    1.074116    3.481462    0.843034    0.001088    0.000022    0.682714    
#> 433: 0.735827    1.074149    3.481460    0.843137    0.001090    0.000022    0.682678    
#> 434: 0.735543    1.074144    3.481463    0.842813    0.001091    0.000022    0.682716    
#> 435: 0.735573    1.074126    3.481466    0.842575    0.001093    0.000022    0.682701    
#> 436: 0.735835    1.074095    3.481470    0.842918    0.001092    0.000022    0.682714    
#> 437: 0.736018    1.074089    3.481469    0.843507    0.001091    0.000022    0.682722    
#> 438: 0.736150    1.074111    3.481467    0.843540    0.001089    0.000022    0.682691    
#> 439: 0.736503    1.074124    3.481462    0.844180    0.001088    0.000022    0.682664    
#> 440: 0.736518    1.074136    3.481461    0.843849    0.001088    0.000022    0.682667    
#> 441: 0.736779    1.074119    3.481462    0.844722    0.001088    0.000022    0.682651    
#> 442: 0.736589    1.074111    3.481464    0.844259    0.001087    0.000022    0.682649    
#> 443: 0.736547    1.074137    3.481465    0.843723    0.001087    0.000022    0.682660    
#> 444: 0.736473    1.074146    3.481465    0.843180    0.001087    0.000022    0.682684    
#> 445: 0.736329    1.074141    3.481462    0.842901    0.001089    0.000022    0.682714    
#> 446: 0.736269    1.074155    3.481460    0.842495    0.001090    0.000022    0.682729    
#> 447: 0.736423    1.074180    3.481458    0.842855    0.001092    0.000022    0.682740    
#> 448: 0.736292    1.074202    3.481460    0.842521    0.001092    0.000022    0.682779    
#> 449: 0.736260    1.074241    3.481466    0.842193    0.001091    0.000022    0.682782    
#> 450: 0.736261    1.074261    3.481467    0.841678    0.001091    0.000022    0.682762    
#> 451: 0.736435    1.074262    3.481466    0.841904    0.001090    0.000022    0.682772    
#> 452: 0.736386    1.074280    3.481464    0.841987    0.001089    0.000022    0.682790    
#> 453: 0.736423    1.074297    3.481460    0.841842    0.001088    0.000022    0.682804    
#> 454: 0.736643    1.074299    3.481454    0.843250    0.001088    0.000022    0.682785    
#> 455: 0.737113    1.074305    3.481445    0.845058    0.001087    0.000022    0.682767    
#> 456: 0.737241    1.074296    3.481442    0.845521    0.001086    0.000022    0.682801    
#> 457: 0.737366    1.074297    3.481442    0.846406    0.001086    0.000022    0.682784    
#> 458: 0.737594    1.074322    3.481446    0.847183    0.001086    0.000022    0.682804    
#> 459: 0.737418    1.074362    3.481450    0.846886    0.001086    0.000022    0.682825    
#> 460: 0.737305    1.074375    3.481455    0.846458    0.001087    0.000022    0.682770    
#> 461: 0.737123    1.074385    3.481460    0.845808    0.001088    0.000022    0.682746    
#> 462: 0.737133    1.074415    3.481465    0.845286    0.001087    0.000022    0.682726    
#> 463: 0.737288    1.074438    3.481465    0.845539    0.001086    0.000022    0.682767    
#> 464: 0.737521    1.074440    3.481468    0.845735    0.001085    0.000022    0.682753    
#> 465: 0.737624    1.074449    3.481469    0.845864    0.001084    0.000022    0.682742    
#> 466: 0.737573    1.074476    3.481468    0.845665    0.001083    0.000022    0.682743    
#> 467: 0.737495    1.074498    3.481466    0.845472    0.001082    0.000022    0.682721    
#> 468: 0.737657    1.074507    3.481466    0.845865    0.001081    0.000022    0.682698    
#> 469: 0.737554    1.074534    3.481467    0.845627    0.001082    0.000022    0.682736    
#> 470: 0.737256    1.074558    3.481466    0.845138    0.001082    0.000022    0.682728    
#> 471: 0.737128    1.074571    3.481464    0.844611    0.001083    0.000022    0.682729    
#> 472: 0.737117    1.074590    3.481463    0.844553    0.001084    0.000022    0.682671    
#> 473: 0.737099    1.074599    3.481466    0.844423    0.001086    0.000022    0.682617    
#> 474: 0.736890    1.074607    3.481468    0.843633    0.001087    0.000022    0.682635    
#> 475: 0.736782    1.074643    3.481469    0.843122    0.001087    0.000022    0.682630    
#> 476: 0.736615    1.074661    3.481466    0.842457    0.001086    0.000022    0.682653    
#> 477: 0.736731    1.074677    3.481466    0.842911    0.001086    0.000022    0.682610    
#> 478: 0.736748    1.074679    3.481465    0.843355    0.001087    0.000022    0.682605    
#> 479: 0.736902    1.074698    3.481465    0.844137    0.001089    0.000022    0.682597    
#> 480: 0.736933    1.074692    3.481466    0.844531    0.001091    0.000022    0.682614    
#> 481: 0.736968    1.074690    3.481466    0.844606    0.001093    0.000022    0.682657    
#> 482: 0.736942    1.074678    3.481466    0.844763    0.001094    0.000022    0.682668    
#> 483: 0.736847    1.074652    3.481463    0.844559    0.001093    0.000022    0.682711    
#> 484: 0.736681    1.074614    3.481463    0.844152    0.001093    0.000022    0.682698    
#> 485: 0.736701    1.074607    3.481462    0.844448    0.001093    0.000022    0.682687    
#> 486: 0.736754    1.074609    3.481459    0.844800    0.001093    0.000022    0.682691    
#> 487: 0.736852    1.074631    3.481458    0.844818    0.001092    0.000022    0.682721    
#> 488: 0.736882    1.074618    3.481460    0.845236    0.001092    0.000022    0.682705    
#> 489: 0.736925    1.074592    3.481461    0.845130    0.001092    0.000022    0.682670    
#> 490: 0.736856    1.074593    3.481464    0.844614    0.001092    0.000022    0.682672    
#> 491: 0.736698    1.074606    3.481468    0.843935    0.001091    0.000022    0.682690    
#> 492: 0.736531    1.074608    3.481471    0.843435    0.001090    0.000022    0.682694    
#> 493: 0.736371    1.074609    3.481471    0.843379    0.001091    0.000022    0.682713    
#> 494: 0.736472    1.074640    3.481470    0.843004    0.001091    0.000022    0.682749    
#> 495: 0.736686    1.074650    3.481472    0.843172    0.001090    0.000022    0.682777    
#> 496: 0.736728    1.074687    3.481473    0.842988    0.001089    0.000022    0.682778    
#> 497: 0.736648    1.074703    3.481472    0.842835    0.001088    0.000022    0.682767    
#> 498: 0.736554    1.074699    3.481470    0.842566    0.001088    0.000022    0.682777    
#> 499: 0.736551    1.074696    3.481468    0.842560    0.001087    0.000022    0.682767    
#> 500: 0.736555    1.074700    3.481464    0.842519    0.001087    0.000022    0.682762    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.301947    0.988444    3.447918    0.392401    0.091977    0.016800    1.708035    
#> 002: 0.219731    1.043232    3.480346    0.372781    0.087379    0.016742    1.127668    
#> 003: 0.324278    1.030973    3.498668    0.354142    0.083010    0.015905    0.946322    
#> 004: 0.249858    1.084734    3.470763    0.336435    0.078859    0.015110    0.858253    
#> 005: 0.291419    1.099028    3.477414    0.319613    0.074916    0.014355    0.834668    
#> 006: 0.297234    1.084367    3.483736    0.303633    0.071170    0.013865    0.820747    
#> 007: 0.257271    1.092696    3.482107    0.288451    0.067612    0.013441    0.835861    
#> 008: 0.269218    1.091798    3.471416    0.274029    0.064231    0.013783    0.841782    
#> 009: 0.269325    1.096159    3.472384    0.260327    0.061020    0.013115    0.839481    
#> 010: 0.239522    1.086541    3.461882    0.247311    0.057969    0.013659    0.855135    
#> 011: 0.289878    1.099362    3.465479    0.234945    0.055070    0.013431    0.857874    
#> 012: 0.270804    1.104339    3.453862    0.223198    0.052317    0.012760    0.830302    
#> 013: 0.185927    1.119890    3.433210    0.212038    0.049701    0.012122    0.858636    
#> 014: 0.240898    1.127104    3.445570    0.201436    0.050653    0.011516    0.855754    
#> 015: 0.241526    1.128842    3.460011    0.191364    0.048120    0.010940    0.821027    
#> 016: 0.236071    1.131569    3.467341    0.181796    0.045714    0.011032    0.828328    
#> 017: 0.283974    1.128236    3.474892    0.172706    0.043929    0.010480    0.816930    
#> 018: 0.280148    1.116568    3.460812    0.164071    0.041732    0.009956    0.835229    
#> 019: 0.228776    1.122131    3.460038    0.155867    0.039646    0.009458    0.819309    
#> 020: 0.201443    1.116407    3.455331    0.148074    0.037664    0.011019    0.844825    
#> 021: 0.252926    1.094352    3.470748    0.140670    0.035780    0.011420    0.821067    
#> 022: 0.291429    1.096977    3.484413    0.133637    0.033991    0.010928    0.818204    
#> 023: 0.346780    1.101025    3.496156    0.126955    0.032292    0.012070    0.825321    
#> 024: 0.349815    1.100840    3.500956    0.120607    0.030677    0.013837    0.818650    
#> 025: 0.347079    1.108384    3.496902    0.114577    0.029143    0.015293    0.829314    
#> 026: 0.303131    1.097483    3.481978    0.108848    0.027686    0.019244    0.837390    
#> 027: 0.298255    1.109554    3.484452    0.103406    0.026302    0.018398    0.841505    
#> 028: 0.294060    1.102776    3.486086    0.098235    0.026827    0.020328    0.815697    
#> 029: 0.300832    1.081824    3.474150    0.093324    0.025486    0.019311    0.845192    
#> 030: 0.279771    1.107490    3.465780    0.088657    0.024212    0.018346    0.828890    
#> 031: 0.272807    1.085746    3.482415    0.101382    0.023001    0.017529    0.834187    
#> 032: 0.273915    1.073118    3.496354    0.096313    0.021851    0.019371    0.844212    
#> 033: 0.291808    1.098194    3.486299    0.091497    0.020759    0.019449    0.851988    
#> 034: 0.324686    1.105174    3.491615    0.086922    0.019780    0.019561    0.846327    
#> 035: 0.291693    1.092716    3.486424    0.082576    0.019434    0.024938    0.824564    
#> 036: 0.287627    1.102124    3.473226    0.078447    0.019914    0.025368    0.832501    
#> 037: 0.285780    1.104383    3.477304    0.074525    0.021451    0.024099    0.834277    
#> 038: 0.323200    1.109033    3.474665    0.080363    0.020379    0.022894    0.863885    
#> 039: 0.319424    1.098704    3.492982    0.076345    0.022131    0.021750    0.828788    
#> 040: 0.309832    1.104523    3.488798    0.072527    0.022148    0.020662    0.850228    
#> 041: 0.292093    1.081584    3.487442    0.068901    0.022648    0.022808    0.840652    
#> 042: 0.325861    1.078291    3.496471    0.067456    0.021516    0.021667    0.841255    
#> 043: 0.295349    1.083035    3.480689    0.064083    0.020440    0.021500    0.840117    
#> 044: 0.289131    1.104568    3.472725    0.060879    0.019418    0.020425    0.839563    
#> 045: 0.291625    1.106166    3.477542    0.057835    0.018447    0.020094    0.851580    
#> 046: 0.281782    1.113459    3.481517    0.066029    0.017525    0.019089    0.853619    
#> 047: 0.311902    1.108206    3.476518    0.062728    0.016648    0.020170    0.840245    
#> 048: 0.315899    1.086352    3.482766    0.059591    0.025189    0.019162    0.825009    
#> 049: 0.304506    1.080683    3.487603    0.056612    0.028328    0.018203    0.848163    
#> 050: 0.342804    1.060411    3.495783    0.053781    0.027198    0.017293    0.861430    
#> 051: 0.322027    1.080982    3.497010    0.051092    0.031296    0.016429    0.852158    
#> 052: 0.346153    1.096845    3.499054    0.052081    0.029731    0.018669    0.837563    
#> 053: 0.360228    1.073277    3.504997    0.059938    0.032522    0.017736    0.836001    
#> 054: 0.290323    1.082654    3.493734    0.059331    0.030896    0.018497    0.829461    
#> 055: 0.298515    1.071600    3.507279    0.056364    0.029351    0.024549    0.838519    
#> 056: 0.320400    1.070161    3.507289    0.053546    0.027883    0.023322    0.841286    
#> 057: 0.341210    1.060898    3.517158    0.050869    0.029744    0.022156    0.853450    
#> 058: 0.330698    1.075378    3.492512    0.053786    0.028257    0.021048    0.856710    
#> 059: 0.316693    1.054156    3.496810    0.051097    0.026844    0.028556    0.856465    
#> 060: 0.353119    1.056963    3.511927    0.048542    0.025502    0.027128    0.848756    
#> 061: 0.362278    1.059134    3.512584    0.047182    0.024227    0.025772    0.864271    
#> 062: 0.352354    1.087676    3.520879    0.044822    0.025175    0.024483    0.874148    
#> 063: 0.388354    1.050483    3.526522    0.052191    0.023916    0.023259    0.864063    
#> 064: 0.380813    1.061501    3.520731    0.054174    0.022720    0.022096    0.865654    
#> 065: 0.395790    1.042239    3.513268    0.061690    0.021913    0.020991    0.850944    
#> 066: 0.367373    1.056733    3.520685    0.061278    0.020817    0.019942    0.853579    
#> 067: 0.346131    1.063618    3.506910    0.058214    0.019776    0.022648    0.844215    
#> 068: 0.289049    1.090911    3.508039    0.055303    0.023659    0.022512    0.869570    
#> 069: 0.297796    1.105407    3.488096    0.052538    0.022476    0.021387    0.878769    
#> 070: 0.281798    1.085585    3.496537    0.052755    0.021352    0.026634    0.878874    
#> 071: 0.293066    1.117064    3.469535    0.050117    0.020285    0.025303    0.879253    
#> 072: 0.272148    1.081245    3.496592    0.053118    0.021897    0.024037    0.858391    
#> 073: 0.323149    1.090950    3.514614    0.057908    0.021979    0.024290    0.840313    
#> 074: 0.292246    1.089342    3.497351    0.056539    0.025510    0.023075    0.838122    
#> 075: 0.318437    1.089595    3.507326    0.063540    0.024234    0.021921    0.863861    
#> 076: 0.301362    1.097919    3.510832    0.063710    0.023023    0.020825    0.842033    
#> 077: 0.314530    1.085194    3.490756    0.060524    0.021871    0.019784    0.830548    
#> 078: 0.338031    1.070328    3.503318    0.057498    0.020778    0.019859    0.852774    
#> 079: 0.348011    1.085729    3.501841    0.054623    0.019739    0.019273    0.835152    
#> 080: 0.344447    1.079264    3.504261    0.051892    0.018752    0.023181    0.849030    
#> 081: 0.349304    1.076037    3.505363    0.049297    0.017814    0.022907    0.838183    
#> 082: 0.333991    1.061124    3.503018    0.046832    0.016924    0.021761    0.832835    
#> 083: 0.351250    1.051390    3.505416    0.047818    0.016240    0.020673    0.862395    
#> 084: 0.328420    1.089326    3.488775    0.045427    0.015428    0.021778    0.841207    
#> 085: 0.306024    1.093527    3.498767    0.043156    0.018759    0.027478    0.854360    
#> 086: 0.339654    1.075351    3.503088    0.043758    0.017821    0.026104    0.859357    
#> 087: 0.324342    1.071355    3.494542    0.050062    0.016930    0.024799    0.854629    
#> 088: 0.318562    1.065105    3.505459    0.047559    0.016083    0.023559    0.868971    
#> 089: 0.324532    1.076894    3.497439    0.045181    0.017628    0.022381    0.849980    
#> 090: 0.308993    1.084099    3.494962    0.042922    0.017266    0.024499    0.841087    
#> 091: 0.306191    1.069860    3.480983    0.040776    0.016403    0.030613    0.845994    
#> 092: 0.268025    1.104030    3.474665    0.038737    0.015583    0.030453    0.852858    
#> 093: 0.244338    1.111562    3.467721    0.036800    0.017263    0.028931    0.862397    
#> 094: 0.267680    1.113762    3.480910    0.047891    0.016400    0.027484    0.832418    
#> 095: 0.284462    1.097451    3.490710    0.049309    0.015580    0.030662    0.844028    
#> 096: 0.265626    1.111395    3.474732    0.047279    0.019047    0.029129    0.848735    
#> 097: 0.281548    1.114814    3.475642    0.049123    0.018095    0.027673    0.832044    
#> 098: 0.251849    1.108553    3.477488    0.058970    0.017193    0.026289    0.838379    
#> 099: 0.248468    1.099169    3.446650    0.056021    0.018386    0.024975    0.844024    
#> 100: 0.267346    1.101453    3.471489    0.053220    0.021603    0.023726    0.841313    
#> 101: 0.248917    1.089684    3.462258    0.050559    0.020523    0.022540    0.840019    
#> 102: 0.253223    1.082256    3.458512    0.055148    0.019497    0.021413    0.868954    
#> 103: 0.282336    1.086324    3.496491    0.052390    0.018873    0.020342    0.828128    
#> 104: 0.301540    1.076971    3.514840    0.054246    0.017929    0.024011    0.841291    
#> 105: 0.311259    1.065403    3.502059    0.051534    0.019201    0.022810    0.825907    
#> 106: 0.337691    1.065865    3.502648    0.056154    0.018400    0.021670    0.840395    
#> 107: 0.385639    1.074798    3.504258    0.058008    0.021456    0.024600    0.852725    
#> 108: 0.338999    1.079861    3.498785    0.056103    0.022691    0.027909    0.867513    
#> 109: 0.308073    1.085014    3.519007    0.053298    0.021636    0.027388    0.858859    
#> 110: 0.305444    1.068177    3.501247    0.050633    0.021134    0.026019    0.849267    
#> 111: 0.317734    1.080264    3.510062    0.048101    0.020565    0.024718    0.838123    
#> 112: 0.306820    1.069176    3.478995    0.049215    0.019537    0.023482    0.833395    
#> 113: 0.309428    1.089531    3.484236    0.046754    0.018560    0.022308    0.829065    
#> 114: 0.309617    1.090286    3.503442    0.044417    0.017632    0.022137    0.852145    
#> 115: 0.329401    1.058581    3.490780    0.053164    0.016751    0.027097    0.871534    
#> 116: 0.302167    1.066279    3.491376    0.051114    0.015913    0.029422    0.870208    
#> 117: 0.273111    1.099276    3.479412    0.055734    0.015118    0.030562    0.879535    
#> 118: 0.280469    1.113317    3.472920    0.052948    0.014560    0.029034    0.860692    
#> 119: 0.274602    1.096082    3.476278    0.050300    0.015001    0.027582    0.853802    
#> 120: 0.280907    1.094093    3.481467    0.047785    0.018068    0.026203    0.840738    
#> 121: 0.279510    1.125646    3.469591    0.045396    0.027113    0.024893    0.845633    
#> 122: 0.293312    1.104116    3.491030    0.046831    0.028139    0.023648    0.863831    
#> 123: 0.348973    1.114313    3.490045    0.046120    0.026732    0.022466    0.860009    
#> 124: 0.373976    1.102002    3.498285    0.043814    0.025395    0.021342    0.871736    
#> 125: 0.389093    1.094480    3.486873    0.041623    0.024125    0.020275    0.879492    
#> 126: 0.353037    1.098550    3.483439    0.049061    0.022919    0.019719    0.865289    
#> 127: 0.356115    1.082695    3.485753    0.046608    0.021773    0.019238    0.861792    
#> 128: 0.318031    1.074407    3.514559    0.044278    0.020685    0.022664    0.867658    
#> 129: 0.326568    1.073713    3.512396    0.045952    0.024744    0.021531    0.844919    
#> 130: 0.331373    1.100973    3.497096    0.043655    0.023506    0.020454    0.842855    
#> 131: 0.304998    1.089642    3.489814    0.043581    0.023993    0.023256    0.828282    
#> 132: 0.298200    1.087628    3.481221    0.047301    0.022793    0.027044    0.823628    
#> 133: 0.301347    1.083889    3.492122    0.050842    0.022778    0.026904    0.852128    
#> 134: 0.334502    1.048885    3.515339    0.048326    0.021639    0.025559    0.853676    
#> 135: 0.326391    1.041136    3.518518    0.050809    0.020557    0.024281    0.851548    
#> 136: 0.332186    1.056756    3.515840    0.048269    0.019529    0.023067    0.821526    
#> 137: 0.370921    1.046312    3.508638    0.047331    0.018553    0.024008    0.825253    
#> 138: 0.367293    1.032895    3.523738    0.044965    0.017625    0.022807    0.830289    
#> 139: 0.378771    1.067179    3.530546    0.042716    0.020522    0.021667    0.846003    
#> 140: 0.373988    1.065592    3.527563    0.040581    0.019496    0.027889    0.873686    
#> 141: 0.361700    1.059033    3.525789    0.038552    0.018521    0.028301    0.859902    
#> 142: 0.361475    1.032496    3.538619    0.036624    0.017595    0.030710    0.866413    
#> 143: 0.347878    1.042625    3.531333    0.034793    0.016715    0.030710    0.858173    
#> 144: 0.408389    1.039298    3.549610    0.033053    0.015879    0.029174    0.846557    
#> 145: 0.382006    1.065050    3.514796    0.031400    0.015310    0.027715    0.857092    
#> 146: 0.365199    1.081742    3.533720    0.038102    0.015441    0.026330    0.861889    
#> 147: 0.349889    1.067863    3.525481    0.046507    0.015294    0.027452    0.853690    
#> 148: 0.361448    1.066528    3.528075    0.044181    0.017467    0.026079    0.864719    
#> 149: 0.373587    1.060585    3.528515    0.042505    0.016593    0.028722    0.849820    
#> 150: 0.393705    1.074329    3.511110    0.052035    0.019159    0.027285    0.845056    
#> 151: 0.334791    1.097875    3.503306    0.070515    0.018201    0.025921    0.855546    
#> 152: 0.321247    1.097888    3.507050    0.048796    0.016098    0.019745    0.858918    
#> 153: 0.294122    1.127779    3.494134    0.048578    0.024118    0.016370    0.876368    
#> 154: 0.308074    1.122654    3.492519    0.049178    0.026849    0.015617    0.874447    
#> 155: 0.282129    1.092091    3.481939    0.046292    0.022672    0.012486    0.857599    
#> 156: 0.290635    1.110033    3.491050    0.045947    0.026195    0.013215    0.853285    
#> 157: 0.308388    1.094423    3.509978    0.054154    0.038016    0.016498    0.839461    
#> 158: 0.332938    1.109786    3.486351    0.058744    0.027918    0.012624    0.832308    
#> 159: 0.296197    1.098131    3.493595    0.055628    0.024457    0.015010    0.836879    
#> 160: 0.329603    1.064587    3.515010    0.054136    0.024490    0.021242    0.854174    
#> 161: 0.307023    1.058385    3.502248    0.065483    0.023349    0.024809    0.849441    
#> 162: 0.273255    1.101084    3.468553    0.058299    0.013168    0.024140    0.848711    
#> 163: 0.294219    1.083129    3.473765    0.049165    0.014012    0.025771    0.837330    
#> 164: 0.316246    1.089920    3.493580    0.052940    0.013796    0.025481    0.831853    
#> 165: 0.360474    1.080353    3.505425    0.039907    0.013899    0.025908    0.825431    
#> 166: 0.398622    1.092401    3.514203    0.045723    0.015158    0.029639    0.841081    
#> 167: 0.387904    1.083583    3.532274    0.051368    0.013977    0.026971    0.869467    
#> 168: 0.381453    1.105295    3.521828    0.049427    0.015538    0.026800    0.843005    
#> 169: 0.344805    1.093405    3.509875    0.054262    0.013429    0.027089    0.849490    
#> 170: 0.342342    1.100888    3.498571    0.047583    0.011059    0.028676    0.842846    
#> 171: 0.322635    1.099364    3.489939    0.051675    0.011527    0.023072    0.825563    
#> 172: 0.319206    1.102811    3.496975    0.058577    0.017649    0.020156    0.817481    
#> 173: 0.314706    1.108559    3.483339    0.047165    0.015703    0.015966    0.843611    
#> 174: 0.315201    1.114774    3.485630    0.081627    0.015281    0.015293    0.856008    
#> 175: 0.314352    1.098681    3.477131    0.081459    0.017021    0.014100    0.876786    
#> 176: 0.295951    1.118253    3.477642    0.086020    0.019073    0.013234    0.837353    
#> 177: 0.321738    1.103013    3.490894    0.090254    0.016928    0.009509    0.845811    
#> 178: 0.316516    1.104258    3.484788    0.073175    0.021931    0.012833    0.835966    
#> 179: 0.343522    1.098085    3.500291    0.089583    0.025320    0.016832    0.833121    
#> 180: 0.333592    1.082434    3.502517    0.091110    0.023838    0.020307    0.819731    
#> 181: 0.344533    1.061148    3.499109    0.068124    0.020180    0.017217    0.829478    
#> 182: 0.303723    1.078197    3.485002    0.080548    0.024330    0.019191    0.834483    
#> 183: 0.297390    1.090030    3.485349    0.061711    0.020187    0.018154    0.820744    
#> 184: 0.327572    1.073150    3.499455    0.067389    0.026438    0.016632    0.839652    
#> 185: 0.311351    1.075094    3.501090    0.056496    0.027626    0.014142    0.830573    
#> 186: 0.347770    1.087827    3.513368    0.059435    0.032386    0.015918    0.844827    
#> 187: 0.333369    1.067707    3.509395    0.067534    0.025967    0.017824    0.866524    
#> 188: 0.296857    1.095950    3.494498    0.059367    0.029530    0.020946    0.851525    
#> 189: 0.311787    1.121350    3.506239    0.060416    0.031238    0.023014    0.864865    
#> 190: 0.308985    1.096327    3.497514    0.073951    0.020246    0.018204    0.863789    
#> 191: 0.297634    1.101303    3.475713    0.072461    0.014735    0.017137    0.862629    
#> 192: 0.268666    1.104116    3.472477    0.045649    0.015508    0.022274    0.843287    
#> 193: 0.270566    1.122135    3.471124    0.046891    0.009495    0.022818    0.854727    
#> 194: 0.252003    1.111295    3.455402    0.051343    0.014397    0.026199    0.857248    
#> 195: 0.233205    1.109838    3.460231    0.035826    0.012954    0.021863    0.858118    
#> 196: 0.252607    1.101730    3.480407    0.032700    0.014037    0.019966    0.867015    
#> 197: 0.256190    1.102178    3.499295    0.034339    0.015038    0.015656    0.874919    
#> 198: 0.290497    1.090292    3.487360    0.030888    0.011597    0.018981    0.867082    
#> 199: 0.258531    1.100295    3.472090    0.032233    0.014285    0.017169    0.870259    
#> 200: 0.248012    1.104072    3.471854    0.036837    0.012567    0.017326    0.878483    
#> 201: 0.265121    1.099592    3.481924    0.034856    0.012246    0.017926    0.876416    
#> 202: 0.276336    1.097347    3.484894    0.036936    0.012345    0.017705    0.871734    
#> 203: 0.286230    1.097521    3.484114    0.040442    0.012176    0.016810    0.869250    
#> 204: 0.292405    1.091089    3.487457    0.038840    0.013689    0.017478    0.865774    
#> 205: 0.296513    1.090560    3.488671    0.038871    0.013862    0.018375    0.865208    
#> 206: 0.300477    1.092160    3.490527    0.039316    0.013974    0.019486    0.861953    
#> 207: 0.295927    1.090724    3.489355    0.038794    0.014444    0.019570    0.863396    
#> 208: 0.296382    1.089349    3.489622    0.037775    0.014043    0.019932    0.865118    
#> 209: 0.298718    1.087921    3.488194    0.037149    0.013481    0.020192    0.866976    
#> 210: 0.300571    1.087121    3.488698    0.037118    0.013124    0.020745    0.865964    
#> 211: 0.300086    1.087075    3.489271    0.036824    0.013255    0.020927    0.864606    
#> 212: 0.299076    1.086458    3.489713    0.036500    0.013230    0.020990    0.864180    
#> 213: 0.299108    1.084371    3.489507    0.036391    0.013584    0.021712    0.863220    
#> 214: 0.301893    1.083081    3.490364    0.036041    0.013918    0.022123    0.861936    
#> 215: 0.302759    1.082430    3.491707    0.036064    0.014063    0.022415    0.862849    
#> 216: 0.304508    1.080726    3.492282    0.036599    0.014100    0.022282    0.863711    
#> 217: 0.306088    1.081007    3.492287    0.036758    0.013920    0.022130    0.862247    
#> 218: 0.307392    1.081884    3.491581    0.036935    0.014049    0.022003    0.862351    
#> 219: 0.306557    1.082031    3.489960    0.037643    0.013971    0.022235    0.862223    
#> 220: 0.305975    1.082225    3.490322    0.037460    0.013844    0.022380    0.861707    
#> 221: 0.306649    1.081554    3.490893    0.037842    0.013976    0.022384    0.860147    
#> 222: 0.307065    1.080736    3.491489    0.037821    0.013768    0.022466    0.859423    
#> 223: 0.309563    1.080632    3.491838    0.038257    0.013701    0.022470    0.858558    
#> 224: 0.311606    1.080560    3.492813    0.038560    0.013660    0.022300    0.857755    
#> 225: 0.312586    1.079594    3.493300    0.039164    0.013681    0.022261    0.857398    
#> 226: 0.312663    1.077999    3.493109    0.039823    0.013689    0.022159    0.857260    
#> 227: 0.310974    1.077811    3.493106    0.040513    0.013675    0.022237    0.856754    
#> 228: 0.309688    1.078555    3.492281    0.041220    0.013682    0.022271    0.856630    
#> 229: 0.309768    1.078304    3.492242    0.041414    0.013746    0.022200    0.856393    
#> 230: 0.309867    1.078512    3.491940    0.041467    0.013737    0.022060    0.856268    
#> 231: 0.311089    1.078809    3.492292    0.041424    0.013789    0.022016    0.856457    
#> 232: 0.310214    1.078786    3.492379    0.041534    0.013855    0.022024    0.856700    
#> 233: 0.310265    1.078591    3.492580    0.041602    0.013862    0.021951    0.856070    
#> 234: 0.310091    1.078920    3.492787    0.041569    0.013985    0.021872    0.855627    
#> 235: 0.310728    1.078634    3.493209    0.041892    0.014003    0.021835    0.855617    
#> 236: 0.310913    1.078945    3.492975    0.041931    0.014020    0.021737    0.855595    
#> 237: 0.311180    1.079013    3.492822    0.042203    0.013981    0.021689    0.855942    
#> 238: 0.311610    1.078971    3.492962    0.042522    0.013930    0.021725    0.855628    
#> 239: 0.311718    1.079387    3.492594    0.042783    0.013942    0.021623    0.855245    
#> 240: 0.312069    1.079627    3.492703    0.042676    0.013987    0.021577    0.855093    
#> 241: 0.312515    1.080029    3.492938    0.042866    0.014017    0.021600    0.854828    
#> 242: 0.312099    1.080184    3.492546    0.042858    0.014126    0.021697    0.854885    
#> 243: 0.310916    1.080960    3.492399    0.043034    0.014239    0.021803    0.855099    
#> 244: 0.310376    1.080845    3.492450    0.043203    0.014243    0.021958    0.854997    
#> 245: 0.310512    1.081126    3.492263    0.043119    0.014204    0.021977    0.855055    
#> 246: 0.311073    1.081114    3.492578    0.042897    0.014134    0.022062    0.855532    
#> 247: 0.311171    1.081101    3.492983    0.042733    0.014071    0.022051    0.855465    
#> 248: 0.311685    1.081545    3.493141    0.042501    0.014021    0.022042    0.855221    
#> 249: 0.312361    1.081378    3.493491    0.042344    0.013940    0.022032    0.855535    
#> 250: 0.312967    1.081322    3.493693    0.042361    0.013951    0.022063    0.855613    
#> 251: 0.313080    1.081428    3.493978    0.042474    0.013926    0.022050    0.855485    
#> 252: 0.313794    1.081574    3.494492    0.042563    0.013993    0.022057    0.855358    
#> 253: 0.314277    1.081590    3.494944    0.042593    0.014018    0.022174    0.855356    
#> 254: 0.314210    1.082134    3.495230    0.042556    0.014012    0.022248    0.855576    
#> 255: 0.314682    1.082292    3.495684    0.042416    0.013962    0.022331    0.855704    
#> 256: 0.315203    1.082049    3.495992    0.042363    0.013905    0.022312    0.855894    
#> 257: 0.315257    1.081624    3.496214    0.042271    0.013920    0.022374    0.855605    
#> 258: 0.315921    1.081205    3.496420    0.042143    0.013903    0.022356    0.855400    
#> 259: 0.315966    1.081155    3.496420    0.042036    0.013921    0.022333    0.855337    
#> 260: 0.315949    1.081412    3.496606    0.042117    0.013944    0.022247    0.855164    
#> 261: 0.316074    1.081398    3.496866    0.042270    0.013954    0.022208    0.855117    
#> 262: 0.315781    1.081437    3.496720    0.042259    0.013956    0.022229    0.855005    
#> 263: 0.315428    1.081467    3.496598    0.042109    0.013950    0.022239    0.854812    
#> 264: 0.315240    1.081430    3.496598    0.042065    0.013940    0.022316    0.854899    
#> 265: 0.315814    1.081192    3.496878    0.042054    0.014015    0.022304    0.855193    
#> 266: 0.316390    1.081409    3.496991    0.042078    0.014074    0.022248    0.855547    
#> 267: 0.316654    1.081527    3.497245    0.042057    0.014118    0.022315    0.855545    
#> 268: 0.316454    1.081470    3.497131    0.042046    0.014190    0.022273    0.855382    
#> 269: 0.316722    1.081221    3.497069    0.042194    0.014266    0.022287    0.855397    
#> 270: 0.317221    1.081148    3.496882    0.042532    0.014205    0.022211    0.855493    
#> 271: 0.317465    1.081241    3.496644    0.042653    0.014171    0.022144    0.855436    
#> 272: 0.317642    1.081276    3.496452    0.042584    0.014176    0.022063    0.855653    
#> 273: 0.317397    1.081448    3.496446    0.042604    0.014174    0.022041    0.855607    
#> 274: 0.317059    1.081437    3.496419    0.042731    0.014156    0.022011    0.855414    
#> 275: 0.317260    1.081478    3.496381    0.042929    0.014160    0.021964    0.855088    
#> 276: 0.317104    1.081495    3.496571    0.043083    0.014124    0.022034    0.854941    
#> 277: 0.316863    1.081677    3.496683    0.043249    0.014087    0.022124    0.854887    
#> 278: 0.316769    1.082046    3.496634    0.043235    0.014107    0.022123    0.854700    
#> 279: 0.316450    1.081959    3.496506    0.043181    0.014131    0.022142    0.854866    
#> 280: 0.316728    1.081902    3.496743    0.043151    0.014115    0.022139    0.854701    
#> 281: 0.316615    1.081866    3.496891    0.043241    0.014104    0.022079    0.854684    
#> 282: 0.316548    1.081970    3.497005    0.043445    0.014127    0.022115    0.855001    
#> 283: 0.316924    1.082074    3.497183    0.043598    0.014192    0.022170    0.855047    
#> 284: 0.316891    1.082015    3.497146    0.043556    0.014201    0.022194    0.854897    
#> 285: 0.317209    1.081869    3.496983    0.043670    0.014179    0.022224    0.855003    
#> 286: 0.317437    1.081944    3.497004    0.043646    0.014168    0.022284    0.855037    
#> 287: 0.317494    1.081962    3.496912    0.043660    0.014130    0.022372    0.855068    
#> 288: 0.317680    1.081809    3.496997    0.043855    0.014103    0.022435    0.855079    
#> 289: 0.317788    1.081724    3.496973    0.044029    0.014086    0.022472    0.854735    
#> 290: 0.317892    1.081739    3.497027    0.044081    0.014099    0.022467    0.854563    
#> 291: 0.318151    1.081872    3.497259    0.044173    0.014041    0.022435    0.854495    
#> 292: 0.318259    1.082035    3.497253    0.044099    0.013972    0.022447    0.854608    
#> 293: 0.318210    1.082216    3.497105    0.043944    0.013949    0.022473    0.854669    
#> 294: 0.318211    1.082439    3.496884    0.043898    0.013909    0.022435    0.854685    
#> 295: 0.318336    1.082408    3.496865    0.043873    0.013855    0.022452    0.854402    
#> 296: 0.318649    1.082354    3.497071    0.043978    0.013808    0.022503    0.854411    
#> 297: 0.318568    1.082348    3.497071    0.043988    0.013798    0.022469    0.854457    
#> 298: 0.318634    1.082425    3.496997    0.044118    0.013784    0.022468    0.854307    
#> 299: 0.318620    1.082403    3.496939    0.044140    0.013734    0.022497    0.854096    
#> 300: 0.318821    1.082419    3.497077    0.044065    0.013717    0.022494    0.854025    
#> 301: 0.318627    1.082469    3.496880    0.044003    0.013710    0.022502    0.853936    
#> 302: 0.318632    1.082608    3.496693    0.044046    0.013708    0.022502    0.853887    
#> 303: 0.318426    1.082658    3.496551    0.044067    0.013681    0.022487    0.853627    
#> 304: 0.318487    1.082669    3.496436    0.044015    0.013683    0.022491    0.853459    
#> 305: 0.318423    1.082646    3.496423    0.043935    0.013706    0.022506    0.853381    
#> 306: 0.318287    1.082586    3.496474    0.043871    0.013715    0.022521    0.853391    
#> 307: 0.318301    1.082445    3.496398    0.043908    0.013714    0.022540    0.853380    
#> 308: 0.318262    1.082286    3.496366    0.043944    0.013739    0.022542    0.853384    
#> 309: 0.318202    1.082203    3.496269    0.043976    0.013768    0.022545    0.853237    
#> 310: 0.318214    1.082077    3.496085    0.044022    0.013797    0.022534    0.853081    
#> 311: 0.318622    1.082143    3.496134    0.044104    0.013771    0.022591    0.852912    
#> 312: 0.318694    1.082107    3.496127    0.044279    0.013749    0.022586    0.852745    
#> 313: 0.318478    1.081897    3.496112    0.044460    0.013751    0.022576    0.852635    
#> 314: 0.318192    1.081954    3.496060    0.044510    0.013752    0.022589    0.852570    
#> 315: 0.317996    1.081934    3.496092    0.044535    0.013741    0.022619    0.852485    
#> 316: 0.317794    1.081837    3.496125    0.044500    0.013763    0.022634    0.852597    
#> 317: 0.317558    1.081844    3.496178    0.044417    0.013773    0.022666    0.852788    
#> 318: 0.317401    1.081866    3.496033    0.044459    0.013794    0.022709    0.852602    
#> 319: 0.317286    1.081801    3.495927    0.044516    0.013797    0.022706    0.852553    
#> 320: 0.316985    1.081648    3.495812    0.044599    0.013786    0.022747    0.852588    
#> 321: 0.316713    1.081681    3.495723    0.044681    0.013761    0.022778    0.852614    
#> 322: 0.316688    1.081643    3.495601    0.044740    0.013736    0.022797    0.852762    
#> 323: 0.316369    1.081690    3.495564    0.044766    0.013745    0.022763    0.852874    
#> 324: 0.316350    1.081772    3.495648    0.044721    0.013749    0.022746    0.852986    
#> 325: 0.316115    1.081915    3.495511    0.044677    0.013747    0.022757    0.853197    
#> 326: 0.316153    1.081817    3.495466    0.044740    0.013792    0.022771    0.853099    
#> 327: 0.316132    1.081895    3.495493    0.044759    0.013790    0.022795    0.853126    
#> 328: 0.315956    1.081969    3.495410    0.044638    0.013804    0.022840    0.853113    
#> 329: 0.315829    1.081986    3.495335    0.044571    0.013813    0.022856    0.853162    
#> 330: 0.315701    1.081898    3.495294    0.044531    0.013822    0.022915    0.853251    
#> 331: 0.315863    1.082002    3.495418    0.044538    0.013843    0.022957    0.853255    
#> 332: 0.315875    1.082041    3.495599    0.044468    0.013833    0.023017    0.853448    
#> 333: 0.315968    1.082099    3.495642    0.044464    0.013843    0.023046    0.853266    
#> 334: 0.315978    1.082154    3.495595    0.044493    0.013854    0.023006    0.853226    
#> 335: 0.315866    1.082254    3.495473    0.044438    0.013828    0.022977    0.853173    
#> 336: 0.315935    1.082369    3.495424    0.044424    0.013821    0.022970    0.853261    
#> 337: 0.316049    1.082554    3.495407    0.044349    0.013816    0.022941    0.853348    
#> 338: 0.316279    1.082564    3.495596    0.044241    0.013814    0.022916    0.853534    
#> 339: 0.316231    1.082755    3.495576    0.044228    0.013836    0.022872    0.853448    
#> 340: 0.316087    1.082752    3.495574    0.044179    0.013838    0.022864    0.853292    
#> 341: 0.316005    1.082742    3.495579    0.044209    0.013826    0.022823    0.853193    
#> 342: 0.315993    1.082625    3.495570    0.044186    0.013820    0.022816    0.853020    
#> 343: 0.315682    1.082638    3.495554    0.044155    0.013790    0.022865    0.852849    
#> 344: 0.315898    1.082679    3.495634    0.044121    0.013781    0.022872    0.852964    
#> 345: 0.315994    1.082690    3.495651    0.044068    0.013791    0.022862    0.852870    
#> 346: 0.316013    1.082811    3.495542    0.044067    0.013778    0.022845    0.852805    
#> 347: 0.316079    1.082685    3.495525    0.044173    0.013794    0.022826    0.852854    
#> 348: 0.315917    1.082664    3.495455    0.044285    0.013784    0.022828    0.852924    
#> 349: 0.315909    1.082581    3.495444    0.044403    0.013788    0.022820    0.852775    
#> 350: 0.315796    1.082548    3.495398    0.044597    0.013792    0.022809    0.852689    
#> 351: 0.315708    1.082776    3.495359    0.044648    0.013816    0.022794    0.852572    
#> 352: 0.315527    1.082946    3.495315    0.044693    0.013849    0.022811    0.852644    
#> 353: 0.315369    1.083198    3.495144    0.044689    0.013875    0.022814    0.852693    
#> 354: 0.315208    1.083348    3.494964    0.044730    0.013881    0.022789    0.852669    
#> 355: 0.315432    1.083183    3.495019    0.044658    0.013872    0.022812    0.852655    
#> 356: 0.315481    1.083012    3.495081    0.044626    0.013909    0.022835    0.852826    
#> 357: 0.315689    1.082939    3.495071    0.044554    0.013907    0.022858    0.852839    
#> 358: 0.315798    1.082967    3.495117    0.044608    0.013907    0.022855    0.852953    
#> 359: 0.315742    1.083049    3.495078    0.044671    0.013923    0.022817    0.852951    
#> 360: 0.315641    1.083071    3.494974    0.044705    0.013927    0.022778    0.852910    
#> 361: 0.315302    1.083023    3.494914    0.044698    0.013964    0.022756    0.852938    
#> 362: 0.315349    1.082907    3.494979    0.044634    0.013974    0.022740    0.852851    
#> 363: 0.315502    1.082788    3.495058    0.044597    0.013974    0.022751    0.852817    
#> 364: 0.315629    1.082770    3.495045    0.044680    0.013959    0.022721    0.852769    
#> 365: 0.315658    1.082740    3.495101    0.044714    0.013978    0.022713    0.852709    
#> 366: 0.315812    1.082686    3.495071    0.044768    0.013966    0.022724    0.852746    
#> 367: 0.316042    1.082747    3.495097    0.044841    0.013985    0.022717    0.852845    
#> 368: 0.316323    1.082761    3.495146    0.044842    0.013988    0.022741    0.852751    
#> 369: 0.316456    1.082788    3.495156    0.044794    0.013986    0.022752    0.852715    
#> 370: 0.316192    1.082959    3.495087    0.044845    0.014008    0.022717    0.852842    
#> 371: 0.315979    1.083053    3.494908    0.044841    0.013987    0.022714    0.852917    
#> 372: 0.315911    1.083058    3.494884    0.044862    0.013975    0.022715    0.852973    
#> 373: 0.316081    1.083130    3.494868    0.044876    0.013986    0.022722    0.852943    
#> 374: 0.316276    1.083073    3.494857    0.044919    0.013996    0.022746    0.852823    
#> 375: 0.316325    1.083000    3.494893    0.044908    0.014016    0.022753    0.852843    
#> 376: 0.316390    1.083020    3.494887    0.044930    0.014050    0.022721    0.852745    
#> 377: 0.316610    1.083092    3.494857    0.044872    0.014074    0.022705    0.852741    
#> 378: 0.316394    1.083099    3.494762    0.044832    0.014105    0.022703    0.852757    
#> 379: 0.316255    1.083047    3.494791    0.044846    0.014121    0.022723    0.852841    
#> 380: 0.316072    1.083077    3.494744    0.044843    0.014120    0.022726    0.852862    
#> 381: 0.315996    1.082946    3.494756    0.044881    0.014122    0.022712    0.852866    
#> 382: 0.316007    1.082734    3.494828    0.044935    0.014136    0.022699    0.852810    
#> 383: 0.316079    1.082582    3.494895    0.044943    0.014136    0.022684    0.852768    
#> 384: 0.315964    1.082447    3.494945    0.045035    0.014155    0.022654    0.852738    
#> 385: 0.316080    1.082330    3.495000    0.045010    0.014182    0.022671    0.852805    
#> 386: 0.316242    1.082380    3.495097    0.044963    0.014184    0.022690    0.852828    
#> 387: 0.316408    1.082327    3.495262    0.044966    0.014188    0.022698    0.852710    
#> 388: 0.316407    1.082295    3.495311    0.044999    0.014181    0.022690    0.852614    
#> 389: 0.316364    1.082207    3.495313    0.045093    0.014166    0.022683    0.852634    
#> 390: 0.316160    1.082165    3.495281    0.045138    0.014139    0.022673    0.852676    
#> 391: 0.316078    1.082149    3.495203    0.045096    0.014131    0.022685    0.852683    
#> 392: 0.316177    1.082148    3.495276    0.045088    0.014131    0.022716    0.852684    
#> 393: 0.316164    1.082143    3.495231    0.045076    0.014127    0.022731    0.852752    
#> 394: 0.316143    1.082109    3.495236    0.045110    0.014123    0.022727    0.852693    
#> 395: 0.316359    1.082158    3.495296    0.045100    0.014124    0.022727    0.852584    
#> 396: 0.316563    1.082269    3.495381    0.045111    0.014133    0.022746    0.852455    
#> 397: 0.316684    1.082263    3.495439    0.045095    0.014166    0.022718    0.852413    
#> 398: 0.316981    1.082198    3.495582    0.045158    0.014165    0.022727    0.852325    
#> 399: 0.317167    1.082165    3.495709    0.045197    0.014178    0.022734    0.852266    
#> 400: 0.317474    1.082192    3.495827    0.045227    0.014179    0.022732    0.852254    
#> 401: 0.317592    1.082200    3.495893    0.045216    0.014187    0.022747    0.852305    
#> 402: 0.317506    1.082245    3.495915    0.045231    0.014174    0.022755    0.852250    
#> 403: 0.317608    1.082254    3.495910    0.045185    0.014158    0.022784    0.852256    
#> 404: 0.317690    1.082306    3.495841    0.045186    0.014170    0.022803    0.852225    
#> 405: 0.317588    1.082384    3.495858    0.045220    0.014178    0.022798    0.852138    
#> 406: 0.317567    1.082500    3.495846    0.045180    0.014194    0.022782    0.852109    
#> 407: 0.317611    1.082620    3.495878    0.045149    0.014188    0.022754    0.852089    
#> 408: 0.317641    1.082795    3.495891    0.045187    0.014189    0.022761    0.852101    
#> 409: 0.317574    1.082851    3.495836    0.045210    0.014169    0.022760    0.852002    
#> 410: 0.317642    1.082863    3.495787    0.045286    0.014169    0.022755    0.851952    
#> 411: 0.317721    1.082731    3.495773    0.045392    0.014164    0.022757    0.851959    
#> 412: 0.317660    1.082703    3.495704    0.045523    0.014154    0.022785    0.851860    
#> 413: 0.317613    1.082678    3.495692    0.045614    0.014150    0.022782    0.851768    
#> 414: 0.317513    1.082655    3.495716    0.045622    0.014145    0.022771    0.851675    
#> 415: 0.317624    1.082541    3.495731    0.045649    0.014148    0.022771    0.851626    
#> 416: 0.317786    1.082507    3.495777    0.045656    0.014150    0.022795    0.851482    
#> 417: 0.317867    1.082347    3.495746    0.045771    0.014143    0.022780    0.851446    
#> 418: 0.317747    1.082261    3.495760    0.045825    0.014152    0.022754    0.851427    
#> 419: 0.317788    1.082302    3.495771    0.045872    0.014163    0.022732    0.851372    
#> 420: 0.317867    1.082327    3.495782    0.045858    0.014159    0.022747    0.851272    
#> 421: 0.317924    1.082350    3.495872    0.045864    0.014159    0.022776    0.851138    
#> 422: 0.318036    1.082251    3.495913    0.045888    0.014174    0.022823    0.851127    
#> 423: 0.318155    1.082167    3.495931    0.045913    0.014189    0.022834    0.851097    
#> 424: 0.318111    1.082158    3.495869    0.045938    0.014186    0.022821    0.851132    
#> 425: 0.318277    1.082247    3.495861    0.046065    0.014216    0.022818    0.851169    
#> 426: 0.318270    1.082321    3.495818    0.046105    0.014225    0.022798    0.851172    
#> 427: 0.318305    1.082280    3.495875    0.046174    0.014225    0.022792    0.851212    
#> 428: 0.318250    1.082296    3.495902    0.046175    0.014216    0.022805    0.851272    
#> 429: 0.318190    1.082247    3.495905    0.046195    0.014201    0.022818    0.851275    
#> 430: 0.318097    1.082312    3.495888    0.046303    0.014200    0.022812    0.851228    
#> 431: 0.317922    1.082396    3.495795    0.046366    0.014204    0.022804    0.851172    
#> 432: 0.317926    1.082531    3.495852    0.046392    0.014206    0.022776    0.851190    
#> 433: 0.318049    1.082617    3.495876    0.046419    0.014213    0.022763    0.851105    
#> 434: 0.318036    1.082653    3.495936    0.046398    0.014225    0.022774    0.851042    
#> 435: 0.318117    1.082659    3.495946    0.046431    0.014218    0.022779    0.850992    
#> 436: 0.318057    1.082584    3.496007    0.046395    0.014223    0.022777    0.850971    
#> 437: 0.318046    1.082554    3.496028    0.046375    0.014240    0.022793    0.850952    
#> 438: 0.318141    1.082615    3.496032    0.046391    0.014241    0.022788    0.850936    
#> 439: 0.318221    1.082627    3.496084    0.046393    0.014244    0.022786    0.850882    
#> 440: 0.318125    1.082674    3.496069    0.046416    0.014243    0.022779    0.850794    
#> 441: 0.318055    1.082735    3.496069    0.046399    0.014259    0.022776    0.850783    
#> 442: 0.317884    1.082792    3.496058    0.046360    0.014263    0.022762    0.850692    
#> 443: 0.317803    1.082823    3.496010    0.046407    0.014248    0.022792    0.850707    
#> 444: 0.317734    1.082798    3.495972    0.046456    0.014240    0.022802    0.850702    
#> 445: 0.317701    1.082775    3.495970    0.046481    0.014227    0.022820    0.850740    
#> 446: 0.317616    1.082757    3.495950    0.046516    0.014211    0.022828    0.850758    
#> 447: 0.317645    1.082731    3.495994    0.046535    0.014200    0.022858    0.850759    
#> 448: 0.317579    1.082757    3.496023    0.046557    0.014204    0.022877    0.850765    
#> 449: 0.317635    1.082833    3.496139    0.046568    0.014222    0.022894    0.850773    
#> 450: 0.317654    1.082883    3.496139    0.046635    0.014207    0.022898    0.850706    
#> 451: 0.317616    1.082916    3.496115    0.046662    0.014205    0.022900    0.850686    
#> 452: 0.317512    1.082956    3.496054    0.046705    0.014207    0.022882    0.850676    
#> 453: 0.317487    1.082961    3.496029    0.046702    0.014204    0.022903    0.850602    
#> 454: 0.317529    1.082997    3.496039    0.046658    0.014198    0.022920    0.850535    
#> 455: 0.317536    1.083010    3.496052    0.046645    0.014179    0.022946    0.850472    
#> 456: 0.317459    1.083021    3.496005    0.046603    0.014172    0.022970    0.850456    
#> 457: 0.317491    1.083015    3.496060    0.046560    0.014180    0.023007    0.850438    
#> 458: 0.317446    1.083128    3.496119    0.046544    0.014187    0.023028    0.850472    
#> 459: 0.317408    1.083310    3.496105    0.046550    0.014189    0.023022    0.850498    
#> 460: 0.317351    1.083330    3.496055    0.046554    0.014172    0.023018    0.850493    
#> 461: 0.317159    1.083342    3.496050    0.046574    0.014162    0.023048    0.850454    
#> 462: 0.317237    1.083348    3.496116    0.046615    0.014151    0.023070    0.850432    
#> 463: 0.317409    1.083331    3.496206    0.046618    0.014146    0.023070    0.850404    
#> 464: 0.317497    1.083400    3.496225    0.046597    0.014144    0.023078    0.850357    
#> 465: 0.317546    1.083343    3.496218    0.046650    0.014153    0.023069    0.850337    
#> 466: 0.317671    1.083336    3.496194    0.046650    0.014145    0.023049    0.850403    
#> 467: 0.317598    1.083391    3.496201    0.046628    0.014148    0.023060    0.850368    
#> 468: 0.317577    1.083408    3.496210    0.046606    0.014138    0.023060    0.850426    
#> 469: 0.317500    1.083503    3.496223    0.046602    0.014140    0.023084    0.850411    
#> 470: 0.317356    1.083529    3.496184    0.046646    0.014141    0.023099    0.850309    
#> 471: 0.317118    1.083552    3.496136    0.046642    0.014140    0.023101    0.850292    
#> 472: 0.317024    1.083506    3.496130    0.046641    0.014143    0.023107    0.850333    
#> 473: 0.316886    1.083465    3.496115    0.046670    0.014149    0.023113    0.850305    
#> 474: 0.316797    1.083426    3.496107    0.046710    0.014153    0.023114    0.850305    
#> 475: 0.316729    1.083498    3.496080    0.046731    0.014158    0.023118    0.850222    
#> 476: 0.316679    1.083489    3.496040    0.046796    0.014171    0.023105    0.850173    
#> 477: 0.316633    1.083521    3.496058    0.046739    0.014166    0.023095    0.850199    
#> 478: 0.316541    1.083526    3.496015    0.046696    0.014148    0.023086    0.850262    
#> 479: 0.316524    1.083561    3.496019    0.046659    0.014147    0.023066    0.850366    
#> 480: 0.316604    1.083525    3.496050    0.046664    0.014153    0.023075    0.850332    
#> 481: 0.316707    1.083553    3.496084    0.046621    0.014145    0.023078    0.850331    
#> 482: 0.316801    1.083597    3.496080    0.046574    0.014146    0.023083    0.850356    
#> 483: 0.316780    1.083664    3.496047    0.046562    0.014132    0.023088    0.850394    
#> 484: 0.316876    1.083642    3.496052    0.046518    0.014124    0.023085    0.850425    
#> 485: 0.316981    1.083725    3.496058    0.046498    0.014132    0.023091    0.850381    
#> 486: 0.317048    1.083735    3.496097    0.046456    0.014137    0.023085    0.850356    
#> 487: 0.317215    1.083703    3.496188    0.046445    0.014140    0.023089    0.850330    
#> 488: 0.317195    1.083595    3.496242    0.046400    0.014133    0.023108    0.850328    
#> 489: 0.317256    1.083497    3.496260    0.046357    0.014134    0.023121    0.850433    
#> 490: 0.317384    1.083523    3.496330    0.046360    0.014126    0.023114    0.850366    
#> 491: 0.317400    1.083558    3.496371    0.046386    0.014125    0.023117    0.850275    
#> 492: 0.317320    1.083564    3.496359    0.046417    0.014129    0.023101    0.850332    
#> 493: 0.317156    1.083579    3.496304    0.046448    0.014146    0.023108    0.850296    
#> 494: 0.317163    1.083553    3.496317    0.046418    0.014150    0.023125    0.850190    
#> 495: 0.317304    1.083559    3.496344    0.046482    0.014143    0.023136    0.850118    
#> 496: 0.317291    1.083607    3.496299    0.046481    0.014144    0.023140    0.850066    
#> 497: 0.317182    1.083566    3.496261    0.046441    0.014152    0.023141    0.850111    
#> 498: 0.317072    1.083566    3.496207    0.046412    0.014155    0.023150    0.850116    
#> 499: 0.317060    1.083585    3.496189    0.046358    0.014155    0.023156    0.850112    
#> 500: 0.317121    1.083563    3.496202    0.046333    0.014137    0.023163    0.850199    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.313951    0.958179    3.443531    0.392401    0.087273    0.016800    1.766753    
#> 002: 0.401556    0.937040    3.449899    0.372781    0.082909    0.015960    1.293875    
#> 003: 0.478195    0.864370    3.437977    0.354142    0.078764    0.015162    1.026809    
#> 004: 0.463108    0.847700    3.432011    0.336435    0.074825    0.014404    0.934062    
#> 005: 0.530957    0.843681    3.418276    0.337388    0.074798    0.013684    0.862727    
#> 006: 0.507569    0.845503    3.404314    0.320518    0.073030    0.013000    0.820518    
#> 007: 0.453541    0.848385    3.397597    0.304492    0.084746    0.012350    0.806673    
#> 008: 0.441414    0.848882    3.388662    0.322565    0.097921    0.012356    0.777810    
#> 009: 0.402128    0.845486    3.376355    0.343981    0.093025    0.012170    0.799724    
#> 010: 0.386175    0.843966    3.380485    0.326782    0.088373    0.013133    0.810359    
#> 011: 0.460350    0.847676    3.382195    0.345026    0.083955    0.012476    0.796637    
#> 012: 0.461587    0.866290    3.378075    0.362913    0.079757    0.011852    0.780024    
#> 013: 0.389693    0.860843    3.379058    0.344767    0.075769    0.013730    0.792725    
#> 014: 0.452235    0.858138    3.390639    0.361507    0.079820    0.018170    0.808017    
#> 015: 0.488291    0.859124    3.410114    0.343432    0.075829    0.017262    0.806962    
#> 016: 0.478774    0.870199    3.403523    0.413903    0.089691    0.019594    0.800202    
#> 017: 0.449499    0.873656    3.395741    0.393207    0.085206    0.018614    0.777314    
#> 018: 0.435347    0.880881    3.376596    0.373547    0.091367    0.017684    0.814501    
#> 019: 0.403546    0.879671    3.374778    0.354870    0.086798    0.016800    0.789283    
#> 020: 0.452985    0.877766    3.379380    0.377729    0.082462    0.015960    0.781917    
#> 021: 0.460821    0.870726    3.387395    0.358843    0.078339    0.015162    0.791997    
#> 022: 0.445690    0.849361    3.401839    0.378170    0.074422    0.014404    0.796358    
#> 023: 0.519127    0.866076    3.417068    0.363719    0.070701    0.013683    0.824632    
#> 024: 0.522250    0.871674    3.407392    0.405537    0.067166    0.012999    0.807289    
#> 025: 0.518725    0.849247    3.401756    0.385260    0.063807    0.013741    0.800501    
#> 026: 0.466237    0.873786    3.395086    0.365997    0.060617    0.013054    0.797874    
#> 027: 0.430309    0.904000    3.384436    0.347697    0.068054    0.012665    0.810372    
#> 028: 0.445593    0.867785    3.390003    0.347026    0.064651    0.013396    0.801239    
#> 029: 0.500641    0.869261    3.380355    0.329675    0.066765    0.012727    0.822079    
#> 030: 0.445884    0.890504    3.372728    0.325429    0.076994    0.012090    0.799884    
#> 031: 0.432411    0.866360    3.377766    0.365646    0.082159    0.011486    0.792534    
#> 032: 0.414230    0.858577    3.374522    0.360680    0.083947    0.010912    0.788745    
#> 033: 0.392995    0.889021    3.366366    0.376923    0.098021    0.010366    0.785955    
#> 034: 0.458326    0.901537    3.370772    0.386728    0.093352    0.010240    0.805699    
#> 035: 0.411704    0.896256    3.373385    0.367392    0.088684    0.009728    0.791813    
#> 036: 0.444362    0.902748    3.372249    0.349022    0.084250    0.009241    0.809059    
#> 037: 0.405669    0.898140    3.379128    0.331571    0.080037    0.008779    0.840716    
#> 038: 0.427199    0.902543    3.369401    0.314993    0.076035    0.008723    0.843741    
#> 039: 0.442374    0.871628    3.381433    0.299243    0.081432    0.008287    0.828355    
#> 040: 0.408029    0.882226    3.377290    0.284281    0.081371    0.007873    0.830115    
#> 041: 0.409069    0.873032    3.381292    0.270067    0.082188    0.007479    0.818153    
#> 042: 0.433001    0.866680    3.386853    0.256573    0.085231    0.007105    0.811660    
#> 043: 0.390665    0.888504    3.374210    0.249752    0.083517    0.006750    0.806032    
#> 044: 0.379343    0.888243    3.374142    0.246736    0.097299    0.006412    0.831945    
#> 045: 0.396429    0.911389    3.361454    0.234399    0.102019    0.006092    0.839293    
#> 046: 0.374560    0.867894    3.365183    0.222679    0.096918    0.005787    0.831596    
#> 047: 0.393181    0.911087    3.363595    0.221667    0.092072    0.005893    0.803272    
#> 048: 0.391294    0.869410    3.360375    0.292625    0.087469    0.006683    0.788690    
#> 049: 0.397894    0.867604    3.380052    0.277994    0.088908    0.007438    0.817073    
#> 050: 0.491746    0.843537    3.383446    0.281204    0.094760    0.007911    0.822463    
#> 051: 0.463088    0.869805    3.388641    0.267144    0.090022    0.007515    0.828809    
#> 052: 0.456759    0.865087    3.396796    0.253787    0.085521    0.007139    0.812730    
#> 053: 0.488596    0.843874    3.400353    0.306086    0.081245    0.006782    0.817782    
#> 054: 0.432093    0.855646    3.400043    0.290782    0.077182    0.006899    0.840862    
#> 055: 0.443020    0.852250    3.397079    0.276242    0.091883    0.006554    0.842849    
#> 056: 0.486732    0.822114    3.408791    0.310954    0.113647    0.006226    0.842474    
#> 057: 0.458982    0.822180    3.411397    0.297424    0.107964    0.007327    0.842959    
#> 058: 0.457463    0.833896    3.394836    0.282552    0.102566    0.008067    0.851732    
#> 059: 0.434959    0.819360    3.405902    0.268425    0.097438    0.008425    0.863342    
#> 060: 0.466216    0.806142    3.418801    0.255004    0.092566    0.010896    0.849585    
#> 061: 0.500546    0.831349    3.411953    0.322323    0.087938    0.011617    0.831029    
#> 062: 0.509504    0.847323    3.411655    0.306207    0.083541    0.013822    0.834640    
#> 063: 0.506810    0.830951    3.411417    0.307534    0.079364    0.016952    0.834363    
#> 064: 0.488409    0.833688    3.413798    0.318176    0.075396    0.016104    0.811276    
#> 065: 0.499830    0.833686    3.404384    0.304826    0.071626    0.016420    0.797666    
#> 066: 0.494145    0.850377    3.407387    0.345526    0.068044    0.018064    0.777246    
#> 067: 0.463952    0.861058    3.395966    0.328755    0.069011    0.017161    0.779751    
#> 068: 0.449542    0.862045    3.408469    0.384430    0.069709    0.016303    0.806143    
#> 069: 0.468131    0.862084    3.404371    0.365208    0.069359    0.015488    0.824219    
#> 070: 0.463220    0.870596    3.394319    0.346948    0.074994    0.014714    0.817631    
#> 071: 0.413127    0.895947    3.370992    0.329600    0.071762    0.013978    0.809005    
#> 072: 0.370086    0.870263    3.370650    0.317365    0.068174    0.013279    0.810395    
#> 073: 0.420897    0.861598    3.387130    0.317670    0.068063    0.012615    0.791753    
#> 074: 0.415549    0.856732    3.392286    0.301787    0.076174    0.012684    0.795643    
#> 075: 0.459744    0.850156    3.417436    0.306738    0.077936    0.012050    0.793402    
#> 076: 0.492687    0.842374    3.421583    0.291401    0.082458    0.011447    0.822861    
#> 077: 0.553514    0.811784    3.425270    0.295011    0.092411    0.010875    0.813136    
#> 078: 0.502419    0.819030    3.425486    0.331075    0.087791    0.010331    0.801214    
#> 079: 0.489489    0.825230    3.424885    0.314521    0.083401    0.010804    0.826154    
#> 080: 0.524805    0.831875    3.423057    0.298795    0.091222    0.010798    0.834505    
#> 081: 0.503157    0.835726    3.416852    0.283855    0.086661    0.010258    0.816250    
#> 082: 0.471304    0.835024    3.406012    0.281602    0.082328    0.009745    0.851568    
#> 083: 0.518540    0.871925    3.404223    0.405190    0.081218    0.009258    0.810106    
#> 084: 0.515276    0.859262    3.408094    0.384930    0.094982    0.008795    0.813251    
#> 085: 0.472896    0.878409    3.404959    0.365684    0.090233    0.008356    0.816035    
#> 086: 0.459525    0.877677    3.396978    0.347399    0.095984    0.010513    0.798311    
#> 087: 0.420849    0.863509    3.381312    0.330030    0.091185    0.009987    0.795163    
#> 088: 0.371951    0.867733    3.379929    0.358670    0.086626    0.009488    0.837641    
#> 089: 0.417643    0.875578    3.375014    0.348739    0.082664    0.011292    0.828170    
#> 090: 0.381648    0.853896    3.385308    0.331302    0.092518    0.010728    0.836793    
#> 091: 0.427042    0.848845    3.370689    0.375563    0.087892    0.010191    0.806994    
#> 092: 0.401920    0.888041    3.370908    0.356785    0.083498    0.009682    0.810865    
#> 093: 0.379690    0.868403    3.371550    0.338946    0.092336    0.009198    0.814250    
#> 094: 0.411110    0.867169    3.371247    0.321999    0.087719    0.008738    0.813789    
#> 095: 0.418524    0.890014    3.376632    0.313966    0.095447    0.010192    0.797609    
#> 096: 0.419011    0.895846    3.380635    0.351958    0.090675    0.010897    0.785868    
#> 097: 0.449140    0.886430    3.386411    0.334360    0.086141    0.010352    0.781409    
#> 098: 0.436948    0.908609    3.383749    0.346934    0.081834    0.009834    0.803093    
#> 099: 0.384357    0.866646    3.370109    0.329588    0.077742    0.009342    0.805350    
#> 100: 0.410205    0.864712    3.379026    0.313108    0.073855    0.010589    0.812537    
#> 101: 0.401937    0.854939    3.368031    0.297453    0.074028    0.010312    0.809491    
#> 102: 0.430294    0.863737    3.373968    0.282580    0.098633    0.010113    0.795113    
#> 103: 0.427142    0.876583    3.386879    0.299261    0.093701    0.009607    0.786285    
#> 104: 0.431289    0.877782    3.386595    0.290295    0.089016    0.010782    0.809526    
#> 105: 0.466502    0.877027    3.386216    0.320687    0.084566    0.012160    0.792595    
#> 106: 0.455280    0.871707    3.381533    0.304653    0.080337    0.013235    0.786373    
#> 107: 0.497341    0.867869    3.393218    0.289420    0.083312    0.012573    0.788434    
#> 108: 0.444296    0.861068    3.386384    0.312970    0.085473    0.011945    0.800942    
#> 109: 0.411768    0.868215    3.394707    0.310288    0.081199    0.011347    0.804863    
#> 110: 0.425946    0.854372    3.379430    0.294774    0.079870    0.010780    0.822333    
#> 111: 0.385483    0.884780    3.381785    0.280035    0.081423    0.010241    0.816478    
#> 112: 0.392040    0.851290    3.372524    0.283606    0.086305    0.009729    0.821426    
#> 113: 0.442294    0.887936    3.386973    0.331107    0.092891    0.009243    0.787393    
#> 114: 0.458099    0.882987    3.386047    0.314552    0.088247    0.008780    0.795628    
#> 115: 0.465708    0.867631    3.393372    0.298824    0.083834    0.010430    0.803374    
#> 116: 0.465383    0.868222    3.400227    0.283883    0.085085    0.010799    0.815150    
#> 117: 0.442674    0.865730    3.398706    0.336087    0.082082    0.010259    0.803434    
#> 118: 0.496212    0.843128    3.406127    0.401903    0.091228    0.009746    0.809239    
#> 119: 0.446308    0.865584    3.394653    0.381808    0.086666    0.010883    0.822163    
#> 120: 0.422378    0.851899    3.385963    0.362718    0.082333    0.011972    0.818869    
#> 121: 0.447574    0.881296    3.394334    0.344582    0.078216    0.011458    0.824175    
#> 122: 0.435643    0.825003    3.400113    0.327353    0.074306    0.010885    0.813896    
#> 123: 0.480290    0.862979    3.393512    0.328235    0.070590    0.010341    0.820462    
#> 124: 0.455995    0.892091    3.393572    0.311823    0.067061    0.011653    0.806491    
#> 125: 0.467076    0.895338    3.386577    0.314285    0.063708    0.013738    0.805263    
#> 126: 0.430548    0.894848    3.376809    0.298571    0.066889    0.016955    0.811249    
#> 127: 0.471455    0.875232    3.379240    0.344109    0.063545    0.018450    0.814069    
#> 128: 0.430777    0.845994    3.396678    0.335042    0.073754    0.018207    0.813124    
#> 129: 0.422820    0.872913    3.394962    0.318290    0.074466    0.017297    0.819190    
#> 130: 0.464992    0.889686    3.393356    0.318959    0.070743    0.016698    0.796061    
#> 131: 0.431327    0.866967    3.387536    0.303011    0.067206    0.015863    0.807053    
#> 132: 0.417488    0.879589    3.371217    0.313797    0.076994    0.015070    0.797401    
#> 133: 0.404786    0.867101    3.380634    0.298107    0.076908    0.015870    0.801750    
#> 134: 0.450409    0.859793    3.394514    0.327482    0.088353    0.015077    0.819642    
#> 135: 0.452493    0.846786    3.400460    0.332791    0.083935    0.014323    0.824703    
#> 136: 0.446591    0.843357    3.397639    0.316152    0.079738    0.013607    0.819091    
#> 137: 0.520943    0.843431    3.407299    0.300344    0.075751    0.012926    0.846834    
#> 138: 0.488693    0.846699    3.409212    0.294522    0.092947    0.012280    0.826889    
#> 139: 0.468053    0.842833    3.417672    0.292053    0.088300    0.014721    0.836094    
#> 140: 0.491515    0.865740    3.420368    0.318156    0.085566    0.013985    0.835953    
#> 141: 0.466628    0.828601    3.416646    0.302248    0.082929    0.013286    0.843139    
#> 142: 0.496673    0.805284    3.440730    0.287136    0.078782    0.014114    0.862388    
#> 143: 0.472990    0.832944    3.427393    0.272779    0.074843    0.013409    0.846819    
#> 144: 0.516498    0.836600    3.435639    0.278737    0.071101    0.014056    0.806237    
#> 145: 0.477320    0.860129    3.400390    0.308737    0.091091    0.013353    0.790184    
#> 146: 0.417162    0.870385    3.405616    0.293300    0.086537    0.012686    0.807305    
#> 147: 0.410304    0.860399    3.389133    0.316758    0.082210    0.012052    0.793831    
#> 148: 0.422902    0.857976    3.393201    0.321040    0.087751    0.011449    0.787584    
#> 149: 0.447727    0.860088    3.399998    0.306106    0.096996    0.010877    0.813294    
#> 150: 0.500870    0.847965    3.395734    0.303343    0.101078    0.010333    0.832122    
#> 151: 0.434390    0.854463    3.398037    0.288176    0.103802    0.009816    0.817935    
#> 152: 0.433437    0.867148    3.408442    0.275343    0.099214    0.009030    0.804069    
#> 153: 0.436818    0.869817    3.406584    0.254182    0.102614    0.005924    0.816612    
#> 154: 0.492280    0.860562    3.410440    0.300122    0.086434    0.007201    0.836278    
#> 155: 0.446097    0.827264    3.404259    0.258257    0.108219    0.006124    0.822851    
#> 156: 0.468763    0.848078    3.409017    0.258742    0.117925    0.006147    0.826103    
#> 157: 0.481157    0.848720    3.410637    0.290345    0.093463    0.005863    0.834107    
#> 158: 0.499861    0.850958    3.407201    0.287595    0.108002    0.006208    0.799697    
#> 159: 0.457084    0.858370    3.403593    0.301105    0.104947    0.005244    0.792428    
#> 160: 0.450024    0.846699    3.404740    0.269424    0.090885    0.005503    0.811369    
#> 161: 0.460889    0.845286    3.398682    0.282998    0.089467    0.006336    0.820429    
#> 162: 0.449026    0.856051    3.392449    0.244355    0.091914    0.005548    0.818866    
#> 163: 0.469674    0.860905    3.394413    0.260898    0.090565    0.004160    0.819744    
#> 164: 0.470327    0.861359    3.399827    0.271770    0.092459    0.005100    0.811278    
#> 165: 0.460682    0.855726    3.408721    0.283946    0.102735    0.005153    0.804420    
#> 166: 0.474925    0.884097    3.399812    0.257629    0.092032    0.005462    0.826653    
#> 167: 0.484019    0.863171    3.410490    0.239232    0.094048    0.005578    0.833668    
#> 168: 0.508740    0.859081    3.417135    0.223557    0.073869    0.005659    0.840801    
#> 169: 0.466705    0.870016    3.407598    0.220508    0.088330    0.006646    0.865800    
#> 170: 0.451422    0.847914    3.407029    0.235148    0.076329    0.007001    0.822103    
#> 171: 0.433580    0.857992    3.397745    0.226266    0.089866    0.005104    0.803920    
#> 172: 0.439298    0.867992    3.395819    0.277725    0.079268    0.004778    0.804986    
#> 173: 0.463206    0.876750    3.388458    0.266660    0.096300    0.004838    0.819979    
#> 174: 0.451446    0.862178    3.393876    0.232525    0.103166    0.005345    0.798391    
#> 175: 0.436301    0.867676    3.389757    0.211280    0.099718    0.004782    0.812621    
#> 176: 0.484326    0.882911    3.393464    0.291361    0.097086    0.005166    0.807567    
#> 177: 0.460726    0.862352    3.401539    0.251701    0.085269    0.004830    0.802573    
#> 178: 0.470880    0.855363    3.401707    0.296803    0.094262    0.004913    0.791464    
#> 179: 0.486462    0.887163    3.393395    0.282782    0.097519    0.004829    0.826666    
#> 180: 0.451833    0.867665    3.396970    0.321175    0.098097    0.004894    0.802215    
#> 181: 0.445220    0.860535    3.381506    0.337974    0.085215    0.004829    0.797130    
#> 182: 0.380543    0.882980    3.371723    0.245485    0.078411    0.005697    0.819137    
#> 183: 0.377875    0.896183    3.371784    0.218438    0.097712    0.005540    0.816584    
#> 184: 0.404334    0.868287    3.372274    0.211971    0.095742    0.004225    0.822211    
#> 185: 0.354287    0.898292    3.366786    0.190604    0.093212    0.003030    0.823213    
#> 186: 0.389736    0.904853    3.371637    0.199468    0.088789    0.003540    0.805250    
#> 187: 0.382012    0.875295    3.378107    0.184514    0.089694    0.004194    0.819975    
#> 188: 0.385567    0.874758    3.374907    0.203202    0.104176    0.004358    0.842486    
#> 189: 0.426821    0.884324    3.383347    0.227912    0.081946    0.003653    0.848465    
#> 190: 0.428145    0.883465    3.385641    0.267834    0.087328    0.004113    0.818225    
#> 191: 0.403968    0.909890    3.371831    0.303842    0.081395    0.004895    0.823526    
#> 192: 0.426477    0.905339    3.382514    0.301819    0.101684    0.006362    0.808050    
#> 193: 0.445045    0.910018    3.379597    0.268488    0.099825    0.005622    0.793850    
#> 194: 0.408234    0.887075    3.373468    0.288657    0.100996    0.006735    0.808713    
#> 195: 0.370201    0.888491    3.365763    0.306619    0.092499    0.008573    0.806670    
#> 196: 0.367754    0.892390    3.372085    0.223179    0.085613    0.007515    0.821760    
#> 197: 0.346511    0.890558    3.384550    0.230494    0.081138    0.007900    0.825272    
#> 198: 0.428796    0.891186    3.373664    0.218521    0.068445    0.010162    0.816556    
#> 199: 0.391994    0.884244    3.374153    0.244211    0.069805    0.011372    0.793981    
#> 200: 0.403319    0.892385    3.376457    0.253122    0.078710    0.009271    0.822119    
#> 201: 0.415378    0.876068    3.382348    0.248330    0.078443    0.010425    0.815166    
#> 202: 0.421788    0.874830    3.383580    0.265993    0.080962    0.011624    0.812684    
#> 203: 0.437878    0.871335    3.383109    0.271943    0.081356    0.012113    0.809449    
#> 204: 0.441831    0.860509    3.386083    0.287833    0.079271    0.013149    0.807307    
#> 205: 0.438458    0.863613    3.386650    0.293679    0.078150    0.013395    0.809359    
#> 206: 0.435188    0.868822    3.386895    0.303914    0.078385    0.013177    0.809616    
#> 207: 0.431618    0.870039    3.383951    0.303800    0.077960    0.012801    0.809292    
#> 208: 0.427819    0.873151    3.382345    0.305978    0.077254    0.012697    0.808877    
#> 209: 0.428058    0.871194    3.381615    0.307335    0.076900    0.012512    0.807913    
#> 210: 0.429861    0.870850    3.381926    0.307483    0.077118    0.012427    0.808204    
#> 211: 0.432368    0.871222    3.383390    0.301569    0.076028    0.012310    0.806865    
#> 212: 0.437851    0.869405    3.384522    0.300053    0.075122    0.012224    0.806745    
#> 213: 0.441440    0.867908    3.385817    0.301322    0.075194    0.012268    0.807366    
#> 214: 0.443561    0.866739    3.386837    0.298446    0.076039    0.012338    0.807419    
#> 215: 0.447018    0.866348    3.388027    0.302211    0.075938    0.012471    0.807094    
#> 216: 0.448642    0.865775    3.388376    0.305224    0.075677    0.012703    0.808116    
#> 217: 0.447156    0.867089    3.388529    0.305240    0.075062    0.012746    0.807400    
#> 218: 0.446819    0.868439    3.388125    0.306423    0.074176    0.012740    0.806160    
#> 219: 0.445523    0.867881    3.387556    0.304931    0.073953    0.012650    0.806241    
#> 220: 0.443767    0.867871    3.387348    0.306092    0.073332    0.012563    0.807174    
#> 221: 0.441416    0.868741    3.386721    0.304862    0.073404    0.012384    0.807482    
#> 222: 0.439722    0.868863    3.386300    0.301886    0.073473    0.012292    0.808895    
#> 223: 0.441332    0.868942    3.386422    0.300432    0.073306    0.012156    0.808834    
#> 224: 0.443579    0.869752    3.387005    0.299235    0.073467    0.012046    0.808605    
#> 225: 0.445774    0.868101    3.388100    0.300711    0.073707    0.012136    0.808714    
#> 226: 0.447942    0.866491    3.388526    0.301447    0.073685    0.012083    0.808543    
#> 227: 0.447633    0.866270    3.388655    0.302055    0.073433    0.012129    0.808896    
#> 228: 0.446541    0.867485    3.388148    0.303589    0.073337    0.012154    0.809040    
#> 229: 0.445021    0.867636    3.387823    0.305222    0.073205    0.012100    0.808537    
#> 230: 0.445383    0.867484    3.387539    0.306024    0.073003    0.011979    0.808394    
#> 231: 0.445467    0.867685    3.387489    0.306875    0.073218    0.011855    0.808140    
#> 232: 0.445017    0.868262    3.387583    0.308047    0.073429    0.011790    0.807657    
#> 233: 0.444188    0.867760    3.387400    0.308292    0.073549    0.011773    0.806870    
#> 234: 0.442872    0.867744    3.387350    0.307690    0.073316    0.011680    0.806610    
#> 235: 0.442466    0.867197    3.387245    0.306202    0.073671    0.011541    0.806348    
#> 236: 0.442895    0.867536    3.387085    0.307694    0.073735    0.011517    0.805959    
#> 237: 0.444582    0.867490    3.387388    0.309222    0.073725    0.011501    0.806306    
#> 238: 0.445594    0.867465    3.387509    0.308876    0.074098    0.011529    0.806662    
#> 239: 0.445473    0.867879    3.387452    0.309005    0.074303    0.011478    0.806751    
#> 240: 0.446374    0.867359    3.387864    0.308553    0.074535    0.011408    0.806532    
#> 241: 0.447373    0.866528    3.388163    0.307735    0.074634    0.011378    0.806409    
#> 242: 0.446642    0.866187    3.388088    0.306316    0.074837    0.011341    0.806823    
#> 243: 0.445602    0.866456    3.388123    0.305662    0.074704    0.011324    0.807354    
#> 244: 0.444625    0.866756    3.388170    0.307029    0.074558    0.011378    0.807258    
#> 245: 0.444103    0.866419    3.388112    0.307409    0.074714    0.011396    0.807360    
#> 246: 0.444192    0.866170    3.388257    0.306880    0.074809    0.011377    0.807648    
#> 247: 0.443741    0.865390    3.388520    0.306382    0.075091    0.011337    0.807760    
#> 248: 0.443694    0.865586    3.388643    0.305795    0.075241    0.011286    0.807680    
#> 249: 0.443564    0.866085    3.388712    0.304777    0.075516    0.011209    0.807654    
#> 250: 0.444139    0.866412    3.388777    0.304793    0.075514    0.011176    0.807826    
#> 251: 0.444806    0.866618    3.389095    0.305689    0.075805    0.011119    0.807678    
#> 252: 0.445286    0.866516    3.389573    0.305874    0.076173    0.011071    0.807664    
#> 253: 0.445573    0.866166    3.389810    0.306537    0.076629    0.011044    0.807713    
#> 254: 0.446148    0.866422    3.389938    0.306429    0.076657    0.011028    0.807633    
#> 255: 0.446470    0.866713    3.390089    0.307064    0.076585    0.011045    0.807428    
#> 256: 0.447191    0.866774    3.390096    0.307866    0.076507    0.011041    0.807266    
#> 257: 0.447376    0.866426    3.390106    0.308130    0.076269    0.011062    0.807215    
#> 258: 0.447327    0.865770    3.390238    0.308485    0.076340    0.011083    0.806923    
#> 259: 0.447678    0.865666    3.390351    0.309267    0.076456    0.011134    0.806596    
#> 260: 0.447408    0.865641    3.390393    0.308969    0.076678    0.011160    0.806244    
#> 261: 0.447790    0.865551    3.390511    0.308907    0.076862    0.011183    0.806063    
#> 262: 0.448201    0.866023    3.390714    0.308646    0.076891    0.011239    0.806022    
#> 263: 0.447781    0.866473    3.390558    0.309368    0.076938    0.011274    0.806278    
#> 264: 0.447244    0.866737    3.390370    0.309506    0.077117    0.011292    0.806492    
#> 265: 0.447412    0.867024    3.390352    0.308752    0.077340    0.011346    0.806504    
#> 266: 0.447267    0.867429    3.390287    0.307570    0.077499    0.011359    0.806697    
#> 267: 0.447115    0.867576    3.390261    0.307156    0.077374    0.011362    0.806769    
#> 268: 0.446872    0.867541    3.390049    0.307003    0.077404    0.011321    0.806933    
#> 269: 0.447595    0.867474    3.390014    0.307682    0.077326    0.011291    0.807267    
#> 270: 0.447920    0.867547    3.389916    0.307680    0.077403    0.011243    0.807305    
#> 271: 0.447847    0.867673    3.389801    0.308719    0.077392    0.011222    0.807414    
#> 272: 0.447874    0.867411    3.389753    0.308641    0.077359    0.011228    0.807672    
#> 273: 0.447842    0.867597    3.389743    0.308667    0.077363    0.011216    0.807672    
#> 274: 0.447704    0.867833    3.389763    0.307993    0.077470    0.011235    0.807558    
#> 275: 0.447923    0.867966    3.389614    0.308429    0.077413    0.011239    0.807507    
#> 276: 0.447371    0.867871    3.389702    0.309162    0.077396    0.011275    0.807273    
#> 277: 0.447281    0.868061    3.389814    0.309054    0.077568    0.011274    0.806969    
#> 278: 0.446906    0.868128    3.389800    0.308554    0.077609    0.011283    0.806979    
#> 279: 0.446460    0.868152    3.389817    0.307983    0.077802    0.011267    0.807019    
#> 280: 0.446414    0.868471    3.389872    0.307479    0.078067    0.011243    0.806796    
#> 281: 0.446334    0.868444    3.390010    0.307110    0.078126    0.011252    0.806980    
#> 282: 0.446410    0.868505    3.390136    0.306620    0.078123    0.011249    0.807235    
#> 283: 0.446694    0.868578    3.390240    0.306902    0.078170    0.011227    0.807492    
#> 284: 0.446889    0.868115    3.390356    0.307000    0.078290    0.011174    0.807567    
#> 285: 0.447089    0.868190    3.390263    0.307158    0.078561    0.011126    0.807518    
#> 286: 0.446964    0.868151    3.390138    0.306710    0.078605    0.011078    0.807621    
#> 287: 0.446889    0.868333    3.389965    0.306504    0.078694    0.011059    0.807651    
#> 288: 0.447326    0.868399    3.389916    0.305721    0.078825    0.011047    0.807912    
#> 289: 0.447746    0.868455    3.390012    0.304687    0.078829    0.011040    0.808056    
#> 290: 0.447947    0.868312    3.390142    0.303983    0.078778    0.011028    0.807930    
#> 291: 0.448481    0.868154    3.390363    0.303376    0.078691    0.011027    0.807679    
#> 292: 0.448684    0.867829    3.390559    0.302967    0.078627    0.011031    0.807544    
#> 293: 0.449048    0.867675    3.390654    0.303257    0.078565    0.011024    0.807342    
#> 294: 0.449336    0.867712    3.390679    0.303537    0.078564    0.011034    0.807322    
#> 295: 0.449437    0.867445    3.390699    0.303464    0.078537    0.011023    0.807181    
#> 296: 0.449395    0.867203    3.390751    0.302836    0.078468    0.011029    0.807430    
#> 297: 0.449352    0.867207    3.390782    0.302595    0.078393    0.011039    0.807479    
#> 298: 0.449568    0.866940    3.390831    0.302532    0.078352    0.011046    0.807382    
#> 299: 0.449606    0.866944    3.390764    0.302301    0.078264    0.011052    0.807073    
#> 300: 0.449692    0.866959    3.390759    0.302236    0.078192    0.011061    0.806783    
#> 301: 0.449735    0.866717    3.390642    0.302334    0.078129    0.011046    0.806761    
#> 302: 0.449408    0.866806    3.390493    0.302159    0.078126    0.011015    0.806888    
#> 303: 0.449244    0.867041    3.390363    0.302081    0.078340    0.010993    0.806698    
#> 304: 0.448887    0.867464    3.390124    0.302442    0.078535    0.010983    0.806769    
#> 305: 0.448379    0.867406    3.390016    0.302492    0.078524    0.010982    0.806778    
#> 306: 0.448064    0.867528    3.389854    0.303155    0.078396    0.010977    0.806673    
#> 307: 0.448022    0.867761    3.389719    0.303759    0.078531    0.010978    0.806547    
#> 308: 0.447616    0.867851    3.389601    0.303811    0.078658    0.010966    0.806452    
#> 309: 0.447753    0.867721    3.389497    0.303918    0.078659    0.010951    0.806528    
#> 310: 0.447584    0.867759    3.389325    0.303881    0.078568    0.010930    0.806700    
#> 311: 0.447185    0.867769    3.389160    0.304105    0.078509    0.010915    0.806640    
#> 312: 0.446807    0.867719    3.388973    0.304267    0.078469    0.010922    0.806706    
#> 313: 0.446217    0.867568    3.388768    0.304694    0.078434    0.010951    0.807016    
#> 314: 0.445710    0.867705    3.388643    0.304574    0.078475    0.010949    0.806996    
#> 315: 0.445181    0.868075    3.388519    0.304412    0.078514    0.010941    0.807065    
#> 316: 0.445057    0.868329    3.388482    0.303908    0.078522    0.010919    0.807183    
#> 317: 0.445137    0.868298    3.388558    0.304188    0.078429    0.010901    0.807274    
#> 318: 0.445435    0.868372    3.388577    0.303763    0.078411    0.010870    0.807281    
#> 319: 0.445614    0.868374    3.388654    0.304055    0.078434    0.010850    0.807325    
#> 320: 0.445417    0.868462    3.388613    0.303707    0.078491    0.010828    0.807341    
#> 321: 0.445194    0.868482    3.388465    0.303394    0.078483    0.010804    0.807436    
#> 322: 0.444914    0.868682    3.388252    0.303367    0.078473    0.010796    0.807471    
#> 323: 0.444282    0.868851    3.388093    0.302915    0.078407    0.010788    0.807671    
#> 324: 0.444197    0.868971    3.388057    0.302792    0.078382    0.010782    0.807489    
#> 325: 0.444206    0.869246    3.387963    0.303015    0.078392    0.010772    0.807422    
#> 326: 0.444275    0.869342    3.387864    0.302749    0.078299    0.010751    0.807579    
#> 327: 0.444223    0.869399    3.387827    0.302824    0.078419    0.010722    0.807731    
#> 328: 0.444149    0.869430    3.387785    0.302929    0.078481    0.010703    0.807672    
#> 329: 0.444373    0.869559    3.387832    0.302667    0.078455    0.010683    0.807759    
#> 330: 0.444104    0.869589    3.387763    0.302882    0.078462    0.010670    0.807664    
#> 331: 0.444314    0.869730    3.387737    0.303152    0.078488    0.010664    0.807583    
#> 332: 0.444270    0.869851    3.387724    0.303122    0.078517    0.010661    0.807524    
#> 333: 0.444036    0.869972    3.387606    0.302759    0.078533    0.010654    0.807538    
#> 334: 0.443838    0.869964    3.387457    0.302864    0.078625    0.010635    0.807536    
#> 335: 0.443612    0.870083    3.387362    0.302518    0.078623    0.010636    0.807520    
#> 336: 0.443242    0.870318    3.387242    0.302101    0.078634    0.010631    0.807440    
#> 337: 0.443024    0.870658    3.387111    0.301918    0.078635    0.010629    0.807551    
#> 338: 0.443036    0.870767    3.387073    0.302221    0.078639    0.010628    0.807530    
#> 339: 0.442936    0.870949    3.387038    0.302375    0.078682    0.010620    0.807473    
#> 340: 0.442869    0.870834    3.387058    0.302193    0.078750    0.010620    0.807463    
#> 341: 0.443012    0.870882    3.387133    0.302454    0.079001    0.010623    0.807453    
#> 342: 0.442913    0.870759    3.387136    0.302220    0.079158    0.010615    0.807458    
#> 343: 0.442485    0.870859    3.387153    0.301753    0.079201    0.010594    0.807582    
#> 344: 0.442292    0.870813    3.387130    0.301361    0.079176    0.010581    0.807574    
#> 345: 0.442291    0.870749    3.387143    0.301510    0.079181    0.010569    0.807616    
#> 346: 0.442526    0.870772    3.387067    0.302111    0.079253    0.010563    0.807476    
#> 347: 0.442752    0.870775    3.386997    0.302132    0.079211    0.010551    0.807579    
#> 348: 0.442587    0.870822    3.386979    0.302201    0.079242    0.010537    0.807565    
#> 349: 0.442464    0.870715    3.386952    0.302236    0.079195    0.010535    0.807581    
#> 350: 0.442302    0.870644    3.386890    0.302213    0.079198    0.010528    0.807550    
#> 351: 0.442209    0.870746    3.386856    0.301900    0.079234    0.010506    0.807664    
#> 352: 0.441743    0.870858    3.386802    0.301817    0.079253    0.010494    0.807838    
#> 353: 0.441657    0.871019    3.386791    0.301899    0.079275    0.010498    0.807794    
#> 354: 0.441688    0.871085    3.386728    0.302185    0.079258    0.010513    0.807623    
#> 355: 0.442053    0.870892    3.386753    0.302750    0.079232    0.010519    0.807603    
#> 356: 0.442224    0.870662    3.386873    0.302906    0.079214    0.010510    0.807663    
#> 357: 0.442314    0.870591    3.386924    0.302844    0.079149    0.010522    0.807613    
#> 358: 0.442487    0.870599    3.387046    0.303092    0.079072    0.010522    0.807408    
#> 359: 0.442552    0.870666    3.387143    0.302937    0.078964    0.010531    0.807267    
#> 360: 0.442532    0.870700    3.387128    0.302937    0.078899    0.010542    0.807071    
#> 361: 0.442468    0.870775    3.387139    0.302739    0.078901    0.010529    0.807037    
#> 362: 0.442610    0.870797    3.387104    0.302802    0.078931    0.010508    0.806956    
#> 363: 0.442607    0.870880    3.387098    0.302746    0.078924    0.010487    0.806864    
#> 364: 0.442634    0.870957    3.387041    0.302699    0.079028    0.010470    0.806904    
#> 365: 0.442475    0.870943    3.387057    0.302632    0.079124    0.010456    0.806974    
#> 366: 0.442488    0.870953    3.387003    0.302618    0.079174    0.010450    0.807092    
#> 367: 0.442789    0.870994    3.386989    0.302568    0.079212    0.010435    0.807237    
#> 368: 0.442934    0.871080    3.386975    0.302365    0.079090    0.010431    0.807238    
#> 369: 0.442855    0.871109    3.386965    0.301955    0.079061    0.010423    0.807293    
#> 370: 0.442762    0.871224    3.386914    0.301741    0.079125    0.010419    0.807415    
#> 371: 0.442651    0.871247    3.386830    0.301465    0.079221    0.010398    0.807507    
#> 372: 0.442457    0.871326    3.386727    0.301264    0.079259    0.010382    0.807561    
#> 373: 0.442345    0.871402    3.386651    0.301713    0.079227    0.010368    0.807594    
#> 374: 0.442580    0.871439    3.386629    0.302139    0.079236    0.010366    0.807584    
#> 375: 0.442650    0.871482    3.386600    0.302587    0.079267    0.010356    0.807497    
#> 376: 0.442665    0.871511    3.386645    0.302882    0.079186    0.010380    0.807338    
#> 377: 0.442699    0.871562    3.386671    0.303264    0.079118    0.010393    0.807293    
#> 378: 0.442695    0.871558    3.386629    0.303330    0.079111    0.010415    0.807279    
#> 379: 0.442708    0.871454    3.386661    0.303272    0.079031    0.010435    0.807244    
#> 380: 0.442584    0.871513    3.386625    0.303030    0.078967    0.010456    0.807274    
#> 381: 0.442527    0.871489    3.386585    0.303133    0.078972    0.010460    0.807151    
#> 382: 0.442473    0.871503    3.386575    0.303281    0.078915    0.010454    0.806956    
#> 383: 0.442479    0.871530    3.386590    0.303460    0.078868    0.010449    0.806826    
#> 384: 0.442405    0.871510    3.386611    0.303905    0.078842    0.010453    0.806789    
#> 385: 0.442482    0.871455    3.386650    0.304158    0.078812    0.010444    0.806760    
#> 386: 0.442607    0.871625    3.386733    0.304115    0.078802    0.010426    0.806815    
#> 387: 0.442730    0.871727    3.386822    0.303931    0.078742    0.010426    0.806844    
#> 388: 0.442852    0.871732    3.386895    0.303714    0.078782    0.010429    0.806921    
#> 389: 0.442984    0.871438    3.386989    0.303503    0.078799    0.010433    0.806957    
#> 390: 0.443010    0.871361    3.386968    0.303590    0.078831    0.010420    0.806981    
#> 391: 0.443082    0.871206    3.386980    0.303608    0.078856    0.010413    0.806984    
#> 392: 0.443244    0.871175    3.387037    0.303793    0.078890    0.010413    0.807039    
#> 393: 0.443269    0.871102    3.387043    0.303801    0.078925    0.010414    0.806962    
#> 394: 0.443151    0.871142    3.387018    0.303760    0.078945    0.010414    0.806933    
#> 395: 0.443307    0.871256    3.387016    0.303807    0.078924    0.010410    0.806866    
#> 396: 0.443543    0.871302    3.387052    0.303708    0.078903    0.010401    0.806859    
#> 397: 0.443599    0.871252    3.387105    0.303403    0.078817    0.010389    0.806921    
#> 398: 0.443745    0.871196    3.387136    0.303220    0.078752    0.010381    0.807020    
#> 399: 0.443625    0.871159    3.387162    0.302820    0.078738    0.010374    0.807138    
#> 400: 0.443685    0.871121    3.387212    0.302366    0.078767    0.010356    0.807211    
#> 401: 0.443743    0.871170    3.387281    0.302094    0.078797    0.010344    0.807336    
#> 402: 0.443807    0.871317    3.387297    0.301892    0.078880    0.010328    0.807437    
#> 403: 0.444058    0.871314    3.387329    0.301745    0.078951    0.010310    0.807514    
#> 404: 0.444291    0.871319    3.387341    0.301814    0.078941    0.010294    0.807500    
#> 405: 0.444224    0.871344    3.387393    0.301698    0.078856    0.010287    0.807660    
#> 406: 0.444394    0.871343    3.387453    0.301803    0.078800    0.010284    0.807927    
#> 407: 0.444411    0.871392    3.387497    0.301822    0.078824    0.010275    0.808013    
#> 408: 0.444631    0.871467    3.387534    0.301959    0.078909    0.010263    0.808069    
#> 409: 0.444702    0.871398    3.387503    0.302162    0.078930    0.010258    0.808047    
#> 410: 0.444610    0.871349    3.387444    0.302212    0.078908    0.010258    0.808128    
#> 411: 0.444693    0.871052    3.387496    0.302116    0.078832    0.010250    0.808264    
#> 412: 0.444749    0.871017    3.387508    0.302265    0.078820    0.010242    0.808201    
#> 413: 0.444723    0.871060    3.387445    0.302529    0.078799    0.010233    0.808235    
#> 414: 0.444496    0.871132    3.387436    0.302386    0.078844    0.010215    0.808195    
#> 415: 0.444572    0.871151    3.387423    0.302332    0.078858    0.010201    0.808202    
#> 416: 0.444833    0.871239    3.387459    0.302373    0.078953    0.010193    0.808130    
#> 417: 0.444842    0.871186    3.387465    0.302271    0.078975    0.010193    0.808113    
#> 418: 0.444597    0.871255    3.387445    0.302212    0.078958    0.010196    0.808103    
#> 419: 0.444638    0.871420    3.387442    0.302116    0.078943    0.010201    0.808060    
#> 420: 0.444858    0.871478    3.387471    0.302264    0.078924    0.010216    0.807969    
#> 421: 0.444786    0.871492    3.387476    0.302276    0.078855    0.010218    0.807939    
#> 422: 0.444899    0.871434    3.387464    0.302375    0.078802    0.010211    0.808051    
#> 423: 0.444996    0.871445    3.387410    0.302606    0.078802    0.010211    0.808118    
#> 424: 0.444864    0.871332    3.387383    0.302613    0.078759    0.010202    0.808163    
#> 425: 0.444756    0.871272    3.387386    0.302525    0.078745    0.010196    0.808321    
#> 426: 0.444693    0.871402    3.387352    0.302454    0.078797    0.010186    0.808371    
#> 427: 0.444602    0.871337    3.387350    0.302280    0.078815    0.010175    0.808332    
#> 428: 0.444511    0.871385    3.387371    0.302317    0.078849    0.010162    0.808295    
#> 429: 0.444485    0.871468    3.387380    0.302306    0.078850    0.010151    0.808255    
#> 430: 0.444394    0.871529    3.387345    0.302171    0.078782    0.010141    0.808263    
#> 431: 0.444306    0.871461    3.387282    0.302276    0.078766    0.010133    0.808217    
#> 432: 0.444245    0.871498    3.387251    0.302493    0.078756    0.010132    0.808122    
#> 433: 0.444304    0.871593    3.387239    0.302555    0.078695    0.010125    0.808239    
#> 434: 0.444087    0.871585    3.387217    0.302369    0.078644    0.010110    0.808305    
#> 435: 0.444002    0.871631    3.387183    0.302267    0.078631    0.010105    0.808289    
#> 436: 0.443849    0.871616    3.387164    0.302183    0.078664    0.010105    0.808264    
#> 437: 0.443820    0.871597    3.387114    0.302394    0.078709    0.010100    0.808276    
#> 438: 0.443717    0.871727    3.387095    0.302327    0.078719    0.010082    0.808235    
#> 439: 0.443624    0.871779    3.387046    0.302081    0.078694    0.010068    0.808184    
#> 440: 0.443508    0.871873    3.387038    0.301960    0.078706    0.010063    0.808196    
#> 441: 0.443364    0.871822    3.387005    0.301982    0.078637    0.010061    0.808108    
#> 442: 0.443132    0.871929    3.386985    0.302035    0.078597    0.010055    0.808044    
#> 443: 0.443027    0.871992    3.386939    0.301836    0.078584    0.010055    0.808021    
#> 444: 0.442914    0.872010    3.386862    0.301913    0.078514    0.010065    0.807979    
#> 445: 0.442853    0.872019    3.386810    0.301744    0.078551    0.010070    0.807952    
#> 446: 0.442670    0.872037    3.386774    0.301500    0.078532    0.010066    0.807951    
#> 447: 0.442794    0.871979    3.386806    0.301582    0.078573    0.010073    0.807870    
#> 448: 0.442943    0.871989    3.386865    0.301564    0.078547    0.010080    0.807810    
#> 449: 0.443051    0.872058    3.386949    0.301530    0.078538    0.010081    0.807812    
#> 450: 0.443055    0.872064    3.386986    0.301377    0.078579    0.010082    0.807788    
#> 451: 0.443163    0.872076    3.386990    0.301074    0.078605    0.010073    0.807772    
#> 452: 0.443228    0.872091    3.387021    0.300943    0.078627    0.010069    0.807755    
#> 453: 0.443273    0.872046    3.387030    0.300929    0.078573    0.010067    0.807694    
#> 454: 0.443308    0.872129    3.387028    0.301232    0.078526    0.010056    0.807589    
#> 455: 0.443420    0.872211    3.387001    0.301491    0.078623    0.010046    0.807553    
#> 456: 0.443352    0.872157    3.386979    0.301621    0.078641    0.010033    0.807559    
#> 457: 0.443350    0.872103    3.387029    0.301611    0.078671    0.010024    0.807482    
#> 458: 0.443412    0.872159    3.387082    0.301586    0.078729    0.010017    0.807420    
#> 459: 0.443328    0.872267    3.387123    0.301442    0.078744    0.010023    0.807366    
#> 460: 0.443322    0.872298    3.387118    0.301231    0.078732    0.010027    0.807382    
#> 461: 0.443315    0.872338    3.387150    0.300996    0.078721    0.010020    0.807466    
#> 462: 0.443274    0.872375    3.387185    0.300785    0.078728    0.010008    0.807566    
#> 463: 0.443222    0.872455    3.387182    0.300605    0.078746    0.010005    0.807607    
#> 464: 0.443284    0.872476    3.387180    0.300564    0.078769    0.010008    0.807593    
#> 465: 0.443356    0.872325    3.387194    0.300714    0.078772    0.009999    0.807592    
#> 466: 0.443453    0.872383    3.387189    0.300588    0.078745    0.009991    0.807601    
#> 467: 0.443440    0.872305    3.387206    0.300672    0.078718    0.009980    0.807572    
#> 468: 0.443610    0.872259    3.387220    0.300712    0.078713    0.009980    0.807601    
#> 469: 0.443675    0.872267    3.387246    0.300638    0.078681    0.009979    0.807643    
#> 470: 0.443581    0.872288    3.387237    0.300471    0.078635    0.009978    0.807693    
#> 471: 0.443342    0.872262    3.387195    0.300293    0.078618    0.009974    0.807702    
#> 472: 0.443217    0.872309    3.387157    0.300361    0.078603    0.009968    0.807758    
#> 473: 0.443072    0.872357    3.387120    0.300302    0.078558    0.009964    0.807783    
#> 474: 0.442966    0.872340    3.387098    0.300247    0.078513    0.009961    0.807874    
#> 475: 0.442988    0.872379    3.387069    0.300296    0.078478    0.009972    0.807811    
#> 476: 0.442956    0.872325    3.387052    0.300404    0.078486    0.009985    0.807830    
#> 477: 0.442843    0.872335    3.387066    0.300491    0.078506    0.009997    0.807734    
#> 478: 0.442776    0.872326    3.387047    0.300575    0.078576    0.010004    0.807760    
#> 479: 0.442744    0.872393    3.387025    0.300652    0.078567    0.010012    0.807788    
#> 480: 0.442781    0.872380    3.387039    0.300698    0.078613    0.010021    0.807746    
#> 481: 0.442880    0.872359    3.387064    0.300814    0.078625    0.010018    0.807727    
#> 482: 0.442929    0.872350    3.387046    0.300891    0.078644    0.010015    0.807774    
#> 483: 0.442929    0.872337    3.387044    0.300805    0.078636    0.010010    0.807770    
#> 484: 0.442897    0.872215    3.387045    0.300578    0.078664    0.010007    0.807822    
#> 485: 0.442949    0.872204    3.387075    0.300464    0.078625    0.010001    0.807940    
#> 486: 0.443067    0.872228    3.387124    0.300278    0.078590    0.009992    0.807943    
#> 487: 0.443204    0.872262    3.387176    0.300146    0.078591    0.009985    0.807919    
#> 488: 0.443243    0.872221    3.387247    0.299845    0.078604    0.009977    0.808020    
#> 489: 0.443380    0.872153    3.387279    0.299647    0.078572    0.009965    0.808167    
#> 490: 0.443415    0.872206    3.387312    0.299402    0.078602    0.009957    0.808253    
#> 491: 0.443431    0.872305    3.387391    0.299347    0.078590    0.009950    0.808296    
#> 492: 0.443476    0.872389    3.387390    0.299368    0.078591    0.009944    0.808421    
#> 493: 0.443472    0.872396    3.387378    0.299420    0.078588    0.009949    0.808461    
#> 494: 0.443527    0.872435    3.387335    0.299421    0.078559    0.009944    0.808402    
#> 495: 0.443552    0.872428    3.387357    0.299290    0.078579    0.009934    0.808404    
#> 496: 0.443608    0.872434    3.387329    0.299179    0.078566    0.009931    0.808463    
#> 497: 0.443575    0.872363    3.387348    0.298911    0.078556    0.009931    0.808531    
#> 498: 0.443505    0.872333    3.387329    0.298746    0.078548    0.009926    0.808526    
#> 499: 0.443507    0.872412    3.387283    0.298755    0.078551    0.009919    0.808531    
#> 500: 0.443437    0.872356    3.387247    0.298604    0.078590    0.009911    0.808486    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.300528    0.973332    3.443197    0.392401    0.073497    0.016800    1.598656    
#> 002: 0.418505    1.058982    3.472818    0.372781    0.069822    0.018404    1.110186    
#> 003: 0.538448    1.017886    3.494071    0.354142    0.066352    0.017484    0.839039    
#> 004: 0.546091    1.039797    3.512006    0.336435    0.063035    0.016610    0.737379    
#> 005: 0.560596    1.054183    3.500394    0.319613    0.068720    0.015780    0.689212    
#> 006: 0.571934    1.060913    3.493355    0.303633    0.065284    0.014991    0.663879    
#> 007: 0.525344    1.079834    3.484834    0.291968    0.062020    0.014241    0.668318    
#> 008: 0.512968    1.075491    3.482980    0.277369    0.063269    0.014010    0.675896    
#> 009: 0.492157    1.070768    3.479261    0.263501    0.065505    0.013309    0.670315    
#> 010: 0.501699    1.065239    3.481115    0.354284    0.065681    0.015027    0.662622    
#> 011: 0.555309    1.077459    3.486297    0.336570    0.062397    0.015071    0.676210    
#> 012: 0.558122    1.066463    3.488413    0.319742    0.063609    0.014317    0.647350    
#> 013: 0.500312    1.079834    3.472360    0.303755    0.067514    0.013602    0.655836    
#> 014: 0.547150    1.077164    3.486500    0.318324    0.066437    0.012921    0.666214    
#> 015: 0.597697    1.078989    3.503132    0.302408    0.063115    0.013763    0.651617    
#> 016: 0.570149    1.093161    3.502878    0.287288    0.069755    0.013075    0.663703    
#> 017: 0.569568    1.076008    3.513025    0.298049    0.066267    0.014731    0.660472    
#> 018: 0.587299    1.097404    3.486696    0.317255    0.062954    0.017418    0.654444    
#> 019: 0.496921    1.090032    3.474745    0.301392    0.059806    0.016547    0.653227    
#> 020: 0.552165    1.088487    3.488035    0.299684    0.058668    0.015720    0.672097    
#> 021: 0.557782    1.064274    3.509819    0.284700    0.069311    0.016209    0.645252    
#> 022: 0.563773    1.061031    3.506753    0.270465    0.068358    0.015398    0.629988    
#> 023: 0.618951    1.090924    3.512257    0.312427    0.075827    0.014629    0.655932    
#> 024: 0.585256    1.092530    3.507792    0.301864    0.072036    0.018451    0.643762    
#> 025: 0.574378    1.076362    3.499350    0.286771    0.072190    0.017528    0.656120    
#> 026: 0.544625    1.079507    3.495351    0.284641    0.068581    0.016652    0.662190    
#> 027: 0.562251    1.096885    3.491367    0.298217    0.070521    0.015819    0.672695    
#> 028: 0.564129    1.098221    3.497905    0.309457    0.066995    0.015028    0.653240    
#> 029: 0.602177    1.091410    3.498237    0.307712    0.074127    0.017172    0.672951    
#> 030: 0.617489    1.090407    3.508677    0.346657    0.070452    0.018900    0.665936    
#> 031: 0.559950    1.050242    3.511203    0.329324    0.069818    0.017955    0.669797    
#> 032: 0.512767    1.066591    3.509681    0.312858    0.069126    0.018859    0.661223    
#> 033: 0.560886    1.080546    3.503401    0.299076    0.065669    0.020399    0.670367    
#> 034: 0.585664    1.090570    3.507876    0.313528    0.062386    0.019379    0.669770    
#> 035: 0.561168    1.069719    3.498896    0.321197    0.059267    0.018410    0.657115    
#> 036: 0.539329    1.084730    3.491398    0.305137    0.056521    0.018526    0.678566    
#> 037: 0.529834    1.091714    3.497284    0.289880    0.061012    0.019870    0.666535    
#> 038: 0.583193    1.093006    3.490687    0.362236    0.064417    0.018876    0.661713    
#> 039: 0.592957    1.067113    3.504378    0.344124    0.061196    0.017933    0.648255    
#> 040: 0.597962    1.078081    3.511207    0.338940    0.061996    0.018473    0.649714    
#> 041: 0.544563    1.068517    3.494091    0.337879    0.058896    0.017549    0.662239    
#> 042: 0.623756    1.069904    3.502241    0.330295    0.057393    0.016672    0.667750    
#> 043: 0.540048    1.086319    3.486626    0.313780    0.054969    0.016542    0.653043    
#> 044: 0.540183    1.087046    3.491087    0.298091    0.053738    0.016191    0.646351    
#> 045: 0.524706    1.104146    3.482373    0.308682    0.051141    0.017561    0.653788    
#> 046: 0.519092    1.094398    3.485374    0.293248    0.060979    0.016683    0.644944    
#> 047: 0.514187    1.098360    3.481670    0.278585    0.062061    0.015848    0.650547    
#> 048: 0.535055    1.088548    3.482748    0.264656    0.067917    0.015056    0.657094    
#> 049: 0.533722    1.095831    3.493293    0.255252    0.065279    0.014733    0.669770    
#> 050: 0.592488    1.061827    3.498437    0.331658    0.070520    0.013996    0.688460    
#> 051: 0.580624    1.079209    3.486066    0.315075    0.077814    0.013296    0.681034    
#> 052: 0.588490    1.078226    3.503900    0.326300    0.073923    0.013077    0.652057    
#> 053: 0.560794    1.068262    3.495130    0.349017    0.072075    0.014398    0.668330    
#> 054: 0.533531    1.071712    3.510167    0.331566    0.068471    0.016458    0.684665    
#> 055: 0.578541    1.067101    3.509590    0.314988    0.065048    0.020315    0.681697    
#> 056: 0.575120    1.045386    3.515223    0.299238    0.065846    0.020571    0.682253    
#> 057: 0.578563    1.065123    3.515197    0.284276    0.068011    0.019542    0.677664    
#> 058: 0.582124    1.077967    3.508142    0.301548    0.071391    0.018565    0.661972    
#> 059: 0.577647    1.030287    3.518507    0.286470    0.067822    0.020843    0.681102    
#> 060: 0.627553    1.012759    3.530201    0.281590    0.064430    0.019801    0.697077    
#> 061: 0.625009    1.046490    3.524782    0.317476    0.063631    0.018811    0.712008    
#> 062: 0.624255    1.058702    3.532770    0.315778    0.060449    0.017870    0.708499    
#> 063: 0.651692    1.027406    3.530215    0.299989    0.074898    0.016977    0.705391    
#> 064: 0.619428    1.033458    3.534856    0.284990    0.071153    0.016128    0.687135    
#> 065: 0.659695    1.026417    3.520486    0.270740    0.077011    0.015322    0.686738    
#> 066: 0.590059    1.078649    3.512012    0.257203    0.073161    0.014555    0.666819    
#> 067: 0.600995    1.061165    3.505009    0.281502    0.069503    0.013828    0.659916    
#> 068: 0.564884    1.059524    3.527007    0.267427    0.066028    0.014753    0.681852    
#> 069: 0.586739    1.053228    3.518781    0.303987    0.062726    0.019578    0.652636    
#> 070: 0.599361    1.046676    3.517638    0.348012    0.059590    0.021919    0.655129    
#> 071: 0.550369    1.077855    3.486228    0.330611    0.056610    0.021419    0.680739    
#> 072: 0.541876    1.054381    3.497154    0.314080    0.053780    0.020348    0.662753    
#> 073: 0.558801    1.076604    3.502654    0.341399    0.051091    0.020339    0.656140    
#> 074: 0.529384    1.056545    3.497266    0.351415    0.048536    0.022908    0.658503    
#> 075: 0.548082    1.050668    3.513988    0.356716    0.060677    0.021763    0.635406    
#> 076: 0.601658    1.063875    3.523304    0.338880    0.057643    0.020674    0.651893    
#> 077: 0.619700    1.051226    3.524588    0.321936    0.061649    0.019641    0.662621    
#> 078: 0.624427    1.042568    3.519720    0.305839    0.058566    0.018659    0.646493    
#> 079: 0.608571    1.081274    3.518025    0.331363    0.057980    0.018867    0.667099    
#> 080: 0.623989    1.053295    3.515258    0.375340    0.055081    0.018976    0.662725    
#> 081: 0.615986    1.058969    3.511868    0.356573    0.052327    0.022572    0.642897    
#> 082: 0.596538    1.051689    3.508481    0.353195    0.049795    0.023002    0.642081    
#> 083: 0.590694    1.065523    3.507404    0.346506    0.056755    0.021852    0.652651    
#> 084: 0.556181    1.076742    3.491917    0.374391    0.060798    0.022015    0.646783    
#> 085: 0.550498    1.077971    3.503934    0.355671    0.057758    0.022919    0.656075    
#> 086: 0.569183    1.082087    3.506033    0.337888    0.072057    0.021773    0.665104    
#> 087: 0.568433    1.085838    3.489923    0.320993    0.071960    0.020685    0.680392    
#> 088: 0.504708    1.076440    3.495359    0.304944    0.068362    0.019650    0.663971    
#> 089: 0.537372    1.098542    3.488110    0.298985    0.064944    0.018668    0.677056    
#> 090: 0.538692    1.090250    3.482768    0.319346    0.061697    0.018193    0.657162    
#> 091: 0.555590    1.071623    3.483145    0.366580    0.058612    0.020548    0.634822    
#> 092: 0.552138    1.087678    3.477247    0.380400    0.066975    0.022075    0.647532    
#> 093: 0.532503    1.069339    3.491571    0.361380    0.063626    0.026166    0.666973    
#> 094: 0.578087    1.075943    3.501401    0.343311    0.072149    0.024858    0.667949    
#> 095: 0.569436    1.081630    3.506455    0.326145    0.068541    0.023615    0.648352    
#> 096: 0.540211    1.077929    3.499305    0.346179    0.065114    0.022434    0.639638    
#> 097: 0.577886    1.090363    3.493409    0.328870    0.063783    0.021313    0.633686    
#> 098: 0.571801    1.084072    3.503125    0.312427    0.062960    0.020247    0.641436    
#> 099: 0.581046    1.050443    3.499165    0.323523    0.063195    0.019235    0.643799    
#> 100: 0.535468    1.071762    3.490216    0.307346    0.060035    0.018273    0.657713    
#> 101: 0.519961    1.077865    3.475731    0.291979    0.063927    0.017359    0.656601    
#> 102: 0.525468    1.070725    3.478529    0.294128    0.060731    0.016491    0.670623    
#> 103: 0.570252    1.084764    3.488530    0.311630    0.057695    0.016904    0.655818    
#> 104: 0.544677    1.080168    3.493758    0.296241    0.060427    0.016971    0.663561    
#> 105: 0.540118    1.066882    3.493008    0.282090    0.062955    0.016122    0.668184    
#> 106: 0.552900    1.084808    3.485237    0.267986    0.069946    0.015316    0.646336    
#> 107: 0.566899    1.081294    3.497470    0.254587    0.074095    0.014550    0.660919    
#> 108: 0.555082    1.070548    3.507350    0.284215    0.076706    0.015327    0.657587    
#> 109: 0.540521    1.077848    3.504803    0.270004    0.087900    0.015028    0.661574    
#> 110: 0.592928    1.073868    3.498187    0.260296    0.083505    0.016892    0.637606    
#> 111: 0.575741    1.078599    3.500270    0.267927    0.079330    0.016437    0.633241    
#> 112: 0.541456    1.068533    3.492532    0.278253    0.075363    0.015615    0.650516    
#> 113: 0.539516    1.095656    3.492810    0.275892    0.071595    0.014834    0.642863    
#> 114: 0.549810    1.091358    3.490266    0.292018    0.069804    0.016590    0.646838    
#> 115: 0.534920    1.062197    3.483864    0.277417    0.066314    0.017271    0.671436    
#> 116: 0.551347    1.100086    3.484420    0.263546    0.062998    0.018512    0.670796    
#> 117: 0.511466    1.107849    3.488539    0.258429    0.074668    0.017587    0.675159    
#> 118: 0.550730    1.087406    3.496015    0.252673    0.070934    0.016707    0.668342    
#> 119: 0.568901    1.086339    3.493052    0.339064    0.067388    0.015872    0.654316    
#> 120: 0.516381    1.088226    3.489054    0.322110    0.064018    0.015458    0.649828    
#> 121: 0.521440    1.108081    3.490362    0.306005    0.064146    0.014685    0.674767    
#> 122: 0.571797    1.085434    3.503423    0.294420    0.060938    0.013951    0.671228    
#> 123: 0.590646    1.106189    3.493175    0.326167    0.059033    0.013254    0.674176    
#> 124: 0.537072    1.116536    3.490988    0.309859    0.064961    0.013200    0.662531    
#> 125: 0.514236    1.115825    3.482052    0.294366    0.069855    0.012540    0.658148    
#> 126: 0.521083    1.132705    3.467660    0.279647    0.079956    0.011913    0.662960    
#> 127: 0.538104    1.106419    3.475112    0.265665    0.082080    0.011317    0.690056    
#> 128: 0.523307    1.083195    3.500050    0.252382    0.077976    0.010751    0.685015    
#> 129: 0.568476    1.097975    3.503350    0.271067    0.074077    0.010432    0.675316    
#> 130: 0.570703    1.089291    3.501204    0.272665    0.074237    0.010029    0.660762    
#> 131: 0.570263    1.078866    3.490672    0.309629    0.070525    0.013846    0.662792    
#> 132: 0.546439    1.082572    3.485915    0.294148    0.066999    0.013941    0.662509    
#> 133: 0.528856    1.083109    3.489719    0.300104    0.063649    0.013478    0.658877    
#> 134: 0.546077    1.066207    3.491498    0.349858    0.060467    0.016078    0.640483    
#> 135: 0.550271    1.064667    3.489783    0.334672    0.062405    0.016885    0.648069    
#> 136: 0.567239    1.059556    3.494802    0.317939    0.068029    0.016479    0.653089    
#> 137: 0.579205    1.066173    3.503195    0.302042    0.072663    0.015656    0.663052    
#> 138: 0.540037    1.087015    3.494156    0.286940    0.069030    0.015083    0.654611    
#> 139: 0.529673    1.098725    3.500710    0.272593    0.065579    0.014329    0.669797    
#> 140: 0.523782    1.120480    3.486288    0.279837    0.063170    0.015149    0.673762    
#> 141: 0.528787    1.098923    3.490767    0.311991    0.079606    0.015470    0.654707    
#> 142: 0.574257    1.074286    3.508248    0.313150    0.086071    0.015026    0.665448    
#> 143: 0.568772    1.090966    3.512390    0.303943    0.081767    0.014274    0.661314    
#> 144: 0.596861    1.073108    3.524354    0.288746    0.077679    0.013561    0.649379    
#> 145: 0.570428    1.080856    3.504318    0.289636    0.073795    0.012883    0.639626    
#> 146: 0.558979    1.096258    3.503195    0.320313    0.070105    0.012238    0.654923    
#> 147: 0.539258    1.076999    3.501035    0.304297    0.066600    0.011626    0.650695    
#> 148: 0.543118    1.088239    3.507690    0.299519    0.063270    0.016888    0.639232    
#> 149: 0.537420    1.068049    3.493270    0.284543    0.060453    0.017109    0.653413    
#> 150: 0.559940    1.057085    3.486770    0.270316    0.065288    0.016402    0.673099    
#> 151: 0.520583    1.074189    3.496199    0.256800    0.062024    0.016125    0.676526    
#> 152: 0.544877    1.083885    3.495461    0.302355    0.055916    0.012621    0.664820    
#> 153: 0.562037    1.081647    3.509248    0.288110    0.057356    0.019304    0.659818    
#> 154: 0.606872    1.077912    3.521221    0.293104    0.060860    0.021530    0.660526    
#> 155: 0.574020    1.051499    3.511855    0.311914    0.052723    0.023219    0.649769    
#> 156: 0.599355    1.066984    3.515867    0.301522    0.057334    0.025196    0.661413    
#> 157: 0.578051    1.073338    3.512987    0.288396    0.052598    0.024056    0.660533    
#> 158: 0.586137    1.085821    3.508876    0.287795    0.048346    0.018724    0.651499    
#> 159: 0.551298    1.101511    3.505854    0.284528    0.050070    0.017139    0.655072    
#> 160: 0.596507    1.060227    3.520777    0.308148    0.044398    0.020564    0.657359    
#> 161: 0.563704    1.082175    3.506969    0.273590    0.048363    0.019495    0.660824    
#> 162: 0.557685    1.079243    3.496971    0.308312    0.043962    0.021501    0.652536    
#> 163: 0.590176    1.060958    3.496996    0.337070    0.046079    0.023887    0.652576    
#> 164: 0.561589    1.081146    3.492071    0.337927    0.052180    0.018929    0.661096    
#> 165: 0.594528    1.078187    3.496606    0.258385    0.053704    0.016900    0.676295    
#> 166: 0.562043    1.116038    3.491944    0.294534    0.050116    0.014841    0.681546    
#> 167: 0.582309    1.093951    3.508832    0.277708    0.065087    0.017262    0.664897    
#> 168: 0.597116    1.087038    3.511024    0.334058    0.061485    0.019962    0.656780    
#> 169: 0.585402    1.111520    3.503095    0.312149    0.062844    0.018446    0.659667    
#> 170: 0.592318    1.085394    3.513786    0.308733    0.059445    0.022538    0.639826    
#> 171: 0.583447    1.063549    3.504731    0.320519    0.048331    0.021588    0.646603    
#> 172: 0.570683    1.070061    3.504350    0.319095    0.052440    0.020481    0.637595    
#> 173: 0.587399    1.092779    3.490131    0.332492    0.051018    0.021931    0.635315    
#> 174: 0.592007    1.077764    3.507926    0.296512    0.047949    0.018747    0.663810    
#> 175: 0.567784    1.079780    3.504060    0.310656    0.047773    0.019446    0.664596    
#> 176: 0.550372    1.083650    3.514410    0.274574    0.054600    0.023061    0.654119    
#> 177: 0.598219    1.080322    3.517773    0.315126    0.048776    0.021311    0.662400    
#> 178: 0.576406    1.073719    3.505763    0.254300    0.062635    0.014501    0.664461    
#> 179: 0.550743    1.095446    3.497201    0.268460    0.065568    0.016940    0.664082    
#> 180: 0.538568    1.077820    3.492133    0.247655    0.063352    0.013587    0.653340    
#> 181: 0.519638    1.097306    3.484146    0.271680    0.051099    0.016769    0.652299    
#> 182: 0.506524    1.106895    3.475021    0.283464    0.069251    0.016649    0.669096    
#> 183: 0.535532    1.094133    3.486644    0.268322    0.063211    0.018806    0.669964    
#> 184: 0.531858    1.075351    3.497926    0.278876    0.070546    0.019693    0.664876    
#> 185: 0.493926    1.094981    3.484726    0.292194    0.069394    0.019785    0.646397    
#> 186: 0.514852    1.118632    3.488513    0.294830    0.060267    0.018704    0.653439    
#> 187: 0.533057    1.102156    3.482001    0.303018    0.065291    0.019503    0.647553    
#> 188: 0.502814    1.119292    3.475091    0.300867    0.067174    0.018590    0.643986    
#> 189: 0.525320    1.113276    3.490830    0.288345    0.058398    0.022116    0.654527    
#> 190: 0.532007    1.084661    3.500145    0.266914    0.054375    0.016483    0.660484    
#> 191: 0.517188    1.104773    3.487036    0.259871    0.061736    0.016756    0.651894    
#> 192: 0.513322    1.110693    3.481326    0.309542    0.064968    0.017275    0.646505    
#> 193: 0.564162    1.109858    3.484406    0.342546    0.066801    0.016976    0.643555    
#> 194: 0.538807    1.102130    3.476955    0.320065    0.056386    0.015659    0.654208    
#> 195: 0.529777    1.084581    3.484911    0.309272    0.044564    0.019343    0.648743    
#> 196: 0.549885    1.084732    3.496318    0.341593    0.053871    0.019804    0.655771    
#> 197: 0.543607    1.071407    3.512045    0.308390    0.046025    0.020935    0.668045    
#> 198: 0.587772    1.058222    3.508211    0.289844    0.057235    0.015126    0.657224    
#> 199: 0.575158    1.071037    3.507191    0.317057    0.045816    0.016656    0.652815    
#> 200: 0.575702    1.066725    3.508713    0.296387    0.053070    0.018085    0.651087    
#> 201: 0.578708    1.062448    3.509582    0.304374    0.053397    0.017310    0.651217    
#> 202: 0.570011    1.069745    3.506598    0.321464    0.050958    0.016897    0.656948    
#> 203: 0.578827    1.071226    3.505529    0.324167    0.053677    0.016995    0.658538    
#> 204: 0.574691    1.067232    3.506360    0.320352    0.055502    0.016493    0.662024    
#> 205: 0.571109    1.072444    3.505814    0.311619    0.056483    0.016835    0.665236    
#> 206: 0.574403    1.077261    3.507116    0.320004    0.056390    0.017255    0.667218    
#> 207: 0.570840    1.079111    3.505297    0.318806    0.057718    0.017202    0.665574    
#> 208: 0.569673    1.080191    3.505559    0.316393    0.058490    0.017567    0.664067    
#> 209: 0.571457    1.078582    3.505144    0.318259    0.059153    0.017783    0.662830    
#> 210: 0.570565    1.078113    3.504505    0.316416    0.059347    0.017818    0.661120    
#> 211: 0.573177    1.079904    3.504283    0.321035    0.060444    0.017756    0.659603    
#> 212: 0.573625    1.079830    3.504395    0.321353    0.060837    0.017558    0.659271    
#> 213: 0.574573    1.077121    3.504649    0.320686    0.061221    0.017317    0.661085    
#> 214: 0.576420    1.076707    3.504847    0.324861    0.061418    0.017248    0.661306    
#> 215: 0.577043    1.076554    3.505826    0.324451    0.061416    0.017343    0.660876    
#> 216: 0.580157    1.074450    3.506732    0.326905    0.061108    0.017652    0.661337    
#> 217: 0.581489    1.073967    3.507315    0.328583    0.060838    0.017846    0.660965    
#> 218: 0.581392    1.073834    3.507220    0.329974    0.060719    0.017756    0.660514    
#> 219: 0.581684    1.072166    3.507145    0.330051    0.059766    0.017991    0.659949    
#> 220: 0.580372    1.072596    3.507055    0.332155    0.059562    0.018246    0.659163    
#> 221: 0.579192    1.072937    3.506833    0.332749    0.059534    0.018276    0.658735    
#> 222: 0.580004    1.072677    3.506233    0.333927    0.059238    0.018428    0.658730    
#> 223: 0.580715    1.073323    3.505624    0.335453    0.058706    0.018651    0.658367    
#> 224: 0.581656    1.074674    3.505545    0.337916    0.058410    0.018823    0.657733    
#> 225: 0.580945    1.074250    3.505607    0.338006    0.057991    0.018918    0.657953    
#> 226: 0.580686    1.073513    3.505063    0.337979    0.057547    0.018922    0.657917    
#> 227: 0.579127    1.073366    3.504478    0.337038    0.057416    0.018921    0.657630    
#> 228: 0.577521    1.074217    3.503773    0.336605    0.056948    0.018899    0.657853    
#> 229: 0.576244    1.074432    3.503200    0.335611    0.056602    0.018872    0.657790    
#> 230: 0.576194    1.074333    3.503048    0.336241    0.056396    0.018896    0.657732    
#> 231: 0.575692    1.075005    3.502910    0.336751    0.056235    0.018916    0.657794    
#> 232: 0.573729    1.075574    3.502836    0.336797    0.056170    0.018905    0.658099    
#> 233: 0.572957    1.075412    3.502683    0.337579    0.055976    0.018971    0.658376    
#> 234: 0.571587    1.075327    3.502612    0.337446    0.055635    0.019144    0.658608    
#> 235: 0.571484    1.075067    3.502349    0.336774    0.055504    0.019296    0.658734    
#> 236: 0.570506    1.075170    3.501726    0.336454    0.055563    0.019394    0.659010    
#> 237: 0.570776    1.075060    3.501725    0.335641    0.055507    0.019441    0.659615    
#> 238: 0.571371    1.075147    3.501878    0.335585    0.055299    0.019608    0.660180    
#> 239: 0.570848    1.075808    3.501690    0.335316    0.055113    0.019625    0.660234    
#> 240: 0.570620    1.075870    3.501636    0.334276    0.055069    0.019574    0.660010    
#> 241: 0.571154    1.075465    3.501903    0.333798    0.055305    0.019618    0.659875    
#> 242: 0.570929    1.075105    3.501720    0.333404    0.055768    0.019621    0.660080    
#> 243: 0.569872    1.075245    3.501536    0.332846    0.056260    0.019581    0.660048    
#> 244: 0.569459    1.074768    3.501705    0.332407    0.056357    0.019556    0.660307    
#> 245: 0.569503    1.074306    3.501857    0.330998    0.056423    0.019466    0.660469    
#> 246: 0.569743    1.073718    3.501981    0.329685    0.056592    0.019465    0.660578    
#> 247: 0.569616    1.073273    3.502071    0.328181    0.056816    0.019413    0.660686    
#> 248: 0.569019    1.073856    3.501834    0.327134    0.056957    0.019359    0.660290    
#> 249: 0.568522    1.074011    3.501783    0.325741    0.057004    0.019305    0.660466    
#> 250: 0.569283    1.074476    3.501896    0.325771    0.057166    0.019319    0.660803    
#> 251: 0.569489    1.074783    3.501994    0.325318    0.057281    0.019325    0.661180    
#> 252: 0.569900    1.074717    3.502384    0.325556    0.057215    0.019336    0.661262    
#> 253: 0.569567    1.074868    3.502483    0.325619    0.056991    0.019422    0.661388    
#> 254: 0.569734    1.075123    3.502636    0.326583    0.056731    0.019532    0.661467    
#> 255: 0.570013    1.075374    3.502637    0.326981    0.056678    0.019573    0.661496    
#> 256: 0.569795    1.075344    3.502478    0.326273    0.056674    0.019668    0.661658    
#> 257: 0.569643    1.075274    3.502359    0.326251    0.056778    0.019658    0.661587    
#> 258: 0.569285    1.075034    3.502296    0.326154    0.056909    0.019610    0.661754    
#> 259: 0.568980    1.075118    3.502077    0.325404    0.056837    0.019590    0.661784    
#> 260: 0.568646    1.075376    3.502093    0.324903    0.056716    0.019583    0.661521    
#> 261: 0.568821    1.075330    3.502160    0.325266    0.056740    0.019575    0.661412    
#> 262: 0.568534    1.075607    3.501978    0.325309    0.056803    0.019518    0.661360    
#> 263: 0.567866    1.076093    3.501809    0.324381    0.056893    0.019495    0.661697    
#> 264: 0.567810    1.076213    3.501834    0.324093    0.057031    0.019455    0.661807    
#> 265: 0.568032    1.076377    3.501795    0.324194    0.057348    0.019375    0.661903    
#> 266: 0.568454    1.076264    3.501870    0.324697    0.057222    0.019344    0.661906    
#> 267: 0.568938    1.075936    3.502088    0.325865    0.057118    0.019303    0.662068    
#> 268: 0.569214    1.075645    3.502068    0.325989    0.056995    0.019333    0.662179    
#> 269: 0.569360    1.075431    3.502005    0.326426    0.056980    0.019354    0.662342    
#> 270: 0.569200    1.075700    3.501836    0.327235    0.056948    0.019385    0.662115    
#> 271: 0.569346    1.075761    3.501596    0.327442    0.056938    0.019353    0.661971    
#> 272: 0.569360    1.075570    3.501506    0.326391    0.056989    0.019336    0.662389    
#> 273: 0.569253    1.075870    3.501493    0.326282    0.057060    0.019304    0.662656    
#> 274: 0.569155    1.076235    3.501558    0.325482    0.057252    0.019215    0.662654    
#> 275: 0.568950    1.076408    3.501352    0.324831    0.057408    0.019147    0.662574    
#> 276: 0.568837    1.076518    3.501534    0.324314    0.057433    0.019137    0.662618    
#> 277: 0.568893    1.076665    3.501694    0.323643    0.057363    0.019171    0.662611    
#> 278: 0.569146    1.076660    3.501801    0.323774    0.057292    0.019197    0.662628    
#> 279: 0.568960    1.076541    3.501743    0.324358    0.057051    0.019254    0.662904    
#> 280: 0.568747    1.076536    3.501832    0.324140    0.056972    0.019295    0.662851    
#> 281: 0.568172    1.076833    3.501844    0.323988    0.056934    0.019283    0.662726    
#> 282: 0.568054    1.077125    3.501816    0.323798    0.057048    0.019300    0.662716    
#> 283: 0.567746    1.077285    3.501897    0.323580    0.057161    0.019325    0.662959    
#> 284: 0.567496    1.077194    3.501819    0.323160    0.057241    0.019333    0.662748    
#> 285: 0.567498    1.077267    3.501739    0.323000    0.057202    0.019362    0.662559    
#> 286: 0.567366    1.077225    3.501676    0.322938    0.057294    0.019422    0.662424    
#> 287: 0.566682    1.077280    3.501438    0.322548    0.057227    0.019442    0.662513    
#> 288: 0.566660    1.077269    3.501331    0.322313    0.057274    0.019473    0.662657    
#> 289: 0.566840    1.077156    3.501237    0.321957    0.057272    0.019454    0.662801    
#> 290: 0.567036    1.077075    3.501237    0.322178    0.057413    0.019436    0.663007    
#> 291: 0.567165    1.077289    3.501228    0.322316    0.057494    0.019378    0.662975    
#> 292: 0.566993    1.077432    3.501176    0.321966    0.057527    0.019321    0.663001    
#> 293: 0.566896    1.077461    3.501067    0.321552    0.057442    0.019289    0.662997    
#> 294: 0.566856    1.077548    3.501051    0.320996    0.057355    0.019261    0.662978    
#> 295: 0.566960    1.077190    3.501049    0.320886    0.057354    0.019268    0.662893    
#> 296: 0.567437    1.077046    3.501131    0.321023    0.057345    0.019284    0.662927    
#> 297: 0.567720    1.076979    3.501274    0.320871    0.057321    0.019321    0.662910    
#> 298: 0.567749    1.076755    3.501344    0.320592    0.057315    0.019330    0.662805    
#> 299: 0.568105    1.076839    3.501359    0.320823    0.057415    0.019310    0.662573    
#> 300: 0.568382    1.076663    3.501448    0.320792    0.057405    0.019333    0.662441    
#> 301: 0.568881    1.076448    3.501461    0.321221    0.057361    0.019326    0.662368    
#> 302: 0.569178    1.076331    3.501470    0.321362    0.057322    0.019323    0.662066    
#> 303: 0.568814    1.076357    3.501428    0.320835    0.057271    0.019316    0.661942    
#> 304: 0.568672    1.076572    3.501252    0.320767    0.057217    0.019313    0.661952    
#> 305: 0.568269    1.076366    3.501196    0.320193    0.057166    0.019313    0.661922    
#> 306: 0.567865    1.076119    3.501092    0.319829    0.057127    0.019295    0.661989    
#> 307: 0.567521    1.076003    3.500930    0.319652    0.057002    0.019301    0.662076    
#> 308: 0.567313    1.076015    3.500817    0.319631    0.056916    0.019284    0.662123    
#> 309: 0.567317    1.075789    3.500734    0.319654    0.056944    0.019281    0.662245    
#> 310: 0.567437    1.075782    3.500658    0.319789    0.056985    0.019267    0.662168    
#> 311: 0.567297    1.075724    3.500618    0.319482    0.057008    0.019243    0.662064    
#> 312: 0.566919    1.075634    3.500476    0.319347    0.057068    0.019209    0.662150    
#> 313: 0.566930    1.075437    3.500417    0.319466    0.057088    0.019226    0.662350    
#> 314: 0.566752    1.075458    3.500393    0.319895    0.057021    0.019260    0.662402    
#> 315: 0.566466    1.075478    3.500350    0.320499    0.056974    0.019294    0.662333    
#> 316: 0.566594    1.075489    3.500360    0.321002    0.056874    0.019313    0.662207    
#> 317: 0.566666    1.075532    3.500385    0.321348    0.056870    0.019298    0.662139    
#> 318: 0.566475    1.075499    3.500275    0.321318    0.056893    0.019278    0.662071    
#> 319: 0.566533    1.075504    3.500262    0.321368    0.056816    0.019246    0.662135    
#> 320: 0.566101    1.075562    3.500178    0.321148    0.056849    0.019191    0.662223    
#> 321: 0.565722    1.075635    3.500062    0.320734    0.056807    0.019176    0.662318    
#> 322: 0.565729    1.075729    3.499972    0.321152    0.056857    0.019158    0.662314    
#> 323: 0.565388    1.075882    3.499866    0.321422    0.056855    0.019163    0.662264    
#> 324: 0.565353    1.076061    3.499832    0.321867    0.056838    0.019188    0.662081    
#> 325: 0.565412    1.076279    3.499767    0.322230    0.056750    0.019173    0.661946    
#> 326: 0.565388    1.076153    3.499742    0.322134    0.056743    0.019164    0.661870    
#> 327: 0.565464    1.076104    3.499734    0.322596    0.056684    0.019182    0.661852    
#> 328: 0.565301    1.076219    3.499636    0.322350    0.056682    0.019154    0.661759    
#> 329: 0.565264    1.076253    3.499618    0.322055    0.056674    0.019125    0.661666    
#> 330: 0.564890    1.076357    3.499485    0.321577    0.056658    0.019102    0.661735    
#> 331: 0.564826    1.076535    3.499438    0.321133    0.056692    0.019065    0.661739    
#> 332: 0.564907    1.076478    3.499536    0.320972    0.056731    0.019055    0.661715    
#> 333: 0.564708    1.076484    3.499494    0.320786    0.056735    0.019053    0.661608    
#> 334: 0.564546    1.076336    3.499479    0.320583    0.056807    0.019034    0.661404    
#> 335: 0.564439    1.076282    3.499370    0.320674    0.056823    0.019011    0.661378    
#> 336: 0.564032    1.076408    3.499240    0.320950    0.056895    0.019038    0.661323    
#> 337: 0.563728    1.076774    3.499027    0.321239    0.057038    0.019048    0.661271    
#> 338: 0.563404    1.076960    3.498960    0.321320    0.057194    0.019041    0.661195    
#> 339: 0.563035    1.077130    3.498833    0.321044    0.057246    0.019032    0.661202    
#> 340: 0.562802    1.077052    3.498775    0.320936    0.057343    0.019034    0.661178    
#> 341: 0.562783    1.076932    3.498845    0.320741    0.057428    0.019010    0.661159    
#> 342: 0.562535    1.076830    3.498807    0.320208    0.057462    0.018989    0.661181    
#> 343: 0.562404    1.076851    3.498849    0.319941    0.057488    0.018981    0.661221    
#> 344: 0.562515    1.076791    3.498917    0.319780    0.057562    0.018974    0.661219    
#> 345: 0.562515    1.076738    3.499009    0.319437    0.057554    0.018967    0.661221    
#> 346: 0.562274    1.076818    3.498892    0.318985    0.057559    0.018937    0.661244    
#> 347: 0.562239    1.076858    3.498803    0.318761    0.057620    0.018907    0.661337    
#> 348: 0.561820    1.077024    3.498672    0.318221    0.057595    0.018876    0.661373    
#> 349: 0.561625    1.077152    3.498569    0.317926    0.057626    0.018845    0.661332    
#> 350: 0.561310    1.077125    3.498496    0.317801    0.057589    0.018827    0.661347    
#> 351: 0.561201    1.077204    3.498415    0.317858    0.057500    0.018840    0.661330    
#> 352: 0.560961    1.077246    3.498444    0.317659    0.057410    0.018878    0.661480    
#> 353: 0.561136    1.077375    3.498439    0.317550    0.057424    0.018864    0.661448    
#> 354: 0.560956    1.077419    3.498335    0.317207    0.057459    0.018859    0.661437    
#> 355: 0.561178    1.077319    3.498344    0.317106    0.057482    0.018846    0.661326    
#> 356: 0.561148    1.077252    3.498370    0.316830    0.057471    0.018846    0.661451    
#> 357: 0.561257    1.077290    3.498339    0.316657    0.057501    0.018811    0.661461    
#> 358: 0.561283    1.077323    3.498370    0.316423    0.057532    0.018802    0.661436    
#> 359: 0.561175    1.077421    3.498344    0.316358    0.057536    0.018796    0.661307    
#> 360: 0.561004    1.077498    3.498226    0.316323    0.057486    0.018809    0.661103    
#> 361: 0.560792    1.077586    3.498094    0.316262    0.057497    0.018815    0.660945    
#> 362: 0.560718    1.077642    3.497984    0.316215    0.057474    0.018810    0.660780    
#> 363: 0.560612    1.077670    3.497966    0.316168    0.057439    0.018829    0.660618    
#> 364: 0.560704    1.077697    3.497898    0.316413    0.057394    0.018854    0.660523    
#> 365: 0.560617    1.077690    3.497901    0.316396    0.057430    0.018877    0.660492    
#> 366: 0.560394    1.077787    3.497790    0.315950    0.057367    0.018885    0.660520    
#> 367: 0.560260    1.077822    3.497785    0.315671    0.057369    0.018875    0.660589    
#> 368: 0.560244    1.077882    3.497700    0.315523    0.057409    0.018854    0.660511    
#> 369: 0.560072    1.077864    3.497670    0.315421    0.057430    0.018839    0.660408    
#> 370: 0.559976    1.077894    3.497642    0.315319    0.057477    0.018848    0.660373    
#> 371: 0.559864    1.077930    3.497540    0.315109    0.057504    0.018837    0.660367    
#> 372: 0.559666    1.078053    3.497453    0.315087    0.057516    0.018834    0.660312    
#> 373: 0.559386    1.078270    3.497372    0.314823    0.057525    0.018840    0.660320    
#> 374: 0.559409    1.078354    3.497304    0.314764    0.057538    0.018828    0.660247    
#> 375: 0.559348    1.078441    3.497325    0.314674    0.057515    0.018834    0.660251    
#> 376: 0.559338    1.078507    3.497313    0.314524    0.057539    0.018819    0.660209    
#> 377: 0.559308    1.078578    3.497316    0.314219    0.057572    0.018804    0.660295    
#> 378: 0.559004    1.078666    3.497236    0.313862    0.057587    0.018795    0.660375    
#> 379: 0.558758    1.078485    3.497202    0.313466    0.057595    0.018787    0.660368    
#> 380: 0.558546    1.078387    3.497168    0.313296    0.057657    0.018766    0.660324    
#> 381: 0.558168    1.078417    3.497061    0.313347    0.057661    0.018761    0.660283    
#> 382: 0.557902    1.078495    3.497001    0.313309    0.057627    0.018759    0.660225    
#> 383: 0.557777    1.078540    3.496957    0.313206    0.057661    0.018729    0.660113    
#> 384: 0.557508    1.078615    3.496886    0.313104    0.057633    0.018701    0.660078    
#> 385: 0.557430    1.078698    3.496837    0.313177    0.057649    0.018665    0.660007    
#> 386: 0.557428    1.078829    3.496855    0.313025    0.057763    0.018641    0.659995    
#> 387: 0.557530    1.078942    3.496924    0.312969    0.057791    0.018621    0.659984    
#> 388: 0.557531    1.079075    3.496931    0.312822    0.057791    0.018609    0.659976    
#> 389: 0.557470    1.079097    3.496913    0.312578    0.057858    0.018585    0.660009    
#> 390: 0.557273    1.079258    3.496883    0.312131    0.057906    0.018586    0.660016    
#> 391: 0.557351    1.079272    3.496868    0.312019    0.057917    0.018593    0.659975    
#> 392: 0.557402    1.079280    3.496918    0.312306    0.057954    0.018598    0.660013    
#> 393: 0.557388    1.079159    3.496912    0.312225    0.057976    0.018593    0.660017    
#> 394: 0.557434    1.079179    3.496882    0.312277    0.057967    0.018577    0.659986    
#> 395: 0.557694    1.079295    3.496920    0.312125    0.057982    0.018565    0.660042    
#> 396: 0.557926    1.079238    3.496963    0.312015    0.058010    0.018572    0.660041    
#> 397: 0.557983    1.079212    3.497033    0.311742    0.058050    0.018587    0.660061    
#> 398: 0.558283    1.079160    3.497108    0.311682    0.058074    0.018605    0.660071    
#> 399: 0.558406    1.079143    3.497244    0.311691    0.058060    0.018629    0.659992    
#> 400: 0.558763    1.079069    3.497355    0.311846    0.058026    0.018646    0.659979    
#> 401: 0.558867    1.079103    3.497371    0.311793    0.058055    0.018647    0.660016    
#> 402: 0.558983    1.079246    3.497388    0.311777    0.058103    0.018646    0.660071    
#> 403: 0.559173    1.079263    3.497407    0.311815    0.058163    0.018633    0.659990    
#> 404: 0.559189    1.079269    3.497346    0.311770    0.058207    0.018621    0.659939    
#> 405: 0.559154    1.079290    3.497335    0.311585    0.058250    0.018604    0.659892    
#> 406: 0.559285    1.079280    3.497347    0.311464    0.058268    0.018588    0.659921    
#> 407: 0.559364    1.079273    3.497373    0.311501    0.058279    0.018568    0.659937    
#> 408: 0.559445    1.079321    3.497411    0.311414    0.058303    0.018557    0.660059    
#> 409: 0.559470    1.079261    3.497419    0.311318    0.058275    0.018539    0.660146    
#> 410: 0.559539    1.079308    3.497399    0.311476    0.058237    0.018542    0.660262    
#> 411: 0.559706    1.079222    3.497419    0.311819    0.058284    0.018540    0.660300    
#> 412: 0.559791    1.079217    3.497451    0.311702    0.058251    0.018539    0.660312    
#> 413: 0.559853    1.079171    3.497443    0.311666    0.058210    0.018525    0.660401    
#> 414: 0.559730    1.079210    3.497478    0.311884    0.058159    0.018554    0.660323    
#> 415: 0.559773    1.079229    3.497463    0.311829    0.058127    0.018552    0.660274    
#> 416: 0.559855    1.079254    3.497489    0.311699    0.058103    0.018543    0.660221    
#> 417: 0.559949    1.079279    3.497474    0.311780    0.058119    0.018542    0.660132    
#> 418: 0.559862    1.079271    3.497475    0.311795    0.058158    0.018544    0.660044    
#> 419: 0.559918    1.079313    3.497489    0.311830    0.058128    0.018550    0.659976    
#> 420: 0.560053    1.079251    3.497526    0.311843    0.058131    0.018549    0.659832    
#> 421: 0.560125    1.079162    3.497639    0.311787    0.058132    0.018560    0.659745    
#> 422: 0.560361    1.079009    3.497728    0.311916    0.058111    0.018561    0.659717    
#> 423: 0.560564    1.078886    3.497818    0.311888    0.058125    0.018565    0.659690    
#> 424: 0.560487    1.078854    3.497810    0.311672    0.058169    0.018542    0.659689    
#> 425: 0.560526    1.078879    3.497798    0.311771    0.058200    0.018533    0.659649    
#> 426: 0.560682    1.078925    3.497838    0.311910    0.058226    0.018538    0.659638    
#> 427: 0.560645    1.078897    3.497891    0.312178    0.058202    0.018544    0.659628    
#> 428: 0.560594    1.078890    3.497882    0.312379    0.058200    0.018565    0.659621    
#> 429: 0.560649    1.078814    3.497961    0.312473    0.058173    0.018582    0.659613    
#> 430: 0.560642    1.078786    3.497985    0.312316    0.058202    0.018589    0.659581    
#> 431: 0.560508    1.078785    3.497973    0.312214    0.058207    0.018594    0.659593    
#> 432: 0.560484    1.078819    3.497991    0.312108    0.058233    0.018604    0.659600    
#> 433: 0.560488    1.078931    3.498050    0.312081    0.058274    0.018612    0.659586    
#> 434: 0.560355    1.078920    3.498047    0.312027    0.058255    0.018618    0.659494    
#> 435: 0.560337    1.078941    3.498059    0.312011    0.058231    0.018619    0.659445    
#> 436: 0.560300    1.079005    3.498073    0.311952    0.058272    0.018611    0.659452    
#> 437: 0.560233    1.078940    3.498082    0.311879    0.058304    0.018612    0.659402    
#> 438: 0.560145    1.079008    3.498096    0.311811    0.058310    0.018613    0.659299    
#> 439: 0.560225    1.079074    3.498104    0.311861    0.058291    0.018613    0.659184    
#> 440: 0.560211    1.079078    3.498131    0.311783    0.058270    0.018602    0.659140    
#> 441: 0.560289    1.079118    3.498174    0.311950    0.058272    0.018597    0.659034    
#> 442: 0.560215    1.079130    3.498201    0.311874    0.058230    0.018592    0.658952    
#> 443: 0.560220    1.079130    3.498162    0.311858    0.058238    0.018596    0.658892    
#> 444: 0.560050    1.079224    3.498038    0.311840    0.058249    0.018592    0.658820    
#> 445: 0.559987    1.079270    3.497998    0.311900    0.058226    0.018589    0.658790    
#> 446: 0.559848    1.079348    3.497946    0.311915    0.058249    0.018592    0.658724    
#> 447: 0.559926    1.079429    3.497946    0.311857    0.058242    0.018593    0.658686    
#> 448: 0.559980    1.079453    3.497952    0.311810    0.058241    0.018594    0.658653    
#> 449: 0.560003    1.079435    3.498048    0.311718    0.058239    0.018604    0.658703    
#> 450: 0.560045    1.079416    3.498072    0.311638    0.058231    0.018598    0.658687    
#> 451: 0.560168    1.079410    3.498093    0.311656    0.058245    0.018604    0.658653    
#> 452: 0.560064    1.079479    3.498050    0.311685    0.058241    0.018610    0.658639    
#> 453: 0.559999    1.079492    3.498004    0.311762    0.058242    0.018594    0.658595    
#> 454: 0.559872    1.079570    3.497948    0.311641    0.058241    0.018577    0.658569    
#> 455: 0.559799    1.079608    3.497919    0.311600    0.058246    0.018554    0.658604    
#> 456: 0.559651    1.079615    3.497858    0.311525    0.058302    0.018548    0.658554    
#> 457: 0.559553    1.079669    3.497856    0.311432    0.058299    0.018546    0.658492    
#> 458: 0.559371    1.079815    3.497835    0.311352    0.058296    0.018548    0.658433    
#> 459: 0.559123    1.079946    3.497804    0.311249    0.058299    0.018547    0.658421    
#> 460: 0.558925    1.080023    3.497733    0.311251    0.058311    0.018549    0.658385    
#> 461: 0.558869    1.080083    3.497759    0.311301    0.058330    0.018571    0.658341    
#> 462: 0.558830    1.080159    3.497785    0.311295    0.058306    0.018585    0.658324    
#> 463: 0.558965    1.080201    3.497808    0.311215    0.058255    0.018592    0.658338    
#> 464: 0.559132    1.080195    3.497828    0.311139    0.058214    0.018592    0.658307    
#> 465: 0.559235    1.080078    3.497850    0.311081    0.058225    0.018587    0.658263    
#> 466: 0.559225    1.080083    3.497830    0.310992    0.058269    0.018579    0.658213    
#> 467: 0.559226    1.080048    3.497860    0.311001    0.058308    0.018577    0.658127    
#> 468: 0.559377    1.080056    3.497917    0.310862    0.058351    0.018566    0.658149    
#> 469: 0.559475    1.080165    3.497941    0.310837    0.058385    0.018553    0.658191    
#> 470: 0.559408    1.080230    3.497891    0.311045    0.058406    0.018559    0.658194    
#> 471: 0.559248    1.080231    3.497853    0.311108    0.058450    0.018555    0.658205    
#> 472: 0.559134    1.080240    3.497816    0.311032    0.058468    0.018541    0.658275    
#> 473: 0.559053    1.080228    3.497813    0.311049    0.058465    0.018536    0.658178    
#> 474: 0.558982    1.080211    3.497802    0.310962    0.058459    0.018534    0.658223    
#> 475: 0.559064    1.080299    3.497818    0.310987    0.058466    0.018522    0.658210    
#> 476: 0.559078    1.080318    3.497791    0.310957    0.058483    0.018514    0.658229    
#> 477: 0.559045    1.080290    3.497816    0.310873    0.058490    0.018503    0.658215    
#> 478: 0.559062    1.080217    3.497856    0.310855    0.058539    0.018491    0.658231    
#> 479: 0.559349    1.080192    3.497948    0.311135    0.058603    0.018480    0.658214    
#> 480: 0.559586    1.080169    3.498002    0.311167    0.058613    0.018475    0.658235    
#> 481: 0.559666    1.080152    3.498020    0.311363    0.058623    0.018472    0.658186    
#> 482: 0.559845    1.080122    3.498034    0.311601    0.058620    0.018478    0.658174    
#> 483: 0.559951    1.080032    3.498068    0.311670    0.058624    0.018482    0.658096    
#> 484: 0.560048    1.079875    3.498114    0.311764    0.058660    0.018477    0.658045    
#> 485: 0.560119    1.079863    3.498167    0.311757    0.058713    0.018474    0.658045    
#> 486: 0.560157    1.079853    3.498213    0.311769    0.058754    0.018472    0.658014    
#> 487: 0.560351    1.079862    3.498283    0.311845    0.058768    0.018462    0.657987    
#> 488: 0.560367    1.079831    3.498329    0.311972    0.058800    0.018462    0.657934    
#> 489: 0.560457    1.079758    3.498361    0.311984    0.058802    0.018462    0.657886    
#> 490: 0.560652    1.079738    3.498440    0.312036    0.058782    0.018460    0.657901    
#> 491: 0.560795    1.079727    3.498481    0.312036    0.058782    0.018451    0.657859    
#> 492: 0.560800    1.079744    3.498479    0.312092    0.058772    0.018446    0.657936    
#> 493: 0.560651    1.079747    3.498477    0.311963    0.058763    0.018448    0.657980    
#> 494: 0.560753    1.079818    3.498474    0.311938    0.058743    0.018459    0.658006    
#> 495: 0.560891    1.079845    3.498487    0.312039    0.058722    0.018472    0.657980    
#> 496: 0.561035    1.079899    3.498487    0.312191    0.058703    0.018497    0.657994    
#> 497: 0.560994    1.079934    3.498450    0.312215    0.058683    0.018503    0.657982    
#> 498: 0.560950    1.079952    3.498394    0.312273    0.058663    0.018503    0.657905    
#> 499: 0.560879    1.080038    3.498324    0.312277    0.058687    0.018496    0.657853    
#> 500: 0.560821    1.080028    3.498267    0.312237    0.058715    0.018493    0.657868    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.246821    0.974716    3.449684    0.392401    0.078377    0.016800    1.789614    
#> 002: 0.117614    1.052888    3.500593    0.372781    0.074458    0.016901    1.138322    
#> 003: 0.185205    1.007861    3.523991    0.354142    0.070735    0.016056    0.915193    
#> 004: 0.127021    1.058058    3.507139    0.336435    0.067199    0.015254    0.851832    
#> 005: 0.165959    1.091401    3.486194    0.319613    0.063839    0.014491    0.790317    
#> 006: 0.129801    1.110772    3.475455    0.303633    0.060647    0.016300    0.755636    
#> 007: 0.069702    1.125717    3.464623    0.288451    0.057614    0.015863    0.752652    
#> 008: 0.059672    1.109789    3.456369    0.274029    0.054734    0.017504    0.749026    
#> 009: 0.024715    1.105858    3.442303    0.260327    0.051997    0.017419    0.741215    
#> 010: 0.065347    1.091735    3.454279    0.247311    0.049397    0.021505    0.762797    
#> 011: 0.097555    1.106983    3.459006    0.234945    0.046927    0.020545    0.758720    
#> 012: 0.084447    1.111947    3.456317    0.223198    0.044581    0.023285    0.738113    
#> 013: 0.029641    1.112832    3.445429    0.212038    0.042352    0.025627    0.741168    
#> 014: 0.089732    1.102666    3.459233    0.201436    0.040234    0.031325    0.754309    
#> 015: 0.095582    1.125321    3.463454    0.191364    0.038223    0.034123    0.729472    
#> 016: 0.108420    1.117972    3.482803    0.181796    0.036311    0.032417    0.738526    
#> 017: 0.110611    1.120816    3.476945    0.172706    0.034496    0.031299    0.731342    
#> 018: 0.120153    1.117562    3.453152    0.164071    0.036203    0.030009    0.747923    
#> 019: 0.022295    1.115370    3.445971    0.155867    0.034393    0.030283    0.729226    
#> 020: 0.062871    1.110867    3.450968    0.148074    0.032673    0.029372    0.764091    
#> 021: 0.063690    1.109588    3.458811    0.140670    0.031040    0.027903    0.728631    
#> 022: 0.063960    1.099384    3.467950    0.133637    0.029488    0.026508    0.722756    
#> 023: 0.138318    1.105130    3.475959    0.138069    0.028013    0.025183    0.725068    
#> 024: 0.137077    1.134401    3.474447    0.131165    0.028412    0.025210    0.733324    
#> 025: 0.088466    1.132886    3.470511    0.124607    0.027991    0.027980    0.724862    
#> 026: 0.072489    1.150854    3.451837    0.118377    0.026591    0.026581    0.744227    
#> 027: 0.064202    1.140887    3.455899    0.112458    0.025262    0.030139    0.737647    
#> 028: 0.096712    1.128618    3.460880    0.107471    0.025931    0.028632    0.722610    
#> 029: 0.114982    1.120910    3.463222    0.106060    0.025381    0.030468    0.731259    
#> 030: 0.102962    1.140161    3.457999    0.103786    0.024112    0.032131    0.738384    
#> 031: 0.089945    1.133187    3.457557    0.119138    0.022906    0.032592    0.726028    
#> 032: 0.052495    1.130804    3.457095    0.129848    0.021772    0.030962    0.730075    
#> 033: 0.060730    1.149579    3.455694    0.123355    0.028282    0.029414    0.729731    
#> 034: 0.091095    1.156045    3.442105    0.117187    0.026868    0.027943    0.747309    
#> 035: 0.036855    1.127697    3.444206    0.121988    0.025524    0.030010    0.721998    
#> 036: 0.031552    1.127516    3.439516    0.118926    0.026200    0.028510    0.723045    
#> 037: 0.040703    1.146850    3.445795    0.112980    0.028309    0.027084    0.729284    
#> 038: 0.086911    1.145276    3.447657    0.108269    0.027121    0.025730    0.729240    
#> 039: 0.070524    1.134166    3.459750    0.112180    0.033401    0.024443    0.736229    
#> 040: 0.029435    1.124602    3.453685    0.126395    0.031731    0.023221    0.740171    
#> 041: 0.044479    1.108643    3.460254    0.121838    0.030144    0.022060    0.734816    
#> 042: 0.110414    1.098116    3.463603    0.115746    0.028637    0.027615    0.721057    
#> 043: 0.075960    1.123192    3.451749    0.109959    0.027205    0.026234    0.722391    
#> 044: 0.067612    1.135119    3.465594    0.104461    0.025845    0.033131    0.713407    
#> 045: 0.038995    1.156245    3.439217    0.099303    0.027534    0.031527    0.728728    
#> 046: 0.073940    1.146364    3.454260    0.095368    0.026157    0.033818    0.754438    
#> 047: 0.118982    1.127919    3.463095    0.097110    0.028576    0.035167    0.727305    
#> 048: 0.109805    1.108542    3.473334    0.092658    0.042323    0.037454    0.752968    
#> 049: 0.078692    1.107976    3.483690    0.094792    0.040207    0.035582    0.774524    
#> 050: 0.133645    1.078189    3.485484    0.090298    0.045149    0.033802    0.767208    
#> 051: 0.143891    1.096334    3.483486    0.109766    0.043688    0.032112    0.754061    
#> 052: 0.109291    1.106535    3.485152    0.104277    0.041503    0.030507    0.736522    
#> 053: 0.130232    1.088927    3.474554    0.099064    0.039428    0.028981    0.750618    
#> 054: 0.104367    1.096089    3.472656    0.104801    0.037457    0.028461    0.738938    
#> 055: 0.110366    1.129731    3.473094    0.099561    0.035733    0.027927    0.729247    
#> 056: 0.113418    1.104284    3.476254    0.094583    0.033946    0.031477    0.736212    
#> 057: 0.102234    1.097895    3.480845    0.089854    0.033810    0.031565    0.755810    
#> 058: 0.080067    1.111603    3.454970    0.085361    0.036691    0.029987    0.741744    
#> 059: 0.068710    1.102822    3.462809    0.094765    0.040417    0.028487    0.742003    
#> 060: 0.103071    1.096632    3.481817    0.099624    0.038396    0.032127    0.738920    
#> 061: 0.125173    1.084806    3.487806    0.127528    0.036476    0.033265    0.748073    
#> 062: 0.126030    1.111056    3.494840    0.121152    0.043184    0.034490    0.755149    
#> 063: 0.124095    1.084344    3.473454    0.120306    0.041025    0.032765    0.767156    
#> 064: 0.119189    1.100032    3.490652    0.116767    0.038973    0.033628    0.758293    
#> 065: 0.131250    1.091430    3.491476    0.110929    0.037025    0.033233    0.759826    
#> 066: 0.157330    1.080040    3.500352    0.105382    0.035174    0.031572    0.728314    
#> 067: 0.153498    1.095476    3.495365    0.100113    0.033415    0.033241    0.732500    
#> 068: 0.086297    1.110312    3.478996    0.125988    0.031744    0.031579    0.742530    
#> 069: 0.092938    1.116254    3.463884    0.119689    0.030157    0.030000    0.738143    
#> 070: 0.106415    1.122312    3.482009    0.113704    0.031677    0.030690    0.738093    
#> 071: 0.099918    1.140652    3.459874    0.108019    0.030093    0.029156    0.765443    
#> 072: 0.050466    1.106737    3.464399    0.102618    0.032727    0.027698    0.770405    
#> 073: 0.085700    1.135340    3.469925    0.103192    0.034297    0.026313    0.742296    
#> 074: 0.062737    1.124256    3.455695    0.098032    0.040307    0.024998    0.733821    
#> 075: 0.093803    1.113067    3.486973    0.101513    0.038292    0.026174    0.723656    
#> 076: 0.112855    1.114309    3.490364    0.096438    0.036377    0.028540    0.737817    
#> 077: 0.105792    1.113785    3.473530    0.091616    0.034558    0.030026    0.733217    
#> 078: 0.117692    1.116181    3.477841    0.087035    0.032831    0.028525    0.728006    
#> 079: 0.132081    1.134931    3.483572    0.109640    0.036149    0.030663    0.732399    
#> 080: 0.132931    1.111160    3.492139    0.118865    0.035796    0.032761    0.738432    
#> 081: 0.086641    1.121963    3.472529    0.112922    0.034006    0.031123    0.711855    
#> 082: 0.083913    1.113431    3.458210    0.107276    0.032306    0.029567    0.730293    
#> 083: 0.101463    1.107748    3.471688    0.101912    0.030691    0.028088    0.737523    
#> 084: 0.063200    1.104982    3.460957    0.096817    0.029305    0.026684    0.724277    
#> 085: 0.046070    1.123561    3.457149    0.091976    0.027840    0.025350    0.750966    
#> 086: 0.046730    1.117798    3.453651    0.087377    0.026448    0.030234    0.738493    
#> 087: 0.034822    1.106966    3.447753    0.083008    0.025125    0.038244    0.749263    
#> 088: 0.023251    1.104210    3.449669    0.123155    0.023869    0.036747    0.733233    
#> 089: 0.073122    1.114582    3.444605    0.116997    0.022676    0.035799    0.727168    
#> 090: 0.053483    1.112319    3.444358    0.111844    0.021542    0.034009    0.728430    
#> 091: 0.045330    1.100685    3.436229    0.106252    0.020465    0.032309    0.753117    
#> 092: 0.042213    1.121463    3.440486    0.101221    0.021004    0.030807    0.736917    
#> 093: 0.026771    1.116118    3.440709    0.096160    0.023893    0.029267    0.752893    
#> 094: 0.024034    1.136430    3.437977    0.091352    0.026163    0.027804    0.739283    
#> 095: 0.060099    1.129544    3.450943    0.090072    0.026830    0.030392    0.748657    
#> 096: 0.021850    1.160166    3.434079    0.089926    0.026461    0.028872    0.736469    
#> 097: 0.052124    1.155981    3.443274    0.085430    0.028622    0.027429    0.738911    
#> 098: 0.041630    1.157378    3.450963    0.081871    0.027564    0.026057    0.770895    
#> 099: 0.031900    1.145594    3.426271    0.103041    0.030699    0.024755    0.752724    
#> 100: 0.043698    1.137705    3.442757    0.104083    0.032843    0.023517    0.755699    
#> 101: 0.043534    1.124736    3.429743    0.114405    0.031615    0.022341    0.725858    
#> 102: 0.031273    1.122784    3.423617    0.108685    0.030197    0.021224    0.746543    
#> 103: 0.096292    1.124296    3.450942    0.120095    0.030294    0.020163    0.720774    
#> 104: 0.079230    1.131096    3.464031    0.114091    0.034010    0.019155    0.721648    
#> 105: 0.064614    1.125945    3.457689    0.108386    0.039872    0.018197    0.726922    
#> 106: 0.073558    1.147388    3.441766    0.102967    0.037878    0.019680    0.731918    
#> 107: 0.107657    1.161029    3.447456    0.108949    0.035985    0.020554    0.745989    
#> 108: 0.087253    1.145379    3.452972    0.104876    0.034185    0.019549    0.750024    
#> 109: 0.056881    1.121610    3.463085    0.101270    0.035252    0.023571    0.731073    
#> 110: 0.049802    1.118931    3.440925    0.123428    0.035097    0.022393    0.714878    
#> 111: 0.062511    1.133037    3.448667    0.117257    0.033342    0.021273    0.713045    
#> 112: 0.047215    1.115159    3.439162    0.113114    0.035014    0.020680    0.719443    
#> 113: 0.061772    1.135914    3.445872    0.107458    0.035260    0.020104    0.714778    
#> 114: 0.084905    1.124073    3.457909    0.113179    0.033497    0.020245    0.731677    
#> 115: 0.086635    1.109986    3.452194    0.107520    0.032539    0.019233    0.754574    
#> 116: 0.087948    1.122808    3.455825    0.116199    0.030912    0.026789    0.745212    
#> 117: 0.070422    1.141357    3.464069    0.110389    0.029367    0.028029    0.728308    
#> 118: 0.072287    1.141777    3.457617    0.104869    0.027898    0.030326    0.731951    
#> 119: 0.080925    1.137507    3.456637    0.104245    0.037524    0.028810    0.730944    
#> 120: 0.051782    1.128658    3.447705    0.099841    0.035648    0.027369    0.726285    
#> 121: 0.042523    1.150956    3.442364    0.094849    0.033865    0.031453    0.733307    
#> 122: 0.057325    1.111011    3.461894    0.093760    0.032172    0.029881    0.733619    
#> 123: 0.097822    1.125844    3.462105    0.089072    0.030563    0.029935    0.721249    
#> 124: 0.117138    1.128268    3.472049    0.106802    0.029035    0.028948    0.728804    
#> 125: 0.132282    1.125820    3.471907    0.101462    0.027583    0.033345    0.739920    
#> 126: 0.079860    1.140468    3.443717    0.096389    0.026204    0.032903    0.752769    
#> 127: 0.087299    1.124612    3.455072    0.092504    0.024894    0.031257    0.753878    
#> 128: 0.082182    1.114295    3.481179    0.094201    0.025146    0.031944    0.733377    
#> 129: 0.101051    1.125302    3.475032    0.117169    0.028926    0.031875    0.721742    
#> 130: 0.113084    1.118769    3.469556    0.116144    0.027480    0.034746    0.701775    
#> 131: 0.083537    1.113441    3.458009    0.115616    0.027406    0.033009    0.720494    
#> 132: 0.031110    1.122412    3.428788    0.110982    0.026036    0.031358    0.753215    
#> 133: 0.054490    1.108025    3.446617    0.105433    0.024734    0.029790    0.753111    
#> 134: 0.124104    1.085484    3.485902    0.100161    0.024753    0.028301    0.752533    
#> 135: 0.076214    1.086930    3.477547    0.105755    0.030479    0.026886    0.752777    
#> 136: 0.077198    1.084614    3.468628    0.100467    0.033762    0.025542    0.733893    
#> 137: 0.106554    1.083493    3.479261    0.103141    0.032074    0.030917    0.743173    
#> 138: 0.079626    1.108981    3.462657    0.097984    0.030470    0.029371    0.739850    
#> 139: 0.100882    1.133249    3.478857    0.093084    0.028947    0.027903    0.728973    
#> 140: 0.120196    1.146295    3.475215    0.098741    0.030253    0.026508    0.751553    
#> 141: 0.090009    1.111670    3.482757    0.099378    0.028740    0.026852    0.727224    
#> 142: 0.124439    1.091636    3.483913    0.108802    0.027303    0.025524    0.727843    
#> 143: 0.087835    1.095718    3.477225    0.116139    0.027354    0.032213    0.708353    
#> 144: 0.130020    1.106895    3.486186    0.111843    0.025987    0.030603    0.717931    
#> 145: 0.089392    1.118401    3.459657    0.118093    0.024687    0.032531    0.721067    
#> 146: 0.061715    1.123782    3.468838    0.112189    0.023453    0.037123    0.749024    
#> 147: 0.065129    1.110722    3.463222    0.106579    0.022280    0.037257    0.740562    
#> 148: 0.081773    1.109830    3.476881    0.106146    0.021166    0.037123    0.750218    
#> 149: 0.078035    1.122001    3.455365    0.100839    0.020108    0.035267    0.750165    
#> 150: 0.088293    1.133204    3.441352    0.110210    0.020776    0.033504    0.738628    
#> 151: 0.050103    1.133962    3.445422    0.104699    0.019737    0.031828    0.735601    
#> 152: 0.053729    1.123898    3.456054    0.099101    0.020733    0.025987    0.734966    
#> 153: 0.074969    1.130892    3.468756    0.129007    0.026074    0.029838    0.749047    
#> 154: 0.098638    1.138919    3.462382    0.100543    0.024425    0.031845    0.739578    
#> 155: 0.076603    1.118988    3.455317    0.094541    0.024645    0.024078    0.735042    
#> 156: 0.075958    1.113090    3.456772    0.113876    0.028339    0.030572    0.732196    
#> 157: 0.087153    1.104108    3.478709    0.136627    0.033081    0.025879    0.740858    
#> 158: 0.117060    1.127037    3.469475    0.133675    0.034711    0.026292    0.722297    
#> 159: 0.072721    1.126184    3.480240    0.129619    0.035713    0.024137    0.740527    
#> 160: 0.118653    1.106841    3.489627    0.111022    0.037962    0.025200    0.744491    
#> 161: 0.092359    1.130853    3.475969    0.119852    0.042361    0.022399    0.726778    
#> 162: 0.079931    1.133562    3.449997    0.129618    0.033985    0.023333    0.725575    
#> 163: 0.112992    1.114718    3.445712    0.135821    0.027183    0.020619    0.724304    
#> 164: 0.088129    1.125579    3.462975    0.108864    0.032287    0.023307    0.727422    
#> 165: 0.106134    1.138434    3.469863    0.116544    0.031348    0.028293    0.719088    
#> 166: 0.100176    1.148833    3.453556    0.107490    0.036313    0.021564    0.736617    
#> 167: 0.091508    1.141077    3.470811    0.092270    0.028161    0.021745    0.751535    
#> 168: 0.102446    1.152078    3.466734    0.105250    0.030872    0.020669    0.729342    
#> 169: 0.049731    1.178448    3.440167    0.114833    0.032048    0.021041    0.741243    
#> 170: 0.080585    1.142811    3.448535    0.118090    0.027830    0.022807    0.720870    
#> 171: 0.067556    1.147944    3.461301    0.095919    0.030667    0.021168    0.719805    
#> 172: 0.077447    1.149291    3.459221    0.079737    0.018237    0.026219    0.731277    
#> 173: 0.070366    1.155168    3.454630    0.089977    0.024635    0.025710    0.726355    
#> 174: 0.062192    1.150058    3.459275    0.086633    0.021676    0.029391    0.734786    
#> 175: 0.066486    1.150626    3.443572    0.102666    0.032156    0.026726    0.733475    
#> 176: 0.071724    1.127059    3.468750    0.098987    0.031002    0.027581    0.727444    
#> 177: 0.058432    1.131306    3.461763    0.097224    0.027299    0.027938    0.729122    
#> 178: 0.059955    1.126361    3.461802    0.084747    0.033274    0.028148    0.729359    
#> 179: 0.099522    1.123842    3.465141    0.068959    0.033922    0.027506    0.750824    
#> 180: 0.090815    1.127686    3.473956    0.061028    0.036843    0.030653    0.755588    
#> 181: 0.078168    1.110730    3.447821    0.052508    0.032476    0.031914    0.763070    
#> 182: 0.038932    1.133008    3.441672    0.044346    0.041777    0.034023    0.760304    
#> 183: 0.036274    1.144057    3.441005    0.044664    0.031283    0.026732    0.759740    
#> 184: 0.050652    1.119389    3.451046    0.054235    0.026734    0.023581    0.757000    
#> 185: 0.022650    1.133341    3.452382    0.053122    0.028136    0.026729    0.757171    
#> 186: 0.053331    1.143224    3.452999    0.045759    0.027785    0.033517    0.747491    
#> 187: 0.066616    1.125107    3.465511    0.062883    0.023913    0.027000    0.751684    
#> 188: 0.060248    1.153899    3.447454    0.070250    0.027127    0.025575    0.767302    
#> 189: 0.097990    1.145001    3.470290    0.084951    0.024585    0.027645    0.762560    
#> 190: 0.092430    1.123151    3.466630    0.083183    0.018981    0.025803    0.740948    
#> 191: 0.076738    1.125141    3.457182    0.073710    0.017718    0.025312    0.747464    
#> 192: 0.052968    1.131177    3.452050    0.086412    0.020109    0.026499    0.742486    
#> 193: 0.077568    1.135213    3.461213    0.109214    0.016765    0.025120    0.727650    
#> 194: 0.045704    1.129103    3.442947    0.102675    0.023724    0.027056    0.741902    
#> 195: 0.043591    1.144633    3.434910    0.086790    0.025031    0.029145    0.743347    
#> 196: 0.053753    1.137166    3.461361    0.080164    0.031283    0.031880    0.753978    
#> 197: 0.057963    1.147456    3.481347    0.069014    0.024327    0.034398    0.766825    
#> 198: 0.082793    1.128710    3.466025    0.072024    0.021035    0.032240    0.734863    
#> 199: 0.062281    1.117294    3.466221    0.088518    0.020704    0.034093    0.731029    
#> 200: 0.058256    1.117392    3.465630    0.093191    0.020434    0.033609    0.734635    
#> 201: 0.060192    1.109911    3.470520    0.082295    0.018407    0.033274    0.740638    
#> 202: 0.068656    1.109792    3.473335    0.082649    0.018233    0.033675    0.737634    
#> 203: 0.089326    1.103425    3.476131    0.085890    0.017413    0.035570    0.739458    
#> 204: 0.103029    1.096081    3.479025    0.090785    0.016689    0.035796    0.738942    
#> 205: 0.108329    1.095136    3.481221    0.095615    0.016632    0.036559    0.741370    
#> 206: 0.103776    1.097720    3.480410    0.096731    0.016734    0.036470    0.742588    
#> 207: 0.098344    1.097512    3.478227    0.098211    0.016829    0.035901    0.741896    
#> 208: 0.096560    1.096984    3.477083    0.099338    0.016675    0.035532    0.740504    
#> 209: 0.098471    1.096602    3.475799    0.100183    0.016698    0.034988    0.739912    
#> 210: 0.100129    1.097267    3.476053    0.099491    0.016232    0.034489    0.739803    
#> 211: 0.100787    1.098763    3.477453    0.098798    0.016470    0.034280    0.739750    
#> 212: 0.099911    1.100217    3.477593    0.099247    0.016600    0.034601    0.739218    
#> 213: 0.101128    1.099515    3.477422    0.099065    0.017005    0.034330    0.739962    
#> 214: 0.104630    1.099733    3.477717    0.099898    0.017118    0.034165    0.741276    
#> 215: 0.105058    1.100479    3.477975    0.099252    0.017210    0.033780    0.742193    
#> 216: 0.105659    1.099661    3.478238    0.099666    0.017412    0.033356    0.744453    
#> 217: 0.104228    1.100022    3.478024    0.100159    0.017273    0.033340    0.743622    
#> 218: 0.103554    1.101350    3.476742    0.101523    0.017416    0.033127    0.743167    
#> 219: 0.104249    1.101539    3.476306    0.101968    0.017541    0.032861    0.743144    
#> 220: 0.105044    1.102120    3.476813    0.101751    0.017545    0.032671    0.743602    
#> 221: 0.105112    1.102215    3.476375    0.102450    0.017598    0.032439    0.743493    
#> 222: 0.105150    1.102020    3.476042    0.102843    0.017595    0.032193    0.743128    
#> 223: 0.105928    1.102373    3.475970    0.103003    0.017538    0.032053    0.743092    
#> 224: 0.106645    1.102788    3.475688    0.103267    0.017659    0.032129    0.742685    
#> 225: 0.106719    1.101510    3.476303    0.102193    0.017843    0.032173    0.743998    
#> 226: 0.106762    1.100302    3.476223    0.101634    0.017806    0.032081    0.743990    
#> 227: 0.104502    1.100247    3.475805    0.101481    0.017701    0.032201    0.744570    
#> 228: 0.101626    1.101183    3.474222    0.101997    0.017740    0.032316    0.745035    
#> 229: 0.099964    1.101652    3.473654    0.101952    0.017696    0.032441    0.744934    
#> 230: 0.100593    1.101404    3.473531    0.101812    0.017676    0.032476    0.744544    
#> 231: 0.101192    1.101333    3.473992    0.101555    0.017756    0.032616    0.743912    
#> 232: 0.100475    1.101153    3.474102    0.101077    0.017889    0.032680    0.743597    
#> 233: 0.100105    1.100768    3.474120    0.101179    0.017980    0.032709    0.743084    
#> 234: 0.099655    1.100947    3.473515    0.101009    0.017984    0.032699    0.743027    
#> 235: 0.100102    1.100779    3.473385    0.100623    0.017964    0.032647    0.742790    
#> 236: 0.099726    1.101173    3.472969    0.100537    0.017969    0.032748    0.742871    
#> 237: 0.100701    1.101572    3.473011    0.100277    0.018039    0.032844    0.742931    
#> 238: 0.100864    1.101989    3.472876    0.100474    0.018130    0.032665    0.743134    
#> 239: 0.101160    1.103024    3.472374    0.100051    0.018339    0.032582    0.743568    
#> 240: 0.101389    1.102900    3.472519    0.099659    0.018452    0.032405    0.743888    
#> 241: 0.101902    1.102586    3.472784    0.099501    0.018565    0.032242    0.744236    
#> 242: 0.102030    1.102258    3.472822    0.099673    0.018791    0.032247    0.744465    
#> 243: 0.101802    1.102529    3.473153    0.099981    0.018861    0.032364    0.745143    
#> 244: 0.102050    1.102607    3.473688    0.100285    0.018959    0.032623    0.745615    
#> 245: 0.103070    1.102372    3.474087    0.099973    0.018962    0.032644    0.746226    
#> 246: 0.103528    1.102308    3.474227    0.099845    0.018927    0.032659    0.745993    
#> 247: 0.103288    1.102400    3.474140    0.099393    0.018956    0.032573    0.745684    
#> 248: 0.102624    1.102321    3.474030    0.099058    0.018919    0.032578    0.745347    
#> 249: 0.102737    1.102107    3.474115    0.098789    0.018996    0.032643    0.745093    
#> 250: 0.102850    1.102399    3.474274    0.098977    0.018986    0.032831    0.745211    
#> 251: 0.102680    1.102724    3.474458    0.098761    0.019065    0.032872    0.745552    
#> 252: 0.102973    1.102966    3.474820    0.098898    0.019054    0.032852    0.745270    
#> 253: 0.103279    1.103319    3.475092    0.099031    0.019021    0.032976    0.745087    
#> 254: 0.103425    1.103786    3.475232    0.099115    0.019019    0.032967    0.744863    
#> 255: 0.103022    1.104014    3.475132    0.099418    0.018995    0.033068    0.744792    
#> 256: 0.103179    1.103873    3.475044    0.100041    0.018978    0.033228    0.744543    
#> 257: 0.102831    1.103607    3.474909    0.100541    0.018925    0.033216    0.744553    
#> 258: 0.102690    1.103327    3.474891    0.100550    0.018931    0.033075    0.744367    
#> 259: 0.102547    1.103374    3.474801    0.100394    0.019001    0.032954    0.744142    
#> 260: 0.102559    1.103773    3.474860    0.100407    0.018985    0.032925    0.743941    
#> 261: 0.102614    1.103772    3.474958    0.100520    0.019028    0.032912    0.743651    
#> 262: 0.103109    1.103726    3.475020    0.100310    0.018989    0.032907    0.743708    
#> 263: 0.102827    1.103905    3.475049    0.100187    0.018895    0.032906    0.743381    
#> 264: 0.102464    1.103984    3.475016    0.100086    0.018765    0.032820    0.743644    
#> 265: 0.102276    1.104080    3.475037    0.100042    0.018707    0.032754    0.743608    
#> 266: 0.102415    1.104300    3.474993    0.100009    0.018673    0.032676    0.743416    
#> 267: 0.102402    1.104277    3.475175    0.100130    0.018697    0.032606    0.743351    
#> 268: 0.102273    1.104138    3.475033    0.100035    0.018763    0.032562    0.743241    
#> 269: 0.102870    1.103842    3.475187    0.099788    0.018854    0.032508    0.743394    
#> 270: 0.103379    1.103860    3.475147    0.099892    0.018860    0.032419    0.743209    
#> 271: 0.103252    1.103807    3.474845    0.099978    0.018825    0.032385    0.743257    
#> 272: 0.102654    1.104033    3.474569    0.100013    0.018847    0.032295    0.743422    
#> 273: 0.102028    1.104578    3.474311    0.100013    0.018953    0.032187    0.743497    
#> 274: 0.101117    1.104943    3.474160    0.099823    0.018955    0.032040    0.743561    
#> 275: 0.101213    1.105069    3.474125    0.099543    0.018949    0.031988    0.743523    
#> 276: 0.101160    1.105304    3.474133    0.099547    0.018920    0.031897    0.743661    
#> 277: 0.100829    1.105360    3.474138    0.099601    0.018944    0.031764    0.743604    
#> 278: 0.100962    1.105450    3.474260    0.099540    0.019010    0.031651    0.743503    
#> 279: 0.101053    1.105363    3.474520    0.099515    0.019061    0.031643    0.743495    
#> 280: 0.101281    1.105419    3.474457    0.099523    0.019109    0.031602    0.743348    
#> 281: 0.101172    1.105435    3.474505    0.099567    0.019053    0.031583    0.743431    
#> 282: 0.100912    1.105679    3.474344    0.099933    0.019018    0.031482    0.743605    
#> 283: 0.100464    1.106072    3.473955    0.100356    0.019019    0.031515    0.743876    
#> 284: 0.099966    1.106236    3.473834    0.100484    0.019019    0.031544    0.743621    
#> 285: 0.100113    1.106292    3.473606    0.100776    0.019067    0.031584    0.743635    
#> 286: 0.100218    1.106392    3.473484    0.101033    0.019107    0.031618    0.743698    
#> 287: 0.100215    1.106637    3.473343    0.100946    0.019145    0.031678    0.743869    
#> 288: 0.100557    1.106627    3.473443    0.100788    0.019232    0.031702    0.744165    
#> 289: 0.100798    1.106629    3.473451    0.100589    0.019190    0.031769    0.744283    
#> 290: 0.100580    1.106777    3.473421    0.100599    0.019189    0.031832    0.744413    
#> 291: 0.100545    1.107095    3.473315    0.100571    0.019231    0.031817    0.744067    
#> 292: 0.100292    1.107332    3.473263    0.100531    0.019199    0.031809    0.743869    
#> 293: 0.100159    1.107451    3.473140    0.100347    0.019162    0.031824    0.743763    
#> 294: 0.099865    1.107541    3.472962    0.100329    0.019130    0.031755    0.743582    
#> 295: 0.099957    1.107248    3.472960    0.100280    0.019125    0.031694    0.743377    
#> 296: 0.100272    1.107067    3.473066    0.100426    0.019091    0.031690    0.743448    
#> 297: 0.100563    1.107063    3.473125    0.100558    0.019068    0.031709    0.743438    
#> 298: 0.100914    1.106917    3.473247    0.100610    0.019029    0.031737    0.743344    
#> 299: 0.100976    1.107114    3.473300    0.100759    0.019018    0.031706    0.743237    
#> 300: 0.101314    1.107134    3.473491    0.100876    0.019022    0.031677    0.743187    
#> 301: 0.101483    1.106896    3.473529    0.100997    0.019021    0.031625    0.743243    
#> 302: 0.101426    1.106943    3.473455    0.101009    0.019050    0.031563    0.743334    
#> 303: 0.101404    1.107147    3.473363    0.101038    0.019060    0.031531    0.743151    
#> 304: 0.101912    1.107368    3.473346    0.101312    0.019052    0.031488    0.743221    
#> 305: 0.101919    1.107358    3.473328    0.101399    0.019078    0.031478    0.743098    
#> 306: 0.101819    1.107311    3.473230    0.101453    0.019052    0.031491    0.742965    
#> 307: 0.101606    1.107190    3.472954    0.101444    0.019029    0.031491    0.743060    
#> 308: 0.101322    1.107045    3.472822    0.101625    0.019000    0.031484    0.743146    
#> 309: 0.101318    1.106836    3.472743    0.101609    0.018944    0.031500    0.743142    
#> 310: 0.101550    1.106604    3.472623    0.101615    0.018949    0.031478    0.743296    
#> 311: 0.101961    1.106525    3.472789    0.101621    0.018952    0.031501    0.743215    
#> 312: 0.101992    1.106363    3.472840    0.101541    0.018958    0.031541    0.743108    
#> 313: 0.101858    1.106162    3.472844    0.101479    0.018993    0.031516    0.743094    
#> 314: 0.101717    1.106167    3.472760    0.101491    0.018999    0.031483    0.742908    
#> 315: 0.101698    1.106121    3.472878    0.101465    0.018974    0.031509    0.742827    
#> 316: 0.101784    1.106260    3.472785    0.101660    0.018989    0.031442    0.742686    
#> 317: 0.101776    1.106292    3.472858    0.101462    0.019028    0.031430    0.742685    
#> 318: 0.101678    1.106179    3.472754    0.101479    0.019044    0.031373    0.742501    
#> 319: 0.101848    1.106065    3.472923    0.101434    0.019101    0.031344    0.742551    
#> 320: 0.101485    1.105988    3.472795    0.101524    0.019139    0.031297    0.742417    
#> 321: 0.101283    1.106019    3.472649    0.101406    0.019177    0.031308    0.742542    
#> 322: 0.101039    1.106104    3.472523    0.101411    0.019204    0.031236    0.742457    
#> 323: 0.100553    1.106125    3.472418    0.101626    0.019202    0.031214    0.742428    
#> 324: 0.100559    1.106257    3.472377    0.101716    0.019221    0.031194    0.742319    
#> 325: 0.100156    1.106457    3.472242    0.101711    0.019206    0.031249    0.742291    
#> 326: 0.100190    1.106427    3.472161    0.101548    0.019200    0.031256    0.742264    
#> 327: 0.100312    1.106495    3.472258    0.101536    0.019209    0.031294    0.742320    
#> 328: 0.100584    1.106502    3.472318    0.101573    0.019228    0.031302    0.742336    
#> 329: 0.100729    1.106399    3.472414    0.101579    0.019263    0.031325    0.742081    
#> 330: 0.100489    1.106402    3.472479    0.101569    0.019272    0.031317    0.742243    
#> 331: 0.100623    1.106576    3.472589    0.101487    0.019274    0.031352    0.742175    
#> 332: 0.100776    1.106547    3.472698    0.101413    0.019264    0.031404    0.742201    
#> 333: 0.100668    1.106606    3.472613    0.101410    0.019303    0.031421    0.742039    
#> 334: 0.100512    1.106681    3.472465    0.101349    0.019302    0.031405    0.741997    
#> 335: 0.100140    1.106815    3.472272    0.101352    0.019340    0.031431    0.741954    
#> 336: 0.099753    1.107028    3.472148    0.101355    0.019409    0.031443    0.741943    
#> 337: 0.099703    1.107263    3.471998    0.101553    0.019432    0.031422    0.741893    
#> 338: 0.099751    1.107450    3.472042    0.101490    0.019469    0.031433    0.741854    
#> 339: 0.099673    1.107551    3.471965    0.101377    0.019460    0.031464    0.741866    
#> 340: 0.099557    1.107508    3.472010    0.101405    0.019462    0.031501    0.741789    
#> 341: 0.099412    1.107595    3.472013    0.101316    0.019488    0.031522    0.741673    
#> 342: 0.099230    1.107655    3.471970    0.101256    0.019462    0.031542    0.741657    
#> 343: 0.099039    1.107755    3.471926    0.101292    0.019440    0.031517    0.741585    
#> 344: 0.099177    1.107715    3.472004    0.101259    0.019461    0.031538    0.741584    
#> 345: 0.099284    1.107733    3.471996    0.101272    0.019510    0.031592    0.741454    
#> 346: 0.099331    1.107705    3.471990    0.101236    0.019539    0.031588    0.741335    
#> 347: 0.099403    1.107579    3.471939    0.101278    0.019554    0.031640    0.741454    
#> 348: 0.099079    1.107618    3.471838    0.101335    0.019563    0.031704    0.741524    
#> 349: 0.099035    1.107666    3.471780    0.101474    0.019567    0.031724    0.741563    
#> 350: 0.098969    1.107701    3.471714    0.101464    0.019568    0.031678    0.741580    
#> 351: 0.098808    1.108021    3.471564    0.101515    0.019605    0.031678    0.741484    
#> 352: 0.098581    1.108215    3.471455    0.101626    0.019682    0.031694    0.741502    
#> 353: 0.098760    1.108366    3.471422    0.101771    0.019722    0.031726    0.741519    
#> 354: 0.098677    1.108502    3.471291    0.101780    0.019730    0.031787    0.741513    
#> 355: 0.099003    1.108470    3.471325    0.101842    0.019751    0.031797    0.741622    
#> 356: 0.099071    1.108449    3.471330    0.101875    0.019775    0.031823    0.741704    
#> 357: 0.099175    1.108539    3.471223    0.101852    0.019755    0.031793    0.741876    
#> 358: 0.099180    1.108672    3.471222    0.101838    0.019797    0.031803    0.741838    
#> 359: 0.099001    1.108817    3.471158    0.101926    0.019807    0.031857    0.741869    
#> 360: 0.098447    1.109000    3.470850    0.102080    0.019809    0.031879    0.741793    
#> 361: 0.098099    1.109127    3.470659    0.102230    0.019777    0.031876    0.741768    
#> 362: 0.097986    1.109123    3.470542    0.102229    0.019766    0.031872    0.741725    
#> 363: 0.097915    1.109095    3.470496    0.102352    0.019745    0.031869    0.741570    
#> 364: 0.098070    1.109082    3.470506    0.102455    0.019740    0.031877    0.741484    
#> 365: 0.098160    1.109050    3.470594    0.102411    0.019777    0.031900    0.741407    
#> 366: 0.097990    1.109062    3.470450    0.102397    0.019782    0.031877    0.741466    
#> 367: 0.097877    1.109153    3.470313    0.102326    0.019794    0.031836    0.741495    
#> 368: 0.098011    1.109286    3.470248    0.102335    0.019762    0.031851    0.741526    
#> 369: 0.097822    1.109392    3.470094    0.102421    0.019764    0.031836    0.741422    
#> 370: 0.097597    1.109522    3.470018    0.102275    0.019772    0.031839    0.741396    
#> 371: 0.097259    1.109706    3.469806    0.102212    0.019784    0.031804    0.741246    
#> 372: 0.097092    1.109849    3.469710    0.102202    0.019773    0.031783    0.741198    
#> 373: 0.096939    1.109977    3.469658    0.102200    0.019777    0.031770    0.741177    
#> 374: 0.096793    1.110067    3.469568    0.102132    0.019781    0.031746    0.741156    
#> 375: 0.096695    1.110035    3.469592    0.102126    0.019781    0.031752    0.741115    
#> 376: 0.096637    1.109962    3.469605    0.102043    0.019772    0.031751    0.740999    
#> 377: 0.096559    1.109955    3.469639    0.102011    0.019776    0.031751    0.740895    
#> 378: 0.096318    1.109947    3.469541    0.101999    0.019777    0.031742    0.740914    
#> 379: 0.096111    1.109950    3.469500    0.102073    0.019795    0.031715    0.740854    
#> 380: 0.095828    1.109960    3.469372    0.102151    0.019826    0.031707    0.740746    
#> 381: 0.095626    1.110017    3.469262    0.102258    0.019820    0.031711    0.740774    
#> 382: 0.095650    1.110049    3.469295    0.102256    0.019828    0.031704    0.740646    
#> 383: 0.095880    1.109977    3.469339    0.102201    0.019820    0.031689    0.740597    
#> 384: 0.095820    1.109979    3.469345    0.102078    0.019844    0.031702    0.740620    
#> 385: 0.095749    1.110010    3.469283    0.102129    0.019885    0.031686    0.740683    
#> 386: 0.095870    1.110082    3.469390    0.102160    0.019897    0.031701    0.740684    
#> 387: 0.096090    1.110107    3.469572    0.102133    0.019894    0.031690    0.740705    
#> 388: 0.096082    1.110114    3.469611    0.102042    0.019853    0.031666    0.740787    
#> 389: 0.096017    1.109982    3.469603    0.101949    0.019839    0.031693    0.740865    
#> 390: 0.095977    1.109978    3.469525    0.101948    0.019824    0.031711    0.740913    
#> 391: 0.096011    1.109990    3.469509    0.101949    0.019809    0.031710    0.740837    
#> 392: 0.096131    1.109962    3.469554    0.102005    0.019811    0.031730    0.740812    
#> 393: 0.096023    1.109952    3.469474    0.102075    0.019827    0.031708    0.740737    
#> 394: 0.095984    1.110022    3.469355    0.102124    0.019827    0.031698    0.740763    
#> 395: 0.096238    1.110121    3.469384    0.102201    0.019811    0.031709    0.740737    
#> 396: 0.096526    1.110251    3.469475    0.102358    0.019813    0.031725    0.740690    
#> 397: 0.096716    1.110213    3.469648    0.102427    0.019794    0.031755    0.740723    
#> 398: 0.097073    1.110075    3.469802    0.102349    0.019794    0.031754    0.740819    
#> 399: 0.097380    1.110020    3.469928    0.102337    0.019788    0.031730    0.740861    
#> 400: 0.097563    1.109919    3.470018    0.102237    0.019776    0.031729    0.740869    
#> 401: 0.097541    1.109961    3.469955    0.102117    0.019806    0.031737    0.740813    
#> 402: 0.097476    1.109987    3.469976    0.101966    0.019814    0.031735    0.740818    
#> 403: 0.097532    1.109997    3.469929    0.101954    0.019839    0.031722    0.740824    
#> 404: 0.097590    1.110007    3.469904    0.101852    0.019837    0.031727    0.740872    
#> 405: 0.097469    1.109967    3.469883    0.101908    0.019843    0.031702    0.740911    
#> 406: 0.097542    1.109939    3.469899    0.101989    0.019851    0.031712    0.740947    
#> 407: 0.097665    1.109920    3.469978    0.102070    0.019851    0.031718    0.740942    
#> 408: 0.097670    1.109952    3.469972    0.101969    0.019843    0.031725    0.741015    
#> 409: 0.097608    1.109940    3.469923    0.101915    0.019835    0.031719    0.741017    
#> 410: 0.097501    1.110001    3.469861    0.101870    0.019831    0.031699    0.741043    
#> 411: 0.097527    1.109876    3.469858    0.101877    0.019813    0.031688    0.741097    
#> 412: 0.097692    1.109837    3.469846    0.101806    0.019814    0.031672    0.741092    
#> 413: 0.097681    1.109912    3.469795    0.101747    0.019828    0.031646    0.741123    
#> 414: 0.097577    1.109909    3.469860    0.101761    0.019810    0.031635    0.741037    
#> 415: 0.097765    1.109794    3.469971    0.101785    0.019790    0.031631    0.740977    
#> 416: 0.098200    1.109736    3.470121    0.101776    0.019778    0.031646    0.741024    
#> 417: 0.098496    1.109577    3.470239    0.101859    0.019775    0.031644    0.741009    
#> 418: 0.098569    1.109544    3.470347    0.101852    0.019770    0.031644    0.740978    
#> 419: 0.098646    1.109640    3.470337    0.101885    0.019775    0.031638    0.740915    
#> 420: 0.098729    1.109645    3.470303    0.101813    0.019775    0.031607    0.740823    
#> 421: 0.098709    1.109637    3.470317    0.101766    0.019763    0.031581    0.740791    
#> 422: 0.098852    1.109578    3.470365    0.101849    0.019755    0.031555    0.740822    
#> 423: 0.098828    1.109552    3.470370    0.101794    0.019760    0.031570    0.740816    
#> 424: 0.098849    1.109501    3.470385    0.101788    0.019779    0.031571    0.740782    
#> 425: 0.099123    1.109524    3.470421    0.101820    0.019809    0.031574    0.740961    
#> 426: 0.099158    1.109527    3.470437    0.101810    0.019804    0.031565    0.740864    
#> 427: 0.099192    1.109442    3.470509    0.101816    0.019811    0.031564    0.740750    
#> 428: 0.099033    1.109456    3.470517    0.101873    0.019821    0.031563    0.740698    
#> 429: 0.098914    1.109457    3.470503    0.101849    0.019854    0.031545    0.740700    
#> 430: 0.098938    1.109499    3.470535    0.101808    0.019872    0.031577    0.740680    
#> 431: 0.098922    1.109505    3.470497    0.101733    0.019855    0.031584    0.740672    
#> 432: 0.098995    1.109547    3.470556    0.101643    0.019835    0.031636    0.740685    
#> 433: 0.099100    1.109598    3.470616    0.101623    0.019821    0.031636    0.740735    
#> 434: 0.099101    1.109548    3.470632    0.101558    0.019817    0.031653    0.740743    
#> 435: 0.099063    1.109526    3.470625    0.101504    0.019817    0.031652    0.740711    
#> 436: 0.099080    1.109450    3.470675    0.101484    0.019789    0.031652    0.740748    
#> 437: 0.099232    1.109401    3.470735    0.101581    0.019768    0.031649    0.740737    
#> 438: 0.099322    1.109484    3.470784    0.101569    0.019751    0.031639    0.740752    
#> 439: 0.099395    1.109530    3.470826    0.101543    0.019758    0.031616    0.740723    
#> 440: 0.099442    1.109624    3.470841    0.101533    0.019775    0.031605    0.740666    
#> 441: 0.099493    1.109652    3.470913    0.101594    0.019831    0.031586    0.740624    
#> 442: 0.099374    1.109734    3.470900    0.101658    0.019856    0.031563    0.740535    
#> 443: 0.099229    1.109833    3.470797    0.101686    0.019873    0.031525    0.740557    
#> 444: 0.099102    1.109912    3.470684    0.101752    0.019898    0.031484    0.740538    
#> 445: 0.099037    1.109977    3.470617    0.101854    0.019945    0.031452    0.740504    
#> 446: 0.098872    1.110068    3.470523    0.101951    0.020004    0.031421    0.740395    
#> 447: 0.098813    1.110147    3.470460    0.101966    0.020039    0.031405    0.740388    
#> 448: 0.098650    1.110156    3.470440    0.101917    0.020029    0.031391    0.740405    
#> 449: 0.098686    1.110226    3.470534    0.101872    0.020029    0.031387    0.740455    
#> 450: 0.098654    1.110271    3.470512    0.101832    0.020042    0.031358    0.740497    
#> 451: 0.098679    1.110324    3.470485    0.101904    0.020083    0.031333    0.740513    
#> 452: 0.098625    1.110363    3.470476    0.101835    0.020099    0.031311    0.740496    
#> 453: 0.098595    1.110409    3.470428    0.101728    0.020113    0.031284    0.740462    
#> 454: 0.098481    1.110489    3.470373    0.101681    0.020105    0.031260    0.740407    
#> 455: 0.098547    1.110549    3.470375    0.101656    0.020100    0.031271    0.740357    
#> 456: 0.098476    1.110583    3.470321    0.101699    0.020103    0.031264    0.740272    
#> 457: 0.098402    1.110619    3.470312    0.101747    0.020096    0.031243    0.740245    
#> 458: 0.098314    1.110709    3.470314    0.101817    0.020106    0.031218    0.740265    
#> 459: 0.098116    1.110792    3.470277    0.101842    0.020115    0.031210    0.740274    
#> 460: 0.097992    1.110844    3.470169    0.101886    0.020111    0.031205    0.740290    
#> 461: 0.097817    1.110934    3.470127    0.101836    0.020117    0.031211    0.740262    
#> 462: 0.097746    1.111039    3.470084    0.101760    0.020124    0.031218    0.740290    
#> 463: 0.097712    1.111069    3.470100    0.101657    0.020127    0.031223    0.740282    
#> 464: 0.097631    1.111151    3.470038    0.101623    0.020138    0.031218    0.740258    
#> 465: 0.097546    1.111076    3.470032    0.101520    0.020141    0.031197    0.740291    
#> 466: 0.097566    1.111143    3.469984    0.101444    0.020152    0.031162    0.740334    
#> 467: 0.097562    1.111137    3.470011    0.101446    0.020168    0.031139    0.740265    
#> 468: 0.097658    1.111143    3.470077    0.101466    0.020167    0.031120    0.740368    
#> 469: 0.097775    1.111179    3.470156    0.101481    0.020160    0.031139    0.740452    
#> 470: 0.097654    1.111252    3.470099    0.101484    0.020177    0.031112    0.740482    
#> 471: 0.097625    1.111267    3.470096    0.101529    0.020183    0.031090    0.740507    
#> 472: 0.097634    1.111316    3.470068    0.101584    0.020183    0.031085    0.740496    
#> 473: 0.097515    1.111358    3.470029    0.101599    0.020188    0.031068    0.740440    
#> 474: 0.097455    1.111336    3.469979    0.101542    0.020192    0.031044    0.740469    
#> 475: 0.097438    1.111406    3.469979    0.101440    0.020179    0.031031    0.740479    
#> 476: 0.097535    1.111335    3.469974    0.101371    0.020198    0.031018    0.740461    
#> 477: 0.097605    1.111268    3.470053    0.101380    0.020211    0.031006    0.740420    
#> 478: 0.097567    1.111183    3.470087    0.101348    0.020221    0.030995    0.740402    
#> 479: 0.097636    1.111178    3.470092    0.101374    0.020238    0.030986    0.740323    
#> 480: 0.097761    1.111150    3.470103    0.101363    0.020237    0.031001    0.740389    
#> 481: 0.097785    1.111165    3.470073    0.101437    0.020237    0.030993    0.740371    
#> 482: 0.097999    1.111196    3.470079    0.101467    0.020231    0.030967    0.740434    
#> 483: 0.098009    1.111178    3.470075    0.101516    0.020216    0.030942    0.740427    
#> 484: 0.097924    1.111128    3.470047    0.101698    0.020211    0.030932    0.740411    
#> 485: 0.097962    1.111145    3.470065    0.101778    0.020210    0.030919    0.740436    
#> 486: 0.098033    1.111132    3.470120    0.101877    0.020206    0.030900    0.740401    
#> 487: 0.098237    1.111125    3.470197    0.101952    0.020190    0.030895    0.740373    
#> 488: 0.098214    1.111122    3.470227    0.101916    0.020187    0.030896    0.740333    
#> 489: 0.098240    1.111094    3.470229    0.101975    0.020194    0.030919    0.740304    
#> 490: 0.098365    1.111089    3.470281    0.102004    0.020188    0.030932    0.740267    
#> 491: 0.098506    1.111155    3.470359    0.101934    0.020186    0.030965    0.740216    
#> 492: 0.098549    1.111214    3.470377    0.101842    0.020194    0.030983    0.740256    
#> 493: 0.098473    1.111188    3.470397    0.101706    0.020197    0.030985    0.740311    
#> 494: 0.098468    1.111208    3.470370    0.101625    0.020189    0.030963    0.740357    
#> 495: 0.098562    1.111282    3.470335    0.101620    0.020189    0.030956    0.740340    
#> 496: 0.098685    1.111367    3.470296    0.101599    0.020208    0.030946    0.740374    
#> 497: 0.098550    1.111336    3.470269    0.101706    0.020225    0.030952    0.740379    
#> 498: 0.098553    1.111268    3.470273    0.101669    0.020233    0.030941    0.740442    
#> 499: 0.098642    1.111238    3.470303    0.101621    0.020247    0.030933    0.740462    
#> 500: 0.098758    1.111197    3.470354    0.101563    0.020255    0.030924    0.740397    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.275953    0.974569    3.446960    0.392401    0.077949    0.016800    1.601771    
#> 002: 0.406059    1.026128    3.461287    0.372781    0.074052    0.018858    1.119594    
#> 003: 0.544721    0.972586    3.478028    0.354142    0.079080    0.017915    0.801154    
#> 004: 0.533798    0.994443    3.482278    0.360537    0.088020    0.017019    0.693482    
#> 005: 0.598832    1.010647    3.481844    0.381616    0.094321    0.016168    0.639595    
#> 006: 0.598821    1.018900    3.478400    0.397979    0.089605    0.015360    0.600962    
#> 007: 0.561291    1.035923    3.467773    0.479693    0.085469    0.015546    0.610412    
#> 008: 0.533312    1.029007    3.463165    0.455708    0.086850    0.014769    0.599262    
#> 009: 0.546374    1.023189    3.468055    0.454426    0.084814    0.014030    0.603086    
#> 010: 0.558761    1.000214    3.468226    0.512819    0.080573    0.013329    0.610317    
#> 011: 0.599039    1.020743    3.474782    0.487178    0.093100    0.012662    0.607178    
#> 012: 0.583358    1.016835    3.465771    0.470751    0.096332    0.013321    0.598207    
#> 013: 0.533786    1.036599    3.451687    0.454151    0.091516    0.014858    0.609966    
#> 014: 0.542866    1.029285    3.465378    0.431443    0.088097    0.016629    0.612431    
#> 015: 0.558871    1.030880    3.480337    0.409871    0.084142    0.019225    0.582129    
#> 016: 0.575389    1.024652    3.482712    0.479491    0.087695    0.022310    0.589946    
#> 017: 0.570287    1.031592    3.480929    0.455517    0.083310    0.021195    0.579821    
#> 018: 0.596722    1.018360    3.474101    0.498478    0.079145    0.020135    0.592612    
#> 019: 0.596832    1.022313    3.478853    0.473554    0.076708    0.019128    0.586673    
#> 020: 0.607563    1.031070    3.476247    0.480264    0.083752    0.018172    0.585436    
#> 021: 0.620831    1.017834    3.486667    0.470542    0.081426    0.018470    0.581021    
#> 022: 0.571900    1.019204    3.486106    0.447015    0.089538    0.017866    0.570113    
#> 023: 0.660114    1.014307    3.494122    0.567099    0.085061    0.021836    0.594322    
#> 024: 0.657506    1.021346    3.492013    0.555265    0.090521    0.021196    0.577039    
#> 025: 0.647100    0.990567    3.490204    0.527501    0.085995    0.020136    0.588902    
#> 026: 0.637502    1.013054    3.480616    0.597162    0.081695    0.020063    0.606761    
#> 027: 0.610341    1.030048    3.471125    0.567304    0.080802    0.019060    0.624083    
#> 028: 0.630667    1.019277    3.489859    0.554993    0.081156    0.023219    0.588791    
#> 029: 0.652240    1.014850    3.488183    0.576342    0.087705    0.022058    0.594117    
#> 030: 0.651840    1.021688    3.484803    0.569299    0.083320    0.021504    0.585943    
#> 031: 0.593984    1.017744    3.489230    0.598645    0.083210    0.020429    0.588442    
#> 032: 0.599630    1.001124    3.487828    0.568713    0.079050    0.022303    0.587902    
#> 033: 0.579381    1.017729    3.481847    0.540277    0.081337    0.021187    0.589737    
#> 034: 0.598684    1.015133    3.486563    0.518960    0.077270    0.020128    0.590532    
#> 035: 0.594845    1.001612    3.482143    0.493012    0.073406    0.020648    0.586785    
#> 036: 0.580310    1.001489    3.488968    0.468362    0.074098    0.025148    0.579598    
#> 037: 0.593967    1.022713    3.480322    0.473843    0.082772    0.024106    0.571483    
#> 038: 0.588551    1.031489    3.477984    0.465648    0.089695    0.024636    0.575974    
#> 039: 0.616745    1.030912    3.485534    0.528122    0.085210    0.025442    0.573792    
#> 040: 0.617305    1.023649    3.481835    0.516801    0.080950    0.028925    0.578423    
#> 041: 0.586285    1.019088    3.479007    0.490961    0.076902    0.027479    0.570064    
#> 042: 0.588790    1.023743    3.478608    0.490333    0.073057    0.026105    0.564292    
#> 043: 0.582552    1.031308    3.472693    0.465816    0.069404    0.024800    0.570532    
#> 044: 0.555625    1.030927    3.464569    0.471924    0.080965    0.023560    0.577875    
#> 045: 0.611620    1.037438    3.462688    0.618628    0.076916    0.022382    0.583044    
#> 046: 0.591329    1.019853    3.466875    0.587696    0.078788    0.021263    0.579936    
#> 047: 0.581028    1.032621    3.474102    0.558311    0.074848    0.021314    0.585866    
#> 048: 0.589621    1.034383    3.475409    0.530396    0.075994    0.020248    0.593747    
#> 049: 0.585839    1.003175    3.478428    0.503876    0.078987    0.021288    0.583213    
#> 050: 0.598002    0.985653    3.478192    0.526620    0.077431    0.020224    0.606965    
#> 051: 0.593972    1.007012    3.474781    0.537293    0.082301    0.022096    0.599272    
#> 052: 0.613745    0.999006    3.495337    0.510429    0.078186    0.023523    0.588061    
#> 053: 0.586483    1.007434    3.482663    0.511461    0.082300    0.022814    0.582928    
#> 054: 0.579539    1.025665    3.480803    0.485888    0.078185    0.025924    0.600847    
#> 055: 0.591135    1.017566    3.487824    0.461594    0.079510    0.024628    0.582955    
#> 056: 0.614487    1.009483    3.488531    0.438514    0.075535    0.023397    0.603768    
#> 057: 0.588013    1.025797    3.494495    0.416588    0.083083    0.022227    0.605426    
#> 058: 0.594447    1.022135    3.479632    0.468888    0.078929    0.021574    0.596105    
#> 059: 0.585583    1.000821    3.481064    0.508787    0.085344    0.020495    0.592859    
#> 060: 0.579317    0.998497    3.488144    0.537545    0.081077    0.024635    0.601418    
#> 061: 0.597816    1.010358    3.485939    0.510667    0.077023    0.024856    0.588596    
#> 062: 0.607483    1.022694    3.487073    0.535658    0.077133    0.028864    0.597014    
#> 063: 0.632930    1.008328    3.476676    0.572639    0.074223    0.027421    0.599498    
#> 064: 0.586735    1.013657    3.477884    0.544007    0.070512    0.026050    0.605672    
#> 065: 0.588783    1.012040    3.462753    0.516807    0.070759    0.024748    0.595777    
#> 066: 0.576380    1.047156    3.472908    0.522095    0.081867    0.023510    0.586494    
#> 067: 0.555198    1.012754    3.467726    0.495990    0.085668    0.022335    0.565301    
#> 068: 0.548484    1.009277    3.482130    0.471191    0.081384    0.022050    0.576327    
#> 069: 0.599400    1.003456    3.480545    0.471606    0.077315    0.026589    0.587123    
#> 070: 0.593222    0.990827    3.492002    0.517327    0.073449    0.027669    0.584136    
#> 071: 0.576503    1.020920    3.472872    0.491461    0.069777    0.027859    0.593416    
#> 072: 0.532624    1.009038    3.471129    0.466888    0.068323    0.028125    0.585372    
#> 073: 0.555340    1.032763    3.470363    0.481313    0.067190    0.026719    0.576261    
#> 074: 0.547370    1.029183    3.462429    0.475393    0.068196    0.026353    0.578347    
#> 075: 0.580643    1.026494    3.478293    0.524353    0.075824    0.025652    0.577914    
#> 076: 0.614762    1.038283    3.486031    0.523468    0.072033    0.028055    0.571191    
#> 077: 0.602556    1.011282    3.486551    0.497295    0.068431    0.026652    0.578692    
#> 078: 0.592000    1.017935    3.487319    0.522700    0.065010    0.028173    0.570611    
#> 079: 0.623346    1.013050    3.487226    0.554497    0.065204    0.029723    0.582860    
#> 080: 0.644698    0.999964    3.496704    0.535485    0.061944    0.033450    0.597062    
#> 081: 0.605574    1.015995    3.487641    0.508711    0.059145    0.032021    0.569838    
#> 082: 0.607312    0.992066    3.491297    0.483276    0.066029    0.031604    0.588284    
#> 083: 0.576243    1.017774    3.481610    0.520481    0.067862    0.030024    0.587368    
#> 084: 0.537494    1.038673    3.466371    0.494457    0.064928    0.028523    0.567754    
#> 085: 0.566687    1.032902    3.482970    0.469734    0.061682    0.027097    0.584430    
#> 086: 0.595623    1.017869    3.490396    0.446247    0.066183    0.026474    0.597565    
#> 087: 0.579184    1.022623    3.479428    0.423935    0.074985    0.025269    0.588565    
#> 088: 0.544801    1.024220    3.479142    0.433431    0.074875    0.024006    0.605321    
#> 089: 0.572644    1.031898    3.462735    0.446567    0.071131    0.023768    0.605675    
#> 090: 0.576513    1.020585    3.472026    0.459490    0.074903    0.029229    0.608994    
#> 091: 0.544167    1.022548    3.462228    0.436515    0.072045    0.029276    0.599668    
#> 092: 0.577133    1.047517    3.470037    0.414690    0.068865    0.028797    0.598430    
#> 093: 0.557938    1.025373    3.471368    0.440391    0.072184    0.027357    0.615547    
#> 094: 0.580229    1.034358    3.475185    0.456893    0.074534    0.029211    0.605559    
#> 095: 0.582786    1.029604    3.484461    0.454427    0.070808    0.027837    0.601867    
#> 096: 0.542900    1.038568    3.471802    0.467360    0.068555    0.026446    0.582775    
#> 097: 0.611476    1.044824    3.470508    0.532670    0.081492    0.025123    0.579525    
#> 098: 0.609969    1.055747    3.482949    0.506037    0.077417    0.025353    0.586350    
#> 099: 0.570241    1.013873    3.473835    0.480735    0.073547    0.024086    0.582785    
#> 100: 0.580545    1.034386    3.474250    0.526554    0.077395    0.023890    0.557301    
#> 101: 0.551891    1.030946    3.454344    0.500226    0.085424    0.022696    0.568250    
#> 102: 0.565829    1.043160    3.456872    0.496922    0.081153    0.021561    0.580411    
#> 103: 0.578572    1.032788    3.474172    0.484274    0.077095    0.020483    0.571841    
#> 104: 0.568432    1.030554    3.480840    0.516117    0.084483    0.021195    0.588500    
#> 105: 0.616208    1.006674    3.482503    0.538784    0.082398    0.020136    0.578212    
#> 106: 0.597619    1.012331    3.482203    0.511845    0.080423    0.023501    0.570527    
#> 107: 0.623196    1.018390    3.479648    0.558449    0.077953    0.024563    0.575171    
#> 108: 0.615714    1.004671    3.493964    0.534460    0.074055    0.025469    0.583981    
#> 109: 0.617303    1.028914    3.498197    0.507737    0.070352    0.024416    0.587676    
#> 110: 0.642608    1.007450    3.496955    0.482350    0.069223    0.025457    0.578552    
#> 111: 0.610822    1.006108    3.494568    0.458233    0.073326    0.024184    0.571334    
#> 112: 0.581822    0.999232    3.486379    0.435321    0.069660    0.022975    0.583219    
#> 113: 0.590662    1.031786    3.480931    0.485104    0.066177    0.023994    0.574156    
#> 114: 0.587549    1.042056    3.469533    0.528126    0.081448    0.023858    0.569560    
#> 115: 0.607544    1.017969    3.468741    0.572482    0.079001    0.025397    0.580977    
#> 116: 0.608164    1.031222    3.464578    0.625682    0.079356    0.024128    0.588375    
#> 117: 0.547786    1.047495    3.458925    0.594398    0.089253    0.022921    0.594054    
#> 118: 0.574778    1.038320    3.458899    0.564678    0.087160    0.021775    0.597627    
#> 119: 0.595389    1.045919    3.454346    0.581578    0.082802    0.025514    0.608791    
#> 120: 0.547273    1.020420    3.466487    0.552499    0.078662    0.029032    0.595715    
#> 121: 0.551109    1.044013    3.468426    0.524874    0.074729    0.027580    0.601528    
#> 122: 0.558438    1.033303    3.474274    0.510980    0.071356    0.026201    0.583092    
#> 123: 0.608516    1.048787    3.463191    0.565438    0.077052    0.024891    0.596119    
#> 124: 0.560361    1.062700    3.460463    0.578238    0.073200    0.023646    0.597660    
#> 125: 0.589516    1.049688    3.456549    0.605513    0.079628    0.022464    0.594333    
#> 126: 0.586082    1.059284    3.457735    0.640474    0.082687    0.021341    0.595146    
#> 127: 0.605603    1.042678    3.454174    0.668413    0.078553    0.020274    0.586102    
#> 128: 0.585732    1.045719    3.470530    0.634993    0.079209    0.023219    0.593977    
#> 129: 0.608298    1.028025    3.483917    0.603243    0.075249    0.025953    0.595425    
#> 130: 0.635420    1.021462    3.479687    0.573081    0.071486    0.027681    0.582838    
#> 131: 0.601433    1.003112    3.464454    0.544427    0.076977    0.026297    0.588514    
#> 132: 0.549158    1.018500    3.462796    0.560342    0.073128    0.025931    0.574845    
#> 133: 0.559737    1.009276    3.471020    0.554438    0.069471    0.030832    0.570612    
#> 134: 0.557514    1.016164    3.481210    0.526716    0.066172    0.035615    0.587682    
#> 135: 0.582545    0.997531    3.489881    0.500380    0.062864    0.033834    0.581172    
#> 136: 0.594055    1.006659    3.489886    0.475361    0.064478    0.032142    0.586284    
#> 137: 0.657332    1.001538    3.499146    0.454558    0.079762    0.030535    0.606941    
#> 138: 0.626334    1.017986    3.494502    0.484813    0.075773    0.029008    0.592782    
#> 139: 0.583998    0.994565    3.498166    0.460572    0.071985    0.027558    0.593803    
#> 140: 0.603178    1.007419    3.493737    0.437544    0.068386    0.027145    0.587199    
#> 141: 0.603359    1.002079    3.493942    0.478291    0.064966    0.026642    0.581543    
#> 142: 0.623030    0.989712    3.501218    0.454377    0.061718    0.026645    0.585385    
#> 143: 0.577878    1.012366    3.491394    0.431658    0.073977    0.025313    0.587780    
#> 144: 0.594920    1.017373    3.488428    0.488409    0.077401    0.024286    0.562599    
#> 145: 0.590231    1.016357    3.475900    0.525460    0.073531    0.023072    0.569719    
#> 146: 0.547951    1.031231    3.471919    0.511119    0.073228    0.024373    0.576397    
#> 147: 0.522468    1.026943    3.453860    0.485563    0.072613    0.025819    0.578575    
#> 148: 0.545543    1.047027    3.475487    0.461285    0.074714    0.025175    0.589395    
#> 149: 0.554006    1.007366    3.481870    0.480216    0.070978    0.025844    0.584842    
#> 150: 0.584732    1.011523    3.470714    0.456205    0.077747    0.024643    0.579002    
#> 151: 0.526704    1.031346    3.474299    0.453897    0.073859    0.024268    0.584377    
#> 152: 0.520652    1.046517    3.460974    0.423861    0.060965    0.022732    0.581772    
#> 153: 0.544296    1.040496    3.474142    0.443742    0.065332    0.029207    0.595032    
#> 154: 0.549977    1.039696    3.468115    0.421314    0.066243    0.025700    0.590098    
#> 155: 0.551820    1.024003    3.470275    0.426632    0.067830    0.024215    0.587951    
#> 156: 0.592658    1.032356    3.484004    0.455346    0.063124    0.019219    0.606080    
#> 157: 0.621529    1.025029    3.493524    0.488977    0.071589    0.018446    0.604363    
#> 158: 0.643738    1.026312    3.490610    0.488555    0.075548    0.019742    0.590435    
#> 159: 0.601463    1.023551    3.491579    0.534134    0.077886    0.023121    0.580342    
#> 160: 0.635941    0.994440    3.499703    0.564225    0.066990    0.024891    0.589630    
#> 161: 0.629239    1.007254    3.488303    0.571772    0.063415    0.024639    0.595711    
#> 162: 0.607220    1.030352    3.476156    0.523114    0.065918    0.025895    0.581392    
#> 163: 0.585652    1.017779    3.477583    0.457865    0.063473    0.028994    0.586354    
#> 164: 0.611745    1.005659    3.488206    0.449270    0.056509    0.029340    0.576190    
#> 165: 0.611235    0.991296    3.497013    0.492943    0.059229    0.026430    0.584886    
#> 166: 0.641368    1.021696    3.485923    0.572213    0.056080    0.028783    0.590386    
#> 167: 0.637394    1.055466    3.475141    0.566351    0.069979    0.027192    0.590098    
#> 168: 0.609891    1.049999    3.479637    0.504328    0.078336    0.026533    0.584302    
#> 169: 0.574772    1.075234    3.474392    0.497831    0.085347    0.027413    0.596191    
#> 170: 0.563352    1.057242    3.466066    0.502280    0.081015    0.021614    0.582873    
#> 171: 0.531408    1.066705    3.464777    0.461138    0.077137    0.019414    0.571310    
#> 172: 0.517759    1.062196    3.460118    0.416568    0.080324    0.017016    0.580661    
#> 173: 0.531642    1.058514    3.450959    0.513919    0.074283    0.017077    0.577958    
#> 174: 0.559746    1.058891    3.455427    0.510686    0.069218    0.017832    0.580917    
#> 175: 0.540498    1.044759    3.450503    0.408950    0.073010    0.018008    0.595414    
#> 176: 0.558899    1.049094    3.465587    0.466375    0.090521    0.015690    0.573594    
#> 177: 0.570398    1.028444    3.478859    0.460281    0.078314    0.016180    0.583655    
#> 178: 0.570905    1.009454    3.482605    0.452680    0.077187    0.017607    0.586685    
#> 179: 0.667881    1.018414    3.484508    0.578624    0.091016    0.016757    0.589544    
#> 180: 0.601357    1.020943    3.483262    0.503765    0.088371    0.018755    0.592306    
#> 181: 0.577964    1.028953    3.458732    0.491754    0.072480    0.017353    0.591916    
#> 182: 0.544404    1.021905    3.462560    0.491377    0.078409    0.017697    0.605607    
#> 183: 0.591597    1.034920    3.464299    0.529218    0.091870    0.018694    0.590216    
#> 184: 0.575743    1.034070    3.466844    0.527199    0.091232    0.017917    0.576205    
#> 185: 0.539984    1.065934    3.457482    0.538044    0.089603    0.019527    0.570980    
#> 186: 0.544382    1.064489    3.459446    0.510975    0.093236    0.018392    0.597767    
#> 187: 0.599262    1.026394    3.469336    0.551029    0.077177    0.020111    0.598429    
#> 188: 0.546601    1.042366    3.471403    0.458066    0.087433    0.021529    0.598388    
#> 189: 0.573446    1.050474    3.483405    0.379241    0.083403    0.021274    0.591305    
#> 190: 0.559217    1.039436    3.475008    0.450403    0.071233    0.019915    0.591598    
#> 191: 0.583331    1.039165    3.469125    0.500984    0.064654    0.019109    0.568850    
#> 192: 0.559564    1.055731    3.469236    0.469658    0.075316    0.020084    0.578249    
#> 193: 0.588008    1.054811    3.480632    0.545939    0.069358    0.020692    0.581609    
#> 194: 0.593062    1.040806    3.477304    0.526572    0.065004    0.020704    0.572930    
#> 195: 0.543513    1.030625    3.457966    0.474898    0.066897    0.021798    0.572440    
#> 196: 0.566614    1.046824    3.462995    0.511260    0.067008    0.023687    0.580351    
#> 197: 0.551151    1.037792    3.478922    0.490771    0.065014    0.027644    0.597656    
#> 198: 0.597100    1.034544    3.468610    0.567337    0.065396    0.029165    0.578388    
#> 199: 0.599439    1.027267    3.477260    0.598406    0.069300    0.028455    0.575712    
#> 200: 0.594960    1.027634    3.483818    0.531758    0.069389    0.025824    0.582434    
#> 201: 0.588892    1.025790    3.482407    0.533315    0.067374    0.027740    0.579929    
#> 202: 0.586609    1.023602    3.479641    0.553322    0.067476    0.027081    0.577784    
#> 203: 0.597061    1.025858    3.477413    0.571254    0.067642    0.026366    0.579680    
#> 204: 0.598832    1.025750    3.476567    0.584797    0.068695    0.025282    0.579342    
#> 205: 0.602734    1.030181    3.476023    0.596537    0.069132    0.024789    0.581606    
#> 206: 0.603310    1.035399    3.476014    0.600407    0.069363    0.024232    0.583008    
#> 207: 0.606764    1.035635    3.475033    0.609463    0.069773    0.023866    0.581746    
#> 208: 0.607445    1.034842    3.474260    0.608302    0.070281    0.023522    0.580060    
#> 209: 0.607734    1.031783    3.474099    0.601412    0.071322    0.023028    0.580716    
#> 210: 0.608503    1.028997    3.475285    0.593146    0.071928    0.022911    0.580708    
#> 211: 0.609461    1.028258    3.475478    0.587682    0.072848    0.022947    0.579321    
#> 212: 0.611026    1.029101    3.475898    0.585433    0.072937    0.023083    0.578498    
#> 213: 0.612889    1.028235    3.476387    0.582139    0.072593    0.023222    0.579177    
#> 214: 0.613606    1.027752    3.476797    0.579419    0.072798    0.023177    0.579998    
#> 215: 0.611813    1.027085    3.477702    0.572415    0.073186    0.023460    0.580253    
#> 216: 0.613013    1.025519    3.478393    0.567220    0.073205    0.023601    0.581308    
#> 217: 0.612365    1.025139    3.479078    0.563351    0.073110    0.023651    0.581632    
#> 218: 0.611825    1.024584    3.479277    0.558063    0.073273    0.023629    0.581407    
#> 219: 0.609535    1.024294    3.478896    0.556572    0.072714    0.023637    0.581827    
#> 220: 0.606868    1.024088    3.478760    0.553760    0.072307    0.023834    0.581961    
#> 221: 0.607166    1.024246    3.478784    0.552507    0.072105    0.023947    0.581544    
#> 222: 0.606154    1.024446    3.478378    0.550182    0.071847    0.024086    0.581190    
#> 223: 0.606000    1.023911    3.478079    0.547946    0.071766    0.024126    0.581169    
#> 224: 0.606530    1.024320    3.478277    0.544959    0.071753    0.024131    0.581101    
#> 225: 0.605187    1.022833    3.478707    0.542756    0.071738    0.024147    0.581644    
#> 226: 0.604884    1.021901    3.478709    0.541355    0.071615    0.024078    0.581830    
#> 227: 0.604456    1.021585    3.478841    0.538865    0.071691    0.023973    0.582029    
#> 228: 0.603884    1.022061    3.478459    0.536725    0.071368    0.023986    0.582000    
#> 229: 0.603431    1.022043    3.478352    0.536332    0.071089    0.023954    0.581771    
#> 230: 0.603253    1.021777    3.478468    0.534706    0.070700    0.023865    0.581863    
#> 231: 0.603015    1.022226    3.478430    0.532981    0.070424    0.023842    0.581762    
#> 232: 0.601752    1.022380    3.478190    0.530928    0.070239    0.023777    0.581836    
#> 233: 0.600795    1.021930    3.478010    0.531612    0.070287    0.023839    0.581624    
#> 234: 0.599188    1.022141    3.477700    0.530283    0.070132    0.023914    0.581467    
#> 235: 0.597697    1.022220    3.477401    0.528231    0.069927    0.023914    0.581155    
#> 236: 0.596767    1.022719    3.476976    0.527094    0.069801    0.023916    0.581264    
#> 237: 0.596520    1.022852    3.476927    0.525191    0.069840    0.023901    0.581727    
#> 238: 0.597254    1.022927    3.477059    0.527599    0.069878    0.023900    0.582242    
#> 239: 0.596837    1.023108    3.476922    0.529504    0.070212    0.023887    0.582073    
#> 240: 0.596877    1.022800    3.476918    0.531741    0.070358    0.023800    0.581709    
#> 241: 0.597040    1.022040    3.476962    0.533902    0.070788    0.023725    0.581637    
#> 242: 0.596824    1.021602    3.476740    0.535698    0.071294    0.023659    0.581952    
#> 243: 0.595646    1.021841    3.476469    0.533460    0.071992    0.023626    0.582223    
#> 244: 0.593754    1.022333    3.476384    0.531914    0.072117    0.023613    0.582635    
#> 245: 0.593375    1.022251    3.476484    0.530710    0.072490    0.023548    0.582804    
#> 246: 0.594228    1.022076    3.476672    0.530128    0.072827    0.023446    0.583118    
#> 247: 0.594656    1.021696    3.476900    0.529971    0.073180    0.023382    0.583559    
#> 248: 0.594740    1.021802    3.476907    0.528913    0.073351    0.023282    0.583641    
#> 249: 0.594338    1.021775    3.476974    0.527075    0.073594    0.023116    0.583646    
#> 250: 0.594744    1.022067    3.477149    0.525102    0.073866    0.022963    0.583833    
#> 251: 0.595603    1.022346    3.477446    0.524895    0.074006    0.022887    0.583834    
#> 252: 0.595985    1.022431    3.477821    0.523232    0.074257    0.022832    0.583890    
#> 253: 0.596488    1.022510    3.477975    0.522644    0.074476    0.022810    0.583734    
#> 254: 0.596817    1.022881    3.477909    0.522135    0.074478    0.022815    0.583768    
#> 255: 0.596546    1.023358    3.477816    0.521803    0.074474    0.022847    0.583828    
#> 256: 0.596088    1.023240    3.477817    0.520347    0.074481    0.022853    0.584184    
#> 257: 0.595548    1.022942    3.477803    0.519348    0.074547    0.022920    0.584179    
#> 258: 0.594943    1.022874    3.477781    0.517683    0.074480    0.022947    0.584073    
#> 259: 0.594658    1.022838    3.477713    0.517675    0.074432    0.023013    0.584059    
#> 260: 0.594429    1.023170    3.477709    0.517301    0.074376    0.023009    0.583972    
#> 261: 0.594850    1.023345    3.477803    0.517590    0.074405    0.022998    0.583994    
#> 262: 0.595140    1.023626    3.477680    0.518625    0.074328    0.022933    0.584118    
#> 263: 0.595014    1.024038    3.477704    0.518022    0.074576    0.022858    0.584250    
#> 264: 0.594887    1.024239    3.477683    0.517869    0.074968    0.022820    0.584312    
#> 265: 0.595034    1.024247    3.477502    0.519551    0.075584    0.022781    0.584386    
#> 266: 0.595242    1.023960    3.477473    0.520289    0.075681    0.022749    0.584415    
#> 267: 0.595656    1.023797    3.477595    0.521415    0.075794    0.022766    0.584343    
#> 268: 0.596025    1.023584    3.477671    0.522469    0.075741    0.022741    0.584437    
#> 269: 0.596019    1.023450    3.477614    0.523009    0.075711    0.022741    0.584609    
#> 270: 0.595853    1.023614    3.477493    0.523813    0.075651    0.022754    0.584647    
#> 271: 0.595710    1.023705    3.477372    0.524294    0.075528    0.022741    0.584946    
#> 272: 0.595859    1.023600    3.477366    0.525171    0.075446    0.022768    0.585310    
#> 273: 0.595474    1.023837    3.477253    0.525958    0.075396    0.022784    0.585448    
#> 274: 0.595589    1.024134    3.477206    0.526542    0.075349    0.022808    0.585460    
#> 275: 0.595503    1.024372    3.477090    0.527018    0.075275    0.022876    0.585379    
#> 276: 0.595659    1.024579    3.477106    0.528607    0.075210    0.022983    0.585242    
#> 277: 0.595469    1.024962    3.477153    0.528719    0.075174    0.023078    0.585210    
#> 278: 0.595448    1.024888    3.477347    0.528428    0.075156    0.023114    0.585298    
#> 279: 0.595457    1.024795    3.477521    0.527553    0.074955    0.023150    0.585619    
#> 280: 0.595546    1.024864    3.477671    0.527429    0.074838    0.023197    0.585471    
#> 281: 0.595518    1.024997    3.477767    0.526892    0.074752    0.023160    0.585470    
#> 282: 0.595766    1.025174    3.477843    0.526777    0.074777    0.023106    0.585473    
#> 283: 0.595802    1.025178    3.477939    0.526440    0.074806    0.023085    0.585804    
#> 284: 0.595417    1.024979    3.477949    0.526294    0.074774    0.023040    0.585909    
#> 285: 0.594883    1.025132    3.477780    0.525343    0.074741    0.022981    0.585952    
#> 286: 0.594249    1.025416    3.477596    0.524144    0.074790    0.022962    0.585948    
#> 287: 0.593374    1.025518    3.477374    0.522846    0.074778    0.023003    0.585999    
#> 288: 0.593429    1.025595    3.477231    0.522763    0.074971    0.022974    0.586013    
#> 289: 0.593506    1.025698    3.477192    0.522812    0.075019    0.022951    0.585960    
#> 290: 0.593566    1.025810    3.477212    0.522851    0.075136    0.022900    0.586072    
#> 291: 0.593633    1.026009    3.477227    0.522893    0.075162    0.022834    0.585896    
#> 292: 0.593671    1.026012    3.477229    0.522194    0.075072    0.022758    0.585886    
#> 293: 0.593447    1.026044    3.477173    0.521905    0.075030    0.022725    0.585774    
#> 294: 0.593096    1.026092    3.477039    0.521220    0.075069    0.022693    0.585729    
#> 295: 0.592601    1.025801    3.477010    0.520633    0.075086    0.022649    0.585695    
#> 296: 0.592268    1.025618    3.476950    0.519775    0.075086    0.022619    0.585722    
#> 297: 0.592233    1.025730    3.476927    0.519281    0.074981    0.022610    0.585669    
#> 298: 0.592230    1.025817    3.476899    0.519377    0.075018    0.022582    0.585596    
#> 299: 0.592176    1.026055    3.476796    0.519100    0.075028    0.022561    0.585459    
#> 300: 0.592304    1.025953    3.476846    0.518508    0.075011    0.022533    0.585352    
#> 301: 0.592624    1.025961    3.476852    0.518297    0.074977    0.022526    0.585187    
#> 302: 0.592506    1.025998    3.476824    0.517629    0.075083    0.022519    0.585073    
#> 303: 0.592220    1.026056    3.476722    0.517294    0.075055    0.022489    0.584940    
#> 304: 0.591993    1.026388    3.476574    0.516956    0.075101    0.022503    0.584860    
#> 305: 0.592003    1.026226    3.476536    0.517041    0.075111    0.022545    0.584800    
#> 306: 0.591853    1.026108    3.476408    0.516990    0.075086    0.022596    0.584685    
#> 307: 0.591535    1.026172    3.476304    0.517223    0.075092    0.022632    0.584744    
#> 308: 0.591252    1.026054    3.476222    0.516803    0.075109    0.022663    0.584828    
#> 309: 0.591272    1.025922    3.476336    0.516900    0.075203    0.022668    0.584968    
#> 310: 0.591332    1.025847    3.476365    0.515971    0.075316    0.022672    0.585000    
#> 311: 0.591471    1.025646    3.476495    0.515827    0.075402    0.022653    0.585012    
#> 312: 0.591471    1.025405    3.476505    0.516079    0.075461    0.022595    0.585147    
#> 313: 0.591391    1.024981    3.476571    0.515826    0.075495    0.022575    0.585262    
#> 314: 0.591296    1.024752    3.476637    0.515324    0.075595    0.022561    0.585319    
#> 315: 0.591198    1.024745    3.476581    0.514978    0.075757    0.022579    0.585359    
#> 316: 0.591494    1.024707    3.476590    0.515202    0.075756    0.022604    0.585199    
#> 317: 0.591794    1.024533    3.476697    0.515274    0.075730    0.022598    0.585145    
#> 318: 0.591963    1.024516    3.476692    0.515439    0.075740    0.022579    0.585089    
#> 319: 0.592048    1.024431    3.476725    0.516111    0.075682    0.022573    0.585148    
#> 320: 0.592043    1.024187    3.476764    0.516639    0.075578    0.022550    0.585230    
#> 321: 0.592074    1.024191    3.476670    0.516678    0.075510    0.022519    0.585310    
#> 322: 0.592039    1.024038    3.476630    0.516175    0.075511    0.022513    0.585365    
#> 323: 0.591864    1.023929    3.476601    0.515527    0.075522    0.022521    0.585348    
#> 324: 0.591757    1.023964    3.476621    0.515352    0.075579    0.022493    0.585297    
#> 325: 0.591599    1.024174    3.476586    0.514860    0.075586    0.022457    0.585295    
#> 326: 0.591368    1.024062    3.476529    0.514069    0.075683    0.022437    0.585299    
#> 327: 0.591382    1.023950    3.476574    0.513407    0.075649    0.022404    0.585267    
#> 328: 0.591361    1.024005    3.476557    0.512898    0.075565    0.022391    0.585204    
#> 329: 0.591484    1.024019    3.476632    0.512633    0.075538    0.022376    0.585109    
#> 330: 0.591131    1.024047    3.476618    0.512307    0.075506    0.022334    0.585073    
#> 331: 0.591090    1.024206    3.476610    0.512311    0.075499    0.022302    0.585095    
#> 332: 0.591169    1.024309    3.476691    0.512559    0.075520    0.022298    0.585197    
#> 333: 0.591031    1.024338    3.476668    0.512152    0.075512    0.022318    0.585162    
#> 334: 0.590785    1.024170    3.476561    0.512048    0.075506    0.022328    0.585254    
#> 335: 0.590555    1.024207    3.476430    0.512029    0.075519    0.022335    0.585292    
#> 336: 0.590155    1.024368    3.476334    0.511861    0.075591    0.022324    0.585467    
#> 337: 0.589864    1.024621    3.476216    0.511524    0.075663    0.022326    0.585525    
#> 338: 0.589554    1.024643    3.476205    0.511478    0.075614    0.022333    0.585549    
#> 339: 0.589345    1.024725    3.476131    0.511740    0.075555    0.022330    0.585512    
#> 340: 0.589230    1.024421    3.476174    0.511271    0.075443    0.022360    0.585557    
#> 341: 0.589377    1.024386    3.476237    0.511277    0.075364    0.022367    0.585585    
#> 342: 0.589193    1.024288    3.476270    0.510960    0.075396    0.022359    0.585599    
#> 343: 0.589040    1.024345    3.476279    0.510593    0.075424    0.022359    0.585608    
#> 344: 0.589009    1.024391    3.476303    0.510812    0.075406    0.022348    0.585566    
#> 345: 0.588935    1.024328    3.476299    0.510676    0.075363    0.022314    0.585556    
#> 346: 0.588722    1.024378    3.476219    0.510203    0.075287    0.022298    0.585577    
#> 347: 0.588420    1.024319    3.476188    0.510030    0.075230    0.022306    0.585695    
#> 348: 0.588121    1.024389    3.476146    0.509683    0.075178    0.022312    0.585777    
#> 349: 0.587806    1.024336    3.476092    0.509375    0.075134    0.022308    0.585758    
#> 350: 0.587693    1.024251    3.476072    0.509369    0.075079    0.022305    0.585804    
#> 351: 0.587688    1.024364    3.476048    0.509085    0.075021    0.022282    0.585933    
#> 352: 0.587565    1.024434    3.476080    0.508637    0.075001    0.022294    0.586034    
#> 353: 0.587559    1.024578    3.476066    0.508406    0.075022    0.022282    0.586025    
#> 354: 0.587388    1.024709    3.475901    0.508370    0.075095    0.022254    0.586060    
#> 355: 0.587608    1.024647    3.475860    0.508506    0.075115    0.022291    0.586120    
#> 356: 0.587618    1.024502    3.475873    0.508972    0.075089    0.022288    0.586181    
#> 357: 0.587854    1.024584    3.475865    0.509333    0.075131    0.022307    0.586180    
#> 358: 0.587676    1.024690    3.475769    0.509512    0.075140    0.022311    0.586161    
#> 359: 0.587451    1.024922    3.475668    0.509801    0.075210    0.022297    0.586201    
#> 360: 0.587217    1.025059    3.475483    0.509796    0.075223    0.022272    0.586190    
#> 361: 0.587080    1.025193    3.475393    0.509626    0.075244    0.022237    0.586240    
#> 362: 0.586857    1.025276    3.475282    0.509347    0.075278    0.022214    0.586162    
#> 363: 0.586700    1.025342    3.475265    0.509180    0.075255    0.022196    0.586053    
#> 364: 0.586594    1.025438    3.475220    0.508646    0.075214    0.022178    0.586110    
#> 365: 0.586369    1.025465    3.475195    0.508084    0.075254    0.022142    0.586206    
#> 366: 0.586171    1.025547    3.475077    0.507889    0.075253    0.022098    0.586323    
#> 367: 0.586225    1.025589    3.475050    0.507568    0.075284    0.022061    0.586396    
#> 368: 0.586314    1.025602    3.475046    0.506790    0.075256    0.022050    0.586479    
#> 369: 0.586059    1.025612    3.475034    0.506259    0.075202    0.022046    0.586636    
#> 370: 0.585919    1.025771    3.475004    0.505943    0.075189    0.022054    0.586695    
#> 371: 0.585994    1.025882    3.474982    0.505944    0.075215    0.022053    0.586713    
#> 372: 0.586026    1.025862    3.474951    0.506558    0.075242    0.022046    0.586692    
#> 373: 0.585766    1.025946    3.474884    0.506445    0.075288    0.022037    0.586697    
#> 374: 0.585685    1.025931    3.474833    0.506488    0.075265    0.022033    0.586569    
#> 375: 0.585545    1.025968    3.474785    0.506453    0.075241    0.022046    0.586434    
#> 376: 0.585572    1.026006    3.474797    0.506607    0.075293    0.022053    0.586274    
#> 377: 0.585471    1.026072    3.474764    0.506570    0.075272    0.022052    0.586300    
#> 378: 0.585254    1.026102    3.474691    0.506516    0.075221    0.022060    0.586241    
#> 379: 0.585196    1.026052    3.474672    0.506432    0.075184    0.022062    0.586233    
#> 380: 0.584933    1.026008    3.474627    0.506378    0.075148    0.022051    0.586312    
#> 381: 0.584544    1.026047    3.474553    0.505928    0.075204    0.022051    0.586351    
#> 382: 0.584335    1.026146    3.474520    0.505967    0.075103    0.022066    0.586247    
#> 383: 0.584198    1.026204    3.474430    0.506178    0.075042    0.022069    0.586124    
#> 384: 0.583976    1.026321    3.474360    0.506405    0.074980    0.022058    0.586021    
#> 385: 0.583879    1.026383    3.474320    0.506143    0.074923    0.022059    0.585968    
#> 386: 0.583995    1.026463    3.474317    0.506254    0.074951    0.022079    0.585993    
#> 387: 0.584017    1.026530    3.474371    0.506435    0.074923    0.022105    0.585987    
#> 388: 0.583947    1.026648    3.474368    0.506506    0.074894    0.022113    0.585908    
#> 389: 0.583724    1.026563    3.474307    0.506207    0.074884    0.022109    0.585923    
#> 390: 0.583433    1.026634    3.474249    0.505901    0.074883    0.022098    0.585946    
#> 391: 0.583334    1.026620    3.474198    0.505497    0.074877    0.022085    0.585903    
#> 392: 0.583238    1.026607    3.474209    0.505304    0.074885    0.022081    0.585880    
#> 393: 0.583189    1.026578    3.474180    0.505152    0.074860    0.022088    0.585840    
#> 394: 0.583088    1.026553    3.474135    0.504896    0.074862    0.022094    0.585842    
#> 395: 0.583066    1.026672    3.474103    0.504548    0.074868    0.022103    0.585795    
#> 396: 0.583022    1.026714    3.474118    0.504419    0.074883    0.022119    0.585722    
#> 397: 0.583043    1.026728    3.474137    0.504377    0.074862    0.022146    0.585708    
#> 398: 0.583045    1.026671    3.474181    0.504063    0.074811    0.022169    0.585624    
#> 399: 0.583013    1.026608    3.474265    0.503876    0.074761    0.022190    0.585541    
#> 400: 0.583154    1.026537    3.474344    0.503428    0.074727    0.022198    0.585510    
#> 401: 0.583397    1.026520    3.474382    0.503453    0.074774    0.022182    0.585574    
#> 402: 0.583454    1.026489    3.474406    0.503417    0.074813    0.022174    0.585622    
#> 403: 0.583693    1.026494    3.474428    0.503754    0.074837    0.022166    0.585609    
#> 404: 0.583767    1.026487    3.474389    0.503902    0.074892    0.022152    0.585674    
#> 405: 0.583651    1.026598    3.474354    0.503885    0.074964    0.022133    0.585733    
#> 406: 0.583674    1.026692    3.474320    0.503732    0.074964    0.022116    0.585935    
#> 407: 0.583590    1.026785    3.474310    0.503490    0.074960    0.022104    0.585984    
#> 408: 0.583687    1.026860    3.474323    0.503380    0.074940    0.022099    0.586038    
#> 409: 0.583697    1.026758    3.474323    0.503309    0.074894    0.022105    0.586023    
#> 410: 0.583664    1.026765    3.474267    0.503169    0.074861    0.022115    0.586063    
#> 411: 0.583766    1.026707    3.474256    0.503347    0.074864    0.022112    0.586065    
#> 412: 0.583774    1.026746    3.474275    0.503230    0.074857    0.022108    0.586145    
#> 413: 0.583782    1.026738    3.474320    0.503126    0.074869    0.022104    0.586231    
#> 414: 0.583815    1.026710    3.474406    0.503109    0.074884    0.022094    0.586313    
#> 415: 0.584037    1.026660    3.474476    0.502939    0.074945    0.022086    0.586265    
#> 416: 0.584193    1.026626    3.474582    0.502760    0.074983    0.022082    0.586228    
#> 417: 0.584213    1.026583    3.474624    0.502558    0.075002    0.022076    0.586215    
#> 418: 0.584091    1.026538    3.474634    0.502297    0.075034    0.022063    0.586127    
#> 419: 0.584226    1.026614    3.474659    0.502379    0.075017    0.022067    0.586036    
#> 420: 0.584335    1.026660    3.474681    0.502215    0.075008    0.022068    0.585941    
#> 421: 0.584349    1.026765    3.474695    0.502238    0.075016    0.022067    0.585871    
#> 422: 0.584495    1.026755    3.474724    0.502121    0.075024    0.022079    0.585838    
#> 423: 0.584460    1.026678    3.474770    0.501779    0.074985    0.022106    0.585900    
#> 424: 0.584415    1.026658    3.474745    0.501581    0.075006    0.022099    0.585857    
#> 425: 0.584277    1.026754    3.474651    0.501543    0.075066    0.022087    0.585863    
#> 426: 0.584038    1.026969    3.474558    0.501596    0.075112    0.022073    0.585830    
#> 427: 0.583770    1.027076    3.474500    0.501482    0.075128    0.022065    0.585778    
#> 428: 0.583572    1.027152    3.474495    0.501319    0.075097    0.022067    0.585791    
#> 429: 0.583400    1.027221    3.474491    0.501115    0.075071    0.022077    0.585795    
#> 430: 0.583255    1.027262    3.474438    0.501095    0.075029    0.022084    0.585837    
#> 431: 0.583157    1.027260    3.474384    0.501069    0.075052    0.022080    0.585715    
#> 432: 0.582971    1.027341    3.474358    0.500911    0.075096    0.022068    0.585675    
#> 433: 0.582872    1.027418    3.474365    0.500820    0.075169    0.022051    0.585770    
#> 434: 0.582754    1.027356    3.474373    0.500732    0.075147    0.022048    0.585737    
#> 435: 0.582783    1.027342    3.474337    0.501015    0.075124    0.022062    0.585721    
#> 436: 0.582848    1.027297    3.474352    0.500863    0.075195    0.022060    0.585755    
#> 437: 0.582823    1.027239    3.474364    0.500806    0.075236    0.022058    0.585820    
#> 438: 0.582610    1.027371    3.474324    0.500503    0.075269    0.022056    0.585868    
#> 439: 0.582557    1.027482    3.474325    0.500465    0.075297    0.022074    0.585797    
#> 440: 0.582628    1.027507    3.474343    0.500437    0.075272    0.022079    0.585736    
#> 441: 0.582626    1.027518    3.474356    0.500627    0.075304    0.022096    0.585658    
#> 442: 0.582579    1.027556    3.474359    0.501001    0.075303    0.022093    0.585608    
#> 443: 0.582606    1.027608    3.474340    0.501007    0.075286    0.022098    0.585524    
#> 444: 0.582565    1.027707    3.474275    0.501078    0.075319    0.022100    0.585444    
#> 445: 0.582500    1.027809    3.474262    0.501094    0.075334    0.022104    0.585447    
#> 446: 0.582502    1.027857    3.474274    0.501063    0.075349    0.022104    0.585418    
#> 447: 0.582574    1.027864    3.474290    0.500968    0.075363    0.022115    0.585404    
#> 448: 0.582659    1.027844    3.474343    0.501042    0.075384    0.022120    0.585326    
#> 449: 0.582872    1.027912    3.474427    0.501480    0.075420    0.022129    0.585286    
#> 450: 0.582826    1.027907    3.474442    0.501447    0.075429    0.022135    0.585258    
#> 451: 0.582920    1.027885    3.474458    0.501613    0.075417    0.022146    0.585237    
#> 452: 0.582979    1.027863    3.474471    0.502163    0.075381    0.022152    0.585179    
#> 453: 0.582989    1.027874    3.474410    0.502864    0.075383    0.022151    0.585121    
#> 454: 0.582908    1.027952    3.474333    0.502992    0.075430    0.022158    0.585096    
#> 455: 0.582784    1.028054    3.474264    0.502886    0.075442    0.022160    0.585155    
#> 456: 0.582687    1.028049    3.474233    0.502890    0.075476    0.022155    0.585196    
#> 457: 0.582549    1.028054    3.474220    0.502628    0.075457    0.022169    0.585195    
#> 458: 0.582482    1.028198    3.474245    0.502421    0.075450    0.022184    0.585175    
#> 459: 0.582393    1.028270    3.474217    0.502477    0.075417    0.022191    0.585167    
#> 460: 0.582243    1.028273    3.474183    0.502378    0.075406    0.022203    0.585148    
#> 461: 0.582152    1.028326    3.474202    0.502090    0.075444    0.022206    0.585091    
#> 462: 0.582101    1.028365    3.474220    0.501958    0.075425    0.022211    0.585048    
#> 463: 0.582196    1.028391    3.474286    0.501858    0.075395    0.022211    0.585000    
#> 464: 0.582362    1.028398    3.474309    0.501760    0.075365    0.022217    0.584953    
#> 465: 0.582470    1.028268    3.474377    0.501609    0.075330    0.022211    0.584923    
#> 466: 0.582542    1.028216    3.474413    0.501453    0.075317    0.022215    0.584907    
#> 467: 0.582527    1.028167    3.474495    0.501238    0.075302    0.022230    0.584870    
#> 468: 0.582781    1.028183    3.474566    0.501396    0.075291    0.022250    0.584849    
#> 469: 0.583023    1.028259    3.474619    0.501614    0.075301    0.022271    0.584878    
#> 470: 0.582996    1.028283    3.474627    0.501631    0.075303    0.022311    0.584881    
#> 471: 0.582866    1.028287    3.474615    0.501373    0.075295    0.022344    0.584934    
#> 472: 0.582828    1.028262    3.474588    0.501299    0.075308    0.022384    0.584956    
#> 473: 0.582654    1.028256    3.474560    0.501233    0.075274    0.022404    0.584937    
#> 474: 0.582682    1.028170    3.474581    0.501286    0.075262    0.022425    0.584965    
#> 475: 0.582811    1.028192    3.474576    0.501476    0.075287    0.022439    0.584994    
#> 476: 0.582888    1.028127    3.474574    0.501595    0.075299    0.022454    0.585035    
#> 477: 0.582973    1.028097    3.474616    0.501600    0.075313    0.022469    0.585022    
#> 478: 0.583047    1.028034    3.474697    0.501304    0.075309    0.022479    0.585080    
#> 479: 0.583127    1.027995    3.474746    0.501236    0.075339    0.022492    0.585119    
#> 480: 0.583076    1.027919    3.474745    0.501006    0.075392    0.022494    0.585255    
#> 481: 0.583047    1.027931    3.474715    0.501049    0.075430    0.022494    0.585278    
#> 482: 0.583031    1.027935    3.474673    0.500981    0.075463    0.022493    0.585331    
#> 483: 0.582942    1.027937    3.474677    0.500930    0.075507    0.022500    0.585347    
#> 484: 0.582901    1.027831    3.474696    0.500998    0.075479    0.022513    0.585352    
#> 485: 0.582955    1.027861    3.474681    0.501097    0.075498    0.022520    0.585358    
#> 486: 0.583113    1.027890    3.474690    0.501389    0.075479    0.022537    0.585292    
#> 487: 0.583258    1.027898    3.474749    0.501498    0.075473    0.022552    0.585237    
#> 488: 0.583359    1.027938    3.474770    0.501717    0.075503    0.022547    0.585190    
#> 489: 0.583557    1.027912    3.474746    0.501959    0.075507    0.022545    0.585190    
#> 490: 0.583721    1.027945    3.474764    0.502093    0.075558    0.022543    0.585147    
#> 491: 0.583870    1.027986    3.474807    0.502271    0.075613    0.022526    0.585142    
#> 492: 0.583921    1.028082    3.474781    0.502308    0.075654    0.022506    0.585148    
#> 493: 0.583879    1.028056    3.474763    0.502317    0.075705    0.022494    0.585135    
#> 494: 0.583862    1.028038    3.474749    0.502464    0.075735    0.022493    0.585131    
#> 495: 0.583863    1.028052    3.474718    0.502627    0.075744    0.022481    0.585104    
#> 496: 0.583873    1.028076    3.474691    0.502612    0.075774    0.022469    0.585087    
#> 497: 0.583841    1.028016    3.474695    0.502386    0.075771    0.022452    0.585128    
#> 498: 0.583845    1.027985    3.474677    0.502238    0.075778    0.022446    0.585079    
#> 499: 0.583768    1.028004    3.474643    0.501947    0.075748    0.022448    0.585051    
#> 500: 0.583801    1.028003    3.474617    0.502265    0.075716    0.022450    0.585026    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.292619    0.967784    3.436924    0.392401    0.095452    0.016800    1.755654    
#> 002: 0.350978    0.963573    3.448351    0.372781    0.090680    0.017105    1.178037    
#> 003: 0.498355    0.896864    3.447812    0.354142    0.086146    0.016249    0.924725    
#> 004: 0.407813    0.927296    3.439613    0.336435    0.081838    0.015437    0.847697    
#> 005: 0.461376    0.921738    3.429260    0.319613    0.077746    0.014665    0.814414    
#> 006: 0.400941    0.919259    3.425448    0.303633    0.073859    0.013932    0.800321    
#> 007: 0.373977    0.936005    3.415641    0.288451    0.076097    0.013235    0.837934    
#> 008: 0.373922    0.916566    3.407551    0.274029    0.072292    0.012573    0.839847    
#> 009: 0.337429    0.893842    3.407120    0.260327    0.068807    0.011945    0.835916    
#> 010: 0.366701    0.914236    3.401473    0.247311    0.065367    0.011348    0.864565    
#> 011: 0.412355    0.934625    3.407178    0.234945    0.062098    0.012016    0.830250    
#> 012: 0.411949    0.926061    3.405504    0.223198    0.069654    0.011415    0.827414    
#> 013: 0.357263    0.932112    3.401038    0.212038    0.066172    0.010844    0.820692    
#> 014: 0.407575    0.932132    3.415941    0.201436    0.078790    0.010302    0.859295    
#> 015: 0.394145    0.937476    3.424408    0.191364    0.080477    0.009787    0.810905    
#> 016: 0.397755    0.950305    3.423637    0.181796    0.077879    0.009298    0.819712    
#> 017: 0.416412    0.921716    3.425234    0.172706    0.082239    0.008833    0.820182    
#> 018: 0.412522    0.920688    3.412372    0.164071    0.084046    0.008391    0.817321    
#> 019: 0.368078    0.929997    3.409457    0.155867    0.079844    0.007971    0.831162    
#> 020: 0.381419    0.926690    3.424447    0.148074    0.075852    0.007573    0.843982    
#> 021: 0.418723    0.908702    3.429003    0.140670    0.086766    0.007194    0.813309    
#> 022: 0.446131    0.916403    3.437535    0.157012    0.092291    0.006835    0.813380    
#> 023: 0.477330    0.910886    3.438019    0.163800    0.091370    0.007192    0.852340    
#> 024: 0.524546    0.916504    3.440905    0.155610    0.086802    0.006832    0.846551    
#> 025: 0.458525    0.883010    3.443281    0.147830    0.082462    0.006490    0.859407    
#> 026: 0.421177    0.909151    3.433998    0.140438    0.083981    0.006997    0.834917    
#> 027: 0.419560    0.945047    3.430801    0.133416    0.079782    0.006647    0.851254    
#> 028: 0.478670    0.915497    3.446991    0.126745    0.075793    0.008493    0.830320    
#> 029: 0.466211    0.908658    3.436184    0.129893    0.078867    0.008171    0.838606    
#> 030: 0.480829    0.911423    3.437165    0.145923    0.077885    0.007762    0.826251    
#> 031: 0.446575    0.904180    3.433786    0.138627    0.082589    0.007374    0.848997    
#> 032: 0.421500    0.887605    3.441572    0.131695    0.078511    0.007005    0.835990    
#> 033: 0.419070    0.920350    3.429496    0.132790    0.074585    0.006872    0.837159    
#> 034: 0.426062    0.926334    3.423892    0.131278    0.070856    0.006528    0.851126    
#> 035: 0.412050    0.906659    3.421669    0.124714    0.067313    0.006202    0.818870    
#> 036: 0.372646    0.917324    3.415348    0.128308    0.078410    0.005892    0.837641    
#> 037: 0.361297    0.910256    3.418867    0.122300    0.074489    0.005615    0.859761    
#> 038: 0.382619    0.925197    3.405757    0.135439    0.076355    0.005842    0.841569    
#> 039: 0.419794    0.904220    3.422733    0.131896    0.074464    0.006382    0.819044    
#> 040: 0.405981    0.921389    3.429513    0.130906    0.074836    0.006063    0.834376    
#> 041: 0.392330    0.896580    3.433083    0.141527    0.071094    0.006736    0.827785    
#> 042: 0.454220    0.903493    3.435456    0.134451    0.072749    0.006399    0.811128    
#> 043: 0.400045    0.915094    3.426039    0.146435    0.069112    0.007838    0.811622    
#> 044: 0.389417    0.935799    3.424824    0.139113    0.065656    0.007791    0.816056    
#> 045: 0.386424    0.953249    3.411472    0.132157    0.062373    0.007932    0.850393    
#> 046: 0.425793    0.933821    3.417617    0.157499    0.066947    0.007536    0.849959    
#> 047: 0.395064    0.919708    3.407449    0.149624    0.063600    0.007159    0.846710    
#> 048: 0.395089    0.916780    3.419311    0.153584    0.069851    0.006801    0.849885    
#> 049: 0.399150    0.911444    3.429932    0.145905    0.078208    0.006670    0.863507    
#> 050: 0.464361    0.902997    3.430867    0.138610    0.082747    0.006337    0.866517    
#> 051: 0.427194    0.906328    3.423258    0.131679    0.087418    0.006459    0.860403    
#> 052: 0.415001    0.924019    3.427465    0.133842    0.083047    0.006136    0.847469    
#> 053: 0.432568    0.911602    3.429759    0.144725    0.090989    0.006565    0.839254    
#> 054: 0.390179    0.909158    3.433740    0.137489    0.104608    0.006501    0.835861    
#> 055: 0.388753    0.894850    3.427657    0.142081    0.099378    0.007114    0.849033    
#> 056: 0.409043    0.902082    3.422282    0.134977    0.094409    0.006758    0.854317    
#> 057: 0.395631    0.910669    3.429107    0.128228    0.089688    0.007209    0.839346    
#> 058: 0.399580    0.894806    3.413473    0.121817    0.097558    0.006848    0.835685    
#> 059: 0.459633    0.873284    3.432922    0.123976    0.092680    0.007855    0.846370    
#> 060: 0.436341    0.877124    3.441033    0.117778    0.098158    0.007462    0.856725    
#> 061: 0.459106    0.903870    3.432135    0.135806    0.103296    0.007674    0.853528    
#> 062: 0.409766    0.907473    3.442683    0.129016    0.100090    0.007608    0.872526    
#> 063: 0.451269    0.874328    3.438789    0.122565    0.095086    0.007227    0.880375    
#> 064: 0.444446    0.905317    3.434443    0.116437    0.090331    0.006866    0.879267    
#> 065: 0.419683    0.881317    3.422835    0.110615    0.097894    0.006523    0.856472    
#> 066: 0.423775    0.921542    3.427877    0.118098    0.092999    0.006196    0.859459    
#> 067: 0.394214    0.897051    3.414577    0.121699    0.093711    0.005887    0.846706    
#> 068: 0.340502    0.929347    3.417845    0.126886    0.095391    0.005993    0.855091    
#> 069: 0.325602    0.945634    3.404406    0.153823    0.090621    0.006813    0.863980    
#> 070: 0.378833    0.921658    3.419923    0.146132    0.099564    0.006472    0.841199    
#> 071: 0.379130    0.950850    3.397749    0.153621    0.094854    0.006759    0.842137    
#> 072: 0.311467    0.915919    3.395616    0.174899    0.090111    0.006421    0.825646    
#> 073: 0.395166    0.933428    3.418073    0.166154    0.085606    0.006100    0.840218    
#> 074: 0.370691    0.905476    3.429221    0.157847    0.081325    0.005795    0.845954    
#> 075: 0.414213    0.896855    3.443874    0.149954    0.079970    0.005505    0.843868    
#> 076: 0.447674    0.907018    3.452430    0.144032    0.075972    0.005230    0.833897    
#> 077: 0.453101    0.888732    3.440001    0.140490    0.072173    0.005344    0.844068    
#> 078: 0.442311    0.920850    3.437227    0.133465    0.071638    0.006413    0.839659    
#> 079: 0.451907    0.936301    3.444698    0.126792    0.069519    0.007387    0.845564    
#> 080: 0.444610    0.910379    3.431976    0.145161    0.069161    0.008002    0.859662    
#> 081: 0.431537    0.920295    3.429771    0.138620    0.075386    0.008691    0.839691    
#> 082: 0.422662    0.888339    3.446405    0.162430    0.084020    0.008256    0.841040    
#> 083: 0.453418    0.914379    3.446271    0.154308    0.079819    0.007843    0.851977    
#> 084: 0.452873    0.918338    3.435931    0.148459    0.075828    0.008596    0.825605    
#> 085: 0.424751    0.915748    3.435978    0.141036    0.074649    0.009236    0.844072    
#> 086: 0.426307    0.912255    3.437990    0.134013    0.070916    0.008774    0.848308    
#> 087: 0.421352    0.911336    3.427392    0.143380    0.070388    0.008336    0.826715    
#> 088: 0.400882    0.899273    3.439909    0.156969    0.072493    0.008860    0.858949    
#> 089: 0.427567    0.925331    3.426353    0.173619    0.072338    0.008417    0.848662    
#> 090: 0.366878    0.925642    3.416768    0.164938    0.082200    0.007997    0.837506    
#> 091: 0.375164    0.900132    3.410592    0.156691    0.090258    0.007597    0.822901    
#> 092: 0.384660    0.942790    3.408188    0.168199    0.086182    0.007217    0.837325    
#> 093: 0.359951    0.924646    3.406988    0.159789    0.081873    0.006856    0.833393    
#> 094: 0.338736    0.955823    3.396856    0.151799    0.087143    0.006513    0.826642    
#> 095: 0.355290    0.954382    3.407144    0.144209    0.092849    0.006188    0.833407    
#> 096: 0.346518    0.951140    3.407500    0.136999    0.100899    0.005878    0.825718    
#> 097: 0.385566    0.949905    3.407383    0.130149    0.095854    0.005584    0.821169    
#> 098: 0.373882    0.961015    3.414258    0.141984    0.091061    0.006109    0.848692    
#> 099: 0.386369    0.915032    3.407449    0.134885    0.099068    0.006939    0.842022    
#> 100: 0.405133    0.904790    3.413737    0.128140    0.102223    0.007736    0.839688    
#> 101: 0.371585    0.922530    3.402356    0.123288    0.097112    0.007349    0.832588    
#> 102: 0.352260    0.945188    3.396741    0.145778    0.092257    0.006982    0.832652    
#> 103: 0.402495    0.935147    3.406239    0.150680    0.087644    0.006633    0.822224    
#> 104: 0.408756    0.940636    3.418909    0.166485    0.083262    0.006301    0.822693    
#> 105: 0.414249    0.933785    3.415450    0.158161    0.095661    0.005986    0.830802    
#> 106: 0.432060    0.924131    3.421045    0.150253    0.090878    0.005687    0.823838    
#> 107: 0.447084    0.917483    3.422585    0.142740    0.086334    0.006176    0.851292    
#> 108: 0.416678    0.923253    3.417681    0.135603    0.084104    0.005868    0.841136    
#> 109: 0.391193    0.927325    3.420129    0.151691    0.079899    0.005574    0.837844    
#> 110: 0.398292    0.921236    3.409508    0.144107    0.099641    0.005296    0.829133    
#> 111: 0.379384    0.928692    3.409067    0.141525    0.094659    0.005548    0.828334    
#> 112: 0.350701    0.888893    3.406924    0.134449    0.089926    0.005271    0.828243    
#> 113: 0.396222    0.936830    3.411752    0.127726    0.085429    0.005007    0.828069    
#> 114: 0.373958    0.936880    3.408393    0.121340    0.081158    0.005101    0.852321    
#> 115: 0.421760    0.907315    3.413580    0.115273    0.077100    0.004846    0.881106    
#> 116: 0.416489    0.918091    3.418761    0.132697    0.082257    0.004604    0.861776    
#> 117: 0.404509    0.934437    3.422491    0.126062    0.117259    0.004373    0.864414    
#> 118: 0.398225    0.935027    3.421487    0.119759    0.111396    0.004155    0.864515    
#> 119: 0.395540    0.926421    3.424627    0.113771    0.105826    0.004234    0.870378    
#> 120: 0.408704    0.896985    3.420867    0.114205    0.100535    0.004023    0.853141    
#> 121: 0.401148    0.956333    3.420679    0.108965    0.098521    0.003822    0.851859    
#> 122: 0.420011    0.920623    3.422092    0.144689    0.096548    0.003631    0.831201    
#> 123: 0.426168    0.932417    3.422855    0.137454    0.092958    0.003449    0.841251    
#> 124: 0.415060    0.973267    3.411939    0.130582    0.088310    0.003951    0.828739    
#> 125: 0.418147    0.953694    3.410601    0.124053    0.083894    0.004178    0.848221    
#> 126: 0.408968    0.959167    3.404294    0.117850    0.079700    0.004201    0.846256    
#> 127: 0.402371    0.935248    3.394102    0.111957    0.086900    0.003991    0.857809    
#> 128: 0.399052    0.935479    3.403856    0.108131    0.087492    0.004594    0.852547    
#> 129: 0.440511    0.952558    3.410501    0.103167    0.083118    0.004364    0.885350    
#> 130: 0.426333    0.955129    3.413249    0.098008    0.087982    0.004357    0.880347    
#> 131: 0.397858    0.914429    3.410326    0.105862    0.090014    0.004301    0.877236    
#> 132: 0.340921    0.940443    3.401877    0.103611    0.085513    0.004086    0.863530    
#> 133: 0.346130    0.923464    3.399072    0.099253    0.081237    0.003969    0.871193    
#> 134: 0.366145    0.918792    3.414000    0.103915    0.084729    0.004944    0.859536    
#> 135: 0.364453    0.920343    3.409671    0.124965    0.106337    0.004696    0.843291    
#> 136: 0.378677    0.915085    3.405656    0.118717    0.101020    0.004462    0.834855    
#> 137: 0.410184    0.913480    3.417562    0.132829    0.095969    0.004239    0.829380    
#> 138: 0.412990    0.931221    3.417196    0.131850    0.091171    0.004027    0.807843    
#> 139: 0.426209    0.934607    3.425742    0.142868    0.086612    0.003825    0.813169    
#> 140: 0.431224    0.949339    3.426918    0.182220    0.082281    0.004264    0.838623    
#> 141: 0.403213    0.921428    3.430358    0.173109    0.085638    0.004051    0.844107    
#> 142: 0.407317    0.923146    3.429946    0.164454    0.097132    0.003848    0.853811    
#> 143: 0.374692    0.922073    3.432863    0.156231    0.092275    0.003657    0.866416    
#> 144: 0.430853    0.932717    3.437724    0.148420    0.087662    0.003474    0.832063    
#> 145: 0.414078    0.954235    3.424165    0.140999    0.083279    0.003301    0.823997    
#> 146: 0.416594    0.935804    3.429309    0.133949    0.079115    0.003136    0.840979    
#> 147: 0.387283    0.907270    3.425797    0.129493    0.076795    0.002979    0.827870    
#> 148: 0.412449    0.929194    3.430656    0.123019    0.072955    0.003512    0.826565    
#> 149: 0.414940    0.933078    3.428377    0.116868    0.072885    0.004190    0.834039    
#> 150: 0.414443    0.927317    3.417951    0.158373    0.098073    0.004520    0.828051    
#> 151: 0.357651    0.956738    3.408768    0.150454    0.093169    0.004294    0.853541    
#> 152: 0.372819    0.930773    3.405544    0.117073    0.071918    0.003915    0.846484    
#> 153: 0.366275    0.951472    3.401992    0.128912    0.080427    0.003714    0.822860    
#> 154: 0.388743    0.946745    3.403993    0.126850    0.073647    0.004622    0.849799    
#> 155: 0.337461    0.926933    3.400188    0.129489    0.097592    0.004804    0.836377    
#> 156: 0.349553    0.949403    3.405115    0.147376    0.095072    0.003748    0.838282    
#> 157: 0.409647    0.927629    3.420521    0.114044    0.113240    0.002540    0.857825    
#> 158: 0.410142    0.928393    3.420781    0.101443    0.094451    0.001982    0.843808    
#> 159: 0.405471    0.926417    3.420294    0.103526    0.088471    0.001733    0.835959    
#> 160: 0.449508    0.912429    3.427378    0.121121    0.086594    0.002133    0.846629    
#> 161: 0.393609    0.922575    3.427429    0.112765    0.103734    0.002718    0.829914    
#> 162: 0.402682    0.936657    3.411706    0.129615    0.098549    0.001810    0.845538    
#> 163: 0.403734    0.926481    3.409007    0.150672    0.110472    0.001908    0.825254    
#> 164: 0.381246    0.930213    3.409006    0.123435    0.104842    0.001508    0.852817    
#> 165: 0.418892    0.921588    3.418254    0.124497    0.102525    0.001282    0.835057    
#> 166: 0.429165    0.955884    3.417453    0.107854    0.110754    0.001192    0.848803    
#> 167: 0.409203    0.954666    3.418968    0.102032    0.105782    0.001564    0.859005    
#> 168: 0.421125    0.930033    3.420886    0.119275    0.111361    0.001649    0.861704    
#> 169: 0.408960    0.968143    3.414465    0.150284    0.125906    0.001708    0.872131    
#> 170: 0.434834    0.937593    3.416914    0.127362    0.128163    0.001694    0.840091    
#> 171: 0.410358    0.917744    3.411726    0.119372    0.101842    0.001563    0.826153    
#> 172: 0.381573    0.934032    3.409642    0.122030    0.099028    0.001641    0.818515    
#> 173: 0.381511    0.936867    3.405657    0.094075    0.092060    0.002145    0.838458    
#> 174: 0.389864    0.949156    3.404622    0.106184    0.092662    0.002087    0.841544    
#> 175: 0.365729    0.946205    3.400552    0.110829    0.078170    0.001834    0.851861    
#> 176: 0.364733    0.952986    3.399259    0.157325    0.094705    0.001853    0.837433    
#> 177: 0.372729    0.949658    3.403394    0.131186    0.081867    0.001374    0.838301    
#> 178: 0.375995    0.937819    3.404072    0.142304    0.090544    0.001260    0.843295    
#> 179: 0.374946    0.949632    3.405360    0.148931    0.095862    0.001481    0.837089    
#> 180: 0.366211    0.935296    3.410431    0.160763    0.077897    0.001059    0.848579    
#> 181: 0.379819    0.914654    3.405809    0.115358    0.094078    0.000724    0.841472    
#> 182: 0.357889    0.936823    3.403157    0.117679    0.090359    0.000705    0.863613    
#> 183: 0.376143    0.949669    3.402110    0.099203    0.078301    0.000797    0.852732    
#> 184: 0.364596    0.947863    3.401750    0.134110    0.097053    0.000841    0.848739    
#> 185: 0.366191    0.956282    3.397573    0.105999    0.115169    0.001118    0.851398    
#> 186: 0.371400    0.974794    3.405213    0.101637    0.107213    0.000912    0.860863    
#> 187: 0.382409    0.933870    3.409050    0.106771    0.107041    0.000822    0.845262    
#> 188: 0.337646    0.964708    3.397848    0.134457    0.110113    0.000886    0.840448    
#> 189: 0.394510    0.958355    3.396397    0.138812    0.098782    0.000994    0.841906    
#> 190: 0.362946    0.944189    3.403114    0.151096    0.095652    0.001176    0.841207    
#> 191: 0.365154    0.942862    3.400694    0.090608    0.082879    0.000931    0.866875    
#> 192: 0.348160    0.946002    3.402802    0.079844    0.082066    0.000937    0.858933    
#> 193: 0.371799    0.960371    3.406375    0.097934    0.085040    0.001087    0.830399    
#> 194: 0.357156    0.948283    3.402702    0.115427    0.091279    0.001456    0.860335    
#> 195: 0.359524    0.931499    3.398582    0.112419    0.088755    0.001470    0.858968    
#> 196: 0.362820    0.929355    3.404375    0.107164    0.089266    0.001572    0.869625    
#> 197: 0.344726    0.942642    3.415809    0.111604    0.088168    0.001449    0.875916    
#> 198: 0.401713    0.936881    3.402704    0.099307    0.100407    0.001345    0.870151    
#> 199: 0.354096    0.936724    3.402234    0.112513    0.080340    0.001423    0.859600    
#> 200: 0.362353    0.938024    3.400093    0.105385    0.113997    0.001658    0.856810    
#> 201: 0.348402    0.942222    3.396648    0.097984    0.109728    0.002036    0.847408    
#> 202: 0.349200    0.948193    3.396245    0.099569    0.105287    0.001992    0.850469    
#> 203: 0.353747    0.946150    3.396988    0.100435    0.104008    0.002128    0.853872    
#> 204: 0.362139    0.939505    3.398245    0.100547    0.105049    0.002136    0.856240    
#> 205: 0.360856    0.943180    3.397001    0.099838    0.102726    0.002182    0.860735    
#> 206: 0.360683    0.945738    3.396659    0.102248    0.099254    0.002260    0.863226    
#> 207: 0.360474    0.941389    3.396691    0.102779    0.101364    0.002304    0.865342    
#> 208: 0.361857    0.941307    3.397049    0.106513    0.099165    0.002404    0.862365    
#> 209: 0.365148    0.939659    3.397200    0.109750    0.096812    0.002507    0.859541    
#> 210: 0.367449    0.938834    3.397187    0.110539    0.096315    0.002548    0.856874    
#> 211: 0.366233    0.940989    3.397319    0.110186    0.097031    0.002556    0.855078    
#> 212: 0.366263    0.941065    3.397294    0.110227    0.097656    0.002541    0.853995    
#> 213: 0.366987    0.939672    3.397352    0.112163    0.096240    0.002652    0.853836    
#> 214: 0.369393    0.939280    3.397514    0.114211    0.094947    0.002735    0.853230    
#> 215: 0.370553    0.939604    3.397815    0.115816    0.093932    0.002841    0.851875    
#> 216: 0.372797    0.937227    3.398297    0.116786    0.094466    0.002881    0.851663    
#> 217: 0.374995    0.938132    3.398558    0.116736    0.095046    0.002957    0.850208    
#> 218: 0.376681    0.938758    3.398556    0.117718    0.096440    0.002992    0.848657    
#> 219: 0.376861    0.937733    3.398291    0.119004    0.096054    0.003003    0.847525    
#> 220: 0.376636    0.938075    3.398681    0.119334    0.095895    0.003068    0.847036    
#> 221: 0.375423    0.939537    3.398589    0.119541    0.095683    0.003085    0.845517    
#> 222: 0.375436    0.939375    3.398570    0.120946    0.095418    0.003087    0.844883    
#> 223: 0.376645    0.939512    3.398657    0.122039    0.094685    0.003082    0.844103    
#> 224: 0.377499    0.939864    3.399042    0.122550    0.094132    0.003077    0.843707    
#> 225: 0.377386    0.938251    3.399440    0.122329    0.094166    0.003070    0.843991    
#> 226: 0.376985    0.937254    3.399406    0.121781    0.093833    0.003033    0.844029    
#> 227: 0.375887    0.936506    3.399805    0.121836    0.094065    0.002990    0.844780    
#> 228: 0.374752    0.937410    3.399744    0.120908    0.094322    0.003000    0.845019    
#> 229: 0.374641    0.936965    3.399812    0.120443    0.094313    0.003007    0.844462    
#> 230: 0.374472    0.936902    3.400047    0.120450    0.093965    0.002989    0.844411    
#> 231: 0.374550    0.937789    3.400234    0.120448    0.094157    0.002949    0.845165    
#> 232: 0.373540    0.937939    3.400515    0.121258    0.093927    0.002926    0.845393    
#> 233: 0.373968    0.936710    3.400901    0.120892    0.094184    0.002908    0.845753    
#> 234: 0.373865    0.936326    3.401264    0.120463    0.094721    0.002875    0.845918    
#> 235: 0.374679    0.935835    3.401356    0.120556    0.094517    0.002838    0.846203    
#> 236: 0.374891    0.936261    3.401463    0.120040    0.094593    0.002810    0.847365    
#> 237: 0.375642    0.936380    3.401517    0.120947    0.094593    0.002772    0.847877    
#> 238: 0.375473    0.936322    3.401611    0.121217    0.094853    0.002746    0.847975    
#> 239: 0.375786    0.936643    3.401777    0.121534    0.095049    0.002721    0.848149    
#> 240: 0.375730    0.936374    3.401796    0.120944    0.095048    0.002714    0.848284    
#> 241: 0.375942    0.935355    3.401936    0.120369    0.095246    0.002708    0.848534    
#> 242: 0.376010    0.934792    3.401914    0.120662    0.095811    0.002719    0.848713    
#> 243: 0.375271    0.935506    3.401725    0.120902    0.095976    0.002741    0.848814    
#> 244: 0.374853    0.935159    3.401865    0.120771    0.095431    0.002734    0.849503    
#> 245: 0.375759    0.934670    3.402075    0.121076    0.095103    0.002723    0.850259    
#> 246: 0.375970    0.934373    3.402263    0.121271    0.094609    0.002719    0.850324    
#> 247: 0.375671    0.933982    3.402389    0.121135    0.094487    0.002714    0.850085    
#> 248: 0.375798    0.934148    3.402440    0.120963    0.094652    0.002701    0.849953    
#> 249: 0.375459    0.934274    3.402427    0.121230    0.094651    0.002677    0.850322    
#> 250: 0.376037    0.935062    3.402481    0.121233    0.094668    0.002664    0.850464    
#> 251: 0.376410    0.935684    3.402657    0.121226    0.094808    0.002650    0.850792    
#> 252: 0.376582    0.935657    3.402837    0.121646    0.094707    0.002654    0.850605    
#> 253: 0.376486    0.935512    3.402957    0.121757    0.094331    0.002654    0.850593    
#> 254: 0.376437    0.935863    3.403087    0.121612    0.094279    0.002647    0.850323    
#> 255: 0.376663    0.935995    3.403412    0.121699    0.094360    0.002640    0.850039    
#> 256: 0.377137    0.935668    3.403540    0.121814    0.094642    0.002642    0.849757    
#> 257: 0.376976    0.935496    3.403646    0.121534    0.094637    0.002644    0.850036    
#> 258: 0.376471    0.935100    3.403628    0.121528    0.094481    0.002636    0.850086    
#> 259: 0.376426    0.935080    3.403629    0.121293    0.094136    0.002628    0.850429    
#> 260: 0.376065    0.935185    3.403687    0.121279    0.094088    0.002623    0.850249    
#> 261: 0.376314    0.935393    3.403763    0.121559    0.094145    0.002618    0.850114    
#> 262: 0.376298    0.935373    3.403759    0.121309    0.094121    0.002617    0.850410    
#> 263: 0.376478    0.935691    3.403797    0.121472    0.094046    0.002633    0.850110    
#> 264: 0.376316    0.935945    3.403780    0.121511    0.094155    0.002652    0.850214    
#> 265: 0.376330    0.936067    3.403795    0.121064    0.094393    0.002664    0.850325    
#> 266: 0.376509    0.936669    3.403655    0.120509    0.094283    0.002676    0.850532    
#> 267: 0.376676    0.936673    3.403726    0.120244    0.094254    0.002693    0.850422    
#> 268: 0.376810    0.936475    3.403682    0.120255    0.094132    0.002701    0.850725    
#> 269: 0.377345    0.936225    3.403739    0.119857    0.094089    0.002697    0.851068    
#> 270: 0.377665    0.936145    3.403625    0.119597    0.094043    0.002688    0.850897    
#> 271: 0.377744    0.936227    3.403522    0.119589    0.093861    0.002682    0.850941    
#> 272: 0.377773    0.935892    3.403468    0.119548    0.093635    0.002677    0.851250    
#> 273: 0.377883    0.935830    3.403432    0.119388    0.093627    0.002667    0.851308    
#> 274: 0.377741    0.935821    3.403450    0.119302    0.093680    0.002657    0.851249    
#> 275: 0.377730    0.936073    3.403374    0.119169    0.093874    0.002654    0.851173    
#> 276: 0.377599    0.935865    3.403481    0.118809    0.093922    0.002658    0.851064    
#> 277: 0.377649    0.936162    3.403643    0.118474    0.093828    0.002660    0.850889    
#> 278: 0.377760    0.936234    3.403809    0.118267    0.093677    0.002666    0.851157    
#> 279: 0.377796    0.936099    3.403955    0.118520    0.093487    0.002673    0.851416    
#> 280: 0.377788    0.936186    3.404047    0.118503    0.093146    0.002677    0.851221    
#> 281: 0.377646    0.936062    3.404154    0.118556    0.092936    0.002677    0.851045    
#> 282: 0.377691    0.936029    3.404269    0.118361    0.092786    0.002682    0.851121    
#> 283: 0.377972    0.936091    3.404383    0.118534    0.092779    0.002687    0.851333    
#> 284: 0.377820    0.935873    3.404457    0.118535    0.092564    0.002691    0.851249    
#> 285: 0.377948    0.935778    3.404372    0.118869    0.092443    0.002708    0.851352    
#> 286: 0.377878    0.936189    3.404199    0.118920    0.092249    0.002720    0.851395    
#> 287: 0.377565    0.936483    3.404020    0.118749    0.092084    0.002724    0.851504    
#> 288: 0.377536    0.936627    3.403930    0.118641    0.092120    0.002734    0.851485    
#> 289: 0.377678    0.936700    3.403871    0.118532    0.091906    0.002737    0.851464    
#> 290: 0.377363    0.936870    3.403886    0.118552    0.091852    0.002730    0.851546    
#> 291: 0.377413    0.936979    3.403879    0.118569    0.091786    0.002730    0.851472    
#> 292: 0.377451    0.937002    3.403860    0.118666    0.091583    0.002732    0.851465    
#> 293: 0.377407    0.936897    3.403842    0.118639    0.091354    0.002733    0.851407    
#> 294: 0.377654    0.936719    3.403915    0.118775    0.091193    0.002742    0.851397    
#> 295: 0.377621    0.936450    3.403879    0.118946    0.091170    0.002739    0.851348    
#> 296: 0.377825    0.936374    3.403962    0.119041    0.090998    0.002751    0.851405    
#> 297: 0.378088    0.936555    3.404009    0.119310    0.090737    0.002760    0.851274    
#> 298: 0.378379    0.936433    3.404070    0.119205    0.090600    0.002759    0.851089    
#> 299: 0.378538    0.936581    3.404126    0.119284    0.090512    0.002760    0.850803    
#> 300: 0.378960    0.936346    3.404271    0.119378    0.090363    0.002764    0.850628    
#> 301: 0.379495    0.936311    3.404292    0.119304    0.090282    0.002779    0.850528    
#> 302: 0.379556    0.936369    3.404230    0.119395    0.090177    0.002779    0.850455    
#> 303: 0.379312    0.936489    3.404207    0.119436    0.089916    0.002780    0.850344    
#> 304: 0.379486    0.936603    3.404187    0.119580    0.089940    0.002779    0.850113    
#> 305: 0.379445    0.936419    3.404196    0.119540    0.089871    0.002780    0.850230    
#> 306: 0.379247    0.936156    3.404189    0.119686    0.089813    0.002778    0.850100    
#> 307: 0.379188    0.936266    3.404082    0.119523    0.089709    0.002779    0.850135    
#> 308: 0.379070    0.936129    3.404088    0.119535    0.089668    0.002782    0.850155    
#> 309: 0.379063    0.935901    3.404083    0.119645    0.089781    0.002784    0.850012    
#> 310: 0.379031    0.935677    3.404029    0.119764    0.090010    0.002774    0.850018    
#> 311: 0.379116    0.935429    3.404113    0.119785    0.090113    0.002776    0.850034    
#> 312: 0.379067    0.935224    3.404154    0.119750    0.090016    0.002781    0.850068    
#> 313: 0.378919    0.934830    3.404163    0.119838    0.089937    0.002783    0.850148    
#> 314: 0.378708    0.934757    3.404125    0.119765    0.089932    0.002787    0.850237    
#> 315: 0.378534    0.934789    3.404084    0.119798    0.090005    0.002792    0.850246    
#> 316: 0.378538    0.935008    3.404089    0.119716    0.089959    0.002794    0.850249    
#> 317: 0.378520    0.934996    3.404163    0.119683    0.089894    0.002794    0.850354    
#> 318: 0.378608    0.935026    3.404197    0.119719    0.089866    0.002794    0.850201    
#> 319: 0.378745    0.935035    3.404249    0.119704    0.089674    0.002797    0.850171    
#> 320: 0.378342    0.935124    3.404182    0.119610    0.089692    0.002796    0.850194    
#> 321: 0.378006    0.935233    3.404039    0.119648    0.089629    0.002791    0.850329    
#> 322: 0.378004    0.935311    3.403902    0.119761    0.089794    0.002788    0.850149    
#> 323: 0.377310    0.935467    3.403756    0.120042    0.089888    0.002787    0.850216    
#> 324: 0.377270    0.935635    3.403727    0.120216    0.089915    0.002789    0.850150    
#> 325: 0.377297    0.935785    3.403677    0.120249    0.089876    0.002786    0.850129    
#> 326: 0.377282    0.935629    3.403629    0.120396    0.089919    0.002787    0.850232    
#> 327: 0.377482    0.935770    3.403655    0.120508    0.090100    0.002789    0.850198    
#> 328: 0.377606    0.936086    3.403654    0.120604    0.090095    0.002791    0.850159    
#> 329: 0.377721    0.936306    3.403661    0.120607    0.090234    0.002786    0.850294    
#> 330: 0.377388    0.936310    3.403638    0.120613    0.090389    0.002787    0.850519    
#> 331: 0.377241    0.936361    3.403650    0.120450    0.090469    0.002785    0.850499    
#> 332: 0.377266    0.936262    3.403688    0.120348    0.090491    0.002784    0.850495    
#> 333: 0.377017    0.936324    3.403689    0.120379    0.090388    0.002784    0.850387    
#> 334: 0.376899    0.936150    3.403674    0.120525    0.090443    0.002781    0.850390    
#> 335: 0.376830    0.936088    3.403639    0.120576    0.090457    0.002777    0.850422    
#> 336: 0.376780    0.936299    3.403651    0.120611    0.090484    0.002778    0.850365    
#> 337: 0.376946    0.936632    3.403643    0.120710    0.090547    0.002778    0.850243    
#> 338: 0.376928    0.936743    3.403658    0.120831    0.090626    0.002773    0.850210    
#> 339: 0.376745    0.936909    3.403630    0.120819    0.090648    0.002769    0.850131    
#> 340: 0.376664    0.936822    3.403661    0.120853    0.090811    0.002763    0.850083    
#> 341: 0.376761    0.936832    3.403722    0.120851    0.090782    0.002757    0.850260    
#> 342: 0.376481    0.936726    3.403683    0.120813    0.090756    0.002755    0.850160    
#> 343: 0.376161    0.936787    3.403718    0.120802    0.090690    0.002749    0.850237    
#> 344: 0.376197    0.936789    3.403742    0.120843    0.090800    0.002749    0.850315    
#> 345: 0.376148    0.936663    3.403760    0.120803    0.090845    0.002746    0.850255    
#> 346: 0.376189    0.936776    3.403749    0.120883    0.090775    0.002741    0.850185    
#> 347: 0.376183    0.936716    3.403655    0.120977    0.090719    0.002741    0.850238    
#> 348: 0.376251    0.936794    3.403646    0.120975    0.090674    0.002742    0.850285    
#> 349: 0.376464    0.936726    3.403620    0.121086    0.090660    0.002744    0.850295    
#> 350: 0.376513    0.936699    3.403617    0.121102    0.090601    0.002746    0.850332    
#> 351: 0.376629    0.936901    3.403571    0.120967    0.090565    0.002748    0.850327    
#> 352: 0.376463    0.936970    3.403564    0.121088    0.090584    0.002752    0.850401    
#> 353: 0.376478    0.937098    3.403544    0.121281    0.090593    0.002750    0.850340    
#> 354: 0.376545    0.937106    3.403463    0.121293    0.090588    0.002748    0.850282    
#> 355: 0.376598    0.937108    3.403383    0.121418    0.090630    0.002745    0.850358    
#> 356: 0.376371    0.937104    3.403358    0.121305    0.090807    0.002740    0.850472    
#> 357: 0.376649    0.937206    3.403368    0.121196    0.090881    0.002733    0.850516    
#> 358: 0.376720    0.937247    3.403416    0.121194    0.090968    0.002727    0.850378    
#> 359: 0.376688    0.937357    3.403425    0.121220    0.091067    0.002721    0.850332    
#> 360: 0.376593    0.937409    3.403384    0.121112    0.090999    0.002718    0.850269    
#> 361: 0.376281    0.937468    3.403334    0.121066    0.090926    0.002714    0.850299    
#> 362: 0.376273    0.937459    3.403328    0.121066    0.090821    0.002710    0.850230    
#> 363: 0.376255    0.937480    3.403307    0.121021    0.090839    0.002706    0.850087    
#> 364: 0.376270    0.937589    3.403288    0.121170    0.090829    0.002704    0.849960    
#> 365: 0.376297    0.937364    3.403392    0.121166    0.090951    0.002709    0.849947    
#> 366: 0.376260    0.937393    3.403398    0.121195    0.090818    0.002710    0.849867    
#> 367: 0.376308    0.937443    3.403383    0.121328    0.090809    0.002709    0.849826    
#> 368: 0.376530    0.937625    3.403355    0.121679    0.090828    0.002708    0.849652    
#> 369: 0.376594    0.937646    3.403365    0.121861    0.090835    0.002704    0.849617    
#> 370: 0.376624    0.937641    3.403382    0.121932    0.090960    0.002702    0.849507    
#> 371: 0.376456    0.937668    3.403339    0.121992    0.090946    0.002701    0.849498    
#> 372: 0.376393    0.937681    3.403297    0.121972    0.090986    0.002699    0.849447    
#> 373: 0.376279    0.937724    3.403251    0.122134    0.091024    0.002697    0.849487    
#> 374: 0.376175    0.937775    3.403196    0.122209    0.091034    0.002692    0.849462    
#> 375: 0.375943    0.937850    3.403137    0.122344    0.091059    0.002685    0.849481    
#> 376: 0.375876    0.937905    3.403126    0.122302    0.091172    0.002680    0.849444    
#> 377: 0.375964    0.937921    3.403123    0.122215    0.091297    0.002674    0.849487    
#> 378: 0.375966    0.937927    3.403089    0.122028    0.091309    0.002672    0.849612    
#> 379: 0.375889    0.937746    3.403108    0.121875    0.091300    0.002670    0.849561    
#> 380: 0.375585    0.937731    3.403050    0.121813    0.091365    0.002670    0.849456    
#> 381: 0.375382    0.937659    3.403052    0.121809    0.091416    0.002665    0.849439    
#> 382: 0.375519    0.937618    3.403038    0.121864    0.091410    0.002662    0.849372    
#> 383: 0.375663    0.937648    3.402998    0.121883    0.091553    0.002660    0.849344    
#> 384: 0.375598    0.937664    3.402986    0.121975    0.091507    0.002661    0.849320    
#> 385: 0.375476    0.937707    3.402962    0.122027    0.091471    0.002663    0.849305    
#> 386: 0.375510    0.938033    3.402947    0.121945    0.091443    0.002660    0.849309    
#> 387: 0.375568    0.938063    3.403021    0.121964    0.091349    0.002659    0.849270    
#> 388: 0.375646    0.938167    3.403058    0.121998    0.091332    0.002657    0.849217    
#> 389: 0.375778    0.938014    3.403069    0.122119    0.091320    0.002650    0.849245    
#> 390: 0.375611    0.938028    3.403039    0.122174    0.091362    0.002645    0.849195    
#> 391: 0.375656    0.937997    3.403039    0.122324    0.091356    0.002642    0.849055    
#> 392: 0.375728    0.938084    3.403064    0.122442    0.091399    0.002637    0.849060    
#> 393: 0.375603    0.938081    3.403034    0.122486    0.091369    0.002635    0.849024    
#> 394: 0.375528    0.938048    3.402989    0.122670    0.091343    0.002634    0.849048    
#> 395: 0.375739    0.938145    3.402995    0.122796    0.091360    0.002632    0.849044    
#> 396: 0.375901    0.938180    3.403040    0.122898    0.091384    0.002630    0.848962    
#> 397: 0.376133    0.938160    3.403133    0.122866    0.091371    0.002635    0.848914    
#> 398: 0.376301    0.938111    3.403194    0.122942    0.091342    0.002640    0.848889    
#> 399: 0.376520    0.938060    3.403285    0.122926    0.091282    0.002645    0.848925    
#> 400: 0.376730    0.938052    3.403338    0.122979    0.091298    0.002650    0.848885    
#> 401: 0.376885    0.938116    3.403353    0.122887    0.091356    0.002648    0.848882    
#> 402: 0.376816    0.938269    3.403361    0.122883    0.091384    0.002646    0.848932    
#> 403: 0.377062    0.938226    3.403412    0.122774    0.091489    0.002647    0.848989    
#> 404: 0.377402    0.938211    3.403442    0.122749    0.091501    0.002646    0.849019    
#> 405: 0.377408    0.938207    3.403480    0.122706    0.091549    0.002649    0.848920    
#> 406: 0.377484    0.938226    3.403518    0.122619    0.091589    0.002652    0.848986    
#> 407: 0.377644    0.938282    3.403559    0.122599    0.091593    0.002648    0.849074    
#> 408: 0.377693    0.938369    3.403587    0.122472    0.091592    0.002643    0.849165    
#> 409: 0.377653    0.938272    3.403584    0.122388    0.091540    0.002640    0.849174    
#> 410: 0.377654    0.938346    3.403524    0.122304    0.091526    0.002640    0.849162    
#> 411: 0.377658    0.938183    3.403460    0.122226    0.091554    0.002639    0.849309    
#> 412: 0.377740    0.938285    3.403403    0.122202    0.091494    0.002638    0.849315    
#> 413: 0.377661    0.938282    3.403365    0.122309    0.091537    0.002639    0.849369    
#> 414: 0.377595    0.938280    3.403360    0.122252    0.091531    0.002641    0.849357    
#> 415: 0.377778    0.938195    3.403381    0.122361    0.091561    0.002642    0.849306    
#> 416: 0.377973    0.938213    3.403412    0.122458    0.091551    0.002640    0.849198    
#> 417: 0.378169    0.938152    3.403470    0.122563    0.091564    0.002640    0.849157    
#> 418: 0.378062    0.938093    3.403468    0.122564    0.091644    0.002639    0.849115    
#> 419: 0.378145    0.938185    3.403448    0.122701    0.091567    0.002638    0.849167    
#> 420: 0.378352    0.938171    3.403466    0.122762    0.091625    0.002635    0.849079    
#> 421: 0.378428    0.938128    3.403509    0.122727    0.091748    0.002635    0.849016    
#> 422: 0.378505    0.938007    3.403522    0.122739    0.091785    0.002636    0.848947    
#> 423: 0.378602    0.937939    3.403545    0.122830    0.091827    0.002633    0.848897    
#> 424: 0.378550    0.937824    3.403528    0.122849    0.091868    0.002630    0.848845    
#> 425: 0.378767    0.937838    3.403544    0.123059    0.091878    0.002629    0.848902    
#> 426: 0.378932    0.937963    3.403562    0.123218    0.091874    0.002632    0.848885    
#> 427: 0.378832    0.937944    3.403539    0.123272    0.091776    0.002633    0.848807    
#> 428: 0.378681    0.938031    3.403507    0.123303    0.091757    0.002632    0.848750    
#> 429: 0.378491    0.938113    3.403477    0.123319    0.091806    0.002632    0.848711    
#> 430: 0.378416    0.938195    3.403442    0.123354    0.091841    0.002631    0.848695    
#> 431: 0.378366    0.938139    3.403399    0.123412    0.091846    0.002630    0.848630    
#> 432: 0.378334    0.938182    3.403390    0.123586    0.091880    0.002628    0.848504    
#> 433: 0.378434    0.938183    3.403425    0.123694    0.091860    0.002630    0.848431    
#> 434: 0.378323    0.938070    3.403469    0.123630    0.091818    0.002630    0.848470    
#> 435: 0.378376    0.938086    3.403496    0.123716    0.091734    0.002632    0.848420    
#> 436: 0.378298    0.937999    3.403512    0.123783    0.091779    0.002628    0.848469    
#> 437: 0.378323    0.937930    3.403529    0.123775    0.091717    0.002629    0.848436    
#> 438: 0.378418    0.938046    3.403567    0.123860    0.091634    0.002630    0.848452    
#> 439: 0.378437    0.938071    3.403592    0.123818    0.091630    0.002629    0.848349    
#> 440: 0.378357    0.938105    3.403625    0.123844    0.091612    0.002627    0.848298    
#> 441: 0.378434    0.938029    3.403661    0.123858    0.091699    0.002626    0.848228    
#> 442: 0.378379    0.938099    3.403695    0.123780    0.091700    0.002625    0.848227    
#> 443: 0.378389    0.938162    3.403715    0.123899    0.091685    0.002626    0.848207    
#> 444: 0.378449    0.938236    3.403747    0.123915    0.091736    0.002628    0.848177    
#> 445: 0.378538    0.938232    3.403762    0.123931    0.091685    0.002628    0.848197    
#> 446: 0.378585    0.938253    3.403749    0.123877    0.091674    0.002626    0.848215    
#> 447: 0.378729    0.938255    3.403738    0.123885    0.091684    0.002626    0.848236    
#> 448: 0.378621    0.938295    3.403753    0.123779    0.091734    0.002630    0.848198    
#> 449: 0.378589    0.938330    3.403825    0.123709    0.091747    0.002634    0.848208    
#> 450: 0.378595    0.938402    3.403854    0.123758    0.091722    0.002636    0.848220    
#> 451: 0.378625    0.938411    3.403860    0.123753    0.091720    0.002638    0.848223    
#> 452: 0.378583    0.938513    3.403839    0.123636    0.091696    0.002639    0.848246    
#> 453: 0.378566    0.938487    3.403851    0.123542    0.091771    0.002640    0.848211    
#> 454: 0.378538    0.938623    3.403843    0.123541    0.091794    0.002640    0.848176    
#> 455: 0.378596    0.938656    3.403832    0.123584    0.091823    0.002639    0.848107    
#> 456: 0.378504    0.938640    3.403837    0.123603    0.091780    0.002640    0.848107    
#> 457: 0.378506    0.938660    3.403864    0.123591    0.091729    0.002641    0.848066    
#> 458: 0.378437    0.938747    3.403907    0.123644    0.091726    0.002645    0.847982    
#> 459: 0.378382    0.938819    3.403924    0.123650    0.091763    0.002645    0.848037    
#> 460: 0.378300    0.938753    3.403909    0.123677    0.091710    0.002645    0.848052    
#> 461: 0.378196    0.938715    3.403930    0.123799    0.091744    0.002648    0.848079    
#> 462: 0.378025    0.938734    3.403935    0.123921    0.091737    0.002648    0.848086    
#> 463: 0.378094    0.938731    3.403965    0.123957    0.091687    0.002644    0.848106    
#> 464: 0.378166    0.938730    3.403989    0.123931    0.091655    0.002641    0.848020    
#> 465: 0.378115    0.938477    3.404008    0.123949    0.091729    0.002636    0.848080    
#> 466: 0.378150    0.938523    3.403978    0.124074    0.091782    0.002634    0.848043    
#> 467: 0.378163    0.938463    3.403977    0.124051    0.091747    0.002634    0.847934    
#> 468: 0.378248    0.938505    3.403983    0.124108    0.091718    0.002635    0.847874    
#> 469: 0.378251    0.938625    3.404017    0.124146    0.091742    0.002637    0.847821    
#> 470: 0.378261    0.938650    3.404032    0.124131    0.091671    0.002641    0.847699    
#> 471: 0.378039    0.938608    3.404029    0.124122    0.091628    0.002645    0.847649    
#> 472: 0.378029    0.938538    3.404067    0.124117    0.091554    0.002648    0.847572    
#> 473: 0.377938    0.938545    3.404088    0.124131    0.091505    0.002648    0.847528    
#> 474: 0.377823    0.938516    3.404106    0.124175    0.091466    0.002652    0.847516    
#> 475: 0.377879    0.938624    3.404108    0.124129    0.091446    0.002651    0.847495    
#> 476: 0.377808    0.938628    3.404106    0.124163    0.091427    0.002654    0.847478    
#> 477: 0.377827    0.938669    3.404124    0.124127    0.091387    0.002657    0.847387    
#> 478: 0.377763    0.938651    3.404131    0.124128    0.091298    0.002657    0.847352    
#> 479: 0.377805    0.938683    3.404143    0.124184    0.091308    0.002657    0.847367    
#> 480: 0.377892    0.938629    3.404196    0.124284    0.091238    0.002656    0.847471    
#> 481: 0.377946    0.938615    3.404236    0.124225    0.091194    0.002654    0.847473    
#> 482: 0.377999    0.938595    3.404247    0.124077    0.091190    0.002653    0.847574    
#> 483: 0.378026    0.938543    3.404261    0.124054    0.091264    0.002651    0.847563    
#> 484: 0.378074    0.938411    3.404297    0.124090    0.091286    0.002648    0.847561    
#> 485: 0.378183    0.938423    3.404340    0.124073    0.091321    0.002646    0.847542    
#> 486: 0.378382    0.938388    3.404377    0.124001    0.091340    0.002646    0.847490    
#> 487: 0.378620    0.938377    3.404434    0.124034    0.091364    0.002647    0.847510    
#> 488: 0.378710    0.938329    3.404476    0.123987    0.091398    0.002646    0.847535    
#> 489: 0.378816    0.938254    3.404524    0.124012    0.091473    0.002646    0.847572    
#> 490: 0.378990    0.938230    3.404579    0.124103    0.091457    0.002642    0.847602    
#> 491: 0.379018    0.938267    3.404636    0.124065    0.091444    0.002639    0.847649    
#> 492: 0.379055    0.938267    3.404662    0.123986    0.091354    0.002638    0.847737    
#> 493: 0.379026    0.938243    3.404692    0.123990    0.091366    0.002640    0.847762    
#> 494: 0.379032    0.938251    3.404699    0.123964    0.091369    0.002641    0.847731    
#> 495: 0.379139    0.938271    3.404731    0.123949    0.091366    0.002641    0.847705    
#> 496: 0.379269    0.938212    3.404751    0.123968    0.091318    0.002642    0.847649    
#> 497: 0.379249    0.938156    3.404767    0.124000    0.091337    0.002643    0.847662    
#> 498: 0.379340    0.938142    3.404763    0.123978    0.091352    0.002642    0.847680    
#> 499: 0.379339    0.938107    3.404721    0.123989    0.091354    0.002644    0.847666    
#> 500: 0.379367    0.938053    3.404675    0.123977    0.091366    0.002643    0.847643    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.278490    0.973377    3.448791    0.392401    0.073494    0.016800    1.624524    
#> 002: 0.430660    1.021182    3.469058    0.372781    0.069820    0.015960    0.979648    
#> 003: 0.545641    1.010005    3.472859    0.354142    0.093985    0.015162    0.777682    
#> 004: 0.576436    1.037474    3.480475    0.336435    0.099806    0.014404    0.683317    
#> 005: 0.630875    1.034401    3.483673    0.319613    0.098568    0.013684    0.632184    
#> 006: 0.646697    1.027344    3.490120    0.365222    0.100121    0.013000    0.585731    
#> 007: 0.652350    1.040441    3.493095    0.436123    0.095115    0.012350    0.593314    
#> 008: 0.645309    1.046445    3.493198    0.414317    0.093417    0.011732    0.591392    
#> 009: 0.602807    1.026975    3.484020    0.422722    0.088746    0.011146    0.585225    
#> 010: 0.591495    1.030085    3.489169    0.439647    0.088517    0.010588    0.584995    
#> 011: 0.692331    1.039270    3.496435    0.418802    0.084091    0.011916    0.575773    
#> 012: 0.685113    1.037358    3.489492    0.437742    0.080813    0.011738    0.566429    
#> 013: 0.631200    1.045732    3.486324    0.415855    0.088432    0.013976    0.557370    
#> 014: 0.659772    1.033441    3.498667    0.406401    0.086357    0.013277    0.562305    
#> 015: 0.659229    1.031961    3.496171    0.403472    0.082420    0.013506    0.541988    
#> 016: 0.642043    1.050153    3.499219    0.383298    0.078299    0.013503    0.554176    
#> 017: 0.658134    1.049080    3.501329    0.448008    0.076045    0.014556    0.544839    
#> 018: 0.675980    1.033577    3.494701    0.478928    0.076021    0.013828    0.562140    
#> 019: 0.641395    1.033248    3.503225    0.454982    0.072220    0.014967    0.566101    
#> 020: 0.670004    1.022278    3.504347    0.432232    0.071142    0.014219    0.570377    
#> 021: 0.662652    1.021172    3.513514    0.410621    0.067585    0.015456    0.550728    
#> 022: 0.666039    1.024608    3.521996    0.408643    0.076436    0.015744    0.549039    
#> 023: 0.754167    1.020900    3.533391    0.437283    0.072614    0.014957    0.568912    
#> 024: 0.737956    1.019156    3.527809    0.431971    0.068983    0.016035    0.564227    
#> 025: 0.722260    1.019039    3.514288    0.441481    0.067357    0.017738    0.568874    
#> 026: 0.681572    1.035932    3.514478    0.419407    0.063990    0.016851    0.573289    
#> 027: 0.698164    1.037119    3.509296    0.420334    0.068973    0.016008    0.576109    
#> 028: 0.697075    1.028506    3.518668    0.399317    0.065524    0.015365    0.556863    
#> 029: 0.732997    1.027576    3.513635    0.447661    0.064600    0.014981    0.571672    
#> 030: 0.714236    1.030396    3.516221    0.425278    0.063831    0.015954    0.568442    
#> 031: 0.689585    1.024432    3.522300    0.454829    0.067250    0.015772    0.567509    
#> 032: 0.699833    1.015768    3.525152    0.457965    0.063887    0.016298    0.558851    
#> 033: 0.642276    1.028211    3.512393    0.435067    0.065723    0.018434    0.568559    
#> 034: 0.692061    1.050262    3.513121    0.416806    0.074126    0.017512    0.561629    
#> 035: 0.653518    1.023621    3.506067    0.395966    0.070420    0.016637    0.553074    
#> 036: 0.687242    1.035442    3.510531    0.422510    0.071439    0.015805    0.567735    
#> 037: 0.693058    1.046154    3.513948    0.439171    0.079214    0.020630    0.561180    
#> 038: 0.694707    1.034702    3.502685    0.500392    0.075253    0.021996    0.565245    
#> 039: 0.693948    1.020455    3.513146    0.475373    0.072612    0.022065    0.545345    
#> 040: 0.697830    1.035531    3.514837    0.523977    0.072467    0.024302    0.560418    
#> 041: 0.703335    1.035251    3.515136    0.515512    0.068844    0.023288    0.560176    
#> 042: 0.676277    1.022841    3.507901    0.489736    0.076230    0.022124    0.554866    
#> 043: 0.700024    1.024785    3.499805    0.465249    0.072419    0.021018    0.556059    
#> 044: 0.686563    1.037502    3.499826    0.443872    0.068993    0.019967    0.546200    
#> 045: 0.711706    1.046941    3.499207    0.500839    0.066846    0.018969    0.547054    
#> 046: 0.696550    1.029380    3.504818    0.486948    0.071368    0.018020    0.533654    
#> 047: 0.677426    1.036874    3.506383    0.462601    0.067799    0.017119    0.538978    
#> 048: 0.679793    1.027693    3.504912    0.490380    0.065810    0.018080    0.554235    
#> 049: 0.661781    1.030921    3.507107    0.465861    0.063970    0.017176    0.572709    
#> 050: 0.731350    1.010692    3.517965    0.443763    0.062418    0.016631    0.583314    
#> 051: 0.705579    1.020806    3.515416    0.435635    0.081055    0.015908    0.556972    
#> 052: 0.737237    1.024232    3.528642    0.485414    0.082147    0.016249    0.557034    
#> 053: 0.722311    1.003281    3.521206    0.461144    0.078040    0.015539    0.555217    
#> 054: 0.706905    1.017412    3.517838    0.438087    0.074138    0.015545    0.566521    
#> 055: 0.703791    1.012176    3.523766    0.460604    0.070431    0.020603    0.559386    
#> 056: 0.699715    1.006717    3.515643    0.437573    0.078697    0.019858    0.575161    
#> 057: 0.708857    1.017022    3.517788    0.415695    0.074762    0.019276    0.573132    
#> 058: 0.708000    1.022327    3.512627    0.455135    0.071024    0.020358    0.571019    
#> 059: 0.698950    0.991844    3.516568    0.463363    0.074763    0.019340    0.574658    
#> 060: 0.687571    0.987655    3.513637    0.446144    0.077770    0.018722    0.573176    
#> 061: 0.726950    1.003196    3.528626    0.446968    0.073881    0.018975    0.573208    
#> 062: 0.694522    1.009833    3.529111    0.441707    0.070187    0.021822    0.594416    
#> 063: 0.732965    1.011223    3.524977    0.436173    0.066678    0.020731    0.588857    
#> 064: 0.730283    1.006131    3.520500    0.443577    0.063396    0.019695    0.591541    
#> 065: 0.681722    1.001301    3.503672    0.424714    0.071671    0.018710    0.572838    
#> 066: 0.664496    1.036681    3.512272    0.403478    0.074022    0.017774    0.573883    
#> 067: 0.644087    1.029841    3.497530    0.405196    0.076499    0.016886    0.579410    
#> 068: 0.660295    1.031164    3.512517    0.384936    0.072674    0.018155    0.599406    
#> 069: 0.688647    1.031142    3.510374    0.365689    0.069156    0.019303    0.590329    
#> 070: 0.704334    1.017234    3.519964    0.447384    0.068890    0.018350    0.567524    
#> 071: 0.669391    1.021307    3.501344    0.425015    0.071723    0.018432    0.566463    
#> 072: 0.658709    1.016767    3.504348    0.422219    0.070136    0.017510    0.572972    
#> 073: 0.685082    1.024012    3.513901    0.436114    0.084361    0.016635    0.563801    
#> 074: 0.707138    1.014432    3.509488    0.414308    0.080143    0.015803    0.568856    
#> 075: 0.705120    1.010554    3.526752    0.437579    0.076136    0.017724    0.554454    
#> 076: 0.735106    1.015901    3.533166    0.452864    0.072329    0.022463    0.560193    
#> 077: 0.720967    1.012933    3.527713    0.450794    0.068713    0.021612    0.563391    
#> 078: 0.698686    1.010655    3.525276    0.452199    0.065277    0.023778    0.568424    
#> 079: 0.687836    1.033272    3.522850    0.429589    0.079751    0.024012    0.572846    
#> 080: 0.721366    1.021825    3.525304    0.470663    0.079697    0.027510    0.577585    
#> 081: 0.696176    1.033403    3.517801    0.449667    0.075712    0.030769    0.564932    
#> 082: 0.661365    1.027403    3.511859    0.427184    0.071926    0.029231    0.570066    
#> 083: 0.664647    1.054218    3.503078    0.419977    0.068330    0.028314    0.569881    
#> 084: 0.644399    1.040005    3.492604    0.415979    0.064914    0.026898    0.559331    
#> 085: 0.661014    1.039999    3.507525    0.409791    0.064882    0.025553    0.554169    
#> 086: 0.681550    1.055045    3.504571    0.408558    0.062958    0.024276    0.549656    
#> 087: 0.683059    1.045016    3.503174    0.403995    0.062747    0.023062    0.555942    
#> 088: 0.633082    1.030606    3.505738    0.398143    0.063627    0.021909    0.559488    
#> 089: 0.646773    1.044257    3.488727    0.398867    0.068561    0.020813    0.560651    
#> 090: 0.657872    1.032098    3.489114    0.447162    0.072107    0.019773    0.569121    
#> 091: 0.616887    1.030161    3.481617    0.424804    0.081193    0.018784    0.565051    
#> 092: 0.640821    1.068165    3.478396    0.454634    0.082553    0.017845    0.559013    
#> 093: 0.620400    1.053571    3.482422    0.468042    0.078425    0.017941    0.568317    
#> 094: 0.658927    1.060964    3.488666    0.486121    0.074504    0.018669    0.561173    
#> 095: 0.644585    1.064377    3.493653    0.506779    0.070779    0.017735    0.560289    
#> 096: 0.614191    1.057507    3.496257    0.481440    0.082709    0.017024    0.558866    
#> 097: 0.668554    1.051372    3.494915    0.532298    0.078574    0.016172    0.549080    
#> 098: 0.676841    1.059692    3.498094    0.511405    0.074645    0.015796    0.542646    
#> 099: 0.674441    1.031355    3.495630    0.507366    0.073419    0.015204    0.541931    
#> 100: 0.675811    1.033186    3.501038    0.533881    0.069748    0.017780    0.539680    
#> 101: 0.647952    1.032513    3.485836    0.507187    0.066260    0.017940    0.544883    
#> 102: 0.649778    1.048192    3.481771    0.505609    0.067755    0.017190    0.551263    
#> 103: 0.702583    1.042765    3.495744    0.576144    0.067113    0.016330    0.548851    
#> 104: 0.697336    1.047200    3.505637    0.596819    0.081397    0.015514    0.554667    
#> 105: 0.702242    1.049560    3.504997    0.566978    0.077568    0.015841    0.572312    
#> 106: 0.689796    1.031226    3.506276    0.538629    0.073690    0.020083    0.571271    
#> 107: 0.697154    1.036782    3.503757    0.545318    0.070005    0.019079    0.568578    
#> 108: 0.679661    1.048943    3.502414    0.518052    0.066505    0.018125    0.576990    
#> 109: 0.703183    1.023418    3.516669    0.492150    0.064045    0.017796    0.574614    
#> 110: 0.680875    1.031114    3.501864    0.487717    0.060843    0.019030    0.559362    
#> 111: 0.694220    1.034454    3.505853    0.515823    0.057801    0.018636    0.554188    
#> 112: 0.669231    1.029812    3.496430    0.490032    0.055575    0.019200    0.550436    
#> 113: 0.667219    1.051900    3.495616    0.497987    0.064624    0.018240    0.542873    
#> 114: 0.691845    1.045821    3.496520    0.494956    0.064067    0.017485    0.547252    
#> 115: 0.703670    1.026022    3.502261    0.483420    0.061965    0.016610    0.571186    
#> 116: 0.683209    1.031819    3.507849    0.459249    0.066881    0.018088    0.555843    
#> 117: 0.675006    1.034481    3.512277    0.540502    0.070608    0.017184    0.567012    
#> 118: 0.687769    1.022951    3.510455    0.513477    0.067078    0.017572    0.553147    
#> 119: 0.685286    1.048586    3.505839    0.487803    0.065172    0.018215    0.560130    
#> 120: 0.656137    1.022049    3.499103    0.496165    0.076771    0.017355    0.561220    
#> 121: 0.685962    1.061168    3.503379    0.471357    0.076132    0.017031    0.557969    
#> 122: 0.686121    1.032171    3.504932    0.483171    0.083479    0.016250    0.548871    
#> 123: 0.680842    1.045440    3.500531    0.465328    0.079305    0.015437    0.557397    
#> 124: 0.689697    1.073431    3.500754    0.442062    0.075596    0.014786    0.554187    
#> 125: 0.689599    1.076589    3.497740    0.486066    0.071816    0.014047    0.556505    
#> 126: 0.695991    1.066645    3.489009    0.532585    0.068972    0.015778    0.549486    
#> 127: 0.684726    1.051430    3.488645    0.553412    0.075044    0.014989    0.565241    
#> 128: 0.644081    1.047698    3.501431    0.525741    0.071423    0.015094    0.570413    
#> 129: 0.701036    1.052553    3.504380    0.499454    0.074367    0.014340    0.573738    
#> 130: 0.706005    1.049134    3.505128    0.474482    0.086658    0.013623    0.562321    
#> 131: 0.681453    1.027833    3.493256    0.450757    0.082325    0.012942    0.567840    
#> 132: 0.648320    1.031057    3.497720    0.428220    0.084177    0.012295    0.560841    
#> 133: 0.673033    1.023776    3.510325    0.428738    0.080661    0.011947    0.557306    
#> 134: 0.673239    1.018225    3.516561    0.416460    0.086877    0.014497    0.560766    
#> 135: 0.675316    1.019448    3.518249    0.397698    0.095114    0.016456    0.559837    
#> 136: 0.706143    1.007077    3.514526    0.463176    0.090358    0.015633    0.555074    
#> 137: 0.759956    1.022347    3.530394    0.457153    0.093619    0.014851    0.582175    
#> 138: 0.717568    1.034365    3.515334    0.491389    0.091501    0.014109    0.568913    
#> 139: 0.697017    1.038618    3.512133    0.505391    0.086926    0.014723    0.568245    
#> 140: 0.697862    1.026916    3.518522    0.480121    0.083226    0.017352    0.563505    
#> 141: 0.688034    1.013439    3.523056    0.482488    0.099159    0.016485    0.560609    
#> 142: 0.697361    1.015465    3.528453    0.472760    0.098008    0.015661    0.573987    
#> 143: 0.661343    1.040627    3.518995    0.449122    0.093108    0.016444    0.576958    
#> 144: 0.707614    1.039869    3.524649    0.426666    0.088453    0.015622    0.559836    
#> 145: 0.663533    1.044412    3.505627    0.410972    0.084030    0.014841    0.554795    
#> 146: 0.658768    1.044666    3.510714    0.390423    0.080883    0.014099    0.561478    
#> 147: 0.613553    1.023170    3.497823    0.370902    0.080677    0.015000    0.560045    
#> 148: 0.637391    1.041955    3.512845    0.404184    0.076643    0.019096    0.559090    
#> 149: 0.663000    1.027176    3.502997    0.464515    0.079862    0.019187    0.565938    
#> 150: 0.697334    1.029225    3.502400    0.441289    0.087662    0.019295    0.572962    
#> 151: 0.636446    1.036951    3.504139    0.419225    0.083279    0.018331    0.565059    
#> 152: 0.624563    1.045227    3.493817    0.446354    0.074419    0.015301    0.559441    
#> 153: 0.633367    1.029613    3.503986    0.459077    0.063537    0.016968    0.572377    
#> 154: 0.666293    1.046828    3.495804    0.504744    0.074985    0.014955    0.571229    
#> 155: 0.663779    1.031566    3.496568    0.471411    0.079109    0.018589    0.563813    
#> 156: 0.678325    1.025798    3.508972    0.458751    0.087608    0.018955    0.568003    
#> 157: 0.717808    1.009200    3.507880    0.562288    0.087775    0.017036    0.551640    
#> 158: 0.716320    1.035080    3.505305    0.483294    0.072352    0.014706    0.553861    
#> 159: 0.655225    1.041430    3.509247    0.417586    0.070475    0.015142    0.565565    
#> 160: 0.693897    1.009484    3.515084    0.443163    0.078659    0.016755    0.545791    
#> 161: 0.667476    1.031291    3.503455    0.436417    0.077131    0.013008    0.554166    
#> 162: 0.693895    1.031100    3.500012    0.496890    0.087354    0.013138    0.575651    
#> 163: 0.727971    1.026536    3.500207    0.535436    0.103206    0.014567    0.568698    
#> 164: 0.701431    1.030483    3.508660    0.484556    0.088884    0.014088    0.543899    
#> 165: 0.724768    1.002791    3.519647    0.518793    0.080589    0.015098    0.559956    
#> 166: 0.768623    1.030776    3.513478    0.680628    0.078704    0.019678    0.553705    
#> 167: 0.733519    1.059444    3.514710    0.595198    0.072947    0.022076    0.557374    
#> 168: 0.736318    1.038857    3.514190    0.556861    0.070634    0.021359    0.551676    
#> 169: 0.787088    1.059667    3.506679    0.700721    0.076720    0.017059    0.555270    
#> 170: 0.778622    1.044898    3.516331    0.738508    0.073362    0.017755    0.553533    
#> 171: 0.750233    1.019319    3.516593    0.635829    0.056411    0.020066    0.555846    
#> 172: 0.694133    1.042586    3.507309    0.480351    0.073745    0.017088    0.539378    
#> 173: 0.703185    1.058526    3.496817    0.561755    0.068206    0.021126    0.541802    
#> 174: 0.702165    1.050988    3.503718    0.573927    0.065489    0.020644    0.545721    
#> 175: 0.656316    1.034529    3.490215    0.472061    0.061617    0.022432    0.552421    
#> 176: 0.670484    1.048094    3.503476    0.478944    0.067538    0.022052    0.541004    
#> 177: 0.702006    1.036148    3.508666    0.557373    0.061815    0.026586    0.555429    
#> 178: 0.680492    1.017448    3.505478    0.498459    0.060598    0.022167    0.565570    
#> 179: 0.733268    1.036617    3.512832    0.584263    0.072701    0.020507    0.588524    
#> 180: 0.680501    1.025338    3.514253    0.485363    0.066629    0.018494    0.575437    
#> 181: 0.685944    1.026320    3.486299    0.470074    0.063577    0.017135    0.579676    
#> 182: 0.648824    1.040801    3.480469    0.496009    0.067660    0.014978    0.590849    
#> 183: 0.638061    1.051720    3.483175    0.479227    0.063802    0.016731    0.575900    
#> 184: 0.642940    1.037619    3.494822    0.482350    0.065872    0.017552    0.560590    
#> 185: 0.652743    1.052806    3.490278    0.451614    0.075845    0.016945    0.549798    
#> 186: 0.630001    1.061501    3.488188    0.442568    0.069010    0.019893    0.546822    
#> 187: 0.664297    1.044355    3.494402    0.537976    0.076475    0.018151    0.551232    
#> 188: 0.631898    1.049354    3.497924    0.443644    0.074091    0.016758    0.553414    
#> 189: 0.646113    1.046541    3.504463    0.415322    0.066689    0.018372    0.560069    
#> 190: 0.648563    1.033488    3.507201    0.434018    0.066861    0.016580    0.560141    
#> 191: 0.665589    1.062052    3.497022    0.419365    0.068145    0.016771    0.548755    
#> 192: 0.644991    1.050646    3.499543    0.420548    0.071201    0.015021    0.544716    
#> 193: 0.693343    1.053416    3.506310    0.489481    0.076473    0.014092    0.552416    
#> 194: 0.693272    1.033996    3.500952    0.504382    0.069163    0.014119    0.561776    
#> 195: 0.663278    1.048809    3.499532    0.495820    0.075616    0.015465    0.556049    
#> 196: 0.671164    1.026978    3.506008    0.503818    0.065457    0.012757    0.566578    
#> 197: 0.638678    1.028306    3.519944    0.400907    0.080225    0.012307    0.585939    
#> 198: 0.687143    1.012767    3.504381    0.418975    0.086179    0.013167    0.575109    
#> 199: 0.652184    1.027313    3.503526    0.474669    0.076435    0.013425    0.568727    
#> 200: 0.673628    1.028891    3.505015    0.554156    0.087282    0.017442    0.581344    
#> 201: 0.682114    1.030949    3.506886    0.537532    0.089054    0.018860    0.577127    
#> 202: 0.683786    1.031914    3.507399    0.537644    0.084502    0.019401    0.574209    
#> 203: 0.693246    1.030630    3.508195    0.516819    0.081483    0.019541    0.576969    
#> 204: 0.690742    1.026611    3.508868    0.514147    0.080448    0.018884    0.576747    
#> 205: 0.689944    1.029846    3.508242    0.512783    0.079011    0.018379    0.577757    
#> 206: 0.688722    1.033824    3.508148    0.519688    0.077464    0.018161    0.577039    
#> 207: 0.686619    1.033582    3.507197    0.508032    0.076370    0.018230    0.573598    
#> 208: 0.682722    1.034949    3.506253    0.500806    0.075570    0.018174    0.570362    
#> 209: 0.680878    1.033059    3.505892    0.497747    0.075928    0.018240    0.568214    
#> 210: 0.681809    1.031924    3.506199    0.494340    0.075849    0.018187    0.566424    
#> 211: 0.685978    1.031528    3.507066    0.492724    0.076562    0.018055    0.564439    
#> 212: 0.687734    1.031932    3.506835    0.490333    0.076747    0.017798    0.563410    
#> 213: 0.687153    1.030015    3.507117    0.487574    0.076488    0.017768    0.564152    
#> 214: 0.688021    1.028958    3.507387    0.485904    0.076360    0.017463    0.564668    
#> 215: 0.688618    1.029585    3.507687    0.482282    0.076720    0.017259    0.564990    
#> 216: 0.690122    1.028302    3.507759    0.482128    0.077548    0.017322    0.565029    
#> 217: 0.689840    1.028057    3.507500    0.479407    0.078450    0.017080    0.564582    
#> 218: 0.690922    1.028374    3.507345    0.479875    0.079298    0.016852    0.563804    
#> 219: 0.690856    1.028343    3.506853    0.480572    0.079101    0.016602    0.563369    
#> 220: 0.688884    1.028650    3.506620    0.476960    0.079367    0.016555    0.563371    
#> 221: 0.688871    1.029474    3.506494    0.477529    0.079602    0.016444    0.562752    
#> 222: 0.689565    1.029730    3.506367    0.481236    0.079720    0.016411    0.562451    
#> 223: 0.690032    1.029371    3.506197    0.480934    0.079412    0.016479    0.561732    
#> 224: 0.692456    1.029571    3.506442    0.482028    0.078823    0.016623    0.561836    
#> 225: 0.692331    1.028728    3.506785    0.483108    0.078535    0.016785    0.562199    
#> 226: 0.691135    1.027641    3.506757    0.484558    0.078135    0.016857    0.562401    
#> 227: 0.690808    1.027289    3.506557    0.485222    0.077747    0.016930    0.562368    
#> 228: 0.690402    1.028343    3.505887    0.488053    0.077518    0.016942    0.562271    
#> 229: 0.689353    1.028574    3.505448    0.489281    0.077004    0.017108    0.562322    
#> 230: 0.689386    1.028764    3.505117    0.489344    0.076686    0.017241    0.562560    
#> 231: 0.688534    1.029352    3.504871    0.489091    0.076453    0.017295    0.561811    
#> 232: 0.688089    1.030074    3.504885    0.488498    0.076288    0.017328    0.561339    
#> 233: 0.687405    1.029866    3.504703    0.489123    0.076022    0.017302    0.561298    
#> 234: 0.687044    1.030086    3.504522    0.488135    0.075774    0.017409    0.560945    
#> 235: 0.686682    1.029966    3.504519    0.488301    0.075574    0.017464    0.560553    
#> 236: 0.685768    1.030232    3.504466    0.486504    0.075338    0.017482    0.560477    
#> 237: 0.685273    1.030005    3.504377    0.485586    0.075291    0.017499    0.560929    
#> 238: 0.685517    1.030172    3.504288    0.486656    0.075158    0.017490    0.561442    
#> 239: 0.684640    1.030595    3.503956    0.486620    0.075128    0.017503    0.561739    
#> 240: 0.684220    1.030809    3.503889    0.486347    0.075009    0.017499    0.561591    
#> 241: 0.684237    1.030195    3.504050    0.484731    0.074902    0.017482    0.561681    
#> 242: 0.684139    1.029843    3.504050    0.481714    0.074890    0.017500    0.562172    
#> 243: 0.683724    1.030376    3.504064    0.479157    0.075038    0.017490    0.562615    
#> 244: 0.684156    1.030458    3.504342    0.478694    0.075123    0.017448    0.562807    
#> 245: 0.684364    1.030208    3.504669    0.479241    0.075302    0.017371    0.563327    
#> 246: 0.684834    1.030190    3.504736    0.479592    0.075370    0.017335    0.563623    
#> 247: 0.684879    1.030058    3.504865    0.477995    0.075618    0.017224    0.563964    
#> 248: 0.684831    1.030234    3.504905    0.476921    0.075845    0.017168    0.564067    
#> 249: 0.684781    1.030067    3.505068    0.476614    0.075676    0.017148    0.564066    
#> 250: 0.685144    1.030306    3.505322    0.475517    0.075715    0.017188    0.563974    
#> 251: 0.685226    1.030500    3.505602    0.475487    0.075908    0.017117    0.564069    
#> 252: 0.685515    1.030684    3.505959    0.475369    0.075744    0.017085    0.563945    
#> 253: 0.685642    1.030662    3.506068    0.474714    0.075601    0.017052    0.564172    
#> 254: 0.685848    1.030878    3.506187    0.474472    0.075563    0.017011    0.564066    
#> 255: 0.685596    1.031086    3.506274    0.472896    0.075703    0.016955    0.563953    
#> 256: 0.685451    1.031160    3.506351    0.471448    0.075755    0.016940    0.563884    
#> 257: 0.685554    1.030963    3.506454    0.471797    0.075834    0.016920    0.563731    
#> 258: 0.685432    1.030688    3.506508    0.471058    0.075919    0.016920    0.563686    
#> 259: 0.685565    1.030494    3.506600    0.470423    0.075772    0.016951    0.563867    
#> 260: 0.685946    1.030678    3.506807    0.470902    0.075834    0.016943    0.563791    
#> 261: 0.686550    1.030486    3.506960    0.472333    0.075758    0.016933    0.563781    
#> 262: 0.687197    1.030475    3.507112    0.472800    0.075785    0.016913    0.563709    
#> 263: 0.687145    1.030597    3.507045    0.473109    0.075785    0.016928    0.563417    
#> 264: 0.686755    1.030681    3.507050    0.473080    0.075871    0.016910    0.563705    
#> 265: 0.686759    1.030669    3.507080    0.473425    0.075807    0.016885    0.563869    
#> 266: 0.687123    1.030611    3.507184    0.474363    0.075781    0.016841    0.563821    
#> 267: 0.686971    1.030768    3.507247    0.474405    0.075836    0.016799    0.563882    
#> 268: 0.687017    1.030372    3.507229    0.474502    0.075744    0.016754    0.563831    
#> 269: 0.687511    1.030351    3.507232    0.474461    0.075687    0.016742    0.563714    
#> 270: 0.687903    1.030584    3.507248    0.474516    0.075748    0.016721    0.563700    
#> 271: 0.688250    1.030450    3.507214    0.474497    0.075834    0.016698    0.563780    
#> 272: 0.688023    1.030128    3.507144    0.474290    0.075975    0.016659    0.563992    
#> 273: 0.687855    1.030196    3.507215    0.474498    0.076062    0.016640    0.564156    
#> 274: 0.688077    1.030332    3.507286    0.474426    0.076340    0.016593    0.564185    
#> 275: 0.687890    1.030448    3.507226    0.474106    0.076447    0.016543    0.564129    
#> 276: 0.687562    1.030728    3.507274    0.474147    0.076551    0.016517    0.564249    
#> 277: 0.687336    1.030935    3.507330    0.473870    0.076583    0.016518    0.564151    
#> 278: 0.687013    1.030979    3.507426    0.473253    0.076542    0.016506    0.564288    
#> 279: 0.686385    1.030845    3.507457    0.472357    0.076425    0.016502    0.564546    
#> 280: 0.686076    1.031012    3.507431    0.472180    0.076289    0.016522    0.564681    
#> 281: 0.685633    1.031131    3.507418    0.471732    0.076326    0.016494    0.564653    
#> 282: 0.685424    1.031394    3.507415    0.471340    0.076393    0.016482    0.564503    
#> 283: 0.685023    1.031426    3.507409    0.471167    0.076592    0.016453    0.564693    
#> 284: 0.684670    1.031191    3.507396    0.471071    0.076649    0.016396    0.564541    
#> 285: 0.684466    1.031332    3.507218    0.471052    0.076689    0.016381    0.564448    
#> 286: 0.684309    1.031442    3.507211    0.470372    0.076779    0.016379    0.564363    
#> 287: 0.684128    1.031558    3.507181    0.470152    0.076718    0.016343    0.564473    
#> 288: 0.684495    1.031517    3.507216    0.469914    0.076686    0.016358    0.564444    
#> 289: 0.684659    1.031450    3.507214    0.470111    0.076595    0.016362    0.564470    
#> 290: 0.684754    1.031537    3.507148    0.470080    0.076605    0.016341    0.564533    
#> 291: 0.684472    1.031823    3.507161    0.469746    0.076704    0.016322    0.564445    
#> 292: 0.684262    1.031940    3.507087    0.469374    0.076825    0.016298    0.564504    
#> 293: 0.684141    1.032153    3.507063    0.469024    0.076747    0.016269    0.564514    
#> 294: 0.683786    1.032247    3.506988    0.468202    0.076697    0.016249    0.564472    
#> 295: 0.683566    1.032052    3.506867    0.468081    0.076738    0.016218    0.564331    
#> 296: 0.683616    1.032098    3.506825    0.467956    0.076861    0.016182    0.564256    
#> 297: 0.683492    1.032175    3.506837    0.467252    0.076957    0.016142    0.564255    
#> 298: 0.683701    1.032098    3.506850    0.467545    0.077028    0.016110    0.564278    
#> 299: 0.683989    1.032135    3.506843    0.468083    0.077187    0.016052    0.564120    
#> 300: 0.684190    1.032008    3.506944    0.467890    0.077159    0.016024    0.564043    
#> 301: 0.684758    1.031804    3.507011    0.467874    0.077205    0.015996    0.564119    
#> 302: 0.685250    1.031734    3.507074    0.467670    0.077286    0.015979    0.564094    
#> 303: 0.685559    1.031687    3.507119    0.467363    0.077330    0.015955    0.563918    
#> 304: 0.685611    1.031878    3.507096    0.466628    0.077427    0.015938    0.563891    
#> 305: 0.685438    1.031775    3.507058    0.466128    0.077425    0.015945    0.563858    
#> 306: 0.684833    1.031668    3.506934    0.465312    0.077390    0.015937    0.563867    
#> 307: 0.684340    1.031603    3.506789    0.465004    0.077171    0.015939    0.564090    
#> 308: 0.683787    1.031467    3.506673    0.465097    0.076965    0.015963    0.564208    
#> 309: 0.683614    1.031429    3.506661    0.465052    0.076968    0.015973    0.564509    
#> 310: 0.683782    1.031297    3.506632    0.465770    0.076931    0.015977    0.564874    
#> 311: 0.683963    1.031198    3.506646    0.466133    0.076898    0.015999    0.564971    
#> 312: 0.683892    1.031238    3.506581    0.466462    0.076866    0.016019    0.565017    
#> 313: 0.683889    1.031080    3.506498    0.466587    0.076766    0.016034    0.565071    
#> 314: 0.683466    1.031160    3.506405    0.466047    0.076753    0.016037    0.564978    
#> 315: 0.683183    1.031393    3.506311    0.465736    0.076841    0.016025    0.564867    
#> 316: 0.683149    1.031521    3.506273    0.465420    0.076940    0.016029    0.564754    
#> 317: 0.683253    1.031566    3.506304    0.465446    0.077067    0.016025    0.564817    
#> 318: 0.683668    1.031507    3.506313    0.466056    0.077078    0.016016    0.564840    
#> 319: 0.683919    1.031509    3.506370    0.466280    0.077063    0.016036    0.564924    
#> 320: 0.683694    1.031412    3.506303    0.466673    0.077196    0.016059    0.564972    
#> 321: 0.683586    1.031597    3.506249    0.466791    0.077311    0.016097    0.565005    
#> 322: 0.683391    1.031605    3.506091    0.467357    0.077364    0.016105    0.565026    
#> 323: 0.682880    1.031747    3.505954    0.467685    0.077418    0.016118    0.564941    
#> 324: 0.682572    1.031806    3.505879    0.467920    0.077429    0.016120    0.564865    
#> 325: 0.682479    1.031873    3.505817    0.467529    0.077479    0.016117    0.564782    
#> 326: 0.682486    1.031726    3.505825    0.467109    0.077515    0.016120    0.564669    
#> 327: 0.682729    1.031741    3.505866    0.467256    0.077638    0.016139    0.564568    
#> 328: 0.682712    1.031839    3.505845    0.466671    0.077677    0.016117    0.564591    
#> 329: 0.682810    1.031946    3.505842    0.466889    0.077739    0.016107    0.564495    
#> 330: 0.682567    1.032034    3.505826    0.466231    0.077750    0.016104    0.564500    
#> 331: 0.682559    1.032162    3.505863    0.465645    0.077790    0.016101    0.564509    
#> 332: 0.682660    1.032159    3.505978    0.465240    0.077839    0.016125    0.564565    
#> 333: 0.682530    1.032172    3.505937    0.465058    0.077798    0.016120    0.564591    
#> 334: 0.682516    1.032079    3.505899    0.464866    0.077837    0.016109    0.564586    
#> 335: 0.682365    1.032132    3.505838    0.464806    0.077726    0.016112    0.564580    
#> 336: 0.681984    1.032291    3.505808    0.464640    0.077609    0.016158    0.564563    
#> 337: 0.681655    1.032586    3.505669    0.464436    0.077618    0.016169    0.564545    
#> 338: 0.681509    1.032755    3.505580    0.464462    0.077635    0.016177    0.564507    
#> 339: 0.681468    1.032894    3.505437    0.464519    0.077727    0.016172    0.564422    
#> 340: 0.681429    1.032681    3.505372    0.464694    0.077808    0.016162    0.564387    
#> 341: 0.681520    1.032632    3.505347    0.464698    0.077851    0.016139    0.564331    
#> 342: 0.681309    1.032457    3.505384    0.464479    0.077865    0.016135    0.564399    
#> 343: 0.681158    1.032510    3.505394    0.464044    0.077876    0.016133    0.564422    
#> 344: 0.681218    1.032491    3.505435    0.463864    0.077907    0.016142    0.564399    
#> 345: 0.681282    1.032395    3.505471    0.463673    0.077864    0.016159    0.564386    
#> 346: 0.680974    1.032387    3.505353    0.463246    0.077890    0.016149    0.564354    
#> 347: 0.680768    1.032336    3.505257    0.463175    0.077937    0.016143    0.564369    
#> 348: 0.680474    1.032329    3.505187    0.463560    0.077990    0.016147    0.564313    
#> 349: 0.680353    1.032214    3.505113    0.463675    0.077957    0.016149    0.564201    
#> 350: 0.680233    1.032119    3.505045    0.464007    0.077985    0.016151    0.564170    
#> 351: 0.680271    1.032288    3.504965    0.463756    0.077977    0.016152    0.564218    
#> 352: 0.679964    1.032499    3.504919    0.463386    0.077991    0.016152    0.564384    
#> 353: 0.679715    1.032583    3.504925    0.462934    0.077989    0.016150    0.564407    
#> 354: 0.679499    1.032584    3.504844    0.462691    0.077915    0.016140    0.564458    
#> 355: 0.679590    1.032499    3.504806    0.462772    0.077950    0.016136    0.564418    
#> 356: 0.679521    1.032439    3.504813    0.462480    0.077907    0.016158    0.564516    
#> 357: 0.679661    1.032625    3.504847    0.462668    0.077881    0.016163    0.564439    
#> 358: 0.679632    1.032689    3.504799    0.462825    0.077902    0.016163    0.564312    
#> 359: 0.679287    1.032764    3.504711    0.462540    0.077907    0.016141    0.564292    
#> 360: 0.678877    1.032822    3.504576    0.462249    0.077950    0.016127    0.564283    
#> 361: 0.678555    1.032882    3.504446    0.461944    0.077985    0.016114    0.564201    
#> 362: 0.678459    1.032961    3.504342    0.461883    0.077964    0.016096    0.564061    
#> 363: 0.678253    1.032960    3.504324    0.461230    0.077978    0.016084    0.563933    
#> 364: 0.678062    1.032995    3.504299    0.460645    0.078065    0.016081    0.563977    
#> 365: 0.677736    1.032964    3.504271    0.460245    0.078087    0.016106    0.563994    
#> 366: 0.677534    1.032977    3.504200    0.460092    0.078028    0.016137    0.563974    
#> 367: 0.677628    1.033042    3.504164    0.460788    0.077991    0.016141    0.563859    
#> 368: 0.677745    1.033152    3.504103    0.460908    0.077988    0.016161    0.563812    
#> 369: 0.677534    1.033200    3.504034    0.461150    0.077910    0.016163    0.563883    
#> 370: 0.677432    1.033334    3.503986    0.461105    0.077874    0.016183    0.563907    
#> 371: 0.677318    1.033402    3.503905    0.461092    0.077820    0.016183    0.563905    
#> 372: 0.677263    1.033423    3.503848    0.461254    0.077810    0.016197    0.563886    
#> 373: 0.676927    1.033585    3.503717    0.461557    0.077765    0.016196    0.563914    
#> 374: 0.676832    1.033690    3.503604    0.462015    0.077667    0.016198    0.563885    
#> 375: 0.676644    1.033759    3.503522    0.462211    0.077589    0.016198    0.563868    
#> 376: 0.676538    1.033848    3.503493    0.462234    0.077507    0.016199    0.563815    
#> 377: 0.676365    1.033907    3.503452    0.462085    0.077501    0.016217    0.563770    
#> 378: 0.676171    1.033998    3.503413    0.461909    0.077444    0.016213    0.563785    
#> 379: 0.676214    1.033952    3.503393    0.462008    0.077390    0.016208    0.563751    
#> 380: 0.676198    1.033983    3.503383    0.461881    0.077358    0.016201    0.563670    
#> 381: 0.675973    1.034031    3.503337    0.461675    0.077390    0.016199    0.563638    
#> 382: 0.675676    1.034046    3.503296    0.461485    0.077349    0.016192    0.563527    
#> 383: 0.675532    1.034079    3.503279    0.461207    0.077339    0.016181    0.563491    
#> 384: 0.675310    1.034097    3.503285    0.460913    0.077311    0.016175    0.563493    
#> 385: 0.675288    1.034161    3.503258    0.460826    0.077295    0.016166    0.563533    
#> 386: 0.675365    1.034391    3.503276    0.460612    0.077323    0.016166    0.563586    
#> 387: 0.675352    1.034592    3.503279    0.460735    0.077368    0.016150    0.563611    
#> 388: 0.675406    1.034698    3.503306    0.460708    0.077407    0.016143    0.563603    
#> 389: 0.675341    1.034721    3.503266    0.460821    0.077501    0.016116    0.563608    
#> 390: 0.675176    1.034806    3.503251    0.460692    0.077552    0.016093    0.563624    
#> 391: 0.675219    1.034723    3.503247    0.460440    0.077577    0.016074    0.563567    
#> 392: 0.675189    1.034697    3.503265    0.460516    0.077569    0.016067    0.563507    
#> 393: 0.675151    1.034644    3.503269    0.460433    0.077561    0.016070    0.563436    
#> 394: 0.675161    1.034621    3.503259    0.460375    0.077491    0.016060    0.563404    
#> 395: 0.675224    1.034774    3.503250    0.460242    0.077548    0.016050    0.563346    
#> 396: 0.675305    1.034801    3.503276    0.460196    0.077558    0.016037    0.563248    
#> 397: 0.675303    1.034745    3.503329    0.459896    0.077543    0.016046    0.563220    
#> 398: 0.675496    1.034686    3.503399    0.459779    0.077542    0.016056    0.563243    
#> 399: 0.675711    1.034643    3.503502    0.460107    0.077553    0.016065    0.563161    
#> 400: 0.675910    1.034620    3.503545    0.460199    0.077509    0.016067    0.563144    
#> 401: 0.675916    1.034715    3.503522    0.460389    0.077468    0.016075    0.563170    
#> 402: 0.675831    1.034850    3.503509    0.459973    0.077435    0.016080    0.563158    
#> 403: 0.675936    1.034874    3.503518    0.459719    0.077422    0.016082    0.563130    
#> 404: 0.675911    1.034933    3.503497    0.459695    0.077431    0.016076    0.563033    
#> 405: 0.676058    1.034969    3.503534    0.460024    0.077409    0.016067    0.562983    
#> 406: 0.676133    1.034972    3.503552    0.460080    0.077402    0.016064    0.563017    
#> 407: 0.676198    1.034951    3.503608    0.459887    0.077408    0.016055    0.563041    
#> 408: 0.676424    1.034987    3.503677    0.459532    0.077418    0.016050    0.563051    
#> 409: 0.676471    1.034875    3.503705    0.459125    0.077393    0.016028    0.563018    
#> 410: 0.676413    1.034884    3.503693    0.458692    0.077354    0.016020    0.563018    
#> 411: 0.676402    1.034765    3.503705    0.458578    0.077352    0.016010    0.563023    
#> 412: 0.676506    1.034779    3.503715    0.458542    0.077305    0.016003    0.563027    
#> 413: 0.676507    1.034832    3.503698    0.458550    0.077332    0.015996    0.563060    
#> 414: 0.676361    1.034792    3.503690    0.458632    0.077308    0.015998    0.563001    
#> 415: 0.676525    1.034714    3.503686    0.458914    0.077281    0.015988    0.562915    
#> 416: 0.676758    1.034670    3.503699    0.459308    0.077216    0.016002    0.562923    
#> 417: 0.676917    1.034694    3.503647    0.459808    0.077170    0.016014    0.562889    
#> 418: 0.676816    1.034750    3.503624    0.459686    0.077178    0.016022    0.562829    
#> 419: 0.676777    1.034806    3.503603    0.459843    0.077180    0.016038    0.562796    
#> 420: 0.676711    1.034915    3.503550    0.459802    0.077215    0.016032    0.562750    
#> 421: 0.676654    1.034968    3.503562    0.459858    0.077235    0.016028    0.562694    
#> 422: 0.676784    1.034886    3.503582    0.459770    0.077260    0.016012    0.562684    
#> 423: 0.676869    1.034882    3.503547    0.459854    0.077325    0.016002    0.562651    
#> 424: 0.676850    1.034863    3.503531    0.460118    0.077318    0.015996    0.562592    
#> 425: 0.676902    1.034910    3.503495    0.460514    0.077308    0.016002    0.562549    
#> 426: 0.676931    1.035032    3.503483    0.460771    0.077263    0.016010    0.562450    
#> 427: 0.676951    1.035060    3.503519    0.460783    0.077210    0.016010    0.562378    
#> 428: 0.676942    1.035086    3.503557    0.460558    0.077215    0.016014    0.562371    
#> 429: 0.677088    1.035079    3.503623    0.460461    0.077175    0.016016    0.562371    
#> 430: 0.677180    1.035046    3.503645    0.460490    0.077185    0.016004    0.562412    
#> 431: 0.677095    1.035027    3.503626    0.460235    0.077205    0.015992    0.562359    
#> 432: 0.676904    1.035098    3.503619    0.459984    0.077260    0.015982    0.562307    
#> 433: 0.676781    1.035236    3.503578    0.459893    0.077232    0.015984    0.562310    
#> 434: 0.676556    1.035220    3.503520    0.459807    0.077228    0.015966    0.562322    
#> 435: 0.676552    1.035251    3.503477    0.459844    0.077174    0.015959    0.562297    
#> 436: 0.676488    1.035239    3.503474    0.459549    0.077219    0.015948    0.562329    
#> 437: 0.676598    1.035210    3.503480    0.459432    0.077239    0.015942    0.562333    
#> 438: 0.676607    1.035222    3.503497    0.459333    0.077201    0.015945    0.562270    
#> 439: 0.676710    1.035279    3.503510    0.459300    0.077208    0.015945    0.562218    
#> 440: 0.676753    1.035377    3.503546    0.459017    0.077180    0.015946    0.562219    
#> 441: 0.676852    1.035320    3.503575    0.458801    0.077159    0.015947    0.562192    
#> 442: 0.676775    1.035312    3.503581    0.458686    0.077158    0.015945    0.562134    
#> 443: 0.676771    1.035326    3.503557    0.458728    0.077128    0.015940    0.562068    
#> 444: 0.676551    1.035449    3.503453    0.458727    0.077115    0.015936    0.562077    
#> 445: 0.676362    1.035557    3.503380    0.458699    0.077059    0.015936    0.562053    
#> 446: 0.676169    1.035642    3.503320    0.458738    0.077006    0.015943    0.562017    
#> 447: 0.676250    1.035707    3.503324    0.458697    0.076953    0.015957    0.562036    
#> 448: 0.676289    1.035742    3.503358    0.458895    0.076911    0.015970    0.561998    
#> 449: 0.676479    1.035759    3.503443    0.459144    0.076860    0.015995    0.561973    
#> 450: 0.676637    1.035701    3.503469    0.459497    0.076821    0.016010    0.561953    
#> 451: 0.676719    1.035648    3.503482    0.459794    0.076814    0.016028    0.561951    
#> 452: 0.676776    1.035626    3.503491    0.459747    0.076789    0.016035    0.561948    
#> 453: 0.676748    1.035625    3.503485    0.459918    0.076768    0.016056    0.561956    
#> 454: 0.676517    1.035788    3.503438    0.459947    0.076741    0.016064    0.561937    
#> 455: 0.676438    1.035857    3.503417    0.459812    0.076737    0.016065    0.561891    
#> 456: 0.676285    1.035767    3.503408    0.459686    0.076728    0.016064    0.561938    
#> 457: 0.676249    1.035696    3.503428    0.459683    0.076719    0.016055    0.561887    
#> 458: 0.676325    1.035738    3.503464    0.459688    0.076708    0.016050    0.561861    
#> 459: 0.676181    1.035816    3.503452    0.459841    0.076760    0.016044    0.561849    
#> 460: 0.676102    1.035837    3.503420    0.459957    0.076815    0.016032    0.561820    
#> 461: 0.676012    1.035844    3.503415    0.460025    0.076846    0.016029    0.561798    
#> 462: 0.676074    1.035856    3.503452    0.460190    0.076809    0.016034    0.561733    
#> 463: 0.676075    1.035900    3.503435    0.460243    0.076783    0.016028    0.561740    
#> 464: 0.676097    1.035998    3.503401    0.460326    0.076772    0.016021    0.561685    
#> 465: 0.676125    1.035900    3.503406    0.460450    0.076782    0.016011    0.561617    
#> 466: 0.676222    1.035922    3.503410    0.460370    0.076835    0.016003    0.561578    
#> 467: 0.676076    1.035878    3.503423    0.460147    0.076830    0.016000    0.561549    
#> 468: 0.676216    1.035851    3.503487    0.459882    0.076845    0.015990    0.561571    
#> 469: 0.676322    1.035927    3.503526    0.459700    0.076860    0.015985    0.561639    
#> 470: 0.676279    1.035940    3.503538    0.459382    0.076864    0.015989    0.561673    
#> 471: 0.676308    1.035883    3.503560    0.458960    0.076872    0.015997    0.561670    
#> 472: 0.676288    1.035827    3.503580    0.458607    0.076870    0.016002    0.561685    
#> 473: 0.676282    1.035830    3.503602    0.458445    0.076895    0.015998    0.561647    
#> 474: 0.676312    1.035774    3.503636    0.458504    0.076950    0.016003    0.561710    
#> 475: 0.676284    1.035864    3.503608    0.458386    0.076955    0.015989    0.561752    
#> 476: 0.676111    1.035816    3.503591    0.458291    0.076964    0.015977    0.561771    
#> 477: 0.675953    1.035774    3.503603    0.458108    0.076952    0.015971    0.561716    
#> 478: 0.675798    1.035749    3.503595    0.457865    0.076930    0.015965    0.561682    
#> 479: 0.675824    1.035769    3.503602    0.457706    0.076929    0.015956    0.561651    
#> 480: 0.675799    1.035765    3.503614    0.457444    0.076963    0.015944    0.561717    
#> 481: 0.675833    1.035782    3.503613    0.457512    0.076957    0.015941    0.561798    
#> 482: 0.675818    1.035841    3.503590    0.457431    0.076965    0.015934    0.561829    
#> 483: 0.675698    1.035806    3.503583    0.457531    0.077027    0.015925    0.561859    
#> 484: 0.675570    1.035694    3.503570    0.457571    0.077067    0.015929    0.561872    
#> 485: 0.675457    1.035724    3.503520    0.457652    0.077107    0.015930    0.561913    
#> 486: 0.675539    1.035754    3.503502    0.457777    0.077082    0.015935    0.561915    
#> 487: 0.675683    1.035770    3.503524    0.457758    0.077085    0.015931    0.561936    
#> 488: 0.675686    1.035814    3.503545    0.457631    0.077158    0.015923    0.561930    
#> 489: 0.675775    1.035776    3.503547    0.457546    0.077219    0.015914    0.561911    
#> 490: 0.675926    1.035729    3.503584    0.457604    0.077239    0.015897    0.561896    
#> 491: 0.675932    1.035724    3.503614    0.457680    0.077239    0.015893    0.561879    
#> 492: 0.675997    1.035792    3.503614    0.457732    0.077261    0.015896    0.561872    
#> 493: 0.675975    1.035820    3.503628    0.457770    0.077290    0.015896    0.561827    
#> 494: 0.676168    1.035818    3.503652    0.457783    0.077270    0.015899    0.561801    
#> 495: 0.676183    1.035828    3.503660    0.457912    0.077255    0.015902    0.561775    
#> 496: 0.676250    1.035841    3.503621    0.458079    0.077257    0.015909    0.561763    
#> 497: 0.676121    1.035862    3.503598    0.458314    0.077213    0.015923    0.561790    
#> 498: 0.676198    1.035886    3.503573    0.458789    0.077206    0.015928    0.561747    
#> 499: 0.676275    1.035875    3.503554    0.458919    0.077198    0.015929    0.561726    
#> 500: 0.676308    1.035841    3.503536    0.459021    0.077162    0.015929    0.561681    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.293312    0.976172    3.439670    0.392401    0.080236    0.016800    1.793512    
#> 002: 0.346595    1.049217    3.451194    0.372781    0.076224    0.017325    1.230640    
#> 003: 0.394310    1.010756    3.454187    0.354142    0.075645    0.016459    0.951724    
#> 004: 0.379340    1.010506    3.449179    0.336435    0.084086    0.018062    0.852755    
#> 005: 0.458958    0.988468    3.450246    0.393312    0.095787    0.017159    0.805570    
#> 006: 0.417016    1.001209    3.448011    0.373646    0.102362    0.018583    0.763717    
#> 007: 0.374657    1.011850    3.443876    0.396625    0.122664    0.019105    0.772022    
#> 008: 0.434471    1.000101    3.443584    0.396466    0.117455    0.019674    0.777822    
#> 009: 0.411083    0.982460    3.449223    0.376643    0.113558    0.019035    0.783254    
#> 010: 0.433249    0.989041    3.454015    0.357811    0.116536    0.019187    0.778578    
#> 011: 0.504291    0.981189    3.463127    0.369128    0.110709    0.019270    0.799578    
#> 012: 0.502662    0.968193    3.470674    0.350672    0.105173    0.018931    0.782391    
#> 013: 0.471088    0.977560    3.453054    0.415230    0.099915    0.025402    0.772228    
#> 014: 0.487395    0.976774    3.459001    0.394469    0.100780    0.024132    0.784153    
#> 015: 0.509195    0.984496    3.487114    0.374745    0.100532    0.023752    0.777091    
#> 016: 0.489366    0.997501    3.488895    0.356008    0.115614    0.025728    0.787674    
#> 017: 0.478270    0.993758    3.482556    0.338208    0.114983    0.024442    0.743187    
#> 018: 0.499012    0.981643    3.476525    0.321297    0.109234    0.023219    0.789944    
#> 019: 0.478884    0.980144    3.483618    0.312130    0.107939    0.023202    0.766902    
#> 020: 0.531382    0.959861    3.498102    0.352632    0.102542    0.024721    0.772062    
#> 021: 0.544319    0.950504    3.494492    0.469874    0.097415    0.025614    0.767382    
#> 022: 0.524345    0.971951    3.500969    0.458388    0.100423    0.025687    0.761166    
#> 023: 0.588526    0.969620    3.506725    0.435469    0.110818    0.024402    0.789236    
#> 024: 0.602899    0.971998    3.505860    0.413696    0.105277    0.026021    0.763080    
#> 025: 0.539375    0.964481    3.493521    0.393011    0.100013    0.026692    0.753993    
#> 026: 0.536606    1.011977    3.475901    0.412454    0.100127    0.029611    0.758202    
#> 027: 0.482313    1.037162    3.461453    0.425225    0.105674    0.028131    0.770305    
#> 028: 0.484037    0.988808    3.483264    0.403964    0.102038    0.028501    0.763363    
#> 029: 0.473266    0.999041    3.466417    0.383766    0.096936    0.027405    0.805769    
#> 030: 0.499476    1.003620    3.464935    0.364577    0.107613    0.028482    0.784088    
#> 031: 0.443780    1.004643    3.466582    0.346348    0.102233    0.027058    0.778179    
#> 032: 0.453354    1.003294    3.468325    0.329031    0.097121    0.025705    0.772526    
#> 033: 0.448922    1.014384    3.460417    0.341987    0.097961    0.024420    0.779132    
#> 034: 0.480517    1.015591    3.471526    0.324888    0.107306    0.023207    0.758647    
#> 035: 0.459403    0.994254    3.468395    0.320737    0.111366    0.022047    0.749574    
#> 036: 0.477273    0.979157    3.474930    0.304700    0.105798    0.020944    0.798437    
#> 037: 0.448454    0.999463    3.461774    0.311880    0.114571    0.019897    0.800240    
#> 038: 0.467264    1.018152    3.447836    0.377471    0.108842    0.018902    0.784707    
#> 039: 0.446228    0.994356    3.461592    0.358598    0.103400    0.018254    0.770269    
#> 040: 0.433409    1.005865    3.471811    0.350421    0.116102    0.019520    0.773852    
#> 041: 0.428652    1.002172    3.459960    0.332900    0.110297    0.019148    0.768574    
#> 042: 0.453021    0.985001    3.471744    0.384631    0.111893    0.020042    0.752091    
#> 043: 0.426190    1.011967    3.450817    0.365400    0.110179    0.019040    0.791954    
#> 044: 0.441808    1.010474    3.461106    0.350233    0.104670    0.018088    0.805406    
#> 045: 0.451781    1.015459    3.444841    0.332721    0.124667    0.019680    0.794104    
#> 046: 0.415233    1.001218    3.439485    0.386110    0.118434    0.020321    0.782913    
#> 047: 0.437143    1.012795    3.443836    0.366805    0.112512    0.021229    0.787050    
#> 048: 0.445750    1.007288    3.452808    0.348465    0.118824    0.023198    0.779278    
#> 049: 0.429901    0.993652    3.453523    0.361138    0.112883    0.022309    0.791146    
#> 050: 0.483519    0.965620    3.463333    0.357770    0.107239    0.022003    0.791727    
#> 051: 0.443092    0.988010    3.453655    0.362908    0.103928    0.023936    0.786458    
#> 052: 0.459191    1.013885    3.468612    0.368144    0.119767    0.022740    0.772906    
#> 053: 0.475207    1.001553    3.473617    0.434150    0.135912    0.025084    0.759761    
#> 054: 0.474387    0.988540    3.478322    0.412443    0.129117    0.025022    0.772403    
#> 055: 0.469765    0.996999    3.472593    0.391820    0.122661    0.023771    0.769277    
#> 056: 0.489149    1.001450    3.471295    0.372229    0.116528    0.022582    0.782997    
#> 057: 0.520941    0.963730    3.490292    0.383179    0.110701    0.023512    0.778461    
#> 058: 0.527307    0.965758    3.478174    0.414936    0.105166    0.023830    0.771723    
#> 059: 0.509459    0.911774    3.496586    0.394189    0.099908    0.025173    0.801831    
#> 060: 0.521220    0.896721    3.512562    0.374480    0.111014    0.023914    0.813928    
#> 061: 0.520121    0.949388    3.499997    0.355756    0.120772    0.022718    0.823414    
#> 062: 0.519851    0.985842    3.491357    0.337968    0.124849    0.021582    0.805581    
#> 063: 0.512947    0.967754    3.481777    0.321070    0.118607    0.020503    0.819445    
#> 064: 0.482270    0.984135    3.487671    0.305016    0.112677    0.019478    0.790450    
#> 065: 0.515349    0.968263    3.476451    0.304327    0.114516    0.019008    0.787165    
#> 066: 0.548727    0.957169    3.490069    0.289110    0.108790    0.018058    0.793569    
#> 067: 0.507189    0.942419    3.484027    0.274655    0.103350    0.021434    0.785641    
#> 068: 0.477542    0.950915    3.489638    0.279164    0.120906    0.022700    0.792335    
#> 069: 0.463513    0.986407    3.470123    0.285322    0.128888    0.021565    0.795695    
#> 070: 0.442015    0.995814    3.473577    0.304851    0.143081    0.020487    0.786869    
#> 071: 0.407133    1.011790    3.450591    0.321427    0.135927    0.019463    0.788486    
#> 072: 0.422339    0.980274    3.460600    0.363683    0.129131    0.018489    0.773729    
#> 073: 0.456839    0.998423    3.483705    0.345499    0.122674    0.017565    0.769727    
#> 074: 0.437310    0.956242    3.479494    0.328224    0.116541    0.018858    0.772846    
#> 075: 0.532624    0.925816    3.518619    0.316060    0.110713    0.017915    0.817782    
#> 076: 0.536557    0.951293    3.517352    0.314119    0.108060    0.017019    0.803035    
#> 077: 0.574076    0.944156    3.502343    0.364955    0.114528    0.016168    0.804859    
#> 078: 0.538555    0.957192    3.500278    0.346708    0.108801    0.019480    0.788302    
#> 079: 0.531332    0.962098    3.495514    0.406680    0.103361    0.018506    0.786138    
#> 080: 0.536967    0.969270    3.492596    0.386346    0.107264    0.017622    0.810104    
#> 081: 0.470208    0.997059    3.468317    0.367029    0.101901    0.016741    0.780489    
#> 082: 0.486249    0.987383    3.478354    0.363305    0.104336    0.016126    0.794120    
#> 083: 0.509518    1.006738    3.479415    0.391171    0.104966    0.018624    0.781983    
#> 084: 0.491899    1.008154    3.460963    0.451596    0.108682    0.019240    0.751631    
#> 085: 0.452424    1.014250    3.463159    0.429016    0.131822    0.018914    0.759640    
#> 086: 0.460412    1.022087    3.462349    0.429254    0.125231    0.017968    0.757930    
#> 087: 0.451586    1.004784    3.456676    0.407792    0.130965    0.017070    0.750761    
#> 088: 0.398690    1.004717    3.452680    0.387402    0.131264    0.016217    0.787241    
#> 089: 0.411589    1.029170    3.434365    0.368032    0.139252    0.015406    0.786084    
#> 090: 0.380492    1.019542    3.441703    0.349630    0.132290    0.014635    0.789067    
#> 091: 0.369699    1.030842    3.432201    0.332149    0.125675    0.016181    0.779584    
#> 092: 0.394894    1.040826    3.426637    0.359751    0.119391    0.016117    0.785380    
#> 093: 0.390335    1.008993    3.425716    0.393487    0.113422    0.017851    0.795519    
#> 094: 0.397071    1.024780    3.425982    0.401479    0.107751    0.017830    0.783976    
#> 095: 0.408387    1.029343    3.445938    0.423635    0.115604    0.020810    0.773443    
#> 096: 0.403991    1.032987    3.450311    0.407116    0.158697    0.019770    0.769456    
#> 097: 0.426450    1.042302    3.434560    0.472050    0.152160    0.018781    0.752533    
#> 098: 0.433540    1.054492    3.438357    0.448447    0.144552    0.017842    0.761912    
#> 099: 0.399060    1.006522    3.426463    0.426025    0.137325    0.016950    0.760467    
#> 100: 0.355881    1.028691    3.422174    0.404724    0.130459    0.016103    0.745230    
#> 101: 0.354962    1.010895    3.409863    0.413435    0.123936    0.015298    0.755918    
#> 102: 0.366399    1.020719    3.404129    0.407558    0.126412    0.014533    0.768326    
#> 103: 0.397639    1.029438    3.430094    0.387181    0.130151    0.013806    0.773819    
#> 104: 0.355295    1.038807    3.445545    0.367822    0.123643    0.013116    0.779300    
#> 105: 0.428277    0.999586    3.455498    0.353140    0.117461    0.014167    0.783354    
#> 106: 0.431917    0.999986    3.450209    0.450887    0.111588    0.015754    0.772569    
#> 107: 0.459723    1.012491    3.455421    0.428343    0.106008    0.016082    0.759848    
#> 108: 0.442734    1.015215    3.451025    0.406925    0.116003    0.015464    0.770697    
#> 109: 0.417128    1.005344    3.447088    0.386579    0.110203    0.014713    0.775248    
#> 110: 0.439733    0.986395    3.432478    0.401224    0.104693    0.013978    0.784589    
#> 111: 0.412498    1.007840    3.437188    0.429340    0.099458    0.013668    0.764342    
#> 112: 0.432293    1.003051    3.442192    0.407873    0.106265    0.015990    0.767887    
#> 113: 0.411173    1.040083    3.445744    0.387480    0.100952    0.017214    0.768456    
#> 114: 0.429894    1.019166    3.451832    0.368106    0.095904    0.019422    0.771821    
#> 115: 0.482818    0.981424    3.456797    0.355063    0.091109    0.019386    0.780908    
#> 116: 0.478719    0.994343    3.464704    0.366644    0.099541    0.028221    0.772015    
#> 117: 0.464349    1.012158    3.473855    0.408797    0.094564    0.027376    0.761115    
#> 118: 0.498012    0.985108    3.471862    0.388357    0.097048    0.026007    0.762213    
#> 119: 0.482738    0.995391    3.465291    0.441940    0.096227    0.024710    0.778478    
#> 120: 0.447506    0.991496    3.450591    0.471411    0.111911    0.023474    0.752860    
#> 121: 0.494970    1.052767    3.452329    0.499024    0.113844    0.022301    0.763849    
#> 122: 0.490139    0.998371    3.462166    0.474073    0.109307    0.021186    0.757836    
#> 123: 0.486174    1.033373    3.450113    0.450369    0.106445    0.020126    0.770054    
#> 124: 0.448726    1.029780    3.453433    0.427851    0.124964    0.019987    0.754635    
#> 125: 0.474275    1.042481    3.452124    0.406458    0.118716    0.021511    0.774318    
#> 126: 0.397378    1.055737    3.423971    0.405046    0.112780    0.022859    0.776782    
#> 127: 0.413674    1.012741    3.428775    0.384793    0.107141    0.021716    0.784227    
#> 128: 0.409499    1.002513    3.452626    0.379494    0.101784    0.020630    0.774852    
#> 129: 0.449977    1.019917    3.446734    0.443066    0.130673    0.019598    0.775790    
#> 130: 0.487120    1.027319    3.450909    0.420913    0.130916    0.018619    0.762972    
#> 131: 0.463539    0.994808    3.442328    0.459021    0.126136    0.019832    0.765774    
#> 132: 0.437644    1.012341    3.436942    0.436070    0.119829    0.020785    0.763057    
#> 133: 0.431090    0.990718    3.451115    0.414266    0.118136    0.020008    0.770416    
#> 134: 0.482338    0.976906    3.472440    0.393553    0.112229    0.019008    0.786818    
#> 135: 0.478009    0.981226    3.477796    0.373875    0.116829    0.018057    0.767931    
#> 136: 0.455566    0.969352    3.468331    0.355181    0.132885    0.017155    0.767394    
#> 137: 0.491521    0.966671    3.469085    0.349572    0.126241    0.016413    0.782302    
#> 138: 0.456481    0.995498    3.456937    0.406946    0.130992    0.015592    0.760346    
#> 139: 0.445680    1.005583    3.458714    0.416605    0.124443    0.016774    0.751450    
#> 140: 0.460457    0.996040    3.471624    0.395774    0.118221    0.023356    0.765147    
#> 141: 0.448648    0.966132    3.467674    0.391829    0.114240    0.022189    0.754997    
#> 142: 0.490247    0.960722    3.484183    0.416959    0.108528    0.024674    0.747185    
#> 143: 0.460411    0.987656    3.486287    0.396111    0.103102    0.026022    0.767708    
#> 144: 0.525674    0.973709    3.499191    0.376306    0.097947    0.030476    0.748403    
#> 145: 0.492471    0.990990    3.473696    0.371597    0.093049    0.028952    0.735371    
#> 146: 0.488286    0.986162    3.473703    0.396941    0.107248    0.027505    0.749666    
#> 147: 0.440970    0.967573    3.475109    0.377094    0.105463    0.026861    0.737767    
#> 148: 0.451817    0.985633    3.474772    0.358239    0.100466    0.025517    0.752772    
#> 149: 0.447467    0.972778    3.480295    0.340327    0.095442    0.025813    0.787081    
#> 150: 0.479383    0.989507    3.466517    0.335504    0.104951    0.024523    0.790245    
#> 151: 0.420386    1.006413    3.461232    0.327040    0.099703    0.023297    0.790318    
#> 152: 0.422925    0.999509    3.471990    0.328002    0.097764    0.021815    0.782778    
#> 153: 0.431371    1.006003    3.470640    0.321131    0.110329    0.015307    0.787075    
#> 154: 0.468771    1.016098    3.472058    0.331518    0.119930    0.016085    0.796305    
#> 155: 0.442087    1.007839    3.460249    0.369102    0.135270    0.015177    0.781830    
#> 156: 0.468701    1.015580    3.475148    0.388464    0.132532    0.016122    0.800132    
#> 157: 0.491091    1.007555    3.482753    0.332446    0.149770    0.019831    0.811731    
#> 158: 0.530181    1.002153    3.468985    0.381215    0.141959    0.015281    0.795354    
#> 159: 0.467596    1.009881    3.468999    0.346827    0.107799    0.015508    0.796725    
#> 160: 0.504822    0.976095    3.482566    0.352073    0.123621    0.012876    0.806571    
#> 161: 0.508768    0.968932    3.480293    0.387025    0.138187    0.014377    0.799184    
#> 162: 0.472168    0.991082    3.460993    0.384511    0.148272    0.010117    0.810505    
#> 163: 0.457553    1.006857    3.456276    0.346128    0.177478    0.011932    0.796633    
#> 164: 0.423049    1.008150    3.443922    0.330858    0.163724    0.011375    0.779709    
#> 165: 0.432245    1.010731    3.449966    0.373086    0.140636    0.013532    0.766430    
#> 166: 0.451129    1.046314    3.449406    0.383026    0.149749    0.013470    0.758720    
#> 167: 0.492842    1.013374    3.465810    0.450211    0.128730    0.013351    0.780009    
#> 168: 0.511544    0.989772    3.463812    0.458437    0.123953    0.012252    0.772123    
#> 169: 0.499691    1.041510    3.456143    0.528560    0.120433    0.012156    0.804054    
#> 170: 0.508652    1.006307    3.469660    0.397450    0.124128    0.012824    0.791122    
#> 171: 0.437785    1.004582    3.463552    0.380396    0.113059    0.012745    0.759906    
#> 172: 0.441585    1.037787    3.456935    0.367099    0.119148    0.012546    0.767608    
#> 173: 0.445246    1.019964    3.448885    0.326935    0.105809    0.013413    0.761147    
#> 174: 0.443442    0.991964    3.462273    0.327584    0.107407    0.012928    0.771522    
#> 175: 0.446303    1.008442    3.453904    0.398120    0.103824    0.014004    0.789880    
#> 176: 0.409309    1.040011    3.454835    0.308598    0.116997    0.012569    0.783442    
#> 177: 0.447260    1.014147    3.469888    0.361734    0.107674    0.012412    0.783871    
#> 178: 0.442789    0.992662    3.459597    0.352733    0.117320    0.011371    0.778987    
#> 179: 0.502700    1.018718    3.457703    0.463236    0.119311    0.012434    0.778150    
#> 180: 0.417803    1.012578    3.452413    0.368104    0.121410    0.011394    0.785966    
#> 181: 0.430603    1.008182    3.442053    0.358109    0.131236    0.010877    0.757410    
#> 182: 0.417899    1.016469    3.433982    0.399462    0.104801    0.013362    0.760157    
#> 183: 0.393727    1.030323    3.430354    0.320500    0.102824    0.016490    0.773505    
#> 184: 0.411150    1.002838    3.442534    0.330575    0.122066    0.014897    0.797509    
#> 185: 0.383806    1.032106    3.437463    0.358327    0.133600    0.011168    0.797230    
#> 186: 0.399759    1.025893    3.451121    0.437044    0.122405    0.012887    0.794269    
#> 187: 0.427614    1.013591    3.457231    0.368092    0.134603    0.012871    0.769277    
#> 188: 0.372135    1.026501    3.440111    0.427722    0.129117    0.011542    0.800113    
#> 189: 0.434959    1.027238    3.450374    0.307985    0.137661    0.012300    0.778550    
#> 190: 0.398296    1.040595    3.451040    0.357743    0.117729    0.013100    0.762406    
#> 191: 0.418938    1.040302    3.437416    0.334908    0.133948    0.012771    0.762505    
#> 192: 0.394358    1.038129    3.441820    0.288359    0.118872    0.013179    0.764418    
#> 193: 0.453057    1.020221    3.447143    0.309841    0.114844    0.013036    0.761254    
#> 194: 0.404323    1.003908    3.446917    0.332501    0.117563    0.016713    0.775315    
#> 195: 0.405134    1.024771    3.442174    0.298749    0.134876    0.016730    0.752529    
#> 196: 0.442215    1.005985    3.454300    0.317741    0.120033    0.016915    0.768728    
#> 197: 0.396902    1.010932    3.468959    0.280407    0.135386    0.015763    0.771296    
#> 198: 0.465810    0.984802    3.455098    0.286763    0.111278    0.019741    0.772389    
#> 199: 0.428153    0.996501    3.457381    0.266525    0.108223    0.020258    0.764919    
#> 200: 0.409798    0.998376    3.461660    0.263467    0.098063    0.015417    0.782036    
#> 201: 0.394512    0.998084    3.461822    0.285911    0.095169    0.016701    0.778065    
#> 202: 0.406879    1.008145    3.456132    0.287011    0.098153    0.016134    0.778202    
#> 203: 0.424303    1.010084    3.452552    0.303073    0.103238    0.015525    0.777991    
#> 204: 0.432254    1.002526    3.456423    0.309813    0.108009    0.016317    0.776435    
#> 205: 0.436943    1.007020    3.458115    0.312600    0.109663    0.016595    0.781089    
#> 206: 0.439271    1.012535    3.458953    0.309188    0.108587    0.017109    0.784677    
#> 207: 0.441197    1.012583    3.458534    0.312900    0.107353    0.017303    0.785837    
#> 208: 0.443224    1.013683    3.459345    0.311981    0.106233    0.017536    0.785117    
#> 209: 0.445661    1.010585    3.459398    0.312550    0.106305    0.017337    0.784082    
#> 210: 0.446546    1.007054    3.459988    0.316810    0.107148    0.017198    0.781922    
#> 211: 0.451885    1.005151    3.462040    0.321268    0.106779    0.017196    0.779422    
#> 212: 0.455007    1.003017    3.462848    0.321345    0.107943    0.017302    0.777754    
#> 213: 0.457875    0.999281    3.463994    0.318060    0.108999    0.017560    0.777688    
#> 214: 0.459925    0.997047    3.464864    0.315071    0.108885    0.017800    0.777428    
#> 215: 0.457473    0.995462    3.465507    0.315061    0.108420    0.017925    0.778179    
#> 216: 0.460994    0.994351    3.466195    0.317042    0.108786    0.018226    0.777599    
#> 217: 0.462922    0.994784    3.467017    0.317353    0.109998    0.018461    0.776712    
#> 218: 0.464274    0.995701    3.467277    0.316220    0.111586    0.018485    0.775807    
#> 219: 0.463795    0.995688    3.466216    0.318963    0.112335    0.018351    0.775190    
#> 220: 0.461963    0.996793    3.465726    0.320688    0.112895    0.018108    0.774218    
#> 221: 0.460509    0.997205    3.464984    0.322425    0.114003    0.017917    0.773536    
#> 222: 0.458381    0.997031    3.464224    0.321852    0.114582    0.017689    0.773705    
#> 223: 0.459928    0.996578    3.464024    0.322595    0.114666    0.017449    0.773691    
#> 224: 0.461149    0.996912    3.464068    0.323193    0.114942    0.017225    0.773936    
#> 225: 0.460579    0.995516    3.464198    0.323410    0.115536    0.017028    0.773194    
#> 226: 0.459725    0.995271    3.463427    0.325786    0.115287    0.016957    0.773222    
#> 227: 0.458720    0.995760    3.462906    0.327658    0.115253    0.016889    0.772414    
#> 228: 0.457392    0.997179    3.461804    0.330081    0.115192    0.016727    0.772187    
#> 229: 0.455649    0.997414    3.460989    0.330798    0.115363    0.016594    0.772038    
#> 230: 0.454643    0.997693    3.460481    0.330633    0.115695    0.016478    0.772145    
#> 231: 0.454322    0.998365    3.460463    0.331991    0.116219    0.016456    0.772043    
#> 232: 0.452900    0.998823    3.460363    0.332224    0.116154    0.016439    0.771951    
#> 233: 0.452364    0.998230    3.460310    0.332127    0.116167    0.016462    0.772211    
#> 234: 0.451212    0.998124    3.459986    0.333493    0.116226    0.016542    0.771556    
#> 235: 0.449763    0.998209    3.459557    0.334896    0.116116    0.016585    0.771411    
#> 236: 0.448337    0.998648    3.459022    0.334768    0.116380    0.016568    0.771908    
#> 237: 0.448100    0.998943    3.458409    0.336486    0.115979    0.016539    0.772562    
#> 238: 0.448256    0.998982    3.458134    0.339643    0.115851    0.016639    0.772769    
#> 239: 0.448102    0.999683    3.457888    0.341503    0.115518    0.016757    0.773129    
#> 240: 0.448692    0.999354    3.458135    0.343193    0.115266    0.016832    0.772803    
#> 241: 0.449758    0.998071    3.458537    0.342746    0.114881    0.016832    0.772703    
#> 242: 0.449679    0.997449    3.458580    0.341718    0.114975    0.016816    0.772796    
#> 243: 0.449333    0.997754    3.458716    0.341581    0.114872    0.016827    0.773217    
#> 244: 0.448583    0.997834    3.458886    0.340420    0.114766    0.016878    0.773712    
#> 245: 0.448485    0.997569    3.459188    0.340351    0.114645    0.016966    0.774187    
#> 246: 0.448270    0.997403    3.459325    0.340969    0.114869    0.017104    0.774848    
#> 247: 0.447613    0.997408    3.459539    0.341537    0.114793    0.017208    0.775028    
#> 248: 0.448121    0.997652    3.459751    0.341006    0.114768    0.017293    0.775209    
#> 249: 0.448317    0.997636    3.460144    0.342396    0.114776    0.017359    0.774755    
#> 250: 0.449117    0.997445    3.460423    0.342245    0.114664    0.017435    0.774861    
#> 251: 0.449852    0.997587    3.460917    0.341931    0.114678    0.017449    0.775125    
#> 252: 0.451169    0.997594    3.461389    0.342859    0.114398    0.017441    0.774974    
#> 253: 0.451201    0.997449    3.461735    0.341909    0.114215    0.017465    0.775053    
#> 254: 0.451490    0.997939    3.462098    0.341293    0.114288    0.017493    0.775181    
#> 255: 0.451600    0.997944    3.462469    0.339614    0.114172    0.017553    0.775261    
#> 256: 0.451849    0.997665    3.462551    0.338996    0.114405    0.017585    0.775249    
#> 257: 0.451880    0.997421    3.462463    0.339301    0.114992    0.017628    0.774963    
#> 258: 0.451552    0.997201    3.462563    0.338661    0.114870    0.017662    0.774832    
#> 259: 0.451411    0.997111    3.462439    0.337583    0.114613    0.017670    0.774939    
#> 260: 0.451241    0.997141    3.462478    0.337067    0.114699    0.017683    0.774792    
#> 261: 0.451457    0.997345    3.462516    0.337756    0.114499    0.017712    0.774752    
#> 262: 0.452156    0.997708    3.462604    0.339521    0.114303    0.017769    0.774401    
#> 263: 0.452551    0.998267    3.462653    0.340153    0.114153    0.017805    0.774244    
#> 264: 0.452939    0.998491    3.462772    0.340892    0.114128    0.017873    0.774543    
#> 265: 0.453360    0.998463    3.462962    0.341118    0.113748    0.018031    0.774868    
#> 266: 0.453715    0.998573    3.463009    0.341243    0.113686    0.018104    0.774761    
#> 267: 0.454360    0.998410    3.463326    0.342011    0.113546    0.018196    0.774567    
#> 268: 0.454491    0.998211    3.463416    0.342245    0.113520    0.018267    0.774448    
#> 269: 0.455393    0.997989    3.463657    0.342284    0.113310    0.018304    0.774409    
#> 270: 0.455771    0.998133    3.463682    0.341934    0.113133    0.018296    0.773959    
#> 271: 0.456071    0.998057    3.463744    0.341262    0.113125    0.018298    0.773993    
#> 272: 0.456173    0.997665    3.463802    0.341139    0.113282    0.018299    0.774231    
#> 273: 0.456079    0.997805    3.463933    0.340866    0.113242    0.018383    0.774406    
#> 274: 0.456222    0.997903    3.464120    0.340438    0.113501    0.018387    0.774250    
#> 275: 0.456026    0.997670    3.464029    0.340434    0.113674    0.018378    0.774268    
#> 276: 0.456283    0.997554    3.464454    0.339532    0.113684    0.018462    0.774370    
#> 277: 0.456530    0.997537    3.464781    0.339073    0.113782    0.018511    0.774339    
#> 278: 0.456768    0.997376    3.465029    0.339201    0.113689    0.018591    0.774140    
#> 279: 0.457101    0.996998    3.465176    0.340563    0.113911    0.018607    0.774245    
#> 280: 0.457321    0.996902    3.465323    0.340946    0.113950    0.018598    0.774305    
#> 281: 0.457277    0.996883    3.465450    0.341011    0.114102    0.018586    0.774199    
#> 282: 0.457725    0.997052    3.465631    0.340746    0.114119    0.018608    0.774212    
#> 283: 0.457898    0.997170    3.465732    0.340830    0.114400    0.018680    0.774415    
#> 284: 0.458102    0.996994    3.465797    0.340830    0.114450    0.018667    0.774218    
#> 285: 0.458426    0.996874    3.465773    0.341082    0.114385    0.018692    0.774091    
#> 286: 0.458541    0.996995    3.465702    0.341893    0.114382    0.018711    0.773958    
#> 287: 0.458531    0.997145    3.465657    0.342907    0.114257    0.018730    0.773704    
#> 288: 0.459174    0.997239    3.465759    0.343498    0.114037    0.018772    0.773477    
#> 289: 0.459613    0.997133    3.465863    0.344132    0.113985    0.018825    0.773506    
#> 290: 0.459975    0.996898    3.466002    0.344492    0.114009    0.018900    0.773580    
#> 291: 0.460475    0.996583    3.466264    0.344654    0.113976    0.018979    0.773354    
#> 292: 0.460372    0.996221    3.466391    0.344762    0.113833    0.019015    0.773491    
#> 293: 0.460703    0.996019    3.466468    0.345108    0.113632    0.019028    0.773474    
#> 294: 0.460845    0.996063    3.466511    0.344942    0.113494    0.019077    0.773182    
#> 295: 0.461265    0.995841    3.466520    0.345875    0.113482    0.019052    0.772976    
#> 296: 0.460927    0.995789    3.466435    0.345978    0.113646    0.019042    0.772939    
#> 297: 0.460890    0.995984    3.466345    0.346269    0.113694    0.018997    0.773163    
#> 298: 0.461062    0.995954    3.466305    0.346930    0.113694    0.018974    0.773133    
#> 299: 0.461233    0.996117    3.466233    0.347595    0.113703    0.018966    0.772833    
#> 300: 0.461610    0.996090    3.466325    0.347825    0.113778    0.019011    0.772704    
#> 301: 0.461795    0.996031    3.466194    0.347738    0.113786    0.018981    0.772789    
#> 302: 0.461933    0.995922    3.466158    0.347968    0.113823    0.018944    0.772649    
#> 303: 0.461840    0.996032    3.466089    0.348261    0.113853    0.018899    0.772730    
#> 304: 0.461880    0.996461    3.465910    0.348567    0.113983    0.018865    0.772860    
#> 305: 0.461700    0.996407    3.465748    0.348558    0.113885    0.018843    0.773000    
#> 306: 0.461273    0.996332    3.465685    0.348219    0.113804    0.018857    0.773003    
#> 307: 0.460989    0.996356    3.465724    0.347921    0.113789    0.018877    0.772931    
#> 308: 0.460566    0.996082    3.465675    0.347463    0.113841    0.018867    0.773364    
#> 309: 0.460368    0.995744    3.465663    0.347684    0.113906    0.018900    0.773511    
#> 310: 0.460430    0.995642    3.465477    0.348177    0.113818    0.018881    0.773722    
#> 311: 0.460182    0.995744    3.465308    0.348029    0.113680    0.018902    0.773706    
#> 312: 0.459948    0.995750    3.465107    0.348184    0.113573    0.018929    0.773741    
#> 313: 0.459605    0.995479    3.465023    0.347863    0.113481    0.018938    0.773729    
#> 314: 0.459214    0.995564    3.464897    0.347864    0.113326    0.018963    0.773721    
#> 315: 0.458749    0.995844    3.464894    0.347759    0.113300    0.018974    0.773825    
#> 316: 0.458547    0.996214    3.464793    0.347200    0.113312    0.018946    0.773896    
#> 317: 0.458394    0.996383    3.464739    0.346992    0.113274    0.018940    0.774053    
#> 318: 0.458450    0.996625    3.464679    0.346953    0.113182    0.018942    0.773871    
#> 319: 0.458645    0.996575    3.464868    0.346618    0.113094    0.018976    0.773861    
#> 320: 0.458433    0.996535    3.464843    0.346026    0.113169    0.018996    0.773945    
#> 321: 0.458416    0.996703    3.464745    0.345971    0.113214    0.018975    0.773966    
#> 322: 0.457983    0.996850    3.464604    0.345644    0.113236    0.018961    0.773936    
#> 323: 0.457463    0.996787    3.464489    0.345802    0.113127    0.018924    0.773831    
#> 324: 0.457328    0.996847    3.464488    0.345755    0.112987    0.018904    0.773706    
#> 325: 0.457138    0.996945    3.464403    0.346167    0.113001    0.018889    0.773674    
#> 326: 0.457064    0.996877    3.464286    0.346923    0.112858    0.018881    0.773647    
#> 327: 0.457089    0.996990    3.464250    0.347910    0.112950    0.018873    0.773557    
#> 328: 0.456657    0.997285    3.464115    0.347683    0.113073    0.018857    0.773524    
#> 329: 0.456503    0.997188    3.464103    0.346950    0.113072    0.018826    0.773472    
#> 330: 0.456348    0.997052    3.464183    0.346234    0.113166    0.018842    0.773577    
#> 331: 0.456422    0.997152    3.464187    0.346246    0.113229    0.018834    0.773686    
#> 332: 0.456331    0.997219    3.464231    0.346077    0.113241    0.018840    0.773794    
#> 333: 0.456294    0.997398    3.464076    0.346856    0.113116    0.018842    0.773776    
#> 334: 0.456101    0.997329    3.463876    0.347114    0.113135    0.018826    0.773989    
#> 335: 0.455789    0.997445    3.463670    0.347403    0.113017    0.018836    0.774008    
#> 336: 0.455488    0.997627    3.463583    0.347347    0.112828    0.018861    0.774085    
#> 337: 0.455412    0.998084    3.463414    0.347883    0.112773    0.018878    0.774060    
#> 338: 0.455328    0.998193    3.463376    0.348459    0.112664    0.018876    0.774086    
#> 339: 0.454995    0.998442    3.463254    0.348573    0.112741    0.018864    0.773996    
#> 340: 0.454715    0.998394    3.463196    0.348611    0.112913    0.018874    0.773949    
#> 341: 0.454671    0.998500    3.463168    0.348682    0.113001    0.018882    0.773945    
#> 342: 0.454547    0.998558    3.463140    0.348788    0.113079    0.018854    0.773970    
#> 343: 0.454236    0.998583    3.463128    0.348506    0.113063    0.018833    0.774045    
#> 344: 0.454243    0.998572    3.463092    0.348292    0.113254    0.018819    0.774073    
#> 345: 0.454055    0.998497    3.463109    0.348179    0.113515    0.018795    0.774052    
#> 346: 0.453921    0.998425    3.463046    0.347941    0.113595    0.018779    0.773989    
#> 347: 0.454193    0.998283    3.463014    0.348030    0.113532    0.018782    0.774055    
#> 348: 0.454251    0.998320    3.463009    0.348201    0.113662    0.018779    0.774007    
#> 349: 0.454247    0.998058    3.463016    0.348714    0.113883    0.018767    0.773968    
#> 350: 0.454398    0.997755    3.463084    0.348760    0.114048    0.018757    0.773948    
#> 351: 0.454681    0.997759    3.463139    0.349142    0.114204    0.018745    0.773951    
#> 352: 0.454542    0.997793    3.463117    0.349666    0.114238    0.018723    0.774105    
#> 353: 0.454580    0.997956    3.463119    0.349994    0.114381    0.018764    0.774178    
#> 354: 0.454561    0.997944    3.462977    0.350725    0.114412    0.018801    0.774112    
#> 355: 0.454597    0.997853    3.462901    0.350917    0.114456    0.018790    0.774260    
#> 356: 0.454496    0.997888    3.462858    0.350558    0.114450    0.018773    0.774415    
#> 357: 0.454715    0.998118    3.462845    0.350644    0.114510    0.018750    0.774488    
#> 358: 0.454807    0.998315    3.462908    0.350393    0.114530    0.018739    0.774525    
#> 359: 0.454494    0.998613    3.462841    0.350069    0.114515    0.018766    0.774568    
#> 360: 0.454285    0.998761    3.462713    0.349596    0.114465    0.018790    0.774545    
#> 361: 0.454023    0.998843    3.462618    0.349033    0.114389    0.018799    0.774543    
#> 362: 0.454088    0.998935    3.462558    0.348895    0.114320    0.018786    0.774427    
#> 363: 0.453942    0.998889    3.462577    0.348374    0.114284    0.018783    0.774226    
#> 364: 0.454056    0.998964    3.462548    0.348535    0.114300    0.018755    0.774182    
#> 365: 0.454156    0.998835    3.462673    0.348169    0.114279    0.018752    0.774330    
#> 366: 0.454205    0.998752    3.462688    0.347629    0.114198    0.018746    0.774549    
#> 367: 0.454464    0.998692    3.462740    0.347697    0.114060    0.018740    0.774556    
#> 368: 0.454429    0.998845    3.462689    0.348125    0.114087    0.018749    0.774417    
#> 369: 0.454203    0.998803    3.462657    0.348625    0.114059    0.018743    0.774408    
#> 370: 0.453952    0.998802    3.462600    0.348712    0.114096    0.018691    0.774485    
#> 371: 0.453894    0.998789    3.462443    0.348698    0.114133    0.018648    0.774485    
#> 372: 0.453586    0.998969    3.462313    0.348812    0.114114    0.018633    0.774422    
#> 373: 0.453015    0.999243    3.462141    0.348976    0.114082    0.018640    0.774463    
#> 374: 0.452579    0.999357    3.462032    0.348842    0.114046    0.018652    0.774366    
#> 375: 0.452358    0.999435    3.461997    0.348707    0.113965    0.018654    0.774385    
#> 376: 0.452309    0.999565    3.461953    0.348518    0.113907    0.018685    0.774364    
#> 377: 0.452106    0.999741    3.461912    0.348100    0.113901    0.018703    0.774403    
#> 378: 0.452049    0.999770    3.461837    0.347904    0.113924    0.018717    0.774498    
#> 379: 0.451894    0.999694    3.461799    0.347775    0.113879    0.018742    0.774455    
#> 380: 0.451476    0.999689    3.461702    0.347757    0.113952    0.018772    0.774355    
#> 381: 0.450956    0.999735    3.461542    0.347874    0.114013    0.018768    0.774299    
#> 382: 0.450718    0.999732    3.461514    0.347866    0.114018    0.018762    0.774167    
#> 383: 0.450778    0.999747    3.461524    0.347796    0.114068    0.018768    0.774004    
#> 384: 0.450791    0.999694    3.461589    0.347631    0.114089    0.018774    0.774050    
#> 385: 0.450761    0.999617    3.461633    0.347575    0.114056    0.018779    0.774068    
#> 386: 0.450882    0.999840    3.461679    0.347322    0.114158    0.018787    0.774141    
#> 387: 0.450961    0.999987    3.461735    0.347225    0.114200    0.018783    0.774100    
#> 388: 0.451160    0.999887    3.461807    0.347131    0.114333    0.018761    0.774058    
#> 389: 0.451243    0.999536    3.461860    0.347191    0.114433    0.018741    0.774154    
#> 390: 0.451046    0.999452    3.461808    0.347135    0.114595    0.018715    0.774193    
#> 391: 0.451175    0.999381    3.461787    0.347098    0.114725    0.018693    0.774216    
#> 392: 0.451418    0.999284    3.461918    0.347019    0.114819    0.018701    0.774186    
#> 393: 0.451367    0.999179    3.461950    0.346759    0.114890    0.018692    0.774154    
#> 394: 0.451317    0.999069    3.461910    0.346543    0.114864    0.018693    0.774184    
#> 395: 0.451518    0.999210    3.461942    0.346202    0.114931    0.018669    0.774199    
#> 396: 0.451565    0.999191    3.461973    0.345920    0.115034    0.018655    0.774169    
#> 397: 0.451700    0.999084    3.461989    0.346121    0.115124    0.018613    0.774183    
#> 398: 0.452124    0.999038    3.462076    0.346477    0.115044    0.018613    0.774262    
#> 399: 0.452459    0.999021    3.462196    0.346500    0.115005    0.018627    0.774255    
#> 400: 0.452587    0.998951    3.462301    0.346594    0.115016    0.018634    0.774283    
#> 401: 0.452726    0.998920    3.462385    0.346349    0.114991    0.018643    0.774339    
#> 402: 0.452817    0.998963    3.462474    0.346155    0.115079    0.018646    0.774411    
#> 403: 0.453131    0.998863    3.462533    0.345906    0.115027    0.018648    0.774438    
#> 404: 0.453273    0.998932    3.462526    0.345616    0.115074    0.018649    0.774364    
#> 405: 0.453285    0.999019    3.462546    0.345732    0.114990    0.018662    0.774295    
#> 406: 0.453232    0.999040    3.462495    0.345759    0.115091    0.018661    0.774337    
#> 407: 0.453298    0.999068    3.462526    0.345817    0.115088    0.018665    0.774370    
#> 408: 0.453432    0.999115    3.462554    0.345739    0.115072    0.018642    0.774410    
#> 409: 0.453447    0.999042    3.462510    0.345530    0.115147    0.018605    0.774402    
#> 410: 0.453472    0.999053    3.462424    0.345585    0.115298    0.018570    0.774432    
#> 411: 0.453705    0.998811    3.462448    0.345720    0.115381    0.018570    0.774538    
#> 412: 0.453803    0.998807    3.462477    0.345555    0.115474    0.018557    0.774582    
#> 413: 0.453654    0.998778    3.462440    0.345245    0.115560    0.018531    0.774705    
#> 414: 0.453451    0.998797    3.462454    0.344992    0.115612    0.018506    0.774740    
#> 415: 0.453474    0.998718    3.462409    0.344744    0.115659    0.018471    0.774774    
#> 416: 0.453427    0.998832    3.462386    0.344557    0.115731    0.018460    0.774843    
#> 417: 0.453389    0.998768    3.462381    0.344283    0.115720    0.018463    0.774902    
#> 418: 0.453145    0.998903    3.462376    0.344432    0.115715    0.018465    0.774922    
#> 419: 0.453229    0.999071    3.462369    0.344540    0.115664    0.018464    0.774906    
#> 420: 0.453571    0.999049    3.462452    0.344721    0.115566    0.018476    0.774835    
#> 421: 0.453816    0.998984    3.462605    0.344579    0.115518    0.018495    0.774780    
#> 422: 0.454192    0.998838    3.462721    0.344640    0.115476    0.018506    0.774753    
#> 423: 0.454438    0.998714    3.462795    0.344401    0.115575    0.018495    0.774780    
#> 424: 0.454466    0.998529    3.462803    0.344244    0.115537    0.018497    0.774760    
#> 425: 0.454531    0.998588    3.462820    0.344449    0.115525    0.018514    0.774708    
#> 426: 0.454591    0.998646    3.462847    0.344658    0.115452    0.018500    0.774623    
#> 427: 0.454598    0.998663    3.462898    0.344598    0.115385    0.018476    0.774589    
#> 428: 0.454520    0.998758    3.462918    0.344404    0.115358    0.018443    0.774722    
#> 429: 0.454607    0.998789    3.462954    0.344336    0.115379    0.018417    0.774822    
#> 430: 0.454577    0.998876    3.462918    0.344185    0.115410    0.018394    0.774911    
#> 431: 0.454488    0.998919    3.462883    0.343864    0.115387    0.018364    0.774923    
#> 432: 0.454300    0.999031    3.462834    0.343851    0.115376    0.018352    0.774883    
#> 433: 0.454356    0.999202    3.462814    0.344038    0.115388    0.018350    0.774864    
#> 434: 0.454260    0.999175    3.462781    0.344223    0.115407    0.018327    0.774779    
#> 435: 0.454232    0.999267    3.462743    0.344195    0.115385    0.018313    0.774682    
#> 436: 0.454176    0.999247    3.462766    0.343923    0.115458    0.018302    0.774634    
#> 437: 0.454066    0.999204    3.462782    0.343870    0.115454    0.018294    0.774632    
#> 438: 0.454091    0.999333    3.462794    0.344006    0.115468    0.018276    0.774623    
#> 439: 0.454040    0.999468    3.462731    0.344212    0.115471    0.018262    0.774607    
#> 440: 0.454123    0.999583    3.462734    0.344263    0.115513    0.018248    0.774612    
#> 441: 0.454095    0.999512    3.462735    0.344029    0.115469    0.018261    0.774531    
#> 442: 0.454056    0.999478    3.462770    0.343908    0.115439    0.018266    0.774477    
#> 443: 0.454105    0.999407    3.462780    0.343949    0.115354    0.018289    0.774493    
#> 444: 0.454119    0.999342    3.462737    0.343902    0.115207    0.018322    0.774493    
#> 445: 0.454118    0.999421    3.462680    0.344229    0.115080    0.018344    0.774482    
#> 446: 0.453942    0.999525    3.462614    0.344428    0.114968    0.018347    0.774480    
#> 447: 0.454039    0.999548    3.462582    0.344552    0.114871    0.018354    0.774543    
#> 448: 0.453923    0.999543    3.462592    0.344558    0.114792    0.018359    0.774489    
#> 449: 0.453988    0.999621    3.462656    0.344514    0.114807    0.018350    0.774545    
#> 450: 0.453988    0.999583    3.462689    0.344745    0.114793    0.018338    0.774545    
#> 451: 0.454176    0.999579    3.462685    0.345101    0.114845    0.018331    0.774492    
#> 452: 0.454224    0.999641    3.462651    0.345037    0.114855    0.018331    0.774474    
#> 453: 0.454267    0.999612    3.462655    0.344895    0.114863    0.018337    0.774386    
#> 454: 0.454230    0.999686    3.462661    0.344806    0.114791    0.018328    0.774306    
#> 455: 0.454310    0.999692    3.462674    0.344988    0.114768    0.018328    0.774264    
#> 456: 0.454369    0.999643    3.462687    0.345011    0.114738    0.018321    0.774253    
#> 457: 0.454339    0.999609    3.462737    0.344950    0.114779    0.018314    0.774223    
#> 458: 0.454342    0.999700    3.462756    0.345083    0.114825    0.018314    0.774152    
#> 459: 0.454183    0.999889    3.462694    0.345132    0.114907    0.018314    0.774138    
#> 460: 0.453956    0.999955    3.462576    0.345126    0.114990    0.018301    0.774127    
#> 461: 0.453868    0.999975    3.462530    0.345545    0.115044    0.018284    0.774079    
#> 462: 0.453708    1.000036    3.462536    0.345891    0.115028    0.018288    0.774081    
#> 463: 0.453637    1.000121    3.462555    0.345958    0.115024    0.018296    0.774009    
#> 464: 0.453699    1.000193    3.462550    0.345929    0.114934    0.018304    0.773920    
#> 465: 0.453741    1.000007    3.462559    0.345844    0.114903    0.018314    0.773911    
#> 466: 0.453718    0.999981    3.462499    0.345896    0.114886    0.018315    0.773900    
#> 467: 0.453570    0.999975    3.462478    0.345626    0.114801    0.018313    0.773903    
#> 468: 0.453800    0.999973    3.462537    0.345786    0.114808    0.018311    0.773986    
#> 469: 0.453767    0.999994    3.462583    0.345743    0.114840    0.018299    0.774036    
#> 470: 0.453646    1.000002    3.462570    0.345888    0.114773    0.018300    0.774013    
#> 471: 0.453525    1.000001    3.462544    0.345905    0.114707    0.018301    0.773995    
#> 472: 0.453536    0.999954    3.462534    0.345806    0.114698    0.018294    0.774064    
#> 473: 0.453421    0.999959    3.462493    0.345735    0.114673    0.018301    0.774017    
#> 474: 0.453431    0.999912    3.462501    0.345933    0.114686    0.018307    0.774065    
#> 475: 0.453611    0.999911    3.462546    0.345984    0.114659    0.018316    0.774000    
#> 476: 0.453875    0.999847    3.462581    0.346143    0.114675    0.018321    0.774019    
#> 477: 0.454025    0.999833    3.462634    0.346248    0.114655    0.018328    0.773912    
#> 478: 0.454070    0.999836    3.462647    0.346407    0.114603    0.018328    0.773864    
#> 479: 0.454160    0.999912    3.462639    0.346597    0.114607    0.018324    0.773813    
#> 480: 0.454251    0.999953    3.462667    0.346670    0.114668    0.018327    0.773800    
#> 481: 0.454187    0.999987    3.462666    0.346455    0.114699    0.018314    0.773823    
#> 482: 0.454245    1.000119    3.462636    0.346371    0.114703    0.018317    0.773829    
#> 483: 0.454123    1.000135    3.462630    0.346237    0.114650    0.018325    0.773768    
#> 484: 0.454004    1.000123    3.462623    0.346249    0.114619    0.018336    0.773751    
#> 485: 0.453957    1.000139    3.462597    0.346540    0.114632    0.018329    0.773748    
#> 486: 0.453859    1.000181    3.462570    0.346431    0.114620    0.018320    0.773697    
#> 487: 0.453960    1.000209    3.462567    0.346402    0.114534    0.018318    0.773651    
#> 488: 0.453880    1.000270    3.462567    0.346493    0.114527    0.018320    0.773656    
#> 489: 0.453932    1.000264    3.462586    0.346627    0.114544    0.018316    0.773723    
#> 490: 0.454005    1.000278    3.462610    0.346954    0.114548    0.018301    0.773729    
#> 491: 0.454062    1.000353    3.462694    0.347150    0.114482    0.018320    0.773723    
#> 492: 0.454139    1.000458    3.462709    0.347312    0.114447    0.018348    0.773697    
#> 493: 0.454248    1.000460    3.462771    0.347347    0.114435    0.018370    0.773680    
#> 494: 0.454501    1.000455    3.462824    0.347240    0.114431    0.018388    0.773660    
#> 495: 0.454726    1.000460    3.462883    0.347444    0.114407    0.018403    0.773598    
#> 496: 0.454960    1.000449    3.462899    0.347671    0.114371    0.018401    0.773639    
#> 497: 0.455050    1.000415    3.462932    0.347851    0.114387    0.018412    0.773635    
#> 498: 0.455200    1.000436    3.462953    0.347828    0.114403    0.018419    0.773572    
#> 499: 0.455232    1.000482    3.462934    0.347779    0.114406    0.018419    0.773519    
#> 500: 0.455205    1.000487    3.462884    0.347705    0.114444    0.018408    0.773475    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.328535    0.957196    3.434286    0.392401    0.079675    0.016800    1.686619    
#> 002: 0.433750    0.990614    3.461397    0.420870    0.075691    0.016666    1.167217    
#> 003: 0.562773    0.994311    3.443701    0.399827    0.071906    0.015833    0.923693    
#> 004: 0.530587    1.018426    3.443280    0.436252    0.068311    0.015041    0.838028    
#> 005: 0.666764    1.027903    3.450565    0.642748    0.065160    0.014289    0.790471    
#> 006: 0.612935    1.007448    3.454452    0.610610    0.061902    0.013575    0.776577    
#> 007: 0.580363    1.032384    3.443402    0.580080    0.062986    0.013014    0.788087    
#> 008: 0.568990    1.041192    3.428810    0.565943    0.062692    0.014360    0.798599    
#> 009: 0.545899    1.014918    3.434306    0.548801    0.061287    0.013642    0.802801    
#> 010: 0.571580    1.013813    3.428978    0.524986    0.058222    0.013390    0.801580    
#> 011: 0.586452    1.038017    3.430379    0.516779    0.055311    0.012886    0.801047    
#> 012: 0.585832    1.035661    3.423204    0.580372    0.053916    0.012242    0.791424    
#> 013: 0.600493    1.031935    3.425246    0.764743    0.056295    0.015905    0.778858    
#> 014: 0.615485    1.026040    3.443421    0.726506    0.053480    0.019439    0.781056    
#> 015: 0.660871    1.019830    3.458534    0.690181    0.054118    0.018467    0.753403    
#> 016: 0.593136    1.033390    3.449111    0.655672    0.052472    0.021203    0.776580    
#> 017: 0.635972    1.026127    3.461838    0.657797    0.049848    0.020143    0.773710    
#> 018: 0.675376    1.033840    3.447008    0.674905    0.053894    0.019136    0.773763    
#> 019: 0.616171    1.031020    3.454199    0.644251    0.051199    0.018179    0.774866    
#> 020: 0.674830    1.022522    3.452587    0.723608    0.048639    0.024325    0.784330    
#> 021: 0.659973    1.005018    3.467405    0.687428    0.053836    0.024788    0.761371    
#> 022: 0.658572    1.009215    3.474939    0.653057    0.053377    0.025563    0.758732    
#> 023: 0.741640    0.996739    3.500438    0.620404    0.053815    0.024284    0.796377    
#> 024: 0.734964    1.023457    3.485831    0.633405    0.051124    0.023070    0.779286    
#> 025: 0.650273    0.999419    3.470308    0.634246    0.051984    0.025098    0.790407    
#> 026: 0.656179    1.037467    3.455903    0.618259    0.049385    0.026853    0.780850    
#> 027: 0.637644    1.047309    3.447619    0.691313    0.046916    0.025511    0.805541    
#> 028: 0.656558    1.044211    3.455738    0.714528    0.050238    0.024235    0.776750    
#> 029: 0.647102    1.017450    3.456219    0.678802    0.055359    0.026695    0.798742    
#> 030: 0.702054    1.048811    3.460254    0.685326    0.067620    0.027514    0.776339    
#> 031: 0.623483    1.020081    3.468854    0.651059    0.064239    0.026138    0.779602    
#> 032: 0.605763    1.020777    3.468459    0.618506    0.063629    0.024831    0.793313    
#> 033: 0.558575    1.044037    3.450758    0.587581    0.064211    0.023590    0.803726    
#> 034: 0.611335    1.050855    3.464035    0.558202    0.063038    0.022410    0.801204    
#> 035: 0.557730    1.035312    3.449598    0.530292    0.059886    0.021290    0.778940    
#> 036: 0.567800    1.034464    3.447297    0.503777    0.057541    0.020225    0.803556    
#> 037: 0.597647    1.033023    3.456024    0.478588    0.054664    0.019214    0.829094    
#> 038: 0.614464    1.037292    3.445623    0.547849    0.058088    0.020638    0.815611    
#> 039: 0.656564    1.038204    3.461793    0.620311    0.055183    0.019606    0.809344    
#> 040: 0.607753    1.062612    3.445347    0.589295    0.052424    0.019995    0.797683    
#> 041: 0.533105    1.056356    3.431628    0.559830    0.056290    0.018995    0.787099    
#> 042: 0.601417    1.040626    3.429863    0.546643    0.061852    0.018904    0.777054    
#> 043: 0.554799    1.062930    3.419537    0.523823    0.058759    0.017959    0.775843    
#> 044: 0.538111    1.062960    3.427305    0.497632    0.055821    0.017061    0.770547    
#> 045: 0.552901    1.080346    3.427235    0.472750    0.053030    0.016208    0.801077    
#> 046: 0.570945    1.050447    3.433438    0.492552    0.055597    0.015398    0.780757    
#> 047: 0.564125    1.055395    3.432880    0.477796    0.060867    0.014628    0.787670    
#> 048: 0.579587    1.026440    3.437617    0.453906    0.061075    0.013897    0.802388    
#> 049: 0.581164    1.016760    3.445827    0.485687    0.058021    0.014392    0.798065    
#> 050: 0.642102    0.987709    3.459324    0.499585    0.057122    0.017873    0.807079    
#> 051: 0.660475    1.015285    3.460125    0.482139    0.059528    0.017825    0.807738    
#> 052: 0.660304    0.996630    3.473104    0.501888    0.056552    0.016933    0.795807    
#> 053: 0.717145    1.004509    3.464669    0.684385    0.063831    0.018076    0.775417    
#> 054: 0.630017    1.006980    3.473491    0.650166    0.065613    0.020508    0.803851    
#> 055: 0.643714    1.012682    3.456542    0.617658    0.066375    0.019483    0.781599    
#> 056: 0.670315    1.035218    3.460540    0.586775    0.067131    0.018509    0.785915    
#> 057: 0.650058    1.035791    3.453961    0.672216    0.067355    0.017583    0.773112    
#> 058: 0.640616    1.054166    3.437924    0.661687    0.063987    0.016704    0.782741    
#> 059: 0.567334    1.023418    3.435469    0.628603    0.060787    0.015869    0.794115    
#> 060: 0.591696    1.002486    3.454280    0.597172    0.058251    0.020482    0.790168    
#> 061: 0.659308    1.005725    3.460870    0.568061    0.055339    0.026009    0.793556    
#> 062: 0.638356    1.043147    3.473574    0.546732    0.056835    0.030483    0.820976    
#> 063: 0.696214    1.003013    3.471699    0.624050    0.053993    0.030136    0.819375    
#> 064: 0.689800    1.014696    3.478365    0.592847    0.055650    0.028629    0.809163    
#> 065: 0.712143    1.014003    3.459012    0.614821    0.052983    0.030956    0.793903    
#> 066: 0.656883    1.026337    3.468810    0.584080    0.050334    0.030646    0.787228    
#> 067: 0.618240    1.022222    3.464664    0.554876    0.047817    0.029114    0.784813    
#> 068: 0.605279    1.042170    3.470166    0.527132    0.045427    0.027658    0.803575    
#> 069: 0.605291    1.058577    3.449031    0.500776    0.043155    0.026275    0.796117    
#> 070: 0.599094    1.052599    3.457388    0.485993    0.046635    0.024961    0.779851    
#> 071: 0.611916    1.071797    3.434318    0.551474    0.051380    0.023713    0.782063    
#> 072: 0.600452    1.022243    3.439758    0.523900    0.052850    0.022528    0.784420    
#> 073: 0.674002    1.038250    3.462612    0.603236    0.050208    0.021401    0.780082    
#> 074: 0.638120    1.022234    3.455344    0.573074    0.047697    0.023778    0.785669    
#> 075: 0.668672    1.015074    3.479751    0.608693    0.065095    0.025212    0.788969    
#> 076: 0.677725    1.037953    3.478751    0.578258    0.061840    0.023952    0.791768    
#> 077: 0.722408    1.016938    3.481404    0.634843    0.058748    0.022754    0.785517    
#> 078: 0.735693    1.011395    3.493970    0.603101    0.055811    0.021682    0.781003    
#> 079: 0.761555    1.020897    3.486153    0.635420    0.053020    0.028802    0.802543    
#> 080: 0.712631    1.000618    3.492159    0.603649    0.050369    0.027361    0.802689    
#> 081: 0.691643    0.997103    3.478909    0.573467    0.047851    0.025993    0.780188    
#> 082: 0.669239    0.978431    3.479161    0.552280    0.045458    0.024694    0.796627    
#> 083: 0.716935    0.997955    3.486769    0.666364    0.043185    0.026508    0.798789    
#> 084: 0.704182    1.015357    3.476506    0.659062    0.045252    0.025182    0.781035    
#> 085: 0.650298    1.009033    3.483314    0.626109    0.042989    0.024387    0.799389    
#> 086: 0.718409    1.017543    3.482146    0.627619    0.042034    0.025924    0.783317    
#> 087: 0.681489    1.001685    3.462160    0.786500    0.045073    0.024628    0.770331    
#> 088: 0.620232    0.991725    3.466663    0.747175    0.045618    0.025308    0.784467    
#> 089: 0.644950    1.009689    3.451984    0.709816    0.043337    0.024930    0.780040    
#> 090: 0.651335    1.007760    3.456122    0.674325    0.045342    0.025138    0.775785    
#> 091: 0.605713    1.001573    3.453283    0.640609    0.049882    0.023882    0.768935    
#> 092: 0.628830    1.018737    3.447990    0.619044    0.058739    0.023849    0.760864    
#> 093: 0.605244    1.007584    3.447303    0.588091    0.060646    0.022656    0.772080    
#> 094: 0.630837    1.025387    3.454629    0.586613    0.057884    0.022458    0.791932    
#> 095: 0.650049    1.037897    3.463220    0.557283    0.055613    0.021336    0.794768    
#> 096: 0.615585    1.032007    3.454114    0.580162    0.052833    0.021119    0.773523    
#> 097: 0.647161    1.040554    3.454021    0.625282    0.050191    0.020063    0.770254    
#> 098: 0.620448    1.042420    3.456406    0.594018    0.052568    0.019060    0.772800    
#> 099: 0.627007    1.024909    3.443220    0.564317    0.049940    0.018107    0.789305    
#> 100: 0.593340    1.040361    3.439130    0.540148    0.049786    0.018750    0.768792    
#> 101: 0.562311    1.040858    3.425315    0.513140    0.047297    0.019048    0.771679    
#> 102: 0.574769    1.027620    3.431597    0.491618    0.044932    0.021669    0.778604    
#> 103: 0.568334    1.030411    3.434157    0.511871    0.042689    0.020586    0.781228    
#> 104: 0.575770    1.036117    3.447730    0.518929    0.056508    0.019557    0.800440    
#> 105: 0.572786    1.022909    3.449153    0.523779    0.057008    0.018579    0.804951    
#> 106: 0.626572    1.038062    3.439474    0.570241    0.061846    0.017650    0.781059    
#> 107: 0.615959    1.037699    3.452137    0.596999    0.061847    0.016767    0.794013    
#> 108: 0.593034    1.028088    3.445438    0.574714    0.063585    0.015929    0.801220    
#> 109: 0.587112    1.019427    3.459165    0.545978    0.064277    0.015133    0.792034    
#> 110: 0.592853    1.030577    3.439731    0.518679    0.067137    0.014376    0.785181    
#> 111: 0.635187    1.031419    3.452235    0.492745    0.063780    0.013657    0.759763    
#> 112: 0.626635    1.017754    3.449176    0.503168    0.068801    0.012974    0.782139    
#> 113: 0.585098    1.043679    3.448722    0.482829    0.067913    0.012326    0.777985    
#> 114: 0.589716    1.056113    3.459987    0.458688    0.076594    0.011709    0.778640    
#> 115: 0.623985    1.016266    3.458947    0.467790    0.077389    0.011124    0.799693    
#> 116: 0.629399    1.023010    3.458332    0.482051    0.073520    0.010568    0.806232    
#> 117: 0.604182    1.039376    3.458939    0.477331    0.069844    0.011493    0.786791    
#> 118: 0.624843    1.019720    3.453384    0.493040    0.066352    0.011592    0.790270    
#> 119: 0.605550    1.010687    3.451169    0.554953    0.063034    0.014055    0.797258    
#> 120: 0.596818    1.008977    3.452130    0.546566    0.059882    0.016407    0.759937    
#> 121: 0.650245    1.045376    3.455292    0.545775    0.056888    0.020767    0.774966    
#> 122: 0.631880    1.009592    3.462814    0.526940    0.054044    0.022487    0.801696    
#> 123: 0.672405    1.030964    3.454783    0.579686    0.061852    0.021363    0.795275    
#> 124: 0.632841    1.073399    3.445998    0.626012    0.058759    0.021086    0.789102    
#> 125: 0.624696    1.072784    3.442387    0.594712    0.055821    0.020032    0.779069    
#> 126: 0.579734    1.070801    3.427822    0.564976    0.054786    0.019075    0.792345    
#> 127: 0.603740    1.038551    3.432858    0.536727    0.052047    0.018121    0.803943    
#> 128: 0.607611    1.027267    3.452421    0.509891    0.052980    0.020066    0.769998    
#> 129: 0.633658    1.035848    3.457044    0.484396    0.050331    0.020284    0.794796    
#> 130: 0.663949    1.063253    3.455206    0.460176    0.047814    0.025786    0.779775    
#> 131: 0.617159    1.028787    3.450206    0.507593    0.045423    0.026090    0.799308    
#> 132: 0.564519    1.024933    3.434892    0.482214    0.044149    0.024785    0.792036    
#> 133: 0.598822    1.031566    3.449514    0.458103    0.041942    0.024774    0.813835    
#> 134: 0.629197    0.998772    3.464442    0.530308    0.043494    0.023535    0.798481    
#> 135: 0.639088    0.989373    3.477066    0.503792    0.050725    0.022358    0.796022    
#> 136: 0.632960    0.988744    3.466980    0.478603    0.050608    0.021240    0.792977    
#> 137: 0.648920    0.995219    3.467405    0.454673    0.048078    0.023577    0.797533    
#> 138: 0.637521    1.009448    3.464384    0.510209    0.052100    0.022398    0.794314    
#> 139: 0.617120    1.029260    3.472692    0.538532    0.049495    0.021278    0.815033    
#> 140: 0.615528    1.017223    3.466852    0.511605    0.047021    0.020215    0.819694    
#> 141: 0.637092    1.002430    3.478524    0.486025    0.049503    0.019204    0.800205    
#> 142: 0.673583    0.983641    3.493912    0.461724    0.051296    0.018244    0.801715    
#> 143: 0.633860    1.007189    3.481279    0.523170    0.048731    0.018154    0.806535    
#> 144: 0.690956    1.011303    3.493208    0.497012    0.047695    0.017246    0.798182    
#> 145: 0.625637    1.032826    3.455805    0.627784    0.049277    0.016384    0.787677    
#> 146: 0.616582    1.034219    3.450652    0.741018    0.050760    0.015565    0.776374    
#> 147: 0.584542    1.020061    3.437156    0.703967    0.048222    0.015701    0.780352    
#> 148: 0.573355    1.039573    3.447698    0.668769    0.058685    0.017079    0.765463    
#> 149: 0.610126    1.026352    3.449751    0.635331    0.057885    0.018216    0.778981    
#> 150: 0.664918    1.030402    3.439114    0.689825    0.071065    0.017305    0.795951    
#> 151: 0.617593    1.053040    3.445541    0.733113    0.067512    0.016440    0.780843    
#> 152: 0.645133    1.042117    3.449302    0.763443    0.051811    0.018318    0.785851    
#> 153: 0.650663    1.049903    3.450394    0.840879    0.055948    0.018810    0.802579    
#> 154: 0.671386    1.042971    3.449506    0.762316    0.046688    0.016520    0.804998    
#> 155: 0.608284    1.022911    3.437451    0.784694    0.051612    0.016115    0.806368    
#> 156: 0.585797    1.043718    3.451682    0.701016    0.061058    0.014355    0.799743    
#> 157: 0.586078    1.045629    3.449996    0.528504    0.065828    0.015925    0.799469    
#> 158: 0.653417    1.054032    3.447559    0.619148    0.060855    0.016246    0.771372    
#> 159: 0.592892    1.049859    3.452100    0.523633    0.055220    0.014721    0.787116    
#> 160: 0.613112    1.015435    3.463628    0.428631    0.057615    0.014070    0.803164    
#> 161: 0.558597    1.042197    3.448412    0.434583    0.054142    0.015562    0.807825    
#> 162: 0.591429    1.064151    3.428206    0.536522    0.053300    0.015233    0.792378    
#> 163: 0.574862    1.055374    3.432049    0.462989    0.040829    0.013797    0.795130    
#> 164: 0.587732    1.062186    3.442671    0.437904    0.043629    0.014781    0.798610    
#> 165: 0.596690    1.052577    3.443857    0.452275    0.050590    0.013919    0.785830    
#> 166: 0.624464    1.070358    3.445984    0.447509    0.054685    0.009829    0.799767    
#> 167: 0.639849    1.060573    3.459689    0.448712    0.055378    0.008405    0.817239    
#> 168: 0.625505    1.063839    3.450722    0.481256    0.053756    0.011381    0.776690    
#> 169: 0.617901    1.074689    3.445159    0.520410    0.067570    0.011942    0.809691    
#> 170: 0.658370    1.032682    3.455141    0.503630    0.070444    0.012601    0.808612    
#> 171: 0.617179    1.019929    3.466661    0.576605    0.061102    0.012213    0.785640    
#> 172: 0.631380    1.058333    3.447554    0.756012    0.059134    0.009645    0.761489    
#> 173: 0.616018    1.077979    3.431642    0.712543    0.068742    0.010833    0.772210    
#> 174: 0.648488    1.060150    3.441936    0.708713    0.067302    0.009811    0.775781    
#> 175: 0.667646    1.049270    3.434680    0.763470    0.077415    0.010503    0.784144    
#> 176: 0.581783    1.056514    3.440347    0.534092    0.079239    0.008427    0.780979    
#> 177: 0.576782    1.044451    3.446139    0.506689    0.073324    0.010461    0.787622    
#> 178: 0.612384    1.027883    3.442723    0.473853    0.061147    0.009232    0.788110    
#> 179: 0.640251    1.040651    3.451630    0.543911    0.072379    0.008824    0.794421    
#> 180: 0.603800    1.024381    3.445416    0.555723    0.064979    0.008290    0.784695    
#> 181: 0.624864    1.013800    3.438653    0.551730    0.049336    0.008898    0.780178    
#> 182: 0.625870    1.036146    3.425892    0.629110    0.052202    0.007044    0.795618    
#> 183: 0.579136    1.064101    3.420301    0.537092    0.057854    0.007114    0.796093    
#> 184: 0.540637    1.040027    3.422153    0.462227    0.067485    0.006543    0.807289    
#> 185: 0.540262    1.058925    3.418660    0.463943    0.083604    0.007039    0.813407    
#> 186: 0.552221    1.074646    3.425934    0.484773    0.073733    0.007509    0.827769    
#> 187: 0.551999    1.056178    3.439138    0.392354    0.069109    0.008750    0.804253    
#> 188: 0.515208    1.063361    3.428401    0.421905    0.073548    0.011690    0.808664    
#> 189: 0.562788    1.053736    3.447560    0.393812    0.065888    0.012495    0.796585    
#> 190: 0.568612    1.039089    3.456153    0.492176    0.057120    0.011841    0.784238    
#> 191: 0.600253    1.067658    3.449344    0.489748    0.040430    0.015137    0.802920    
#> 192: 0.548392    1.048629    3.446738    0.418376    0.050729    0.013017    0.812668    
#> 193: 0.590367    1.066131    3.447322    0.432546    0.051753    0.013283    0.775088    
#> 194: 0.546291    1.050941    3.438087    0.399041    0.054554    0.012674    0.791740    
#> 195: 0.512193    1.057525    3.425031    0.395393    0.050655    0.011056    0.805057    
#> 196: 0.546994    1.045240    3.437004    0.439615    0.059635    0.010469    0.824836    
#> 197: 0.524869    1.053383    3.453347    0.472033    0.052851    0.012640    0.812162    
#> 198: 0.607186    1.030525    3.447096    0.497216    0.053120    0.014563    0.783170    
#> 199: 0.605298    1.029648    3.446798    0.450771    0.046037    0.014887    0.793476    
#> 200: 0.534569    1.042027    3.441888    0.450918    0.063555    0.014909    0.787547    
#> 201: 0.557534    1.032600    3.446745    0.499911    0.057607    0.015704    0.786115    
#> 202: 0.564521    1.030853    3.445433    0.539484    0.053248    0.017308    0.786080    
#> 203: 0.592288    1.030084    3.443837    0.587512    0.052680    0.018180    0.786516    
#> 204: 0.592428    1.023060    3.445748    0.574328    0.050420    0.017679    0.792259    
#> 205: 0.590780    1.025810    3.444210    0.570304    0.048570    0.017931    0.793142    
#> 206: 0.589172    1.029133    3.444855    0.574424    0.048871    0.017623    0.794423    
#> 207: 0.584771    1.032517    3.442396    0.568732    0.050300    0.017229    0.794293    
#> 208: 0.584702    1.032540    3.442501    0.563162    0.050067    0.017072    0.794399    
#> 209: 0.585345    1.031832    3.442088    0.558493    0.050795    0.016956    0.793721    
#> 210: 0.586472    1.030754    3.442126    0.560770    0.050385    0.016927    0.792139    
#> 211: 0.590037    1.032148    3.442222    0.566679    0.050689    0.016674    0.790081    
#> 212: 0.591780    1.032329    3.442610    0.564770    0.050771    0.016852    0.789373    
#> 213: 0.593464    1.030065    3.443283    0.559509    0.050343    0.017016    0.790430    
#> 214: 0.597561    1.028286    3.444680    0.557288    0.050201    0.017224    0.791270    
#> 215: 0.596516    1.027895    3.445152    0.549262    0.049765    0.017324    0.792378    
#> 216: 0.596331    1.026367    3.445712    0.540140    0.049847    0.017233    0.794524    
#> 217: 0.597144    1.026033    3.446351    0.536593    0.050062    0.017126    0.793682    
#> 218: 0.597866    1.026645    3.445651    0.535223    0.050693    0.017069    0.792728    
#> 219: 0.596530    1.026368    3.444978    0.536866    0.050436    0.016918    0.793437    
#> 220: 0.595168    1.026987    3.444417    0.541741    0.050322    0.016740    0.793908    
#> 221: 0.595287    1.028209    3.444243    0.541962    0.050255    0.016733    0.793722    
#> 222: 0.594852    1.028515    3.444318    0.541973    0.050313    0.016709    0.793657    
#> 223: 0.597271    1.029044    3.444621    0.544528    0.050145    0.016805    0.792760    
#> 224: 0.599148    1.029839    3.445257    0.543736    0.049942    0.016822    0.792434    
#> 225: 0.600008    1.028285    3.445889    0.545386    0.049727    0.016792    0.792092    
#> 226: 0.600446    1.027249    3.445858    0.545454    0.049200    0.016753    0.792205    
#> 227: 0.600122    1.027016    3.445979    0.544063    0.049082    0.016619    0.792371    
#> 228: 0.599558    1.028800    3.445461    0.543173    0.049406    0.016537    0.792460    
#> 229: 0.597210    1.029258    3.445011    0.541615    0.049414    0.016474    0.792195    
#> 230: 0.597609    1.029498    3.444623    0.544108    0.049590    0.016331    0.791961    
#> 231: 0.597185    1.030411    3.444224    0.547231    0.049904    0.016197    0.791518    
#> 232: 0.596534    1.030751    3.444218    0.547788    0.050321    0.016036    0.791191    
#> 233: 0.596087    1.029987    3.444474    0.548127    0.050865    0.016006    0.791070    
#> 234: 0.596421    1.030318    3.444723    0.549541    0.051077    0.016112    0.791303    
#> 235: 0.596584    1.030141    3.444498    0.548585    0.051135    0.016054    0.792187    
#> 236: 0.596472    1.030621    3.444111    0.551336    0.051311    0.016087    0.792690    
#> 237: 0.597600    1.031340    3.443867    0.554025    0.051545    0.016184    0.792988    
#> 238: 0.597958    1.032113    3.443701    0.556094    0.051846    0.016166    0.793444    
#> 239: 0.598417    1.032958    3.443689    0.560121    0.052173    0.016172    0.793009    
#> 240: 0.599361    1.032687    3.443849    0.566981    0.052429    0.016124    0.792635    
#> 241: 0.600924    1.031957    3.444023    0.571981    0.052799    0.016097    0.792204    
#> 242: 0.601973    1.031537    3.443921    0.574346    0.053438    0.016055    0.792526    
#> 243: 0.601607    1.031783    3.443912    0.573878    0.054000    0.015965    0.792867    
#> 244: 0.600827    1.031777    3.444066    0.571757    0.054189    0.015883    0.793098    
#> 245: 0.601947    1.031432    3.444368    0.573268    0.054484    0.015841    0.793652    
#> 246: 0.602518    1.031131    3.444878    0.571145    0.054457    0.015829    0.793933    
#> 247: 0.603481    1.030824    3.445291    0.572271    0.054800    0.015806    0.793614    
#> 248: 0.604101    1.031188    3.445402    0.572683    0.055105    0.015762    0.793420    
#> 249: 0.603750    1.031569    3.445208    0.573877    0.055368    0.015738    0.793333    
#> 250: 0.604116    1.031978    3.445325    0.574441    0.055717    0.015692    0.793114    
#> 251: 0.604407    1.032546    3.445623    0.573396    0.056328    0.015658    0.793035    
#> 252: 0.604906    1.032609    3.445956    0.572316    0.056666    0.015672    0.793036    
#> 253: 0.604262    1.032863    3.446113    0.570684    0.056781    0.015709    0.793124    
#> 254: 0.604398    1.033363    3.446326    0.568948    0.056936    0.015706    0.792900    
#> 255: 0.604151    1.033778    3.446623    0.567122    0.057117    0.015720    0.792950    
#> 256: 0.604610    1.033820    3.446745    0.565798    0.057271    0.015762    0.792736    
#> 257: 0.604459    1.033503    3.446867    0.565174    0.057103    0.015791    0.792807    
#> 258: 0.604307    1.032888    3.447048    0.564175    0.057020    0.015767    0.792763    
#> 259: 0.604056    1.032808    3.447037    0.562012    0.056883    0.015732    0.793040    
#> 260: 0.603745    1.032999    3.447292    0.559525    0.056868    0.015686    0.793157    
#> 261: 0.603971    1.033054    3.447494    0.559730    0.057051    0.015677    0.792942    
#> 262: 0.605181    1.033147    3.447754    0.561327    0.057201    0.015664    0.792897    
#> 263: 0.605635    1.033250    3.447984    0.560901    0.057368    0.015679    0.792589    
#> 264: 0.605590    1.032934    3.448189    0.560592    0.057469    0.015644    0.792508    
#> 265: 0.605707    1.032983    3.448276    0.560434    0.057706    0.015629    0.792540    
#> 266: 0.606240    1.033028    3.448348    0.562006    0.057752    0.015648    0.792597    
#> 267: 0.605991    1.033189    3.448580    0.561987    0.057921    0.015671    0.792891    
#> 268: 0.606735    1.033071    3.448543    0.562554    0.058006    0.015647    0.793312    
#> 269: 0.607615    1.032679    3.448456    0.563839    0.058076    0.015674    0.793135    
#> 270: 0.608165    1.032591    3.448412    0.563618    0.058059    0.015711    0.792627    
#> 271: 0.608237    1.032832    3.448302    0.563015    0.057988    0.015714    0.792523    
#> 272: 0.608399    1.032985    3.448272    0.561916    0.057835    0.015698    0.793088    
#> 273: 0.607892    1.033379    3.448194    0.561587    0.057868    0.015674    0.793360    
#> 274: 0.607677    1.033736    3.448271    0.560936    0.057947    0.015651    0.793364    
#> 275: 0.607471    1.033776    3.448188    0.560488    0.057951    0.015634    0.793083    
#> 276: 0.607143    1.033725    3.448429    0.559854    0.058044    0.015687    0.793014    
#> 277: 0.607143    1.033546    3.448746    0.559856    0.058051    0.015722    0.793007    
#> 278: 0.607814    1.033318    3.449098    0.560579    0.057997    0.015742    0.792838    
#> 279: 0.608696    1.032957    3.449392    0.561932    0.057994    0.015778    0.792820    
#> 280: 0.608955    1.032827    3.449608    0.561434    0.057955    0.015859    0.792511    
#> 281: 0.609223    1.032780    3.449874    0.561263    0.057874    0.015910    0.792304    
#> 282: 0.609573    1.032717    3.450128    0.561201    0.057798    0.015939    0.792312    
#> 283: 0.609708    1.032771    3.450292    0.560425    0.057661    0.015924    0.792958    
#> 284: 0.609603    1.032593    3.450395    0.558550    0.057649    0.015934    0.792965    
#> 285: 0.609470    1.032592    3.450236    0.557662    0.057624    0.015924    0.793306    
#> 286: 0.609431    1.032591    3.450016    0.557567    0.057568    0.015912    0.793423    
#> 287: 0.609288    1.032648    3.449874    0.557808    0.057557    0.015876    0.793573    
#> 288: 0.609539    1.032466    3.449827    0.559055    0.057582    0.015843    0.793607    
#> 289: 0.610102    1.032233    3.449821    0.561340    0.057575    0.015843    0.793476    
#> 290: 0.610706    1.032192    3.449979    0.562030    0.057615    0.015855    0.793545    
#> 291: 0.611058    1.032228    3.450086    0.562180    0.057705    0.015886    0.793488    
#> 292: 0.610757    1.032389    3.450045    0.561366    0.057722    0.015903    0.793410    
#> 293: 0.610635    1.032540    3.449955    0.561193    0.057684    0.015907    0.793390    
#> 294: 0.610386    1.032690    3.449930    0.560070    0.057636    0.015903    0.793447    
#> 295: 0.610509    1.032410    3.449976    0.560657    0.057545    0.015888    0.793199    
#> 296: 0.610761    1.032280    3.450054    0.560524    0.057480    0.015912    0.793144    
#> 297: 0.611234    1.032344    3.450109    0.560842    0.057346    0.015946    0.793163    
#> 298: 0.611223    1.032202    3.450163    0.560321    0.057267    0.015959    0.793081    
#> 299: 0.611350    1.032231    3.450231    0.560082    0.057290    0.015977    0.793007    
#> 300: 0.611385    1.032125    3.450326    0.558776    0.057275    0.016002    0.792741    
#> 301: 0.611395    1.032000    3.450280    0.558842    0.057263    0.016022    0.792475    
#> 302: 0.611304    1.032189    3.450202    0.559216    0.057341    0.015992    0.792300    
#> 303: 0.610792    1.032403    3.450042    0.559007    0.057343    0.015974    0.792092    
#> 304: 0.610494    1.032763    3.449878    0.558508    0.057358    0.015983    0.791987    
#> 305: 0.609995    1.032790    3.449739    0.557351    0.057292    0.015990    0.791930    
#> 306: 0.608978    1.032854    3.449526    0.556266    0.057222    0.015974    0.791936    
#> 307: 0.608398    1.032765    3.449394    0.555977    0.057074    0.015966    0.792246    
#> 308: 0.607569    1.032598    3.449261    0.555210    0.057009    0.016003    0.792293    
#> 309: 0.607349    1.032433    3.449195    0.555196    0.056984    0.016051    0.792323    
#> 310: 0.607662    1.032353    3.449040    0.555696    0.057092    0.016067    0.792379    
#> 311: 0.607197    1.032393    3.448950    0.555409    0.057177    0.016055    0.792342    
#> 312: 0.606803    1.032349    3.448869    0.555047    0.057199    0.016056    0.792369    
#> 313: 0.606878    1.032139    3.448900    0.554612    0.057160    0.016069    0.792413    
#> 314: 0.607172    1.031946    3.448975    0.554748    0.057185    0.016098    0.792346    
#> 315: 0.607556    1.031923    3.449095    0.555000    0.057229    0.016120    0.792164    
#> 316: 0.607801    1.031812    3.449183    0.554462    0.057177    0.016107    0.792215    
#> 317: 0.608101    1.031707    3.449323    0.554344    0.057133    0.016106    0.792276    
#> 318: 0.608397    1.031705    3.449403    0.554194    0.057058    0.016104    0.792198    
#> 319: 0.608530    1.031783    3.449457    0.554719    0.056978    0.016124    0.792368    
#> 320: 0.607749    1.032002    3.449273    0.554080    0.057018    0.016120    0.792596    
#> 321: 0.607064    1.032350    3.448970    0.553854    0.057015    0.016102    0.792807    
#> 322: 0.606708    1.032501    3.448777    0.552825    0.057040    0.016107    0.792938    
#> 323: 0.605610    1.032651    3.448599    0.552208    0.056979    0.016098    0.793166    
#> 324: 0.604958    1.032953    3.448427    0.551438    0.057033    0.016076    0.792940    
#> 325: 0.604408    1.033322    3.448210    0.551533    0.057000    0.016036    0.792908    
#> 326: 0.604290    1.033375    3.448074    0.552129    0.057026    0.016016    0.792751    
#> 327: 0.604532    1.033602    3.448030    0.552772    0.057154    0.016012    0.792588    
#> 328: 0.604665    1.033767    3.448026    0.552653    0.057124    0.016005    0.792531    
#> 329: 0.604795    1.033928    3.448096    0.552544    0.057095    0.016026    0.792328    
#> 330: 0.604847    1.034015    3.448079    0.552649    0.057069    0.016030    0.792239    
#> 331: 0.605270    1.034240    3.448108    0.552696    0.057088    0.016024    0.792191    
#> 332: 0.605643    1.034129    3.448270    0.552143    0.057122    0.016006    0.792397    
#> 333: 0.605541    1.034103    3.448219    0.551882    0.057151    0.015996    0.792580    
#> 334: 0.605086    1.033998    3.448099    0.551641    0.057201    0.015985    0.792661    
#> 335: 0.604850    1.034065    3.447924    0.551654    0.057273    0.015979    0.792647    
#> 336: 0.604678    1.034195    3.447892    0.551648    0.057395    0.015985    0.792573    
#> 337: 0.604716    1.034494    3.447746    0.551894    0.057442    0.015994    0.792557    
#> 338: 0.604891    1.034681    3.447807    0.552022    0.057458    0.016018    0.792418    
#> 339: 0.604643    1.034902    3.447799    0.551693    0.057440    0.016063    0.792329    
#> 340: 0.604560    1.034877    3.447852    0.551193    0.057472    0.016123    0.792364    
#> 341: 0.604679    1.034861    3.447853    0.550926    0.057443    0.016153    0.792379    
#> 342: 0.604528    1.034876    3.447901    0.550700    0.057442    0.016160    0.792284    
#> 343: 0.604202    1.034980    3.447883    0.550264    0.057447    0.016148    0.792167    
#> 344: 0.604120    1.034966    3.447909    0.550187    0.057503    0.016147    0.792090    
#> 345: 0.603939    1.034974    3.447906    0.549832    0.057452    0.016142    0.792087    
#> 346: 0.603687    1.035062    3.447882    0.549024    0.057395    0.016162    0.791989    
#> 347: 0.603760    1.034959    3.447841    0.549459    0.057355    0.016197    0.792030    
#> 348: 0.603509    1.035009    3.447797    0.549805    0.057336    0.016232    0.792011    
#> 349: 0.603535    1.034833    3.447783    0.550609    0.057251    0.016262    0.791990    
#> 350: 0.603590    1.034739    3.447722    0.551217    0.057160    0.016280    0.791913    
#> 351: 0.603840    1.034882    3.447648    0.552216    0.057072    0.016286    0.791935    
#> 352: 0.603603    1.035060    3.447674    0.551960    0.057024    0.016347    0.792018    
#> 353: 0.603949    1.035255    3.447721    0.551870    0.056909    0.016354    0.792065    
#> 354: 0.604117    1.035350    3.447640    0.552313    0.056793    0.016376    0.792110    
#> 355: 0.604473    1.035254    3.447659    0.552185    0.056720    0.016395    0.792128    
#> 356: 0.604921    1.035123    3.447809    0.552110    0.056696    0.016392    0.792211    
#> 357: 0.605406    1.035063    3.447914    0.552450    0.056667    0.016370    0.792204    
#> 358: 0.605661    1.035166    3.447995    0.553002    0.056812    0.016350    0.792102    
#> 359: 0.605648    1.035368    3.447971    0.553313    0.056871    0.016350    0.791924    
#> 360: 0.605309    1.035438    3.447790    0.552842    0.056870    0.016355    0.791769    
#> 361: 0.604790    1.035479    3.447671    0.552156    0.056832    0.016337    0.791750    
#> 362: 0.604588    1.035434    3.447575    0.551620    0.056766    0.016334    0.791694    
#> 363: 0.604734    1.035406    3.447607    0.551475    0.056741    0.016333    0.791507    
#> 364: 0.605228    1.035336    3.447670    0.551859    0.056764    0.016336    0.791449    
#> 365: 0.605278    1.035202    3.447724    0.552034    0.056897    0.016332    0.791455    
#> 366: 0.605218    1.035207    3.447644    0.552085    0.056947    0.016309    0.791497    
#> 367: 0.605387    1.035090    3.447677    0.551808    0.057067    0.016281    0.791401    
#> 368: 0.605807    1.035152    3.447727    0.551622    0.057032    0.016268    0.791360    
#> 369: 0.605686    1.035151    3.447749    0.551893    0.057020    0.016254    0.791329    
#> 370: 0.605666    1.035317    3.447720    0.552266    0.057030    0.016256    0.791310    
#> 371: 0.605422    1.035344    3.447609    0.552352    0.057007    0.016241    0.791114    
#> 372: 0.605048    1.035520    3.447476    0.552677    0.057064    0.016217    0.791118    
#> 373: 0.604535    1.035718    3.447286    0.552152    0.057075    0.016203    0.791116    
#> 374: 0.604334    1.035839    3.447186    0.551927    0.057070    0.016197    0.791120    
#> 375: 0.603864    1.035931    3.447103    0.550946    0.057099    0.016178    0.791260    
#> 376: 0.603954    1.036100    3.447054    0.550946    0.057150    0.016174    0.791256    
#> 377: 0.603704    1.036243    3.446988    0.550646    0.057165    0.016170    0.791254    
#> 378: 0.603173    1.036295    3.446916    0.549912    0.057144    0.016157    0.791401    
#> 379: 0.602852    1.036190    3.446909    0.548964    0.057162    0.016143    0.791461    
#> 380: 0.602804    1.036202    3.446911    0.548429    0.057174    0.016148    0.791363    
#> 381: 0.602520    1.036276    3.446847    0.548166    0.057238    0.016131    0.791275    
#> 382: 0.602420    1.036330    3.446844    0.547495    0.057166    0.016133    0.791226    
#> 383: 0.602642    1.036307    3.446879    0.547512    0.057148    0.016121    0.791172    
#> 384: 0.602658    1.036186    3.446940    0.547613    0.057082    0.016133    0.791115    
#> 385: 0.602817    1.036148    3.446975    0.547201    0.057020    0.016133    0.791114    
#> 386: 0.603008    1.036216    3.447046    0.546840    0.056984    0.016116    0.791189    
#> 387: 0.603170    1.036253    3.447164    0.546366    0.056928    0.016136    0.791208    
#> 388: 0.603454    1.036175    3.447265    0.546932    0.056901    0.016148    0.791154    
#> 389: 0.603524    1.035976    3.447282    0.546902    0.056918    0.016145    0.791170    
#> 390: 0.603363    1.035988    3.447255    0.546859    0.056917    0.016150    0.791094    
#> 391: 0.603373    1.035961    3.447202    0.547031    0.056871    0.016151    0.790910    
#> 392: 0.603282    1.035950    3.447172    0.547140    0.056863    0.016149    0.790858    
#> 393: 0.603113    1.035929    3.447119    0.546990    0.056871    0.016154    0.790826    
#> 394: 0.603013    1.035996    3.447086    0.546768    0.056831    0.016149    0.790804    
#> 395: 0.603168    1.036143    3.447058    0.547095    0.056756    0.016158    0.790784    
#> 396: 0.603338    1.036330    3.447055    0.547330    0.056730    0.016173    0.790759    
#> 397: 0.603455    1.036345    3.447038    0.548314    0.056693    0.016184    0.790733    
#> 398: 0.603740    1.036290    3.447039    0.548819    0.056652    0.016183    0.790786    
#> 399: 0.603817    1.036264    3.447053    0.548907    0.056614    0.016181    0.790832    
#> 400: 0.604185    1.036357    3.447114    0.549239    0.056645    0.016185    0.790819    
#> 401: 0.604124    1.036426    3.447086    0.548753    0.056686    0.016172    0.790888    
#> 402: 0.603991    1.036434    3.447074    0.548581    0.056652    0.016166    0.790864    
#> 403: 0.604251    1.036420    3.447054    0.548948    0.056706    0.016146    0.790801    
#> 404: 0.604327    1.036402    3.447043    0.548930    0.056693    0.016148    0.790674    
#> 405: 0.604187    1.036438    3.447062    0.548369    0.056691    0.016154    0.790707    
#> 406: 0.604249    1.036466    3.447080    0.548324    0.056655    0.016168    0.790823    
#> 407: 0.604347    1.036545    3.447118    0.548380    0.056644    0.016182    0.790733    
#> 408: 0.604550    1.036706    3.447164    0.548313    0.056656    0.016178    0.790783    
#> 409: 0.604665    1.036748    3.447128    0.548399    0.056604    0.016183    0.790743    
#> 410: 0.604704    1.036727    3.447088    0.548717    0.056543    0.016190    0.790703    
#> 411: 0.604871    1.036582    3.447066    0.549464    0.056562    0.016175    0.790729    
#> 412: 0.605054    1.036508    3.447059    0.550339    0.056558    0.016154    0.790739    
#> 413: 0.605304    1.036500    3.447003    0.551546    0.056586    0.016138    0.790681    
#> 414: 0.605239    1.036396    3.447022    0.551738    0.056553    0.016152    0.790563    
#> 415: 0.605234    1.036360    3.447042    0.551812    0.056447    0.016163    0.790473    
#> 416: 0.605253    1.036366    3.447049    0.551666    0.056417    0.016158    0.790406    
#> 417: 0.605157    1.036334    3.447075    0.551153    0.056394    0.016151    0.790364    
#> 418: 0.605035    1.036339    3.447090    0.550773    0.056448    0.016141    0.790313    
#> 419: 0.604862    1.036435    3.447032    0.550263    0.056462    0.016135    0.790401    
#> 420: 0.604917    1.036514    3.447028    0.550404    0.056514    0.016131    0.790342    
#> 421: 0.604720    1.036500    3.447063    0.550226    0.056548    0.016130    0.790248    
#> 422: 0.604895    1.036413    3.447072    0.550623    0.056520    0.016125    0.790232    
#> 423: 0.605003    1.036264    3.447105    0.550566    0.056471    0.016133    0.790266    
#> 424: 0.604820    1.036195    3.447068    0.550168    0.056427    0.016132    0.790312    
#> 425: 0.604940    1.036176    3.447065    0.550057    0.056386    0.016140    0.790310    
#> 426: 0.604798    1.036170    3.447076    0.549875    0.056366    0.016130    0.790339    
#> 427: 0.604695    1.036116    3.447107    0.549712    0.056330    0.016155    0.790315    
#> 428: 0.604471    1.036160    3.447054    0.549914    0.056281    0.016162    0.790291    
#> 429: 0.604584    1.036128    3.447094    0.549788    0.056301    0.016143    0.790329    
#> 430: 0.604670    1.036123    3.447130    0.549689    0.056326    0.016144    0.790278    
#> 431: 0.604634    1.036113    3.447084    0.549722    0.056319    0.016123    0.790212    
#> 432: 0.604415    1.036163    3.447045    0.549931    0.056338    0.016111    0.790201    
#> 433: 0.604274    1.036293    3.446999    0.550133    0.056297    0.016119    0.790257    
#> 434: 0.604106    1.036198    3.446994    0.549979    0.056204    0.016120    0.790273    
#> 435: 0.604042    1.036168    3.447003    0.549641    0.056126    0.016129    0.790223    
#> 436: 0.604001    1.036113    3.447010    0.549408    0.056118    0.016118    0.790221    
#> 437: 0.603976    1.036060    3.446995    0.549159    0.056115    0.016119    0.790245    
#> 438: 0.603882    1.036169    3.446979    0.549201    0.056144    0.016112    0.790215    
#> 439: 0.604010    1.036291    3.446967    0.549590    0.056141    0.016105    0.790125    
#> 440: 0.603961    1.036387    3.446974    0.549500    0.056152    0.016089    0.790127    
#> 441: 0.604072    1.036393    3.447022    0.549233    0.056178    0.016085    0.790101    
#> 442: 0.603940    1.036456    3.447022    0.548971    0.056172    0.016082    0.790023    
#> 443: 0.603874    1.036534    3.446933    0.549009    0.056227    0.016061    0.789969    
#> 444: 0.603765    1.036599    3.446859    0.548748    0.056316    0.016044    0.789916    
#> 445: 0.603644    1.036674    3.446807    0.548707    0.056350    0.016044    0.789806    
#> 446: 0.603356    1.036734    3.446734    0.548589    0.056388    0.016043    0.789730    
#> 447: 0.603417    1.036762    3.446725    0.548563    0.056412    0.016045    0.789649    
#> 448: 0.603340    1.036819    3.446723    0.548587    0.056444    0.016052    0.789602    
#> 449: 0.603302    1.036933    3.446776    0.548139    0.056476    0.016053    0.789681    
#> 450: 0.603309    1.037001    3.446751    0.548356    0.056499    0.016050    0.789631    
#> 451: 0.603300    1.037094    3.446673    0.548666    0.056500    0.016052    0.789599    
#> 452: 0.603208    1.037169    3.446575    0.549265    0.056473    0.016050    0.789541    
#> 453: 0.603128    1.037306    3.446482    0.549505    0.056499    0.016059    0.789439    
#> 454: 0.602857    1.037526    3.446378    0.549466    0.056536    0.016046    0.789349    
#> 455: 0.602818    1.037660    3.446290    0.549671    0.056552    0.016027    0.789301    
#> 456: 0.602636    1.037702    3.446199    0.549575    0.056544    0.016018    0.789370    
#> 457: 0.602356    1.037725    3.446159    0.549440    0.056516    0.016011    0.789390    
#> 458: 0.602249    1.037904    3.446187    0.549113    0.056516    0.016007    0.789396    
#> 459: 0.602190    1.038097    3.446157    0.549034    0.056552    0.016002    0.789369    
#> 460: 0.602182    1.038173    3.446165    0.549123    0.056550    0.016001    0.789331    
#> 461: 0.602207    1.038205    3.446200    0.549390    0.056581    0.015999    0.789284    
#> 462: 0.602130    1.038284    3.446218    0.549402    0.056578    0.015991    0.789291    
#> 463: 0.602114    1.038358    3.446182    0.549520    0.056535    0.015975    0.789384    
#> 464: 0.601966    1.038468    3.446103    0.549367    0.056532    0.015973    0.789370    
#> 465: 0.601903    1.038427    3.446062    0.549355    0.056551    0.015964    0.789331    
#> 466: 0.601995    1.038444    3.446064    0.549210    0.056582    0.015952    0.789305    
#> 467: 0.601853    1.038411    3.446090    0.548877    0.056593    0.015942    0.789236    
#> 468: 0.601884    1.038370    3.446139    0.548528    0.056592    0.015935    0.789224    
#> 469: 0.601947    1.038475    3.446188    0.548225    0.056570    0.015944    0.789252    
#> 470: 0.601958    1.038512    3.446222    0.548053    0.056574    0.015946    0.789231    
#> 471: 0.601833    1.038477    3.446202    0.547740    0.056546    0.015952    0.789263    
#> 472: 0.601637    1.038505    3.446182    0.547298    0.056539    0.015968    0.789327    
#> 473: 0.601519    1.038533    3.446156    0.547186    0.056513    0.015961    0.789326    
#> 474: 0.601621    1.038495    3.446126    0.547439    0.056496    0.015952    0.789380    
#> 475: 0.601864    1.038526    3.446127    0.547673    0.056506    0.015937    0.789390    
#> 476: 0.601874    1.038549    3.446091    0.547864    0.056550    0.015915    0.789488    
#> 477: 0.601658    1.038563    3.446082    0.547482    0.056595    0.015900    0.789467    
#> 478: 0.601491    1.038542    3.446074    0.547522    0.056621    0.015890    0.789468    
#> 479: 0.601698    1.038605    3.446089    0.547959    0.056659    0.015883    0.789448    
#> 480: 0.601925    1.038599    3.446128    0.548261    0.056687    0.015885    0.789510    
#> 481: 0.602011    1.038621    3.446119    0.548412    0.056695    0.015886    0.789532    
#> 482: 0.602133    1.038625    3.446045    0.548379    0.056717    0.015885    0.789639    
#> 483: 0.601939    1.038653    3.445986    0.548518    0.056764    0.015889    0.789626    
#> 484: 0.601864    1.038589    3.445971    0.548516    0.056782    0.015892    0.789655    
#> 485: 0.601866    1.038608    3.445943    0.548797    0.056777    0.015888    0.789678    
#> 486: 0.601926    1.038609    3.445971    0.548683    0.056752    0.015888    0.789627    
#> 487: 0.602195    1.038657    3.446026    0.548745    0.056765    0.015881    0.789609    
#> 488: 0.602492    1.038580    3.446062    0.549074    0.056770    0.015870    0.789595    
#> 489: 0.602677    1.038527    3.446084    0.549007    0.056784    0.015861    0.789619    
#> 490: 0.602833    1.038540    3.446116    0.548853    0.056821    0.015858    0.789578    
#> 491: 0.602944    1.038648    3.446150    0.548850    0.056872    0.015842    0.789527    
#> 492: 0.603014    1.038703    3.446171    0.548896    0.056879    0.015834    0.789566    
#> 493: 0.602942    1.038697    3.446214    0.548737    0.056905    0.015828    0.789633    
#> 494: 0.603058    1.038728    3.446212    0.548901    0.056924    0.015820    0.789619    
#> 495: 0.603266    1.038748    3.446239    0.549542    0.056908    0.015815    0.789630    
#> 496: 0.603357    1.038806    3.446182    0.549915    0.056891    0.015800    0.789651    
#> 497: 0.603226    1.038786    3.446131    0.549645    0.056894    0.015787    0.789720    
#> 498: 0.603045    1.038792    3.446059    0.549628    0.056919    0.015778    0.789674    
#> 499: 0.602827    1.038886    3.445960    0.549526    0.056956    0.015776    0.789636    
#> 500: 0.602804    1.038895    3.445880    0.549697    0.056949    0.015767    0.789618    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.285556    0.967911    3.437737    0.392401    0.077930    0.016800    1.781305    
#> 002: 0.349733    1.012507    3.437160    0.372781    0.074034    0.016466    1.115495    
#> 003: 0.439674    0.948256    3.436876    0.354142    0.086666    0.015643    0.820142    
#> 004: 0.432527    0.949046    3.449131    0.336435    0.087729    0.014861    0.677496    
#> 005: 0.487521    0.939287    3.443631    0.319613    0.088713    0.014118    0.644421    
#> 006: 0.448509    0.946063    3.428060    0.366900    0.084835    0.013412    0.619645    
#> 007: 0.425099    0.960299    3.428953    0.348555    0.081996    0.012741    0.630566    
#> 008: 0.442714    0.949538    3.431716    0.386119    0.080228    0.012104    0.624932    
#> 009: 0.432139    0.930452    3.426024    0.367418    0.076216    0.011499    0.624359    
#> 010: 0.451037    0.920675    3.426165    0.488925    0.073857    0.012030    0.629227    
#> 011: 0.487434    0.923500    3.430252    0.518769    0.073740    0.014967    0.613466    
#> 012: 0.444074    0.928074    3.427262    0.492830    0.080133    0.015248    0.605701    
#> 013: 0.447879    0.951266    3.427896    0.468189    0.086897    0.014486    0.611214    
#> 014: 0.482054    0.919954    3.436919    0.470869    0.082552    0.013761    0.633487    
#> 015: 0.498936    0.931610    3.445988    0.453445    0.078425    0.014930    0.615095    
#> 016: 0.467971    0.940132    3.430625    0.456393    0.074503    0.014184    0.617672    
#> 017: 0.441945    0.941119    3.431702    0.480324    0.070778    0.016245    0.593075    
#> 018: 0.474281    0.949779    3.425655    0.501765    0.067239    0.015745    0.591606    
#> 019: 0.434359    0.948752    3.422292    0.476676    0.071058    0.015009    0.584017    
#> 020: 0.458389    0.951449    3.432176    0.470557    0.078209    0.017085    0.597495    
#> 021: 0.457583    0.934305    3.435603    0.447029    0.086058    0.017042    0.577967    
#> 022: 0.478213    0.936656    3.448931    0.476040    0.089511    0.017069    0.575611    
#> 023: 0.531758    0.933439    3.452307    0.570701    0.085036    0.018718    0.579822    
#> 024: 0.507047    0.937944    3.447350    0.542165    0.080784    0.018910    0.568495    
#> 025: 0.488502    0.933794    3.436792    0.515057    0.093510    0.017964    0.581041    
#> 026: 0.482620    0.939828    3.430742    0.489304    0.088835    0.017066    0.574953    
#> 027: 0.471056    0.958488    3.431029    0.465770    0.084393    0.017277    0.589439    
#> 028: 0.490069    0.950972    3.426795    0.490898    0.080173    0.016414    0.590748    
#> 029: 0.495954    0.935844    3.436283    0.492949    0.076165    0.015593    0.592648    
#> 030: 0.497434    0.945613    3.433270    0.518156    0.072385    0.015442    0.585545    
#> 031: 0.458481    0.931241    3.435414    0.492248    0.077119    0.014669    0.584880    
#> 032: 0.449167    0.920203    3.431452    0.484107    0.073263    0.014300    0.579059    
#> 033: 0.442431    0.934123    3.440074    0.459901    0.069967    0.014034    0.593743    
#> 034: 0.492974    0.954878    3.444156    0.452615    0.076264    0.014906    0.596349    
#> 035: 0.469163    0.924846    3.437175    0.468997    0.072664    0.014161    0.587236    
#> 036: 0.446748    0.945197    3.435806    0.445547    0.069031    0.013452    0.610019    
#> 037: 0.478737    0.950174    3.431316    0.460835    0.085708    0.012878    0.619113    
#> 038: 0.487414    0.943378    3.431326    0.467828    0.083368    0.012234    0.612340    
#> 039: 0.468682    0.936406    3.442544    0.525765    0.079199    0.013978    0.589580    
#> 040: 0.489983    0.954557    3.438100    0.549029    0.079482    0.015762    0.607880    
#> 041: 0.441966    0.956084    3.429050    0.521577    0.076908    0.014974    0.607937    
#> 042: 0.459778    0.958082    3.429779    0.495498    0.083097    0.014225    0.592950    
#> 043: 0.454235    0.961488    3.419622    0.477924    0.081599    0.013514    0.589155    
#> 044: 0.425210    0.961094    3.424619    0.454028    0.077519    0.012838    0.604677    
#> 045: 0.442450    0.968280    3.417146    0.469212    0.073643    0.012196    0.601201    
#> 046: 0.480530    0.938735    3.422748    0.529216    0.092686    0.011586    0.595769    
#> 047: 0.455085    0.956663    3.417790    0.502755    0.088051    0.011007    0.615638    
#> 048: 0.451656    0.948098    3.423850    0.477617    0.083649    0.010457    0.607294    
#> 049: 0.467329    0.954325    3.437797    0.453736    0.079466    0.013092    0.603295    
#> 050: 0.485275    0.925854    3.439742    0.456420    0.078940    0.014794    0.626218    
#> 051: 0.503596    0.933112    3.444696    0.484030    0.084229    0.017363    0.595546    
#> 052: 0.525869    0.924954    3.456946    0.491964    0.080018    0.016495    0.598974    
#> 053: 0.503757    0.920565    3.449647    0.474940    0.076017    0.015670    0.593684    
#> 054: 0.503014    0.917890    3.450460    0.451193    0.074497    0.016860    0.600799    
#> 055: 0.519502    0.924811    3.455384    0.451289    0.079509    0.018121    0.596127    
#> 056: 0.506560    0.910586    3.447071    0.444448    0.075534    0.018819    0.631726    
#> 057: 0.482440    0.935290    3.454291    0.422226    0.079265    0.017878    0.642734    
#> 058: 0.547419    0.916214    3.455443    0.434890    0.075302    0.017802    0.624975    
#> 059: 0.489093    0.895958    3.449894    0.443025    0.085751    0.018316    0.610411    
#> 060: 0.493360    0.917183    3.442472    0.492465    0.081464    0.020668    0.598740    
#> 061: 0.515991    0.950205    3.449314    0.541345    0.082129    0.022183    0.613996    
#> 062: 0.499357    0.936168    3.453766    0.514278    0.092954    0.021074    0.620497    
#> 063: 0.527605    0.908155    3.454177    0.488564    0.088306    0.020020    0.620192    
#> 064: 0.519391    0.915981    3.458705    0.466011    0.084082    0.019019    0.601941    
#> 065: 0.518709    0.920505    3.441307    0.489335    0.094049    0.018068    0.606205    
#> 066: 0.538088    0.925212    3.460602    0.464869    0.089347    0.017165    0.605102    
#> 067: 0.526431    0.912384    3.455320    0.483762    0.084879    0.018720    0.593820    
#> 068: 0.492368    0.917643    3.456115    0.494994    0.080635    0.018907    0.615942    
#> 069: 0.492759    0.926085    3.445153    0.509714    0.087857    0.018993    0.610846    
#> 070: 0.496279    0.927874    3.446570    0.515248    0.084856    0.018044    0.589297    
#> 071: 0.491354    0.937159    3.435145    0.489486    0.080613    0.017454    0.590993    
#> 072: 0.492465    0.922818    3.439311    0.465011    0.088118    0.016582    0.596569    
#> 073: 0.489105    0.927272    3.454427    0.441761    0.093139    0.015753    0.603088    
#> 074: 0.510641    0.899114    3.454383    0.444371    0.088482    0.014965    0.597015    
#> 075: 0.514409    0.901624    3.464550    0.448059    0.091771    0.014217    0.599704    
#> 076: 0.549422    0.922078    3.469199    0.479329    0.087182    0.015490    0.615595    
#> 077: 0.542309    0.886098    3.466847    0.455363    0.082823    0.015757    0.607512    
#> 078: 0.487171    0.917728    3.464216    0.432594    0.078682    0.015547    0.587368    
#> 079: 0.500713    0.944517    3.449946    0.429113    0.083701    0.015663    0.594511    
#> 080: 0.507074    0.931239    3.446121    0.506710    0.079516    0.014880    0.594949    
#> 081: 0.495426    0.943973    3.432904    0.481375    0.075540    0.016353    0.597838    
#> 082: 0.496766    0.933440    3.434649    0.492207    0.071919    0.015535    0.609998    
#> 083: 0.474428    0.960401    3.437586    0.467597    0.075444    0.014814    0.594521    
#> 084: 0.469655    0.946137    3.433595    0.447725    0.071672    0.014557    0.623508    
#> 085: 0.494725    0.952432    3.446909    0.477655    0.069627    0.016843    0.618059    
#> 086: 0.531050    0.945516    3.450843    0.453773    0.068670    0.016001    0.603804    
#> 087: 0.506777    0.931537    3.447885    0.431084    0.070570    0.015201    0.593324    
#> 088: 0.455337    0.916258    3.449903    0.482668    0.074001    0.014804    0.596231    
#> 089: 0.466107    0.952250    3.426640    0.511257    0.070301    0.014064    0.595776    
#> 090: 0.457169    0.939977    3.426619    0.508895    0.070317    0.016852    0.593012    
#> 091: 0.461973    0.926436    3.419365    0.505641    0.070515    0.019858    0.601211    
#> 092: 0.453202    0.966365    3.419725    0.531190    0.078267    0.020535    0.599844    
#> 093: 0.462042    0.935291    3.430610    0.504630    0.074354    0.020011    0.625726    
#> 094: 0.466951    0.933121    3.430641    0.479399    0.077127    0.021340    0.612138    
#> 095: 0.478763    0.942873    3.430747    0.570704    0.073270    0.023099    0.599254    
#> 096: 0.437799    0.957167    3.430607    0.542169    0.076932    0.021944    0.593318    
#> 097: 0.457450    0.950490    3.425421    0.515060    0.082105    0.020847    0.583821    
#> 098: 0.470325    0.964686    3.432791    0.489307    0.077999    0.019805    0.581785    
#> 099: 0.456129    0.925579    3.426673    0.497184    0.074592    0.018814    0.583774    
#> 100: 0.469176    0.944739    3.436444    0.472325    0.073057    0.017874    0.586649    
#> 101: 0.427305    0.942314    3.414658    0.448709    0.078276    0.016980    0.601311    
#> 102: 0.426405    0.951711    3.420825    0.428740    0.074362    0.016131    0.623622    
#> 103: 0.454198    0.935525    3.429062    0.522278    0.070644    0.015325    0.618093    
#> 104: 0.449942    0.936428    3.444605    0.498239    0.079267    0.015579    0.614513    
#> 105: 0.462711    0.922227    3.439776    0.491369    0.083686    0.014800    0.632841    
#> 106: 0.457192    0.932993    3.427359    0.466801    0.079502    0.014060    0.619556    
#> 107: 0.464961    0.948251    3.427524    0.443461    0.081348    0.013357    0.614228    
#> 108: 0.450937    0.931429    3.435051    0.465028    0.077281    0.013738    0.607630    
#> 109: 0.462474    0.941780    3.439675    0.511775    0.073417    0.016123    0.597686    
#> 110: 0.477691    0.934853    3.424872    0.486186    0.079258    0.015317    0.609038    
#> 111: 0.477693    0.927530    3.443538    0.461877    0.084657    0.014551    0.590147    
#> 112: 0.462871    0.926947    3.428747    0.452621    0.097582    0.013824    0.604183    
#> 113: 0.441293    0.956046    3.433558    0.429990    0.092703    0.013132    0.596000    
#> 114: 0.461347    0.957133    3.431181    0.420354    0.094199    0.012476    0.595237    
#> 115: 0.457090    0.931582    3.430212    0.399336    0.089489    0.011852    0.610681    
#> 116: 0.500335    0.929590    3.438241    0.445910    0.085014    0.011259    0.604121    
#> 117: 0.448051    0.951282    3.431944    0.423615    0.080764    0.010696    0.624326    
#> 118: 0.456123    0.935894    3.436724    0.402434    0.082373    0.010283    0.618026    
#> 119: 0.463445    0.945864    3.440262    0.503677    0.094349    0.011128    0.639835    
#> 120: 0.454875    0.932797    3.436732    0.478493    0.102869    0.010571    0.643543    
#> 121: 0.495458    0.950642    3.434572    0.454568    0.097726    0.010404    0.634277    
#> 122: 0.492868    0.933730    3.444493    0.431840    0.092840    0.010493    0.621883    
#> 123: 0.535603    0.954596    3.440606    0.536063    0.088198    0.009968    0.598146    
#> 124: 0.506029    0.958193    3.435545    0.513218    0.083788    0.009470    0.600962    
#> 125: 0.509797    0.964166    3.429907    0.487557    0.087628    0.009601    0.601605    
#> 126: 0.500667    0.967812    3.420335    0.584702    0.091230    0.009132    0.599517    
#> 127: 0.432356    0.962590    3.416687    0.555467    0.099802    0.008675    0.611284    
#> 128: 0.440775    0.963111    3.428436    0.527693    0.094812    0.008242    0.606656    
#> 129: 0.479141    0.957463    3.434176    0.513545    0.090072    0.009877    0.603074    
#> 130: 0.507335    0.952119    3.432794    0.537473    0.092399    0.009671    0.593987    
#> 131: 0.484831    0.947281    3.424867    0.528485    0.087779    0.010566    0.594873    
#> 132: 0.452032    0.945063    3.419087    0.502061    0.083736    0.010509    0.616858    
#> 133: 0.431833    0.950283    3.419167    0.476958    0.088985    0.011019    0.618049    
#> 134: 0.449346    0.923568    3.433518    0.453110    0.084536    0.010674    0.617124    
#> 135: 0.454222    0.933122    3.445386    0.449250    0.095762    0.011798    0.610150    
#> 136: 0.482827    0.913782    3.444886    0.480860    0.090974    0.011208    0.598345    
#> 137: 0.519513    0.933411    3.448723    0.456817    0.086425    0.010648    0.606808    
#> 138: 0.501949    0.934069    3.444536    0.451100    0.092417    0.010382    0.623232    
#> 139: 0.499367    0.949039    3.447081    0.485126    0.104111    0.010130    0.615686    
#> 140: 0.501548    0.945403    3.448539    0.508666    0.098905    0.014156    0.609604    
#> 141: 0.476609    0.926375    3.453052    0.483232    0.098635    0.013448    0.613997    
#> 142: 0.497726    0.913904    3.465783    0.459071    0.093703    0.012776    0.619072    
#> 143: 0.510676    0.931294    3.458048    0.436117    0.089018    0.013867    0.620468    
#> 144: 0.537865    0.919440    3.470711    0.414311    0.090460    0.013174    0.614593    
#> 145: 0.492117    0.933970    3.450104    0.412688    0.092096    0.012515    0.603040    
#> 146: 0.480313    0.928629    3.450664    0.392054    0.099537    0.011889    0.617086    
#> 147: 0.434305    0.922352    3.438571    0.401601    0.094560    0.011295    0.616661    
#> 148: 0.441711    0.933129    3.444797    0.401971    0.089832    0.011705    0.607627    
#> 149: 0.441415    0.924822    3.436472    0.391713    0.085340    0.011582    0.614264    
#> 150: 0.468388    0.922335    3.428336    0.424091    0.083801    0.014490    0.614731    
#> 151: 0.412429    0.948442    3.423856    0.402886    0.079611    0.013765    0.612491    
#> 152: 0.433028    0.937267    3.426646    0.471605    0.077089    0.011066    0.611242    
#> 153: 0.449543    0.937396    3.432356    0.542366    0.075922    0.012457    0.594550    
#> 154: 0.467037    0.951770    3.429641    0.496388    0.098389    0.012553    0.609836    
#> 155: 0.446288    0.938996    3.417217    0.516080    0.080309    0.011181    0.616456    
#> 156: 0.449019    0.948663    3.430290    0.507478    0.084174    0.010007    0.613602    
#> 157: 0.470091    0.944209    3.437038    0.457342    0.087921    0.012920    0.618248    
#> 158: 0.486768    0.945719    3.438937    0.451612    0.068595    0.013486    0.607670    
#> 159: 0.444428    0.944546    3.439825    0.436602    0.053491    0.015427    0.622411    
#> 160: 0.517123    0.911736    3.455253    0.555496    0.051627    0.017100    0.620724    
#> 161: 0.503404    0.920709    3.446341    0.438851    0.058617    0.015967    0.622544    
#> 162: 0.494884    0.941343    3.437605    0.557837    0.063589    0.016875    0.622565    
#> 163: 0.510567    0.924355    3.437883    0.597947    0.064946    0.015732    0.613947    
#> 164: 0.487989    0.935314    3.440970    0.544237    0.068919    0.015787    0.598474    
#> 165: 0.536378    0.923472    3.445655    0.564560    0.063474    0.015428    0.610621    
#> 166: 0.549569    0.955049    3.442829    0.575185    0.063051    0.017769    0.602173    
#> 167: 0.522803    0.962150    3.443569    0.575293    0.071407    0.016876    0.609860    
#> 168: 0.500682    0.961751    3.446128    0.598443    0.074721    0.018022    0.591905    
#> 169: 0.481039    0.961138    3.423731    0.541369    0.072713    0.015663    0.602482    
#> 170: 0.478516    0.958770    3.436546    0.518449    0.063054    0.015903    0.602567    
#> 171: 0.487054    0.950340    3.439338    0.539015    0.050977    0.018185    0.604110    
#> 172: 0.482833    0.945052    3.440848    0.544961    0.063422    0.018530    0.586176    
#> 173: 0.476437    0.948013    3.429361    0.498628    0.063959    0.017586    0.593778    
#> 174: 0.505623    0.935639    3.435111    0.443506    0.058340    0.014789    0.600452    
#> 175: 0.486606    0.953531    3.425250    0.452022    0.065149    0.014654    0.613231    
#> 176: 0.479004    0.956445    3.436947    0.480621    0.074715    0.011656    0.596121    
#> 177: 0.466025    0.942521    3.443575    0.418276    0.072245    0.017164    0.591221    
#> 178: 0.476014    0.928591    3.442220    0.449738    0.073010    0.016533    0.599585    
#> 179: 0.503093    0.956442    3.438092    0.477383    0.089386    0.017247    0.601167    
#> 180: 0.471516    0.948044    3.437784    0.428918    0.082687    0.015602    0.601389    
#> 181: 0.471192    0.958774    3.424863    0.447102    0.076335    0.015630    0.598623    
#> 182: 0.435910    0.960355    3.418607    0.384370    0.079149    0.017111    0.621238    
#> 183: 0.470100    0.966035    3.428369    0.435869    0.073795    0.018722    0.625178    
#> 184: 0.466448    0.941003    3.430933    0.468704    0.070712    0.017237    0.594315    
#> 185: 0.445184    0.942153    3.433292    0.367434    0.064839    0.015741    0.612080    
#> 186: 0.439305    0.962648    3.429829    0.409323    0.066164    0.019240    0.610472    
#> 187: 0.457466    0.951607    3.432413    0.429133    0.061420    0.016119    0.608573    
#> 188: 0.464470    0.959084    3.426033    0.512140    0.069453    0.017370    0.616075    
#> 189: 0.465905    0.954710    3.440098    0.479868    0.077683    0.015746    0.623842    
#> 190: 0.466417    0.953891    3.440452    0.479758    0.074948    0.014257    0.601564    
#> 191: 0.458981    0.952072    3.435327    0.407113    0.067827    0.013919    0.600230    
#> 192: 0.440840    0.963540    3.435441    0.446576    0.073689    0.011212    0.617980    
#> 193: 0.462581    0.957596    3.431281    0.436316    0.076864    0.010611    0.616782    
#> 194: 0.440854    0.943129    3.416258    0.498248    0.075334    0.010926    0.627297    
#> 195: 0.405816    0.962309    3.408906    0.422122    0.082045    0.011754    0.619495    
#> 196: 0.420176    0.953901    3.415818    0.448476    0.089000    0.008759    0.633843    
#> 197: 0.448238    0.943644    3.431327    0.498944    0.081319    0.010136    0.636323    
#> 198: 0.452688    0.930539    3.430473    0.500712    0.084507    0.009832    0.625039    
#> 199: 0.469475    0.934441    3.428714    0.562206    0.076945    0.009064    0.628818    
#> 200: 0.436856    0.936604    3.431246    0.460306    0.082087    0.010026    0.630813    
#> 201: 0.430204    0.930775    3.432504    0.468542    0.084899    0.011066    0.617987    
#> 202: 0.437832    0.933985    3.432017    0.467156    0.080538    0.010603    0.620008    
#> 203: 0.446646    0.933677    3.429720    0.472799    0.081218    0.010473    0.620260    
#> 204: 0.449148    0.931552    3.430564    0.481786    0.085863    0.010377    0.619743    
#> 205: 0.452231    0.937380    3.431679    0.474772    0.089093    0.010487    0.618673    
#> 206: 0.454152    0.942558    3.431839    0.475216    0.089498    0.010632    0.618988    
#> 207: 0.452147    0.943143    3.430675    0.470612    0.089204    0.010783    0.620173    
#> 208: 0.452487    0.942037    3.431299    0.468124    0.088456    0.010884    0.619131    
#> 209: 0.455122    0.939686    3.430873    0.472825    0.088133    0.010989    0.617402    
#> 210: 0.458395    0.938556    3.431258    0.471040    0.087163    0.011090    0.615677    
#> 211: 0.462372    0.938613    3.432105    0.475611    0.087397    0.011182    0.613977    
#> 212: 0.465246    0.937878    3.432160    0.479224    0.086605    0.011265    0.614870    
#> 213: 0.464897    0.936259    3.432182    0.483569    0.085524    0.011215    0.617071    
#> 214: 0.466954    0.935460    3.432537    0.492507    0.084628    0.011164    0.616652    
#> 215: 0.469411    0.934939    3.433193    0.495771    0.085041    0.011104    0.616262    
#> 216: 0.471267    0.933586    3.433809    0.495562    0.086353    0.010974    0.617073    
#> 217: 0.471904    0.934160    3.434094    0.495419    0.087554    0.010893    0.615953    
#> 218: 0.473720    0.935091    3.434052    0.498525    0.088105    0.010796    0.616077    
#> 219: 0.472965    0.934954    3.433700    0.496794    0.087600    0.010724    0.616310    
#> 220: 0.470489    0.935583    3.433096    0.494846    0.087281    0.010812    0.616377    
#> 221: 0.468577    0.936750    3.432653    0.493278    0.086850    0.010955    0.615694    
#> 222: 0.468141    0.936976    3.432276    0.493156    0.086721    0.011082    0.615529    
#> 223: 0.468476    0.937565    3.432237    0.493168    0.086542    0.011171    0.614703    
#> 224: 0.469820    0.938115    3.432391    0.495040    0.086391    0.011268    0.613867    
#> 225: 0.469290    0.937647    3.432680    0.491557    0.085762    0.011326    0.613845    
#> 226: 0.469836    0.936832    3.432912    0.490064    0.085542    0.011374    0.613609    
#> 227: 0.470187    0.936809    3.433135    0.488566    0.085446    0.011426    0.613194    
#> 228: 0.469405    0.937399    3.432798    0.487359    0.085022    0.011504    0.613068    
#> 229: 0.468575    0.937536    3.432628    0.487149    0.084897    0.011557    0.612351    
#> 230: 0.469688    0.937250    3.432744    0.487699    0.085172    0.011638    0.612390    
#> 231: 0.470308    0.937137    3.433199    0.487255    0.084996    0.011748    0.612188    
#> 232: 0.470347    0.937157    3.433599    0.486204    0.084540    0.011848    0.612142    
#> 233: 0.469942    0.936618    3.433875    0.486550    0.084226    0.011885    0.612163    
#> 234: 0.470144    0.936818    3.434005    0.486810    0.083932    0.011998    0.611826    
#> 235: 0.469900    0.937005    3.433838    0.485635    0.083638    0.012040    0.611446    
#> 236: 0.469171    0.937313    3.433847    0.484835    0.083402    0.012110    0.611342    
#> 237: 0.469977    0.937313    3.433931    0.484703    0.083086    0.012251    0.611672    
#> 238: 0.470437    0.937173    3.434178    0.484202    0.082733    0.012354    0.612348    
#> 239: 0.469942    0.937588    3.434007    0.483714    0.082311    0.012391    0.612333    
#> 240: 0.470222    0.937482    3.434041    0.483255    0.082043    0.012438    0.611902    
#> 241: 0.470697    0.936660    3.434153    0.483335    0.081930    0.012503    0.612087    
#> 242: 0.470963    0.935900    3.434235    0.484956    0.082215    0.012577    0.612316    
#> 243: 0.470775    0.935962    3.434141    0.485614    0.082540    0.012614    0.612655    
#> 244: 0.470144    0.936015    3.434166    0.484267    0.082408    0.012671    0.612669    
#> 245: 0.470147    0.935475    3.434259    0.483557    0.082314    0.012660    0.613162    
#> 246: 0.470224    0.935381    3.434381    0.483319    0.082262    0.012721    0.613213    
#> 247: 0.470132    0.935171    3.434606    0.481587    0.082277    0.012770    0.613270    
#> 248: 0.470276    0.935452    3.434770    0.481134    0.081990    0.012797    0.613245    
#> 249: 0.470243    0.935447    3.434998    0.478817    0.081804    0.012852    0.613067    
#> 250: 0.471494    0.935581    3.435440    0.479349    0.081855    0.012907    0.612729    
#> 251: 0.472934    0.935750    3.435873    0.479453    0.082049    0.012948    0.612439    
#> 252: 0.473963    0.935692    3.436337    0.479945    0.082021    0.012996    0.612381    
#> 253: 0.474129    0.935586    3.436529    0.480003    0.081805    0.013082    0.612016    
#> 254: 0.474757    0.935715    3.436636    0.481043    0.081808    0.013186    0.611705    
#> 255: 0.475305    0.936010    3.436780    0.481741    0.081709    0.013329    0.611563    
#> 256: 0.475663    0.935923    3.436814    0.482032    0.081719    0.013463    0.611438    
#> 257: 0.475375    0.935597    3.436751    0.482596    0.081628    0.013541    0.611601    
#> 258: 0.475700    0.935273    3.436761    0.483045    0.081666    0.013578    0.611775    
#> 259: 0.475963    0.935137    3.436782    0.482890    0.081643    0.013613    0.612036    
#> 260: 0.476037    0.935152    3.436798    0.483367    0.081680    0.013598    0.611943    
#> 261: 0.476205    0.935169    3.436872    0.483172    0.081696    0.013551    0.612053    
#> 262: 0.476331    0.935291    3.436866    0.482739    0.081868    0.013513    0.611972    
#> 263: 0.476097    0.935201    3.436882    0.481865    0.081900    0.013574    0.612132    
#> 264: 0.475844    0.935429    3.436799    0.481283    0.081881    0.013569    0.612490    
#> 265: 0.475933    0.935390    3.436910    0.482001    0.082189    0.013549    0.612856    
#> 266: 0.476464    0.935256    3.437175    0.481665    0.082264    0.013492    0.612878    
#> 267: 0.476857    0.935171    3.437349    0.481406    0.082436    0.013424    0.612905    
#> 268: 0.477033    0.934944    3.437406    0.481182    0.082383    0.013390    0.612894    
#> 269: 0.477780    0.934829    3.437491    0.481352    0.082334    0.013356    0.612864    
#> 270: 0.478400    0.934888    3.437539    0.482378    0.082379    0.013351    0.612534    
#> 271: 0.478511    0.935022    3.437506    0.482650    0.082396    0.013363    0.612447    
#> 272: 0.479053    0.934625    3.437585    0.482053    0.082553    0.013373    0.612856    
#> 273: 0.479210    0.934801    3.437724    0.481701    0.082569    0.013386    0.613129    
#> 274: 0.479104    0.934756    3.437949    0.480910    0.082675    0.013358    0.613169    
#> 275: 0.479125    0.934726    3.438009    0.480351    0.082812    0.013336    0.613134    
#> 276: 0.479050    0.934769    3.438230    0.478936    0.082981    0.013339    0.613087    
#> 277: 0.478894    0.934722    3.438416    0.478268    0.082976    0.013383    0.613012    
#> 278: 0.478760    0.934680    3.438535    0.477618    0.083087    0.013424    0.612984    
#> 279: 0.478763    0.934386    3.438668    0.477889    0.083008    0.013455    0.613135    
#> 280: 0.478723    0.934551    3.438762    0.477878    0.082872    0.013452    0.612930    
#> 281: 0.478733    0.934713    3.438941    0.477476    0.082742    0.013440    0.612734    
#> 282: 0.478747    0.934796    3.439025    0.477706    0.082649    0.013463    0.612613    
#> 283: 0.478745    0.934791    3.439102    0.477278    0.082569    0.013492    0.612879    
#> 284: 0.478488    0.934638    3.439156    0.476562    0.082491    0.013538    0.612747    
#> 285: 0.478334    0.934604    3.439058    0.476159    0.082327    0.013622    0.612614    
#> 286: 0.478211    0.934845    3.439017    0.476103    0.082364    0.013689    0.612525    
#> 287: 0.477598    0.935037    3.438756    0.475934    0.082218    0.013731    0.612479    
#> 288: 0.477456    0.935066    3.438627    0.476197    0.082178    0.013775    0.612440    
#> 289: 0.477743    0.935000    3.438726    0.475505    0.082100    0.013785    0.612323    
#> 290: 0.477828    0.934924    3.438878    0.474806    0.082013    0.013803    0.612383    
#> 291: 0.478073    0.935078    3.439071    0.474185    0.081944    0.013808    0.612216    
#> 292: 0.477901    0.935004    3.439115    0.473898    0.081891    0.013798    0.612193    
#> 293: 0.477669    0.935014    3.439096    0.473537    0.081753    0.013794    0.612201    
#> 294: 0.477522    0.935038    3.439038    0.473268    0.081607    0.013786    0.612169    
#> 295: 0.477156    0.934974    3.439003    0.472629    0.081494    0.013776    0.612029    
#> 296: 0.476931    0.934899    3.439019    0.471841    0.081456    0.013769    0.612038    
#> 297: 0.476838    0.935087    3.439050    0.471615    0.081344    0.013760    0.612144    
#> 298: 0.476900    0.935010    3.439086    0.471377    0.081231    0.013782    0.612093    
#> 299: 0.476933    0.935014    3.438933    0.471912    0.081160    0.013785    0.611913    
#> 300: 0.476883    0.934973    3.438929    0.472205    0.080997    0.013802    0.611825    
#> 301: 0.477016    0.934867    3.438892    0.472584    0.081004    0.013814    0.611692    
#> 302: 0.477251    0.934894    3.438885    0.473117    0.080949    0.013837    0.611539    
#> 303: 0.477386    0.934867    3.438893    0.472957    0.080775    0.013878    0.611205    
#> 304: 0.477367    0.935096    3.438764    0.472910    0.080628    0.013939    0.611076    
#> 305: 0.477231    0.935095    3.438725    0.472914    0.080492    0.013999    0.610769    
#> 306: 0.477049    0.935259    3.438634    0.472914    0.080440    0.014032    0.610554    
#> 307: 0.476571    0.935302    3.438548    0.472065    0.080339    0.014044    0.610573    
#> 308: 0.476072    0.935296    3.438485    0.471679    0.080321    0.014066    0.610507    
#> 309: 0.475811    0.935183    3.438420    0.471473    0.080307    0.014073    0.610541    
#> 310: 0.475761    0.935211    3.438311    0.471206    0.080366    0.014072    0.610477    
#> 311: 0.475611    0.935235    3.438282    0.470899    0.080408    0.014074    0.610383    
#> 312: 0.475585    0.935160    3.438234    0.470955    0.080533    0.014062    0.610403    
#> 313: 0.475084    0.935046    3.438131    0.470409    0.080645    0.014044    0.610496    
#> 314: 0.474729    0.935142    3.438073    0.470331    0.080736    0.014028    0.610462    
#> 315: 0.474572    0.935260    3.438053    0.470840    0.080747    0.014021    0.610306    
#> 316: 0.474742    0.935395    3.437964    0.472208    0.080754    0.014031    0.610225    
#> 317: 0.474848    0.935399    3.437936    0.472969    0.080810    0.014042    0.610384    
#> 318: 0.474652    0.935483    3.437804    0.472795    0.080704    0.014090    0.610477    
#> 319: 0.474637    0.935553    3.437799    0.472776    0.080636    0.014109    0.610466    
#> 320: 0.474260    0.935408    3.437773    0.472488    0.080552    0.014133    0.610520    
#> 321: 0.474037    0.935436    3.437665    0.472088    0.080449    0.014163    0.610487    
#> 322: 0.474223    0.935361    3.437574    0.472717    0.080414    0.014144    0.610371    
#> 323: 0.474223    0.935463    3.437542    0.473066    0.080531    0.014124    0.610151    
#> 324: 0.474296    0.935505    3.437556    0.473831    0.080621    0.014115    0.609885    
#> 325: 0.474427    0.935655    3.437503    0.474336    0.080727    0.014105    0.609614    
#> 326: 0.474321    0.935606    3.437405    0.474389    0.080804    0.014106    0.609464    
#> 327: 0.474447    0.935683    3.437393    0.474668    0.080883    0.014121    0.609389    
#> 328: 0.474414    0.935773    3.437384    0.474754    0.080835    0.014121    0.609325    
#> 329: 0.474722    0.935844    3.437463    0.474834    0.080835    0.014141    0.609189    
#> 330: 0.474758    0.935837    3.437513    0.474776    0.080768    0.014156    0.609128    
#> 331: 0.474805    0.935962    3.437526    0.474342    0.080789    0.014153    0.609054    
#> 332: 0.475005    0.935895    3.437650    0.474291    0.080668    0.014167    0.609012    
#> 333: 0.475177    0.935813    3.437695    0.474098    0.080593    0.014186    0.608897    
#> 334: 0.475109    0.935786    3.437589    0.474003    0.080479    0.014179    0.608805    
#> 335: 0.475000    0.935737    3.437443    0.474243    0.080550    0.014169    0.608755    
#> 336: 0.474675    0.935930    3.437334    0.474525    0.080630    0.014185    0.608680    
#> 337: 0.474416    0.936208    3.437235    0.474734    0.080701    0.014181    0.608667    
#> 338: 0.474168    0.936358    3.437180    0.475110    0.080753    0.014176    0.608683    
#> 339: 0.473819    0.936574    3.437111    0.475436    0.080706    0.014175    0.608647    
#> 340: 0.473599    0.936494    3.437092    0.475677    0.080704    0.014184    0.608589    
#> 341: 0.473469    0.936488    3.437088    0.475509    0.080647    0.014184    0.608569    
#> 342: 0.473191    0.936469    3.437094    0.475085    0.080599    0.014183    0.608597    
#> 343: 0.473192    0.936556    3.437094    0.474846    0.080548    0.014177    0.608494    
#> 344: 0.473375    0.936430    3.437119    0.475314    0.080496    0.014181    0.608434    
#> 345: 0.473414    0.936416    3.437172    0.475126    0.080411    0.014201    0.608401    
#> 346: 0.473444    0.936440    3.437121    0.475132    0.080300    0.014207    0.608394    
#> 347: 0.473229    0.936342    3.436988    0.475100    0.080240    0.014244    0.608474    
#> 348: 0.473017    0.936454    3.436936    0.474897    0.080205    0.014289    0.608538    
#> 349: 0.473040    0.936353    3.436924    0.474937    0.080245    0.014312    0.608601    
#> 350: 0.472831    0.936261    3.436885    0.474480    0.080161    0.014349    0.608547    
#> 351: 0.472872    0.936403    3.436818    0.474242    0.080028    0.014403    0.608600    
#> 352: 0.472638    0.936600    3.436829    0.473986    0.079988    0.014463    0.608721    
#> 353: 0.472653    0.936771    3.436809    0.474237    0.079945    0.014502    0.608643    
#> 354: 0.472467    0.936935    3.436704    0.473909    0.079856    0.014542    0.608663    
#> 355: 0.472558    0.936943    3.436683    0.474030    0.079824    0.014578    0.608617    
#> 356: 0.472434    0.936904    3.436659    0.473856    0.079750    0.014620    0.608715    
#> 357: 0.472465    0.936956    3.436661    0.473803    0.079737    0.014619    0.608671    
#> 358: 0.472239    0.937067    3.436622    0.473558    0.079703    0.014638    0.608605    
#> 359: 0.471911    0.937229    3.436524    0.473369    0.079696    0.014622    0.608614    
#> 360: 0.471569    0.937278    3.436378    0.472691    0.079665    0.014605    0.608604    
#> 361: 0.471405    0.937362    3.436275    0.472709    0.079605    0.014600    0.608557    
#> 362: 0.471264    0.937351    3.436233    0.472324    0.079560    0.014593    0.608419    
#> 363: 0.471282    0.937337    3.436237    0.472444    0.079536    0.014593    0.608286    
#> 364: 0.471466    0.937466    3.436259    0.472374    0.079520    0.014580    0.608293    
#> 365: 0.471460    0.937516    3.436291    0.472303    0.079479    0.014593    0.608359    
#> 366: 0.471187    0.937642    3.436212    0.471667    0.079434    0.014608    0.608602    
#> 367: 0.470960    0.937698    3.436202    0.471228    0.079457    0.014622    0.608626    
#> 368: 0.471166    0.937815    3.436241    0.470999    0.079404    0.014638    0.608604    
#> 369: 0.471339    0.937818    3.436279    0.471001    0.079350    0.014624    0.608677    
#> 370: 0.471289    0.937805    3.436290    0.470694    0.079300    0.014618    0.608757    
#> 371: 0.471255    0.937792    3.436267    0.470482    0.079197    0.014623    0.608815    
#> 372: 0.471186    0.937819    3.436231    0.470392    0.079140    0.014624    0.608805    
#> 373: 0.470996    0.937903    3.436198    0.470271    0.079098    0.014629    0.608803    
#> 374: 0.471068    0.937871    3.436204    0.470085    0.079116    0.014629    0.608806    
#> 375: 0.471047    0.937804    3.436254    0.470017    0.079139    0.014633    0.608756    
#> 376: 0.471023    0.937830    3.436272    0.469757    0.079181    0.014613    0.608723    
#> 377: 0.470949    0.937801    3.436262    0.469472    0.079184    0.014612    0.608710    
#> 378: 0.470981    0.937781    3.436279    0.469143    0.079134    0.014603    0.608696    
#> 379: 0.470915    0.937593    3.436321    0.469021    0.079175    0.014603    0.608669    
#> 380: 0.470900    0.937556    3.436357    0.468982    0.079187    0.014599    0.608572    
#> 381: 0.470892    0.937507    3.436408    0.468751    0.079227    0.014592    0.608488    
#> 382: 0.470878    0.937496    3.436465    0.468654    0.079224    0.014578    0.608383    
#> 383: 0.471084    0.937456    3.436494    0.468922    0.079253    0.014553    0.608388    
#> 384: 0.471098    0.937365    3.436539    0.468714    0.079199    0.014542    0.608394    
#> 385: 0.471217    0.937260    3.436559    0.468638    0.079141    0.014545    0.608356    
#> 386: 0.471440    0.937315    3.436640    0.468463    0.079045    0.014550    0.608422    
#> 387: 0.471631    0.937321    3.436723    0.468158    0.079036    0.014554    0.608361    
#> 388: 0.471650    0.937321    3.436786    0.467650    0.079003    0.014560    0.608303    
#> 389: 0.471618    0.937194    3.436806    0.467215    0.079032    0.014562    0.608339    
#> 390: 0.471617    0.937219    3.436804    0.466895    0.079006    0.014561    0.608256    
#> 391: 0.471807    0.937252    3.436794    0.466976    0.078959    0.014567    0.608142    
#> 392: 0.471866    0.937287    3.436823    0.467494    0.078924    0.014581    0.608091    
#> 393: 0.471878    0.937166    3.436835    0.467675    0.078905    0.014582    0.608053    
#> 394: 0.471970    0.937176    3.436815    0.468127    0.078805    0.014576    0.608028    
#> 395: 0.472091    0.937227    3.436831    0.468324    0.078755    0.014575    0.608003    
#> 396: 0.472193    0.937303    3.436820    0.468766    0.078725    0.014575    0.607943    
#> 397: 0.472203    0.937284    3.436859    0.468878    0.078667    0.014582    0.607888    
#> 398: 0.472294    0.937180    3.436936    0.468717    0.078697    0.014588    0.607948    
#> 399: 0.472448    0.937114    3.437033    0.468826    0.078682    0.014584    0.607961    
#> 400: 0.472736    0.936982    3.437159    0.468913    0.078626    0.014604    0.607934    
#> 401: 0.473001    0.936984    3.437206    0.469037    0.078609    0.014616    0.607951    
#> 402: 0.473132    0.937036    3.437255    0.468770    0.078547    0.014636    0.608008    
#> 403: 0.473389    0.937059    3.437291    0.468737    0.078496    0.014651    0.607993    
#> 404: 0.473425    0.937168    3.437202    0.468794    0.078464    0.014669    0.607978    
#> 405: 0.473216    0.937261    3.437177    0.468441    0.078480    0.014684    0.607940    
#> 406: 0.473076    0.937275    3.437163    0.468221    0.078461    0.014697    0.607955    
#> 407: 0.473099    0.937240    3.437207    0.468152    0.078448    0.014703    0.607984    
#> 408: 0.473174    0.937288    3.437204    0.467862    0.078444    0.014724    0.607950    
#> 409: 0.473180    0.937245    3.437197    0.467686    0.078446    0.014731    0.607877    
#> 410: 0.473091    0.937241    3.437150    0.467783    0.078425    0.014734    0.607875    
#> 411: 0.473171    0.937126    3.437128    0.468087    0.078505    0.014738    0.607887    
#> 412: 0.473076    0.937189    3.437085    0.467781    0.078502    0.014750    0.607860    
#> 413: 0.472971    0.937347    3.436994    0.467773    0.078477    0.014761    0.607862    
#> 414: 0.472622    0.937449    3.436951    0.468020    0.078409    0.014776    0.607869    
#> 415: 0.472656    0.937458    3.436889    0.468411    0.078332    0.014786    0.607895    
#> 416: 0.472659    0.937529    3.436842    0.468509    0.078301    0.014795    0.607905    
#> 417: 0.472622    0.937592    3.436756    0.468696    0.078357    0.014797    0.607833    
#> 418: 0.472377    0.937665    3.436715    0.468503    0.078465    0.014790    0.607756    
#> 419: 0.472342    0.937781    3.436658    0.468596    0.078478    0.014795    0.607686    
#> 420: 0.472237    0.937841    3.436620    0.468889    0.078507    0.014790    0.607578    
#> 421: 0.471996    0.937902    3.436579    0.468801    0.078560    0.014787    0.607534    
#> 422: 0.472140    0.937841    3.436591    0.469281    0.078644    0.014787    0.607482    
#> 423: 0.472164    0.937823    3.436560    0.469510    0.078662    0.014786    0.607462    
#> 424: 0.472074    0.937845    3.436512    0.469508    0.078664    0.014784    0.607436    
#> 425: 0.472128    0.937944    3.436464    0.469592    0.078692    0.014795    0.607420    
#> 426: 0.472168    0.937996    3.436438    0.469778    0.078713    0.014806    0.607400    
#> 427: 0.472293    0.938010    3.436465    0.470279    0.078707    0.014812    0.607317    
#> 428: 0.472246    0.938038    3.436514    0.470281    0.078712    0.014816    0.607350    
#> 429: 0.472300    0.938036    3.436573    0.470081    0.078689    0.014816    0.607343    
#> 430: 0.472305    0.938069    3.436604    0.469951    0.078709    0.014823    0.607359    
#> 431: 0.472323    0.938033    3.436620    0.469956    0.078751    0.014819    0.607308    
#> 432: 0.472187    0.938077    3.436609    0.469991    0.078791    0.014821    0.607256    
#> 433: 0.472107    0.938155    3.436598    0.469937    0.078834    0.014835    0.607192    
#> 434: 0.471994    0.938122    3.436608    0.469785    0.078864    0.014842    0.607139    
#> 435: 0.472032    0.938133    3.436585    0.469689    0.078850    0.014840    0.607114    
#> 436: 0.472124    0.938105    3.436632    0.469727    0.078926    0.014835    0.607084    
#> 437: 0.472197    0.938084    3.436655    0.469640    0.078913    0.014836    0.607026    
#> 438: 0.472154    0.938156    3.436620    0.469552    0.078900    0.014831    0.606929    
#> 439: 0.472250    0.938264    3.436599    0.469719    0.078897    0.014832    0.606817    
#> 440: 0.472369    0.938294    3.436645    0.469689    0.078880    0.014827    0.606798    
#> 441: 0.472549    0.938251    3.436660    0.469988    0.078877    0.014822    0.606717    
#> 442: 0.472505    0.938214    3.436670    0.470053    0.078854    0.014822    0.606619    
#> 443: 0.472533    0.938233    3.436648    0.470206    0.078839    0.014817    0.606597    
#> 444: 0.472409    0.938266    3.436586    0.470002    0.078863    0.014812    0.606586    
#> 445: 0.472321    0.938338    3.436546    0.469974    0.078890    0.014806    0.606592    
#> 446: 0.472115    0.938415    3.436493    0.469873    0.078920    0.014799    0.606587    
#> 447: 0.472180    0.938422    3.436493    0.469840    0.078931    0.014795    0.606630    
#> 448: 0.472118    0.938423    3.436494    0.469568    0.078973    0.014783    0.606600    
#> 449: 0.471974    0.938519    3.436539    0.469218    0.078981    0.014776    0.606603    
#> 450: 0.471939    0.938571    3.436539    0.468986    0.078939    0.014772    0.606657    
#> 451: 0.471957    0.938583    3.436492    0.468872    0.078872    0.014768    0.606700    
#> 452: 0.471828    0.938603    3.436442    0.468599    0.078845    0.014760    0.606703    
#> 453: 0.471587    0.938683    3.436354    0.468389    0.078864    0.014748    0.606687    
#> 454: 0.471396    0.938769    3.436309    0.468136    0.078926    0.014744    0.606688    
#> 455: 0.471380    0.938788    3.436280    0.468143    0.078886    0.014746    0.606702    
#> 456: 0.471227    0.938776    3.436236    0.467977    0.078867    0.014747    0.606774    
#> 457: 0.471238    0.938752    3.436278    0.467885    0.078815    0.014749    0.606810    
#> 458: 0.471364    0.938848    3.436331    0.467854    0.078782    0.014741    0.606765    
#> 459: 0.471218    0.938951    3.436349    0.467589    0.078759    0.014726    0.606829    
#> 460: 0.471193    0.938999    3.436330    0.467485    0.078761    0.014714    0.606864    
#> 461: 0.471271    0.939025    3.436341    0.467481    0.078753    0.014716    0.606881    
#> 462: 0.471161    0.939053    3.436383    0.467392    0.078733    0.014722    0.606874    
#> 463: 0.471136    0.939063    3.436427    0.467339    0.078684    0.014716    0.606866    
#> 464: 0.471217    0.939075    3.436434    0.467107    0.078652    0.014713    0.606808    
#> 465: 0.471302    0.938970    3.436474    0.467023    0.078635    0.014704    0.606808    
#> 466: 0.471357    0.938936    3.436485    0.466780    0.078663    0.014694    0.606825    
#> 467: 0.471333    0.938890    3.436536    0.466691    0.078682    0.014685    0.606789    
#> 468: 0.471474    0.938884    3.436593    0.466558    0.078700    0.014669    0.606869    
#> 469: 0.471506    0.938982    3.436612    0.466604    0.078700    0.014668    0.606912    
#> 470: 0.471430    0.939046    3.436572    0.466645    0.078739    0.014675    0.606885    
#> 471: 0.471323    0.939052    3.436531    0.466710    0.078728    0.014669    0.606885    
#> 472: 0.471187    0.939056    3.436482    0.466764    0.078759    0.014673    0.606856    
#> 473: 0.471115    0.939068    3.436445    0.466943    0.078768    0.014666    0.606829    
#> 474: 0.470971    0.939063    3.436400    0.466823    0.078791    0.014662    0.606848    
#> 475: 0.470928    0.939117    3.436384    0.466629    0.078796    0.014656    0.606818    
#> 476: 0.470907    0.939155    3.436372    0.466589    0.078810    0.014643    0.606817    
#> 477: 0.470818    0.939164    3.436371    0.466560    0.078826    0.014629    0.606760    
#> 478: 0.470759    0.939156    3.436377    0.466663    0.078822    0.014621    0.606787    
#> 479: 0.470962    0.939162    3.436395    0.467135    0.078861    0.014616    0.606775    
#> 480: 0.471131    0.939116    3.436423    0.467356    0.078950    0.014616    0.606794    
#> 481: 0.471209    0.939112    3.436424    0.467700    0.078994    0.014611    0.606814    
#> 482: 0.471211    0.939189    3.436390    0.467814    0.079009    0.014604    0.606812    
#> 483: 0.471152    0.939231    3.436359    0.468002    0.079047    0.014601    0.606768    
#> 484: 0.471167    0.939126    3.436332    0.468456    0.079046    0.014598    0.606757    
#> 485: 0.471190    0.939141    3.436283    0.468885    0.079035    0.014617    0.606745    
#> 486: 0.471178    0.939262    3.436244    0.469135    0.079028    0.014623    0.606716    
#> 487: 0.471204    0.939310    3.436213    0.469337    0.079025    0.014622    0.606688    
#> 488: 0.471066    0.939328    3.436184    0.469509    0.079056    0.014617    0.606669    
#> 489: 0.471048    0.939310    3.436135    0.469770    0.079056    0.014625    0.606649    
#> 490: 0.471058    0.939301    3.436140    0.469688    0.079058    0.014627    0.606640    
#> 491: 0.471077    0.939330    3.436180    0.469482    0.079074    0.014627    0.606616    
#> 492: 0.471089    0.939363    3.436196    0.469313    0.079103    0.014623    0.606672    
#> 493: 0.471011    0.939365    3.436187    0.469014    0.079116    0.014613    0.606666    
#> 494: 0.471092    0.939382    3.436178    0.468832    0.079159    0.014604    0.606613    
#> 495: 0.471210    0.939396    3.436179    0.469100    0.079167    0.014599    0.606555    
#> 496: 0.471274    0.939444    3.436171    0.468916    0.079148    0.014603    0.606566    
#> 497: 0.471250    0.939514    3.436161    0.468988    0.079106    0.014610    0.606606    
#> 498: 0.471180    0.939543    3.436140    0.468981    0.079077    0.014613    0.606556    
#> 499: 0.471148    0.939580    3.436110    0.468947    0.079054    0.014612    0.606499    
#> 500: 0.471365    0.939565    3.436110    0.469228    0.079078    0.014613    0.606473    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.290110    0.984344    3.443926    0.392401    0.083480    0.016800    1.794045    
#> 002: 0.400435    1.087334    3.484585    0.372781    0.079306    0.019907    1.148440    
#> 003: 0.537729    1.095853    3.495331    0.415482    0.075340    0.018912    0.868399    
#> 004: 0.575152    1.139304    3.512991    0.592817    0.089570    0.017966    0.760003    
#> 005: 0.697534    1.155486    3.509488    0.665428    0.085474    0.017068    0.722409    
#> 006: 0.677119    1.155484    3.521282    0.632157    0.081200    0.016215    0.698065    
#> 007: 0.637507    1.180347    3.509880    0.655341    0.077140    0.015404    0.701391    
#> 008: 0.659748    1.174300    3.499286    0.766520    0.082695    0.014802    0.704771    
#> 009: 0.630653    1.156120    3.494456    0.771435    0.080441    0.014062    0.697729    
#> 010: 0.612907    1.153357    3.495347    0.766081    0.076419    0.014035    0.717336    
#> 011: 0.718091    1.158440    3.506885    0.778485    0.081565    0.013333    0.706100    
#> 012: 0.736812    1.147456    3.510575    0.828119    0.078302    0.014688    0.686093    
#> 013: 0.666995    1.151182    3.508539    0.835928    0.084060    0.018440    0.703879    
#> 014: 0.685675    1.138351    3.518200    0.794131    0.079857    0.018114    0.709261    
#> 015: 0.684605    1.151398    3.529575    0.754425    0.081389    0.017208    0.695156    
#> 016: 0.733486    1.161342    3.542332    0.716703    0.077320    0.020944    0.685708    
#> 017: 0.743181    1.172223    3.535046    0.709519    0.073454    0.019897    0.681563    
#> 018: 0.716709    1.150873    3.533070    0.674043    0.070201    0.018902    0.677495    
#> 019: 0.678323    1.150744    3.529759    0.640341    0.066691    0.017957    0.677217    
#> 020: 0.746004    1.140391    3.532054    0.815663    0.063356    0.021147    0.667320    
#> 021: 0.745871    1.126993    3.533562    0.774880    0.060188    0.021838    0.666697    
#> 022: 0.707732    1.131154    3.542161    0.804830    0.057179    0.022017    0.679259    
#> 023: 0.784299    1.144910    3.556029    0.764589    0.054320    0.024646    0.679422    
#> 024: 0.800062    1.166321    3.552355    0.769259    0.051653    0.023414    0.658881    
#> 025: 0.764564    1.142802    3.539577    0.730796    0.053729    0.022243    0.660986    
#> 026: 0.765855    1.172034    3.534892    0.728214    0.051042    0.022614    0.677900    
#> 027: 0.710845    1.170572    3.527375    0.691803    0.048490    0.024958    0.690042    
#> 028: 0.736382    1.171239    3.530167    0.734937    0.052569    0.023710    0.679552    
#> 029: 0.721092    1.168600    3.522889    0.698190    0.053801    0.024819    0.683204    
#> 030: 0.737621    1.171081    3.525966    0.689283    0.060181    0.024375    0.681544    
#> 031: 0.660565    1.153823    3.521511    0.792628    0.062958    0.023156    0.682414    
#> 032: 0.673769    1.149100    3.520803    0.814184    0.059882    0.021998    0.670849    
#> 033: 0.665192    1.163713    3.519757    0.786598    0.056888    0.020898    0.675794    
#> 034: 0.741416    1.161391    3.520875    0.747268    0.054993    0.019853    0.677844    
#> 035: 0.694489    1.137405    3.528848    0.709905    0.052244    0.019531    0.675203    
#> 036: 0.703753    1.135815    3.536163    0.674409    0.052050    0.019642    0.695043    
#> 037: 0.696362    1.142280    3.532988    0.640689    0.049447    0.019899    0.695268    
#> 038: 0.702978    1.142445    3.525761    0.644865    0.046975    0.021389    0.703133    
#> 039: 0.716189    1.133514    3.540157    0.700082    0.051102    0.024912    0.706704    
#> 040: 0.661729    1.150646    3.535945    0.673828    0.048920    0.026197    0.702119    
#> 041: 0.582385    1.155315    3.515796    0.640136    0.051499    0.026766    0.703004    
#> 042: 0.654545    1.158443    3.520705    0.669276    0.051158    0.025427    0.665119    
#> 043: 0.638536    1.170624    3.507756    0.635812    0.048600    0.027654    0.687911    
#> 044: 0.588052    1.175508    3.502090    0.651488    0.047197    0.027251    0.683847    
#> 045: 0.621162    1.201983    3.497514    0.618914    0.044837    0.026409    0.678607    
#> 046: 0.676791    1.173132    3.511763    0.684697    0.045566    0.025834    0.671794    
#> 047: 0.677932    1.176389    3.518386    0.652791    0.043288    0.025771    0.672860    
#> 048: 0.684114    1.161700    3.515180    0.680080    0.042919    0.024957    0.694947    
#> 049: 0.692790    1.156998    3.531030    0.699837    0.046946    0.026850    0.682609    
#> 050: 0.721521    1.142887    3.537411    0.694761    0.048018    0.028017    0.698314    
#> 051: 0.645945    1.159661    3.520386    0.660023    0.050619    0.029275    0.709656    
#> 052: 0.676752    1.149409    3.527381    0.627022    0.048088    0.027812    0.688141    
#> 053: 0.736428    1.151114    3.528022    0.784876    0.048969    0.026421    0.683420    
#> 054: 0.639096    1.168581    3.521629    0.745632    0.048081    0.025100    0.703617    
#> 055: 0.670447    1.161788    3.532211    0.708532    0.061043    0.025548    0.697043    
#> 056: 0.735857    1.134806    3.531775    0.722136    0.066925    0.024271    0.686663    
#> 057: 0.735863    1.146394    3.542314    0.735715    0.063579    0.024194    0.707808    
#> 058: 0.739139    1.151775    3.527191    0.698930    0.060400    0.022984    0.697076    
#> 059: 0.737814    1.109010    3.538046    0.663983    0.063401    0.022944    0.715325    
#> 060: 0.715683    1.106377    3.553487    0.630784    0.060231    0.024196    0.711694    
#> 061: 0.734521    1.118505    3.563052    0.599245    0.057220    0.028045    0.720195    
#> 062: 0.768258    1.133439    3.564362    0.721226    0.062209    0.026643    0.716721    
#> 063: 0.768931    1.113282    3.558406    0.685165    0.061140    0.029299    0.711836    
#> 064: 0.723820    1.146361    3.552497    0.650906    0.058083    0.027834    0.709741    
#> 065: 0.739744    1.134443    3.518445    0.691576    0.055179    0.026443    0.705631    
#> 066: 0.716449    1.160777    3.526781    0.656997    0.052420    0.025303    0.681847    
#> 067: 0.652077    1.153652    3.519887    0.655736    0.049799    0.025825    0.671221    
#> 068: 0.633937    1.154338    3.524096    0.627366    0.047309    0.028755    0.686898    
#> 069: 0.629843    1.169240    3.509228    0.718819    0.044943    0.027317    0.717729    
#> 070: 0.703886    1.152125    3.523189    0.783129    0.054171    0.027516    0.691192    
#> 071: 0.695448    1.170008    3.514938    0.743973    0.059079    0.026141    0.680272    
#> 072: 0.703391    1.140733    3.521721    0.706774    0.063012    0.024834    0.684214    
#> 073: 0.687649    1.164928    3.542215    0.671436    0.059862    0.025548    0.698973    
#> 074: 0.643260    1.149215    3.532044    0.637864    0.056869    0.028508    0.685152    
#> 075: 0.712952    1.133900    3.559915    0.605971    0.058585    0.027082    0.685541    
#> 076: 0.722117    1.149404    3.558586    0.594306    0.055656    0.028659    0.680878    
#> 077: 0.780629    1.140460    3.560457    0.707189    0.052873    0.027226    0.693745    
#> 078: 0.755385    1.142989    3.552624    0.742656    0.053213    0.030524    0.688940    
#> 079: 0.753331    1.142489    3.549043    0.705523    0.050552    0.035087    0.707797    
#> 080: 0.792644    1.115687    3.569817    0.670247    0.048025    0.036825    0.698431    
#> 081: 0.726856    1.132405    3.548574    0.636735    0.045624    0.036023    0.682720    
#> 082: 0.714535    1.121369    3.547508    0.687220    0.043342    0.034222    0.691457    
#> 083: 0.814524    1.128229    3.546056    0.872234    0.042686    0.032511    0.693906    
#> 084: 0.757305    1.134313    3.537881    0.848585    0.041698    0.030885    0.682915    
#> 085: 0.715689    1.135998    3.553415    0.806156    0.048779    0.030258    0.691868    
#> 086: 0.779365    1.146691    3.535963    0.918815    0.046340    0.032650    0.686328    
#> 087: 0.733482    1.142371    3.528085    0.906294    0.046070    0.031017    0.672443    
#> 088: 0.654290    1.149085    3.531383    0.860979    0.051423    0.029467    0.680938    
#> 089: 0.669602    1.170943    3.513283    0.817930    0.055195    0.027993    0.678808    
#> 090: 0.648350    1.158793    3.514600    0.777034    0.061707    0.026594    0.706306    
#> 091: 0.652691    1.149797    3.504664    0.738182    0.058622    0.025264    0.700231    
#> 092: 0.620580    1.183929    3.500525    0.701273    0.055691    0.027461    0.682449    
#> 093: 0.613469    1.179033    3.498210    0.666209    0.053794    0.026088    0.698283    
#> 094: 0.660541    1.179837    3.504364    0.713667    0.051104    0.024784    0.684922    
#> 095: 0.679086    1.175407    3.505997    0.795405    0.048549    0.023544    0.678578    
#> 096: 0.657657    1.168705    3.509796    0.768193    0.046121    0.025930    0.682214    
#> 097: 0.706771    1.165514    3.505502    0.808130    0.048060    0.025581    0.681408    
#> 098: 0.688075    1.185767    3.515230    0.801095    0.047515    0.029001    0.696013    
#> 099: 0.639383    1.177094    3.494183    0.761040    0.045139    0.027551    0.693664    
#> 100: 0.690019    1.159034    3.514570    0.767441    0.044040    0.027156    0.679564    
#> 101: 0.693043    1.153568    3.504317    0.753294    0.042500    0.025798    0.693150    
#> 102: 0.693535    1.146044    3.507087    0.739581    0.055040    0.024508    0.690499    
#> 103: 0.693009    1.156002    3.516910    0.776643    0.052397    0.023283    0.684756    
#> 104: 0.673133    1.146649    3.531641    0.746183    0.053095    0.022119    0.698938    
#> 105: 0.704427    1.131717    3.532745    0.708874    0.057477    0.021013    0.693806    
#> 106: 0.695795    1.164420    3.525021    0.673430    0.062816    0.019962    0.694030    
#> 107: 0.740446    1.154337    3.535452    0.639758    0.059676    0.022751    0.696173    
#> 108: 0.709151    1.152369    3.524778    0.764347    0.057099    0.021614    0.689842    
#> 109: 0.697580    1.136826    3.540316    0.726130    0.054244    0.020533    0.694626    
#> 110: 0.693031    1.141891    3.529325    0.689823    0.056438    0.020364    0.683829    
#> 111: 0.694048    1.150809    3.530413    0.655332    0.055354    0.019346    0.675922    
#> 112: 0.689634    1.140851    3.518944    0.630320    0.056165    0.018379    0.682739    
#> 113: 0.695589    1.155119    3.519015    0.743199    0.053356    0.017460    0.680281    
#> 114: 0.691272    1.153087    3.522508    0.706039    0.053485    0.021143    0.675911    
#> 115: 0.707694    1.134433    3.520481    0.732016    0.064407    0.020086    0.686384    
#> 116: 0.705930    1.141397    3.526501    0.695415    0.069488    0.021674    0.697331    
#> 117: 0.662669    1.164769    3.524023    0.660644    0.073559    0.020590    0.687049    
#> 118: 0.681626    1.139664    3.529449    0.627612    0.069881    0.020161    0.677996    
#> 119: 0.721085    1.146184    3.535622    0.719497    0.066387    0.026309    0.675046    
#> 120: 0.685303    1.138699    3.537281    0.695054    0.063068    0.026124    0.675167    
#> 121: 0.683440    1.161364    3.529120    0.677711    0.059915    0.026157    0.669903    
#> 122: 0.696174    1.151307    3.535360    0.694660    0.056919    0.026270    0.670621    
#> 123: 0.724455    1.183204    3.523542    0.659927    0.055013    0.024956    0.675125    
#> 124: 0.707748    1.187688    3.524485    0.671911    0.054608    0.024774    0.690642    
#> 125: 0.686513    1.178620    3.505930    0.692152    0.051877    0.023535    0.691122    
#> 126: 0.660911    1.189708    3.505134    0.657544    0.055581    0.022359    0.702560    
#> 127: 0.670520    1.161297    3.516951    0.624667    0.054710    0.022211    0.701475    
#> 128: 0.694690    1.135465    3.542378    0.634365    0.053217    0.026053    0.686227    
#> 129: 0.755914    1.138991    3.549784    0.670494    0.051399    0.026028    0.694925    
#> 130: 0.778097    1.147689    3.542293    0.682501    0.048829    0.032687    0.688952    
#> 131: 0.731554    1.134080    3.525890    0.734813    0.046387    0.032522    0.684986    
#> 132: 0.675314    1.136354    3.503006    0.707014    0.049261    0.030896    0.679353    
#> 133: 0.670853    1.146469    3.521052    0.671664    0.051147    0.032609    0.680037    
#> 134: 0.737546    1.126954    3.539971    0.823665    0.048590    0.036998    0.692255    
#> 135: 0.740131    1.128238    3.538550    0.782482    0.046480    0.035148    0.679492    
#> 136: 0.766982    1.115165    3.544683    0.750190    0.044156    0.033391    0.691150    
#> 137: 0.781381    1.120414    3.552277    0.753446    0.041948    0.032780    0.702735    
#> 138: 0.714620    1.134413    3.542784    0.715773    0.047906    0.031141    0.703966    
#> 139: 0.700749    1.147248    3.548711    0.768027    0.045511    0.030273    0.702862    
#> 140: 0.708382    1.147353    3.544388    0.729626    0.043235    0.032444    0.715351    
#> 141: 0.681195    1.127108    3.537166    0.693145    0.046830    0.030822    0.699643    
#> 142: 0.730879    1.116859    3.553061    0.660275    0.058421    0.029281    0.689754    
#> 143: 0.690762    1.148276    3.535843    0.634896    0.055500    0.027817    0.691016    
#> 144: 0.712579    1.153071    3.542100    0.603151    0.058171    0.026426    0.676058    
#> 145: 0.699397    1.152848    3.521636    0.621829    0.065517    0.025105    0.671277    
#> 146: 0.678037    1.168606    3.526110    0.684988    0.062241    0.023850    0.680034    
#> 147: 0.630671    1.148458    3.505628    0.650738    0.059129    0.022657    0.679192    
#> 148: 0.656391    1.156998    3.526005    0.707989    0.057298    0.022412    0.665943    
#> 149: 0.692860    1.135405    3.532827    0.672589    0.056140    0.024121    0.683350    
#> 150: 0.693230    1.146394    3.514969    0.638960    0.067852    0.022915    0.687307    
#> 151: 0.617424    1.169837    3.509843    0.607012    0.064459    0.021769    0.684087    
#> 152: 0.626751    1.173266    3.514420    0.660447    0.055942    0.023688    0.674473    
#> 153: 0.665332    1.168139    3.541067    0.539006    0.061584    0.028798    0.703008    
#> 154: 0.712676    1.160404    3.544627    0.568974    0.044993    0.027726    0.690611    
#> 155: 0.701909    1.156604    3.532705    0.666920    0.062846    0.022289    0.676902    
#> 156: 0.696597    1.149289    3.537258    0.672081    0.063063    0.016307    0.694374    
#> 157: 0.720748    1.141746    3.535215    0.624052    0.072039    0.017143    0.703274    
#> 158: 0.741563    1.159205    3.532896    0.671340    0.064272    0.015448    0.673835    
#> 159: 0.679561    1.145357    3.544583    0.613923    0.058992    0.016564    0.688010    
#> 160: 0.687924    1.123893    3.544242    0.570304    0.054209    0.019405    0.700959    
#> 161: 0.693700    1.139763    3.534576    0.686102    0.049839    0.017389    0.703999    
#> 162: 0.698074    1.155713    3.526973    0.668464    0.049872    0.021808    0.683233    
#> 163: 0.715140    1.159426    3.518976    0.687207    0.050355    0.022793    0.682607    
#> 164: 0.717978    1.153507    3.535921    0.653302    0.046343    0.029264    0.695423    
#> 165: 0.747422    1.152678    3.538139    0.817821    0.057436    0.025069    0.675995    
#> 166: 0.792118    1.178425    3.538656    0.789044    0.063690    0.022970    0.704730    
#> 167: 0.763810    1.176225    3.544588    0.693174    0.061895    0.021871    0.703389    
#> 168: 0.748712    1.184367    3.533867    0.672430    0.060892    0.022098    0.686473    
#> 169: 0.697241    1.190876    3.522916    0.816863    0.074936    0.018298    0.688002    
#> 170: 0.682903    1.174376    3.525178    0.667079    0.064756    0.012997    0.690550    
#> 171: 0.688289    1.168935    3.523917    0.636701    0.063347    0.016107    0.673264    
#> 172: 0.679934    1.189946    3.523653    0.752343    0.066141    0.016751    0.670860    
#> 173: 0.661127    1.192333    3.513727    0.613819    0.071803    0.019158    0.661012    
#> 174: 0.685164    1.176332    3.524756    0.639355    0.072781    0.018448    0.682528    
#> 175: 0.721214    1.168275    3.516151    0.679107    0.083540    0.019207    0.685640    
#> 176: 0.702171    1.189634    3.534126    0.721268    0.071065    0.016930    0.687979    
#> 177: 0.745338    1.164860    3.547659    0.703522    0.067352    0.017618    0.681858    
#> 178: 0.767812    1.129737    3.553957    0.699637    0.065468    0.017504    0.701505    
#> 179: 0.787925    1.151198    3.550668    0.714389    0.065071    0.017046    0.695241    
#> 180: 0.728386    1.138410    3.549677    0.603958    0.067726    0.018998    0.695444    
#> 181: 0.727446    1.119040    3.532051    0.624949    0.060337    0.016038    0.690641    
#> 182: 0.712275    1.134823    3.528199    0.761834    0.068622    0.017770    0.721586    
#> 183: 0.713170    1.156270    3.533079    0.594072    0.072339    0.019133    0.703117    
#> 184: 0.707383    1.124109    3.534233    0.646402    0.068402    0.017078    0.702131    
#> 185: 0.677022    1.166995    3.531474    0.510080    0.073468    0.021673    0.694853    
#> 186: 0.669018    1.164419    3.527986    0.490452    0.059001    0.019405    0.710399    
#> 187: 0.656126    1.149564    3.537198    0.486099    0.067039    0.020049    0.696585    
#> 188: 0.638167    1.153864    3.536066    0.494889    0.069360    0.019963    0.692088    
#> 189: 0.674047    1.172773    3.550283    0.557951    0.073024    0.019655    0.697755    
#> 190: 0.733703    1.155201    3.551637    0.581612    0.060643    0.017568    0.693829    
#> 191: 0.722304    1.168001    3.531929    0.656331    0.054187    0.016481    0.687584    
#> 192: 0.671652    1.163121    3.531205    0.620811    0.062212    0.016553    0.700071    
#> 193: 0.736024    1.159757    3.539005    0.582727    0.058759    0.016315    0.695480    
#> 194: 0.687888    1.138257    3.533319    0.571723    0.065377    0.014736    0.701524    
#> 195: 0.664993    1.144470    3.527557    0.616357    0.059328    0.017274    0.694629    
#> 196: 0.679175    1.153642    3.536236    0.645362    0.054951    0.017316    0.712207    
#> 197: 0.663201    1.161527    3.551235    0.594150    0.047932    0.019973    0.710573    
#> 198: 0.690776    1.138576    3.540258    0.570454    0.053951    0.022314    0.685112    
#> 199: 0.687582    1.140160    3.540073    0.480983    0.054173    0.018304    0.689141    
#> 200: 0.670724    1.155862    3.532769    0.490307    0.067015    0.018674    0.686454    
#> 201: 0.656227    1.153701    3.534984    0.499144    0.062043    0.019828    0.684441    
#> 202: 0.650065    1.159705    3.528603    0.521436    0.056713    0.021790    0.684663    
#> 203: 0.666089    1.157030    3.526828    0.558618    0.056855    0.022701    0.685595    
#> 204: 0.672782    1.150684    3.528439    0.581501    0.055166    0.022684    0.687364    
#> 205: 0.670711    1.153990    3.527911    0.595496    0.055367    0.022736    0.688852    
#> 206: 0.672210    1.156984    3.529400    0.612560    0.055700    0.022099    0.691245    
#> 207: 0.676381    1.158048    3.528685    0.616567    0.056749    0.021874    0.690160    
#> 208: 0.676124    1.156598    3.528656    0.615675    0.055069    0.022193    0.688417    
#> 209: 0.677743    1.154770    3.528180    0.612268    0.055371    0.022374    0.688470    
#> 210: 0.678364    1.153244    3.528794    0.612362    0.054812    0.022279    0.687201    
#> 211: 0.682720    1.153186    3.529672    0.610468    0.054867    0.022241    0.687458    
#> 212: 0.685075    1.151991    3.530150    0.613808    0.055349    0.022309    0.686179    
#> 213: 0.688367    1.149617    3.530557    0.623612    0.055353    0.022236    0.685652    
#> 214: 0.690152    1.148800    3.531384    0.625523    0.055736    0.022164    0.685150    
#> 215: 0.688323    1.148399    3.531959    0.620655    0.055706    0.022033    0.685104    
#> 216: 0.691046    1.147093    3.532741    0.622649    0.055899    0.021650    0.686987    
#> 217: 0.692247    1.147493    3.532663    0.623019    0.056092    0.021278    0.686988    
#> 218: 0.691658    1.148270    3.531842    0.626971    0.055939    0.021063    0.686407    
#> 219: 0.688693    1.149226    3.530150    0.628710    0.055507    0.021126    0.686412    
#> 220: 0.685963    1.150205    3.529307    0.632479    0.055491    0.021222    0.685858    
#> 221: 0.682627    1.151102    3.528016    0.633433    0.054697    0.021138    0.686430    
#> 222: 0.680276    1.151818    3.526666    0.635738    0.054401    0.021045    0.686446    
#> 223: 0.680200    1.152503    3.525883    0.640632    0.054085    0.021178    0.685698    
#> 224: 0.681712    1.153339    3.525736    0.641045    0.054225    0.021214    0.685515    
#> 225: 0.680436    1.152639    3.526058    0.638884    0.054037    0.021217    0.686218    
#> 226: 0.679716    1.151446    3.525851    0.639940    0.053761    0.021210    0.686266    
#> 227: 0.680201    1.151310    3.525921    0.640837    0.053753    0.021088    0.685753    
#> 228: 0.679776    1.152095    3.525406    0.638889    0.053959    0.020995    0.685276    
#> 229: 0.678228    1.152220    3.525198    0.637783    0.054054    0.020910    0.685117    
#> 230: 0.679718    1.152200    3.525163    0.636334    0.054275    0.020710    0.685305    
#> 231: 0.680812    1.152376    3.525499    0.637741    0.054503    0.020581    0.685516    
#> 232: 0.681845    1.152173    3.525752    0.640189    0.054953    0.020429    0.685429    
#> 233: 0.681640    1.151489    3.525742    0.639919    0.055449    0.020282    0.685377    
#> 234: 0.681023    1.151441    3.525744    0.640428    0.055698    0.020224    0.684967    
#> 235: 0.681151    1.151216    3.525734    0.639323    0.055863    0.020047    0.684938    
#> 236: 0.680692    1.151600    3.525468    0.639524    0.056335    0.019904    0.685179    
#> 237: 0.681920    1.151628    3.525432    0.645375    0.056926    0.019762    0.685765    
#> 238: 0.684032    1.152093    3.525246    0.652406    0.057329    0.019626    0.686130    
#> 239: 0.684255    1.153288    3.524691    0.657107    0.057556    0.019631    0.686426    
#> 240: 0.686186    1.153611    3.524737    0.663673    0.057617    0.019586    0.686274    
#> 241: 0.687450    1.152927    3.524922    0.665298    0.057708    0.019522    0.686592    
#> 242: 0.687635    1.151938    3.524977    0.665072    0.058077    0.019527    0.687250    
#> 243: 0.687457    1.152195    3.524944    0.665917    0.058218    0.019548    0.687406    
#> 244: 0.687044    1.152349    3.525015    0.668619    0.058327    0.019614    0.687540    
#> 245: 0.687119    1.151474    3.525207    0.670061    0.058402    0.019708    0.687977    
#> 246: 0.686805    1.151290    3.525162    0.670864    0.058398    0.019751    0.688059    
#> 247: 0.686676    1.151306    3.524996    0.673886    0.058673    0.019740    0.687874    
#> 248: 0.686631    1.151779    3.524828    0.674998    0.058721    0.019778    0.687654    
#> 249: 0.686983    1.151680    3.524938    0.677692    0.058615    0.019849    0.687581    
#> 250: 0.688090    1.151634    3.525431    0.678345    0.058496    0.019955    0.687800    
#> 251: 0.688780    1.152039    3.525831    0.680627    0.058576    0.019957    0.688191    
#> 252: 0.689598    1.152236    3.526188    0.681279    0.058538    0.019979    0.688258    
#> 253: 0.689233    1.152588    3.526252    0.680387    0.058458    0.019987    0.688274    
#> 254: 0.689252    1.153437    3.526277    0.680412    0.058512    0.019987    0.688070    
#> 255: 0.688668    1.154043    3.526140    0.679092    0.058603    0.020020    0.687993    
#> 256: 0.688260    1.154147    3.526060    0.678461    0.058754    0.020008    0.688134    
#> 257: 0.687781    1.153819    3.525916    0.678880    0.058717    0.019933    0.688553    
#> 258: 0.687436    1.153289    3.525927    0.678209    0.058751    0.019953    0.688757    
#> 259: 0.687833    1.153185    3.525864    0.680119    0.058851    0.019975    0.689180    
#> 260: 0.687970    1.153413    3.525879    0.681150    0.058890    0.019978    0.689148    
#> 261: 0.687825    1.153496    3.526002    0.679919    0.059035    0.020029    0.689017    
#> 262: 0.688750    1.153863    3.526148    0.680738    0.059201    0.020035    0.688883    
#> 263: 0.688207    1.154236    3.526247    0.679496    0.059209    0.020121    0.689107    
#> 264: 0.686959    1.154618    3.525953    0.678484    0.059355    0.020097    0.689525    
#> 265: 0.686915    1.154760    3.525840    0.678236    0.059648    0.020082    0.689668    
#> 266: 0.686846    1.154984    3.525933    0.677431    0.059805    0.020052    0.689700    
#> 267: 0.686748    1.154919    3.526237    0.676723    0.059931    0.020038    0.689838    
#> 268: 0.686724    1.154790    3.526218    0.677340    0.059665    0.019986    0.689823    
#> 269: 0.687586    1.154578    3.526328    0.679886    0.059517    0.019982    0.689594    
#> 270: 0.687764    1.154635    3.526253    0.681616    0.059431    0.019935    0.689150    
#> 271: 0.687907    1.154873    3.526103    0.681661    0.059345    0.019936    0.689182    
#> 272: 0.687930    1.154882    3.525989    0.682620    0.059281    0.019914    0.689575    
#> 273: 0.687953    1.155281    3.525873    0.684231    0.059438    0.019870    0.689880    
#> 274: 0.687743    1.155591    3.525901    0.681864    0.059491    0.019837    0.689752    
#> 275: 0.687602    1.155800    3.525848    0.680887    0.059516    0.019797    0.689533    
#> 276: 0.686765    1.156306    3.525934    0.679052    0.059664    0.019818    0.689465    
#> 277: 0.686409    1.156678    3.526005    0.678955    0.059814    0.019841    0.689536    
#> 278: 0.686014    1.156758    3.526005    0.678941    0.059831    0.019827    0.689535    
#> 279: 0.686504    1.156589    3.526017    0.680652    0.059819    0.019851    0.689667    
#> 280: 0.686587    1.156747    3.525934    0.680535    0.059851    0.019860    0.689583    
#> 281: 0.685969    1.157087    3.525930    0.680092    0.059898    0.019853    0.689672    
#> 282: 0.685451    1.157270    3.525863    0.678998    0.059941    0.019797    0.689789    
#> 283: 0.685097    1.157418    3.525767    0.678889    0.059920    0.019765    0.690281    
#> 284: 0.684732    1.157120    3.525629    0.678609    0.059933    0.019756    0.690364    
#> 285: 0.684524    1.157270    3.525306    0.679292    0.059925    0.019707    0.690379    
#> 286: 0.684291    1.157516    3.524973    0.680166    0.060022    0.019662    0.690526    
#> 287: 0.683813    1.157949    3.524669    0.680447    0.060130    0.019633    0.690530    
#> 288: 0.683791    1.158241    3.524390    0.680660    0.060199    0.019608    0.690651    
#> 289: 0.684192    1.158345    3.524379    0.680865    0.060215    0.019558    0.690659    
#> 290: 0.684393    1.158352    3.524396    0.680708    0.060308    0.019517    0.690845    
#> 291: 0.684483    1.158549    3.524462    0.680549    0.060418    0.019492    0.690731    
#> 292: 0.684897    1.158540    3.524405    0.682433    0.060363    0.019480    0.690670    
#> 293: 0.684927    1.158597    3.524342    0.684262    0.060374    0.019483    0.690646    
#> 294: 0.684446    1.158714    3.524203    0.684081    0.060354    0.019472    0.690716    
#> 295: 0.684098    1.158739    3.523955    0.686172    0.060354    0.019449    0.690693    
#> 296: 0.683779    1.158684    3.523895    0.686162    0.060451    0.019442    0.690876    
#> 297: 0.684125    1.158720    3.523892    0.687658    0.060470    0.019454    0.690868    
#> 298: 0.684458    1.158572    3.523916    0.688900    0.060408    0.019443    0.690805    
#> 299: 0.684734    1.158636    3.523861    0.690301    0.060366    0.019428    0.690754    
#> 300: 0.684831    1.158440    3.523976    0.690012    0.060382    0.019388    0.690756    
#> 301: 0.684825    1.158284    3.523976    0.689311    0.060296    0.019418    0.690563    
#> 302: 0.684939    1.158334    3.524008    0.689494    0.060254    0.019404    0.690517    
#> 303: 0.685062    1.158552    3.524016    0.688954    0.060268    0.019418    0.690348    
#> 304: 0.685135    1.158811    3.523919    0.688738    0.060278    0.019478    0.690288    
#> 305: 0.684586    1.158673    3.523877    0.687746    0.060223    0.019515    0.690158    
#> 306: 0.684413    1.158624    3.523787    0.687422    0.060191    0.019545    0.690069    
#> 307: 0.683897    1.158534    3.523696    0.686511    0.060196    0.019556    0.690166    
#> 308: 0.683753    1.158497    3.523654    0.686865    0.060234    0.019556    0.690166    
#> 309: 0.683938    1.158301    3.523727    0.687184    0.060286    0.019568    0.690113    
#> 310: 0.683866    1.158233    3.523668    0.686773    0.060290    0.019547    0.690053    
#> 311: 0.683739    1.158101    3.523710    0.685441    0.060353    0.019541    0.690044    
#> 312: 0.683578    1.157913    3.523703    0.684465    0.060338    0.019507    0.690157    
#> 313: 0.683149    1.157560    3.523644    0.683461    0.060240    0.019500    0.690436    
#> 314: 0.682887    1.157554    3.523631    0.683090    0.060147    0.019525    0.690515    
#> 315: 0.683314    1.157661    3.523721    0.683128    0.060140    0.019554    0.690539    
#> 316: 0.683559    1.157702    3.523710    0.682697    0.060048    0.019592    0.690538    
#> 317: 0.684231    1.157521    3.523890    0.683277    0.059931    0.019629    0.690452    
#> 318: 0.684747    1.157475    3.523927    0.683465    0.059899    0.019643    0.690253    
#> 319: 0.685250    1.157383    3.524014    0.684449    0.059828    0.019672    0.690255    
#> 320: 0.684586    1.157262    3.523913    0.683184    0.059752    0.019701    0.690359    
#> 321: 0.684113    1.157424    3.523757    0.681942    0.059604    0.019707    0.690593    
#> 322: 0.683981    1.157475    3.523631    0.681713    0.059458    0.019725    0.690705    
#> 323: 0.683446    1.157447    3.523517    0.681588    0.059374    0.019754    0.690804    
#> 324: 0.683322    1.157522    3.523513    0.682061    0.059452    0.019746    0.690775    
#> 325: 0.683735    1.157647    3.523529    0.682619    0.059473    0.019715    0.690788    
#> 326: 0.684364    1.157510    3.523559    0.683834    0.059542    0.019710    0.690804    
#> 327: 0.685227    1.157515    3.523723    0.684929    0.059688    0.019700    0.690708    
#> 328: 0.686014    1.157512    3.523845    0.685860    0.059678    0.019696    0.690505    
#> 329: 0.686372    1.157547    3.523905    0.686197    0.059715    0.019699    0.690440    
#> 330: 0.686682    1.157424    3.523969    0.686843    0.059705    0.019697    0.690306    
#> 331: 0.687293    1.157559    3.524033    0.688670    0.059718    0.019692    0.690160    
#> 332: 0.687817    1.157465    3.524125    0.689061    0.059703    0.019682    0.690168    
#> 333: 0.687929    1.157501    3.524108    0.689631    0.059689    0.019647    0.690269    
#> 334: 0.688069    1.157498    3.524031    0.690710    0.059671    0.019636    0.690245    
#> 335: 0.688180    1.157478    3.524005    0.690974    0.059682    0.019628    0.690223    
#> 336: 0.687972    1.157543    3.523939    0.691224    0.059793    0.019646    0.690252    
#> 337: 0.688007    1.157845    3.523878    0.691693    0.059848    0.019662    0.690288    
#> 338: 0.688283    1.157978    3.523897    0.692932    0.059893    0.019640    0.690294    
#> 339: 0.688187    1.158155    3.523829    0.693656    0.059913    0.019624    0.690295    
#> 340: 0.688179    1.158069    3.523768    0.693402    0.059951    0.019614    0.690311    
#> 341: 0.688266    1.157995    3.523733    0.693376    0.060035    0.019626    0.690394    
#> 342: 0.687681    1.157843    3.523674    0.692581    0.060084    0.019616    0.690472    
#> 343: 0.687079    1.157861    3.523589    0.691874    0.060140    0.019619    0.690622    
#> 344: 0.686842    1.157773    3.523529    0.691606    0.060230    0.019634    0.690678    
#> 345: 0.686650    1.157688    3.523459    0.692216    0.060196    0.019624    0.690642    
#> 346: 0.686648    1.157882    3.523316    0.692915    0.060237    0.019612    0.690482    
#> 347: 0.686531    1.157807    3.523185    0.693297    0.060121    0.019635    0.690489    
#> 348: 0.686470    1.157899    3.523082    0.693761    0.060110    0.019669    0.690403    
#> 349: 0.686302    1.157914    3.523073    0.694337    0.060055    0.019697    0.690345    
#> 350: 0.685865    1.157999    3.522979    0.694051    0.060032    0.019699    0.690295    
#> 351: 0.685694    1.158271    3.522796    0.694299    0.060007    0.019684    0.690296    
#> 352: 0.685262    1.158556    3.522727    0.693977    0.059999    0.019724    0.690321    
#> 353: 0.685087    1.158785    3.522607    0.693899    0.059890    0.019771    0.690272    
#> 354: 0.685021    1.158917    3.522440    0.694283    0.059776    0.019802    0.690169    
#> 355: 0.685231    1.158944    3.522307    0.694146    0.059742    0.019853    0.690108    
#> 356: 0.685078    1.158968    3.522313    0.693273    0.059777    0.019884    0.690192    
#> 357: 0.685278    1.159090    3.522330    0.693302    0.059773    0.019898    0.690056    
#> 358: 0.685185    1.159185    3.522366    0.693722    0.059844    0.019899    0.690058    
#> 359: 0.685136    1.159333    3.522363    0.693550    0.059943    0.019895    0.689940    
#> 360: 0.685071    1.159372    3.522287    0.693027    0.059915    0.019882    0.689869    
#> 361: 0.684881    1.159332    3.522262    0.692496    0.059892    0.019880    0.689744    
#> 362: 0.684848    1.159289    3.522178    0.692666    0.059874    0.019891    0.689607    
#> 363: 0.684819    1.159293    3.522140    0.692921    0.059854    0.019896    0.689459    
#> 364: 0.684932    1.159360    3.522048    0.693189    0.059833    0.019929    0.689465    
#> 365: 0.684707    1.159399    3.521991    0.693357    0.059860    0.019958    0.689511    
#> 366: 0.684578    1.159601    3.521830    0.694094    0.059852    0.019973    0.689578    
#> 367: 0.684707    1.159711    3.521771    0.694939    0.059900    0.019969    0.689544    
#> 368: 0.684728    1.159754    3.521748    0.694734    0.059813    0.019983    0.689479    
#> 369: 0.684767    1.159721    3.521735    0.694899    0.059804    0.019962    0.689486    
#> 370: 0.684555    1.159872    3.521719    0.694535    0.059863    0.019982    0.689479    
#> 371: 0.684227    1.159920    3.521643    0.694290    0.059901    0.019974    0.689401    
#> 372: 0.683834    1.160015    3.521535    0.694342    0.059998    0.019955    0.689371    
#> 373: 0.683439    1.160127    3.521463    0.693864    0.060008    0.019964    0.689431    
#> 374: 0.683356    1.160132    3.521442    0.693839    0.060004    0.019976    0.689408    
#> 375: 0.683426    1.160140    3.521442    0.694128    0.060017    0.019991    0.689340    
#> 376: 0.683468    1.160171    3.521451    0.693641    0.060049    0.019997    0.689227    
#> 377: 0.683342    1.160292    3.521447    0.692825    0.060116    0.020008    0.689239    
#> 378: 0.683319    1.160250    3.521462    0.692600    0.060069    0.020021    0.689242    
#> 379: 0.683216    1.160056    3.521524    0.692154    0.060026    0.020013    0.689275    
#> 380: 0.683139    1.159941    3.521551    0.691364    0.059987    0.020036    0.689317    
#> 381: 0.682749    1.159985    3.521480    0.691062    0.059993    0.020048    0.689347    
#> 382: 0.682587    1.159990    3.521525    0.690734    0.059909    0.020080    0.689322    
#> 383: 0.682799    1.159973    3.521533    0.691292    0.059863    0.020105    0.689239    
#> 384: 0.682736    1.159954    3.521504    0.691937    0.059859    0.020154    0.689137    
#> 385: 0.682509    1.160043    3.521481    0.692190    0.059813    0.020181    0.689043    
#> 386: 0.682638    1.160233    3.521547    0.692130    0.059737    0.020201    0.689033    
#> 387: 0.682553    1.160373    3.521608    0.691912    0.059659    0.020231    0.688970    
#> 388: 0.682612    1.160452    3.521627    0.691856    0.059655    0.020243    0.688865    
#> 389: 0.682343    1.160299    3.521580    0.691367    0.059613    0.020274    0.688875    
#> 390: 0.682045    1.160366    3.521506    0.690970    0.059622    0.020287    0.688878    
#> 391: 0.682202    1.160344    3.521516    0.691069    0.059598    0.020296    0.688775    
#> 392: 0.682397    1.160357    3.521576    0.691225    0.059568    0.020302    0.688809    
#> 393: 0.682294    1.160249    3.521527    0.690844    0.059565    0.020299    0.688785    
#> 394: 0.682360    1.160249    3.521488    0.690728    0.059520    0.020300    0.688750    
#> 395: 0.682609    1.160367    3.521478    0.691408    0.059477    0.020310    0.688691    
#> 396: 0.682738    1.160452    3.521464    0.691958    0.059451    0.020313    0.688563    
#> 397: 0.682810    1.160491    3.521480    0.692485    0.059407    0.020332    0.688525    
#> 398: 0.683161    1.160457    3.521524    0.693357    0.059338    0.020354    0.688461    
#> 399: 0.683295    1.160371    3.521654    0.693317    0.059267    0.020376    0.688434    
#> 400: 0.683720    1.160265    3.521816    0.693092    0.059234    0.020414    0.688470    
#> 401: 0.683886    1.160314    3.521886    0.692695    0.059256    0.020446    0.688522    
#> 402: 0.684111    1.160357    3.521947    0.692177    0.059252    0.020465    0.688516    
#> 403: 0.684595    1.160364    3.521992    0.692687    0.059294    0.020459    0.688528    
#> 404: 0.684594    1.160441    3.521964    0.692603    0.059276    0.020478    0.688497    
#> 405: 0.684402    1.160464    3.521986    0.692544    0.059189    0.020499    0.688440    
#> 406: 0.684418    1.160506    3.521962    0.692280    0.059089    0.020521    0.688455    
#> 407: 0.684491    1.160561    3.522013    0.692619    0.059001    0.020541    0.688395    
#> 408: 0.684654    1.160685    3.522052    0.692177    0.059023    0.020546    0.688382    
#> 409: 0.684757    1.160708    3.522084    0.691834    0.058976    0.020569    0.688286    
#> 410: 0.684779    1.160712    3.522082    0.691690    0.058907    0.020588    0.688338    
#> 411: 0.684811    1.160556    3.522106    0.691536    0.058844    0.020591    0.688339    
#> 412: 0.684841    1.160532    3.522122    0.691189    0.058764    0.020599    0.688326    
#> 413: 0.684956    1.160562    3.522100    0.691500    0.058692    0.020630    0.688255    
#> 414: 0.684837    1.160584    3.522143    0.691061    0.058622    0.020644    0.688227    
#> 415: 0.685153    1.160467    3.522234    0.690888    0.058595    0.020698    0.688219    
#> 416: 0.685353    1.160466    3.522304    0.690478    0.058539    0.020729    0.688158    
#> 417: 0.685301    1.160319    3.522326    0.689758    0.058493    0.020738    0.688190    
#> 418: 0.685206    1.160204    3.522399    0.689242    0.058504    0.020754    0.688225    
#> 419: 0.685378    1.160207    3.522448    0.689114    0.058514    0.020762    0.688241    
#> 420: 0.685838    1.160196    3.522505    0.689677    0.058567    0.020761    0.688211    
#> 421: 0.686073    1.160160    3.522608    0.689740    0.058571    0.020763    0.688225    
#> 422: 0.686414    1.160043    3.522669    0.690194    0.058575    0.020761    0.688222    
#> 423: 0.686540    1.159972    3.522695    0.690287    0.058615    0.020750    0.688184    
#> 424: 0.686545    1.159970    3.522660    0.690324    0.058610    0.020737    0.688168    
#> 425: 0.686544    1.160042    3.522599    0.690293    0.058597    0.020733    0.688187    
#> 426: 0.686741    1.160164    3.522589    0.691061    0.058642    0.020737    0.688155    
#> 427: 0.686746    1.160165    3.522616    0.691148    0.058655    0.020747    0.688100    
#> 428: 0.686790    1.160246    3.522627    0.691672    0.058629    0.020763    0.688105    
#> 429: 0.686770    1.160335    3.522614    0.691801    0.058617    0.020775    0.688153    
#> 430: 0.686635    1.160387    3.522600    0.691425    0.058600    0.020780    0.688142    
#> 431: 0.686595    1.160362    3.522572    0.691284    0.058627    0.020754    0.688087    
#> 432: 0.686675    1.160451    3.522583    0.691565    0.058638    0.020746    0.688044    
#> 433: 0.686785    1.160531    3.522639    0.692019    0.058627    0.020750    0.688018    
#> 434: 0.686680    1.160464    3.522624    0.692130    0.058599    0.020754    0.687985    
#> 435: 0.686842    1.160399    3.522641    0.692173    0.058575    0.020773    0.687913    
#> 436: 0.686773    1.160330    3.522680    0.691889    0.058618    0.020767    0.687945    
#> 437: 0.686821    1.160224    3.522682    0.691980    0.058625    0.020745    0.688026    
#> 438: 0.686871    1.160340    3.522692    0.692125    0.058633    0.020726    0.688022    
#> 439: 0.687074    1.160390    3.522722    0.692345    0.058640    0.020721    0.687952    
#> 440: 0.687129    1.160489    3.522821    0.691825    0.058595    0.020743    0.687945    
#> 441: 0.687186    1.160388    3.522923    0.691149    0.058582    0.020762    0.687900    
#> 442: 0.687184    1.160383    3.522976    0.690603    0.058531    0.020782    0.687791    
#> 443: 0.687231    1.160413    3.522941    0.690554    0.058532    0.020772    0.687778    
#> 444: 0.687204    1.160400    3.522936    0.690316    0.058522    0.020762    0.687779    
#> 445: 0.687199    1.160467    3.522913    0.690101    0.058509    0.020763    0.687835    
#> 446: 0.687114    1.160573    3.522833    0.690145    0.058523    0.020747    0.687850    
#> 447: 0.687205    1.160669    3.522823    0.690062    0.058567    0.020748    0.687829    
#> 448: 0.687215    1.160765    3.522842    0.690171    0.058555    0.020765    0.687830    
#> 449: 0.687303    1.160792    3.522928    0.689863    0.058544    0.020806    0.687792    
#> 450: 0.687357    1.160776    3.522969    0.689607    0.058513    0.020829    0.687785    
#> 451: 0.687464    1.160759    3.522987    0.689500    0.058488    0.020843    0.687831    
#> 452: 0.687422    1.160756    3.523011    0.689146    0.058436    0.020843    0.687793    
#> 453: 0.687324    1.160809    3.523014    0.688789    0.058427    0.020846    0.687778    
#> 454: 0.687367    1.160995    3.522954    0.689322    0.058430    0.020842    0.687760    
#> 455: 0.687501    1.161068    3.522926    0.689897    0.058447    0.020840    0.687715    
#> 456: 0.687456    1.161073    3.522936    0.689842    0.058421    0.020839    0.687705    
#> 457: 0.687484    1.161030    3.522984    0.689846    0.058424    0.020841    0.687679    
#> 458: 0.687491    1.161097    3.523049    0.689874    0.058438    0.020850    0.687675    
#> 459: 0.687393    1.161176    3.523067    0.689360    0.058457    0.020844    0.687703    
#> 460: 0.687349    1.161116    3.523072    0.689168    0.058441    0.020855    0.687672    
#> 461: 0.687513    1.161067    3.523123    0.689419    0.058474    0.020850    0.687610    
#> 462: 0.687521    1.161057    3.523169    0.689715    0.058492    0.020843    0.687559    
#> 463: 0.687662    1.161121    3.523172    0.690077    0.058483    0.020823    0.687533    
#> 464: 0.687672    1.161108    3.523165    0.690313    0.058469    0.020817    0.687487    
#> 465: 0.687706    1.160972    3.523187    0.690203    0.058481    0.020793    0.687483    
#> 466: 0.687818    1.160999    3.523201    0.690017    0.058470    0.020781    0.687469    
#> 467: 0.687840    1.160952    3.523281    0.689965    0.058455    0.020767    0.687386    
#> 468: 0.688160    1.160886    3.523415    0.689960    0.058426    0.020775    0.687372    
#> 469: 0.688258    1.160924    3.523539    0.689728    0.058410    0.020796    0.687332    
#> 470: 0.688110    1.160934    3.523539    0.689495    0.058381    0.020823    0.687318    
#> 471: 0.687971    1.160922    3.523550    0.688939    0.058375    0.020827    0.687302    
#> 472: 0.687824    1.160904    3.523578    0.688332    0.058351    0.020836    0.687282    
#> 473: 0.687646    1.160893    3.523541    0.687978    0.058323    0.020830    0.687257    
#> 474: 0.687490    1.160873    3.523489    0.687802    0.058304    0.020831    0.687274    
#> 475: 0.687353    1.161021    3.523456    0.687714    0.058318    0.020832    0.687291    
#> 476: 0.687301    1.161067    3.523391    0.688025    0.058326    0.020829    0.687283    
#> 477: 0.687260    1.161108    3.523379    0.688021    0.058339    0.020839    0.687190    
#> 478: 0.687154    1.161149    3.523371    0.688137    0.058325    0.020857    0.687199    
#> 479: 0.687206    1.161228    3.523369    0.688541    0.058369    0.020882    0.687190    
#> 480: 0.687202    1.161321    3.523312    0.688957    0.058410    0.020900    0.687233    
#> 481: 0.687149    1.161296    3.523276    0.689355    0.058378    0.020924    0.687286    
#> 482: 0.687135    1.161308    3.523191    0.689558    0.058323    0.020933    0.687320    
#> 483: 0.687007    1.161334    3.523157    0.689582    0.058321    0.020930    0.687300    
#> 484: 0.687024    1.161296    3.523144    0.689752    0.058309    0.020937    0.687253    
#> 485: 0.687220    1.161283    3.523155    0.690839    0.058285    0.020951    0.687278    
#> 486: 0.687352    1.161284    3.523170    0.691438    0.058261    0.020954    0.687298    
#> 487: 0.687692    1.161301    3.523262    0.691959    0.058285    0.020971    0.687271    
#> 488: 0.687913    1.161150    3.523336    0.691993    0.058275    0.020970    0.687288    
#> 489: 0.688144    1.161081    3.523389    0.691930    0.058260    0.020988    0.687273    
#> 490: 0.688227    1.161057    3.523466    0.691672    0.058256    0.021011    0.687236    
#> 491: 0.688378    1.161051    3.523533    0.691605    0.058235    0.021005    0.687180    
#> 492: 0.688406    1.161099    3.523513    0.691810    0.058209    0.020995    0.687250    
#> 493: 0.688336    1.161096    3.523541    0.691746    0.058193    0.021004    0.687288    
#> 494: 0.688447    1.161106    3.523547    0.691434    0.058150    0.021011    0.687255    
#> 495: 0.688625    1.161167    3.523564    0.691572    0.058126    0.021015    0.687267    
#> 496: 0.688713    1.161186    3.523564    0.691321    0.058087    0.021021    0.687362    
#> 497: 0.688572    1.161173    3.523553    0.691102    0.058048    0.021014    0.687440    
#> 498: 0.688440    1.161091    3.523515    0.690713    0.058041    0.021006    0.687431    
#> 499: 0.688348    1.161085    3.523490    0.690540    0.058019    0.021003    0.687416    
#> 500: 0.688347    1.161058    3.523473    0.690307    0.058032    0.021003    0.687358    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.250230    0.989426    3.448790    0.392401    0.095371    0.016800    1.478150    
#> 002: 0.263019    0.980616    3.484583    0.372781    0.090603    0.015960    1.083718    
#> 003: 0.268898    0.984716    3.475003    0.354142    0.093241    0.015162    0.969899    
#> 004: 0.252498    1.025124    3.467524    0.336435    0.092124    0.014404    0.870534    
#> 005: 0.301068    1.031614    3.459460    0.319613    0.110244    0.013684    0.835328    
#> 006: 0.324615    1.015726    3.456245    0.303633    0.104732    0.016225    0.807929    
#> 007: 0.274295    1.049927    3.448729    0.305968    0.099495    0.019622    0.794960    
#> 008: 0.282285    1.065589    3.445047    0.290670    0.100569    0.018641    0.791474    
#> 009: 0.248551    1.037758    3.433491    0.276881    0.095540    0.019664    0.789776    
#> 010: 0.278762    1.048310    3.434103    0.289264    0.093679    0.018680    0.800071    
#> 011: 0.320845    1.047631    3.450315    0.299631    0.089550    0.021071    0.828156    
#> 012: 0.327228    1.044585    3.440451    0.301074    0.085073    0.020017    0.783982    
#> 013: 0.266509    1.052345    3.439128    0.331469    0.080819    0.019469    0.787232    
#> 014: 0.304916    1.068403    3.446208    0.363711    0.083709    0.018921    0.782982    
#> 015: 0.317270    1.064685    3.460795    0.345526    0.079523    0.021859    0.774807    
#> 016: 0.296622    1.060180    3.462240    0.328250    0.075547    0.020766    0.793961    
#> 017: 0.305642    1.050254    3.463888    0.329011    0.071770    0.021576    0.780712    
#> 018: 0.315706    1.038501    3.445961    0.312561    0.068181    0.021590    0.774548    
#> 019: 0.267051    1.066659    3.431911    0.333333    0.071030    0.022356    0.760109    
#> 020: 0.294995    1.068296    3.444730    0.392488    0.079328    0.027155    0.773856    
#> 021: 0.356904    1.043795    3.469305    0.372863    0.077071    0.026441    0.772286    
#> 022: 0.337790    1.031136    3.481075    0.354220    0.077192    0.029525    0.769086    
#> 023: 0.400760    1.055366    3.477326    0.336509    0.073332    0.028049    0.823229    
#> 024: 0.398104    1.059096    3.473324    0.319684    0.069666    0.026646    0.826291    
#> 025: 0.352508    1.031559    3.472699    0.303699    0.066183    0.028810    0.787166    
#> 026: 0.324005    1.076939    3.453284    0.325990    0.068282    0.031212    0.779561    
#> 027: 0.285162    1.091093    3.440573    0.323222    0.064868    0.029652    0.788040    
#> 028: 0.261681    1.086212    3.438864    0.335371    0.061625    0.031851    0.759365    
#> 029: 0.288584    1.089590    3.420104    0.344664    0.062890    0.030258    0.791562    
#> 030: 0.315177    1.105710    3.434894    0.327431    0.085159    0.033116    0.776486    
#> 031: 0.291342    1.083278    3.445329    0.348746    0.085360    0.031460    0.774798    
#> 032: 0.291374    1.068015    3.446985    0.362365    0.081092    0.033587    0.763459    
#> 033: 0.263321    1.077670    3.437179    0.344766    0.077038    0.033349    0.770528    
#> 034: 0.297661    1.072155    3.459261    0.327528    0.073186    0.031682    0.777304    
#> 035: 0.308658    1.070171    3.447886    0.337331    0.069526    0.030098    0.751399    
#> 036: 0.292649    1.093120    3.444808    0.350846    0.066050    0.030601    0.761269    
#> 037: 0.286164    1.085671    3.444465    0.333303    0.072461    0.029071    0.759446    
#> 038: 0.309591    1.064844    3.445151    0.316638    0.068838    0.030860    0.761141    
#> 039: 0.298704    1.053494    3.457063    0.333794    0.065396    0.034096    0.763470    
#> 040: 0.321603    1.042950    3.472440    0.374056    0.062126    0.040954    0.793962    
#> 041: 0.289076    1.040777    3.464878    0.355354    0.059020    0.038907    0.775562    
#> 042: 0.310733    1.035449    3.456556    0.337586    0.056593    0.036961    0.766230    
#> 043: 0.294544    1.049317    3.444506    0.404694    0.059684    0.035113    0.766965    
#> 044: 0.280690    1.068625    3.439267    0.384460    0.066435    0.033358    0.784287    
#> 045: 0.285034    1.092976    3.440288    0.365237    0.063113    0.035021    0.779594    
#> 046: 0.279816    1.075930    3.441878    0.346975    0.065015    0.033270    0.761792    
#> 047: 0.293928    1.076606    3.440691    0.348728    0.061764    0.031606    0.759016    
#> 048: 0.305114    1.050581    3.454100    0.331292    0.060320    0.032160    0.767554    
#> 049: 0.303510    1.051132    3.462140    0.381528    0.059791    0.030552    0.771334    
#> 050: 0.358326    1.037972    3.459700    0.436756    0.056801    0.029024    0.790073    
#> 051: 0.316068    1.053541    3.459647    0.414918    0.053961    0.032497    0.767077    
#> 052: 0.337345    1.063416    3.473129    0.394172    0.051263    0.037147    0.776925    
#> 053: 0.335306    1.047483    3.471680    0.374464    0.056632    0.043735    0.766716    
#> 054: 0.324656    1.030118    3.481296    0.355741    0.053800    0.045205    0.788741    
#> 055: 0.332022    1.031425    3.482630    0.337954    0.051110    0.043103    0.777596    
#> 056: 0.356835    1.017567    3.481632    0.353337    0.062148    0.040947    0.785018    
#> 057: 0.352464    1.035682    3.485885    0.376991    0.059041    0.038900    0.799257    
#> 058: 0.365791    1.035609    3.478911    0.375913    0.056089    0.036955    0.768374    
#> 059: 0.372826    1.008351    3.478746    0.386562    0.056663    0.039962    0.782849    
#> 060: 0.350714    0.999393    3.478754    0.368809    0.056618    0.039851    0.784068    
#> 061: 0.351145    1.004108    3.490060    0.350368    0.053787    0.045089    0.798387    
#> 062: 0.362857    1.017036    3.500091    0.389057    0.051098    0.049028    0.782829    
#> 063: 0.403351    1.010060    3.486103    0.421898    0.048543    0.046577    0.777923    
#> 064: 0.380272    1.011495    3.484807    0.400803    0.046116    0.044248    0.767744    
#> 065: 0.362338    1.010175    3.470961    0.380763    0.043810    0.042035    0.767808    
#> 066: 0.349245    1.039036    3.475775    0.361725    0.041620    0.040913    0.759937    
#> 067: 0.335589    1.027331    3.468923    0.343638    0.045273    0.038867    0.771520    
#> 068: 0.287666    1.031985    3.479066    0.339946    0.043010    0.045325    0.770549    
#> 069: 0.290062    1.044478    3.445251    0.385319    0.040859    0.045393    0.778549    
#> 070: 0.328878    1.056295    3.460935    0.396195    0.038816    0.048461    0.765312    
#> 071: 0.300115    1.090108    3.437842    0.376385    0.036875    0.049710    0.803113    
#> 072: 0.265533    1.066101    3.444053    0.357566    0.035032    0.053021    0.795411    
#> 073: 0.324254    1.041166    3.479180    0.339688    0.033799    0.053163    0.791891    
#> 074: 0.255069    1.041308    3.465106    0.322703    0.041305    0.050505    0.786671    
#> 075: 0.329765    1.018310    3.496110    0.307194    0.049186    0.048793    0.778457    
#> 076: 0.328055    1.048035    3.486724    0.291834    0.053499    0.046353    0.770638    
#> 077: 0.381598    1.013307    3.491154    0.294481    0.064952    0.044036    0.784214    
#> 078: 0.381185    1.003700    3.497352    0.279756    0.061704    0.044606    0.772613    
#> 079: 0.383281    1.016952    3.494256    0.265769    0.058619    0.045017    0.800138    
#> 080: 0.403137    1.015072    3.509889    0.272422    0.055688    0.042767    0.805558    
#> 081: 0.393895    1.008023    3.510442    0.286186    0.052904    0.044716    0.789420    
#> 082: 0.341118    0.993122    3.498559    0.271877    0.050258    0.045183    0.790796    
#> 083: 0.336954    1.023755    3.490207    0.258283    0.048014    0.045612    0.779056    
#> 084: 0.354869    1.014831    3.491583    0.256222    0.051568    0.043331    0.786367    
#> 085: 0.372471    1.034733    3.503867    0.272509    0.058147    0.041165    0.776024    
#> 086: 0.324854    1.039569    3.484025    0.258884    0.061266    0.039107    0.767612    
#> 087: 0.308892    1.030494    3.469864    0.280208    0.060558    0.037151    0.780841    
#> 088: 0.232483    1.035406    3.464711    0.314525    0.059493    0.035294    0.790510    
#> 089: 0.316172    1.075647    3.456202    0.298799    0.063564    0.033529    0.761421    
#> 090: 0.284062    1.073114    3.453352    0.309010    0.066668    0.031853    0.765031    
#> 091: 0.285647    1.057631    3.437442    0.293559    0.073147    0.030260    0.777925    
#> 092: 0.300162    1.072225    3.435690    0.331501    0.082825    0.028747    0.786064    
#> 093: 0.257193    1.066583    3.440555    0.314926    0.078684    0.030620    0.776655    
#> 094: 0.249628    1.075077    3.434967    0.318737    0.074750    0.029089    0.784172    
#> 095: 0.256134    1.072592    3.441484    0.308563    0.071012    0.027634    0.755306    
#> 096: 0.219999    1.079175    3.439086    0.293135    0.084651    0.027422    0.763557    
#> 097: 0.271631    1.094055    3.438149    0.309850    0.080419    0.032136    0.756620    
#> 098: 0.269108    1.099181    3.452502    0.294358    0.076398    0.034471    0.767636    
#> 099: 0.276569    1.076780    3.431844    0.319070    0.073159    0.035246    0.759309    
#> 100: 0.299625    1.075206    3.446575    0.372752    0.069501    0.036150    0.752638    
#> 101: 0.253131    1.070163    3.412553    0.412136    0.066026    0.034343    0.766782    
#> 102: 0.223214    1.062869    3.407836    0.391529    0.062725    0.032626    0.785455    
#> 103: 0.264130    1.082570    3.428337    0.382146    0.060971    0.030994    0.749637    
#> 104: 0.295053    1.088160    3.448320    0.364400    0.073187    0.032408    0.759395    
#> 105: 0.284947    1.088438    3.448085    0.383591    0.069528    0.033036    0.757875    
#> 106: 0.329520    1.071318    3.443737    0.367933    0.066051    0.037412    0.756491    
#> 107: 0.316829    1.075143    3.445836    0.365535    0.062749    0.035764    0.764633    
#> 108: 0.276786    1.074635    3.447850    0.347258    0.068201    0.033976    0.775996    
#> 109: 0.229638    1.063063    3.448688    0.329895    0.064791    0.032277    0.786592    
#> 110: 0.307563    1.046190    3.440279    0.344083    0.061551    0.035199    0.769712    
#> 111: 0.318546    1.048050    3.460345    0.330334    0.058473    0.038544    0.761242    
#> 112: 0.253750    1.030319    3.436497    0.354898    0.055550    0.036617    0.801432    
#> 113: 0.281283    1.070993    3.449244    0.409322    0.052772    0.041863    0.782850    
#> 114: 0.304158    1.069914    3.462552    0.388856    0.050134    0.042676    0.777531    
#> 115: 0.345013    1.028848    3.467427    0.392634    0.047627    0.044157    0.801909    
#> 116: 0.328143    1.049560    3.458609    0.373002    0.047971    0.044305    0.772120    
#> 117: 0.282411    1.069006    3.465051    0.354352    0.045573    0.042090    0.789202    
#> 118: 0.362084    1.062916    3.469848    0.336634    0.047080    0.039986    0.781947    
#> 119: 0.355558    1.049940    3.474631    0.319802    0.044726    0.038684    0.804587    
#> 120: 0.339082    1.006377    3.486959    0.303812    0.042489    0.041067    0.782074    
#> 121: 0.378626    1.023230    3.491640    0.288622    0.053554    0.039014    0.806084    
#> 122: 0.362715    1.006777    3.491784    0.274191    0.050876    0.037442    0.803716    
#> 123: 0.390757    1.051062    3.476793    0.260481    0.050295    0.036146    0.778894    
#> 124: 0.340936    1.065778    3.471156    0.269701    0.050896    0.035225    0.788853    
#> 125: 0.341295    1.053304    3.456086    0.289261    0.050421    0.033464    0.783219    
#> 126: 0.298504    1.064789    3.447295    0.280806    0.063924    0.036168    0.765957    
#> 127: 0.336621    1.057305    3.447987    0.289072    0.060728    0.034359    0.767566    
#> 128: 0.285022    1.049582    3.466079    0.296441    0.057691    0.034805    0.773082    
#> 129: 0.329379    1.054071    3.473109    0.321435    0.054807    0.034117    0.781337    
#> 130: 0.351777    1.060083    3.460807    0.305363    0.052066    0.033791    0.775691    
#> 131: 0.293140    1.050312    3.455320    0.290095    0.049463    0.035585    0.796810    
#> 132: 0.252019    1.037596    3.437456    0.289762    0.058520    0.040381    0.811835    
#> 133: 0.286254    1.044689    3.461154    0.434641    0.055594    0.041532    0.795260    
#> 134: 0.330909    1.026237    3.480943    0.495529    0.052814    0.045833    0.766624    
#> 135: 0.367691    1.002394    3.480453    0.474089    0.050173    0.046222    0.768453    
#> 136: 0.351628    1.012025    3.480747    0.450384    0.047665    0.047908    0.774405    
#> 137: 0.367612    1.024631    3.483067    0.427865    0.050627    0.045513    0.787273    
#> 138: 0.313065    1.037796    3.467750    0.406472    0.048096    0.050567    0.768967    
#> 139: 0.304934    1.050416    3.472955    0.386148    0.045691    0.054670    0.785163    
#> 140: 0.351569    1.046309    3.478857    0.377723    0.043406    0.061933    0.785789    
#> 141: 0.352354    1.046324    3.473061    0.397836    0.041236    0.058836    0.767205    
#> 142: 0.336902    1.022723    3.479584    0.424728    0.039174    0.055895    0.782090    
#> 143: 0.300482    1.040988    3.470344    0.448977    0.037215    0.053100    0.793018    
#> 144: 0.336283    1.045001    3.478215    0.426528    0.037837    0.050445    0.784547    
#> 145: 0.284151    1.042684    3.456237    0.427589    0.035945    0.047923    0.776354    
#> 146: 0.278787    1.055741    3.456871    0.406210    0.047763    0.045526    0.792240    
#> 147: 0.218160    1.039647    3.446596    0.385899    0.058552    0.043250    0.787114    
#> 148: 0.251140    1.074381    3.444604    0.430981    0.063298    0.041088    0.786943    
#> 149: 0.284213    1.053600    3.440433    0.409432    0.070212    0.039033    0.791474    
#> 150: 0.304297    1.051248    3.447062    0.388961    0.070529    0.039749    0.790664    
#> 151: 0.236564    1.087357    3.441813    0.369513    0.067003    0.037762    0.780436    
#> 152: 0.226120    1.075335    3.433860    0.327856    0.046945    0.036725    0.774272    
#> 153: 0.260226    1.079192    3.456074    0.325266    0.041073    0.042502    0.784920    
#> 154: 0.295024    1.088264    3.461444    0.323743    0.048527    0.039954    0.776208    
#> 155: 0.330790    1.050426    3.474755    0.308921    0.046499    0.043237    0.757377    
#> 156: 0.330569    1.062896    3.460442    0.323826    0.042746    0.039093    0.779040    
#> 157: 0.360265    1.041265    3.470723    0.321055    0.051926    0.041083    0.773513    
#> 158: 0.351314    1.044760    3.468308    0.352572    0.052634    0.038903    0.773731    
#> 159: 0.296889    1.061336    3.466346    0.356590    0.045445    0.037948    0.766888    
#> 160: 0.342834    1.026091    3.485125    0.406349    0.048877    0.043445    0.759587    
#> 161: 0.324319    1.036246    3.481593    0.338134    0.037062    0.045316    0.770750    
#> 162: 0.308382    1.042077    3.459189    0.327279    0.038558    0.038029    0.786451    
#> 163: 0.286346    1.046814    3.444380    0.345724    0.052398    0.034719    0.773329    
#> 164: 0.308215    1.047206    3.454492    0.353665    0.043879    0.046942    0.767356    
#> 165: 0.310927    1.031350    3.460367    0.334316    0.049304    0.041497    0.767303    
#> 166: 0.283414    1.051063    3.446890    0.297344    0.049728    0.043693    0.757850    
#> 167: 0.319355    1.062744    3.467764    0.348360    0.055590    0.044412    0.756936    
#> 168: 0.360243    1.060072    3.466179    0.358367    0.057139    0.040276    0.757861    
#> 169: 0.327318    1.078289    3.472297    0.315409    0.070224    0.038051    0.776165    
#> 170: 0.361093    1.046291    3.475224    0.352154    0.058290    0.036161    0.751433    
#> 171: 0.340415    1.037607    3.477279    0.307168    0.043816    0.036396    0.748515    
#> 172: 0.293768    1.065812    3.472362    0.288947    0.050334    0.030692    0.762750    
#> 173: 0.305921    1.076124    3.448491    0.307466    0.041955    0.039112    0.756024    
#> 174: 0.325410    1.065960    3.467835    0.239320    0.049864    0.037802    0.768998    
#> 175: 0.297601    1.056597    3.443412    0.304909    0.029643    0.037607    0.775362    
#> 176: 0.279001    1.060024    3.461419    0.226575    0.032387    0.040497    0.773552    
#> 177: 0.320139    1.055464    3.476558    0.238921    0.040282    0.043681    0.772441    
#> 178: 0.324519    1.050761    3.479055    0.252300    0.037087    0.042057    0.769544    
#> 179: 0.346496    1.058683    3.472650    0.228265    0.043253    0.040393    0.794580    
#> 180: 0.298743    1.055612    3.462048    0.225488    0.046697    0.027706    0.795665    
#> 181: 0.297157    1.040391    3.444659    0.239213    0.039809    0.030301    0.796655    
#> 182: 0.259443    1.046976    3.442980    0.283065    0.030621    0.034053    0.804433    
#> 183: 0.289741    1.071997    3.444684    0.282634    0.044595    0.035057    0.779957    
#> 184: 0.308519    1.030693    3.460628    0.294475    0.057296    0.036606    0.771791    
#> 185: 0.288700    1.080661    3.446833    0.311070    0.065923    0.030691    0.759343    
#> 186: 0.290049    1.095862    3.450757    0.307558    0.059597    0.034999    0.779210    
#> 187: 0.323189    1.059676    3.462449    0.322229    0.074672    0.038784    0.768292    
#> 188: 0.277471    1.082990    3.456710    0.265455    0.080445    0.036597    0.782939    
#> 189: 0.311685    1.091751    3.475408    0.267103    0.062766    0.042790    0.789964    
#> 190: 0.288603    1.061523    3.476861    0.279347    0.050403    0.036577    0.772301    
#> 191: 0.261003    1.052349    3.457307    0.243356    0.043043    0.033814    0.780834    
#> 192: 0.279452    1.042299    3.468728    0.286141    0.049633    0.039042    0.762439    
#> 193: 0.350850    1.067465    3.472540    0.277155    0.052502    0.036835    0.755134    
#> 194: 0.319489    1.065843    3.448996    0.297419    0.057019    0.037426    0.789333    
#> 195: 0.280561    1.072663    3.447327    0.335173    0.053236    0.041661    0.764169    
#> 196: 0.306399    1.072942    3.465506    0.330175    0.039299    0.044008    0.796559    
#> 197: 0.268156    1.061029    3.484318    0.305309    0.050343    0.040217    0.786675    
#> 198: 0.334950    1.044864    3.466929    0.332410    0.041484    0.040753    0.773827    
#> 199: 0.280115    1.055602    3.446137    0.275479    0.047037    0.036556    0.779404    
#> 200: 0.299270    1.034699    3.457948    0.369153    0.045432    0.036763    0.789021    
#> 201: 0.287576    1.035120    3.463921    0.371961    0.046057    0.039864    0.782041    
#> 202: 0.290590    1.039115    3.462763    0.372051    0.045266    0.038553    0.782840    
#> 203: 0.306171    1.037325    3.462241    0.370973    0.045104    0.037629    0.781897    
#> 204: 0.311770    1.033685    3.462994    0.368879    0.048325    0.036019    0.781940    
#> 205: 0.313843    1.037024    3.462506    0.360792    0.048072    0.035580    0.786400    
#> 206: 0.310221    1.040071    3.464770    0.351502    0.047308    0.036945    0.786055    
#> 207: 0.311605    1.042119    3.464319    0.348777    0.047993    0.036354    0.784863    
#> 208: 0.314993    1.043024    3.466615    0.343663    0.047617    0.036436    0.786982    
#> 209: 0.318751    1.041761    3.466560    0.342420    0.048176    0.036525    0.788446    
#> 210: 0.321204    1.042385    3.466586    0.338537    0.048667    0.036462    0.787972    
#> 211: 0.321303    1.044704    3.466650    0.336060    0.049666    0.037300    0.787173    
#> 212: 0.321398    1.045905    3.466060    0.329707    0.050369    0.036590    0.785368    
#> 213: 0.320975    1.042963    3.466488    0.324685    0.051525    0.036528    0.785985    
#> 214: 0.323004    1.041639    3.467622    0.320877    0.052273    0.036591    0.785812    
#> 215: 0.322291    1.041363    3.468403    0.317147    0.052587    0.036875    0.786198    
#> 216: 0.323724    1.039259    3.469472    0.314932    0.053232    0.037331    0.788773    
#> 217: 0.322936    1.038859    3.470143    0.311206    0.053705    0.037451    0.788776    
#> 218: 0.323437    1.039953    3.469274    0.311977    0.053826    0.037213    0.787938    
#> 219: 0.322107    1.039438    3.468309    0.310848    0.053287    0.037158    0.787228    
#> 220: 0.320541    1.040254    3.467876    0.313312    0.052990    0.037451    0.785686    
#> 221: 0.318668    1.041002    3.467383    0.314907    0.053034    0.037667    0.784438    
#> 222: 0.318225    1.041301    3.466346    0.315549    0.053062    0.038057    0.784338    
#> 223: 0.318898    1.041964    3.466399    0.312684    0.052946    0.038389    0.784490    
#> 224: 0.319678    1.041784    3.466176    0.312706    0.052106    0.038665    0.784237    
#> 225: 0.319532    1.040367    3.466798    0.312151    0.051719    0.039182    0.784988    
#> 226: 0.320366    1.039346    3.466560    0.311728    0.051388    0.039347    0.785450    
#> 227: 0.319815    1.039535    3.466488    0.311798    0.050948    0.039685    0.785329    
#> 228: 0.318219    1.040538    3.465746    0.312640    0.050456    0.039960    0.785129    
#> 229: 0.318127    1.040953    3.465804    0.311493    0.050252    0.040138    0.784389    
#> 230: 0.318261    1.041312    3.465272    0.310234    0.050278    0.039882    0.784556    
#> 231: 0.318048    1.042116    3.465255    0.309413    0.050491    0.039506    0.784163    
#> 232: 0.316976    1.042501    3.465076    0.308526    0.050363    0.039338    0.784162    
#> 233: 0.316975    1.042166    3.464961    0.307448    0.050529    0.039285    0.783936    
#> 234: 0.315996    1.042591    3.464628    0.307360    0.050815    0.039525    0.784079    
#> 235: 0.316240    1.042605    3.464633    0.307177    0.051067    0.039624    0.783981    
#> 236: 0.316498    1.043431    3.464399    0.308076    0.051145    0.039680    0.784655    
#> 237: 0.317690    1.043649    3.464505    0.307498    0.051121    0.039650    0.785623    
#> 238: 0.318513    1.043567    3.464760    0.307050    0.051079    0.039674    0.786698    
#> 239: 0.317573    1.044152    3.464596    0.306766    0.051140    0.039805    0.786363    
#> 240: 0.316849    1.044290    3.464591    0.306739    0.051250    0.039656    0.785786    
#> 241: 0.316668    1.043986    3.464450    0.305867    0.051488    0.039511    0.785232    
#> 242: 0.316051    1.043626    3.463949    0.304665    0.051921    0.039353    0.785697    
#> 243: 0.314528    1.044312    3.463607    0.304267    0.052371    0.039137    0.785731    
#> 244: 0.313638    1.044234    3.463656    0.304204    0.052484    0.038876    0.785951    
#> 245: 0.313669    1.044176    3.463799    0.304553    0.052896    0.038749    0.785884    
#> 246: 0.313956    1.044184    3.463841    0.304435    0.053145    0.038717    0.786288    
#> 247: 0.313883    1.044685    3.464098    0.305865    0.053357    0.038657    0.786193    
#> 248: 0.313456    1.044918    3.464034    0.305762    0.053562    0.038438    0.785854    
#> 249: 0.313708    1.044889    3.464133    0.306093    0.053775    0.038308    0.785623    
#> 250: 0.314009    1.045040    3.464466    0.305382    0.054067    0.038110    0.785512    
#> 251: 0.314492    1.045792    3.464893    0.305330    0.054272    0.037989    0.785614    
#> 252: 0.314662    1.046164    3.465143    0.304446    0.054377    0.037926    0.785536    
#> 253: 0.314989    1.046365    3.465336    0.304297    0.054539    0.037771    0.786013    
#> 254: 0.315688    1.046710    3.465700    0.303834    0.054479    0.037696    0.786224    
#> 255: 0.315383    1.046889    3.465693    0.302310    0.054429    0.037508    0.786165    
#> 256: 0.315738    1.046754    3.465823    0.301115    0.054578    0.037286    0.785984    
#> 257: 0.316117    1.046474    3.465934    0.301530    0.054632    0.037248    0.785397    
#> 258: 0.315353    1.045963    3.465876    0.300667    0.054534    0.037253    0.785042    
#> 259: 0.315142    1.045526    3.465944    0.300438    0.054419    0.037283    0.784899    
#> 260: 0.315183    1.045637    3.465952    0.300997    0.054450    0.037219    0.784437    
#> 261: 0.315785    1.045538    3.466046    0.301048    0.054481    0.037142    0.784265    
#> 262: 0.316313    1.045788    3.466227    0.301440    0.054600    0.037071    0.783856    
#> 263: 0.316268    1.046108    3.466197    0.300736    0.054753    0.036978    0.783946    
#> 264: 0.316513    1.046582    3.466155    0.301609    0.055200    0.037000    0.783641    
#> 265: 0.316544    1.046675    3.466096    0.301881    0.055679    0.037045    0.783474    
#> 266: 0.316890    1.047208    3.466032    0.302294    0.055880    0.037064    0.783137    
#> 267: 0.316934    1.047414    3.466198    0.302260    0.055976    0.037122    0.783079    
#> 268: 0.316698    1.047375    3.466032    0.302464    0.055802    0.037134    0.783221    
#> 269: 0.317063    1.047386    3.465907    0.303403    0.055582    0.037152    0.783022    
#> 270: 0.317297    1.047580    3.465799    0.303593    0.055407    0.037144    0.782595    
#> 271: 0.317363    1.047644    3.465760    0.303958    0.055295    0.037114    0.782477    
#> 272: 0.317258    1.047432    3.465637    0.304484    0.055342    0.037124    0.782676    
#> 273: 0.317331    1.047688    3.465768    0.304251    0.055360    0.037112    0.782906    
#> 274: 0.317541    1.048047    3.465868    0.303670    0.055378    0.037117    0.782705    
#> 275: 0.317709    1.047967    3.465987    0.303031    0.055320    0.037113    0.782854    
#> 276: 0.317958    1.047899    3.466126    0.303174    0.055320    0.037135    0.782785    
#> 277: 0.317576    1.048068    3.466210    0.303209    0.055225    0.037227    0.782470    
#> 278: 0.317401    1.048180    3.466253    0.303660    0.055241    0.037286    0.782273    
#> 279: 0.317590    1.047854    3.466479    0.303964    0.055152    0.037403    0.782324    
#> 280: 0.317668    1.047804    3.466536    0.303080    0.055162    0.037439    0.782317    
#> 281: 0.317275    1.048148    3.466406    0.302149    0.055314    0.037405    0.782098    
#> 282: 0.317546    1.048446    3.466647    0.301565    0.055487    0.037456    0.782415    
#> 283: 0.317847    1.048448    3.466823    0.301154    0.055608    0.037440    0.782935    
#> 284: 0.317762    1.048048    3.466869    0.301438    0.055552    0.037347    0.783056    
#> 285: 0.318118    1.047870    3.466831    0.301726    0.055520    0.037324    0.783287    
#> 286: 0.318442    1.047713    3.466895    0.301686    0.055581    0.037313    0.783346    
#> 287: 0.318610    1.047578    3.466935    0.302123    0.055547    0.037316    0.783299    
#> 288: 0.319102    1.047313    3.467154    0.301664    0.055441    0.037440    0.783334    
#> 289: 0.319386    1.047160    3.467234    0.301937    0.055525    0.037488    0.783311    
#> 290: 0.319515    1.047099    3.467143    0.301466    0.055589    0.037482    0.783749    
#> 291: 0.319366    1.047236    3.467216    0.300300    0.055404    0.037437    0.783897    
#> 292: 0.319433    1.047343    3.467230    0.300370    0.055227    0.037428    0.783722    
#> 293: 0.319587    1.047446    3.467141    0.300785    0.055063    0.037448    0.783448    
#> 294: 0.319667    1.047599    3.467047    0.301048    0.055051    0.037413    0.783331    
#> 295: 0.319436    1.047488    3.466999    0.300973    0.054943    0.037490    0.783240    
#> 296: 0.319094    1.047495    3.466921    0.300816    0.055009    0.037523    0.783246    
#> 297: 0.319237    1.047566    3.466904    0.300655    0.054932    0.037430    0.783314    
#> 298: 0.319432    1.047520    3.466843    0.301021    0.055034    0.037351    0.783180    
#> 299: 0.320094    1.047587    3.466985    0.301334    0.055045    0.037313    0.783098    
#> 300: 0.320801    1.047465    3.467294    0.300926    0.055020    0.037354    0.783086    
#> 301: 0.321361    1.047229    3.467507    0.301131    0.055025    0.037399    0.783163    
#> 302: 0.321835    1.047188    3.467491    0.301334    0.055077    0.037425    0.783022    
#> 303: 0.321772    1.047219    3.467402    0.301026    0.055020    0.037429    0.782994    
#> 304: 0.321870    1.047385    3.467312    0.300991    0.055013    0.037415    0.782960    
#> 305: 0.321855    1.047131    3.467308    0.301276    0.054961    0.037449    0.782830    
#> 306: 0.321386    1.046932    3.467174    0.301528    0.055005    0.037460    0.782691    
#> 307: 0.320867    1.046853    3.467127    0.301249    0.054976    0.037520    0.782829    
#> 308: 0.320686    1.046818    3.467165    0.301724    0.054931    0.037548    0.783007    
#> 309: 0.320551    1.046628    3.467132    0.302077    0.054962    0.037567    0.783164    
#> 310: 0.320773    1.046516    3.467102    0.302643    0.054950    0.037592    0.783236    
#> 311: 0.320544    1.046400    3.467102    0.303187    0.054893    0.037595    0.783197    
#> 312: 0.320572    1.046181    3.467070    0.302865    0.054842    0.037577    0.783275    
#> 313: 0.320690    1.045906    3.467079    0.302398    0.054789    0.037586    0.783525    
#> 314: 0.320087    1.045873    3.466953    0.302298    0.054734    0.037565    0.783584    
#> 315: 0.319751    1.045900    3.466943    0.302472    0.054819    0.037567    0.783474    
#> 316: 0.319744    1.046070    3.466888    0.302291    0.054892    0.037549    0.783383    
#> 317: 0.319802    1.045928    3.467038    0.302365    0.054921    0.037485    0.783582    
#> 318: 0.319619    1.045839    3.467034    0.301869    0.054944    0.037483    0.783393    
#> 319: 0.319675    1.045659    3.467067    0.301384    0.054843    0.037503    0.783397    
#> 320: 0.319287    1.045750    3.467010    0.301411    0.054786    0.037508    0.783578    
#> 321: 0.318691    1.045869    3.466838    0.300818    0.054746    0.037471    0.783723    
#> 322: 0.318422    1.045922    3.466670    0.300467    0.054715    0.037504    0.783736    
#> 323: 0.317823    1.045984    3.466529    0.300313    0.054716    0.037586    0.783756    
#> 324: 0.317459    1.046071    3.466428    0.300310    0.054676    0.037612    0.783747    
#> 325: 0.317005    1.046341    3.466234    0.300386    0.054644    0.037570    0.783802    
#> 326: 0.316904    1.046428    3.466025    0.300696    0.054588    0.037607    0.783712    
#> 327: 0.316721    1.046626    3.465897    0.301107    0.054613    0.037607    0.783655    
#> 328: 0.316683    1.046726    3.465817    0.301613    0.054626    0.037594    0.783575    
#> 329: 0.316841    1.046679    3.465786    0.302122    0.054566    0.037528    0.783450    
#> 330: 0.316387    1.046541    3.465848    0.301726    0.054549    0.037478    0.783518    
#> 331: 0.316259    1.046682    3.465885    0.301538    0.054607    0.037471    0.783400    
#> 332: 0.316206    1.046720    3.466002    0.301428    0.054625    0.037507    0.783378    
#> 333: 0.316018    1.046838    3.465999    0.301570    0.054530    0.037551    0.783425    
#> 334: 0.315896    1.046800    3.465884    0.301666    0.054449    0.037564    0.783345    
#> 335: 0.315866    1.046798    3.465837    0.301295    0.054421    0.037505    0.783337    
#> 336: 0.315372    1.046900    3.465780    0.300887    0.054423    0.037484    0.783288    
#> 337: 0.315082    1.047154    3.465589    0.300970    0.054499    0.037475    0.783179    
#> 338: 0.314913    1.047165    3.465657    0.301104    0.054528    0.037481    0.783116    
#> 339: 0.314727    1.047464    3.465494    0.301176    0.054601    0.037480    0.782984    
#> 340: 0.314818    1.047458    3.465427    0.301313    0.054697    0.037461    0.782771    
#> 341: 0.315014    1.047351    3.465490    0.301718    0.054694    0.037425    0.782738    
#> 342: 0.314943    1.047218    3.465587    0.301733    0.054710    0.037428    0.782604    
#> 343: 0.314804    1.047210    3.465587    0.301829    0.054743    0.037432    0.782499    
#> 344: 0.314873    1.047119    3.465569    0.302067    0.054772    0.037402    0.782482    
#> 345: 0.314815    1.047018    3.465616    0.302283    0.054755    0.037349    0.782545    
#> 346: 0.314781    1.047139    3.465596    0.302462    0.054776    0.037277    0.782524    
#> 347: 0.314952    1.047091    3.465586    0.302368    0.054830    0.037193    0.782673    
#> 348: 0.314682    1.047017    3.465548    0.302427    0.054911    0.037111    0.782722    
#> 349: 0.314499    1.047017    3.465477    0.302410    0.054969    0.037025    0.782694    
#> 350: 0.314335    1.046930    3.465413    0.302575    0.055064    0.036993    0.782707    
#> 351: 0.314158    1.047264    3.465228    0.302969    0.055220    0.036911    0.782742    
#> 352: 0.313733    1.047463    3.465094    0.303684    0.055254    0.036906    0.782941    
#> 353: 0.313603    1.047718    3.465004    0.303995    0.055213    0.036901    0.783001    
#> 354: 0.313633    1.047882    3.464922    0.304067    0.055274    0.036885    0.783004    
#> 355: 0.313968    1.047770    3.464890    0.304240    0.055279    0.036861    0.782986    
#> 356: 0.313965    1.047730    3.464892    0.304219    0.055334    0.036825    0.783162    
#> 357: 0.314042    1.047787    3.464843    0.304449    0.055392    0.036831    0.783130    
#> 358: 0.313934    1.047869    3.464849    0.304451    0.055380    0.036814    0.783093    
#> 359: 0.313750    1.047934    3.464775    0.304315    0.055318    0.036803    0.783119    
#> 360: 0.313384    1.048017    3.464546    0.304299    0.055272    0.036788    0.783051    
#> 361: 0.313078    1.048012    3.464365    0.304624    0.055265    0.036740    0.782943    
#> 362: 0.313045    1.047973    3.464262    0.305187    0.055293    0.036686    0.782761    
#> 363: 0.313052    1.047910    3.464225    0.305469    0.055265    0.036634    0.782573    
#> 364: 0.313182    1.047936    3.464210    0.305435    0.055269    0.036575    0.782595    
#> 365: 0.312960    1.047891    3.464199    0.305395    0.055400    0.036540    0.782582    
#> 366: 0.312901    1.048002    3.464028    0.305629    0.055412    0.036553    0.782566    
#> 367: 0.312740    1.048124    3.464004    0.305675    0.055500    0.036547    0.782549    
#> 368: 0.312888    1.048302    3.463959    0.305364    0.055509    0.036576    0.782520    
#> 369: 0.312852    1.048301    3.463936    0.305117    0.055474    0.036603    0.782596    
#> 370: 0.312577    1.048579    3.463809    0.304781    0.055538    0.036595    0.782628    
#> 371: 0.312462    1.048664    3.463670    0.305101    0.055493    0.036587    0.782594    
#> 372: 0.312498    1.048741    3.463665    0.304885    0.055536    0.036570    0.782489    
#> 373: 0.312324    1.048890    3.463588    0.304826    0.055559    0.036573    0.782479    
#> 374: 0.312331    1.048867    3.463588    0.304391    0.055523    0.036579    0.782514    
#> 375: 0.312346    1.048823    3.463675    0.304098    0.055511    0.036621    0.782606    
#> 376: 0.312436    1.048895    3.463726    0.303842    0.055554    0.036624    0.782525    
#> 377: 0.312452    1.048976    3.463754    0.303789    0.055527    0.036590    0.782429    
#> 378: 0.312422    1.048994    3.463731    0.303762    0.055501    0.036552    0.782408    
#> 379: 0.312246    1.048790    3.463752    0.303645    0.055427    0.036551    0.782400    
#> 380: 0.312175    1.048677    3.463830    0.303329    0.055406    0.036554    0.782371    
#> 381: 0.312315    1.048503    3.463912    0.303241    0.055422    0.036554    0.782262    
#> 382: 0.312290    1.048372    3.463971    0.302751    0.055384    0.036569    0.782294    
#> 383: 0.312361    1.048344    3.463957    0.302583    0.055413    0.036503    0.782210    
#> 384: 0.312046    1.048370    3.463952    0.302660    0.055375    0.036468    0.782250    
#> 385: 0.311955    1.048335    3.463858    0.302774    0.055356    0.036450    0.782234    
#> 386: 0.312001    1.048397    3.463898    0.302801    0.055376    0.036469    0.782353    
#> 387: 0.312131    1.048387    3.464007    0.302760    0.055404    0.036477    0.782357    
#> 388: 0.312191    1.048341    3.464094    0.302598    0.055425    0.036476    0.782329    
#> 389: 0.312210    1.048242    3.464115    0.302402    0.055495    0.036426    0.782295    
#> 390: 0.312196    1.048210    3.464077    0.302539    0.055597    0.036347    0.782259    
#> 391: 0.312256    1.048163    3.464050    0.302950    0.055644    0.036329    0.782218    
#> 392: 0.312405    1.048153    3.464184    0.302822    0.055693    0.036358    0.782225    
#> 393: 0.312417    1.048029    3.464158    0.302727    0.055701    0.036362    0.782245    
#> 394: 0.312451    1.048054    3.464109    0.302857    0.055714    0.036317    0.782222    
#> 395: 0.312596    1.048150    3.464119    0.303148    0.055821    0.036285    0.782211    
#> 396: 0.312793    1.048228    3.464197    0.303093    0.055931    0.036274    0.782172    
#> 397: 0.312811    1.048206    3.464210    0.303396    0.055991    0.036283    0.782192    
#> 398: 0.313055    1.048092    3.464275    0.303609    0.056006    0.036327    0.782099    
#> 399: 0.313377    1.048053    3.464414    0.303687    0.056009    0.036374    0.782000    
#> 400: 0.313441    1.048097    3.464495    0.303380    0.056015    0.036386    0.781944    
#> 401: 0.313545    1.048226    3.464479    0.303073    0.055979    0.036391    0.782036    
#> 402: 0.313425    1.048357    3.464479    0.302785    0.055986    0.036398    0.782009    
#> 403: 0.313623    1.048366    3.464512    0.302723    0.055977    0.036418    0.781905    
#> 404: 0.313627    1.048351    3.464435    0.302715    0.055971    0.036414    0.781800    
#> 405: 0.313793    1.048402    3.464475    0.302752    0.055969    0.036423    0.781767    
#> 406: 0.313954    1.048432    3.464448    0.303075    0.055993    0.036414    0.781824    
#> 407: 0.313975    1.048507    3.464399    0.303450    0.056014    0.036371    0.781844    
#> 408: 0.314074    1.048643    3.464444    0.303296    0.056085    0.036352    0.781984    
#> 409: 0.313993    1.048658    3.464360    0.303269    0.056082    0.036298    0.781924    
#> 410: 0.313828    1.048773    3.464263    0.303143    0.056099    0.036258    0.782010    
#> 411: 0.313692    1.048637    3.464243    0.303050    0.056114    0.036245    0.782063    
#> 412: 0.313539    1.048607    3.464214    0.302884    0.056095    0.036217    0.782105    
#> 413: 0.313343    1.048620    3.464149    0.302875    0.056067    0.036167    0.782149    
#> 414: 0.313139    1.048619    3.464140    0.303094    0.056091    0.036149    0.782061    
#> 415: 0.313259    1.048617    3.464152    0.302994    0.056094    0.036111    0.781983    
#> 416: 0.313324    1.048703    3.464221    0.302898    0.056086    0.036114    0.781891    
#> 417: 0.313432    1.048660    3.464293    0.302634    0.056065    0.036094    0.781856    
#> 418: 0.313326    1.048700    3.464303    0.302643    0.056072    0.036095    0.781765    
#> 419: 0.313335    1.048870    3.464302    0.302443    0.056085    0.036105    0.781705    
#> 420: 0.313314    1.048986    3.464256    0.302464    0.056100    0.036105    0.781570    
#> 421: 0.313275    1.049104    3.464272    0.302353    0.056110    0.036118    0.781432    
#> 422: 0.313352    1.049088    3.464256    0.302620    0.056036    0.036118    0.781370    
#> 423: 0.313486    1.049123    3.464255    0.302596    0.055993    0.036113    0.781316    
#> 424: 0.313329    1.049075    3.464210    0.302602    0.055972    0.036090    0.781339    
#> 425: 0.313561    1.049128    3.464268    0.302370    0.055950    0.036078    0.781420    
#> 426: 0.313624    1.049181    3.464263    0.302297    0.055968    0.036068    0.781298    
#> 427: 0.313516    1.049126    3.464286    0.302117    0.055960    0.036018    0.781245    
#> 428: 0.313357    1.049188    3.464251    0.302217    0.055924    0.035990    0.781188    
#> 429: 0.313310    1.049177    3.464255    0.302092    0.055905    0.035966    0.781193    
#> 430: 0.313250    1.049160    3.464204    0.302233    0.055889    0.035921    0.781167    
#> 431: 0.313116    1.049240    3.464168    0.302319    0.055955    0.035887    0.781027    
#> 432: 0.313128    1.049334    3.464222    0.302323    0.056016    0.035849    0.780987    
#> 433: 0.313119    1.049450    3.464214    0.302231    0.056075    0.035831    0.780946    
#> 434: 0.313057    1.049366    3.464224    0.302190    0.056066    0.035814    0.780817    
#> 435: 0.313092    1.049308    3.464198    0.301865    0.056029    0.035782    0.780738    
#> 436: 0.313243    1.049305    3.464289    0.301594    0.056067    0.035762    0.780674    
#> 437: 0.313375    1.049281    3.464376    0.301663    0.056137    0.035754    0.780631    
#> 438: 0.313422    1.049382    3.464386    0.301824    0.056139    0.035765    0.780497    
#> 439: 0.313468    1.049425    3.464400    0.301996    0.056140    0.035762    0.780346    
#> 440: 0.313374    1.049475    3.464407    0.301926    0.056135    0.035746    0.780260    
#> 441: 0.313354    1.049398    3.464445    0.301757    0.056109    0.035750    0.780226    
#> 442: 0.313049    1.049388    3.464371    0.301753    0.056100    0.035747    0.780157    
#> 443: 0.312789    1.049478    3.464278    0.301677    0.056052    0.035772    0.780121    
#> 444: 0.312397    1.049585    3.464155    0.301538    0.056009    0.035816    0.780118    
#> 445: 0.312175    1.049667    3.464089    0.301335    0.055927    0.035881    0.780142    
#> 446: 0.311959    1.049835    3.463966    0.301359    0.055837    0.035925    0.780140    
#> 447: 0.311988    1.049950    3.463913    0.301350    0.055761    0.035972    0.780171    
#> 448: 0.311886    1.050055    3.463864    0.301452    0.055739    0.036019    0.780059    
#> 449: 0.311886    1.050124    3.463907    0.301530    0.055716    0.036042    0.780057    
#> 450: 0.311783    1.050168    3.463865    0.301646    0.055739    0.036090    0.779996    
#> 451: 0.311937    1.050228    3.463843    0.301973    0.055750    0.036144    0.779914    
#> 452: 0.311909    1.050343    3.463849    0.302222    0.055740    0.036166    0.779843    
#> 453: 0.311854    1.050417    3.463811    0.302278    0.055751    0.036179    0.779741    
#> 454: 0.311678    1.050557    3.463745    0.302134    0.055770    0.036184    0.779701    
#> 455: 0.311578    1.050636    3.463638    0.302081    0.055774    0.036182    0.779628    
#> 456: 0.311587    1.050622    3.463593    0.302142    0.055792    0.036181    0.779564    
#> 457: 0.311582    1.050613    3.463636    0.302248    0.055827    0.036210    0.779458    
#> 458: 0.311701    1.050695    3.463750    0.302133    0.055837    0.036231    0.779409    
#> 459: 0.311630    1.050725    3.463753    0.301896    0.055798    0.036252    0.779361    
#> 460: 0.311530    1.050696    3.463760    0.301797    0.055787    0.036263    0.779332    
#> 461: 0.311390    1.050680    3.463790    0.301729    0.055755    0.036279    0.779302    
#> 462: 0.311125    1.050750    3.463771    0.301811    0.055718    0.036293    0.779263    
#> 463: 0.310953    1.050768    3.463756    0.301912    0.055681    0.036287    0.779252    
#> 464: 0.311034    1.050791    3.463739    0.301966    0.055624    0.036289    0.779169    
#> 465: 0.310959    1.050681    3.463729    0.301984    0.055631    0.036292    0.779191    
#> 466: 0.310894    1.050677    3.463700    0.301981    0.055662    0.036296    0.779121    
#> 467: 0.310710    1.050659    3.463689    0.301967    0.055666    0.036326    0.779016    
#> 468: 0.310819    1.050626    3.463751    0.301957    0.055662    0.036337    0.778980    
#> 469: 0.310825    1.050683    3.463775    0.301833    0.055706    0.036321    0.779048    
#> 470: 0.310673    1.050702    3.463767    0.301734    0.055691    0.036346    0.778997    
#> 471: 0.310560    1.050704    3.463768    0.301681    0.055665    0.036353    0.778968    
#> 472: 0.310551    1.050729    3.463761    0.301578    0.055664    0.036346    0.778939    
#> 473: 0.310503    1.050751    3.463785    0.301376    0.055670    0.036357    0.778869    
#> 474: 0.310528    1.050757    3.463776    0.301306    0.055668    0.036365    0.778894    
#> 475: 0.310595    1.050859    3.463747    0.301284    0.055684    0.036339    0.778847    
#> 476: 0.310652    1.050869    3.463757    0.301168    0.055670    0.036327    0.778899    
#> 477: 0.310728    1.050930    3.463791    0.301256    0.055650    0.036313    0.778848    
#> 478: 0.310712    1.050910    3.463798    0.301305    0.055635    0.036314    0.778896    
#> 479: 0.310794    1.050956    3.463814    0.301310    0.055602    0.036310    0.778922    
#> 480: 0.310789    1.050983    3.463784    0.301315    0.055596    0.036311    0.778954    
#> 481: 0.310680    1.051012    3.463722    0.301528    0.055587    0.036310    0.778886    
#> 482: 0.310715    1.051041    3.463621    0.301793    0.055616    0.036335    0.778887    
#> 483: 0.310649    1.051060    3.463544    0.301804    0.055670    0.036348    0.778875    
#> 484: 0.310819    1.050999    3.463564    0.302201    0.055693    0.036368    0.778832    
#> 485: 0.310993    1.050992    3.463602    0.302411    0.055704    0.036371    0.778829    
#> 486: 0.311108    1.051054    3.463688    0.302451    0.055684    0.036381    0.778828    
#> 487: 0.311447    1.051079    3.463824    0.302492    0.055709    0.036365    0.778826    
#> 488: 0.311524    1.051055    3.463861    0.302315    0.055711    0.036348    0.778826    
#> 489: 0.311729    1.050984    3.463848    0.302333    0.055730    0.036316    0.778854    
#> 490: 0.311865    1.050997    3.463896    0.302316    0.055746    0.036301    0.778837    
#> 491: 0.312000    1.051033    3.463934    0.302510    0.055728    0.036305    0.778772    
#> 492: 0.312027    1.051071    3.463921    0.302528    0.055711    0.036318    0.778790    
#> 493: 0.311874    1.051132    3.463876    0.302398    0.055695    0.036335    0.778861    
#> 494: 0.311824    1.051266    3.463777    0.302429    0.055716    0.036336    0.778831    
#> 495: 0.311728    1.051342    3.463732    0.302485    0.055715    0.036321    0.778796    
#> 496: 0.311708    1.051435    3.463672    0.302478    0.055694    0.036321    0.778813    
#> 497: 0.311666    1.051448    3.463665    0.302411    0.055683    0.036329    0.778887    
#> 498: 0.311664    1.051437    3.463642    0.302542    0.055696    0.036332    0.778861    
#> 499: 0.311574    1.051478    3.463593    0.302654    0.055726    0.036333    0.778808    
#> 500: 0.311526    1.051441    3.463564    0.302555    0.055730    0.036319    0.778818    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.298219    0.966992    3.438594    0.392401    0.078674    0.016800    1.676400    
#> 002: 0.384947    0.947047    3.449027    0.372781    0.074741    0.015960    1.213770    
#> 003: 0.436257    0.838058    3.449059    0.354142    0.071921    0.015162    0.975459    
#> 004: 0.420073    0.847424    3.427350    0.336435    0.068325    0.014404    0.926755    
#> 005: 0.427583    0.858781    3.408867    0.373561    0.068849    0.013684    0.842878    
#> 006: 0.367682    0.861344    3.404486    0.354883    0.066327    0.013000    0.807513    
#> 007: 0.317969    0.879129    3.391013    0.366522    0.072059    0.012350    0.816385    
#> 008: 0.329306    0.892595    3.378630    0.377284    0.068456    0.011732    0.830560    
#> 009: 0.280596    0.886150    3.368182    0.358419    0.071731    0.011146    0.841174    
#> 010: 0.309429    0.889937    3.368625    0.350279    0.072691    0.010588    0.832213    
#> 011: 0.335170    0.907275    3.370062    0.340904    0.069057    0.011292    0.821542    
#> 012: 0.333019    0.898836    3.371810    0.363883    0.065604    0.011383    0.782977    
#> 013: 0.304039    0.890853    3.362680    0.443956    0.062324    0.013192    0.802155    
#> 014: 0.326566    0.900208    3.376258    0.421758    0.070830    0.014600    0.807782    
#> 015: 0.385970    0.887233    3.391687    0.400670    0.069411    0.013870    0.802693    
#> 016: 0.338794    0.887839    3.394353    0.380637    0.065940    0.013177    0.829031    
#> 017: 0.391908    0.889446    3.393876    0.409026    0.062643    0.012518    0.806108    
#> 018: 0.365983    0.899770    3.379341    0.388574    0.065860    0.011892    0.819159    
#> 019: 0.349274    0.905300    3.378506    0.369146    0.062567    0.011297    0.803899    
#> 020: 0.364024    0.910275    3.384443    0.387501    0.059439    0.011187    0.806433    
#> 021: 0.374985    0.898748    3.396282    0.429183    0.058582    0.010628    0.793982    
#> 022: 0.363840    0.884475    3.407969    0.407724    0.074274    0.010096    0.813798    
#> 023: 0.434611    0.873187    3.422667    0.387338    0.081093    0.010689    0.844406    
#> 024: 0.415474    0.904178    3.414167    0.430139    0.077038    0.010155    0.811964    
#> 025: 0.397770    0.878373    3.403673    0.409305    0.073186    0.009806    0.800640    
#> 026: 0.373114    0.916867    3.395873    0.388840    0.086531    0.012638    0.793978    
#> 027: 0.346350    0.937521    3.379865    0.369398    0.082205    0.012006    0.803169    
#> 028: 0.397330    0.924693    3.390587    0.420703    0.082659    0.012701    0.797031    
#> 029: 0.395728    0.918837    3.375210    0.399668    0.078526    0.012066    0.836114    
#> 030: 0.397694    0.919581    3.388041    0.404096    0.083709    0.013505    0.807786    
#> 031: 0.343448    0.901854    3.388716    0.409607    0.079524    0.013267    0.798720    
#> 032: 0.349884    0.888212    3.393570    0.396499    0.075548    0.015640    0.778657    
#> 033: 0.324661    0.908930    3.379324    0.376674    0.071770    0.015694    0.786089    
#> 034: 0.347609    0.917939    3.383770    0.370006    0.068182    0.016145    0.788293    
#> 035: 0.320431    0.892132    3.377967    0.351506    0.064773    0.015338    0.773895    
#> 036: 0.329204    0.916348    3.376727    0.334767    0.065948    0.014571    0.793062    
#> 037: 0.302054    0.926752    3.366990    0.348027    0.062651    0.013842    0.807222    
#> 038: 0.336192    0.912407    3.368360    0.361227    0.059518    0.013150    0.828665    
#> 039: 0.306687    0.912626    3.372366    0.343166    0.057559    0.012493    0.827458    
#> 040: 0.340631    0.919892    3.386320    0.327039    0.070947    0.011868    0.806100    
#> 041: 0.310400    0.900781    3.382736    0.320448    0.067400    0.011275    0.813726    
#> 042: 0.336432    0.887929    3.381328    0.319336    0.064030    0.010711    0.806939    
#> 043: 0.317662    0.910282    3.361676    0.303369    0.060829    0.010175    0.816554    
#> 044: 0.301470    0.927353    3.367243    0.375148    0.060568    0.009667    0.808143    
#> 045: 0.299539    0.934942    3.356834    0.356391    0.063838    0.009672    0.800057    
#> 046: 0.319418    0.930062    3.368501    0.338571    0.060646    0.009188    0.815848    
#> 047: 0.324957    0.929692    3.369536    0.342911    0.071480    0.008729    0.794830    
#> 048: 0.329918    0.903718    3.373439    0.325765    0.080308    0.008292    0.813488    
#> 049: 0.296723    0.908992    3.375787    0.354453    0.076293    0.010927    0.807308    
#> 050: 0.352821    0.880323    3.386022    0.351833    0.072478    0.014593    0.836065    
#> 051: 0.332232    0.898146    3.385613    0.334242    0.068854    0.017179    0.839169    
#> 052: 0.361031    0.899487    3.397557    0.317529    0.072125    0.016320    0.808879    
#> 053: 0.372241    0.874943    3.399076    0.338726    0.072610    0.015504    0.796223    
#> 054: 0.314255    0.878401    3.402405    0.322588    0.082001    0.017417    0.829338    
#> 055: 0.345934    0.876100    3.399424    0.350930    0.077901    0.016546    0.853488    
#> 056: 0.392754    0.882391    3.401785    0.343373    0.078896    0.015719    0.823116    
#> 057: 0.398922    0.867661    3.422992    0.365676    0.074951    0.014933    0.848004    
#> 058: 0.408525    0.871020    3.415220    0.387179    0.071204    0.015552    0.834452    
#> 059: 0.404601    0.832127    3.417281    0.369030    0.067643    0.019336    0.841330    
#> 060: 0.411787    0.821545    3.423860    0.350579    0.070522    0.018369    0.854169    
#> 061: 0.438972    0.841211    3.424941    0.333050    0.066996    0.017450    0.870795    
#> 062: 0.409781    0.881651    3.422526    0.334269    0.063646    0.016578    0.871652    
#> 063: 0.422110    0.868533    3.417409    0.317556    0.060464    0.015749    0.868673    
#> 064: 0.413915    0.865232    3.422061    0.314800    0.062870    0.014962    0.851765    
#> 065: 0.420538    0.849064    3.407090    0.349038    0.073900    0.014214    0.836875    
#> 066: 0.389252    0.883772    3.407250    0.333869    0.070205    0.013503    0.816001    
#> 067: 0.409640    0.881569    3.408385    0.323698    0.066695    0.014240    0.816143    
#> 068: 0.359600    0.879846    3.417251    0.307513    0.063360    0.018693    0.813593    
#> 069: 0.364526    0.881615    3.395095    0.330916    0.060192    0.017758    0.819288    
#> 070: 0.377767    0.894828    3.395939    0.414293    0.057183    0.018820    0.807053    
#> 071: 0.318097    0.951994    3.360031    0.419260    0.062019    0.019359    0.810613    
#> 072: 0.291206    0.917679    3.366479    0.427287    0.058918    0.018391    0.799362    
#> 073: 0.315675    0.924209    3.373862    0.419864    0.055973    0.017471    0.803111    
#> 074: 0.292592    0.908363    3.366296    0.398870    0.053174    0.016598    0.815581    
#> 075: 0.338041    0.896753    3.389608    0.432155    0.052433    0.015768    0.798767    
#> 076: 0.377133    0.894942    3.391224    0.410547    0.063219    0.015763    0.802954    
#> 077: 0.422231    0.870330    3.399371    0.448198    0.060058    0.014975    0.817297    
#> 078: 0.388838    0.878617    3.411629    0.425788    0.057625    0.014226    0.816173    
#> 079: 0.430573    0.894661    3.408013    0.404498    0.054744    0.018870    0.845038    
#> 080: 0.392450    0.884595    3.399216    0.393666    0.052788    0.017926    0.859585    
#> 081: 0.371086    0.887054    3.395907    0.373983    0.050306    0.017030    0.846230    
#> 082: 0.358250    0.887235    3.400872    0.385636    0.048946    0.018219    0.836040    
#> 083: 0.385880    0.910379    3.389384    0.477427    0.060935    0.018032    0.819956    
#> 084: 0.362224    0.890207    3.388045    0.453556    0.068469    0.017130    0.793427    
#> 085: 0.392212    0.883022    3.412738    0.430878    0.065046    0.016274    0.796736    
#> 086: 0.395521    0.886843    3.403342    0.471001    0.062365    0.015460    0.799566    
#> 087: 0.370310    0.879314    3.398276    0.462054    0.070263    0.014687    0.791151    
#> 088: 0.318199    0.879907    3.394690    0.438951    0.070643    0.013953    0.812421    
#> 089: 0.352495    0.892458    3.389077    0.417004    0.067111    0.013255    0.832233    
#> 090: 0.358526    0.905773    3.386335    0.396154    0.063755    0.012592    0.821741    
#> 091: 0.330588    0.894122    3.369543    0.376346    0.071531    0.011963    0.811134    
#> 092: 0.325160    0.919305    3.361612    0.366388    0.067954    0.011364    0.795033    
#> 093: 0.299577    0.901580    3.368690    0.348068    0.064556    0.011287    0.820260    
#> 094: 0.325938    0.910404    3.361174    0.367806    0.061328    0.013512    0.817994    
#> 095: 0.341314    0.910107    3.385396    0.360829    0.075286    0.012837    0.804306    
#> 096: 0.323587    0.892745    3.387256    0.348728    0.084210    0.012694    0.815476    
#> 097: 0.368590    0.919192    3.385756    0.397201    0.079999    0.012520    0.796732    
#> 098: 0.344386    0.928160    3.384518    0.377341    0.075999    0.012595    0.811480    
#> 099: 0.310108    0.905858    3.370093    0.358474    0.072199    0.014107    0.815706    
#> 100: 0.297167    0.913107    3.371545    0.359677    0.071752    0.013402    0.792471    
#> 101: 0.300533    0.894728    3.360690    0.347962    0.068164    0.013705    0.788486    
#> 102: 0.318267    0.910714    3.350223    0.417240    0.064756    0.013020    0.792098    
#> 103: 0.331069    0.898701    3.368106    0.396378    0.061518    0.012749    0.787034    
#> 104: 0.285920    0.918270    3.376932    0.399447    0.059343    0.016865    0.818060    
#> 105: 0.276619    0.902045    3.375606    0.380222    0.056549    0.016022    0.816448    
#> 106: 0.330935    0.914895    3.362285    0.452811    0.054963    0.015221    0.798792    
#> 107: 0.343619    0.942018    3.369248    0.449321    0.062089    0.014460    0.787247    
#> 108: 0.301961    0.923417    3.356489    0.437337    0.068041    0.013737    0.803529    
#> 109: 0.285094    0.925334    3.369283    0.415470    0.067793    0.013050    0.821656    
#> 110: 0.316567    0.901979    3.361127    0.394697    0.064403    0.012397    0.814250    
#> 111: 0.350292    0.888336    3.374795    0.406638    0.061183    0.011778    0.801954    
#> 112: 0.343309    0.892246    3.362475    0.386306    0.058124    0.011189    0.808524    
#> 113: 0.297169    0.926832    3.356883    0.406066    0.055218    0.011825    0.786318    
#> 114: 0.330248    0.930943    3.373929    0.385763    0.056573    0.014954    0.778551    
#> 115: 0.369602    0.891479    3.377503    0.413455    0.054117    0.014207    0.804551    
#> 116: 0.346798    0.899167    3.381174    0.392782    0.053715    0.013496    0.810114    
#> 117: 0.336581    0.924893    3.384772    0.392688    0.057426    0.012822    0.811563    
#> 118: 0.331762    0.910967    3.380614    0.373053    0.057694    0.012180    0.807610    
#> 119: 0.345869    0.909958    3.383272    0.405853    0.054810    0.012607    0.814521    
#> 120: 0.333386    0.894186    3.379491    0.430500    0.069495    0.013591    0.780826    
#> 121: 0.375948    0.908367    3.387432    0.461796    0.069658    0.012911    0.794434    
#> 122: 0.332141    0.894665    3.386754    0.438706    0.066175    0.013357    0.809111    
#> 123: 0.380703    0.930711    3.386629    0.416771    0.063415    0.013905    0.800542    
#> 124: 0.396345    0.934558    3.385484    0.395932    0.060245    0.013210    0.803028    
#> 125: 0.376279    0.924510    3.382961    0.376136    0.062873    0.013578    0.800272    
#> 126: 0.320859    0.940988    3.367999    0.357329    0.066506    0.012899    0.797748    
#> 127: 0.316689    0.932699    3.356220    0.339462    0.069053    0.012254    0.825546    
#> 128: 0.289378    0.927007    3.369194    0.322489    0.065600    0.012941    0.813809    
#> 129: 0.343222    0.927076    3.378275    0.331424    0.068887    0.012294    0.819990    
#> 130: 0.372873    0.921748    3.381145    0.328587    0.072596    0.012495    0.803937    
#> 131: 0.355905    0.889971    3.377810    0.349242    0.073448    0.013060    0.794026    
#> 132: 0.352298    0.915741    3.366025    0.391602    0.069775    0.012407    0.803411    
#> 133: 0.341075    0.897316    3.375579    0.412226    0.066287    0.013959    0.814280    
#> 134: 0.352038    0.873064    3.387305    0.419585    0.062972    0.016859    0.827122    
#> 135: 0.333675    0.878530    3.387465    0.427576    0.059824    0.017011    0.824780    
#> 136: 0.364374    0.860275    3.387700    0.406197    0.068914    0.016161    0.809763    
#> 137: 0.411032    0.872735    3.399657    0.435926    0.065469    0.015500    0.824378    
#> 138: 0.377580    0.885012    3.389615    0.440326    0.062195    0.016583    0.819538    
#> 139: 0.363475    0.900323    3.399624    0.443738    0.059086    0.018373    0.826774    
#> 140: 0.362998    0.900425    3.400587    0.421551    0.056131    0.021031    0.850397    
#> 141: 0.332052    0.883771    3.392050    0.412651    0.054936    0.019979    0.807270    
#> 142: 0.384958    0.867715    3.406415    0.422608    0.056921    0.018980    0.795396    
#> 143: 0.357552    0.885336    3.392349    0.407334    0.054075    0.019734    0.801497    
#> 144: 0.372402    0.883795    3.401694    0.386967    0.051371    0.021002    0.798767    
#> 145: 0.345097    0.904657    3.379299    0.384614    0.048802    0.019952    0.792758    
#> 146: 0.344962    0.907799    3.389007    0.445057    0.063775    0.018955    0.804394    
#> 147: 0.307007    0.897875    3.372054    0.422804    0.061676    0.018007    0.798681    
#> 148: 0.278294    0.912784    3.377993    0.401664    0.058592    0.017107    0.793916    
#> 149: 0.281385    0.891487    3.392135    0.381580    0.055663    0.016251    0.818548    
#> 150: 0.325554    0.894118    3.375730    0.362501    0.057554    0.015439    0.831222    
#> 151: 0.294136    0.925069    3.375995    0.344376    0.059081    0.014667    0.809206    
#> 152: 0.290081    0.922500    3.374771    0.332316    0.062857    0.016403    0.806438    
#> 153: 0.273140    0.924348    3.368751    0.296078    0.063394    0.015466    0.819532    
#> 154: 0.344114    0.926051    3.385133    0.308410    0.065789    0.013820    0.814680    
#> 155: 0.317192    0.910457    3.375153    0.397709    0.047964    0.013499    0.798748    
#> 156: 0.334437    0.915445    3.386875    0.374139    0.051341    0.012970    0.816290    
#> 157: 0.343014    0.904032    3.396823    0.359936    0.057038    0.015449    0.842738    
#> 158: 0.403129    0.911656    3.388790    0.352275    0.055373    0.014576    0.798726    
#> 159: 0.356459    0.914190    3.397762    0.320078    0.058718    0.012994    0.817851    
#> 160: 0.356179    0.878203    3.402429    0.301244    0.059941    0.012500    0.820631    
#> 161: 0.369564    0.907497    3.392287    0.404348    0.060264    0.015895    0.789114    
#> 162: 0.359590    0.922991    3.375683    0.384807    0.044265    0.017816    0.800310    
#> 163: 0.332476    0.909019    3.368998    0.329949    0.047101    0.019644    0.797401    
#> 164: 0.320308    0.909752    3.374004    0.279791    0.058231    0.018908    0.804904    
#> 165: 0.364996    0.887787    3.387104    0.377217    0.055871    0.015106    0.799816    
#> 166: 0.380786    0.919385    3.380467    0.379542    0.058063    0.017613    0.811593    
#> 167: 0.377603    0.938308    3.388992    0.384824    0.057362    0.017475    0.794538    
#> 168: 0.384190    0.917348    3.391520    0.404211    0.061082    0.018277    0.789930    
#> 169: 0.358120    0.934779    3.371636    0.410006    0.058406    0.014346    0.798469    
#> 170: 0.324389    0.913690    3.378248    0.334395    0.063906    0.013045    0.796467    
#> 171: 0.322540    0.928308    3.368262    0.387081    0.062320    0.013156    0.783149    
#> 172: 0.322905    0.932534    3.377781    0.406441    0.047133    0.011793    0.799459    
#> 173: 0.294790    0.949978    3.359302    0.350924    0.050469    0.015417    0.808104    
#> 174: 0.297336    0.930155    3.373704    0.340798    0.054657    0.014315    0.821414    
#> 175: 0.305169    0.927760    3.364904    0.391631    0.051010    0.013985    0.835400    
#> 176: 0.284236    0.944324    3.369543    0.323608    0.057309    0.012474    0.827254    
#> 177: 0.318196    0.925092    3.384974    0.390619    0.067542    0.013499    0.808776    
#> 178: 0.343344    0.916167    3.380196    0.356955    0.064140    0.012338    0.797694    
#> 179: 0.388472    0.924675    3.372840    0.420774    0.072498    0.012376    0.803555    
#> 180: 0.313029    0.918805    3.374929    0.362458    0.071335    0.008820    0.813887    
#> 181: 0.318454    0.923551    3.355563    0.338813    0.063025    0.008709    0.810603    
#> 182: 0.297469    0.925670    3.346212    0.430219    0.061261    0.008424    0.812490    
#> 183: 0.291865    0.948307    3.347017    0.330769    0.057624    0.008122    0.822881    
#> 184: 0.259552    0.952520    3.338707    0.308065    0.059358    0.008210    0.813426    
#> 185: 0.253146    0.953000    3.339406    0.308626    0.070115    0.007277    0.828335    
#> 186: 0.283868    0.960393    3.351883    0.333178    0.067146    0.006516    0.823728    
#> 187: 0.302716    0.903217    3.371017    0.283864    0.069717    0.006903    0.831494    
#> 188: 0.254222    0.924101    3.361665    0.281343    0.072425    0.007129    0.850446    
#> 189: 0.314253    0.930338    3.371731    0.281295    0.063370    0.006657    0.834774    
#> 190: 0.303946    0.927552    3.375616    0.339611    0.060144    0.006825    0.830144    
#> 191: 0.286199    0.927950    3.355058    0.323101    0.060996    0.007014    0.810886    
#> 192: 0.288962    0.932884    3.363551    0.339270    0.064961    0.007043    0.802856    
#> 193: 0.329778    0.947475    3.365903    0.330337    0.061334    0.008175    0.792363    
#> 194: 0.295519    0.929039    3.364954    0.339068    0.059401    0.010067    0.801344    
#> 195: 0.261290    0.937698    3.362166    0.326021    0.065089    0.009788    0.810245    
#> 196: 0.333464    0.937890    3.370891    0.339873    0.070005    0.010345    0.805568    
#> 197: 0.296821    0.930932    3.381709    0.303678    0.062237    0.011544    0.807024    
#> 198: 0.340963    0.897340    3.371126    0.346422    0.060799    0.011823    0.824928    
#> 199: 0.300516    0.907898    3.367097    0.284155    0.056224    0.012822    0.829641    
#> 200: 0.308268    0.906015    3.379641    0.344172    0.056469    0.011726    0.833386    
#> 201: 0.308293    0.901836    3.375601    0.359296    0.057527    0.013918    0.819154    
#> 202: 0.320265    0.903111    3.375241    0.373581    0.057994    0.013971    0.816506    
#> 203: 0.332686    0.901088    3.374359    0.386221    0.059567    0.014182    0.815189    
#> 204: 0.332690    0.900260    3.375656    0.382653    0.059428    0.014333    0.815154    
#> 205: 0.331155    0.906539    3.377456    0.383102    0.060413    0.015036    0.812485    
#> 206: 0.330855    0.910703    3.378924    0.385668    0.059392    0.015713    0.810484    
#> 207: 0.328951    0.912241    3.378092    0.388711    0.058754    0.016129    0.807810    
#> 208: 0.324714    0.913284    3.377053    0.392887    0.057878    0.016218    0.804598    
#> 209: 0.329639    0.911345    3.376618    0.395935    0.056743    0.016599    0.803401    
#> 210: 0.331210    0.909413    3.376769    0.398698    0.055692    0.016654    0.802982    
#> 211: 0.336089    0.908117    3.378869    0.400231    0.054938    0.016383    0.801501    
#> 212: 0.342603    0.905209    3.380520    0.395940    0.054803    0.016335    0.803925    
#> 213: 0.346175    0.900985    3.382810    0.388077    0.055573    0.016400    0.805457    
#> 214: 0.351737    0.899327    3.384879    0.381208    0.055672    0.016303    0.805968    
#> 215: 0.352003    0.899530    3.385999    0.376983    0.055531    0.016373    0.806723    
#> 216: 0.354648    0.897907    3.386389    0.378911    0.055244    0.016422    0.809487    
#> 217: 0.355028    0.899171    3.386591    0.377527    0.054687    0.016400    0.809799    
#> 218: 0.354243    0.900042    3.385788    0.378279    0.054582    0.016466    0.809773    
#> 219: 0.352725    0.900016    3.384610    0.381021    0.054152    0.016591    0.809885    
#> 220: 0.350007    0.901408    3.383564    0.384462    0.054223    0.016613    0.808838    
#> 221: 0.347568    0.902414    3.382851    0.385428    0.054488    0.016577    0.807796    
#> 222: 0.346467    0.903032    3.382119    0.383981    0.054285    0.016654    0.807854    
#> 223: 0.346026    0.903905    3.381673    0.383511    0.053985    0.016691    0.807848    
#> 224: 0.346491    0.905039    3.381455    0.382550    0.053504    0.016860    0.808056    
#> 225: 0.345307    0.903734    3.382160    0.381934    0.053339    0.016881    0.808272    
#> 226: 0.346153    0.902614    3.382367    0.380515    0.053122    0.016823    0.808452    
#> 227: 0.346413    0.901711    3.382966    0.381136    0.053150    0.016661    0.808575    
#> 228: 0.346283    0.902236    3.382628    0.382248    0.052881    0.016595    0.808588    
#> 229: 0.346250    0.901944    3.382581    0.380910    0.052727    0.016555    0.807856    
#> 230: 0.345951    0.902046    3.382453    0.378871    0.052680    0.016580    0.807653    
#> 231: 0.346887    0.902523    3.382971    0.377847    0.052442    0.016468    0.807930    
#> 232: 0.346388    0.902093    3.383425    0.375957    0.052291    0.016387    0.808638    
#> 233: 0.346423    0.901030    3.383607    0.375315    0.052091    0.016355    0.808966    
#> 234: 0.345224    0.901129    3.383569    0.376718    0.051854    0.016406    0.808511    
#> 235: 0.344179    0.900725    3.383424    0.376396    0.051735    0.016540    0.808515    
#> 236: 0.344097    0.901033    3.383275    0.377070    0.051291    0.016620    0.808902    
#> 237: 0.345354    0.901110    3.383197    0.379993    0.051204    0.016662    0.809012    
#> 238: 0.347581    0.901429    3.383370    0.385148    0.051151    0.016841    0.809508    
#> 239: 0.348259    0.902408    3.383437    0.388931    0.051271    0.016932    0.809571    
#> 240: 0.349061    0.902669    3.383582    0.393249    0.051496    0.016934    0.808951    
#> 241: 0.350377    0.901934    3.383925    0.395451    0.051524    0.016903    0.808920    
#> 242: 0.350094    0.901368    3.383920    0.395153    0.051988    0.016844    0.809388    
#> 243: 0.349994    0.901941    3.383882    0.394569    0.052480    0.016726    0.809552    
#> 244: 0.349701    0.901536    3.384066    0.394885    0.052703    0.016617    0.809754    
#> 245: 0.349332    0.901359    3.383847    0.394460    0.052961    0.016495    0.810182    
#> 246: 0.349298    0.901044    3.383931    0.394259    0.053012    0.016506    0.810161    
#> 247: 0.348849    0.900977    3.384078    0.394341    0.053375    0.016479    0.810140    
#> 248: 0.348232    0.901257    3.384079    0.393394    0.053581    0.016447    0.809967    
#> 249: 0.347511    0.901443    3.383914    0.393891    0.053518    0.016391    0.809915    
#> 250: 0.348038    0.901914    3.384013    0.394317    0.053585    0.016363    0.810117    
#> 251: 0.347631    0.902328    3.384244    0.393710    0.053616    0.016335    0.810226    
#> 252: 0.348068    0.902314    3.384619    0.393837    0.053415    0.016367    0.810328    
#> 253: 0.348276    0.902294    3.384722    0.393577    0.053219    0.016368    0.810173    
#> 254: 0.348314    0.902542    3.384852    0.392828    0.052884    0.016372    0.810417    
#> 255: 0.347836    0.902782    3.384884    0.391224    0.052794    0.016321    0.810703    
#> 256: 0.347971    0.902682    3.384873    0.390263    0.052857    0.016296    0.810677    
#> 257: 0.348073    0.902472    3.384876    0.390292    0.052955    0.016305    0.810460    
#> 258: 0.347867    0.902127    3.384906    0.389465    0.053165    0.016263    0.810246    
#> 259: 0.348081    0.902014    3.384869    0.389465    0.053155    0.016211    0.810461    
#> 260: 0.348226    0.902246    3.384998    0.389417    0.053245    0.016163    0.810391    
#> 261: 0.348254    0.902096    3.385317    0.389087    0.053410    0.016062    0.810461    
#> 262: 0.348673    0.902170    3.385537    0.389628    0.053442    0.015967    0.810422    
#> 263: 0.348143    0.902492    3.385593    0.388781    0.053482    0.015929    0.810482    
#> 264: 0.348273    0.902602    3.385611    0.389688    0.053662    0.015942    0.810441    
#> 265: 0.348657    0.902721    3.385760    0.389447    0.053715    0.015932    0.810483    
#> 266: 0.349107    0.902836    3.385795    0.390342    0.053607    0.015972    0.810475    
#> 267: 0.349374    0.902771    3.385978    0.391663    0.053510    0.016013    0.810298    
#> 268: 0.349553    0.902578    3.385953    0.391926    0.053615    0.015982    0.810202    
#> 269: 0.349681    0.902379    3.385982    0.391991    0.053670    0.015983    0.810126    
#> 270: 0.349767    0.902322    3.385933    0.391615    0.053601    0.015929    0.809831    
#> 271: 0.349795    0.902205    3.385878    0.391136    0.053675    0.015892    0.809778    
#> 272: 0.349966    0.902054    3.385802    0.391318    0.053730    0.015865    0.809932    
#> 273: 0.349798    0.902299    3.385822    0.392170    0.053794    0.015830    0.809936    
#> 274: 0.349655    0.902520    3.385852    0.391965    0.054001    0.015778    0.809725    
#> 275: 0.349469    0.902645    3.385754    0.391860    0.054212    0.015745    0.809435    
#> 276: 0.349031    0.902911    3.385765    0.391700    0.054283    0.015715    0.809350    
#> 277: 0.349092    0.903136    3.385899    0.391457    0.054272    0.015724    0.809182    
#> 278: 0.349227    0.903127    3.386056    0.391604    0.054277    0.015757    0.809320    
#> 279: 0.349310    0.903038    3.386040    0.391683    0.054274    0.015709    0.809418    
#> 280: 0.348892    0.903057    3.386045    0.391322    0.054391    0.015678    0.809352    
#> 281: 0.348534    0.903097    3.386072    0.390678    0.054560    0.015667    0.809515    
#> 282: 0.347966    0.903391    3.386017    0.390201    0.054643    0.015681    0.809764    
#> 283: 0.347604    0.903317    3.386117    0.389708    0.054717    0.015713    0.810072    
#> 284: 0.347503    0.903054    3.386133    0.389518    0.054907    0.015732    0.809972    
#> 285: 0.347789    0.903085    3.386047    0.390919    0.054942    0.015774    0.809731    
#> 286: 0.347709    0.903083    3.385988    0.391017    0.054823    0.015817    0.809746    
#> 287: 0.347826    0.903071    3.385949    0.391508    0.054783    0.015799    0.809511    
#> 288: 0.348056    0.902951    3.385813    0.392090    0.054648    0.015829    0.809490    
#> 289: 0.348421    0.902746    3.385747    0.392970    0.054688    0.015790    0.809333    
#> 290: 0.348347    0.902745    3.385732    0.392853    0.054823    0.015766    0.809213    
#> 291: 0.348594    0.902986    3.385813    0.392444    0.054952    0.015733    0.809165    
#> 292: 0.348579    0.903184    3.385821    0.392072    0.055007    0.015717    0.809239    
#> 293: 0.348461    0.903261    3.385697    0.391859    0.054979    0.015704    0.809171    
#> 294: 0.347890    0.903594    3.385473    0.391780    0.055029    0.015722    0.808922    
#> 295: 0.347872    0.903694    3.385285    0.392920    0.055111    0.015721    0.808830    
#> 296: 0.347925    0.903781    3.385141    0.393909    0.055215    0.015697    0.808772    
#> 297: 0.348009    0.903749    3.385070    0.394383    0.055163    0.015700    0.808685    
#> 298: 0.348263    0.903661    3.385092    0.395237    0.055155    0.015714    0.808599    
#> 299: 0.348868    0.903806    3.385013    0.395917    0.055097    0.015712    0.808395    
#> 300: 0.349317    0.903741    3.385082    0.395870    0.055014    0.015706    0.808318    
#> 301: 0.349625    0.903436    3.385086    0.395952    0.054860    0.015700    0.808277    
#> 302: 0.349754    0.903249    3.385116    0.395839    0.054763    0.015670    0.808261    
#> 303: 0.349676    0.903279    3.385073    0.396117    0.054751    0.015615    0.808170    
#> 304: 0.349629    0.903541    3.384968    0.395882    0.054756    0.015584    0.808412    
#> 305: 0.349387    0.903488    3.384863    0.395676    0.054698    0.015560    0.808366    
#> 306: 0.348962    0.903338    3.384793    0.395052    0.054798    0.015552    0.808491    
#> 307: 0.348567    0.903351    3.384713    0.394494    0.054745    0.015553    0.808793    
#> 308: 0.347958    0.903251    3.384622    0.393946    0.054613    0.015593    0.809187    
#> 309: 0.347635    0.903086    3.384514    0.393720    0.054737    0.015626    0.809410    
#> 310: 0.347715    0.903095    3.384286    0.394446    0.054836    0.015613    0.809552    
#> 311: 0.347514    0.903070    3.384173    0.393947    0.054884    0.015565    0.809529    
#> 312: 0.347345    0.902950    3.384071    0.393710    0.054876    0.015519    0.809487    
#> 313: 0.347298    0.902665    3.384015    0.393255    0.054964    0.015502    0.809546    
#> 314: 0.347044    0.902684    3.383934    0.393255    0.054924    0.015494    0.809390    
#> 315: 0.346787    0.902776    3.383893    0.392546    0.054878    0.015465    0.809329    
#> 316: 0.346828    0.902868    3.383862    0.391682    0.054929    0.015428    0.809315    
#> 317: 0.346719    0.902806    3.383928    0.391525    0.054970    0.015400    0.809396    
#> 318: 0.346875    0.902922    3.383855    0.391800    0.055127    0.015389    0.809179    
#> 319: 0.347001    0.903063    3.383877    0.391902    0.055218    0.015390    0.809226    
#> 320: 0.346165    0.903125    3.383658    0.391550    0.055315    0.015379    0.809201    
#> 321: 0.345400    0.903333    3.383330    0.391498    0.055325    0.015353    0.809345    
#> 322: 0.344963    0.903465    3.383129    0.390773    0.055347    0.015350    0.809392    
#> 323: 0.344375    0.903659    3.382938    0.390446    0.055359    0.015321    0.809454    
#> 324: 0.344025    0.903945    3.382842    0.390282    0.055416    0.015312    0.809334    
#> 325: 0.344018    0.904323    3.382738    0.389535    0.055403    0.015291    0.809451    
#> 326: 0.343970    0.904338    3.382650    0.389473    0.055272    0.015284    0.809417    
#> 327: 0.343984    0.904439    3.382637    0.389098    0.055172    0.015315    0.809463    
#> 328: 0.344127    0.904632    3.382643    0.388736    0.055186    0.015326    0.809367    
#> 329: 0.344156    0.904717    3.382623    0.388794    0.055200    0.015318    0.809323    
#> 330: 0.344029    0.904684    3.382564    0.388560    0.055319    0.015289    0.809295    
#> 331: 0.344104    0.904852    3.382491    0.388758    0.055385    0.015284    0.809200    
#> 332: 0.343908    0.904756    3.382452    0.388379    0.055430    0.015270    0.809341    
#> 333: 0.343934    0.904683    3.382429    0.388261    0.055369    0.015263    0.809416    
#> 334: 0.343568    0.904592    3.382250    0.388143    0.055366    0.015269    0.809390    
#> 335: 0.343122    0.904604    3.382138    0.388206    0.055350    0.015247    0.809426    
#> 336: 0.342676    0.904737    3.381983    0.387907    0.055244    0.015248    0.809440    
#> 337: 0.342569    0.905097    3.381845    0.388140    0.055311    0.015263    0.809420    
#> 338: 0.342556    0.905231    3.381835    0.388483    0.055341    0.015291    0.809347    
#> 339: 0.342292    0.905338    3.381762    0.388673    0.055411    0.015291    0.809245    
#> 340: 0.342193    0.905312    3.381723    0.388475    0.055449    0.015304    0.809096    
#> 341: 0.342215    0.905438    3.381713    0.388061    0.055461    0.015303    0.809105    
#> 342: 0.342066    0.905409    3.381690    0.388088    0.055404    0.015295    0.809064    
#> 343: 0.341547    0.905555    3.381661    0.387460    0.055399    0.015307    0.809118    
#> 344: 0.341499    0.905583    3.381698    0.386816    0.055420    0.015289    0.809134    
#> 345: 0.341335    0.905529    3.381782    0.386261    0.055495    0.015267    0.809178    
#> 346: 0.341229    0.905557    3.381793    0.385567    0.055502    0.015268    0.809094    
#> 347: 0.341400    0.905465    3.381783    0.385743    0.055475    0.015260    0.809109    
#> 348: 0.341345    0.905601    3.381794    0.385578    0.055414    0.015245    0.809250    
#> 349: 0.341475    0.905528    3.381859    0.385881    0.055399    0.015238    0.809184    
#> 350: 0.341299    0.905306    3.381860    0.386079    0.055363    0.015262    0.809171    
#> 351: 0.341615    0.905414    3.381807    0.386471    0.055404    0.015284    0.809216    
#> 352: 0.341390    0.905573    3.381778    0.386773    0.055434    0.015298    0.809219    
#> 353: 0.341573    0.905728    3.381787    0.386593    0.055592    0.015296    0.809200    
#> 354: 0.341462    0.905807    3.381647    0.387180    0.055657    0.015303    0.809003    
#> 355: 0.341554    0.905744    3.381570    0.386988    0.055733    0.015294    0.808994    
#> 356: 0.341443    0.905680    3.381610    0.386628    0.055774    0.015287    0.809162    
#> 357: 0.341539    0.905740    3.381632    0.386537    0.055759    0.015288    0.809112    
#> 358: 0.341661    0.905751    3.381728    0.386565    0.055727    0.015275    0.808985    
#> 359: 0.341645    0.905841    3.381673    0.386688    0.055694    0.015267    0.808840    
#> 360: 0.341568    0.905990    3.381545    0.386571    0.055612    0.015266    0.808714    
#> 361: 0.341349    0.906058    3.381420    0.386277    0.055581    0.015245    0.808650    
#> 362: 0.341449    0.906133    3.381353    0.386178    0.055559    0.015228    0.808524    
#> 363: 0.341511    0.906215    3.381320    0.386161    0.055575    0.015228    0.808285    
#> 364: 0.341670    0.906301    3.381320    0.386308    0.055556    0.015222    0.808341    
#> 365: 0.341715    0.906273    3.381360    0.386103    0.055622    0.015230    0.808442    
#> 366: 0.341648    0.906325    3.381274    0.385840    0.055575    0.015208    0.808460    
#> 367: 0.341671    0.906373    3.381267    0.385929    0.055550    0.015185    0.808412    
#> 368: 0.341932    0.906543    3.381273    0.386137    0.055543    0.015164    0.808241    
#> 369: 0.341922    0.906629    3.381259    0.386226    0.055496    0.015167    0.808161    
#> 370: 0.341854    0.906735    3.381253    0.386180    0.055541    0.015157    0.808077    
#> 371: 0.341897    0.906722    3.381158    0.386168    0.055500    0.015146    0.808043    
#> 372: 0.341915    0.906803    3.381159    0.386142    0.055529    0.015120    0.807915    
#> 373: 0.341797    0.907031    3.381133    0.385764    0.055579    0.015108    0.807895    
#> 374: 0.341675    0.906961    3.381101    0.385334    0.055566    0.015095    0.807896    
#> 375: 0.341444    0.906988    3.381073    0.384804    0.055498    0.015074    0.808125    
#> 376: 0.341445    0.906965    3.381030    0.384489    0.055459    0.015062    0.808262    
#> 377: 0.341478    0.907000    3.381003    0.384460    0.055516    0.015032    0.808334    
#> 378: 0.341198    0.907013    3.380895    0.384208    0.055567    0.015008    0.808532    
#> 379: 0.340986    0.906905    3.380883    0.383879    0.055584    0.014994    0.808717    
#> 380: 0.341059    0.906830    3.380939    0.383422    0.055668    0.014992    0.808615    
#> 381: 0.340753    0.906852    3.380933    0.383004    0.055716    0.014981    0.808663    
#> 382: 0.340762    0.906813    3.380962    0.382687    0.055731    0.014980    0.808722    
#> 383: 0.340856    0.906745    3.380994    0.382599    0.055867    0.014973    0.808708    
#> 384: 0.340852    0.906687    3.381009    0.382824    0.055855    0.014989    0.808738    
#> 385: 0.340835    0.906701    3.381050    0.382641    0.055890    0.015010    0.808848    
#> 386: 0.340934    0.906901    3.381076    0.382717    0.055909    0.015015    0.808931    
#> 387: 0.341007    0.907024    3.381117    0.382449    0.055918    0.015024    0.808994    
#> 388: 0.341161    0.907078    3.381200    0.382400    0.055912    0.015024    0.808942    
#> 389: 0.341191    0.906844    3.381250    0.382319    0.055943    0.015002    0.809002    
#> 390: 0.341179    0.906827    3.381288    0.382247    0.055998    0.014986    0.809052    
#> 391: 0.341246    0.906731    3.381289    0.382076    0.055994    0.014991    0.809008    
#> 392: 0.341385    0.906684    3.381319    0.382003    0.056034    0.015001    0.808970    
#> 393: 0.341384    0.906525    3.381294    0.381966    0.056089    0.014998    0.808930    
#> 394: 0.341370    0.906570    3.381274    0.381630    0.056105    0.014996    0.808990    
#> 395: 0.341584    0.906622    3.381283    0.381576    0.056214    0.014984    0.808979    
#> 396: 0.341731    0.906739    3.381272    0.381476    0.056272    0.014982    0.808954    
#> 397: 0.341810    0.906756    3.381290    0.381831    0.056329    0.014976    0.808945    
#> 398: 0.341967    0.906763    3.381285    0.382199    0.056371    0.014969    0.808875    
#> 399: 0.342063    0.906841    3.381341    0.382317    0.056433    0.014974    0.808746    
#> 400: 0.342201    0.906871    3.381395    0.382245    0.056486    0.014970    0.808708    
#> 401: 0.342304    0.906919    3.381409    0.382199    0.056499    0.014970    0.808868    
#> 402: 0.342411    0.906977    3.381439    0.382260    0.056593    0.014967    0.808884    
#> 403: 0.342782    0.906934    3.381468    0.382431    0.056635    0.014948    0.808985    
#> 404: 0.342780    0.906851    3.381455    0.382032    0.056710    0.014935    0.808954    
#> 405: 0.342665    0.906846    3.381483    0.381944    0.056757    0.014936    0.808955    
#> 406: 0.342875    0.906813    3.381507    0.382448    0.056776    0.014931    0.809001    
#> 407: 0.343074    0.906796    3.381511    0.382847    0.056809    0.014945    0.808901    
#> 408: 0.343399    0.906820    3.381525    0.383157    0.056795    0.014941    0.808928    
#> 409: 0.343450    0.906725    3.381534    0.383074    0.056811    0.014935    0.808864    
#> 410: 0.343396    0.906707    3.381495    0.382823    0.056824    0.014935    0.808830    
#> 411: 0.343507    0.906542    3.381490    0.382909    0.056856    0.014934    0.808911    
#> 412: 0.343467    0.906558    3.381474    0.382766    0.056838    0.014927    0.809029    
#> 413: 0.343361    0.906582    3.381395    0.382608    0.056841    0.014917    0.809096    
#> 414: 0.343133    0.906569    3.381410    0.382404    0.056841    0.014927    0.808980    
#> 415: 0.343244    0.906546    3.381414    0.382170    0.056843    0.014935    0.808943    
#> 416: 0.343268    0.906593    3.381402    0.381939    0.056833    0.014929    0.808978    
#> 417: 0.343287    0.906532    3.381439    0.381447    0.056866    0.014923    0.808964    
#> 418: 0.343376    0.906447    3.381516    0.381451    0.056900    0.014917    0.808928    
#> 419: 0.343569    0.906383    3.381590    0.381662    0.056860    0.014912    0.808897    
#> 420: 0.343960    0.906296    3.381691    0.381806    0.056835    0.014916    0.808799    
#> 421: 0.343908    0.906243    3.381753    0.381802    0.056859    0.014923    0.808639    
#> 422: 0.344152    0.906121    3.381796    0.381984    0.056847    0.014928    0.808593    
#> 423: 0.344331    0.906016    3.381797    0.382071    0.056812    0.014929    0.808579    
#> 424: 0.344175    0.905990    3.381767    0.381947    0.056772    0.014931    0.808580    
#> 425: 0.344233    0.906078    3.381744    0.382113    0.056766    0.014942    0.808610    
#> 426: 0.344233    0.906164    3.381757    0.382101    0.056731    0.014937    0.808642    
#> 427: 0.344119    0.906169    3.381736    0.381876    0.056723    0.014919    0.808551    
#> 428: 0.343892    0.906253    3.381668    0.381888    0.056723    0.014915    0.808607    
#> 429: 0.343889    0.906316    3.381628    0.381948    0.056709    0.014907    0.808617    
#> 430: 0.343733    0.906348    3.381606    0.381719    0.056717    0.014916    0.808644    
#> 431: 0.343683    0.906389    3.381605    0.381401    0.056704    0.014921    0.808683    
#> 432: 0.343512    0.906518    3.381611    0.381289    0.056705    0.014929    0.808698    
#> 433: 0.343538    0.906653    3.381614    0.381683    0.056743    0.014937    0.808671    
#> 434: 0.343493    0.906623    3.381596    0.381881    0.056751    0.014937    0.808638    
#> 435: 0.343598    0.906593    3.381620    0.381806    0.056738    0.014931    0.808674    
#> 436: 0.343640    0.906523    3.381636    0.381526    0.056744    0.014916    0.808730    
#> 437: 0.343819    0.906455    3.381650    0.381419    0.056739    0.014927    0.808772    
#> 438: 0.344021    0.906485    3.381701    0.381632    0.056713    0.014930    0.808659    
#> 439: 0.344203    0.906590    3.381749    0.381861    0.056644    0.014948    0.808518    
#> 440: 0.344265    0.906626    3.381783    0.381808    0.056636    0.014935    0.808400    
#> 441: 0.344302    0.906551    3.381837    0.381531    0.056620    0.014942    0.808321    
#> 442: 0.344168    0.906511    3.381860    0.381313    0.056583    0.014934    0.808285    
#> 443: 0.344207    0.906529    3.381815    0.381315    0.056545    0.014928    0.808210    
#> 444: 0.344025    0.906584    3.381730    0.381453    0.056513    0.014948    0.808094    
#> 445: 0.343892    0.906619    3.381663    0.381724    0.056494    0.014973    0.808000    
#> 446: 0.343777    0.906706    3.381576    0.382072    0.056436    0.014987    0.807961    
#> 447: 0.343808    0.906738    3.381587    0.382070    0.056382    0.014997    0.807971    
#> 448: 0.343717    0.906773    3.381594    0.382056    0.056362    0.015003    0.807937    
#> 449: 0.343849    0.906819    3.381672    0.382260    0.056334    0.015001    0.808026    
#> 450: 0.343874    0.906809    3.381724    0.382519    0.056377    0.014998    0.808008    
#> 451: 0.344006    0.906870    3.381703    0.382802    0.056388    0.014994    0.807981    
#> 452: 0.343985    0.906881    3.381675    0.382952    0.056433    0.014985    0.807902    
#> 453: 0.343945    0.906912    3.381628    0.382929    0.056516    0.014982    0.807846    
#> 454: 0.343821    0.906995    3.381566    0.382871    0.056505    0.014976    0.807808    
#> 455: 0.343906    0.906988    3.381566    0.382898    0.056521    0.014968    0.807742    
#> 456: 0.343863    0.906925    3.381552    0.382972    0.056540    0.014960    0.807831    
#> 457: 0.343943    0.906879    3.381570    0.382962    0.056540    0.014953    0.807806    
#> 458: 0.344063    0.906945    3.381643    0.382858    0.056552    0.014967    0.807754    
#> 459: 0.343939    0.907069    3.381653    0.382710    0.056586    0.014974    0.807723    
#> 460: 0.343938    0.906988    3.381671    0.382775    0.056553    0.014989    0.807639    
#> 461: 0.344033    0.906978    3.381736    0.382976    0.056534    0.015005    0.807508    
#> 462: 0.344019    0.907010    3.381800    0.383270    0.056488    0.015011    0.807445    
#> 463: 0.344018    0.907073    3.381807    0.383398    0.056440    0.015013    0.807418    
#> 464: 0.344106    0.907116    3.381801    0.383582    0.056415    0.015015    0.807340    
#> 465: 0.344064    0.907014    3.381803    0.383615    0.056381    0.015008    0.807275    
#> 466: 0.344018    0.907063    3.381762    0.383697    0.056353    0.014996    0.807230    
#> 467: 0.343808    0.907081    3.381741    0.383600    0.056338    0.015004    0.807154    
#> 468: 0.343823    0.907083    3.381778    0.383469    0.056321    0.015004    0.807182    
#> 469: 0.343715    0.907179    3.381787    0.383261    0.056325    0.014999    0.807334    
#> 470: 0.343659    0.907202    3.381749    0.383263    0.056265    0.015013    0.807348    
#> 471: 0.343484    0.907190    3.381719    0.383064    0.056267    0.015008    0.807393    
#> 472: 0.343444    0.907216    3.381747    0.382739    0.056239    0.015003    0.807525    
#> 473: 0.343338    0.907238    3.381729    0.382507    0.056219    0.015001    0.807595    
#> 474: 0.343266    0.907188    3.381720    0.382502    0.056176    0.015013    0.807658    
#> 475: 0.343262    0.907376    3.381671    0.382511    0.056176    0.015011    0.807707    
#> 476: 0.343244    0.907409    3.381646    0.382694    0.056129    0.015016    0.807829    
#> 477: 0.343109    0.907417    3.381630    0.382854    0.056073    0.015028    0.807814    
#> 478: 0.342972    0.907470    3.381555    0.383061    0.056070    0.015031    0.807776    
#> 479: 0.343048    0.907519    3.381537    0.383236    0.056057    0.015027    0.807784    
#> 480: 0.342987    0.907488    3.381508    0.383440    0.056078    0.015026    0.807860    
#> 481: 0.342943    0.907458    3.381517    0.383446    0.056119    0.015030    0.807836    
#> 482: 0.343091    0.907394    3.381514    0.383520    0.056133    0.015025    0.807864    
#> 483: 0.342986    0.907330    3.381509    0.383500    0.056134    0.015035    0.807860    
#> 484: 0.343059    0.907267    3.381485    0.383715    0.056136    0.015049    0.807805    
#> 485: 0.343096    0.907232    3.381522    0.383774    0.056159    0.015068    0.807752    
#> 486: 0.343155    0.907230    3.381526    0.383835    0.056168    0.015079    0.807680    
#> 487: 0.343401    0.907265    3.381581    0.383931    0.056175    0.015082    0.807632    
#> 488: 0.343366    0.907273    3.381604    0.383687    0.056196    0.015095    0.807612    
#> 489: 0.343479    0.907291    3.381553    0.383755    0.056201    0.015106    0.807574    
#> 490: 0.343530    0.907385    3.381548    0.383735    0.056165    0.015105    0.807604    
#> 491: 0.343448    0.907484    3.381552    0.383866    0.056133    0.015105    0.807626    
#> 492: 0.343396    0.907559    3.381547    0.384207    0.056146    0.015120    0.807711    
#> 493: 0.343346    0.907537    3.381559    0.384109    0.056150    0.015115    0.807789    
#> 494: 0.343330    0.907651    3.381491    0.383973    0.056156    0.015106    0.807763    
#> 495: 0.343322    0.907770    3.381443    0.384185    0.056193    0.015105    0.807761    
#> 496: 0.343387    0.907841    3.381376    0.384401    0.056210    0.015107    0.807804    
#> 497: 0.343320    0.907788    3.381346    0.384362    0.056280    0.015101    0.807808    
#> 498: 0.343217    0.907766    3.381286    0.384313    0.056291    0.015101    0.807787    
#> 499: 0.343257    0.907808    3.381246    0.384450    0.056339    0.015098    0.807777    
#> 500: 0.343286    0.907826    3.381207    0.384285    0.056390    0.015091    0.807782    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.236351    0.982657    3.438722    0.392401    0.080794    0.016800    1.671247    
#> 002: 0.169234    0.985459    3.486589    0.372781    0.076754    0.015960    1.120206    
#> 003: 0.176759    0.937066    3.476844    0.354142    0.072916    0.015722    0.869037    
#> 004: 0.111678    0.969478    3.461894    0.336435    0.101851    0.016579    0.740600    
#> 005: 0.115512    0.988682    3.438867    0.319613    0.109549    0.015750    0.710335    
#> 006: 0.079452    0.983679    3.438578    0.303633    0.104071    0.014962    0.670069    
#> 007: 0.052981    1.002745    3.438004    0.288451    0.099113    0.018308    0.688507    
#> 008: 0.046381    1.002388    3.424003    0.274029    0.094158    0.020254    0.673977    
#> 009: 0.017303    0.999046    3.399001    0.260327    0.089450    0.019242    0.674973    
#> 010: 0.035114    0.983372    3.412825    0.247311    0.084977    0.021207    0.677262    
#> 011: 0.087420    0.995009    3.420826    0.234945    0.092404    0.022298    0.694448    
#> 012: 0.063064    1.021444    3.406992    0.223198    0.104500    0.021183    0.690919    
#> 013: 0.006179    1.022575    3.395145    0.212038    0.099275    0.020635    0.694347    
#> 014: 0.066245    0.993606    3.422652    0.201436    0.096823    0.020291    0.685552    
#> 015: 0.061696    0.980927    3.438519    0.191364    0.091982    0.021156    0.677994    
#> 016: 0.075971    0.992367    3.447359    0.181796    0.087383    0.029788    0.670554    
#> 017: 0.051587    1.010373    3.430863    0.172706    0.083014    0.034157    0.650463    
#> 018: 0.063367    1.000212    3.407808    0.164071    0.078863    0.033930    0.660674    
#> 019: 0.028907    1.012593    3.404277    0.155867    0.074920    0.032234    0.648103    
#> 020: 0.033348    1.023986    3.401909    0.148074    0.071174    0.030622    0.644951    
#> 021: 0.060592    1.012420    3.424206    0.140670    0.067615    0.029091    0.647002    
#> 022: 0.067921    1.009022    3.438599    0.133637    0.064235    0.034641    0.647350    
#> 023: 0.092355    1.012547    3.429791    0.126955    0.061023    0.033058    0.661560    
#> 024: 0.119055    1.000323    3.441577    0.120607    0.062074    0.031405    0.668111    
#> 025: 0.112293    0.973545    3.448043    0.114577    0.059102    0.029835    0.664104    
#> 026: 0.083599    0.990083    3.428235    0.108848    0.056147    0.028343    0.659688    
#> 027: 0.063151    1.002721    3.425231    0.103406    0.053985    0.033304    0.667050    
#> 028: 0.072638    0.990846    3.424956    0.098235    0.051286    0.031638    0.654323    
#> 029: 0.098599    0.993605    3.420224    0.107874    0.058936    0.030056    0.670276    
#> 030: 0.071885    1.010204    3.415392    0.102902    0.064541    0.030954    0.683667    
#> 031: 0.051067    1.012238    3.423568    0.097757    0.063904    0.029406    0.674907    
#> 032: 0.074552    0.987594    3.432991    0.092869    0.066264    0.027936    0.668038    
#> 033: 0.046325    1.015331    3.418316    0.088226    0.079323    0.026539    0.691394    
#> 034: 0.099221    1.011230    3.429162    0.085772    0.075357    0.029067    0.673737    
#> 035: 0.052659    1.004262    3.425565    0.081483    0.076815    0.027614    0.648605    
#> 036: 0.063890    1.007970    3.423018    0.077409    0.072975    0.027642    0.668352    
#> 037: 0.060391    1.011682    3.414476    0.074983    0.069326    0.026260    0.685779    
#> 038: 0.069567    1.015388    3.410195    0.073232    0.065860    0.024947    0.699335    
#> 039: 0.079900    0.997559    3.423091    0.079199    0.063976    0.023699    0.667846    
#> 040: 0.082604    0.993095    3.438409    0.086496    0.063924    0.023200    0.677152    
#> 041: 0.062152    0.984442    3.430751    0.082171    0.066948    0.022040    0.670753    
#> 042: 0.095578    0.990184    3.432955    0.078063    0.063601    0.022098    0.674468    
#> 043: 0.050696    1.016878    3.415245    0.089595    0.075477    0.021777    0.662231    
#> 044: 0.021438    1.021089    3.413980    0.085115    0.074180    0.022391    0.669991    
#> 045: 0.011457    1.048137    3.397638    0.080859    0.077354    0.021272    0.669452    
#> 046: 0.037252    1.017223    3.408815    0.082516    0.073487    0.021157    0.676651    
#> 047: 0.069108    1.030333    3.405713    0.078390    0.069812    0.022726    0.679096    
#> 048: 0.054499    0.999450    3.412258    0.074471    0.066322    0.028208    0.680687    
#> 049: 0.038271    1.017672    3.419352    0.072484    0.063006    0.026798    0.670033    
#> 050: 0.090095    0.984546    3.435078    0.071232    0.065233    0.026622    0.681818    
#> 051: 0.092109    0.998328    3.433468    0.086418    0.061972    0.025291    0.681477    
#> 052: 0.095668    0.983444    3.447168    0.088740    0.060281    0.027682    0.665825    
#> 053: 0.108282    0.981411    3.442401    0.104482    0.057313    0.031392    0.653742    
#> 054: 0.078680    0.976480    3.450920    0.099258    0.054447    0.039477    0.688241    
#> 055: 0.044177    0.985362    3.435164    0.101876    0.065070    0.037504    0.676640    
#> 056: 0.067960    0.970477    3.430990    0.096782    0.064348    0.035628    0.677175    
#> 057: 0.056008    0.989286    3.434476    0.091943    0.065869    0.036679    0.688791    
#> 058: 0.052320    0.981890    3.421631    0.087346    0.062576    0.034845    0.681961    
#> 059: 0.078562    0.951350    3.437993    0.087294    0.059447    0.033103    0.693311    
#> 060: 0.069529    0.964721    3.438163    0.101013    0.056475    0.033726    0.680418    
#> 061: 0.101721    0.984827    3.449497    0.122981    0.053651    0.042410    0.699829    
#> 062: 0.104374    0.975977    3.463103    0.116832    0.050968    0.042544    0.697143    
#> 063: 0.114985    0.945729    3.448384    0.119169    0.048420    0.042540    0.675746    
#> 064: 0.091529    0.968774    3.446020    0.113211    0.053455    0.040413    0.682293    
#> 065: 0.120849    0.962557    3.452582    0.107550    0.050782    0.045483    0.676794    
#> 066: 0.128617    0.985915    3.455847    0.122890    0.048243    0.043209    0.673133    
#> 067: 0.123478    0.976342    3.450463    0.116746    0.050946    0.041049    0.662753    
#> 068: 0.078057    0.994275    3.431122    0.125463    0.056190    0.038996    0.664123    
#> 069: 0.091561    1.005917    3.427761    0.130506    0.053380    0.037064    0.667738    
#> 070: 0.104564    1.006707    3.449929    0.128102    0.061831    0.035697    0.656770    
#> 071: 0.056389    1.021693    3.406866    0.136619    0.061478    0.033912    0.680985    
#> 072: 0.011855    1.002840    3.409078    0.129788    0.058727    0.033030    0.688947    
#> 073: 0.023406    1.008145    3.413042    0.123299    0.067055    0.031379    0.686173    
#> 074: 0.000952    0.995857    3.412046    0.117134    0.076166    0.029810    0.686349    
#> 075: 0.022047    0.993630    3.430696    0.111277    0.072357    0.028339    0.669904    
#> 076: 0.030597    1.002958    3.425324    0.105713    0.068740    0.027515    0.679524    
#> 077: 0.085240    0.996849    3.423948    0.100428    0.065303    0.026139    0.667439    
#> 078: 0.084258    0.993915    3.423363    0.095406    0.062037    0.024832    0.657270    
#> 079: 0.083034    1.017773    3.424718    0.090636    0.060906    0.026651    0.687549    
#> 080: 0.091055    0.999860    3.447044    0.095007    0.068350    0.025319    0.679407    
#> 081: 0.080621    0.997817    3.435772    0.090256    0.064932    0.024744    0.649065    
#> 082: 0.083844    0.973236    3.451164    0.085743    0.061686    0.026833    0.677570    
#> 083: 0.105140    0.996212    3.445462    0.081456    0.058601    0.025491    0.682111    
#> 084: 0.075420    1.010196    3.426863    0.077383    0.059613    0.028408    0.657590    
#> 085: 0.050848    1.021303    3.435666    0.073514    0.064026    0.026988    0.670686    
#> 086: 0.038928    1.008767    3.428654    0.069839    0.060824    0.025639    0.674516    
#> 087: 0.035365    1.010473    3.415770    0.077966    0.057783    0.025798    0.674444    
#> 088: 0.006343    1.009724    3.413989    0.082796    0.054894    0.024508    0.676123    
#> 089: 0.009413    1.037788    3.390726    0.091455    0.060292    0.032719    0.678609    
#> 090: 0.020647    1.019494    3.407877    0.094605    0.065728    0.031083    0.659389    
#> 091: 0.016843    0.995547    3.396334    0.089875    0.062441    0.029529    0.671591    
#> 092: -0.004047   1.025092    3.392899    0.085486    0.063921    0.032497    0.680252    
#> 093: -0.007940   1.013165    3.401464    0.081212    0.082287    0.030872    0.674096    
#> 094: 0.008662    1.036839    3.401816    0.081622    0.078173    0.029329    0.678429    
#> 095: 0.057132    1.018796    3.416133    0.085325    0.074264    0.029860    0.665210    
#> 096: 0.029931    1.017542    3.407190    0.081059    0.070551    0.028367    0.656090    
#> 097: 0.037242    1.035824    3.407266    0.077006    0.067385    0.026948    0.648614    
#> 098: 0.026625    1.047758    3.403273    0.079063    0.064016    0.025601    0.686086    
#> 099: -0.007262   1.013992    3.383443    0.075110    0.060815    0.024321    0.674402    
#> 100: 0.004258    1.022034    3.407029    0.071707    0.058022    0.023105    0.674088    
#> 101: -0.011609   1.015195    3.384580    0.068122    0.055320    0.021950    0.674357    
#> 102: -0.024111   1.023411    3.383646    0.065375    0.080371    0.020852    0.682875    
#> 103: 0.033484    1.028006    3.406812    0.075651    0.076353    0.019810    0.660698    
#> 104: 0.019256    1.018395    3.417208    0.080754    0.075631    0.018819    0.682500    
#> 105: 0.042644    1.014374    3.415691    0.076716    0.092048    0.017878    0.672680    
#> 106: 0.063888    1.004489    3.415654    0.072880    0.087446    0.016984    0.673839    
#> 107: 0.058629    1.025545    3.418392    0.069236    0.083074    0.016989    0.703434    
#> 108: 0.056267    1.002192    3.416573    0.075825    0.078920    0.019068    0.693802    
#> 109: 0.028474    1.016684    3.415648    0.093978    0.074974    0.024235    0.655306    
#> 110: 0.028138    0.985955    3.406677    0.089279    0.071225    0.023024    0.666456    
#> 111: 0.043552    0.997729    3.421757    0.095670    0.070170    0.021872    0.666008    
#> 112: 0.048710    0.984267    3.413607    0.090887    0.082706    0.020779    0.670764    
#> 113: 0.058275    1.013367    3.421533    0.086343    0.078570    0.021810    0.662393    
#> 114: 0.059841    0.992242    3.423408    0.095469    0.074642    0.023072    0.665173    
#> 115: 0.065299    0.988051    3.413451    0.090695    0.075181    0.024842    0.681333    
#> 116: 0.045666    1.013513    3.410350    0.091576    0.071422    0.023599    0.678659    
#> 117: 0.045990    1.012348    3.422805    0.086997    0.067851    0.027158    0.676755    
#> 118: 0.045404    1.015920    3.424618    0.082647    0.069042    0.029206    0.660888    
#> 119: 0.067856    1.006541    3.430191    0.086101    0.066720    0.027746    0.660286    
#> 120: 0.054770    1.011892    3.414618    0.081796    0.063384    0.027590    0.660339    
#> 121: 0.020508    1.029863    3.405881    0.077706    0.060214    0.029284    0.674399    
#> 122: 0.049728    1.001131    3.420386    0.086399    0.057204    0.027820    0.676048    
#> 123: 0.071026    1.013958    3.413450    0.088172    0.058927    0.026510    0.668481    
#> 124: 0.083217    1.017450    3.425319    0.087205    0.057231    0.027775    0.677717    
#> 125: 0.088668    1.030028    3.417367    0.094013    0.065879    0.026386    0.674432    
#> 126: 0.037843    1.030483    3.404103    0.104801    0.073405    0.026728    0.667278    
#> 127: 0.052137    1.026140    3.410024    0.099561    0.069735    0.028114    0.668254    
#> 128: 0.053070    1.014939    3.435457    0.094583    0.066248    0.026709    0.685116    
#> 129: 0.058605    1.004577    3.422795    0.092972    0.074439    0.031984    0.681241    
#> 130: 0.072465    1.007059    3.415993    0.104816    0.070717    0.030385    0.659036    
#> 131: 0.034654    0.997851    3.410031    0.105596    0.067182    0.033492    0.673691    
#> 132: 0.021850    1.021785    3.407841    0.102356    0.063822    0.031817    0.673152    
#> 133: 0.037442    1.010866    3.410759    0.126398    0.061110    0.032649    0.666677    
#> 134: 0.070964    1.000436    3.425893    0.133818    0.058054    0.031017    0.656068    
#> 135: 0.049166    0.992315    3.415801    0.127606    0.062232    0.029466    0.669808    
#> 136: 0.052838    0.987141    3.418940    0.129636    0.059120    0.038665    0.654730    
#> 137: 0.053433    0.997723    3.416055    0.123154    0.056164    0.039090    0.641817    
#> 138: 0.037252    1.013692    3.410782    0.122554    0.059832    0.037135    0.655558    
#> 139: 0.039242    1.039417    3.422981    0.129088    0.056840    0.035278    0.664014    
#> 140: 0.054353    1.046162    3.406474    0.122778    0.056602    0.035546    0.675297    
#> 141: 0.039305    1.016303    3.411647    0.116639    0.053772    0.034094    0.667620    
#> 142: 0.043022    0.985101    3.432103    0.110807    0.051084    0.032389    0.682595    
#> 143: 0.037198    1.009791    3.417983    0.105267    0.057995    0.030769    0.659613    
#> 144: 0.087861    0.996477    3.439945    0.100003    0.058801    0.029231    0.647460    
#> 145: 0.062001    1.001010    3.414469    0.095003    0.061016    0.030960    0.648173    
#> 146: 0.037787    0.997417    3.431154    0.090253    0.057965    0.032860    0.650251    
#> 147: 0.006095    1.000889    3.412304    0.098358    0.055067    0.033731    0.654374    
#> 148: 0.033564    1.008803    3.422407    0.093440    0.069041    0.032045    0.661297    
#> 149: 0.044300    1.018963    3.425232    0.108702    0.065589    0.034956    0.655503    
#> 150: 0.077726    1.015327    3.406269    0.113266    0.062310    0.034446    0.670930    
#> 151: 0.026189    1.027684    3.415553    0.107602    0.062516    0.033747    0.665144    
#> 152: 0.019524    1.031119    3.405352    0.128591    0.068220    0.033817    0.643616    
#> 153: 0.022677    1.038252    3.394679    0.139003    0.074672    0.029779    0.651943    
#> 154: 0.025322    1.050950    3.396746    0.124290    0.066000    0.029631    0.660184    
#> 155: 0.005118    1.030309    3.396858    0.103954    0.077883    0.019519    0.663434    
#> 156: 0.009982    1.031199    3.400000    0.108254    0.076628    0.019561    0.672750    
#> 157: 0.038773    1.011816    3.418810    0.107773    0.078622    0.022616    0.667090    
#> 158: 0.064555    1.020280    3.414289    0.100999    0.088032    0.021192    0.657417    
#> 159: 0.019186    1.012627    3.414918    0.096430    0.068367    0.023959    0.664508    
#> 160: 0.047617    1.000103    3.417379    0.110578    0.069865    0.021801    0.663372    
#> 161: 0.050509    1.014738    3.413903    0.098341    0.060888    0.024644    0.672282    
#> 162: 0.052460    1.019632    3.410841    0.094368    0.071420    0.028841    0.664408    
#> 163: 0.074896    1.013424    3.424541    0.097681    0.061100    0.029993    0.665617    
#> 164: 0.075016    1.024576    3.420371    0.099220    0.061495    0.032784    0.662042    
#> 165: 0.074291    1.014342    3.414893    0.080527    0.072408    0.028561    0.651530    
#> 166: 0.082286    1.039587    3.420741    0.092555    0.067024    0.031503    0.673308    
#> 167: 0.046030    1.029558    3.425340    0.088197    0.058410    0.029800    0.673368    
#> 168: 0.053036    1.042391    3.415479    0.112372    0.058571    0.027344    0.656335    
#> 169: 0.033273    1.056625    3.400807    0.120651    0.067907    0.028328    0.663783    
#> 170: 0.023898    1.040056    3.398918    0.128635    0.056712    0.028125    0.647457    
#> 171: -0.008427   1.040336    3.391980    0.104520    0.077254    0.022236    0.637801    
#> 172: 0.003364    1.043077    3.390892    0.098739    0.067778    0.018618    0.664353    
#> 173: 0.010851    1.031724    3.394658    0.104635    0.064540    0.017025    0.650012    
#> 174: 0.007068    1.039385    3.395909    0.113798    0.085698    0.016264    0.649539    
#> 175: 0.021368    1.024450    3.395904    0.119257    0.075703    0.020906    0.654846    
#> 176: 0.039915    1.035565    3.412678    0.128058    0.064884    0.021517    0.656356    
#> 177: 0.029573    1.014057    3.421312    0.102852    0.073837    0.023218    0.680478    
#> 178: 0.051972    1.000360    3.427813    0.104757    0.076191    0.027499    0.668212    
#> 179: 0.054863    1.011729    3.423057    0.073029    0.058591    0.022547    0.673799    
#> 180: 0.065479    1.006101    3.430057    0.098846    0.067944    0.024421    0.658166    
#> 181: 0.060528    1.008915    3.402038    0.093648    0.062256    0.022802    0.666997    
#> 182: -0.007083   1.008470    3.398852    0.084376    0.073758    0.022785    0.698061    
#> 183: 0.013144    1.038469    3.395764    0.100044    0.084213    0.016674    0.670630    
#> 184: 0.018539    1.018518    3.396400    0.102683    0.074632    0.018544    0.652239    
#> 185: -0.024723   1.036017    3.391803    0.088835    0.066713    0.022044    0.665532    
#> 186: 0.009808    1.044550    3.397244    0.091270    0.072943    0.027101    0.671342    
#> 187: 0.030947    1.013308    3.398356    0.104632    0.062399    0.026601    0.683108    
#> 188: 0.018976    1.042498    3.403166    0.111042    0.071613    0.028019    0.677045    
#> 189: 0.040613    1.037090    3.419809    0.089028    0.077195    0.025303    0.670266    
#> 190: 0.022720    1.037020    3.414608    0.098084    0.064771    0.025532    0.646130    
#> 191: 0.027774    1.026133    3.409356    0.078055    0.053493    0.033148    0.648637    
#> 192: 0.023680    1.046983    3.409843    0.075338    0.070499    0.030282    0.643950    
#> 193: 0.038158    1.044710    3.417113    0.073455    0.065229    0.032331    0.658001    
#> 194: 0.057505    1.022240    3.421633    0.095375    0.071463    0.029519    0.664730    
#> 195: 0.033001    1.022156    3.410616    0.091322    0.069625    0.027630    0.665447    
#> 196: 0.043735    1.016263    3.422853    0.089135    0.066583    0.025026    0.680635    
#> 197: 0.011353    1.017536    3.422829    0.099449    0.072253    0.025113    0.681611    
#> 198: 0.074138    0.997779    3.430208    0.075178    0.066729    0.023892    0.660816    
#> 199: 0.064993    0.997278    3.421812    0.101191    0.075768    0.022553    0.664022    
#> 200: 0.067389    1.008752    3.421569    0.091936    0.068225    0.016860    0.686312    
#> 201: 0.048659    1.000887    3.421505    0.092198    0.063398    0.018876    0.678252    
#> 202: 0.050466    1.001386    3.421262    0.090536    0.064130    0.019951    0.675777    
#> 203: 0.062409    1.001593    3.420577    0.088990    0.065832    0.020200    0.677023    
#> 204: 0.069251    0.997418    3.424392    0.088870    0.070252    0.020577    0.675852    
#> 205: 0.071733    0.998025    3.425942    0.087165    0.072163    0.020530    0.675298    
#> 206: 0.074719    1.002525    3.425695    0.087106    0.074375    0.019871    0.676635    
#> 207: 0.072045    1.002807    3.423793    0.088783    0.075156    0.019099    0.678805    
#> 208: 0.068311    1.003541    3.423485    0.090526    0.074661    0.018931    0.678486    
#> 209: 0.070463    1.002270    3.422347    0.089738    0.075244    0.018335    0.677963    
#> 210: 0.071644    1.001057    3.422503    0.087887    0.076311    0.018261    0.677624    
#> 211: 0.070700    1.003166    3.422367    0.087558    0.076046    0.018123    0.677244    
#> 212: 0.070267    1.002089    3.422652    0.087435    0.076011    0.018314    0.677533    
#> 213: 0.071499    0.999676    3.423579    0.087384    0.075665    0.018580    0.676963    
#> 214: 0.072818    0.998758    3.424324    0.087824    0.075790    0.018867    0.676792    
#> 215: 0.072041    0.999638    3.424466    0.086537    0.076020    0.019052    0.676727    
#> 216: 0.073178    0.998985    3.424503    0.085646    0.076408    0.018979    0.679215    
#> 217: 0.072044    1.000468    3.423891    0.085463    0.076446    0.019285    0.678658    
#> 218: 0.070097    1.001797    3.423066    0.085601    0.076500    0.019600    0.677779    
#> 219: 0.068233    1.002584    3.421571    0.085384    0.076065    0.019954    0.677475    
#> 220: 0.066223    1.002926    3.420814    0.086105    0.075607    0.020124    0.677211    
#> 221: 0.065401    1.002890    3.420670    0.086701    0.075208    0.020246    0.676618    
#> 222: 0.064845    1.003386    3.420132    0.087245    0.074779    0.020363    0.675929    
#> 223: 0.064768    1.003385    3.419708    0.086909    0.075082    0.020433    0.675325    
#> 224: 0.065790    1.004370    3.419814    0.087420    0.075432    0.020518    0.674454    
#> 225: 0.065782    1.003647    3.420291    0.087117    0.075033    0.020712    0.674550    
#> 226: 0.064730    1.002782    3.420048    0.087054    0.074520    0.020956    0.675047    
#> 227: 0.062366    1.002928    3.419826    0.086498    0.074261    0.021183    0.675594    
#> 228: 0.060622    1.004286    3.418868    0.086494    0.074250    0.021368    0.675680    
#> 229: 0.058926    1.004897    3.417967    0.086445    0.074007    0.021385    0.675796    
#> 230: 0.058575    1.004975    3.417435    0.086779    0.073779    0.021320    0.675867    
#> 231: 0.057705    1.005714    3.417366    0.087493    0.073873    0.021359    0.675709    
#> 232: 0.056725    1.005556    3.417340    0.087262    0.073930    0.021433    0.675508    
#> 233: 0.055902    1.004765    3.417563    0.087181    0.073806    0.021674    0.675635    
#> 234: 0.056047    1.004245    3.417744    0.086779    0.073266    0.021965    0.675183    
#> 235: 0.056279    1.003752    3.417857    0.086239    0.073317    0.021943    0.675119    
#> 236: 0.057045    1.003590    3.418297    0.086369    0.073377    0.022067    0.675397    
#> 237: 0.057803    1.003506    3.418344    0.086351    0.073372    0.022283    0.675838    
#> 238: 0.057955    1.003267    3.418423    0.085973    0.073418    0.022423    0.676141    
#> 239: 0.057969    1.004087    3.418331    0.085593    0.073620    0.022513    0.676219    
#> 240: 0.058259    1.003962    3.418640    0.085734    0.073656    0.022458    0.676038    
#> 241: 0.058507    1.003025    3.418966    0.085537    0.073538    0.022469    0.676142    
#> 242: 0.058412    1.002587    3.418837    0.085773    0.073855    0.022437    0.676348    
#> 243: 0.058130    1.002611    3.418918    0.085742    0.073809    0.022513    0.676730    
#> 244: 0.057332    1.002339    3.419062    0.085857    0.074032    0.022628    0.676876    
#> 245: 0.057184    1.001697    3.419262    0.085827    0.074120    0.022702    0.677126    
#> 246: 0.056879    1.001278    3.419228    0.085598    0.074146    0.022722    0.677067    
#> 247: 0.056315    1.000934    3.419243    0.085463    0.073965    0.022726    0.677041    
#> 248: 0.056144    1.001666    3.419109    0.085699    0.073999    0.022759    0.676863    
#> 249: 0.055887    1.001940    3.419097    0.085846    0.074122    0.022825    0.676717    
#> 250: 0.056413    1.002515    3.419222    0.085766    0.073922    0.022855    0.676854    
#> 251: 0.057051    1.003116    3.419630    0.085545    0.073730    0.022856    0.676813    
#> 252: 0.057628    1.003318    3.420079    0.085411    0.073894    0.022841    0.677024    
#> 253: 0.057940    1.003372    3.420356    0.085426    0.073997    0.022926    0.676703    
#> 254: 0.058467    1.003583    3.420659    0.085569    0.073721    0.023043    0.676285    
#> 255: 0.058657    1.003889    3.421041    0.085747    0.073544    0.023210    0.675875    
#> 256: 0.059022    1.003928    3.421009    0.085882    0.073372    0.023346    0.675874    
#> 257: 0.058993    1.003788    3.420828    0.085915    0.073136    0.023454    0.676101    
#> 258: 0.058553    1.003833    3.420601    0.086096    0.073021    0.023513    0.675855    
#> 259: 0.058394    1.003972    3.420460    0.086010    0.072978    0.023522    0.675807    
#> 260: 0.057762    1.004491    3.420226    0.086078    0.072917    0.023468    0.675459    
#> 261: 0.057462    1.004429    3.420167    0.086654    0.072877    0.023539    0.675270    
#> 262: 0.057469    1.004870    3.420051    0.086607    0.073021    0.023609    0.675085    
#> 263: 0.057253    1.005346    3.419897    0.086597    0.073159    0.023655    0.675060    
#> 264: 0.056951    1.005580    3.419704    0.086646    0.073554    0.023596    0.675407    
#> 265: 0.056539    1.006065    3.419497    0.086593    0.073801    0.023572    0.675503    
#> 266: 0.056364    1.006533    3.419219    0.086568    0.074051    0.023533    0.675552    
#> 267: 0.056442    1.006543    3.419307    0.086449    0.074108    0.023545    0.675545    
#> 268: 0.056516    1.006398    3.419243    0.086733    0.074044    0.023499    0.675551    
#> 269: 0.056981    1.006301    3.419467    0.086923    0.073921    0.023465    0.675948    
#> 270: 0.057372    1.006420    3.419421    0.086876    0.073873    0.023403    0.675908    
#> 271: 0.057328    1.006440    3.419389    0.087147    0.073761    0.023365    0.676075    
#> 272: 0.057175    1.006211    3.419270    0.087717    0.073726    0.023363    0.676490    
#> 273: 0.056913    1.006475    3.419218    0.088079    0.073782    0.023362    0.676694    
#> 274: 0.056374    1.006851    3.419178    0.088090    0.073717    0.023333    0.676831    
#> 275: 0.056066    1.006859    3.418991    0.087912    0.073580    0.023329    0.676711    
#> 276: 0.056068    1.006899    3.419111    0.087779    0.073420    0.023325    0.676520    
#> 277: 0.055842    1.007131    3.419194    0.087652    0.073447    0.023323    0.676238    
#> 278: 0.055978    1.007191    3.419337    0.087518    0.073564    0.023304    0.676058    
#> 279: 0.056045    1.007185    3.419400    0.087592    0.073648    0.023323    0.675930    
#> 280: 0.056243    1.007328    3.419516    0.087538    0.073638    0.023312    0.675724    
#> 281: 0.056034    1.007381    3.419539    0.087560    0.073537    0.023399    0.675589    
#> 282: 0.056106    1.007470    3.419541    0.087526    0.073432    0.023404    0.675600    
#> 283: 0.056540    1.007431    3.419701    0.087291    0.073278    0.023458    0.675938    
#> 284: 0.056614    1.007208    3.419772    0.087087    0.073124    0.023493    0.675851    
#> 285: 0.056500    1.007321    3.419594    0.086902    0.073105    0.023508    0.675883    
#> 286: 0.056637    1.007384    3.419471    0.086830    0.072979    0.023492    0.675854    
#> 287: 0.056596    1.007507    3.419345    0.086663    0.073052    0.023527    0.675719    
#> 288: 0.056527    1.007548    3.419239    0.086670    0.073055    0.023486    0.675629    
#> 289: 0.056486    1.007559    3.419187    0.086875    0.072982    0.023455    0.675745    
#> 290: 0.056277    1.007596    3.419158    0.086802    0.073007    0.023429    0.676036    
#> 291: 0.056254    1.007732    3.419261    0.086667    0.072967    0.023446    0.675932    
#> 292: 0.056278    1.007831    3.419351    0.086686    0.072875    0.023442    0.675823    
#> 293: 0.056284    1.007898    3.419360    0.086768    0.072859    0.023427    0.675773    
#> 294: 0.056046    1.007848    3.419243    0.086703    0.072867    0.023419    0.675603    
#> 295: 0.055903    1.007586    3.419237    0.086642    0.072762    0.023454    0.675523    
#> 296: 0.055949    1.007505    3.419251    0.086712    0.072703    0.023492    0.675540    
#> 297: 0.055997    1.007676    3.419131    0.086857    0.072800    0.023461    0.675656    
#> 298: 0.055951    1.007874    3.418979    0.087017    0.072866    0.023432    0.675683    
#> 299: 0.055656    1.008082    3.418775    0.087181    0.072801    0.023411    0.675403    
#> 300: 0.055412    1.008161    3.418651    0.087152    0.072897    0.023394    0.675406    
#> 301: 0.055024    1.008197    3.418475    0.087351    0.072997    0.023395    0.675411    
#> 302: 0.054553    1.008615    3.418180    0.087675    0.073043    0.023367    0.675380    
#> 303: 0.053862    1.009036    3.417900    0.087870    0.073215    0.023388    0.675254    
#> 304: 0.053556    1.009371    3.417624    0.088033    0.073257    0.023428    0.675099    
#> 305: 0.053048    1.009348    3.417404    0.088233    0.073159    0.023523    0.675021    
#> 306: 0.052584    1.009445    3.417251    0.088358    0.073077    0.023600    0.674935    
#> 307: 0.052349    1.009499    3.417101    0.088379    0.073122    0.023648    0.675067    
#> 308: 0.052205    1.009682    3.417034    0.088537    0.073303    0.023633    0.675123    
#> 309: 0.052414    1.009486    3.417051    0.088633    0.073341    0.023617    0.675177    
#> 310: 0.052608    1.009337    3.416971    0.088767    0.073213    0.023636    0.675199    
#> 311: 0.052640    1.009536    3.416991    0.089033    0.073181    0.023661    0.675136    
#> 312: 0.052575    1.009522    3.416905    0.089053    0.073143    0.023636    0.675023    
#> 313: 0.052451    1.009427    3.416888    0.088789    0.073094    0.023634    0.675005    
#> 314: 0.052118    1.009616    3.416763    0.088662    0.073095    0.023609    0.674865    
#> 315: 0.051919    1.009775    3.416705    0.088849    0.073083    0.023611    0.674652    
#> 316: 0.051831    1.010033    3.416526    0.089072    0.072997    0.023570    0.674543    
#> 317: 0.051790    1.010128    3.416509    0.089445    0.072943    0.023588    0.674539    
#> 318: 0.051574    1.010319    3.416377    0.089607    0.072917    0.023582    0.674464    
#> 319: 0.051497    1.010326    3.416370    0.089616    0.072970    0.023556    0.674367    
#> 320: 0.051023    1.010359    3.416256    0.089713    0.072950    0.023516    0.674433    
#> 321: 0.050601    1.010647    3.416042    0.089583    0.072889    0.023492    0.674544    
#> 322: 0.050447    1.010854    3.415835    0.089578    0.072754    0.023476    0.674523    
#> 323: 0.049933    1.010942    3.415682    0.089750    0.072628    0.023485    0.674455    
#> 324: 0.049747    1.011195    3.415573    0.089900    0.072637    0.023507    0.674173    
#> 325: 0.049601    1.011455    3.415402    0.090029    0.072601    0.023510    0.673952    
#> 326: 0.049401    1.011447    3.415310    0.090021    0.072587    0.023533    0.673849    
#> 327: 0.049451    1.011425    3.415358    0.090017    0.072547    0.023571    0.673865    
#> 328: 0.049636    1.011525    3.415383    0.090019    0.072514    0.023620    0.673581    
#> 329: 0.049933    1.011569    3.415515    0.090048    0.072448    0.023651    0.673384    
#> 330: 0.049923    1.011573    3.415556    0.090022    0.072397    0.023653    0.673306    
#> 331: 0.050060    1.011609    3.415657    0.089989    0.072371    0.023664    0.673282    
#> 332: 0.050032    1.011461    3.415733    0.089945    0.072315    0.023616    0.673380    
#> 333: 0.049830    1.011429    3.415716    0.089884    0.072350    0.023595    0.673345    
#> 334: 0.049609    1.011418    3.415553    0.089763    0.072443    0.023564    0.673375    
#> 335: 0.049317    1.011402    3.415450    0.089601    0.072525    0.023534    0.673413    
#> 336: 0.049063    1.011496    3.415357    0.089514    0.072591    0.023480    0.673461    
#> 337: 0.048881    1.011819    3.415223    0.089448    0.072608    0.023469    0.673435    
#> 338: 0.049003    1.011917    3.415279    0.089366    0.072583    0.023485    0.673461    
#> 339: 0.048955    1.012054    3.415245    0.089261    0.072526    0.023515    0.673499    
#> 340: 0.048811    1.011913    3.415253    0.089175    0.072418    0.023579    0.673434    
#> 341: 0.048804    1.011928    3.415285    0.089011    0.072379    0.023614    0.673435    
#> 342: 0.048534    1.011666    3.415255    0.088785    0.072371    0.023610    0.673507    
#> 343: 0.048201    1.011760    3.415143    0.088845    0.072321    0.023620    0.673476    
#> 344: 0.048093    1.011802    3.415129    0.088990    0.072354    0.023623    0.673467    
#> 345: 0.048026    1.011703    3.415113    0.089000    0.072242    0.023657    0.673426    
#> 346: 0.048058    1.011754    3.415028    0.089094    0.072197    0.023680    0.673341    
#> 347: 0.048069    1.011780    3.414940    0.089086    0.072059    0.023698    0.673292    
#> 348: 0.047726    1.011883    3.414803    0.089117    0.072013    0.023705    0.673246    
#> 349: 0.047525    1.011869    3.414700    0.089079    0.071946    0.023718    0.673177    
#> 350: 0.047225    1.011738    3.414586    0.088930    0.071928    0.023692    0.673249    
#> 351: 0.047109    1.011871    3.414474    0.088798    0.071962    0.023670    0.673292    
#> 352: 0.046727    1.012025    3.414399    0.088812    0.072018    0.023702    0.673437    
#> 353: 0.046600    1.012217    3.414410    0.088869    0.071984    0.023776    0.673423    
#> 354: 0.046599    1.012264    3.414329    0.088799    0.071958    0.023811    0.673381    
#> 355: 0.047026    1.012158    3.414332    0.088894    0.071962    0.023848    0.673331    
#> 356: 0.047099    1.011996    3.414346    0.088912    0.071914    0.023862    0.673461    
#> 357: 0.047283    1.012149    3.414317    0.088942    0.071850    0.023885    0.673403    
#> 358: 0.047246    1.012223    3.414339    0.088892    0.071855    0.023895    0.673358    
#> 359: 0.047116    1.012170    3.414346    0.088820    0.071779    0.023919    0.673295    
#> 360: 0.046888    1.012161    3.414235    0.088640    0.071672    0.023910    0.673295    
#> 361: 0.046823    1.012152    3.414196    0.088607    0.071533    0.023912    0.673299    
#> 362: 0.046868    1.012093    3.414147    0.088682    0.071493    0.023912    0.673176    
#> 363: 0.046780    1.012050    3.414104    0.088754    0.071476    0.023912    0.672989    
#> 364: 0.046769    1.012013    3.414116    0.088853    0.071499    0.023902    0.672975    
#> 365: 0.046727    1.011806    3.414131    0.088942    0.071481    0.023897    0.673001    
#> 366: 0.046581    1.011837    3.413969    0.088969    0.071543    0.023873    0.673005    
#> 367: 0.046608    1.011927    3.413920    0.088955    0.071643    0.023846    0.673064    
#> 368: 0.046676    1.011852    3.413921    0.088925    0.071572    0.023842    0.673029    
#> 369: 0.046770    1.011710    3.413978    0.088980    0.071511    0.023867    0.672947    
#> 370: 0.046785    1.011732    3.413956    0.088974    0.071502    0.023880    0.673031    
#> 371: 0.046777    1.011835    3.413925    0.089000    0.071543    0.023900    0.673017    
#> 372: 0.046731    1.011796    3.413903    0.089020    0.071543    0.023878    0.673059    
#> 373: 0.046733    1.011894    3.413901    0.088985    0.071525    0.023883    0.673144    
#> 374: 0.046836    1.011940    3.413913    0.088923    0.071534    0.023870    0.673125    
#> 375: 0.046822    1.011914    3.413950    0.088935    0.071578    0.023877    0.673075    
#> 376: 0.046791    1.011993    3.413940    0.088888    0.071569    0.023876    0.672966    
#> 377: 0.046741    1.011992    3.413924    0.088805    0.071481    0.023876    0.672902    
#> 378: 0.046401    1.012058    3.413800    0.088800    0.071375    0.023874    0.672951    
#> 379: 0.046183    1.012016    3.413756    0.088860    0.071304    0.023897    0.672959    
#> 380: 0.045974    1.012015    3.413717    0.088930    0.071238    0.023902    0.672864    
#> 381: 0.045715    1.012124    3.413615    0.089036    0.071263    0.023903    0.672779    
#> 382: 0.045644    1.012189    3.413562    0.089086    0.071209    0.023891    0.672665    
#> 383: 0.045771    1.012177    3.413535    0.089144    0.071184    0.023886    0.672590    
#> 384: 0.045674    1.012166    3.413517    0.089223    0.071275    0.023878    0.672568    
#> 385: 0.045896    1.012155    3.413609    0.089237    0.071302    0.023880    0.672568    
#> 386: 0.046052    1.012191    3.413692    0.089272    0.071330    0.023882    0.672589    
#> 387: 0.046222    1.012105    3.413817    0.089254    0.071279    0.023885    0.672485    
#> 388: 0.046325    1.012035    3.413889    0.089220    0.071301    0.023890    0.672446    
#> 389: 0.046367    1.011886    3.413933    0.089178    0.071268    0.023905    0.672471    
#> 390: 0.046350    1.011775    3.414004    0.089030    0.071255    0.023926    0.672547    
#> 391: 0.046332    1.011707    3.414028    0.088979    0.071292    0.023921    0.672474    
#> 392: 0.046385    1.011634    3.414107    0.089010    0.071325    0.023909    0.672514    
#> 393: 0.046447    1.011509    3.414087    0.089016    0.071380    0.023893    0.672557    
#> 394: 0.046369    1.011464    3.414090    0.089126    0.071386    0.023917    0.672563    
#> 395: 0.046416    1.011490    3.414102    0.089366    0.071317    0.023938    0.672521    
#> 396: 0.046476    1.011484    3.414125    0.089510    0.071334    0.023941    0.672347    
#> 397: 0.046505    1.011377    3.414143    0.089551    0.071315    0.023917    0.672380    
#> 398: 0.046664    1.011276    3.414231    0.089610    0.071268    0.023885    0.672425    
#> 399: 0.046834    1.011201    3.414316    0.089633    0.071199    0.023852    0.672384    
#> 400: 0.046984    1.011245    3.414393    0.089642    0.071182    0.023822    0.672344    
#> 401: 0.047055    1.011215    3.414423    0.089639    0.071172    0.023816    0.672290    
#> 402: 0.047138    1.011257    3.414490    0.089612    0.071090    0.023828    0.672304    
#> 403: 0.047383    1.011160    3.414563    0.089692    0.071028    0.023816    0.672319    
#> 404: 0.047523    1.011112    3.414585    0.089798    0.070922    0.023832    0.672242    
#> 405: 0.047485    1.011058    3.414617    0.089777    0.070878    0.023850    0.672276    
#> 406: 0.047456    1.010975    3.414626    0.089782    0.070872    0.023859    0.672325    
#> 407: 0.047528    1.010939    3.414670    0.089785    0.070838    0.023864    0.672306    
#> 408: 0.047545    1.011026    3.414675    0.089701    0.070926    0.023870    0.672356    
#> 409: 0.047425    1.011045    3.414676    0.089684    0.070932    0.023874    0.672288    
#> 410: 0.047284    1.011123    3.414580    0.089722    0.070912    0.023870    0.672342    
#> 411: 0.047181    1.011022    3.414489    0.089825    0.070865    0.023862    0.672481    
#> 412: 0.047059    1.011131    3.414381    0.089898    0.070875    0.023855    0.672416    
#> 413: 0.046963    1.011229    3.414278    0.090085    0.070855    0.023851    0.672450    
#> 414: 0.046756    1.011287    3.414242    0.090148    0.070902    0.023816    0.672497    
#> 415: 0.046809    1.011183    3.414264    0.090246    0.070883    0.023819    0.672439    
#> 416: 0.046918    1.011250    3.414302    0.090271    0.070911    0.023812    0.672389    
#> 417: 0.046926    1.011190    3.414327    0.090311    0.070879    0.023809    0.672288    
#> 418: 0.046856    1.011230    3.414367    0.090276    0.070859    0.023798    0.672212    
#> 419: 0.047007    1.011418    3.414404    0.090290    0.070838    0.023809    0.672177    
#> 420: 0.047019    1.011472    3.414404    0.090339    0.070780    0.023830    0.672057    
#> 421: 0.046923    1.011532    3.414406    0.090371    0.070714    0.023845    0.672028    
#> 422: 0.047051    1.011447    3.414405    0.090412    0.070678    0.023853    0.671981    
#> 423: 0.047125    1.011346    3.414437    0.090417    0.070607    0.023867    0.672003    
#> 424: 0.047128    1.011309    3.414435    0.090347    0.070515    0.023858    0.672054    
#> 425: 0.047339    1.011319    3.414461    0.090296    0.070502    0.023853    0.672133    
#> 426: 0.047467    1.011369    3.414491    0.090320    0.070542    0.023838    0.672085    
#> 427: 0.047539    1.011278    3.414613    0.090392    0.070548    0.023863    0.671962    
#> 428: 0.047530    1.011315    3.414629    0.090474    0.070475    0.023876    0.671941    
#> 429: 0.047573    1.011303    3.414661    0.090538    0.070429    0.023880    0.671907    
#> 430: 0.047621    1.011295    3.414682    0.090711    0.070385    0.023901    0.671927    
#> 431: 0.047597    1.011204    3.414666    0.090841    0.070400    0.023895    0.671859    
#> 432: 0.047558    1.011275    3.414668    0.090942    0.070413    0.023904    0.671854    
#> 433: 0.047568    1.011377    3.414672    0.090978    0.070430    0.023889    0.671817    
#> 434: 0.047509    1.011267    3.414715    0.090962    0.070381    0.023911    0.671792    
#> 435: 0.047543    1.011212    3.414715    0.090953    0.070370    0.023927    0.671732    
#> 436: 0.047604    1.011111    3.414784    0.090975    0.070363    0.023932    0.671761    
#> 437: 0.047741    1.010956    3.414858    0.091024    0.070305    0.023937    0.671713    
#> 438: 0.047800    1.010942    3.414864    0.091044    0.070263    0.023934    0.671706    
#> 439: 0.047826    1.011056    3.414872    0.091086    0.070226    0.023947    0.671632    
#> 440: 0.047781    1.011162    3.414893    0.091092    0.070190    0.023946    0.671599    
#> 441: 0.047837    1.011145    3.414917    0.091199    0.070162    0.023945    0.671562    
#> 442: 0.047814    1.011195    3.414926    0.091204    0.070122    0.023936    0.671469    
#> 443: 0.047731    1.011331    3.414857    0.091270    0.070138    0.023931    0.671399    
#> 444: 0.047714    1.011459    3.414786    0.091309    0.070151    0.023924    0.671367    
#> 445: 0.047678    1.011565    3.414761    0.091351    0.070176    0.023926    0.671358    
#> 446: 0.047529    1.011587    3.414732    0.091358    0.070158    0.023925    0.671317    
#> 447: 0.047624    1.011579    3.414756    0.091465    0.070198    0.023933    0.671317    
#> 448: 0.047529    1.011553    3.414738    0.091544    0.070153    0.023927    0.671237    
#> 449: 0.047550    1.011591    3.414767    0.091666    0.070163    0.023937    0.671198    
#> 450: 0.047494    1.011535    3.414755    0.091712    0.070176    0.023946    0.671175    
#> 451: 0.047508    1.011584    3.414718    0.091765    0.070221    0.023951    0.671232    
#> 452: 0.047440    1.011654    3.414679    0.091810    0.070220    0.023935    0.671207    
#> 453: 0.047292    1.011691    3.414601    0.091829    0.070188    0.023925    0.671187    
#> 454: 0.047100    1.011854    3.414501    0.091831    0.070173    0.023922    0.671176    
#> 455: 0.047069    1.011954    3.414454    0.091848    0.070160    0.023935    0.671176    
#> 456: 0.046907    1.012006    3.414398    0.091834    0.070138    0.023941    0.671161    
#> 457: 0.046769    1.012021    3.414375    0.091891    0.070134    0.023942    0.671093    
#> 458: 0.046668    1.012189    3.414351    0.091907    0.070146    0.023929    0.671052    
#> 459: 0.046511    1.012353    3.414290    0.091951    0.070198    0.023913    0.670969    
#> 460: 0.046323    1.012385    3.414209    0.091966    0.070173    0.023897    0.670925    
#> 461: 0.046147    1.012438    3.414173    0.091964    0.070163    0.023891    0.670924    
#> 462: 0.046096    1.012521    3.414156    0.091933    0.070171    0.023884    0.670939    
#> 463: 0.046041    1.012600    3.414142    0.091905    0.070199    0.023878    0.670983    
#> 464: 0.046012    1.012695    3.414068    0.091827    0.070241    0.023869    0.670957    
#> 465: 0.045865    1.012624    3.414049    0.091814    0.070286    0.023854    0.671017    
#> 466: 0.045813    1.012662    3.413986    0.091767    0.070274    0.023826    0.671051    
#> 467: 0.045696    1.012658    3.413972    0.091824    0.070259    0.023805    0.671063    
#> 468: 0.045710    1.012645    3.413982    0.091811    0.070256    0.023784    0.671104    
#> 469: 0.045737    1.012683    3.413994    0.091808    0.070236    0.023791    0.671086    
#> 470: 0.045710    1.012786    3.413965    0.091729    0.070212    0.023791    0.671059    
#> 471: 0.045539    1.012817    3.413937    0.091694    0.070202    0.023773    0.671093    
#> 472: 0.045545    1.012767    3.413958    0.091685    0.070209    0.023772    0.671068    
#> 473: 0.045491    1.012760    3.413966    0.091612    0.070170    0.023771    0.671048    
#> 474: 0.045440    1.012756    3.413951    0.091455    0.070157    0.023761    0.671105    
#> 475: 0.045515    1.012819    3.413961    0.091328    0.070146    0.023753    0.671080    
#> 476: 0.045542    1.012839    3.413954    0.091220    0.070181    0.023744    0.671104    
#> 477: 0.045553    1.012826    3.414003    0.091167    0.070229    0.023739    0.671059    
#> 478: 0.045441    1.012854    3.413955    0.091216    0.070262    0.023744    0.671120    
#> 479: 0.045455    1.012891    3.413940    0.091299    0.070267    0.023738    0.671092    
#> 480: 0.045472    1.012932    3.413943    0.091330    0.070307    0.023742    0.671060    
#> 481: 0.045441    1.012990    3.413940    0.091424    0.070292    0.023739    0.671002    
#> 482: 0.045426    1.013002    3.413894    0.091530    0.070260    0.023744    0.670960    
#> 483: 0.045329    1.012959    3.413856    0.091571    0.070204    0.023744    0.670928    
#> 484: 0.045365    1.012901    3.413870    0.091626    0.070137    0.023749    0.670882    
#> 485: 0.045333    1.012960    3.413879    0.091673    0.070115    0.023757    0.670896    
#> 486: 0.045276    1.012995    3.413903    0.091704    0.070077    0.023743    0.670897    
#> 487: 0.045344    1.013019    3.413941    0.091693    0.070085    0.023726    0.670851    
#> 488: 0.045385    1.013002    3.413970    0.091725    0.070064    0.023716    0.670801    
#> 489: 0.045485    1.012948    3.414005    0.091762    0.070065    0.023724    0.670820    
#> 490: 0.045517    1.012957    3.414061    0.091749    0.070122    0.023723    0.670813    
#> 491: 0.045618    1.012995    3.414139    0.091720    0.070127    0.023733    0.670771    
#> 492: 0.045655    1.013085    3.414150    0.091647    0.070163    0.023716    0.670822    
#> 493: 0.045665    1.013097    3.414166    0.091614    0.070158    0.023732    0.670836    
#> 494: 0.045715    1.013092    3.414160    0.091666    0.070120    0.023741    0.670757    
#> 495: 0.045792    1.013080    3.414189    0.091754    0.070085    0.023743    0.670696    
#> 496: 0.045935    1.013229    3.414160    0.091770    0.070118    0.023727    0.670721    
#> 497: 0.045943    1.013224    3.414158    0.091744    0.070098    0.023718    0.670717    
#> 498: 0.045917    1.013249    3.414137    0.091707    0.070097    0.023722    0.670698    
#> 499: 0.045861    1.013276    3.414081    0.091684    0.070057    0.023721    0.670689    
#> 500: 0.045778    1.013319    3.414006    0.091680    0.070063    0.023715    0.670656    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.275035    0.970544    3.454949    0.400674    0.081620    0.016800    1.518177    
#> 002: 0.242691    0.999555    3.498481    0.380640    0.077539    0.016039    1.075250    
#> 003: 0.366813    0.971843    3.510998    0.361608    0.073662    0.015506    0.917388    
#> 004: 0.325143    1.008102    3.503678    0.343528    0.074293    0.014731    0.818678    
#> 005: 0.367945    1.042553    3.492413    0.326351    0.098713    0.013994    0.758264    
#> 006: 0.350673    1.062243    3.484187    0.322748    0.099156    0.013536    0.710079    
#> 007: 0.318788    1.078149    3.485350    0.353656    0.106776    0.014732    0.712993    
#> 008: 0.303625    1.069426    3.476999    0.335973    0.107822    0.013996    0.726363    
#> 009: 0.277158    1.074169    3.462996    0.321282    0.102431    0.013367    0.719688    
#> 010: 0.296956    1.072190    3.464245    0.327954    0.097309    0.014015    0.729045    
#> 011: 0.342917    1.079312    3.472651    0.339679    0.092444    0.013314    0.734794    
#> 012: 0.335685    1.064541    3.464361    0.397562    0.087821    0.012648    0.692700    
#> 013: 0.305754    1.073964    3.463280    0.481106    0.083430    0.017223    0.684783    
#> 014: 0.362575    1.063464    3.477262    0.541035    0.079259    0.020847    0.694396    
#> 015: 0.363583    1.062103    3.485257    0.513983    0.076778    0.020228    0.670465    
#> 016: 0.334842    1.086487    3.476621    0.488284    0.074599    0.022479    0.688164    
#> 017: 0.355377    1.075573    3.491920    0.463870    0.077108    0.021519    0.683075    
#> 018: 0.345329    1.087700    3.474920    0.440676    0.077450    0.020443    0.686274    
#> 019: 0.300964    1.103160    3.470531    0.419765    0.073578    0.019421    0.676890    
#> 020: 0.354532    1.085379    3.482684    0.481256    0.071565    0.022338    0.692915    
#> 021: 0.398148    1.067865    3.497224    0.464995    0.071678    0.021540    0.687742    
#> 022: 0.403136    1.072333    3.507238    0.448630    0.068094    0.025132    0.686112    
#> 023: 0.450150    1.064482    3.509597    0.462351    0.078211    0.023876    0.696919    
#> 024: 0.402262    1.095861    3.496293    0.439233    0.079056    0.022682    0.696733    
#> 025: 0.369500    1.071204    3.485917    0.551187    0.075103    0.024242    0.701650    
#> 026: 0.358540    1.093690    3.473694    0.523628    0.071348    0.026524    0.699053    
#> 027: 0.339336    1.101631    3.470270    0.497446    0.071528    0.025198    0.701424    
#> 028: 0.344409    1.095614    3.467027    0.494318    0.067952    0.023938    0.674058    
#> 029: 0.339820    1.092312    3.453363    0.487675    0.064554    0.024602    0.694404    
#> 030: 0.351470    1.091624    3.466964    0.463291    0.061377    0.033698    0.688739    
#> 031: 0.304908    1.076960    3.477957    0.465516    0.068576    0.032013    0.685961    
#> 032: 0.307795    1.076096    3.484975    0.442240    0.066912    0.030412    0.684316    
#> 033: 0.290907    1.091925    3.467524    0.452545    0.068312    0.028892    0.688711    
#> 034: 0.340434    1.091511    3.481885    0.450842    0.064896    0.027447    0.678134    
#> 035: 0.351419    1.068286    3.484366    0.428962    0.061759    0.026075    0.659304    
#> 036: 0.343301    1.086728    3.476558    0.460038    0.060494    0.024771    0.680618    
#> 037: 0.308669    1.106564    3.468202    0.437036    0.074780    0.023533    0.702977    
#> 038: 0.369955    1.095886    3.468874    0.486164    0.078871    0.024291    0.688608    
#> 039: 0.382267    1.080831    3.494137    0.467270    0.077888    0.023076    0.678318    
#> 040: 0.399515    1.088682    3.494148    0.482808    0.075283    0.023022    0.693908    
#> 041: 0.345358    1.077548    3.487446    0.458667    0.076498    0.021871    0.687856    
#> 042: 0.368408    1.090508    3.477909    0.476772    0.074480    0.021739    0.681426    
#> 043: 0.335617    1.085568    3.464250    0.488094    0.081218    0.020652    0.697135    
#> 044: 0.319376    1.096664    3.467067    0.463690    0.091514    0.019620    0.690573    
#> 045: 0.290408    1.113030    3.458359    0.440505    0.086938    0.018639    0.696676    
#> 046: 0.328197    1.076382    3.478135    0.418480    0.082591    0.017707    0.681793    
#> 047: 0.339180    1.088125    3.478752    0.430926    0.078462    0.019708    0.672725    
#> 048: 0.311994    1.095131    3.469052    0.409379    0.074539    0.024676    0.665955    
#> 049: 0.339440    1.079072    3.470865    0.473190    0.073618    0.023443    0.669205    
#> 050: 0.400624    1.061541    3.486977    0.574965    0.069937    0.022270    0.688329    
#> 051: 0.373067    1.071163    3.481871    0.546216    0.066440    0.021416    0.699995    
#> 052: 0.393277    1.077035    3.503340    0.518906    0.066818    0.021249    0.678204    
#> 053: 0.380145    1.073692    3.490955    0.492960    0.081572    0.021062    0.687020    
#> 054: 0.387325    1.072535    3.491996    0.468312    0.077493    0.029366    0.695117    
#> 055: 0.400111    1.070591    3.499546    0.454171    0.073998    0.027898    0.697665    
#> 056: 0.415505    1.067122    3.499216    0.571952    0.087272    0.026503    0.728350    
#> 057: 0.417503    1.063583    3.504603    0.543354    0.082908    0.025178    0.714822    
#> 058: 0.391355    1.077589    3.483397    0.551356    0.078763    0.023919    0.704786    
#> 059: 0.378036    1.033965    3.498723    0.575680    0.077275    0.026421    0.699297    
#> 060: 0.401240    1.039483    3.506080    0.546896    0.074740    0.034504    0.715672    
#> 061: 0.412593    1.042941    3.515343    0.519551    0.071003    0.032779    0.717618    
#> 062: 0.428454    1.049036    3.516037    0.534443    0.067453    0.033673    0.691763    
#> 063: 0.431976    1.032529    3.513033    0.507721    0.064080    0.031989    0.701927    
#> 064: 0.401580    1.042221    3.504520    0.501016    0.060876    0.030390    0.717892    
#> 065: 0.412267    1.040624    3.503546    0.475965    0.057833    0.028870    0.693515    
#> 066: 0.399996    1.066289    3.494055    0.558926    0.056389    0.027427    0.675249    
#> 067: 0.372523    1.055064    3.484596    0.530980    0.058040    0.026056    0.686008    
#> 068: 0.331517    1.066991    3.490814    0.504431    0.070136    0.025085    0.698461    
#> 069: 0.336700    1.057354    3.486623    0.555088    0.073752    0.023831    0.694538    
#> 070: 0.366045    1.068334    3.488711    0.564532    0.070863    0.024393    0.690985    
#> 071: 0.292238    1.102485    3.456582    0.536305    0.074944    0.023173    0.724236    
#> 072: 0.313399    1.071023    3.469654    0.509490    0.076036    0.022014    0.701022    
#> 073: 0.342574    1.090260    3.486318    0.484016    0.078549    0.021614    0.689798    
#> 074: 0.320296    1.057283    3.491279    0.459815    0.074621    0.024351    0.702085    
#> 075: 0.383706    1.047932    3.511737    0.495643    0.085471    0.023527    0.694191    
#> 076: 0.386144    1.049242    3.522522    0.470861    0.081198    0.033490    0.718579    
#> 077: 0.432546    1.037383    3.512296    0.447318    0.077138    0.031816    0.716293    
#> 078: 0.382841    1.044805    3.508491    0.495713    0.073281    0.030225    0.700768    
#> 079: 0.396246    1.063577    3.497037    0.470927    0.069617    0.032365    0.722541    
#> 080: 0.389318    1.049542    3.492736    0.449307    0.068231    0.030746    0.734545    
#> 081: 0.392683    1.056141    3.492479    0.426842    0.064820    0.029209    0.709208    
#> 082: 0.356416    1.045264    3.500102    0.405500    0.061579    0.029787    0.722965    
#> 083: 0.357150    1.069458    3.497233    0.430331    0.058500    0.028892    0.700690    
#> 084: 0.369477    1.077604    3.493731    0.408815    0.067216    0.027447    0.684880    
#> 085: 0.400516    1.085782    3.518167    0.388374    0.063856    0.026075    0.695391    
#> 086: 0.378309    1.072892    3.510809    0.368955    0.060663    0.026250    0.690535    
#> 087: 0.344541    1.066178    3.502480    0.351925    0.057883    0.024938    0.690929    
#> 088: 0.335028    1.072637    3.503574    0.397721    0.061919    0.023691    0.692539    
#> 089: 0.333842    1.081351    3.481859    0.401756    0.065642    0.022506    0.693804    
#> 090: 0.328432    1.088382    3.477566    0.414913    0.083861    0.021381    0.687174    
#> 091: 0.311218    1.067840    3.457214    0.394167    0.079668    0.020312    0.692048    
#> 092: 0.312674    1.098245    3.453760    0.466574    0.079815    0.019296    0.681850    
#> 093: 0.273782    1.100182    3.446791    0.447881    0.076435    0.018332    0.695077    
#> 094: 0.290351    1.110760    3.449722    0.425487    0.078231    0.021076    0.705217    
#> 095: 0.312394    1.106630    3.468552    0.404212    0.074319    0.020023    0.695225    
#> 096: 0.267826    1.106861    3.460226    0.384002    0.091547    0.019021    0.686613    
#> 097: 0.309879    1.095606    3.463792    0.364802    0.086970    0.020614    0.691760    
#> 098: 0.299030    1.118839    3.468024    0.346561    0.082621    0.019677    0.693519    
#> 099: 0.322695    1.072793    3.472078    0.367842    0.081199    0.018979    0.694751    
#> 100: 0.319803    1.094068    3.477756    0.381026    0.077139    0.018244    0.666505    
#> 101: 0.304377    1.092800    3.459423    0.444406    0.073282    0.020126    0.678373    
#> 102: 0.279379    1.085448    3.451436    0.422186    0.069618    0.019168    0.691178    
#> 103: 0.278455    1.098268    3.462464    0.407745    0.069901    0.020292    0.682441    
#> 104: 0.286319    1.102501    3.480422    0.395244    0.081157    0.021256    0.705214    
#> 105: 0.326199    1.099856    3.474893    0.420531    0.077099    0.020194    0.694179    
#> 106: 0.370050    1.091436    3.471529    0.448901    0.073244    0.021103    0.692403    
#> 107: 0.330413    1.112154    3.458524    0.507589    0.087610    0.021220    0.676191    
#> 108: 0.323679    1.091724    3.457913    0.518439    0.083988    0.020159    0.703375    
#> 109: 0.329597    1.107318    3.472883    0.492517    0.090789    0.019151    0.689393    
#> 110: 0.346826    1.088785    3.459173    0.483238    0.086250    0.018194    0.696937    
#> 111: 0.344757    1.097717    3.468180    0.462582    0.081937    0.017284    0.686952    
#> 112: 0.289596    1.082018    3.450846    0.453845    0.077840    0.017515    0.692258    
#> 113: 0.287910    1.117453    3.454076    0.431832    0.073948    0.016639    0.679326    
#> 114: 0.316191    1.110227    3.459698    0.469980    0.070251    0.020768    0.702722    
#> 115: 0.342126    1.081712    3.466159    0.497129    0.066738    0.020272    0.701807    
#> 116: 0.359438    1.086875    3.471185    0.472273    0.074763    0.022907    0.681956    
#> 117: 0.314012    1.103966    3.472588    0.448659    0.071025    0.024101    0.685860    
#> 118: 0.330693    1.089543    3.478754    0.426226    0.067474    0.026923    0.689613    
#> 119: 0.347344    1.091167    3.474555    0.434995    0.064100    0.025670    0.706813    
#> 120: 0.315427    1.080635    3.478118    0.413245    0.065331    0.029144    0.688416    
#> 121: 0.360994    1.100565    3.476887    0.416050    0.065142    0.028065    0.691578    
#> 122: 0.381667    1.067497    3.496410    0.412647    0.069719    0.026661    0.689503    
#> 123: 0.398084    1.088727    3.499350    0.429461    0.077350    0.025328    0.706406    
#> 124: 0.401863    1.109042    3.491123    0.459612    0.073483    0.024078    0.711737    
#> 125: 0.376611    1.101729    3.480698    0.466187    0.069808    0.022874    0.694363    
#> 126: 0.347935    1.108975    3.472339    0.442878    0.076899    0.022109    0.698561    
#> 127: 0.364674    1.088290    3.476862    0.474532    0.077945    0.025308    0.700876    
#> 128: 0.320849    1.059894    3.484928    0.510819    0.074048    0.029860    0.711958    
#> 129: 0.356323    1.086878    3.483899    0.511109    0.070346    0.030270    0.712707    
#> 130: 0.365411    1.100467    3.479625    0.485554    0.066828    0.032150    0.676022    
#> 131: 0.345358    1.077788    3.474547    0.461276    0.063487    0.030543    0.687642    
#> 132: 0.328068    1.095178    3.457076    0.449813    0.064217    0.029015    0.686947    
#> 133: 0.338303    1.084638    3.472784    0.573026    0.073248    0.027565    0.688119    
#> 134: 0.363148    1.074120    3.493806    0.552953    0.075521    0.026186    0.687742    
#> 135: 0.350399    1.078282    3.476704    0.525597    0.071745    0.024877    0.689924    
#> 136: 0.336038    1.081983    3.473496    0.499317    0.068354    0.025212    0.669372    
#> 137: 0.363879    1.079146    3.473225    0.474351    0.070721    0.025001    0.683038    
#> 138: 0.318657    1.091271    3.477154    0.450634    0.071731    0.023772    0.672020    
#> 139: 0.315811    1.096371    3.484424    0.430307    0.073785    0.022583    0.691269    
#> 140: 0.359173    1.093688    3.491976    0.422214    0.085518    0.023777    0.695710    
#> 141: 0.368602    1.076509    3.488443    0.430037    0.088232    0.022588    0.686755    
#> 142: 0.381069    1.055155    3.505580    0.478530    0.083820    0.023997    0.689950    
#> 143: 0.374301    1.074276    3.495783    0.517118    0.079629    0.023774    0.698059    
#> 144: 0.409026    1.078723    3.502577    0.491262    0.075865    0.022918    0.671476    
#> 145: 0.350280    1.088121    3.483575    0.485532    0.080220    0.021772    0.684788    
#> 146: 0.341020    1.081832    3.494063    0.461256    0.076209    0.020683    0.703321    
#> 147: 0.318500    1.071271    3.479261    0.438193    0.082015    0.019649    0.694167    
#> 148: 0.356440    1.084492    3.486444    0.508346    0.085161    0.019819    0.686687    
#> 149: 0.358513    1.058074    3.493878    0.482929    0.086992    0.018828    0.682541    
#> 150: 0.371914    1.055722    3.482054    0.458782    0.085711    0.017886    0.703097    
#> 151: 0.291934    1.087603    3.470328    0.435843    0.081425    0.016992    0.692086    
#> 152: 0.311210    1.099647    3.481543    0.405616    0.079990    0.015344    0.709264    
#> 153: 0.322141    1.097651    3.494763    0.360049    0.085917    0.018788    0.708807    
#> 154: 0.367743    1.076826    3.487345    0.393495    0.082577    0.020067    0.701343    
#> 155: 0.367687    1.060695    3.494364    0.387599    0.087657    0.018008    0.709070    
#> 156: 0.352933    1.066253    3.500164    0.304637    0.088088    0.015111    0.723291    
#> 157: 0.396291    1.054591    3.501274    0.382071    0.101350    0.014774    0.714400    
#> 158: 0.395492    1.065903    3.493115    0.427470    0.103340    0.017423    0.697176    
#> 159: 0.350643    1.073490    3.489018    0.431222    0.090053    0.016406    0.702072    
#> 160: 0.376019    1.046828    3.494925    0.455259    0.082967    0.015291    0.704651    
#> 161: 0.360946    1.059867    3.500577    0.386903    0.075069    0.018790    0.697975    
#> 162: 0.356657    1.074470    3.494252    0.353683    0.084746    0.018988    0.708004    
#> 163: 0.385011    1.065634    3.486521    0.366444    0.101019    0.019628    0.689170    
#> 164: 0.384034    1.059309    3.490999    0.422177    0.068626    0.021259    0.678392    
#> 165: 0.354699    1.064708    3.486233    0.399750    0.074874    0.021448    0.684039    
#> 166: 0.331324    1.095127    3.481413    0.354461    0.079715    0.021047    0.690222    
#> 167: 0.381927    1.107691    3.494759    0.427805    0.082460    0.018407    0.696309    
#> 168: 0.406210    1.094966    3.492673    0.444881    0.091157    0.018572    0.685300    
#> 169: 0.376128    1.122079    3.487462    0.375649    0.085938    0.017233    0.698896    
#> 170: 0.393882    1.086505    3.496743    0.370437    0.079463    0.017027    0.675456    
#> 171: 0.364638    1.078958    3.492807    0.354076    0.066200    0.015809    0.669972    
#> 172: 0.327185    1.100943    3.486067    0.352112    0.073276    0.015048    0.677307    
#> 173: 0.325612    1.096247    3.471734    0.368113    0.069260    0.015213    0.677156    
#> 174: 0.338331    1.087106    3.485884    0.333828    0.081275    0.016049    0.678055    
#> 175: 0.335210    1.098630    3.469027    0.394030    0.077964    0.015636    0.693929    
#> 176: 0.315813    1.101135    3.480860    0.303398    0.070753    0.017279    0.692845    
#> 177: 0.325928    1.112641    3.480561    0.325065    0.079139    0.022860    0.689654    
#> 178: 0.322697    1.083254    3.474799    0.342864    0.079956    0.021047    0.694289    
#> 179: 0.366678    1.089332    3.486365    0.341365    0.070477    0.023253    0.709367    
#> 180: 0.312336    1.088561    3.483170    0.320780    0.063022    0.020506    0.717275    
#> 181: 0.328064    1.067561    3.462247    0.354723    0.056153    0.018216    0.707420    
#> 182: 0.307022    1.093930    3.450359    0.405118    0.066601    0.016979    0.713326    
#> 183: 0.316481    1.107298    3.451430    0.430863    0.081833    0.016289    0.699397    
#> 184: 0.289082    1.109853    3.449633    0.449111    0.069612    0.015695    0.704358    
#> 185: 0.287712    1.134584    3.447233    0.480119    0.078955    0.016669    0.695733    
#> 186: 0.298009    1.127578    3.459849    0.462086    0.067423    0.023818    0.696384    
#> 187: 0.324433    1.083751    3.471821    0.492294    0.073395    0.024110    0.690512    
#> 188: 0.291536    1.101677    3.476753    0.401656    0.081652    0.021376    0.709277    
#> 189: 0.338052    1.109617    3.485592    0.419185    0.076464    0.020177    0.709760    
#> 190: 0.316193    1.097110    3.480748    0.448147    0.070671    0.018679    0.695460    
#> 191: 0.312571    1.097420    3.475129    0.398447    0.064432    0.019397    0.669037    
#> 192: 0.334231    1.098755    3.488061    0.471170    0.073396    0.020466    0.675908    
#> 193: 0.342013    1.106448    3.480236    0.452155    0.070027    0.019022    0.689509    
#> 194: 0.320051    1.093462    3.465486    0.446701    0.068524    0.017747    0.691844    
#> 195: 0.311552    1.111247    3.464668    0.468074    0.080299    0.018984    0.687763    
#> 196: 0.309007    1.090297    3.477753    0.445623    0.077503    0.020274    0.701817    
#> 197: 0.321049    1.086461    3.501541    0.382082    0.072518    0.020985    0.695056    
#> 198: 0.384710    1.058655    3.503279    0.466569    0.068682    0.022203    0.688749    
#> 199: 0.362832    1.061444    3.500068    0.430095    0.065180    0.020966    0.687940    
#> 200: 0.398239    1.053347    3.501326    0.576282    0.073330    0.023076    0.699957    
#> 201: 0.381429    1.045921    3.500786    0.538391    0.069530    0.026022    0.695528    
#> 202: 0.376326    1.053620    3.496453    0.515699    0.070798    0.026363    0.698714    
#> 203: 0.381259    1.055187    3.493607    0.501794    0.066381    0.026132    0.695537    
#> 204: 0.382449    1.055570    3.493645    0.507598    0.066124    0.024930    0.693408    
#> 205: 0.375863    1.062624    3.493339    0.499065    0.064468    0.024627    0.697150    
#> 206: 0.370373    1.068073    3.493703    0.492647    0.063436    0.024659    0.699447    
#> 207: 0.365167    1.071501    3.490540    0.493971    0.064906    0.023895    0.697979    
#> 208: 0.362208    1.073490    3.489056    0.487695    0.065236    0.023421    0.696417    
#> 209: 0.365062    1.072269    3.488978    0.487696    0.066149    0.022943    0.695676    
#> 210: 0.364885    1.070608    3.489084    0.484975    0.066172    0.022512    0.694489    
#> 211: 0.366781    1.070367    3.490280    0.478515    0.066642    0.022299    0.692333    
#> 212: 0.368909    1.069050    3.491098    0.473479    0.067667    0.022219    0.691733    
#> 213: 0.370085    1.067004    3.491306    0.467888    0.069059    0.021966    0.693667    
#> 214: 0.371151    1.066219    3.491563    0.460949    0.069897    0.021667    0.695149    
#> 215: 0.370671    1.066185    3.492514    0.453587    0.070798    0.021386    0.695191    
#> 216: 0.374693    1.064550    3.493538    0.450744    0.072333    0.021429    0.696532    
#> 217: 0.373447    1.065466    3.493705    0.444472    0.073465    0.021508    0.697008    
#> 218: 0.373447    1.067263    3.492932    0.445518    0.074296    0.021677    0.696224    
#> 219: 0.370435    1.067000    3.491774    0.443172    0.073833    0.021826    0.695667    
#> 220: 0.367398    1.067441    3.491076    0.448012    0.073454    0.021810    0.696028    
#> 221: 0.366365    1.068770    3.490482    0.449914    0.073420    0.021828    0.695817    
#> 222: 0.365257    1.069462    3.489714    0.450086    0.073581    0.021885    0.695516    
#> 223: 0.364996    1.070128    3.489365    0.447453    0.073635    0.021720    0.695131    
#> 224: 0.365655    1.071040    3.489710    0.444548    0.073389    0.021686    0.694802    
#> 225: 0.365152    1.070401    3.490100    0.440972    0.073022    0.021858    0.694725    
#> 226: 0.364690    1.070209    3.489590    0.439578    0.072879    0.021871    0.694353    
#> 227: 0.364073    1.070144    3.489658    0.437916    0.072638    0.021820    0.693831    
#> 228: 0.362912    1.071362    3.488937    0.437421    0.072655    0.021844    0.693260    
#> 229: 0.360805    1.071544    3.488343    0.437503    0.072406    0.021827    0.692795    
#> 230: 0.361253    1.071461    3.487968    0.437783    0.072116    0.021802    0.692776    
#> 231: 0.360840    1.071909    3.487796    0.437989    0.072088    0.021687    0.692461    
#> 232: 0.360787    1.072109    3.488160    0.435543    0.072030    0.021686    0.692181    
#> 233: 0.360578    1.071108    3.488626    0.435537    0.072471    0.021822    0.692230    
#> 234: 0.360459    1.071172    3.488462    0.437710    0.072614    0.021954    0.691967    
#> 235: 0.360479    1.071417    3.488267    0.437534    0.072723    0.022042    0.691999    
#> 236: 0.360349    1.072179    3.487957    0.438281    0.072777    0.022073    0.692167    
#> 237: 0.360613    1.072263    3.487894    0.437610    0.072908    0.022079    0.692764    
#> 238: 0.360771    1.072428    3.487784    0.437778    0.073043    0.022032    0.693642    
#> 239: 0.360141    1.072864    3.487488    0.437310    0.073407    0.022007    0.693658    
#> 240: 0.359597    1.072883    3.487371    0.437879    0.073383    0.021883    0.693679    
#> 241: 0.359190    1.072112    3.487255    0.438037    0.073446    0.021766    0.693746    
#> 242: 0.358758    1.071703    3.486967    0.436638    0.073748    0.021663    0.693795    
#> 243: 0.358509    1.072230    3.486981    0.436056    0.074313    0.021502    0.694231    
#> 244: 0.357258    1.072045    3.487055    0.436098    0.074341    0.021451    0.694509    
#> 245: 0.357295    1.071835    3.487168    0.435465    0.074726    0.021443    0.694826    
#> 246: 0.358006    1.071803    3.487496    0.434946    0.074612    0.021507    0.694800    
#> 247: 0.358541    1.072099    3.487824    0.435083    0.074609    0.021546    0.694225    
#> 248: 0.358437    1.072456    3.487871    0.434128    0.074444    0.021580    0.694010    
#> 249: 0.358198    1.072838    3.487768    0.435205    0.074750    0.021591    0.693520    
#> 250: 0.358871    1.073104    3.487862    0.436179    0.074991    0.021642    0.693526    
#> 251: 0.359519    1.073175    3.488289    0.436344    0.075104    0.021672    0.693320    
#> 252: 0.360673    1.073210    3.488529    0.436091    0.075153    0.021740    0.693315    
#> 253: 0.360547    1.073184    3.488477    0.437425    0.075058    0.021792    0.693453    
#> 254: 0.360783    1.073448    3.488586    0.437557    0.074922    0.021793    0.693597    
#> 255: 0.360147    1.073890    3.488530    0.436777    0.074848    0.021797    0.693565    
#> 256: 0.359893    1.074212    3.488318    0.435550    0.074942    0.021765    0.693482    
#> 257: 0.359036    1.074387    3.488076    0.435220    0.075010    0.021775    0.693297    
#> 258: 0.358275    1.074496    3.487855    0.434738    0.075064    0.021783    0.693300    
#> 259: 0.358011    1.074463    3.487726    0.434008    0.074858    0.021731    0.693226    
#> 260: 0.358150    1.074870    3.487768    0.433613    0.074837    0.021657    0.693004    
#> 261: 0.358534    1.074728    3.487947    0.432140    0.074954    0.021582    0.692810    
#> 262: 0.358911    1.074764    3.488095    0.431151    0.074859    0.021575    0.692699    
#> 263: 0.359442    1.074979    3.488240    0.430807    0.074900    0.021527    0.692785    
#> 264: 0.359921    1.074934    3.488401    0.431492    0.075217    0.021509    0.692930    
#> 265: 0.359765    1.075011    3.488389    0.432320    0.075399    0.021497    0.693019    
#> 266: 0.359994    1.075091    3.488364    0.432091    0.075496    0.021534    0.693177    
#> 267: 0.360492    1.074821    3.488654    0.432598    0.075360    0.021570    0.692977    
#> 268: 0.360295    1.074657    3.488570    0.432566    0.075456    0.021457    0.693060    
#> 269: 0.360785    1.074566    3.488590    0.432893    0.075399    0.021428    0.693182    
#> 270: 0.360912    1.074858    3.488443    0.433009    0.075358    0.021420    0.693121    
#> 271: 0.360770    1.075248    3.488130    0.433220    0.075222    0.021395    0.693266    
#> 272: 0.360630    1.075023    3.488067    0.433228    0.075113    0.021353    0.693742    
#> 273: 0.360216    1.075117    3.488121    0.432917    0.075043    0.021376    0.694124    
#> 274: 0.359818    1.075380    3.488148    0.432348    0.075007    0.021419    0.694127    
#> 275: 0.359539    1.075556    3.487981    0.431733    0.074860    0.021414    0.694248    
#> 276: 0.359449    1.075635    3.488098    0.431807    0.074639    0.021485    0.694314    
#> 277: 0.359123    1.075724    3.488209    0.432173    0.074569    0.021564    0.694133    
#> 278: 0.358911    1.075845    3.488223    0.432230    0.074487    0.021589    0.693869    
#> 279: 0.358253    1.075875    3.488208    0.431544    0.074393    0.021630    0.693760    
#> 280: 0.358215    1.076192    3.488305    0.430060    0.074242    0.021685    0.693537    
#> 281: 0.358124    1.076079    3.488437    0.428883    0.074214    0.021717    0.693419    
#> 282: 0.358306    1.075983    3.488605    0.428466    0.074064    0.021781    0.693306    
#> 283: 0.358521    1.075886    3.488843    0.428780    0.074012    0.021860    0.693359    
#> 284: 0.358582    1.075555    3.488906    0.429474    0.073929    0.021928    0.693385    
#> 285: 0.358567    1.075661    3.488703    0.429908    0.073850    0.022008    0.693474    
#> 286: 0.357951    1.075882    3.488438    0.430141    0.073725    0.022035    0.693486    
#> 287: 0.357430    1.076387    3.488064    0.430883    0.073727    0.022072    0.693409    
#> 288: 0.357554    1.076549    3.487926    0.431298    0.073724    0.022140    0.693384    
#> 289: 0.357533    1.076826    3.487834    0.431193    0.073785    0.022157    0.693367    
#> 290: 0.356961    1.077018    3.487604    0.430536    0.073874    0.022190    0.693557    
#> 291: 0.356486    1.077214    3.487528    0.429550    0.073946    0.022165    0.693441    
#> 292: 0.356178    1.077294    3.487399    0.429749    0.073951    0.022149    0.693330    
#> 293: 0.356088    1.077226    3.487288    0.430692    0.073904    0.022127    0.693182    
#> 294: 0.356223    1.077346    3.487220    0.431700    0.073841    0.022132    0.693041    
#> 295: 0.356275    1.076961    3.487232    0.431754    0.073694    0.022171    0.692949    
#> 296: 0.356505    1.076808    3.487285    0.431582    0.073663    0.022215    0.692979    
#> 297: 0.356693    1.076876    3.487318    0.431553    0.073536    0.022225    0.692958    
#> 298: 0.356678    1.076752    3.487298    0.431514    0.073483    0.022239    0.692829    
#> 299: 0.356548    1.076666    3.487216    0.431587    0.073455    0.022257    0.692617    
#> 300: 0.356894    1.076493    3.487376    0.431818    0.073447    0.022229    0.692563    
#> 301: 0.357321    1.076284    3.487452    0.431778    0.073371    0.022206    0.692666    
#> 302: 0.357512    1.076443    3.487452    0.431224    0.073381    0.022174    0.692548    
#> 303: 0.357423    1.076550    3.487408    0.430897    0.073536    0.022106    0.692461    
#> 304: 0.357568    1.076765    3.487367    0.430393    0.073661    0.022055    0.692440    
#> 305: 0.357634    1.076379    3.487439    0.430386    0.073682    0.022048    0.692464    
#> 306: 0.357503    1.076062    3.487397    0.430476    0.073738    0.022066    0.692343    
#> 307: 0.357167    1.075838    3.487331    0.429953    0.073661    0.022066    0.692523    
#> 308: 0.356957    1.075649    3.487295    0.429607    0.073653    0.022089    0.692626    
#> 309: 0.357130    1.075563    3.487256    0.429463    0.073704    0.022122    0.692809    
#> 310: 0.357305    1.075514    3.487225    0.429527    0.073724    0.022119    0.692952    
#> 311: 0.357274    1.075531    3.487243    0.429468    0.073655    0.022100    0.692944    
#> 312: 0.356993    1.075507    3.487133    0.429021    0.073650    0.022100    0.693180    
#> 313: 0.356787    1.075272    3.487137    0.427887    0.073686    0.022149    0.693270    
#> 314: 0.356741    1.075181    3.487146    0.427531    0.073715    0.022159    0.693409    
#> 315: 0.356778    1.075251    3.487142    0.427077    0.073727    0.022165    0.693375    
#> 316: 0.356592    1.075384    3.487177    0.426443    0.073752    0.022166    0.693428    
#> 317: 0.356396    1.075354    3.487191    0.426610    0.073813    0.022132    0.693791    
#> 318: 0.356416    1.075536    3.487078    0.425960    0.073860    0.022123    0.693945    
#> 319: 0.356473    1.075427    3.487192    0.425788    0.073824    0.022125    0.694056    
#> 320: 0.356272    1.075437    3.487151    0.425677    0.073868    0.022125    0.694098    
#> 321: 0.355868    1.075441    3.486926    0.425195    0.073810    0.022135    0.694141    
#> 322: 0.355669    1.075520    3.486800    0.424586    0.073838    0.022152    0.694034    
#> 323: 0.355325    1.075596    3.486625    0.424529    0.073808    0.022169    0.693898    
#> 324: 0.355143    1.075824    3.486584    0.424498    0.073864    0.022185    0.693756    
#> 325: 0.354773    1.076070    3.486418    0.424393    0.073843    0.022166    0.693688    
#> 326: 0.354651    1.076027    3.486264    0.424745    0.073750    0.022212    0.693507    
#> 327: 0.354683    1.076062    3.486276    0.425056    0.073728    0.022237    0.693460    
#> 328: 0.354635    1.076323    3.486231    0.425744    0.073650    0.022258    0.693366    
#> 329: 0.354458    1.076428    3.486128    0.426214    0.073663    0.022254    0.693288    
#> 330: 0.353871    1.076634    3.486003    0.425920    0.073630    0.022223    0.693301    
#> 331: 0.353617    1.076837    3.485965    0.426059    0.073589    0.022207    0.693145    
#> 332: 0.353690    1.076810    3.485931    0.426668    0.073646    0.022214    0.693131    
#> 333: 0.353651    1.076967    3.485819    0.426853    0.073591    0.022219    0.693130    
#> 334: 0.353343    1.076874    3.485605    0.426839    0.073559    0.022219    0.693098    
#> 335: 0.352795    1.076932    3.485403    0.426409    0.073480    0.022209    0.693206    
#> 336: 0.352162    1.077244    3.485251    0.426010    0.073464    0.022214    0.693284    
#> 337: 0.352056    1.077729    3.485116    0.426412    0.073419    0.022205    0.693321    
#> 338: 0.351921    1.077889    3.485121    0.426571    0.073334    0.022248    0.693336    
#> 339: 0.351633    1.078067    3.485086    0.426792    0.073314    0.022294    0.693370    
#> 340: 0.351564    1.077865    3.485062    0.426901    0.073249    0.022348    0.693464    
#> 341: 0.351674    1.077858    3.485117    0.427110    0.073311    0.022386    0.693598    
#> 342: 0.351602    1.077704    3.485160    0.426993    0.073317    0.022396    0.693470    
#> 343: 0.351386    1.077800    3.485183    0.427020    0.073318    0.022364    0.693343    
#> 344: 0.351523    1.077759    3.485300    0.427051    0.073320    0.022349    0.693228    
#> 345: 0.351752    1.077548    3.485421    0.427019    0.073278    0.022337    0.693185    
#> 346: 0.351575    1.077533    3.485383    0.426820    0.073207    0.022358    0.693147    
#> 347: 0.351494    1.077327    3.485326    0.426556    0.073101    0.022388    0.693190    
#> 348: 0.351196    1.077427    3.485192    0.426550    0.073066    0.022404    0.693136    
#> 349: 0.350838    1.077388    3.485089    0.426444    0.072994    0.022403    0.693079    
#> 350: 0.350389    1.077330    3.484963    0.426373    0.072976    0.022402    0.693107    
#> 351: 0.350140    1.077614    3.484744    0.426816    0.072997    0.022409    0.693194    
#> 352: 0.349794    1.077832    3.484618    0.427106    0.073013    0.022464    0.693292    
#> 353: 0.349785    1.078073    3.484522    0.427008    0.072974    0.022482    0.693230    
#> 354: 0.349692    1.078203    3.484417    0.426885    0.072867    0.022519    0.693112    
#> 355: 0.349859    1.078170    3.484387    0.426674    0.072755    0.022550    0.693032    
#> 356: 0.349754    1.078117    3.484383    0.426601    0.072674    0.022572    0.693174    
#> 357: 0.350078    1.078247    3.484367    0.427417    0.072550    0.022563    0.693144    
#> 358: 0.350140    1.078438    3.484362    0.427587    0.072583    0.022540    0.693097    
#> 359: 0.350155    1.078616    3.484384    0.427350    0.072547    0.022543    0.693053    
#> 360: 0.350036    1.078713    3.484299    0.427096    0.072493    0.022535    0.692996    
#> 361: 0.350032    1.078735    3.484253    0.427144    0.072345    0.022501    0.692952    
#> 362: 0.350135    1.078837    3.484158    0.427464    0.072320    0.022471    0.692812    
#> 363: 0.350184    1.078905    3.484149    0.427589    0.072380    0.022420    0.692715    
#> 364: 0.350219    1.079010    3.484161    0.427155    0.072489    0.022363    0.692727    
#> 365: 0.349994    1.079128    3.484158    0.426819    0.072652    0.022307    0.692763    
#> 366: 0.349881    1.079296    3.484056    0.426187    0.072725    0.022261    0.692895    
#> 367: 0.349959    1.079281    3.484019    0.425801    0.072785    0.022214    0.692873    
#> 368: 0.349996    1.079431    3.483976    0.425381    0.072738    0.022188    0.692832    
#> 369: 0.349843    1.079453    3.483951    0.424912    0.072751    0.022181    0.692858    
#> 370: 0.349853    1.079493    3.483979    0.424373    0.072762    0.022205    0.692941    
#> 371: 0.349984    1.079388    3.484000    0.424240    0.072724    0.022231    0.692931    
#> 372: 0.349969    1.079393    3.484033    0.424083    0.072699    0.022249    0.692841    
#> 373: 0.349831    1.079475    3.483983    0.424166    0.072642    0.022280    0.692831    
#> 374: 0.350011    1.079473    3.483940    0.424121    0.072551    0.022296    0.692871    
#> 375: 0.350181    1.079420    3.484012    0.424154    0.072517    0.022315    0.692928    
#> 376: 0.350245    1.079416    3.484012    0.424300    0.072452    0.022352    0.692898    
#> 377: 0.350086    1.079448    3.483987    0.424531    0.072343    0.022379    0.692956    
#> 378: 0.349704    1.079395    3.483891    0.424659    0.072274    0.022417    0.692979    
#> 379: 0.349601    1.079188    3.483896    0.424740    0.072142    0.022474    0.692967    
#> 380: 0.349422    1.079034    3.483888    0.424506    0.072083    0.022520    0.692984    
#> 381: 0.349057    1.079066    3.483760    0.424559    0.072163    0.022535    0.692888    
#> 382: 0.348728    1.079114    3.483688    0.424254    0.072087    0.022572    0.692786    
#> 383: 0.348576    1.079168    3.483603    0.424202    0.072161    0.022534    0.692749    
#> 384: 0.348307    1.079123    3.483604    0.424008    0.072101    0.022549    0.692789    
#> 385: 0.348365    1.079110    3.483615    0.424115    0.072090    0.022546    0.692781    
#> 386: 0.348525    1.079066    3.483721    0.424207    0.072098    0.022550    0.692787    
#> 387: 0.348859    1.079010    3.483861    0.424388    0.072050    0.022564    0.692752    
#> 388: 0.349051    1.079020    3.483988    0.424130    0.071975    0.022567    0.692758    
#> 389: 0.349174    1.078887    3.484037    0.423776    0.071938    0.022565    0.692791    
#> 390: 0.349106    1.078999    3.483989    0.423540    0.071898    0.022563    0.692787    
#> 391: 0.349202    1.078895    3.483995    0.423427    0.071875    0.022569    0.692682    
#> 392: 0.349093    1.078965    3.484018    0.423239    0.071879    0.022579    0.692709    
#> 393: 0.349077    1.078944    3.483941    0.423399    0.071872    0.022608    0.692688    
#> 394: 0.349127    1.078971    3.483866    0.423560    0.071913    0.022605    0.692769    
#> 395: 0.349242    1.079055    3.483843    0.423857    0.071986    0.022605    0.692813    
#> 396: 0.349316    1.079154    3.483869    0.423764    0.072056    0.022594    0.692806    
#> 397: 0.349476    1.079152    3.483925    0.424033    0.072062    0.022591    0.692852    
#> 398: 0.349590    1.079084    3.483956    0.424106    0.072095    0.022591    0.692839    
#> 399: 0.349568    1.079088    3.483983    0.424092    0.072113    0.022589    0.692827    
#> 400: 0.349670    1.079151    3.483965    0.424103    0.072160    0.022582    0.692757    
#> 401: 0.349697    1.079221    3.483923    0.424156    0.072215    0.022549    0.692816    
#> 402: 0.349610    1.079309    3.483897    0.423780    0.072266    0.022527    0.692827    
#> 403: 0.349719    1.079239    3.483876    0.423971    0.072243    0.022498    0.692747    
#> 404: 0.349672    1.079207    3.483784    0.423941    0.072264    0.022487    0.692711    
#> 405: 0.349642    1.079193    3.483804    0.424139    0.072259    0.022491    0.692784    
#> 406: 0.349804    1.079166    3.483776    0.424869    0.072237    0.022511    0.692800    
#> 407: 0.349914    1.079207    3.483782    0.425273    0.072248    0.022510    0.692726    
#> 408: 0.350143    1.079361    3.483801    0.425191    0.072314    0.022499    0.692714    
#> 409: 0.350023    1.079279    3.483769    0.425187    0.072305    0.022491    0.692687    
#> 410: 0.349849    1.079367    3.483692    0.425127    0.072305    0.022478    0.692627    
#> 411: 0.349791    1.079315    3.483665    0.424891    0.072286    0.022471    0.692642    
#> 412: 0.349664    1.079420    3.483610    0.424549    0.072284    0.022444    0.692725    
#> 413: 0.349498    1.079424    3.483551    0.424460    0.072235    0.022428    0.692786    
#> 414: 0.349411    1.079369    3.483589    0.424484    0.072172    0.022434    0.692765    
#> 415: 0.349542    1.079363    3.483601    0.424184    0.072172    0.022422    0.692762    
#> 416: 0.349625    1.079453    3.483643    0.424232    0.072166    0.022427    0.692797    
#> 417: 0.349629    1.079383    3.483618    0.424024    0.072172    0.022414    0.692849    
#> 418: 0.349503    1.079442    3.483600    0.424089    0.072235    0.022395    0.692801    
#> 419: 0.349474    1.079584    3.483593    0.423913    0.072199    0.022402    0.692778    
#> 420: 0.349466    1.079599    3.483618    0.423859    0.072181    0.022412    0.692680    
#> 421: 0.349342    1.079624    3.483678    0.423646    0.072138    0.022424    0.692698    
#> 422: 0.349465    1.079604    3.483715    0.423641    0.072062    0.022431    0.692687    
#> 423: 0.349743    1.079574    3.483841    0.423514    0.071999    0.022460    0.692764    
#> 424: 0.349763    1.079539    3.483837    0.423413    0.071936    0.022470    0.692736    
#> 425: 0.349856    1.079550    3.483842    0.423254    0.071876    0.022494    0.692764    
#> 426: 0.349878    1.079660    3.483848    0.423250    0.071882    0.022499    0.692722    
#> 427: 0.349759    1.079718    3.483873    0.423150    0.071865    0.022493    0.692721    
#> 428: 0.349718    1.079726    3.483879    0.423452    0.071873    0.022486    0.692709    
#> 429: 0.349837    1.079716    3.483960    0.423358    0.071879    0.022473    0.692720    
#> 430: 0.349965    1.079706    3.484007    0.423407    0.071844    0.022458    0.692717    
#> 431: 0.350082    1.079664    3.484041    0.423389    0.071843    0.022438    0.692724    
#> 432: 0.350236    1.079651    3.484119    0.423405    0.071864    0.022430    0.692755    
#> 433: 0.350406    1.079680    3.484174    0.423115    0.071852    0.022425    0.692770    
#> 434: 0.350346    1.079523    3.484215    0.422976    0.071811    0.022432    0.692765    
#> 435: 0.350420    1.079471    3.484210    0.422529    0.071783    0.022432    0.692749    
#> 436: 0.350356    1.079451    3.484257    0.422353    0.071797    0.022414    0.692705    
#> 437: 0.350467    1.079363    3.484267    0.422508    0.071809    0.022412    0.692692    
#> 438: 0.350439    1.079437    3.484291    0.422777    0.071771    0.022432    0.692601    
#> 439: 0.350592    1.079493    3.484305    0.422992    0.071751    0.022449    0.692472    
#> 440: 0.350742    1.079547    3.484371    0.423092    0.071734    0.022437    0.692459    
#> 441: 0.350888    1.079451    3.484415    0.423195    0.071709    0.022437    0.692454    
#> 442: 0.350802    1.079508    3.484439    0.423131    0.071676    0.022435    0.692413    
#> 443: 0.350785    1.079601    3.484396    0.422985    0.071665    0.022419    0.692407    
#> 444: 0.350745    1.079643    3.484343    0.422864    0.071703    0.022426    0.692343    
#> 445: 0.350588    1.079688    3.484300    0.422867    0.071663    0.022450    0.692349    
#> 446: 0.350326    1.079766    3.484244    0.422938    0.071664    0.022439    0.692337    
#> 447: 0.350311    1.079919    3.484216    0.422717    0.071693    0.022438    0.692310    
#> 448: 0.350188    1.079953    3.484183    0.422635    0.071724    0.022427    0.692304    
#> 449: 0.350154    1.080140    3.484188    0.422676    0.071815    0.022392    0.692407    
#> 450: 0.350070    1.080176    3.484167    0.422569    0.071934    0.022365    0.692483    
#> 451: 0.350095    1.080263    3.484100    0.422909    0.072072    0.022346    0.692560    
#> 452: 0.350025    1.080356    3.484069    0.423014    0.072127    0.022319    0.692528    
#> 453: 0.349916    1.080418    3.484052    0.422899    0.072156    0.022313    0.692510    
#> 454: 0.349829    1.080482    3.484033    0.422711    0.072144    0.022299    0.692505    
#> 455: 0.349792    1.080481    3.484023    0.422697    0.072116    0.022299    0.692447    
#> 456: 0.349756    1.080462    3.484002    0.422985    0.072158    0.022280    0.692452    
#> 457: 0.349860    1.080406    3.484022    0.423130    0.072196    0.022265    0.692372    
#> 458: 0.349939    1.080470    3.484098    0.423207    0.072242    0.022252    0.692273    
#> 459: 0.349962    1.080599    3.484136    0.423161    0.072301    0.022244    0.692259    
#> 460: 0.349926    1.080685    3.484146    0.422983    0.072349    0.022233    0.692271    
#> 461: 0.349931    1.080756    3.484187    0.422816    0.072375    0.022245    0.692180    
#> 462: 0.349843    1.080857    3.484165    0.422985    0.072381    0.022251    0.692129    
#> 463: 0.349800    1.080895    3.484131    0.423124    0.072364    0.022263    0.692100    
#> 464: 0.349834    1.080919    3.484085    0.423192    0.072360    0.022265    0.692027    
#> 465: 0.349790    1.080814    3.484033    0.423345    0.072377    0.022250    0.692005    
#> 466: 0.349813    1.080829    3.484007    0.423521    0.072380    0.022244    0.691964    
#> 467: 0.349683    1.080822    3.484027    0.423724    0.072396    0.022234    0.691925    
#> 468: 0.349925    1.080810    3.484077    0.424000    0.072386    0.022241    0.691930    
#> 469: 0.349967    1.080858    3.484124    0.423996    0.072386    0.022247    0.691941    
#> 470: 0.349934    1.080908    3.484125    0.423949    0.072354    0.022255    0.691899    
#> 471: 0.349883    1.080872    3.484118    0.423924    0.072317    0.022263    0.691930    
#> 472: 0.349813    1.080880    3.484103    0.423977    0.072352    0.022265    0.691890    
#> 473: 0.349673    1.080916    3.484073    0.423788    0.072339    0.022261    0.691827    
#> 474: 0.349594    1.080878    3.484079    0.423748    0.072291    0.022265    0.691874    
#> 475: 0.349668    1.080974    3.484060    0.423679    0.072316    0.022245    0.691854    
#> 476: 0.349589    1.080995    3.484024    0.423516    0.072343    0.022240    0.691875    
#> 477: 0.349530    1.081052    3.484007    0.423746    0.072309    0.022221    0.691826    
#> 478: 0.349372    1.081087    3.484007    0.423537    0.072326    0.022204    0.691821    
#> 479: 0.349334    1.081227    3.483999    0.423335    0.072372    0.022185    0.691840    
#> 480: 0.349300    1.081253    3.484024    0.423216    0.072439    0.022186    0.691926    
#> 481: 0.349358    1.081314    3.483996    0.423249    0.072488    0.022173    0.691999    
#> 482: 0.349473    1.081296    3.483961    0.423398    0.072562    0.022154    0.692075    
#> 483: 0.349471    1.081322    3.483964    0.423253    0.072610    0.022137    0.692035    
#> 484: 0.349457    1.081188    3.483982    0.423042    0.072585    0.022130    0.692030    
#> 485: 0.349471    1.081193    3.484001    0.422888    0.072602    0.022131    0.692093    
#> 486: 0.349461    1.081236    3.484025    0.422798    0.072608    0.022121    0.692097    
#> 487: 0.349647    1.081311    3.484088    0.422829    0.072599    0.022117    0.692152    
#> 488: 0.349635    1.081321    3.484101    0.422880    0.072625    0.022108    0.692086    
#> 489: 0.349820    1.081339    3.484093    0.422942    0.072683    0.022101    0.692088    
#> 490: 0.349970    1.081284    3.484160    0.422812    0.072676    0.022107    0.692092    
#> 491: 0.350090    1.081334    3.484195    0.422886    0.072649    0.022102    0.692091    
#> 492: 0.350104    1.081406    3.484183    0.422872    0.072669    0.022094    0.692176    
#> 493: 0.350010    1.081430    3.484168    0.422658    0.072694    0.022073    0.692177    
#> 494: 0.350106    1.081515    3.484119    0.422436    0.072722    0.022058    0.692168    
#> 495: 0.350125    1.081534    3.484096    0.422278    0.072746    0.022050    0.692172    
#> 496: 0.350120    1.081573    3.484022    0.422223    0.072732    0.022044    0.692172    
#> 497: 0.350154    1.081590    3.484000    0.422147    0.072729    0.022060    0.692254    
#> 498: 0.350131    1.081586    3.483960    0.422319    0.072727    0.022077    0.692223    
#> 499: 0.350224    1.081650    3.483946    0.422336    0.072724    0.022091    0.692171    
#> 500: 0.350243    1.081617    3.483929    0.422110    0.072668    0.022101    0.692135    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.300549    0.960803    3.444612    0.392401    0.083122    0.016800    1.677799    
#> 002: 0.382279    0.951601    3.469252    0.372781    0.078966    0.015960    1.141447    
#> 003: 0.486865    0.899317    3.462398    0.354142    0.075811    0.015162    0.886562    
#> 004: 0.470437    0.929140    3.462932    0.336435    0.094134    0.014404    0.765486    
#> 005: 0.533667    0.938978    3.449315    0.319613    0.101146    0.013684    0.717980    
#> 006: 0.507274    0.930717    3.450116    0.303633    0.103269    0.013000    0.697040    
#> 007: 0.454356    0.940298    3.449732    0.288451    0.111878    0.012350    0.723798    
#> 008: 0.457242    0.925942    3.440786    0.278063    0.130311    0.011732    0.725619    
#> 009: 0.441804    0.931186    3.442706    0.264160    0.140963    0.011146    0.723944    
#> 010: 0.477624    0.925856    3.438525    0.250952    0.140312    0.010723    0.726514    
#> 011: 0.516937    0.917055    3.450088    0.289914    0.133297    0.012295    0.727584    
#> 012: 0.526041    0.923232    3.451650    0.278398    0.126632    0.012558    0.722275    
#> 013: 0.483274    0.939640    3.445736    0.277179    0.120300    0.012290    0.719721    
#> 014: 0.519169    0.931791    3.445842    0.275343    0.114285    0.011676    0.726828    
#> 015: 0.532136    0.921375    3.465004    0.278195    0.108571    0.011092    0.710382    
#> 016: 0.526064    0.945425    3.461823    0.294990    0.109636    0.010538    0.721248    
#> 017: 0.528738    0.942442    3.465363    0.280240    0.125607    0.010011    0.709505    
#> 018: 0.534064    0.919199    3.458853    0.305842    0.119326    0.009510    0.719942    
#> 019: 0.493639    0.912523    3.453654    0.290550    0.114131    0.009035    0.723113    
#> 020: 0.490145    0.941702    3.460572    0.276023    0.122173    0.009064    0.711833    
#> 021: 0.519254    0.934233    3.465351    0.262222    0.116065    0.008611    0.711206    
#> 022: 0.528868    0.918482    3.475728    0.249111    0.121068    0.008181    0.707366    
#> 023: 0.565833    0.917214    3.475476    0.251250    0.115609    0.007772    0.735124    
#> 024: 0.556478    0.941175    3.469851    0.238688    0.109828    0.007383    0.737698    
#> 025: 0.541612    0.904737    3.463908    0.226753    0.126097    0.007014    0.733530    
#> 026: 0.554896    0.936023    3.466362    0.215416    0.132998    0.008326    0.703035    
#> 027: 0.507689    0.959309    3.462063    0.204645    0.126348    0.008015    0.735895    
#> 028: 0.538923    0.955359    3.460134    0.234488    0.120031    0.007665    0.722845    
#> 029: 0.558780    0.924550    3.448733    0.263936    0.114029    0.007282    0.755205    
#> 030: 0.551840    0.936771    3.455385    0.250739    0.113571    0.007064    0.743849    
#> 031: 0.506394    0.920323    3.461381    0.252003    0.116477    0.006905    0.716098    
#> 032: 0.497587    0.906332    3.467918    0.250632    0.121783    0.006931    0.712084    
#> 033: 0.504709    0.919605    3.459515    0.261308    0.115694    0.007229    0.713651    
#> 034: 0.551986    0.938561    3.461199    0.283257    0.123271    0.007863    0.713431    
#> 035: 0.536173    0.908829    3.464322    0.269094    0.130945    0.007470    0.719353    
#> 036: 0.526217    0.932718    3.462811    0.291996    0.125369    0.007097    0.735476    
#> 037: 0.516029    0.923721    3.468693    0.277396    0.133436    0.006742    0.728605    
#> 038: 0.540998    0.934998    3.461477    0.263527    0.126764    0.006878    0.729120    
#> 039: 0.544441    0.921280    3.467839    0.250350    0.120792    0.006534    0.709350    
#> 040: 0.535128    0.934765    3.471438    0.237833    0.127884    0.007297    0.724436    
#> 041: 0.468092    0.940285    3.451041    0.238380    0.124284    0.006932    0.719544    
#> 042: 0.505918    0.929267    3.450047    0.234944    0.138275    0.006586    0.721640    
#> 043: 0.487709    0.960447    3.442447    0.223197    0.133757    0.006256    0.704544    
#> 044: 0.465381    0.964716    3.442261    0.255063    0.127069    0.005944    0.715242    
#> 045: 0.483599    0.963596    3.438889    0.255992    0.133985    0.005646    0.713132    
#> 046: 0.465312    0.948458    3.440510    0.243193    0.130988    0.005364    0.706313    
#> 047: 0.501932    0.958624    3.436444    0.283752    0.126382    0.005096    0.718478    
#> 048: 0.508961    0.944328    3.437511    0.313968    0.120063    0.004841    0.714920    
#> 049: 0.498049    0.951848    3.447203    0.343811    0.114060    0.005829    0.718004    
#> 050: 0.543498    0.914791    3.456610    0.326620    0.112002    0.008090    0.712700    
#> 051: 0.537718    0.926836    3.454068    0.310289    0.122057    0.008350    0.728089    
#> 052: 0.542702    0.940649    3.460547    0.294775    0.128709    0.007933    0.705343    
#> 053: 0.544112    0.910535    3.468186    0.280036    0.122273    0.008417    0.708176    
#> 054: 0.506224    0.911849    3.463413    0.288621    0.140892    0.007996    0.715306    
#> 055: 0.513054    0.920836    3.464987    0.281130    0.133847    0.010166    0.716955    
#> 056: 0.528261    0.917243    3.465635    0.285861    0.127155    0.012219    0.734051    
#> 057: 0.574238    0.881881    3.480956    0.271568    0.120797    0.011609    0.750514    
#> 058: 0.583217    0.860713    3.492023    0.257990    0.114757    0.011028    0.742840    
#> 059: 0.551919    0.852897    3.492694    0.245090    0.122939    0.010477    0.749233    
#> 060: 0.550931    0.851584    3.501913    0.232836    0.129880    0.009953    0.758039    
#> 061: 0.580712    0.879780    3.492065    0.270871    0.155140    0.009455    0.746301    
#> 062: 0.596152    0.895168    3.494155    0.257327    0.152461    0.009248    0.739165    
#> 063: 0.602147    0.872430    3.487513    0.257213    0.144838    0.009094    0.741314    
#> 064: 0.577676    0.906388    3.482626    0.244352    0.137596    0.008639    0.722058    
#> 065: 0.568759    0.912077    3.471754    0.261148    0.132879    0.008207    0.709485    
#> 066: 0.560411    0.922405    3.471863    0.248090    0.126235    0.007797    0.694814    
#> 067: 0.543690    0.888198    3.472811    0.247966    0.119923    0.008805    0.717009    
#> 068: 0.534916    0.909238    3.482949    0.271266    0.121419    0.008784    0.748380    
#> 069: 0.529077    0.918399    3.466714    0.296685    0.144260    0.008345    0.719363    
#> 070: 0.549434    0.933887    3.468705    0.281851    0.139924    0.007928    0.711768    
#> 071: 0.506247    0.925501    3.457278    0.267759    0.146192    0.007531    0.710106    
#> 072: 0.496627    0.919818    3.459957    0.254371    0.138883    0.007155    0.718476    
#> 073: 0.543502    0.912718    3.479485    0.241652    0.131939    0.007860    0.715835    
#> 074: 0.533614    0.912846    3.479266    0.241838    0.128584    0.007467    0.720937    
#> 075: 0.552206    0.885041    3.492045    0.272885    0.125334    0.007393    0.720643    
#> 076: 0.582014    0.890928    3.495837    0.284612    0.143306    0.007024    0.743268    
#> 077: 0.604178    0.878075    3.493194    0.270382    0.136140    0.006919    0.730098    
#> 078: 0.600055    0.916487    3.489792    0.256863    0.133783    0.007912    0.725897    
#> 079: 0.587383    0.919526    3.491647    0.244019    0.133427    0.010128    0.732479    
#> 080: 0.578846    0.908243    3.487881    0.231819    0.132049    0.010852    0.749702    
#> 081: 0.554481    0.948750    3.478513    0.220228    0.125446    0.010309    0.738825    
#> 082: 0.547072    0.922612    3.479342    0.227926    0.119174    0.011625    0.733085    
#> 083: 0.562935    0.930878    3.484435    0.305735    0.113215    0.011438    0.732800    
#> 084: 0.539082    0.925114    3.469920    0.290448    0.107555    0.010866    0.727957    
#> 085: 0.514087    0.915215    3.479587    0.275926    0.128007    0.010323    0.719290    
#> 086: 0.529534    0.949083    3.468092    0.262129    0.121606    0.009806    0.710153    
#> 087: 0.513562    0.943928    3.453562    0.249023    0.124888    0.009316    0.710360    
#> 088: 0.491654    0.943404    3.452554    0.281541    0.143401    0.008850    0.716185    
#> 089: 0.468304    0.964122    3.440353    0.267464    0.147937    0.008408    0.714917    
#> 090: 0.443285    0.946195    3.432508    0.254091    0.140540    0.007987    0.741094    
#> 091: 0.449581    0.934061    3.419807    0.246772    0.133513    0.007588    0.743079    
#> 092: 0.466207    0.966950    3.423337    0.262847    0.142883    0.007209    0.723616    
#> 093: 0.429197    0.965452    3.418322    0.278416    0.135739    0.008506    0.735265    
#> 094: 0.470084    0.986915    3.419427    0.314793    0.128952    0.008080    0.733263    
#> 095: 0.474629    0.986427    3.434485    0.299053    0.122505    0.007891    0.715822    
#> 096: 0.447700    0.962131    3.438174    0.284100    0.137917    0.007496    0.707018    
#> 097: 0.490020    0.976311    3.437401    0.269895    0.131021    0.007121    0.705281    
#> 098: 0.493108    0.959330    3.449167    0.263275    0.124470    0.007815    0.721010    
#> 099: 0.464408    0.921322    3.440055    0.279718    0.139242    0.007432    0.717893    
#> 100: 0.441821    0.964914    3.428491    0.265732    0.132280    0.007232    0.713627    
#> 101: 0.414022    0.947358    3.416517    0.252445    0.125666    0.006870    0.710335    
#> 102: 0.450351    0.950909    3.415750    0.259183    0.122066    0.006527    0.727584    
#> 103: 0.459437    0.959949    3.427748    0.279139    0.115963    0.006200    0.713729    
#> 104: 0.435880    0.976534    3.435759    0.308636    0.133546    0.005890    0.710449    
#> 105: 0.479969    0.966438    3.434459    0.293204    0.126869    0.005596    0.725372    
#> 106: 0.504771    0.961557    3.438084    0.278544    0.120526    0.005495    0.718454    
#> 107: 0.521101    0.952254    3.444151    0.285799    0.118342    0.006083    0.712791    
#> 108: 0.500377    0.931346    3.441790    0.271509    0.122198    0.005779    0.710644    
#> 109: 0.467369    0.945833    3.446974    0.257933    0.122815    0.005490    0.715439    
#> 110: 0.514646    0.940848    3.437259    0.330763    0.126622    0.005216    0.710189    
#> 111: 0.492169    0.946821    3.444675    0.314225    0.126414    0.004955    0.720071    
#> 112: 0.475950    0.897256    3.444197    0.298514    0.121939    0.004707    0.728576    
#> 113: 0.484318    0.972177    3.435639    0.312592    0.115842    0.004472    0.704904    
#> 114: 0.469824    0.962943    3.438138    0.334614    0.110050    0.004248    0.723912    
#> 115: 0.516541    0.936460    3.441926    0.377629    0.113118    0.004036    0.729816    
#> 116: 0.498056    0.956563    3.443289    0.358748    0.123333    0.004184    0.715978    
#> 117: 0.485912    0.980326    3.441872    0.340810    0.117355    0.003975    0.738569    
#> 118: 0.524118    0.931779    3.447769    0.323770    0.123823    0.004117    0.736331    
#> 119: 0.510768    0.941257    3.449566    0.307581    0.117632    0.004147    0.749091    
#> 120: 0.481053    0.951581    3.442802    0.292202    0.142273    0.004262    0.725372    
#> 121: 0.494646    0.970283    3.445978    0.277592    0.160083    0.004049    0.720982    
#> 122: 0.522041    0.937040    3.453679    0.263713    0.152079    0.003846    0.718389    
#> 123: 0.553207    0.962745    3.448758    0.316907    0.148016    0.003654    0.734076    
#> 124: 0.511528    0.961538    3.444120    0.301061    0.151834    0.004144    0.735294    
#> 125: 0.525411    0.990062    3.439151    0.286008    0.144242    0.004144    0.724487    
#> 126: 0.478696    0.996563    3.429826    0.271708    0.137030    0.004080    0.741004    
#> 127: 0.499406    0.956331    3.435122    0.271265    0.130178    0.004591    0.725204    
#> 128: 0.474911    0.944246    3.445869    0.279065    0.123669    0.004362    0.721808    
#> 129: 0.519185    0.944753    3.450681    0.268143    0.146684    0.004160    0.720121    
#> 130: 0.571845    0.940509    3.456021    0.302115    0.139350    0.004534    0.704017    
#> 131: 0.544487    0.935843    3.455480    0.287009    0.155749    0.005544    0.723124    
#> 132: 0.499244    0.920841    3.445372    0.297918    0.147962    0.005267    0.737119    
#> 133: 0.482005    0.927341    3.444854    0.283022    0.161382    0.005003    0.749902    
#> 134: 0.529184    0.914512    3.457379    0.269185    0.153313    0.004798    0.736286    
#> 135: 0.507203    0.932633    3.457611    0.266384    0.162182    0.004558    0.716492    
#> 136: 0.522147    0.890196    3.461569    0.253064    0.175844    0.004331    0.711001    
#> 137: 0.562403    0.925848    3.467734    0.241305    0.167052    0.004114    0.727335    
#> 138: 0.509921    0.933388    3.461364    0.229240    0.158699    0.003908    0.730890    
#> 139: 0.526209    0.926954    3.472877    0.225198    0.156804    0.004352    0.735014    
#> 140: 0.537760    0.934266    3.483011    0.215796    0.148964    0.006771    0.742115    
#> 141: 0.545723    0.893527    3.484172    0.205007    0.149039    0.006959    0.728629    
#> 142: 0.565838    0.915886    3.486933    0.201497    0.144653    0.006611    0.738732    
#> 143: 0.537944    0.932295    3.488195    0.191422    0.137420    0.008024    0.734307    
#> 144: 0.606522    0.942187    3.491761    0.230860    0.130549    0.007623    0.709186    
#> 145: 0.549368    0.936161    3.472346    0.241298    0.124022    0.007242    0.699342    
#> 146: 0.534574    0.933668    3.469278    0.240554    0.117821    0.006880    0.712565    
#> 147: 0.479510    0.925981    3.456255    0.253536    0.134295    0.006536    0.700536    
#> 148: 0.498414    0.947860    3.459847    0.263915    0.127580    0.006360    0.699818    
#> 149: 0.494991    0.925219    3.457368    0.270250    0.121201    0.006042    0.714344    
#> 150: 0.527579    0.931336    3.449406    0.292465    0.115141    0.005740    0.733162    
#> 151: 0.488418    0.957266    3.446098    0.296120    0.109384    0.005453    0.733166    
#> 152: 0.494375    0.970079    3.453478    0.308659    0.116783    0.004227    0.724726    
#> 153: 0.505817    0.951166    3.454665    0.262450    0.120899    0.004501    0.724787    
#> 154: 0.529768    0.957343    3.459344    0.276528    0.131553    0.004831    0.737740    
#> 155: 0.520658    0.937241    3.454137    0.259589    0.124651    0.004717    0.718210    
#> 156: 0.533919    0.928565    3.471923    0.251431    0.143088    0.004576    0.726653    
#> 157: 0.564916    0.921619    3.477178    0.269689    0.167419    0.004038    0.740651    
#> 158: 0.597793    0.941659    3.481485    0.297239    0.127560    0.003705    0.731846    
#> 159: 0.545413    0.941506    3.473554    0.272737    0.106771    0.003667    0.735416    
#> 160: 0.548241    0.894860    3.478509    0.234154    0.122586    0.003177    0.752130    
#> 161: 0.556217    0.907398    3.474650    0.211752    0.139303    0.003369    0.760800    
#> 162: 0.533760    0.929503    3.462106    0.248827    0.140809    0.003258    0.752564    
#> 163: 0.544735    0.932044    3.460352    0.254152    0.166017    0.002928    0.734046    
#> 164: 0.530847    0.919688    3.465107    0.270870    0.137630    0.003006    0.728238    
#> 165: 0.560930    0.913328    3.476034    0.261980    0.114176    0.003612    0.717292    
#> 166: 0.558065    0.937847    3.472071    0.218756    0.128504    0.003955    0.711930    
#> 167: 0.548732    0.939319    3.474807    0.203647    0.128889    0.003291    0.738919    
#> 168: 0.551108    0.939620    3.475197    0.200549    0.139144    0.003138    0.743654    
#> 169: 0.530322    0.970462    3.463273    0.157346    0.137274    0.002228    0.776131    
#> 170: 0.542057    0.935221    3.465745    0.173374    0.130733    0.002093    0.760739    
#> 171: 0.496903    0.928950    3.464675    0.180872    0.135866    0.002833    0.724637    
#> 172: 0.499611    0.940432    3.462733    0.201545    0.148400    0.002319    0.730904    
#> 173: 0.512612    0.952499    3.455000    0.206943    0.143672    0.002751    0.740001    
#> 174: 0.499659    0.935018    3.454512    0.206748    0.138170    0.002526    0.733678    
#> 175: 0.505621    0.952515    3.454184    0.226660    0.125730    0.003211    0.737503    
#> 176: 0.515946    0.953771    3.455811    0.272237    0.133683    0.002638    0.748060    
#> 177: 0.535056    0.920483    3.463999    0.243425    0.149039    0.002831    0.732010    
#> 178: 0.528595    0.924509    3.465582    0.246323    0.155299    0.003182    0.717270    
#> 179: 0.571026    0.957585    3.460060    0.217156    0.152612    0.003197    0.738067    
#> 180: 0.491149    0.957576    3.454442    0.225837    0.143914    0.003229    0.733389    
#> 181: 0.492880    0.935186    3.439640    0.202218    0.131603    0.002377    0.713517    
#> 182: 0.476912    0.953608    3.431803    0.205214    0.129089    0.002850    0.710952    
#> 183: 0.456492    0.964414    3.436914    0.218455    0.113271    0.002848    0.725915    
#> 184: 0.477618    0.931638    3.437666    0.252314    0.119254    0.004158    0.745085    
#> 185: 0.480381    0.958641    3.436238    0.234287    0.108304    0.004003    0.736555    
#> 186: 0.498420    0.974049    3.448946    0.207877    0.112666    0.005898    0.729376    
#> 187: 0.496478    0.935886    3.458943    0.226352    0.122756    0.006187    0.710706    
#> 188: 0.486300    0.938855    3.448789    0.191743    0.123348    0.006574    0.746631    
#> 189: 0.513931    0.951597    3.461844    0.228518    0.118725    0.005934    0.729387    
#> 190: 0.504974    0.941857    3.464078    0.212252    0.121256    0.005146    0.713286    
#> 191: 0.500590    0.945713    3.455639    0.248084    0.144788    0.004468    0.700910    
#> 192: 0.485162    0.955387    3.455092    0.262729    0.132481    0.004034    0.712558    
#> 193: 0.548731    0.953175    3.455533    0.237348    0.125508    0.003407    0.694848    
#> 194: 0.490529    0.934630    3.448455    0.225956    0.136496    0.002779    0.716418    
#> 195: 0.452156    0.936716    3.437230    0.235201    0.157436    0.002559    0.732911    
#> 196: 0.448346    0.949700    3.438038    0.251752    0.143805    0.001906    0.735190    
#> 197: 0.432274    0.946998    3.450721    0.228856    0.148662    0.002208    0.744104    
#> 198: 0.492243    0.928308    3.438709    0.224920    0.122422    0.002588    0.740496    
#> 199: 0.432216    0.956695    3.432934    0.196126    0.120419    0.002672    0.739112    
#> 200: 0.433600    0.962274    3.441554    0.213422    0.127965    0.002848    0.739236    
#> 201: 0.445236    0.952319    3.443448    0.202592    0.128491    0.003479    0.728566    
#> 202: 0.465148    0.952670    3.444115    0.218802    0.131501    0.003676    0.728066    
#> 203: 0.478430    0.947723    3.443936    0.222773    0.134661    0.003788    0.725428    
#> 204: 0.486238    0.941342    3.445205    0.230716    0.137133    0.003703    0.725219    
#> 205: 0.491023    0.945283    3.445927    0.243589    0.139104    0.003644    0.725583    
#> 206: 0.496905    0.946736    3.447174    0.249621    0.135440    0.003745    0.726248    
#> 207: 0.493393    0.945210    3.446260    0.249074    0.134771    0.003866    0.726765    
#> 208: 0.494579    0.944840    3.445827    0.253770    0.134627    0.003898    0.725766    
#> 209: 0.500211    0.940975    3.446302    0.256128    0.135220    0.003949    0.724673    
#> 210: 0.503880    0.937032    3.447475    0.254237    0.135066    0.003970    0.723675    
#> 211: 0.507161    0.937565    3.448865    0.252074    0.135516    0.003918    0.723705    
#> 212: 0.510557    0.936384    3.449683    0.250364    0.136031    0.003833    0.724811    
#> 213: 0.513187    0.934628    3.450169    0.254208    0.137743    0.003846    0.725786    
#> 214: 0.515231    0.933774    3.450282    0.253498    0.138955    0.003821    0.726696    
#> 215: 0.516506    0.933713    3.450661    0.255391    0.139240    0.003799    0.728489    
#> 216: 0.518268    0.931981    3.450862    0.255995    0.139887    0.003777    0.729948    
#> 217: 0.518008    0.933630    3.450624    0.254266    0.140581    0.003717    0.729839    
#> 218: 0.517230    0.935089    3.450295    0.252872    0.140157    0.003617    0.728900    
#> 219: 0.516464    0.934551    3.449695    0.249120    0.140032    0.003584    0.729756    
#> 220: 0.514567    0.935257    3.449498    0.247052    0.139826    0.003532    0.730173    
#> 221: 0.513685    0.936404    3.449298    0.246285    0.139428    0.003479    0.730267    
#> 222: 0.514299    0.936299    3.449372    0.244260    0.139194    0.003431    0.730259    
#> 223: 0.514720    0.935301    3.449440    0.244589    0.138550    0.003409    0.730015    
#> 224: 0.516085    0.935032    3.449691    0.245307    0.138550    0.003400    0.729901    
#> 225: 0.516687    0.933441    3.450080    0.245864    0.138769    0.003397    0.729694    
#> 226: 0.517027    0.933024    3.449952    0.246276    0.139289    0.003385    0.729622    
#> 227: 0.516304    0.932825    3.450231    0.245618    0.138910    0.003371    0.729486    
#> 228: 0.515571    0.933950    3.450115    0.246139    0.138516    0.003329    0.729883    
#> 229: 0.514556    0.933243    3.450146    0.246589    0.138920    0.003301    0.729623    
#> 230: 0.514603    0.932569    3.450150    0.247884    0.139152    0.003278    0.729294    
#> 231: 0.514654    0.932569    3.450220    0.249021    0.139491    0.003263    0.729717    
#> 232: 0.513226    0.933159    3.450463    0.248476    0.139681    0.003274    0.730291    
#> 233: 0.512910    0.932182    3.450704    0.248072    0.139782    0.003222    0.731021    
#> 234: 0.511521    0.932409    3.450686    0.247213    0.139890    0.003191    0.730909    
#> 235: 0.510980    0.932197    3.450492    0.246435    0.139997    0.003181    0.731214    
#> 236: 0.511060    0.932739    3.450237    0.247080    0.139941    0.003165    0.731928    
#> 237: 0.511851    0.932730    3.450136    0.248491    0.139686    0.003167    0.732154    
#> 238: 0.511444    0.932779    3.450030    0.247327    0.139676    0.003177    0.732702    
#> 239: 0.510620    0.933039    3.449898    0.247400    0.139508    0.003183    0.732774    
#> 240: 0.509991    0.932935    3.449832    0.246948    0.139544    0.003195    0.732504    
#> 241: 0.510467    0.931944    3.450054    0.246844    0.139052    0.003200    0.732240    
#> 242: 0.509870    0.931722    3.450062    0.247943    0.138952    0.003212    0.732099    
#> 243: 0.508916    0.932199    3.450040    0.247642    0.138787    0.003238    0.732083    
#> 244: 0.507636    0.932261    3.450027    0.249043    0.138492    0.003254    0.732013    
#> 245: 0.507586    0.931666    3.449939    0.249906    0.138254    0.003254    0.732323    
#> 246: 0.506969    0.931284    3.449850    0.248961    0.138094    0.003278    0.732157    
#> 247: 0.506689    0.931054    3.449969    0.248584    0.138092    0.003287    0.731976    
#> 248: 0.506338    0.931290    3.449983    0.248196    0.137755    0.003299    0.731887    
#> 249: 0.506105    0.931586    3.449984    0.247832    0.137625    0.003326    0.731760    
#> 250: 0.506277    0.932294    3.449952    0.248431    0.137578    0.003342    0.731714    
#> 251: 0.506283    0.932940    3.450028    0.249627    0.137395    0.003346    0.731422    
#> 252: 0.506849    0.933047    3.450173    0.250051    0.136916    0.003345    0.731295    
#> 253: 0.506575    0.933419    3.450172    0.251085    0.136484    0.003359    0.730947    
#> 254: 0.506672    0.933347    3.450353    0.251452    0.135978    0.003380    0.730945    
#> 255: 0.506609    0.933507    3.450599    0.252268    0.135719    0.003418    0.730896    
#> 256: 0.506595    0.933634    3.450613    0.253542    0.135910    0.003455    0.730676    
#> 257: 0.506275    0.933109    3.450626    0.253642    0.136027    0.003481    0.730814    
#> 258: 0.506001    0.933092    3.450608    0.254358    0.136108    0.003479    0.730741    
#> 259: 0.505727    0.933482    3.450502    0.255441    0.136069    0.003471    0.730834    
#> 260: 0.505461    0.933920    3.450557    0.256138    0.136027    0.003469    0.730847    
#> 261: 0.505608    0.933915    3.450632    0.255940    0.135805    0.003459    0.731043    
#> 262: 0.506089    0.934249    3.450670    0.255522    0.135813    0.003447    0.731347    
#> 263: 0.505423    0.934691    3.450660    0.255049    0.135633    0.003454    0.731782    
#> 264: 0.505134    0.934766    3.450571    0.254472    0.135496    0.003438    0.732135    
#> 265: 0.505374    0.935079    3.450623    0.254543    0.135176    0.003438    0.732300    
#> 266: 0.505779    0.935265    3.450564    0.254291    0.135133    0.003448    0.731944    
#> 267: 0.506017    0.935499    3.450566    0.253937    0.135120    0.003456    0.731805    
#> 268: 0.506119    0.935323    3.450481    0.253187    0.135113    0.003452    0.732009    
#> 269: 0.506985    0.935559    3.450482    0.253304    0.135171    0.003456    0.732173    
#> 270: 0.507467    0.935963    3.450386    0.253596    0.135144    0.003448    0.731911    
#> 271: 0.507473    0.935848    3.450267    0.253523    0.135176    0.003436    0.731778    
#> 272: 0.507451    0.935647    3.450181    0.253986    0.135358    0.003425    0.732017    
#> 273: 0.507397    0.935716    3.450160    0.253653    0.135452    0.003416    0.732146    
#> 274: 0.507164    0.936043    3.450169    0.253467    0.135287    0.003409    0.732113    
#> 275: 0.507502    0.936181    3.450088    0.254157    0.135290    0.003409    0.732006    
#> 276: 0.507482    0.936552    3.450179    0.255115    0.135409    0.003404    0.732314    
#> 277: 0.507386    0.936811    3.450246    0.255157    0.135334    0.003397    0.732399    
#> 278: 0.506923    0.937079    3.450195    0.254693    0.135134    0.003387    0.732610    
#> 279: 0.506527    0.937190    3.450114    0.253660    0.135268    0.003376    0.733093    
#> 280: 0.506234    0.937409    3.450099    0.252773    0.135303    0.003368    0.733145    
#> 281: 0.505763    0.937592    3.450124    0.252542    0.135448    0.003354    0.733179    
#> 282: 0.505626    0.937695    3.450150    0.253136    0.135471    0.003355    0.732916    
#> 283: 0.505913    0.937733    3.450165    0.253752    0.135615    0.003365    0.732797    
#> 284: 0.505461    0.937620    3.450132    0.253386    0.135543    0.003377    0.732650    
#> 285: 0.505334    0.937626    3.449988    0.254048    0.135395    0.003401    0.732434    
#> 286: 0.505235    0.937667    3.449894    0.254795    0.135414    0.003417    0.732139    
#> 287: 0.505151    0.937740    3.449787    0.255523    0.135412    0.003415    0.731949    
#> 288: 0.505172    0.937794    3.449660    0.256026    0.135186    0.003422    0.731830    
#> 289: 0.505398    0.937747    3.449658    0.256573    0.135254    0.003425    0.731784    
#> 290: 0.505450    0.937686    3.449685    0.256649    0.135407    0.003422    0.731787    
#> 291: 0.505504    0.937941    3.449711    0.256616    0.135481    0.003423    0.731572    
#> 292: 0.505116    0.937809    3.449634    0.256588    0.135763    0.003414    0.731671    
#> 293: 0.504722    0.937857    3.449490    0.256716    0.135739    0.003403    0.731693    
#> 294: 0.504371    0.937882    3.449336    0.256880    0.135524    0.003398    0.731645    
#> 295: 0.504055    0.937777    3.449218    0.256861    0.135529    0.003386    0.731806    
#> 296: 0.503543    0.937765    3.449188    0.256504    0.135999    0.003374    0.731994    
#> 297: 0.503697    0.937743    3.449219    0.256641    0.136088    0.003372    0.732092    
#> 298: 0.503870    0.937594    3.449304    0.256663    0.136039    0.003372    0.732197    
#> 299: 0.504278    0.937695    3.449393    0.256790    0.135962    0.003364    0.732076    
#> 300: 0.504699    0.937465    3.449509    0.256734    0.135967    0.003364    0.731833    
#> 301: 0.504865    0.937393    3.449515    0.256406    0.136009    0.003364    0.731789    
#> 302: 0.504936    0.937441    3.449527    0.256343    0.135847    0.003355    0.731707    
#> 303: 0.504743    0.937646    3.449497    0.256305    0.135826    0.003356    0.731551    
#> 304: 0.504517    0.937819    3.449425    0.256532    0.135692    0.003366    0.731442    
#> 305: 0.504210    0.937714    3.449396    0.256861    0.135657    0.003371    0.731310    
#> 306: 0.503856    0.937731    3.449319    0.257238    0.135665    0.003381    0.731061    
#> 307: 0.503769    0.937550    3.449269    0.257284    0.135618    0.003380    0.730967    
#> 308: 0.503281    0.937523    3.449168    0.257806    0.135505    0.003373    0.730910    
#> 309: 0.503284    0.937228    3.449093    0.258385    0.135585    0.003374    0.730847    
#> 310: 0.503339    0.937177    3.448950    0.258794    0.135635    0.003365    0.730930    
#> 311: 0.503263    0.937236    3.448926    0.259286    0.135663    0.003360    0.730797    
#> 312: 0.503039    0.937137    3.448810    0.259519    0.135775    0.003355    0.730751    
#> 313: 0.502617    0.936948    3.448727    0.259777    0.135808    0.003349    0.730797    
#> 314: 0.502257    0.937146    3.448630    0.259961    0.135743    0.003349    0.730777    
#> 315: 0.501869    0.937199    3.448607    0.259842    0.135710    0.003345    0.730892    
#> 316: 0.502004    0.937452    3.448548    0.260206    0.135686    0.003340    0.730915    
#> 317: 0.501785    0.937513    3.448494    0.259997    0.135789    0.003337    0.731103    
#> 318: 0.501805    0.937674    3.448382    0.259971    0.135741    0.003336    0.731164    
#> 319: 0.501646    0.937874    3.448351    0.259921    0.135640    0.003346    0.731036    
#> 320: 0.500900    0.938027    3.448230    0.260118    0.135760    0.003361    0.730992    
#> 321: 0.500436    0.938315    3.448049    0.260353    0.135752    0.003380    0.730963    
#> 322: 0.500210    0.938406    3.447879    0.260434    0.135618    0.003393    0.730871    
#> 323: 0.499707    0.938497    3.447786    0.260486    0.135646    0.003396    0.730776    
#> 324: 0.499655    0.938685    3.447756    0.260152    0.135587    0.003397    0.730617    
#> 325: 0.499408    0.938824    3.447659    0.259904    0.135612    0.003398    0.730472    
#> 326: 0.499119    0.938823    3.447548    0.259595    0.135399    0.003401    0.730373    
#> 327: 0.498921    0.939023    3.447467    0.259350    0.135462    0.003416    0.730365    
#> 328: 0.498844    0.939089    3.447376    0.259194    0.135484    0.003430    0.730284    
#> 329: 0.498786    0.939152    3.447370    0.259431    0.135435    0.003444    0.730181    
#> 330: 0.498606    0.939204    3.447335    0.259791    0.135399    0.003454    0.730125    
#> 331: 0.498651    0.939330    3.447312    0.259961    0.135450    0.003460    0.730000    
#> 332: 0.498637    0.939268    3.447284    0.259939    0.135398    0.003460    0.730014    
#> 333: 0.498471    0.939338    3.447234    0.260281    0.135218    0.003463    0.730022    
#> 334: 0.498420    0.939043    3.447179    0.260447    0.135129    0.003463    0.729961    
#> 335: 0.498312    0.939168    3.447073    0.260144    0.134972    0.003463    0.729960    
#> 336: 0.497858    0.939448    3.446953    0.260099    0.134759    0.003475    0.729932    
#> 337: 0.497877    0.939855    3.446846    0.260080    0.134764    0.003484    0.729889    
#> 338: 0.497698    0.940017    3.446848    0.259886    0.134807    0.003495    0.729866    
#> 339: 0.497620    0.940208    3.446823    0.259481    0.134785    0.003502    0.729815    
#> 340: 0.497613    0.940066    3.446859    0.259418    0.134879    0.003508    0.729752    
#> 341: 0.497784    0.940033    3.446938    0.259155    0.134915    0.003506    0.729752    
#> 342: 0.497638    0.939806    3.446937    0.258888    0.134875    0.003505    0.729698    
#> 343: 0.497454    0.939844    3.446990    0.259070    0.134808    0.003497    0.729663    
#> 344: 0.497487    0.939786    3.447041    0.259264    0.134792    0.003495    0.729680    
#> 345: 0.497599    0.939789    3.447082    0.259357    0.134892    0.003496    0.729668    
#> 346: 0.497602    0.939826    3.447111    0.259616    0.134992    0.003493    0.729587    
#> 347: 0.497704    0.939807    3.447069    0.259326    0.135059    0.003494    0.729667    
#> 348: 0.497371    0.939901    3.446945    0.258983    0.135093    0.003499    0.729660    
#> 349: 0.497086    0.939859    3.446822    0.258870    0.135180    0.003503    0.729611    
#> 350: 0.496724    0.939806    3.446716    0.258617    0.135181    0.003506    0.729664    
#> 351: 0.496525    0.940140    3.446619    0.258473    0.135275    0.003513    0.729631    
#> 352: 0.496359    0.940382    3.446580    0.258707    0.135232    0.003519    0.729729    
#> 353: 0.496530    0.940588    3.446575    0.258685    0.135191    0.003532    0.729671    
#> 354: 0.496595    0.940667    3.446509    0.258653    0.135098    0.003539    0.729689    
#> 355: 0.496826    0.940591    3.446487    0.258785    0.135152    0.003535    0.729857    
#> 356: 0.496838    0.940566    3.446482    0.258911    0.135253    0.003525    0.729916    
#> 357: 0.496992    0.940619    3.446490    0.258842    0.135294    0.003517    0.729997    
#> 358: 0.496770    0.940669    3.446544    0.258851    0.135281    0.003513    0.729894    
#> 359: 0.496688    0.940662    3.446564    0.259020    0.135277    0.003508    0.729890    
#> 360: 0.496527    0.940595    3.446496    0.259247    0.135221    0.003507    0.729801    
#> 361: 0.496347    0.940575    3.446435    0.259303    0.135127    0.003502    0.729770    
#> 362: 0.496292    0.940570    3.446409    0.259280    0.135045    0.003501    0.729693    
#> 363: 0.496436    0.940456    3.446427    0.259369    0.135044    0.003508    0.729607    
#> 364: 0.496609    0.940496    3.446459    0.259344    0.135007    0.003511    0.729527    
#> 365: 0.496675    0.940488    3.446489    0.259532    0.134858    0.003517    0.729449    
#> 366: 0.496799    0.940475    3.446496    0.259515    0.134827    0.003524    0.729377    
#> 367: 0.496886    0.940485    3.446533    0.259010    0.134688    0.003528    0.729476    
#> 368: 0.496790    0.940586    3.446504    0.258702    0.134726    0.003537    0.729350    
#> 369: 0.496678    0.940638    3.446505    0.258103    0.134765    0.003539    0.729380    
#> 370: 0.496593    0.940776    3.446524    0.257568    0.134805    0.003548    0.729380    
#> 371: 0.496487    0.940927    3.446472    0.257375    0.134770    0.003553    0.729345    
#> 372: 0.496337    0.941018    3.446429    0.257128    0.134712    0.003558    0.729403    
#> 373: 0.496182    0.941194    3.446374    0.256952    0.134657    0.003563    0.729421    
#> 374: 0.496291    0.941312    3.446333    0.256795    0.134697    0.003562    0.729346    
#> 375: 0.496152    0.941373    3.446324    0.256772    0.134590    0.003560    0.729352    
#> 376: 0.496049    0.941443    3.446289    0.256538    0.134478    0.003559    0.729402    
#> 377: 0.496118    0.941544    3.446319    0.256531    0.134475    0.003556    0.729377    
#> 378: 0.495982    0.941571    3.446300    0.256564    0.134481    0.003554    0.729437    
#> 379: 0.495877    0.941488    3.446306    0.256533    0.134492    0.003551    0.729327    
#> 380: 0.495813    0.941515    3.446301    0.256379    0.134631    0.003553    0.729234    
#> 381: 0.495750    0.941609    3.446280    0.256574    0.134664    0.003553    0.729198    
#> 382: 0.495581    0.941648    3.446260    0.256758    0.134676    0.003551    0.729079    
#> 383: 0.495798    0.941702    3.446275    0.256850    0.134704    0.003551    0.729094    
#> 384: 0.495750    0.941678    3.446302    0.256919    0.134680    0.003556    0.729061    
#> 385: 0.495796    0.941595    3.446320    0.256772    0.134630    0.003564    0.729029    
#> 386: 0.495961    0.941754    3.446333    0.256706    0.134593    0.003567    0.729010    
#> 387: 0.496115    0.941880    3.446369    0.256520    0.134577    0.003571    0.728933    
#> 388: 0.496302    0.941947    3.446431    0.256494    0.134599    0.003571    0.728894    
#> 389: 0.496525    0.941788    3.446478    0.256539    0.134613    0.003570    0.729009    
#> 390: 0.496596    0.941810    3.446516    0.257059    0.134644    0.003571    0.728881    
#> 391: 0.496704    0.941708    3.446520    0.257182    0.134617    0.003575    0.728746    
#> 392: 0.496765    0.941707    3.446579    0.256922    0.134608    0.003577    0.728746    
#> 393: 0.496680    0.941541    3.446598    0.256890    0.134607    0.003580    0.728621    
#> 394: 0.496812    0.941467    3.446612    0.257187    0.134583    0.003581    0.728644    
#> 395: 0.497154    0.941479    3.446673    0.257271    0.134647    0.003581    0.728660    
#> 396: 0.497408    0.941446    3.446748    0.257275    0.134664    0.003582    0.728680    
#> 397: 0.497517    0.941381    3.446808    0.257215    0.134666    0.003591    0.728635    
#> 398: 0.497778    0.941279    3.446874    0.257312    0.134639    0.003598    0.728668    
#> 399: 0.497882    0.941290    3.446997    0.257158    0.134660    0.003603    0.728725    
#> 400: 0.498065    0.941233    3.447101    0.257140    0.134579    0.003608    0.728673    
#> 401: 0.498191    0.941236    3.447155    0.256970    0.134507    0.003620    0.728644    
#> 402: 0.498247    0.941279    3.447198    0.256929    0.134478    0.003627    0.728593    
#> 403: 0.498447    0.941281    3.447204    0.256729    0.134386    0.003633    0.728602    
#> 404: 0.498598    0.941314    3.447173    0.256638    0.134317    0.003633    0.728518    
#> 405: 0.498540    0.941336    3.447189    0.256700    0.134169    0.003641    0.728564    
#> 406: 0.498546    0.941388    3.447168    0.256590    0.134174    0.003651    0.728596    
#> 407: 0.498533    0.941382    3.447207    0.256564    0.134227    0.003655    0.728602    
#> 408: 0.498613    0.941402    3.447208    0.256677    0.134201    0.003656    0.728560    
#> 409: 0.498640    0.941269    3.447204    0.256669    0.134183    0.003654    0.728513    
#> 410: 0.498631    0.941290    3.447164    0.256662    0.134310    0.003652    0.728504    
#> 411: 0.498811    0.941050    3.447157    0.256530    0.134420    0.003657    0.728657    
#> 412: 0.498846    0.941077    3.447123    0.256452    0.134435    0.003659    0.728658    
#> 413: 0.498814    0.941065    3.447087    0.256496    0.134469    0.003659    0.728740    
#> 414: 0.498646    0.941014    3.447053    0.256325    0.134465    0.003662    0.728688    
#> 415: 0.498585    0.940965    3.447019    0.256114    0.134478    0.003665    0.728722    
#> 416: 0.498581    0.941085    3.447009    0.255984    0.134421    0.003665    0.728733    
#> 417: 0.498637    0.941192    3.446995    0.256058    0.134432    0.003666    0.728657    
#> 418: 0.498522    0.941298    3.446963    0.256241    0.134491    0.003669    0.728602    
#> 419: 0.498505    0.941462    3.446915    0.256314    0.134496    0.003671    0.728587    
#> 420: 0.498578    0.941475    3.446933    0.256479    0.134517    0.003671    0.728527    
#> 421: 0.498514    0.941469    3.446950    0.256642    0.134498    0.003669    0.728448    
#> 422: 0.498611    0.941396    3.446946    0.256594    0.134513    0.003668    0.728480    
#> 423: 0.498751    0.941317    3.446960    0.256708    0.134709    0.003662    0.728587    
#> 424: 0.498779    0.941214    3.446945    0.256866    0.134686    0.003656    0.728618    
#> 425: 0.499056    0.941251    3.446940    0.257168    0.134706    0.003657    0.728598    
#> 426: 0.499202    0.941321    3.446971    0.257273    0.134642    0.003654    0.728644    
#> 427: 0.499232    0.941251    3.446979    0.257342    0.134637    0.003649    0.728627    
#> 428: 0.499153    0.941311    3.446973    0.257238    0.134726    0.003642    0.728685    
#> 429: 0.499160    0.941386    3.446964    0.257261    0.134768    0.003638    0.728726    
#> 430: 0.499279    0.941413    3.446961    0.257356    0.134679    0.003638    0.728749    
#> 431: 0.499173    0.941423    3.446920    0.257238    0.134659    0.003637    0.728700    
#> 432: 0.499065    0.941567    3.446911    0.257347    0.134710    0.003637    0.728710    
#> 433: 0.499089    0.941645    3.446912    0.257332    0.134681    0.003639    0.728648    
#> 434: 0.498938    0.941623    3.446930    0.257127    0.134716    0.003641    0.728601    
#> 435: 0.498979    0.941564    3.446949    0.257085    0.134702    0.003639    0.728549    
#> 436: 0.499040    0.941516    3.446966    0.257114    0.134725    0.003638    0.728475    
#> 437: 0.498996    0.941453    3.446948    0.257157    0.134722    0.003639    0.728440    
#> 438: 0.498926    0.941591    3.446936    0.257075    0.134736    0.003635    0.728432    
#> 439: 0.498881    0.941718    3.446904    0.256770    0.134707    0.003632    0.728488    
#> 440: 0.498791    0.941791    3.446929    0.256651    0.134702    0.003630    0.728513    
#> 441: 0.498727    0.941776    3.446938    0.256624    0.134699    0.003628    0.728511    
#> 442: 0.498624    0.941884    3.446944    0.256636    0.134672    0.003624    0.728415    
#> 443: 0.498623    0.942043    3.446921    0.256467    0.134562    0.003622    0.728413    
#> 444: 0.498601    0.942206    3.446900    0.256383    0.134461    0.003625    0.728437    
#> 445: 0.498545    0.942277    3.446871    0.256107    0.134397    0.003629    0.728495    
#> 446: 0.498495    0.942337    3.446829    0.256318    0.134328    0.003630    0.728478    
#> 447: 0.498636    0.942396    3.446827    0.256273    0.134267    0.003635    0.728521    
#> 448: 0.498617    0.942433    3.446822    0.256215    0.134239    0.003640    0.728479    
#> 449: 0.498663    0.942497    3.446926    0.256141    0.134195    0.003644    0.728483    
#> 450: 0.498670    0.942407    3.446997    0.255975    0.134163    0.003650    0.728536    
#> 451: 0.498802    0.942353    3.447043    0.255795    0.134152    0.003654    0.728610    
#> 452: 0.498726    0.942337    3.447044    0.255528    0.134183    0.003655    0.728622    
#> 453: 0.498574    0.942298    3.447030    0.255534    0.134210    0.003651    0.728567    
#> 454: 0.498477    0.942432    3.446998    0.255424    0.134187    0.003648    0.728556    
#> 455: 0.498459    0.942481    3.446968    0.255421    0.134140    0.003650    0.728509    
#> 456: 0.498429    0.942497    3.446950    0.255455    0.134106    0.003655    0.728471    
#> 457: 0.498452    0.942427    3.446984    0.255391    0.134094    0.003655    0.728396    
#> 458: 0.498498    0.942536    3.447033    0.255446    0.134065    0.003654    0.728385    
#> 459: 0.498438    0.942668    3.447059    0.255141    0.134061    0.003652    0.728411    
#> 460: 0.498280    0.942729    3.447062    0.254879    0.134086    0.003651    0.728423    
#> 461: 0.498303    0.942753    3.447083    0.254542    0.134017    0.003653    0.728525    
#> 462: 0.498141    0.942784    3.447110    0.254246    0.133948    0.003659    0.728558    
#> 463: 0.498108    0.942754    3.447139    0.254213    0.133931    0.003659    0.728534    
#> 464: 0.498042    0.942727    3.447169    0.254079    0.133878    0.003658    0.728499    
#> 465: 0.498001    0.942470    3.447173    0.254066    0.133851    0.003658    0.728510    
#> 466: 0.498006    0.942461    3.447134    0.253909    0.133839    0.003654    0.728595    
#> 467: 0.497955    0.942401    3.447120    0.254042    0.133803    0.003656    0.728575    
#> 468: 0.498110    0.942388    3.447130    0.254204    0.133776    0.003657    0.728619    
#> 469: 0.498082    0.942514    3.447136    0.254052    0.133741    0.003655    0.728677    
#> 470: 0.498105    0.942545    3.447138    0.254042    0.133722    0.003657    0.728691    
#> 471: 0.498096    0.942401    3.447131    0.254034    0.133686    0.003656    0.728677    
#> 472: 0.498053    0.942329    3.447154    0.254050    0.133691    0.003657    0.728626    
#> 473: 0.497891    0.942321    3.447161    0.253873    0.133723    0.003657    0.728618    
#> 474: 0.497867    0.942256    3.447179    0.253792    0.133702    0.003660    0.728645    
#> 475: 0.498021    0.942260    3.447210    0.253776    0.133740    0.003662    0.728580    
#> 476: 0.498236    0.942174    3.447231    0.253854    0.133665    0.003661    0.728650    
#> 477: 0.498305    0.942170    3.447256    0.253755    0.133630    0.003662    0.728609    
#> 478: 0.498299    0.942108    3.447292    0.253513    0.133534    0.003663    0.728569    
#> 479: 0.498389    0.942142    3.447324    0.253510    0.133516    0.003663    0.728546    
#> 480: 0.498386    0.942089    3.447352    0.253532    0.133634    0.003663    0.728524    
#> 481: 0.498411    0.942028    3.447366    0.253459    0.133672    0.003661    0.728515    
#> 482: 0.498512    0.942019    3.447369    0.253410    0.133708    0.003657    0.728581    
#> 483: 0.498509    0.941950    3.447369    0.253398    0.133721    0.003655    0.728590    
#> 484: 0.498494    0.941853    3.447366    0.253330    0.133786    0.003654    0.728639    
#> 485: 0.498509    0.941772    3.447379    0.253289    0.133789    0.003650    0.728631    
#> 486: 0.498509    0.941715    3.447384    0.253280    0.133797    0.003644    0.728608    
#> 487: 0.498662    0.941680    3.447411    0.253293    0.133750    0.003641    0.728607    
#> 488: 0.498673    0.941708    3.447430    0.253280    0.133790    0.003638    0.728604    
#> 489: 0.498843    0.941712    3.447449    0.253372    0.133796    0.003638    0.728562    
#> 490: 0.498923    0.941651    3.447469    0.253447    0.133784    0.003636    0.728553    
#> 491: 0.498919    0.941674    3.447494    0.253365    0.133775    0.003636    0.728515    
#> 492: 0.498823    0.941672    3.447506    0.253179    0.133803    0.003640    0.728629    
#> 493: 0.498807    0.941664    3.447538    0.253199    0.133759    0.003642    0.728739    
#> 494: 0.498893    0.941739    3.447537    0.253070    0.133838    0.003640    0.728720    
#> 495: 0.498913    0.941769    3.447551    0.253127    0.133836    0.003644    0.728677    
#> 496: 0.498952    0.941855    3.447524    0.253021    0.133766    0.003647    0.728625    
#> 497: 0.498874    0.941895    3.447523    0.252855    0.133790    0.003650    0.728663    
#> 498: 0.498875    0.941901    3.447509    0.252766    0.133734    0.003651    0.728597    
#> 499: 0.498806    0.941936    3.447479    0.252657    0.133690    0.003649    0.728566    
#> 500: 0.498785    0.941858    3.447476    0.252548    0.133663    0.003646    0.728529    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.314575    0.961008    3.441263    0.392401    0.083315    0.016800    1.729610    
#> 002: 0.396364    0.908341    3.442256    0.372781    0.079149    0.015960    1.022525    
#> 003: 0.470422    0.840281    3.460613    0.354142    0.075778    0.015162    0.807553    
#> 004: 0.435691    0.832827    3.453707    0.336435    0.098648    0.014404    0.709794    
#> 005: 0.439660    0.846337    3.449084    0.319613    0.107759    0.013684    0.684384    
#> 006: 0.402992    0.831128    3.445994    0.303633    0.112132    0.013000    0.651335    
#> 007: 0.377499    0.842122    3.438819    0.288451    0.117272    0.012350    0.664108    
#> 008: 0.369550    0.844820    3.431386    0.274029    0.117559    0.011732    0.650187    
#> 009: 0.364594    0.848132    3.426849    0.260327    0.131945    0.011146    0.654858    
#> 010: 0.337805    0.852955    3.415864    0.247311    0.125348    0.010588    0.680724    
#> 011: 0.409369    0.866150    3.424939    0.234945    0.119081    0.011199    0.684889    
#> 012: 0.388516    0.849401    3.419408    0.223198    0.124948    0.010639    0.674765    
#> 013: 0.322381    0.864380    3.415898    0.212038    0.135337    0.010107    0.674434    
#> 014: 0.379874    0.856658    3.420590    0.201436    0.128570    0.009858    0.697912    
#> 015: 0.403203    0.842006    3.439816    0.191364    0.122142    0.011529    0.658418    
#> 016: 0.398943    0.862500    3.444128    0.181796    0.116035    0.013031    0.666384    
#> 017: 0.390189    0.855690    3.438933    0.172706    0.123976    0.012379    0.658540    
#> 018: 0.382571    0.869975    3.426070    0.164071    0.139740    0.011760    0.670481    
#> 019: 0.349002    0.867208    3.422381    0.160730    0.132753    0.011172    0.665014    
#> 020: 0.374385    0.858371    3.428473    0.152693    0.126115    0.010731    0.671955    
#> 021: 0.383148    0.854214    3.436271    0.145059    0.119809    0.010738    0.658987    
#> 022: 0.393818    0.874231    3.434106    0.143007    0.113819    0.010201    0.661783    
#> 023: 0.447487    0.853371    3.441107    0.148390    0.127055    0.009691    0.687816    
#> 024: 0.460402    0.865526    3.450608    0.140971    0.130375    0.009207    0.683856    
#> 025: 0.426261    0.821843    3.442368    0.133922    0.167002    0.008746    0.680363    
#> 026: 0.395181    0.865018    3.427693    0.127226    0.158652    0.010144    0.694642    
#> 027: 0.367248    0.887166    3.427284    0.120865    0.150720    0.010504    0.692720    
#> 028: 0.403983    0.863930    3.441525    0.114822    0.143184    0.010838    0.676252    
#> 029: 0.407696    0.859746    3.428497    0.153056    0.136024    0.011611    0.666892    
#> 030: 0.412648    0.859561    3.430772    0.145403    0.141131    0.011778    0.668706    
#> 031: 0.397948    0.835986    3.440532    0.158790    0.134074    0.011189    0.668783    
#> 032: 0.379734    0.822091    3.437201    0.167078    0.127371    0.010956    0.656865    
#> 033: 0.372710    0.837174    3.433508    0.158724    0.133739    0.013038    0.683043    
#> 034: 0.397786    0.864665    3.436094    0.150788    0.127052    0.013825    0.675346    
#> 035: 0.393751    0.830110    3.432979    0.157582    0.126527    0.014517    0.665428    
#> 036: 0.400588    0.839249    3.433806    0.172016    0.120201    0.014612    0.664731    
#> 037: 0.388708    0.864054    3.430994    0.163416    0.114191    0.013881    0.666731    
#> 038: 0.414014    0.871324    3.429550    0.167171    0.123934    0.013187    0.691240    
#> 039: 0.417235    0.862414    3.434067    0.162610    0.118869    0.012528    0.656986    
#> 040: 0.381760    0.865768    3.436238    0.154479    0.112925    0.012425    0.678842    
#> 041: 0.384369    0.853461    3.440336    0.154384    0.124992    0.013206    0.670225    
#> 042: 0.404645    0.831923    3.438434    0.146665    0.143627    0.012545    0.671324    
#> 043: 0.380893    0.864800    3.423070    0.139332    0.136446    0.011918    0.661334    
#> 044: 0.364197    0.876986    3.420075    0.132365    0.129623    0.011322    0.675254    
#> 045: 0.365857    0.909956    3.411833    0.125747    0.123142    0.010756    0.682736    
#> 046: 0.370662    0.878899    3.417003    0.119459    0.116985    0.010218    0.681747    
#> 047: 0.388607    0.887183    3.416839    0.131650    0.115197    0.012233    0.671909    
#> 048: 0.365611    0.878188    3.422117    0.151744    0.109850    0.012641    0.660478    
#> 049: 0.359877    0.886791    3.426530    0.144157    0.128007    0.012009    0.671955    
#> 050: 0.411539    0.837961    3.439207    0.136949    0.124956    0.011409    0.715427    
#> 051: 0.386448    0.863017    3.431058    0.130102    0.118709    0.010838    0.706477    
#> 052: 0.385784    0.889861    3.428825    0.148251    0.117506    0.010296    0.668137    
#> 053: 0.383131    0.881424    3.423724    0.140839    0.140255    0.009781    0.679534    
#> 054: 0.346735    0.863441    3.422333    0.141409    0.133243    0.010486    0.672736    
#> 055: 0.359932    0.867231    3.423115    0.140549    0.138366    0.012268    0.677649    
#> 056: 0.372513    0.853340    3.430624    0.136870    0.133053    0.011654    0.691101    
#> 057: 0.399846    0.848835    3.443334    0.158702    0.126400    0.011522    0.691649    
#> 058: 0.391080    0.863618    3.427552    0.150767    0.128789    0.010946    0.690651    
#> 059: 0.382971    0.827382    3.435179    0.143229    0.122349    0.015069    0.685575    
#> 060: 0.392357    0.841916    3.436959    0.143933    0.116232    0.014315    0.681869    
#> 061: 0.406862    0.851863    3.441616    0.169361    0.137874    0.013926    0.676859    
#> 062: 0.390750    0.870700    3.439055    0.170242    0.132353    0.014919    0.683616    
#> 063: 0.422862    0.818549    3.446657    0.187401    0.129406    0.014173    0.676798    
#> 064: 0.403191    0.841823    3.443297    0.178031    0.127910    0.013465    0.682355    
#> 065: 0.417621    0.851266    3.428615    0.169129    0.123125    0.012791    0.684443    
#> 066: 0.404111    0.857423    3.431165    0.179309    0.131373    0.012152    0.667016    
#> 067: 0.361449    0.850145    3.415360    0.170343    0.132155    0.011544    0.667066    
#> 068: 0.349798    0.876506    3.422284    0.161826    0.141492    0.010967    0.683573    
#> 069: 0.365810    0.861463    3.420824    0.153735    0.134417    0.010821    0.695068    
#> 070: 0.384870    0.840360    3.441263    0.146048    0.127696    0.011968    0.673750    
#> 071: 0.365774    0.843375    3.423780    0.139157    0.121311    0.011370    0.670935    
#> 072: 0.337527    0.860295    3.410984    0.138606    0.120600    0.010801    0.661328    
#> 073: 0.358423    0.885093    3.424324    0.149889    0.137360    0.010261    0.660645    
#> 074: 0.339077    0.851816    3.425402    0.171134    0.153515    0.009748    0.668347    
#> 075: 0.348326    0.839179    3.432161    0.162577    0.152700    0.009261    0.674696    
#> 076: 0.385097    0.848975    3.441273    0.155478    0.145065    0.009645    0.676522    
#> 077: 0.420540    0.847476    3.432431    0.147704    0.137812    0.011226    0.666421    
#> 078: 0.404643    0.849646    3.439512    0.140319    0.130921    0.010665    0.658391    
#> 079: 0.400583    0.868207    3.440867    0.133303    0.126468    0.012123    0.685330    
#> 080: 0.413628    0.855638    3.442879    0.146411    0.122346    0.014359    0.689499    
#> 081: 0.397416    0.855640    3.436994    0.155206    0.116229    0.015286    0.674684    
#> 082: 0.419124    0.849696    3.448384    0.147446    0.119953    0.014522    0.687635    
#> 083: 0.415958    0.882173    3.447589    0.140074    0.113956    0.013796    0.678382    
#> 084: 0.411864    0.852100    3.443533    0.133070    0.113285    0.014118    0.672146    
#> 085: 0.418240    0.859509    3.454758    0.148008    0.107620    0.014821    0.687664    
#> 086: 0.407080    0.865330    3.444386    0.145906    0.102239    0.014080    0.662552    
#> 087: 0.384136    0.833743    3.436516    0.146847    0.097127    0.013585    0.671228    
#> 088: 0.333908    0.841721    3.424466    0.151658    0.116824    0.012906    0.684912    
#> 089: 0.340636    0.879484    3.412036    0.153211    0.144453    0.012261    0.676097    
#> 090: 0.346478    0.853942    3.420576    0.145550    0.137230    0.011648    0.669216    
#> 091: 0.358463    0.855795    3.411458    0.152759    0.130368    0.011065    0.676340    
#> 092: 0.373999    0.873457    3.413736    0.155666    0.123850    0.012100    0.696959    
#> 093: 0.319091    0.852584    3.413261    0.154155    0.138949    0.011966    0.689348    
#> 094: 0.316525    0.882925    3.408013    0.156415    0.157264    0.011367    0.679653    
#> 095: 0.327574    0.869237    3.412410    0.148594    0.149401    0.010799    0.690492    
#> 096: 0.323636    0.874800    3.411541    0.141165    0.141931    0.010259    0.692250    
#> 097: 0.348850    0.873045    3.416184    0.143844    0.134834    0.009746    0.663442    
#> 098: 0.360932    0.904938    3.416990    0.152954    0.129506    0.009259    0.694508    
#> 099: 0.343608    0.865202    3.407411    0.147824    0.129741    0.008796    0.689855    
#> 100: 0.328081    0.862658    3.412497    0.144336    0.145470    0.008356    0.702232    
#> 101: 0.314061    0.848147    3.401427    0.146710    0.138197    0.007938    0.685269    
#> 102: 0.325028    0.872262    3.398098    0.140486    0.131287    0.007541    0.696367    
#> 103: 0.360594    0.863584    3.406368    0.173775    0.146791    0.007164    0.677015    
#> 104: 0.359028    0.867505    3.415146    0.187749    0.147623    0.006806    0.674186    
#> 105: 0.391033    0.881538    3.412954    0.202065    0.147132    0.006466    0.679202    
#> 106: 0.377455    0.840309    3.420204    0.191962    0.139775    0.006142    0.674637    
#> 107: 0.393653    0.860552    3.423332    0.182364    0.154643    0.005835    0.696514    
#> 108: 0.361148    0.858019    3.412322    0.173246    0.146911    0.005544    0.704046    
#> 109: 0.337919    0.880842    3.414375    0.164583    0.139565    0.005266    0.688547    
#> 110: 0.345940    0.862739    3.405328    0.156354    0.144104    0.005330    0.681118    
#> 111: 0.349446    0.860166    3.411653    0.152821    0.136899    0.005064    0.690524    
#> 112: 0.357998    0.832063    3.413918    0.191803    0.130850    0.004810    0.690089    
#> 113: 0.378643    0.884507    3.414305    0.184836    0.124307    0.004570    0.675377    
#> 114: 0.376727    0.882932    3.413918    0.175594    0.124056    0.004341    0.683936    
#> 115: 0.387340    0.869193    3.415440    0.166815    0.149544    0.004665    0.682553    
#> 116: 0.382786    0.855477    3.422545    0.158474    0.144172    0.006207    0.689889    
#> 117: 0.335197    0.892662    3.415780    0.159933    0.140406    0.005897    0.690886    
#> 118: 0.360458    0.881079    3.411147    0.173565    0.133386    0.005602    0.692486    
#> 119: 0.353069    0.903369    3.407520    0.164887    0.126717    0.005322    0.698912    
#> 120: 0.318943    0.872915    3.405068    0.156642    0.124253    0.005076    0.704843    
#> 121: 0.345375    0.901341    3.403963    0.148810    0.122368    0.005896    0.703054    
#> 122: 0.363208    0.857068    3.416461    0.166164    0.130691    0.005601    0.684522    
#> 123: 0.385709    0.875083    3.418296    0.157856    0.138259    0.005321    0.690049    
#> 124: 0.386055    0.904482    3.408829    0.149963    0.131346    0.005055    0.705479    
#> 125: 0.354099    0.903828    3.403471    0.142465    0.150644    0.004802    0.692105    
#> 126: 0.331474    0.916682    3.390878    0.135342    0.143112    0.005208    0.692456    
#> 127: 0.336744    0.882623    3.394404    0.128575    0.135956    0.005542    0.701607    
#> 128: 0.336056    0.893584    3.409441    0.127384    0.129158    0.005265    0.705264    
#> 129: 0.351443    0.879192    3.405111    0.163691    0.122700    0.005113    0.679333    
#> 130: 0.370614    0.875942    3.414809    0.155506    0.116565    0.005178    0.675213    
#> 131: 0.368375    0.856319    3.415877    0.154665    0.122279    0.004919    0.707790    
#> 132: 0.330816    0.864440    3.405061    0.146932    0.156793    0.005193    0.694305    
#> 133: 0.357766    0.856855    3.410399    0.144646    0.165222    0.005382    0.703743    
#> 134: 0.390967    0.859607    3.423330    0.148344    0.156960    0.006816    0.665728    
#> 135: 0.368204    0.848056    3.429008    0.141177    0.149112    0.006475    0.678148    
#> 136: 0.372726    0.833801    3.423420    0.137675    0.141657    0.006151    0.676118    
#> 137: 0.412336    0.845630    3.434801    0.130792    0.141140    0.006754    0.667410    
#> 138: 0.395485    0.853255    3.430330    0.135750    0.134083    0.007993    0.672610    
#> 139: 0.410972    0.845440    3.438369    0.135049    0.127379    0.008914    0.667704    
#> 140: 0.419124    0.864979    3.446285    0.139366    0.121010    0.010412    0.692394    
#> 141: 0.411453    0.841704    3.450863    0.132397    0.118251    0.011543    0.686861    
#> 142: 0.423574    0.823030    3.451397    0.125778    0.112338    0.010966    0.692225    
#> 143: 0.401604    0.851113    3.445451    0.119489    0.127277    0.010417    0.680982    
#> 144: 0.433965    0.857616    3.446531    0.132751    0.123489    0.009897    0.657097    
#> 145: 0.399835    0.874659    3.433066    0.126114    0.117314    0.009402    0.663236    
#> 146: 0.368804    0.872336    3.441991    0.119808    0.126551    0.009673    0.678319    
#> 147: 0.356391    0.857832    3.429761    0.151038    0.124550    0.011352    0.663254    
#> 148: 0.379692    0.859115    3.434622    0.143486    0.118322    0.010785    0.664961    
#> 149: 0.388907    0.813696    3.444475    0.141800    0.134530    0.012337    0.672834    
#> 150: 0.409218    0.831336    3.437617    0.151672    0.127803    0.011720    0.667113    
#> 151: 0.345088    0.879193    3.426054    0.166635    0.121413    0.011134    0.678801    
#> 152: 0.362546    0.875413    3.431682    0.179027    0.102389    0.009005    0.668132    
#> 153: 0.376302    0.839219    3.435312    0.154298    0.102821    0.009511    0.669157    
#> 154: 0.409912    0.838653    3.445067    0.175656    0.110982    0.012568    0.666422    
#> 155: 0.407566    0.837909    3.445152    0.160318    0.115870    0.012218    0.674062    
#> 156: 0.395419    0.830834    3.446381    0.171593    0.132802    0.011887    0.698177    
#> 157: 0.433217    0.840568    3.450656    0.182057    0.140225    0.012956    0.674074    
#> 158: 0.433856    0.857493    3.448359    0.188898    0.123071    0.012874    0.676289    
#> 159: 0.410696    0.875289    3.443565    0.156130    0.121255    0.013271    0.684116    
#> 160: 0.424041    0.819650    3.457640    0.173633    0.140657    0.015095    0.676404    
#> 161: 0.408399    0.833270    3.442544    0.158634    0.106401    0.018936    0.661293    
#> 162: 0.396327    0.865465    3.426271    0.170952    0.095564    0.021080    0.659396    
#> 163: 0.437235    0.859012    3.432770    0.201162    0.112684    0.021553    0.652856    
#> 164: 0.410145    0.864014    3.431016    0.208856    0.095910    0.020359    0.656494    
#> 165: 0.415861    0.841763    3.439586    0.163321    0.102592    0.023566    0.657110    
#> 166: 0.421821    0.892417    3.435194    0.191621    0.120029    0.023490    0.673908    
#> 167: 0.419951    0.879890    3.443817    0.174264    0.117393    0.017969    0.684517    
#> 168: 0.423044    0.888111    3.433729    0.169416    0.116075    0.010795    0.669092    
#> 169: 0.411709    0.888779    3.421987    0.168354    0.116598    0.013242    0.670629    
#> 170: 0.403179    0.883358    3.426751    0.151241    0.118216    0.011387    0.659029    
#> 171: 0.399462    0.856392    3.427806    0.155041    0.117042    0.010985    0.649138    
#> 172: 0.374841    0.892948    3.424770    0.152165    0.126354    0.011662    0.649544    
#> 173: 0.375591    0.870189    3.421136    0.143422    0.112678    0.008019    0.663491    
#> 174: 0.368880    0.868402    3.424808    0.133424    0.125686    0.007275    0.674245    
#> 175: 0.367914    0.868028    3.424122    0.144237    0.120593    0.007414    0.679388    
#> 176: 0.391487    0.882749    3.434436    0.137340    0.140642    0.006476    0.681811    
#> 177: 0.402928    0.853007    3.442854    0.128420    0.133024    0.005290    0.677434    
#> 178: 0.406000    0.862107    3.439052    0.135556    0.121724    0.006777    0.665115    
#> 179: 0.388910    0.897880    3.426291    0.108628    0.103291    0.008547    0.695606    
#> 180: 0.368048    0.902647    3.418694    0.116754    0.111670    0.007660    0.682640    
#> 181: 0.373945    0.888951    3.407681    0.105271    0.093823    0.006591    0.688559    
#> 182: 0.328138    0.908171    3.399283    0.091776    0.116446    0.005916    0.709409    
#> 183: 0.331990    0.910833    3.399666    0.100466    0.118665    0.005831    0.710636    
#> 184: 0.320739    0.899941    3.406349    0.131856    0.125958    0.006550    0.702514    
#> 185: 0.316234    0.900598    3.401831    0.149297    0.116451    0.006089    0.702390    
#> 186: 0.373642    0.907727    3.412163    0.152082    0.131731    0.006852    0.697795    
#> 187: 0.364935    0.882710    3.420760    0.185952    0.135807    0.006667    0.675376    
#> 188: 0.317046    0.884032    3.411590    0.159720    0.142773    0.005391    0.679522    
#> 189: 0.353418    0.896389    3.409491    0.144512    0.129277    0.005206    0.687739    
#> 190: 0.330931    0.893700    3.410835    0.127785    0.122767    0.005829    0.686513    
#> 191: 0.334535    0.889923    3.405468    0.142204    0.124475    0.005659    0.681128    
#> 192: 0.341658    0.892623    3.410521    0.170708    0.133470    0.006219    0.661770    
#> 193: 0.368877    0.886142    3.414010    0.174265    0.130176    0.005444    0.670722    
#> 194: 0.343062    0.890235    3.405980    0.183751    0.142147    0.005861    0.666384    
#> 195: 0.328644    0.876550    3.393855    0.188793    0.121306    0.006103    0.672777    
#> 196: 0.341948    0.871717    3.408128    0.190967    0.131025    0.006212    0.676796    
#> 197: 0.323201    0.875115    3.424081    0.169909    0.143921    0.005477    0.695287    
#> 198: 0.368522    0.860891    3.405872    0.165840    0.140446    0.005762    0.691409    
#> 199: 0.342844    0.871157    3.407647    0.144769    0.158683    0.004715    0.703125    
#> 200: 0.334814    0.882336    3.406436    0.137814    0.160647    0.004295    0.711712    
#> 201: 0.327586    0.879313    3.410804    0.131248    0.160052    0.005021    0.707090    
#> 202: 0.333774    0.880246    3.413997    0.137686    0.153246    0.005004    0.704829    
#> 203: 0.343706    0.880177    3.414387    0.138959    0.146925    0.004933    0.699750    
#> 204: 0.347890    0.876684    3.414262    0.142465    0.149935    0.004934    0.699696    
#> 205: 0.346688    0.882519    3.414445    0.140870    0.149241    0.004850    0.701770    
#> 206: 0.351524    0.884808    3.414366    0.141602    0.151746    0.004860    0.702828    
#> 207: 0.350879    0.881363    3.413563    0.138971    0.152772    0.004800    0.705290    
#> 208: 0.353120    0.879625    3.413659    0.140280    0.149426    0.004818    0.703405    
#> 209: 0.355547    0.877786    3.412907    0.143867    0.146912    0.004803    0.702716    
#> 210: 0.354689    0.874904    3.412883    0.143066    0.146584    0.004794    0.699866    
#> 211: 0.355893    0.873873    3.413514    0.140745    0.145209    0.004779    0.697445    
#> 212: 0.355945    0.874003    3.413779    0.139310    0.145209    0.004804    0.695690    
#> 213: 0.357202    0.872605    3.414240    0.140210    0.145703    0.004959    0.693805    
#> 214: 0.359302    0.871102    3.414847    0.140027    0.145487    0.005078    0.692363    
#> 215: 0.360629    0.869745    3.415957    0.139743    0.145914    0.005288    0.690373    
#> 216: 0.363021    0.866966    3.416572    0.140545    0.145253    0.005428    0.690567    
#> 217: 0.364941    0.866807    3.416922    0.141279    0.144609    0.005486    0.689535    
#> 218: 0.366559    0.866690    3.416896    0.143188    0.145559    0.005574    0.689054    
#> 219: 0.366048    0.866539    3.416395    0.144536    0.145311    0.005633    0.687676    
#> 220: 0.366059    0.866566    3.416678    0.145035    0.144979    0.005672    0.687004    
#> 221: 0.365691    0.866970    3.416606    0.145144    0.144388    0.005735    0.685882    
#> 222: 0.365582    0.867221    3.416844    0.145785    0.144443    0.005808    0.685162    
#> 223: 0.366900    0.866197    3.417277    0.146825    0.144251    0.005877    0.684327    
#> 224: 0.368665    0.866257    3.417885    0.148487    0.143753    0.005910    0.683939    
#> 225: 0.368847    0.864945    3.418333    0.149023    0.143023    0.005985    0.684045    
#> 226: 0.369298    0.864517    3.418342    0.150117    0.142825    0.005965    0.684003    
#> 227: 0.368219    0.864537    3.418294    0.150543    0.142389    0.005970    0.684053    
#> 228: 0.367661    0.865864    3.417777    0.151833    0.142227    0.006053    0.683892    
#> 229: 0.366153    0.866460    3.417215    0.152883    0.142085    0.006022    0.683158    
#> 230: 0.365417    0.866495    3.416860    0.153559    0.141662    0.005991    0.682747    
#> 231: 0.364676    0.866724    3.416653    0.154064    0.140954    0.005960    0.682454    
#> 232: 0.363303    0.867003    3.416568    0.155188    0.139993    0.005995    0.681963    
#> 233: 0.362380    0.866303    3.416445    0.156192    0.139750    0.006061    0.681740    
#> 234: 0.361309    0.866510    3.416302    0.156282    0.140191    0.006072    0.681608    
#> 235: 0.361230    0.866556    3.416074    0.156026    0.139722    0.006065    0.681540    
#> 236: 0.360525    0.866697    3.415894    0.155721    0.139501    0.006097    0.681506    
#> 237: 0.360534    0.867095    3.415737    0.155354    0.139486    0.006153    0.681534    
#> 238: 0.360726    0.867117    3.415639    0.155089    0.139622    0.006168    0.681501    
#> 239: 0.360917    0.867387    3.415684    0.154745    0.139825    0.006189    0.681565    
#> 240: 0.361005    0.867056    3.415754    0.154019    0.139788    0.006172    0.681381    
#> 241: 0.361227    0.866495    3.415927    0.153774    0.139517    0.006186    0.681336    
#> 242: 0.361050    0.866143    3.415827    0.153867    0.140086    0.006233    0.681329    
#> 243: 0.360383    0.866645    3.415719    0.154264    0.140669    0.006257    0.681543    
#> 244: 0.359672    0.866444    3.415678    0.155350    0.140439    0.006318    0.681637    
#> 245: 0.359117    0.866028    3.415537    0.155782    0.140202    0.006351    0.681823    
#> 246: 0.358967    0.866095    3.415535    0.156554    0.139911    0.006388    0.681746    
#> 247: 0.358677    0.866157    3.415586    0.156918    0.139467    0.006412    0.681590    
#> 248: 0.358414    0.866560    3.415517    0.157382    0.139372    0.006397    0.681132    
#> 249: 0.358289    0.866962    3.415426    0.157178    0.139013    0.006376    0.681223    
#> 250: 0.358475    0.867592    3.415471    0.157597    0.138756    0.006367    0.681187    
#> 251: 0.359044    0.867962    3.415635    0.158149    0.138784    0.006369    0.681321    
#> 252: 0.359234    0.867926    3.415896    0.158337    0.138690    0.006346    0.681049    
#> 253: 0.359479    0.867850    3.416031    0.158629    0.138374    0.006349    0.680810    
#> 254: 0.359794    0.867996    3.416211    0.158903    0.138183    0.006343    0.680405    
#> 255: 0.360069    0.868459    3.416320    0.159627    0.137959    0.006365    0.680243    
#> 256: 0.360030    0.868450    3.416231    0.160114    0.137673    0.006359    0.680183    
#> 257: 0.359562    0.868574    3.416098    0.160377    0.137153    0.006369    0.679986    
#> 258: 0.358944    0.868784    3.415962    0.160597    0.137219    0.006341    0.679635    
#> 259: 0.358559    0.868898    3.415796    0.160651    0.136879    0.006344    0.679497    
#> 260: 0.358560    0.869092    3.415841    0.161040    0.136780    0.006333    0.679219    
#> 261: 0.358722    0.868999    3.415935    0.161679    0.136822    0.006328    0.679185    
#> 262: 0.358830    0.869006    3.416071    0.161680    0.136696    0.006331    0.679264    
#> 263: 0.359165    0.869024    3.416144    0.161425    0.136890    0.006338    0.679500    
#> 264: 0.359058    0.868907    3.416026    0.161515    0.137063    0.006323    0.680110    
#> 265: 0.359046    0.868911    3.416066    0.162000    0.137415    0.006310    0.679977    
#> 266: 0.358829    0.869185    3.415868    0.161971    0.137325    0.006272    0.680277    
#> 267: 0.358909    0.869461    3.415882    0.161581    0.137482    0.006241    0.680215    
#> 268: 0.359168    0.869555    3.415847    0.161394    0.137435    0.006219    0.680218    
#> 269: 0.359825    0.869786    3.415875    0.161464    0.137274    0.006189    0.680661    
#> 270: 0.360411    0.870195    3.415841    0.161247    0.137123    0.006177    0.680736    
#> 271: 0.360410    0.870241    3.415805    0.161098    0.137053    0.006153    0.681086    
#> 272: 0.360562    0.869982    3.415759    0.160794    0.136959    0.006135    0.681298    
#> 273: 0.360825    0.870006    3.415733    0.160508    0.137194    0.006117    0.681254    
#> 274: 0.360723    0.870036    3.415805    0.160370    0.137151    0.006102    0.681361    
#> 275: 0.360463    0.870280    3.415620    0.160204    0.137032    0.006113    0.681617    
#> 276: 0.359966    0.870710    3.415639    0.160270    0.137217    0.006109    0.681750    
#> 277: 0.359667    0.871089    3.415731    0.160294    0.137171    0.006117    0.681601    
#> 278: 0.359376    0.871113    3.415794    0.160020    0.137080    0.006123    0.681603    
#> 279: 0.359391    0.871114    3.415866    0.159925    0.136856    0.006134    0.681585    
#> 280: 0.359236    0.871249    3.415995    0.159557    0.136591    0.006154    0.681590    
#> 281: 0.359054    0.871331    3.416103    0.159708    0.136215    0.006154    0.681777    
#> 282: 0.359249    0.871436    3.416237    0.159747    0.135983    0.006188    0.681773    
#> 283: 0.359623    0.871495    3.416441    0.159908    0.135902    0.006243    0.681807    
#> 284: 0.359574    0.871621    3.416433    0.159740    0.135503    0.006295    0.681645    
#> 285: 0.359593    0.871795    3.416290    0.159835    0.135316    0.006328    0.681573    
#> 286: 0.359414    0.871881    3.416187    0.159761    0.135071    0.006357    0.681312    
#> 287: 0.359193    0.872077    3.416039    0.159751    0.134782    0.006380    0.681248    
#> 288: 0.359507    0.872321    3.415976    0.159586    0.134688    0.006373    0.681411    
#> 289: 0.359684    0.872409    3.415975    0.159274    0.134567    0.006380    0.681433    
#> 290: 0.360066    0.872302    3.416075    0.159194    0.134821    0.006389    0.681543    
#> 291: 0.360242    0.872493    3.416223    0.159194    0.134919    0.006392    0.681397    
#> 292: 0.360320    0.872414    3.416259    0.159255    0.134880    0.006395    0.681327    
#> 293: 0.360280    0.872526    3.416207    0.159523    0.134829    0.006404    0.681166    
#> 294: 0.360124    0.872617    3.416180    0.159626    0.134644    0.006414    0.681117    
#> 295: 0.360074    0.872344    3.416159    0.159800    0.134558    0.006427    0.681008    
#> 296: 0.359985    0.872301    3.416149    0.159674    0.134312    0.006450    0.681016    
#> 297: 0.360221    0.872446    3.416121    0.159731    0.134075    0.006472    0.680984    
#> 298: 0.360262    0.872423    3.416169    0.159899    0.133976    0.006492    0.680897    
#> 299: 0.360453    0.872485    3.416172    0.159822    0.133755    0.006513    0.680788    
#> 300: 0.360673    0.872320    3.416270    0.159691    0.133470    0.006521    0.680670    
#> 301: 0.360934    0.872194    3.416331    0.159659    0.133341    0.006529    0.680570    
#> 302: 0.361151    0.872149    3.416345    0.159820    0.133299    0.006519    0.680367    
#> 303: 0.361142    0.872187    3.416322    0.159667    0.133240    0.006519    0.680156    
#> 304: 0.361279    0.872341    3.416317    0.159764    0.133159    0.006534    0.680248    
#> 305: 0.361560    0.872024    3.416381    0.159835    0.133087    0.006562    0.680118    
#> 306: 0.361240    0.871913    3.416289    0.159776    0.133164    0.006559    0.680145    
#> 307: 0.361041    0.871971    3.416168    0.159591    0.133192    0.006554    0.680214    
#> 308: 0.360691    0.872048    3.416048    0.159690    0.133239    0.006571    0.680167    
#> 309: 0.360604    0.871938    3.415918    0.159703    0.133185    0.006579    0.680298    
#> 310: 0.360507    0.871996    3.415745    0.159635    0.133041    0.006598    0.680347    
#> 311: 0.360434    0.871959    3.415742    0.159859    0.133041    0.006628    0.680323    
#> 312: 0.360291    0.871866    3.415637    0.160159    0.133001    0.006631    0.680315    
#> 313: 0.360123    0.871693    3.415582    0.160439    0.132900    0.006658    0.680351    
#> 314: 0.359707    0.871967    3.415494    0.160462    0.132886    0.006662    0.680403    
#> 315: 0.359187    0.872369    3.415412    0.160646    0.132758    0.006678    0.680407    
#> 316: 0.359015    0.872575    3.415358    0.160492    0.132840    0.006683    0.680365    
#> 317: 0.358905    0.872688    3.415383    0.160518    0.132891    0.006678    0.680406    
#> 318: 0.358962    0.872764    3.415330    0.160416    0.132956    0.006674    0.680268    
#> 319: 0.358889    0.872655    3.415278    0.160292    0.133059    0.006672    0.680205    
#> 320: 0.358714    0.872516    3.415160    0.160353    0.133064    0.006664    0.680360    
#> 321: 0.358423    0.872711    3.415061    0.160290    0.132973    0.006658    0.680366    
#> 322: 0.358476    0.872722    3.414931    0.160392    0.133011    0.006658    0.680254    
#> 323: 0.357925    0.872790    3.414793    0.160457    0.132930    0.006666    0.680205    
#> 324: 0.357772    0.872859    3.414755    0.160468    0.132914    0.006665    0.680073    
#> 325: 0.357723    0.873102    3.414673    0.160281    0.132915    0.006651    0.680047    
#> 326: 0.357614    0.873056    3.414551    0.160019    0.133040    0.006637    0.679997    
#> 327: 0.357522    0.873019    3.414488    0.160027    0.133050    0.006633    0.679969    
#> 328: 0.357550    0.873005    3.414476    0.160088    0.133021    0.006634    0.679848    
#> 329: 0.357687    0.872930    3.414522    0.160329    0.133032    0.006630    0.679856    
#> 330: 0.357469    0.872975    3.414548    0.160311    0.132919    0.006625    0.679969    
#> 331: 0.357418    0.872854    3.414533    0.160108    0.132843    0.006619    0.679975    
#> 332: 0.357361    0.872875    3.414573    0.159837    0.132912    0.006626    0.679994    
#> 333: 0.357040    0.872908    3.414578    0.159671    0.132919    0.006656    0.679888    
#> 334: 0.356776    0.872779    3.414500    0.159689    0.132867    0.006667    0.679872    
#> 335: 0.356653    0.872935    3.414403    0.159446    0.132870    0.006669    0.679894    
#> 336: 0.356448    0.873250    3.414331    0.159234    0.132879    0.006685    0.679957    
#> 337: 0.356386    0.873507    3.414261    0.159145    0.132761    0.006687    0.679969    
#> 338: 0.356414    0.873537    3.414321    0.159178    0.132597    0.006697    0.680039    
#> 339: 0.356412    0.873580    3.414357    0.159105    0.132568    0.006717    0.680042    
#> 340: 0.356398    0.873349    3.414408    0.159033    0.132572    0.006738    0.679940    
#> 341: 0.356473    0.873219    3.414517    0.159086    0.132510    0.006759    0.679959    
#> 342: 0.356346    0.872902    3.414603    0.159052    0.132603    0.006775    0.679972    
#> 343: 0.356092    0.872857    3.414696    0.159153    0.132525    0.006771    0.680062    
#> 344: 0.356150    0.872986    3.414728    0.159145    0.132565    0.006778    0.680161    
#> 345: 0.356159    0.872871    3.414741    0.159216    0.132484    0.006777    0.680125    
#> 346: 0.356071    0.872824    3.414653    0.159253    0.132352    0.006771    0.680085    
#> 347: 0.356057    0.872810    3.414548    0.159156    0.132330    0.006771    0.680200    
#> 348: 0.355902    0.872880    3.414443    0.159003    0.132230    0.006768    0.680263    
#> 349: 0.355799    0.872921    3.414353    0.158949    0.132148    0.006766    0.680353    
#> 350: 0.355600    0.872964    3.414244    0.158909    0.132184    0.006755    0.680415    
#> 351: 0.355408    0.873159    3.414097    0.158752    0.132269    0.006745    0.680460    
#> 352: 0.355007    0.873371    3.414047    0.158823    0.132359    0.006746    0.680513    
#> 353: 0.354986    0.873637    3.413929    0.158967    0.132302    0.006744    0.680509    
#> 354: 0.354932    0.873785    3.413779    0.159066    0.132208    0.006763    0.680430    
#> 355: 0.355037    0.873645    3.413800    0.159299    0.132136    0.006782    0.680371    
#> 356: 0.355170    0.873552    3.413889    0.159227    0.132206    0.006783    0.680501    
#> 357: 0.355275    0.873595    3.413903    0.159285    0.132242    0.006778    0.680395    
#> 358: 0.355392    0.873674    3.413944    0.159201    0.132147    0.006789    0.680256    
#> 359: 0.355290    0.873817    3.413909    0.159162    0.132141    0.006797    0.680188    
#> 360: 0.355131    0.873892    3.413785    0.159282    0.132159    0.006796    0.680116    
#> 361: 0.354929    0.873963    3.413709    0.159313    0.132025    0.006791    0.680026    
#> 362: 0.354949    0.873929    3.413736    0.159447    0.131946    0.006787    0.679809    
#> 363: 0.354948    0.873774    3.413710    0.159367    0.131980    0.006790    0.679700    
#> 364: 0.354939    0.873801    3.413674    0.159463    0.131988    0.006798    0.679711    
#> 365: 0.354943    0.873737    3.413707    0.159524    0.132064    0.006805    0.679750    
#> 366: 0.354977    0.873715    3.413701    0.159657    0.131993    0.006812    0.679744    
#> 367: 0.355178    0.873767    3.413718    0.159761    0.132096    0.006812    0.679743    
#> 368: 0.355448    0.873803    3.413731    0.159660    0.132012    0.006814    0.679675    
#> 369: 0.355592    0.873825    3.413747    0.159503    0.131961    0.006830    0.679669    
#> 370: 0.355612    0.873988    3.413749    0.159403    0.131890    0.006843    0.679681    
#> 371: 0.355560    0.874061    3.413689    0.159351    0.131858    0.006842    0.679652    
#> 372: 0.355574    0.874031    3.413679    0.159322    0.131989    0.006837    0.679708    
#> 373: 0.355517    0.874153    3.413671    0.159470    0.131987    0.006834    0.679801    
#> 374: 0.355448    0.874260    3.413594    0.159391    0.131931    0.006823    0.679786    
#> 375: 0.355249    0.874341    3.413512    0.159408    0.131967    0.006811    0.679716    
#> 376: 0.355130    0.874438    3.413461    0.159469    0.132078    0.006805    0.679700    
#> 377: 0.354847    0.874625    3.413416    0.159464    0.132162    0.006792    0.679779    
#> 378: 0.354599    0.874683    3.413336    0.159540    0.132202    0.006797    0.679955    
#> 379: 0.354421    0.874597    3.413296    0.159565    0.132173    0.006806    0.679935    
#> 380: 0.354144    0.874556    3.413247    0.159493    0.132177    0.006814    0.679933    
#> 381: 0.354042    0.874559    3.413213    0.159476    0.132240    0.006808    0.679860    
#> 382: 0.354038    0.874579    3.413195    0.159469    0.132184    0.006804    0.679778    
#> 383: 0.354223    0.874554    3.413235    0.159410    0.132238    0.006796    0.679772    
#> 384: 0.354227    0.874403    3.413294    0.159431    0.132333    0.006790    0.679788    
#> 385: 0.354353    0.874271    3.413369    0.159333    0.132291    0.006792    0.679853    
#> 386: 0.354522    0.874343    3.413442    0.159123    0.132214    0.006792    0.679947    
#> 387: 0.354785    0.874298    3.413572    0.159038    0.132160    0.006796    0.679907    
#> 388: 0.354857    0.874224    3.413671    0.158919    0.132130    0.006799    0.679919    
#> 389: 0.354993    0.873976    3.413715    0.158805    0.132098    0.006791    0.680023    
#> 390: 0.355004    0.873865    3.413753    0.158827    0.131988    0.006787    0.680016    
#> 391: 0.355168    0.873730    3.413809    0.158901    0.131958    0.006785    0.679977    
#> 392: 0.355308    0.873679    3.413881    0.159013    0.131984    0.006783    0.680031    
#> 393: 0.355246    0.873617    3.413885    0.159051    0.131991    0.006783    0.680019    
#> 394: 0.355338    0.873591    3.413896    0.159149    0.132052    0.006772    0.680082    
#> 395: 0.355596    0.873669    3.413928    0.159285    0.132124    0.006764    0.680118    
#> 396: 0.355728    0.873756    3.413944    0.159228    0.132082    0.006757    0.680066    
#> 397: 0.355796    0.873799    3.413977    0.159017    0.132003    0.006753    0.680133    
#> 398: 0.355945    0.873772    3.414060    0.158815    0.132043    0.006758    0.680195    
#> 399: 0.356208    0.873733    3.414140    0.158689    0.132022    0.006756    0.680236    
#> 400: 0.356365    0.873708    3.414231    0.158522    0.131979    0.006751    0.680238    
#> 401: 0.356525    0.873633    3.414302    0.158364    0.131932    0.006748    0.680311    
#> 402: 0.356637    0.873591    3.414363    0.158273    0.131900    0.006746    0.680339    
#> 403: 0.356953    0.873561    3.414429    0.158267    0.131930    0.006748    0.680271    
#> 404: 0.357166    0.873527    3.414418    0.158188    0.131857    0.006746    0.680250    
#> 405: 0.357211    0.873553    3.414436    0.158089    0.131882    0.006747    0.680301    
#> 406: 0.357227    0.873558    3.414442    0.157957    0.131896    0.006752    0.680327    
#> 407: 0.357268    0.873503    3.414513    0.157777    0.131986    0.006747    0.680396    
#> 408: 0.357337    0.873410    3.414541    0.157681    0.132157    0.006738    0.680397    
#> 409: 0.357273    0.873333    3.414517    0.157528    0.132169    0.006732    0.680417    
#> 410: 0.357330    0.873327    3.414518    0.157448    0.132150    0.006730    0.680415    
#> 411: 0.357438    0.873134    3.414549    0.157441    0.132184    0.006726    0.680438    
#> 412: 0.357457    0.873229    3.414549    0.157440    0.132209    0.006724    0.680452    
#> 413: 0.357426    0.873241    3.414534    0.157437    0.132157    0.006718    0.680544    
#> 414: 0.357340    0.873256    3.414547    0.157565    0.132181    0.006705    0.680520    
#> 415: 0.357395    0.873292    3.414560    0.157729    0.132249    0.006699    0.680430    
#> 416: 0.357508    0.873338    3.414596    0.157715    0.132286    0.006690    0.680349    
#> 417: 0.357521    0.873277    3.414609    0.157765    0.132284    0.006680    0.680286    
#> 418: 0.357473    0.873285    3.414621    0.157695    0.132375    0.006663    0.680270    
#> 419: 0.357521    0.873315    3.414610    0.157750    0.132418    0.006656    0.680252    
#> 420: 0.357747    0.873338    3.414640    0.157883    0.132473    0.006650    0.680179    
#> 421: 0.357738    0.873259    3.414703    0.157936    0.132584    0.006647    0.680139    
#> 422: 0.357946    0.873167    3.414746    0.158012    0.132755    0.006645    0.680197    
#> 423: 0.358023    0.873169    3.414767    0.158132    0.132771    0.006651    0.680143    
#> 424: 0.358010    0.873130    3.414779    0.158253    0.132737    0.006646    0.680105    
#> 425: 0.358179    0.873146    3.414803    0.158300    0.132607    0.006641    0.680166    
#> 426: 0.358403    0.873223    3.414837    0.158349    0.132631    0.006639    0.680145    
#> 427: 0.358401    0.873224    3.414887    0.158324    0.132624    0.006645    0.680050    
#> 428: 0.358349    0.873271    3.414904    0.158332    0.132659    0.006647    0.679993    
#> 429: 0.358403    0.873278    3.414934    0.158334    0.132596    0.006651    0.679981    
#> 430: 0.358463    0.873297    3.414980    0.158349    0.132634    0.006654    0.679884    
#> 431: 0.358424    0.873246    3.414951    0.158301    0.132626    0.006652    0.679766    
#> 432: 0.358411    0.873313    3.414970    0.158191    0.132664    0.006652    0.679721    
#> 433: 0.358437    0.873354    3.414987    0.157969    0.132601    0.006652    0.679704    
#> 434: 0.358341    0.873314    3.415010    0.157707    0.132590    0.006655    0.679698    
#> 435: 0.358445    0.873352    3.415005    0.157597    0.132513    0.006652    0.679678    
#> 436: 0.358426    0.873271    3.415020    0.157465    0.132432    0.006654    0.679721    
#> 437: 0.358424    0.873172    3.415011    0.157443    0.132441    0.006655    0.679709    
#> 438: 0.358455    0.873299    3.415002    0.157396    0.132358    0.006663    0.679710    
#> 439: 0.358486    0.873434    3.414991    0.157318    0.132345    0.006657    0.679754    
#> 440: 0.358388    0.873539    3.415004    0.157259    0.132318    0.006650    0.679755    
#> 441: 0.358357    0.873563    3.415015    0.157205    0.132338    0.006647    0.679764    
#> 442: 0.358362    0.873629    3.415043    0.157297    0.132435    0.006644    0.679753    
#> 443: 0.358424    0.873667    3.415064    0.157314    0.132445    0.006650    0.679694    
#> 444: 0.358463    0.873768    3.415059    0.157301    0.132465    0.006648    0.679652    
#> 445: 0.358497    0.873759    3.415044    0.157234    0.132353    0.006649    0.679686    
#> 446: 0.358309    0.873819    3.414974    0.157223    0.132266    0.006648    0.679646    
#> 447: 0.358329    0.873833    3.414965    0.157267    0.132201    0.006658    0.679584    
#> 448: 0.358226    0.873877    3.414946    0.157226    0.132207    0.006659    0.679518    
#> 449: 0.358331    0.873906    3.415029    0.157145    0.132228    0.006656    0.679547    
#> 450: 0.358430    0.873841    3.415085    0.157071    0.132285    0.006661    0.679564    
#> 451: 0.358648    0.873780    3.415138    0.156960    0.132340    0.006666    0.679553    
#> 452: 0.358779    0.873778    3.415170    0.156826    0.132334    0.006663    0.679577    
#> 453: 0.358770    0.873703    3.415205    0.156801    0.132291    0.006658    0.679534    
#> 454: 0.358815    0.873787    3.415218    0.156771    0.132315    0.006657    0.679518    
#> 455: 0.359019    0.873806    3.415237    0.156749    0.132261    0.006659    0.679441    
#> 456: 0.359045    0.873750    3.415261    0.156800    0.132334    0.006664    0.679409    
#> 457: 0.359013    0.873656    3.415299    0.156806    0.132389    0.006673    0.679336    
#> 458: 0.359122    0.873652    3.415369    0.156817    0.132380    0.006678    0.679320    
#> 459: 0.359114    0.873707    3.415392    0.156779    0.132405    0.006678    0.679282    
#> 460: 0.359032    0.873664    3.415385    0.156779    0.132435    0.006681    0.679253    
#> 461: 0.358963    0.873620    3.415397    0.156689    0.132395    0.006693    0.679225    
#> 462: 0.358893    0.873652    3.415418    0.156621    0.132298    0.006698    0.679187    
#> 463: 0.358964    0.873730    3.415440    0.156572    0.132249    0.006706    0.679118    
#> 464: 0.359118    0.873791    3.415457    0.156614    0.132236    0.006712    0.679041    
#> 465: 0.359190    0.873709    3.415459    0.156618    0.132232    0.006710    0.679011    
#> 466: 0.359278    0.873709    3.415466    0.156522    0.132193    0.006709    0.679006    
#> 467: 0.359338    0.873629    3.415513    0.156547    0.132166    0.006712    0.678933    
#> 468: 0.359549    0.873553    3.415619    0.156568    0.132117    0.006721    0.678919    
#> 469: 0.359760    0.873533    3.415712    0.156566    0.132045    0.006737    0.678839    
#> 470: 0.359846    0.873472    3.415744    0.156469    0.131980    0.006749    0.678722    
#> 471: 0.359808    0.873408    3.415775    0.156409    0.131948    0.006752    0.678662    
#> 472: 0.359802    0.873389    3.415803    0.156368    0.131948    0.006761    0.678629    
#> 473: 0.359721    0.873408    3.415814    0.156359    0.131927    0.006773    0.678554    
#> 474: 0.359705    0.873341    3.415856    0.156384    0.131920    0.006784    0.678551    
#> 475: 0.359727    0.873344    3.415856    0.156360    0.131801    0.006786    0.678544    
#> 476: 0.359778    0.873249    3.415833    0.156429    0.131740    0.006785    0.678557    
#> 477: 0.359799    0.873220    3.415837    0.156494    0.131662    0.006786    0.678478    
#> 478: 0.359775    0.873254    3.415839    0.156552    0.131596    0.006787    0.678459    
#> 479: 0.359781    0.873252    3.415845    0.156617    0.131572    0.006787    0.678470    
#> 480: 0.359860    0.873222    3.415876    0.156567    0.131568    0.006793    0.678480    
#> 481: 0.359890    0.873256    3.415903    0.156725    0.131546    0.006802    0.678556    
#> 482: 0.359877    0.873234    3.415900    0.156781    0.131540    0.006808    0.678605    
#> 483: 0.359809    0.873159    3.415897    0.156776    0.131529    0.006808    0.678640    
#> 484: 0.359747    0.873093    3.415882    0.156790    0.131482    0.006805    0.678667    
#> 485: 0.359755    0.873172    3.415852    0.156782    0.131528    0.006802    0.678662    
#> 486: 0.359711    0.873225    3.415851    0.156801    0.131504    0.006796    0.678632    
#> 487: 0.359744    0.873258    3.415861    0.156889    0.131475    0.006794    0.678600    
#> 488: 0.359692    0.873334    3.415852    0.156829    0.131448    0.006801    0.678599    
#> 489: 0.359727    0.873390    3.415848    0.156959    0.131457    0.006804    0.678573    
#> 490: 0.359801    0.873387    3.415858    0.157045    0.131410    0.006802    0.678615    
#> 491: 0.359875    0.873433    3.415897    0.157072    0.131437    0.006794    0.678616    
#> 492: 0.359931    0.873471    3.415915    0.157121    0.131481    0.006783    0.678717    
#> 493: 0.359950    0.873437    3.415942    0.157116    0.131521    0.006783    0.678743    
#> 494: 0.359945    0.873403    3.415929    0.157093    0.131503    0.006780    0.678755    
#> 495: 0.359974    0.873380    3.415952    0.157072    0.131452    0.006778    0.678751    
#> 496: 0.359989    0.873524    3.415923    0.156973    0.131405    0.006774    0.678779    
#> 497: 0.359960    0.873595    3.415914    0.157009    0.131390    0.006767    0.678838    
#> 498: 0.359983    0.873612    3.415901    0.156973    0.131380    0.006762    0.678788    
#> 499: 0.360000    0.873703    3.415865    0.156869    0.131399    0.006758    0.678736    
#> 500: 0.359990    0.873725    3.415837    0.156780    0.131337    0.006756    0.678677    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.294218    0.980179    3.447126    0.392401    0.083614    0.016800    1.616474    
#> 002: 0.467866    1.020166    3.472605    0.372781    0.079433    0.015960    1.120514    
#> 003: 0.611976    0.975502    3.479933    0.354142    0.075461    0.015162    0.934558    
#> 004: 0.579793    1.009933    3.477660    0.336435    0.071688    0.014404    0.829880    
#> 005: 0.686278    1.007093    3.480514    0.319613    0.068104    0.013684    0.778061    
#> 006: 0.668364    1.034526    3.472957    0.375510    0.064699    0.013000    0.722866    
#> 007: 0.628164    1.033303    3.470776    0.391496    0.061464    0.012350    0.709310    
#> 008: 0.665869    1.039173    3.463204    0.425021    0.060509    0.011732    0.715779    
#> 009: 0.618004    1.053729    3.451686    0.469734    0.057483    0.011146    0.725817    
#> 010: 0.595255    1.053923    3.448449    0.446247    0.054609    0.012241    0.704368    
#> 011: 0.658615    1.048286    3.464033    0.496726    0.051879    0.014525    0.694477    
#> 012: 0.700873    1.047393    3.461518    0.504325    0.049285    0.013799    0.690833    
#> 013: 0.631587    1.044898    3.460851    0.479108    0.046821    0.014866    0.699194    
#> 014: 0.708881    1.046471    3.472667    0.480313    0.044480    0.014122    0.711863    
#> 015: 0.706710    1.042938    3.491572    0.476172    0.044672    0.013416    0.696697    
#> 016: 0.713610    1.027902    3.496430    0.452363    0.042438    0.017192    0.701290    
#> 017: 0.700399    1.044811    3.490264    0.520650    0.040316    0.018162    0.688836    
#> 018: 0.663110    1.053705    3.476927    0.494618    0.041498    0.017254    0.687527    
#> 019: 0.664948    1.046824    3.481083    0.469887    0.039423    0.016391    0.689189    
#> 020: 0.696237    1.036519    3.496473    0.471630    0.037452    0.018065    0.695972    
#> 021: 0.709875    1.019499    3.490793    0.459957    0.035579    0.017161    0.696892    
#> 022: 0.706016    1.019285    3.501623    0.474326    0.033800    0.017712    0.683771    
#> 023: 0.786229    1.022002    3.506720    0.504195    0.032110    0.016826    0.720023    
#> 024: 0.776355    1.051682    3.496572    0.582905    0.030505    0.015985    0.706668    
#> 025: 0.710801    1.032229    3.490380    0.553760    0.040514    0.015186    0.693324    
#> 026: 0.695788    1.057083    3.487302    0.526072    0.042119    0.016410    0.698052    
#> 027: 0.709580    1.053822    3.487442    0.500536    0.046869    0.017414    0.703620    
#> 028: 0.672577    1.047639    3.474990    0.490864    0.044525    0.016543    0.687548    
#> 029: 0.708490    1.031452    3.466416    0.571028    0.042299    0.015716    0.712244    
#> 030: 0.684569    1.065968    3.467934    0.542477    0.046057    0.015558    0.695899    
#> 031: 0.705885    1.057139    3.477255    0.651967    0.044596    0.014780    0.688185    
#> 032: 0.698054    1.054054    3.486173    0.682458    0.049508    0.017412    0.678759    
#> 033: 0.689125    1.073551    3.462519    0.648335    0.047033    0.016541    0.687360    
#> 034: 0.702630    1.075103    3.465920    0.615918    0.044725    0.017749    0.680288    
#> 035: 0.677663    1.046898    3.469471    0.585122    0.042489    0.016862    0.670304    
#> 036: 0.670815    1.064195    3.466827    0.609083    0.040365    0.016018    0.682123    
#> 037: 0.697327    1.063082    3.475174    0.604356    0.038346    0.015469    0.705283    
#> 038: 0.723300    1.043337    3.465396    0.628538    0.036429    0.016848    0.698726    
#> 039: 0.684106    1.034538    3.471038    0.648548    0.034608    0.019202    0.685915    
#> 040: 0.719092    1.041119    3.485487    0.616121    0.032877    0.022036    0.689167    
#> 041: 0.707926    1.029866    3.477642    0.603596    0.031233    0.020934    0.695049    
#> 042: 0.696966    1.037067    3.479196    0.573416    0.032767    0.019887    0.678923    
#> 043: 0.629571    1.061939    3.466908    0.544745    0.036989    0.018893    0.674882    
#> 044: 0.672159    1.061355    3.462729    0.530939    0.035139    0.017948    0.679041    
#> 045: 0.654895    1.084509    3.454953    0.537304    0.038236    0.020179    0.666855    
#> 046: 0.661473    1.052587    3.474905    0.510438    0.036351    0.019170    0.667848    
#> 047: 0.676118    1.035256    3.471686    0.495278    0.034534    0.018211    0.681531    
#> 048: 0.692261    1.019678    3.479719    0.530957    0.032807    0.019611    0.684990    
#> 049: 0.724620    1.025846    3.483153    0.504409    0.031166    0.019839    0.693162    
#> 050: 0.744587    1.011203    3.488447    0.527361    0.029608    0.023007    0.688978    
#> 051: 0.699606    1.027859    3.475668    0.507260    0.028128    0.022582    0.691511    
#> 052: 0.766413    1.038594    3.488354    0.663765    0.026721    0.022633    0.666754    
#> 053: 0.779818    1.028103    3.485695    0.731866    0.025385    0.024777    0.680186    
#> 054: 0.676050    1.027870    3.481801    0.695272    0.024204    0.023538    0.699205    
#> 055: 0.702087    1.030185    3.481254    0.660509    0.022993    0.022361    0.701942    
#> 056: 0.720665    1.037493    3.482949    0.627483    0.027201    0.021243    0.699007    
#> 057: 0.715242    1.034023    3.484901    0.596109    0.025841    0.020181    0.735195    
#> 058: 0.712190    1.036410    3.467526    0.566304    0.024549    0.019750    0.732524    
#> 059: 0.692842    1.016848    3.485998    0.537989    0.034278    0.020829    0.703441    
#> 060: 0.718010    1.002291    3.501646    0.513630    0.032564    0.025998    0.708173    
#> 061: 0.760559    0.994185    3.502782    0.487948    0.030936    0.024698    0.713217    
#> 062: 0.739585    1.026336    3.500584    0.502058    0.029389    0.023463    0.708724    
#> 063: 0.760797    1.018083    3.490164    0.554938    0.029573    0.022290    0.700799    
#> 064: 0.672968    1.018317    3.484923    0.604983    0.028401    0.021175    0.703099    
#> 065: 0.720255    1.026076    3.471176    0.574733    0.031919    0.020117    0.698024    
#> 066: 0.744536    1.036040    3.488418    0.573108    0.031091    0.019111    0.664896    
#> 067: 0.687523    1.054637    3.469017    0.585521    0.029537    0.020560    0.678353    
#> 068: 0.666255    1.051640    3.477948    0.556245    0.028060    0.020128    0.689104    
#> 069: 0.603155    1.054708    3.451516    0.575150    0.028130    0.020395    0.708396    
#> 070: 0.667715    1.062902    3.467456    0.611628    0.032398    0.020057    0.690580    
#> 071: 0.674120    1.077626    3.457897    0.605837    0.033303    0.019906    0.693474    
#> 072: 0.645975    1.057747    3.467652    0.575545    0.031638    0.021764    0.681988    
#> 073: 0.665861    1.056132    3.471773    0.576115    0.036245    0.020676    0.691752    
#> 074: 0.641923    1.054935    3.462442    0.547309    0.036560    0.019642    0.690765    
#> 075: 0.633134    1.039385    3.480202    0.519944    0.037550    0.018660    0.690444    
#> 076: 0.673444    1.038571    3.487201    0.527103    0.035673    0.020138    0.691501    
#> 077: 0.728771    1.041490    3.479547    0.522489    0.037737    0.019132    0.689919    
#> 078: 0.698260    1.047331    3.482839    0.533032    0.035850    0.018929    0.685178    
#> 079: 0.678355    1.066445    3.481011    0.506380    0.034057    0.019649    0.721669    
#> 080: 0.713162    1.048558    3.481534    0.483872    0.033964    0.019054    0.695594    
#> 081: 0.721401    1.058382    3.472822    0.459679    0.032266    0.018101    0.702626    
#> 082: 0.681537    1.044025    3.489889    0.493476    0.030652    0.017808    0.712414    
#> 083: 0.733642    1.053112    3.492589    0.512015    0.029120    0.021290    0.696940    
#> 084: 0.735805    1.053634    3.487983    0.565071    0.031871    0.020226    0.702810    
#> 085: 0.714729    1.045652    3.496053    0.566415    0.035637    0.019215    0.706720    
#> 086: 0.741608    1.034354    3.490884    0.666616    0.034576    0.018254    0.698376    
#> 087: 0.762100    1.022988    3.483925    0.633285    0.032847    0.017341    0.693409    
#> 088: 0.650110    1.029719    3.476225    0.601621    0.034662    0.016474    0.690697    
#> 089: 0.650347    1.060343    3.462216    0.571540    0.032929    0.015650    0.677614    
#> 090: 0.618724    1.057948    3.457641    0.542963    0.031707    0.017081    0.693130    
#> 091: 0.674148    1.056250    3.451045    0.515815    0.032838    0.016443    0.690859    
#> 092: 0.635774    1.084062    3.451694    0.490024    0.034701    0.015620    0.689216    
#> 093: 0.631366    1.070353    3.451017    0.477397    0.032966    0.014839    0.692171    
#> 094: 0.674237    1.071426    3.450353    0.609685    0.031318    0.014097    0.691927    
#> 095: 0.695765    1.078768    3.471976    0.579201    0.032862    0.013393    0.693766    
#> 096: 0.645891    1.090279    3.463585    0.550241    0.038151    0.013211    0.685544    
#> 097: 0.711462    1.084083    3.459278    0.587147    0.036244    0.014578    0.672569    
#> 098: 0.720872    1.089513    3.475550    0.613732    0.034432    0.013903    0.697325    
#> 099: 0.642359    1.056059    3.458377    0.583046    0.032710    0.018107    0.692886    
#> 100: 0.648369    1.056296    3.467997    0.602214    0.031075    0.021771    0.691744    
#> 101: 0.625567    1.051684    3.450451    0.572103    0.029521    0.021520    0.685064    
#> 102: 0.623114    1.055108    3.433119    0.543498    0.028313    0.020444    0.688921    
#> 103: 0.682615    1.056088    3.453747    0.648314    0.028035    0.020513    0.678202    
#> 104: 0.664389    1.054401    3.464650    0.672108    0.035477    0.019488    0.682117    
#> 105: 0.686296    1.057744    3.478989    0.638503    0.036886    0.018513    0.685936    
#> 106: 0.634857    1.062526    3.459493    0.606578    0.035042    0.017588    0.693908    
#> 107: 0.650760    1.067052    3.457826    0.576249    0.033290    0.020051    0.695467    
#> 108: 0.647993    1.060338    3.467993    0.547437    0.039954    0.019048    0.730147    
#> 109: 0.649206    1.061210    3.475355    0.520065    0.039309    0.018096    0.712776    
#> 110: 0.640492    1.050869    3.456624    0.497833    0.037344    0.017191    0.692844    
#> 111: 0.677900    1.065397    3.464875    0.485196    0.035476    0.016332    0.689781    
#> 112: 0.655869    1.045406    3.457175    0.460937    0.033703    0.015515    0.703010    
#> 113: 0.662408    1.057396    3.459887    0.553281    0.032136    0.017084    0.667220    
#> 114: 0.674298    1.056015    3.458255    0.548472    0.030529    0.016716    0.688623    
#> 115: 0.669384    1.027024    3.460543    0.521049    0.034941    0.015881    0.693613    
#> 116: 0.646098    1.049531    3.463483    0.494996    0.039337    0.015087    0.689222    
#> 117: 0.644411    1.063147    3.470525    0.504285    0.037370    0.014332    0.701628    
#> 118: 0.694446    1.062087    3.478389    0.548073    0.035502    0.017533    0.678945    
#> 119: 0.708980    1.048106    3.478373    0.548874    0.033727    0.024803    0.712930    
#> 120: 0.695981    1.022540    3.489424    0.521430    0.032040    0.024014    0.676663    
#> 121: 0.727841    1.046462    3.475128    0.523380    0.030438    0.023028    0.687470    
#> 122: 0.708151    1.020678    3.491466    0.563218    0.028916    0.023640    0.677145    
#> 123: 0.696477    1.045075    3.472303    0.535058    0.031044    0.022458    0.687159    
#> 124: 0.683959    1.073374    3.472408    0.508305    0.033640    0.021335    0.683847    
#> 125: 0.738340    1.048803    3.475637    0.584925    0.031958    0.020269    0.674359    
#> 126: 0.713379    1.065090    3.461633    0.562972    0.035558    0.020767    0.693077    
#> 127: 0.733096    1.046779    3.466586    0.574225    0.036510    0.020010    0.686972    
#> 128: 0.658197    1.051598    3.473601    0.545514    0.034684    0.019009    0.683502    
#> 129: 0.676639    1.044826    3.482769    0.518238    0.035451    0.018059    0.712983    
#> 130: 0.725823    1.068252    3.476646    0.492326    0.036779    0.017464    0.696980    
#> 131: 0.650021    1.057880    3.460970    0.475572    0.034940    0.019094    0.689224    
#> 132: 0.645717    1.052672    3.446629    0.451794    0.033193    0.018139    0.716407    
#> 133: 0.627915    1.045201    3.462755    0.546203    0.037453    0.018724    0.694774    
#> 134: 0.711893    1.036837    3.482125    0.564046    0.040237    0.017824    0.678939    
#> 135: 0.705643    1.025715    3.489009    0.570564    0.040120    0.018749    0.675571    
#> 136: 0.722476    1.032398    3.483026    0.677869    0.038983    0.018179    0.670222    
#> 137: 0.685986    1.037192    3.475412    0.643975    0.039143    0.017270    0.690593    
#> 138: 0.686270    1.049843    3.471281    0.611776    0.037186    0.017197    0.684244    
#> 139: 0.663468    1.068650    3.471960    0.581188    0.035327    0.019781    0.675819    
#> 140: 0.670984    1.058234    3.478933    0.552128    0.034499    0.023238    0.681322    
#> 141: 0.667708    1.045306    3.470909    0.568986    0.036910    0.022077    0.667825    
#> 142: 0.674974    1.040166    3.490829    0.540536    0.035065    0.020973    0.696240    
#> 143: 0.657472    1.050218    3.478836    0.513509    0.033311    0.021260    0.697664    
#> 144: 0.723067    1.066399    3.493520    0.487834    0.031646    0.020197    0.674270    
#> 145: 0.639382    1.072615    3.460452    0.475469    0.030186    0.019187    0.675214    
#> 146: 0.621338    1.070034    3.465885    0.453571    0.028738    0.018228    0.696390    
#> 147: 0.616072    1.061395    3.463014    0.465208    0.031889    0.017317    0.690523    
#> 148: 0.637158    1.059787    3.479457    0.463789    0.032323    0.019058    0.673342    
#> 149: 0.652512    1.047205    3.468098    0.547138    0.040797    0.018105    0.679869    
#> 150: 0.724030    1.050586    3.470833    0.519781    0.044522    0.017200    0.704450    
#> 151: 0.639708    1.070281    3.464505    0.513715    0.042296    0.017413    0.693958    
#> 152: 0.628887    1.067861    3.461956    0.548562    0.037541    0.020604    0.693079    
#> 153: 0.628208    1.076219    3.470456    0.466561    0.034255    0.018923    0.703290    
#> 154: 0.686505    1.092077    3.467336    0.540520    0.037023    0.017439    0.696877    
#> 155: 0.668125    1.049225    3.460127    0.515019    0.031921    0.016793    0.683202    
#> 156: 0.675856    1.059977    3.470793    0.505873    0.042823    0.015942    0.695193    
#> 157: 0.699792    1.048111    3.480054    0.638236    0.038602    0.016557    0.697502    
#> 158: 0.695487    1.071615    3.471374    0.547239    0.039935    0.014659    0.683056    
#> 159: 0.670490    1.061632    3.474184    0.573308    0.031848    0.014017    0.677394    
#> 160: 0.723961    1.031991    3.485272    0.610829    0.035995    0.011799    0.692121    
#> 161: 0.688294    1.040694    3.470341    0.612395    0.034064    0.015355    0.679773    
#> 162: 0.692170    1.052225    3.464689    0.620965    0.034943    0.016325    0.702959    
#> 163: 0.726863    1.039503    3.463694    0.708971    0.037948    0.017704    0.691558    
#> 164: 0.682812    1.049559    3.464458    0.682813    0.035132    0.021579    0.678401    
#> 165: 0.659431    1.062782    3.454017    0.640355    0.028709    0.021267    0.693484    
#> 166: 0.737801    1.079164    3.451156    0.836220    0.027113    0.021642    0.687598    
#> 167: 0.752380    1.073930    3.476973    0.798425    0.025475    0.023473    0.702782    
#> 168: 0.769395    1.069163    3.484239    0.752032    0.027116    0.025445    0.687305    
#> 169: 0.770420    1.076329    3.469155    0.740367    0.027869    0.020052    0.680877    
#> 170: 0.787431    1.051025    3.478925    0.829983    0.026354    0.018483    0.677967    
#> 171: 0.732776    1.064209    3.481377    0.697149    0.024945    0.019917    0.677844    
#> 172: 0.705969    1.079345    3.481196    0.599938    0.021300    0.018534    0.678884    
#> 173: 0.670482    1.081616    3.455940    0.602082    0.021312    0.022577    0.673310    
#> 174: 0.658838    1.073883    3.464517    0.571793    0.022769    0.019791    0.702976    
#> 175: 0.655306    1.063723    3.465099    0.538902    0.025493    0.022346    0.683160    
#> 176: 0.663370    1.070348    3.475525    0.541614    0.023146    0.019159    0.682111    
#> 177: 0.705876    1.067648    3.479376    0.559800    0.030141    0.024882    0.685841    
#> 178: 0.701274    1.047509    3.477242    0.508326    0.027458    0.021535    0.697220    
#> 179: 0.750182    1.070057    3.474374    0.634038    0.028433    0.018635    0.699953    
#> 180: 0.712778    1.057927    3.469996    0.614414    0.028622    0.017376    0.696073    
#> 181: 0.717635    1.040080    3.456580    0.617549    0.024738    0.016390    0.707393    
#> 182: 0.650299    1.038901    3.452703    0.513856    0.020536    0.018334    0.724386    
#> 183: 0.633200    1.054370    3.451876    0.486986    0.022556    0.015578    0.718573    
#> 184: 0.681152    1.042086    3.467163    0.573150    0.020588    0.014546    0.709235    
#> 185: 0.655971    1.067226    3.474503    0.474921    0.020134    0.016731    0.709795    
#> 186: 0.662098    1.076603    3.470809    0.463676    0.014627    0.020642    0.724220    
#> 187: 0.656076    1.070980    3.480027    0.495257    0.021601    0.021976    0.707788    
#> 188: 0.605210    1.085868    3.463905    0.466710    0.028427    0.021076    0.711682    
#> 189: 0.630996    1.082359    3.469259    0.494660    0.026342    0.020210    0.712535    
#> 190: 0.655933    1.064978    3.479271    0.482903    0.025007    0.021171    0.702340    
#> 191: 0.663413    1.068928    3.467302    0.523619    0.024713    0.019983    0.693307    
#> 192: 0.642222    1.078569    3.470091    0.565827    0.031041    0.024086    0.689855    
#> 193: 0.675477    1.071729    3.462765    0.607387    0.025981    0.022330    0.681597    
#> 194: 0.672165    1.069121    3.451786    0.614336    0.026034    0.020349    0.695547    
#> 195: 0.610391    1.072609    3.446471    0.544173    0.028410    0.017765    0.688396    
#> 196: 0.620253    1.074072    3.455521    0.512610    0.026611    0.017681    0.703348    
#> 197: 0.600105    1.084728    3.479232    0.462664    0.031287    0.019468    0.708513    
#> 198: 0.659748    1.074447    3.471502    0.428187    0.024519    0.022186    0.697065    
#> 199: 0.625618    1.065893    3.464802    0.419511    0.024877    0.018880    0.702122    
#> 200: 0.634663    1.049039    3.474028    0.412602    0.021972    0.019049    0.711979    
#> 201: 0.640920    1.043210    3.473535    0.442887    0.022479    0.020076    0.698587    
#> 202: 0.652434    1.044099    3.475687    0.472278    0.022674    0.020135    0.697289    
#> 203: 0.664653    1.043479    3.475146    0.468225    0.022908    0.019792    0.698553    
#> 204: 0.663835    1.039610    3.475446    0.474031    0.023893    0.019688    0.699526    
#> 205: 0.666471    1.042845    3.475854    0.478181    0.024932    0.020397    0.700847    
#> 206: 0.668688    1.045086    3.476546    0.499965    0.025714    0.020565    0.699835    
#> 207: 0.666700    1.046650    3.474862    0.493719    0.026265    0.020188    0.697690    
#> 208: 0.665481    1.048027    3.474233    0.491083    0.026766    0.020024    0.695440    
#> 209: 0.666489    1.047656    3.472961    0.494319    0.026921    0.019830    0.693269    
#> 210: 0.668652    1.046219    3.473548    0.492499    0.026809    0.019867    0.692551    
#> 211: 0.670654    1.046156    3.474680    0.487388    0.026850    0.020070    0.693071    
#> 212: 0.675070    1.046212    3.474965    0.487556    0.027010    0.020141    0.693868    
#> 213: 0.676972    1.043740    3.475968    0.490970    0.027443    0.020012    0.694425    
#> 214: 0.678099    1.042699    3.476479    0.491895    0.027729    0.019870    0.695095    
#> 215: 0.677847    1.042133    3.477112    0.491448    0.027622    0.019857    0.695882    
#> 216: 0.682513    1.039859    3.478045    0.493797    0.027730    0.019913    0.697469    
#> 217: 0.683402    1.038850    3.479167    0.494863    0.027846    0.019891    0.697847    
#> 218: 0.685748    1.039021    3.478834    0.499631    0.027655    0.019975    0.697900    
#> 219: 0.685497    1.038772    3.477969    0.503647    0.027631    0.020121    0.697106    
#> 220: 0.685440    1.038413    3.478104    0.505659    0.027338    0.020258    0.696773    
#> 221: 0.685034    1.038199    3.478045    0.508998    0.027509    0.020291    0.695642    
#> 222: 0.685619    1.038500    3.477782    0.513656    0.027699    0.020358    0.694250    
#> 223: 0.687615    1.038756    3.478093    0.516136    0.027803    0.020426    0.692889    
#> 224: 0.690594    1.039173    3.478576    0.517590    0.027627    0.020556    0.692356    
#> 225: 0.691016    1.038513    3.479090    0.519210    0.027592    0.020681    0.692260    
#> 226: 0.691950    1.037940    3.478770    0.523672    0.027607    0.020717    0.691936    
#> 227: 0.692413    1.037656    3.478969    0.526512    0.027326    0.020754    0.691386    
#> 228: 0.693122    1.038413    3.478394    0.528294    0.027162    0.020806    0.691207    
#> 229: 0.692841    1.038421    3.478074    0.528455    0.027061    0.020817    0.690562    
#> 230: 0.694662    1.038324    3.478241    0.530201    0.027133    0.020752    0.690114    
#> 231: 0.694965    1.038227    3.478600    0.530734    0.027103    0.020636    0.689897    
#> 232: 0.695856    1.037972    3.478774    0.535059    0.027043    0.020552    0.689542    
#> 233: 0.695716    1.037465    3.478845    0.535340    0.027159    0.020493    0.689629    
#> 234: 0.695227    1.037406    3.478718    0.533772    0.027091    0.020473    0.690169    
#> 235: 0.695310    1.037133    3.478846    0.531903    0.027238    0.020397    0.689899    
#> 236: 0.694305    1.037543    3.478849    0.528917    0.027462    0.020303    0.689867    
#> 237: 0.695428    1.037444    3.478912    0.530451    0.027536    0.020327    0.690276    
#> 238: 0.696183    1.037416    3.479081    0.530971    0.027600    0.020362    0.690816    
#> 239: 0.695679    1.037577    3.478938    0.531100    0.027621    0.020400    0.690831    
#> 240: 0.695164    1.037576    3.478944    0.530847    0.027668    0.020351    0.690818    
#> 241: 0.695013    1.037122    3.479133    0.529744    0.027683    0.020245    0.691059    
#> 242: 0.693840    1.036689    3.478882    0.527227    0.027895    0.020134    0.691585    
#> 243: 0.692868    1.037601    3.478615    0.526004    0.028173    0.020116    0.691653    
#> 244: 0.693100    1.037904    3.478560    0.528560    0.028403    0.020060    0.691617    
#> 245: 0.692960    1.037660    3.478783    0.529364    0.028541    0.020176    0.691754    
#> 246: 0.692710    1.037517    3.478842    0.529927    0.028637    0.020225    0.691805    
#> 247: 0.691646    1.037406    3.478870    0.530096    0.028691    0.020210    0.691595    
#> 248: 0.691884    1.037603    3.478911    0.531152    0.028696    0.020277    0.690989    
#> 249: 0.691912    1.037627    3.478907    0.532211    0.028805    0.020348    0.690873    
#> 250: 0.693136    1.037591    3.479105    0.531552    0.028805    0.020315    0.691198    
#> 251: 0.694519    1.037451    3.479557    0.532911    0.028873    0.020301    0.691320    
#> 252: 0.695313    1.037547    3.479955    0.531968    0.028771    0.020378    0.691426    
#> 253: 0.694869    1.037885    3.480070    0.531393    0.028738    0.020360    0.691701    
#> 254: 0.695070    1.038478    3.480354    0.531325    0.028649    0.020414    0.692123    
#> 255: 0.694793    1.038716    3.480337    0.532669    0.028628    0.020503    0.692080    
#> 256: 0.694755    1.038778    3.480116    0.534049    0.028678    0.020539    0.691927    
#> 257: 0.694488    1.038566    3.479940    0.535231    0.028619    0.020601    0.691613    
#> 258: 0.694063    1.038131    3.479921    0.535161    0.028512    0.020614    0.691438    
#> 259: 0.694304    1.037892    3.479959    0.535138    0.028472    0.020598    0.691695    
#> 260: 0.694526    1.037971    3.480112    0.534987    0.028481    0.020578    0.691444    
#> 261: 0.695378    1.037868    3.480288    0.536156    0.028425    0.020565    0.691481    
#> 262: 0.695214    1.038002    3.480279    0.535890    0.028455    0.020518    0.691491    
#> 263: 0.694140    1.038180    3.480246    0.535697    0.028473    0.020497    0.691679    
#> 264: 0.693536    1.038255    3.480294    0.535004    0.028597    0.020492    0.691834    
#> 265: 0.693761    1.038250    3.480349    0.535147    0.028654    0.020495    0.691903    
#> 266: 0.693760    1.038488    3.480342    0.534271    0.028665    0.020564    0.691876    
#> 267: 0.693226    1.038537    3.480410    0.533850    0.028634    0.020610    0.692146    
#> 268: 0.692842    1.038477    3.480187    0.534131    0.028617    0.020596    0.692154    
#> 269: 0.693769    1.038494    3.480130    0.536555    0.028546    0.020644    0.691967    
#> 270: 0.694170    1.038711    3.479981    0.538658    0.028525    0.020632    0.691790    
#> 271: 0.694808    1.038667    3.479814    0.540071    0.028541    0.020605    0.691815    
#> 272: 0.694953    1.038600    3.479617    0.541034    0.028610    0.020548    0.691784    
#> 273: 0.695321    1.038956    3.479697    0.542196    0.028685    0.020537    0.691948    
#> 274: 0.694870    1.039253    3.479706    0.541563    0.028805    0.020475    0.691913    
#> 275: 0.694717    1.039415    3.479564    0.542264    0.028864    0.020424    0.691690    
#> 276: 0.693768    1.039854    3.479459    0.541548    0.029055    0.020384    0.691657    
#> 277: 0.693570    1.040305    3.479396    0.541633    0.029156    0.020363    0.691527    
#> 278: 0.693163    1.040409    3.479419    0.540952    0.029177    0.020338    0.691349    
#> 279: 0.692837    1.040317    3.479304    0.540802    0.029241    0.020342    0.691479    
#> 280: 0.692385    1.040467    3.479130    0.541238    0.029317    0.020352    0.691393    
#> 281: 0.691713    1.040694    3.478969    0.541379    0.029397    0.020329    0.691305    
#> 282: 0.691761    1.040861    3.478945    0.540738    0.029381    0.020274    0.691384    
#> 283: 0.691559    1.041191    3.478973    0.540779    0.029402    0.020195    0.691765    
#> 284: 0.691519    1.041068    3.479041    0.540238    0.029519    0.020138    0.691780    
#> 285: 0.691498    1.040906    3.479084    0.539968    0.029676    0.020137    0.691821    
#> 286: 0.691931    1.040839    3.478964    0.540847    0.029689    0.020102    0.692100    
#> 287: 0.691647    1.041101    3.478746    0.541361    0.029792    0.020096    0.692176    
#> 288: 0.691728    1.040998    3.478688    0.541171    0.029702    0.020151    0.692315    
#> 289: 0.691941    1.040993    3.478632    0.540735    0.029709    0.020181    0.692374    
#> 290: 0.691715    1.041089    3.478506    0.540799    0.029776    0.020147    0.692617    
#> 291: 0.691777    1.041419    3.478595    0.540644    0.029857    0.020069    0.692600    
#> 292: 0.691833    1.041623    3.478583    0.540907    0.029906    0.020009    0.692576    
#> 293: 0.691565    1.041830    3.478520    0.540716    0.029941    0.019950    0.692646    
#> 294: 0.691094    1.042145    3.478379    0.540052    0.029995    0.019921    0.692672    
#> 295: 0.690855    1.042112    3.478283    0.540384    0.030033    0.019879    0.692571    
#> 296: 0.691124    1.042078    3.478236    0.540559    0.030180    0.019848    0.692561    
#> 297: 0.690997    1.042234    3.478196    0.540260    0.030257    0.019794    0.692584    
#> 298: 0.691175    1.042152    3.478089    0.540643    0.030320    0.019737    0.692476    
#> 299: 0.691490    1.042287    3.477976    0.541563    0.030353    0.019710    0.692306    
#> 300: 0.691590    1.042257    3.478067    0.541839    0.030378    0.019673    0.692282    
#> 301: 0.691868    1.042127    3.478097    0.541830    0.030384    0.019647    0.692312    
#> 302: 0.692074    1.042023    3.478035    0.542165    0.030385    0.019616    0.692125    
#> 303: 0.691700    1.042095    3.477953    0.540672    0.030458    0.019597    0.691899    
#> 304: 0.691680    1.042252    3.477865    0.539880    0.030514    0.019576    0.691662    
#> 305: 0.691694    1.042184    3.477904    0.539234    0.030511    0.019573    0.691552    
#> 306: 0.691274    1.042029    3.477896    0.538651    0.030527    0.019590    0.691416    
#> 307: 0.690812    1.041871    3.477855    0.537918    0.030530    0.019603    0.691518    
#> 308: 0.690432    1.041864    3.477766    0.538325    0.030505    0.019621    0.691645    
#> 309: 0.690254    1.041712    3.477687    0.538225    0.030524    0.019608    0.691624    
#> 310: 0.690749    1.041483    3.477637    0.538720    0.030511    0.019596    0.691725    
#> 311: 0.690555    1.041427    3.477603    0.538770    0.030496    0.019572    0.691691    
#> 312: 0.690167    1.041499    3.477379    0.539268    0.030476    0.019580    0.691694    
#> 313: 0.689919    1.041476    3.477189    0.539617    0.030451    0.019599    0.691788    
#> 314: 0.689152    1.041624    3.476990    0.539644    0.030418    0.019613    0.691681    
#> 315: 0.688740    1.041784    3.476906    0.539584    0.030382    0.019598    0.691678    
#> 316: 0.688518    1.041907    3.476896    0.539347    0.030411    0.019582    0.691719    
#> 317: 0.688611    1.041867    3.476948    0.539367    0.030415    0.019573    0.691675    
#> 318: 0.688679    1.041985    3.476894    0.539987    0.030422    0.019535    0.691449    
#> 319: 0.688995    1.042037    3.476969    0.540618    0.030448    0.019547    0.691415    
#> 320: 0.688740    1.042094    3.476903    0.540701    0.030468    0.019545    0.691454    
#> 321: 0.688403    1.042206    3.476722    0.540679    0.030454    0.019544    0.691701    
#> 322: 0.688284    1.042251    3.476555    0.541357    0.030438    0.019568    0.691666    
#> 323: 0.687680    1.042301    3.476422    0.540805    0.030441    0.019555    0.691608    
#> 324: 0.687628    1.042533    3.476437    0.540572    0.030493    0.019534    0.691545    
#> 325: 0.687807    1.042657    3.476410    0.540397    0.030515    0.019503    0.691606    
#> 326: 0.688049    1.042466    3.476401    0.540855    0.030491    0.019490    0.691671    
#> 327: 0.688349    1.042485    3.476486    0.541068    0.030513    0.019492    0.691605    
#> 328: 0.688686    1.042533    3.476512    0.541174    0.030551    0.019486    0.691507    
#> 329: 0.689002    1.042572    3.476535    0.541783    0.030540    0.019476    0.691407    
#> 330: 0.688994    1.042567    3.476484    0.542150    0.030561    0.019445    0.691338    
#> 331: 0.689265    1.042785    3.476449    0.542846    0.030631    0.019444    0.691243    
#> 332: 0.689635    1.042767    3.476546    0.542558    0.030669    0.019421    0.691444    
#> 333: 0.689318    1.042786    3.476504    0.541616    0.030636    0.019409    0.691640    
#> 334: 0.689074    1.042797    3.476361    0.542009    0.030634    0.019413    0.691656    
#> 335: 0.689003    1.042869    3.476326    0.541951    0.030602    0.019395    0.691613    
#> 336: 0.688772    1.042896    3.476310    0.541607    0.030568    0.019390    0.691697    
#> 337: 0.688723    1.042952    3.476362    0.540904    0.030544    0.019399    0.691768    
#> 338: 0.688663    1.042995    3.476403    0.540746    0.030537    0.019431    0.691738    
#> 339: 0.688652    1.043080    3.476377    0.540921    0.030555    0.019459    0.691667    
#> 340: 0.688284    1.043061    3.476367    0.540493    0.030615    0.019479    0.691671    
#> 341: 0.688563    1.042990    3.476469    0.540655    0.030634    0.019499    0.691656    
#> 342: 0.688260    1.042869    3.476433    0.540073    0.030627    0.019500    0.691633    
#> 343: 0.687857    1.042949    3.476324    0.539906    0.030604    0.019514    0.691731    
#> 344: 0.687664    1.042971    3.476281    0.539740    0.030594    0.019525    0.691808    
#> 345: 0.687528    1.043034    3.476236    0.539902    0.030573    0.019523    0.691690    
#> 346: 0.687553    1.043196    3.476123    0.540318    0.030547    0.019512    0.691598    
#> 347: 0.687522    1.043147    3.476040    0.540718    0.030548    0.019502    0.691696    
#> 348: 0.687556    1.043217    3.475918    0.541654    0.030583    0.019502    0.691769    
#> 349: 0.687736    1.043139    3.475895    0.541750    0.030584    0.019496    0.691768    
#> 350: 0.688031    1.043056    3.475888    0.542272    0.030598    0.019529    0.691715    
#> 351: 0.688134    1.043101    3.475865    0.541891    0.030585    0.019553    0.691677    
#> 352: 0.687653    1.043255    3.475739    0.541452    0.030568    0.019575    0.691774    
#> 353: 0.687659    1.043466    3.475679    0.541753    0.030565    0.019599    0.691631    
#> 354: 0.687602    1.043540    3.475525    0.541681    0.030561    0.019629    0.691522    
#> 355: 0.688020    1.043507    3.475478    0.542025    0.030569    0.019619    0.691382    
#> 356: 0.687859    1.043486    3.475509    0.541042    0.030592    0.019584    0.691575    
#> 357: 0.688027    1.043634    3.475513    0.540933    0.030631    0.019547    0.691531    
#> 358: 0.688286    1.043675    3.475547    0.541409    0.030685    0.019526    0.691443    
#> 359: 0.688056    1.043844    3.475436    0.541048    0.030650    0.019504    0.691429    
#> 360: 0.687811    1.043904    3.475235    0.540797    0.030596    0.019518    0.691370    
#> 361: 0.687422    1.043961    3.475137    0.540581    0.030525    0.019515    0.691281    
#> 362: 0.687278    1.044011    3.475050    0.540495    0.030485    0.019510    0.691099    
#> 363: 0.687073    1.044086    3.474995    0.540072    0.030473    0.019487    0.690902    
#> 364: 0.687222    1.044163    3.474950    0.540073    0.030508    0.019463    0.690850    
#> 365: 0.687166    1.044133    3.474969    0.540028    0.030551    0.019466    0.690939    
#> 366: 0.687209    1.044195    3.474917    0.540350    0.030553    0.019475    0.691042    
#> 367: 0.687543    1.044311    3.474876    0.541264    0.030534    0.019474    0.691065    
#> 368: 0.687561    1.044433    3.474726    0.541605    0.030524    0.019481    0.691057    
#> 369: 0.687345    1.044617    3.474647    0.541403    0.030538    0.019486    0.691061    
#> 370: 0.687122    1.044769    3.474586    0.541104    0.030517    0.019493    0.691062    
#> 371: 0.686771    1.044850    3.474432    0.541267    0.030479    0.019512    0.690970    
#> 372: 0.686360    1.044977    3.474281    0.541521    0.030478    0.019519    0.690963    
#> 373: 0.686007    1.045102    3.474119    0.542003    0.030447    0.019546    0.691081    
#> 374: 0.686114    1.045166    3.474033    0.543554    0.030393    0.019565    0.691060    
#> 375: 0.686205    1.045221    3.473933    0.545047    0.030365    0.019575    0.691096    
#> 376: 0.686085    1.045332    3.473860    0.545494    0.030302    0.019616    0.691118    
#> 377: 0.685962    1.045536    3.473771    0.545633    0.030286    0.019623    0.691200    
#> 378: 0.685643    1.045602    3.473701    0.545510    0.030256    0.019639    0.691262    
#> 379: 0.685326    1.045576    3.473683    0.545139    0.030219    0.019645    0.691222    
#> 380: 0.685021    1.045607    3.473632    0.544535    0.030233    0.019661    0.691168    
#> 381: 0.684704    1.045726    3.473555    0.544552    0.030270    0.019650    0.691057    
#> 382: 0.684609    1.045764    3.473511    0.544580    0.030275    0.019636    0.690966    
#> 383: 0.684539    1.045789    3.473498    0.544517    0.030326    0.019622    0.690897    
#> 384: 0.684548    1.045819    3.473571    0.544740    0.030330    0.019640    0.690848    
#> 385: 0.684624    1.045843    3.473611    0.544770    0.030325    0.019665    0.690853    
#> 386: 0.684926    1.045978    3.473699    0.544603    0.030321    0.019668    0.690892    
#> 387: 0.685209    1.046102    3.473778    0.544879    0.030307    0.019674    0.690909    
#> 388: 0.685341    1.046141    3.473807    0.544785    0.030301    0.019666    0.690942    
#> 389: 0.685166    1.046018    3.473795    0.544440    0.030345    0.019649    0.691030    
#> 390: 0.685103    1.046026    3.473747    0.544150    0.030388    0.019615    0.690986    
#> 391: 0.685302    1.045983    3.473770    0.544251    0.030412    0.019617    0.690900    
#> 392: 0.685575    1.046018    3.473822    0.544492    0.030421    0.019611    0.690884    
#> 393: 0.685580    1.046012    3.473789    0.544257    0.030437    0.019606    0.690864    
#> 394: 0.685796    1.046085    3.473752    0.544237    0.030418    0.019573    0.690802    
#> 395: 0.685996    1.046176    3.473730    0.544545    0.030438    0.019561    0.690725    
#> 396: 0.685985    1.046249    3.473738    0.544348    0.030508    0.019544    0.690610    
#> 397: 0.685899    1.046178    3.473790    0.543920    0.030548    0.019538    0.690647    
#> 398: 0.686198    1.046021    3.473894    0.543691    0.030584    0.019521    0.690662    
#> 399: 0.686297    1.046062    3.473991    0.543459    0.030628    0.019522    0.690714    
#> 400: 0.686376    1.046137    3.474041    0.543189    0.030649    0.019510    0.690711    
#> 401: 0.686477    1.046248    3.474033    0.543058    0.030656    0.019495    0.690743    
#> 402: 0.686279    1.046305    3.474012    0.542674    0.030651    0.019489    0.690751    
#> 403: 0.686424    1.046388    3.473970    0.542773    0.030664    0.019473    0.690807    
#> 404: 0.686559    1.046461    3.473911    0.543384    0.030657    0.019471    0.690761    
#> 405: 0.686715    1.046564    3.473909    0.544467    0.030609    0.019488    0.690705    
#> 406: 0.686745    1.046624    3.473881    0.544835    0.030588    0.019507    0.690759    
#> 407: 0.686741    1.046713    3.473902    0.545340    0.030589    0.019521    0.690748    
#> 408: 0.686945    1.046880    3.473895    0.545552    0.030639    0.019509    0.690748    
#> 409: 0.687019    1.046899    3.473883    0.545524    0.030641    0.019505    0.690692    
#> 410: 0.686904    1.046951    3.473824    0.545243    0.030643    0.019503    0.690712    
#> 411: 0.686774    1.046923    3.473799    0.544979    0.030646    0.019501    0.690722    
#> 412: 0.686703    1.046950    3.473718    0.545192    0.030663    0.019485    0.690800    
#> 413: 0.686887    1.047034    3.473627    0.545873    0.030657    0.019475    0.690774    
#> 414: 0.686546    1.047127    3.473580    0.546353    0.030636    0.019478    0.690767    
#> 415: 0.686826    1.047165    3.473575    0.546864    0.030625    0.019481    0.690758    
#> 416: 0.687095    1.047262    3.473624    0.547030    0.030609    0.019480    0.690774    
#> 417: 0.687079    1.047237    3.473624    0.546881    0.030608    0.019472    0.690741    
#> 418: 0.686952    1.047208    3.473686    0.546289    0.030600    0.019477    0.690685    
#> 419: 0.687121    1.047256    3.473725    0.546365    0.030574    0.019481    0.690734    
#> 420: 0.687348    1.047244    3.473768    0.546363    0.030562    0.019482    0.690638    
#> 421: 0.687419    1.047276    3.473819    0.546373    0.030532    0.019493    0.690552    
#> 422: 0.687365    1.047237    3.473808    0.546085    0.030504    0.019494    0.690559    
#> 423: 0.687413    1.047181    3.473781    0.546529    0.030490    0.019480    0.690501    
#> 424: 0.687222    1.047212    3.473701    0.546541    0.030472    0.019485    0.690456    
#> 425: 0.687123    1.047273    3.473603    0.546580    0.030434    0.019504    0.690482    
#> 426: 0.687031    1.047390    3.473540    0.546902    0.030419    0.019514    0.690474    
#> 427: 0.686902    1.047433    3.473529    0.547187    0.030423    0.019500    0.690427    
#> 428: 0.686825    1.047575    3.473498    0.547237    0.030444    0.019488    0.690386    
#> 429: 0.686972    1.047615    3.473478    0.547464    0.030452    0.019483    0.690379    
#> 430: 0.686901    1.047667    3.473478    0.547499    0.030429    0.019464    0.690442    
#> 431: 0.686913    1.047702    3.473455    0.547415    0.030407    0.019447    0.690325    
#> 432: 0.686877    1.047756    3.473450    0.547428    0.030381    0.019440    0.690275    
#> 433: 0.686955    1.047826    3.473487    0.547304    0.030360    0.019437    0.690318    
#> 434: 0.686752    1.047745    3.473523    0.546761    0.030367    0.019413    0.690386    
#> 435: 0.686762    1.047704    3.473525    0.546689    0.030390    0.019392    0.690360    
#> 436: 0.686706    1.047581    3.473593    0.546265    0.030443    0.019378    0.690424    
#> 437: 0.686972    1.047493    3.473605    0.546185    0.030476    0.019368    0.690429    
#> 438: 0.687009    1.047556    3.473617    0.546386    0.030495    0.019363    0.690346    
#> 439: 0.687012    1.047629    3.473596    0.546518    0.030479    0.019361    0.690240    
#> 440: 0.686892    1.047681    3.473599    0.546286    0.030476    0.019348    0.690260    
#> 441: 0.686767    1.047692    3.473593    0.546135    0.030447    0.019345    0.690255    
#> 442: 0.686590    1.047753    3.473608    0.546066    0.030449    0.019335    0.690232    
#> 443: 0.686668    1.047812    3.473573    0.546195    0.030466    0.019323    0.690246    
#> 444: 0.686490    1.047905    3.473469    0.546242    0.030474    0.019310    0.690220    
#> 445: 0.686257    1.047997    3.473390    0.546323    0.030491    0.019321    0.690287    
#> 446: 0.686056    1.048068    3.473315    0.546221    0.030480    0.019319    0.690306    
#> 447: 0.686218    1.048101    3.473305    0.546505    0.030506    0.019320    0.690332    
#> 448: 0.686416    1.048123    3.473322    0.546790    0.030533    0.019326    0.690375    
#> 449: 0.686502    1.048185    3.473396    0.546921    0.030520    0.019330    0.690439    
#> 450: 0.686684    1.048217    3.473395    0.547293    0.030542    0.019328    0.690428    
#> 451: 0.686665    1.048339    3.473332    0.547163    0.030582    0.019325    0.690486    
#> 452: 0.686513    1.048453    3.473255    0.546990    0.030598    0.019323    0.690432    
#> 453: 0.686470    1.048487    3.473208    0.546988    0.030586    0.019328    0.690325    
#> 454: 0.686558    1.048554    3.473207    0.547503    0.030539    0.019341    0.690219    
#> 455: 0.686826    1.048552    3.473247    0.547928    0.030505    0.019356    0.690168    
#> 456: 0.686893    1.048454    3.473261    0.548003    0.030476    0.019352    0.690188    
#> 457: 0.686833    1.048480    3.473269    0.548039    0.030482    0.019339    0.690104    
#> 458: 0.686760    1.048585    3.473260    0.548003    0.030508    0.019329    0.690067    
#> 459: 0.686554    1.048721    3.473225    0.548024    0.030557    0.019318    0.690058    
#> 460: 0.686381    1.048824    3.473174    0.547793    0.030594    0.019308    0.690098    
#> 461: 0.686268    1.048918    3.473155    0.547779    0.030622    0.019308    0.690092    
#> 462: 0.686090    1.049016    3.473109    0.547930    0.030630    0.019297    0.690053    
#> 463: 0.685986    1.049109    3.473088    0.548135    0.030646    0.019291    0.690068    
#> 464: 0.685996    1.049267    3.473057    0.548330    0.030639    0.019298    0.690035    
#> 465: 0.686120    1.049218    3.473029    0.548764    0.030638    0.019289    0.689963    
#> 466: 0.686247    1.049253    3.472966    0.548992    0.030646    0.019278    0.689916    
#> 467: 0.686155    1.049289    3.472958    0.549084    0.030652    0.019261    0.689833    
#> 468: 0.686240    1.049276    3.473004    0.549069    0.030646    0.019262    0.689851    
#> 469: 0.686316    1.049351    3.473013    0.549207    0.030665    0.019259    0.689847    
#> 470: 0.686172    1.049376    3.473001    0.548894    0.030652    0.019266    0.689865    
#> 471: 0.686100    1.049382    3.473001    0.548279    0.030650    0.019264    0.689919    
#> 472: 0.686123    1.049384    3.473047    0.548035    0.030649    0.019265    0.689945    
#> 473: 0.686194    1.049410    3.473056    0.548233    0.030665    0.019267    0.689907    
#> 474: 0.686185    1.049401    3.473061    0.548435    0.030646    0.019285    0.689931    
#> 475: 0.686179    1.049495    3.473032    0.548547    0.030638    0.019304    0.689884    
#> 476: 0.685989    1.049542    3.472964    0.548578    0.030604    0.019310    0.689838    
#> 477: 0.685895    1.049582    3.472974    0.548509    0.030580    0.019333    0.689834    
#> 478: 0.685722    1.049625    3.472949    0.548387    0.030582    0.019359    0.689843    
#> 479: 0.685722    1.049698    3.472935    0.548447    0.030577    0.019370    0.689920    
#> 480: 0.685729    1.049782    3.472907    0.548583    0.030613    0.019367    0.689941    
#> 481: 0.685673    1.049782    3.472897    0.548607    0.030608    0.019372    0.689951    
#> 482: 0.685735    1.049800    3.472887    0.548741    0.030619    0.019372    0.689936    
#> 483: 0.685617    1.049845    3.472903    0.548564    0.030642    0.019380    0.689885    
#> 484: 0.685519    1.049766    3.472955    0.548227    0.030655    0.019400    0.689849    
#> 485: 0.685548    1.049747    3.472980    0.548191    0.030653    0.019420    0.689858    
#> 486: 0.685608    1.049757    3.473015    0.548276    0.030652    0.019428    0.689815    
#> 487: 0.685813    1.049744    3.473078    0.548400    0.030665    0.019434    0.689757    
#> 488: 0.685827    1.049670    3.473091    0.548282    0.030667    0.019434    0.689723    
#> 489: 0.685780    1.049690    3.473075    0.548059    0.030693    0.019428    0.689785    
#> 490: 0.685884    1.049780    3.473107    0.547897    0.030715    0.019418    0.689818    
#> 491: 0.685884    1.049885    3.473130    0.547837    0.030711    0.019417    0.689806    
#> 492: 0.685847    1.049970    3.473106    0.547853    0.030725    0.019428    0.689836    
#> 493: 0.685808    1.050036    3.473132    0.547910    0.030735    0.019439    0.689834    
#> 494: 0.686037    1.050105    3.473138    0.548033    0.030748    0.019448    0.689809    
#> 495: 0.686154    1.050190    3.473127    0.548039    0.030764    0.019452    0.689737    
#> 496: 0.686187    1.050252    3.473109    0.548031    0.030760    0.019458    0.689750    
#> 497: 0.686202    1.050268    3.473082    0.548313    0.030759    0.019463    0.689828    
#> 498: 0.686204    1.050309    3.473041    0.548720    0.030759    0.019471    0.689807    
#> 499: 0.686160    1.050319    3.473013    0.548771    0.030766    0.019478    0.689747    
#> 500: 0.686133    1.050278    3.473000    0.548670    0.030765    0.019465    0.689714    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.317689    0.983108    3.447444    0.392401    0.081860    0.016800    1.742336    
#> 002: 0.429867    1.103968    3.478840    0.372781    0.077767    0.020192    1.144359    
#> 003: 0.605225    1.084093    3.508407    0.354142    0.073878    0.019183    0.863176    
#> 004: 0.637248    1.109563    3.521482    0.336435    0.070184    0.018224    0.797499    
#> 005: 0.690508    1.111832    3.517313    0.372386    0.066675    0.017312    0.722671    
#> 006: 0.612503    1.127712    3.495802    0.353767    0.063341    0.016447    0.684955    
#> 007: 0.561061    1.134906    3.482147    0.365457    0.060174    0.015624    0.695674    
#> 008: 0.568038    1.139232    3.479269    0.383809    0.057166    0.014843    0.691083    
#> 009: 0.584151    1.124285    3.482806    0.370629    0.054307    0.014101    0.694157    
#> 010: 0.569597    1.120471    3.487360    0.390996    0.051592    0.013721    0.708740    
#> 011: 0.647987    1.120630    3.498806    0.435706    0.049012    0.013895    0.691600    
#> 012: 0.623948    1.122806    3.485831    0.421595    0.046562    0.013200    0.681546    
#> 013: 0.566827    1.122919    3.478192    0.400516    0.044234    0.012651    0.701743    
#> 014: 0.631842    1.128457    3.493821    0.419588    0.042022    0.015827    0.715791    
#> 015: 0.677407    1.123672    3.516891    0.398609    0.039921    0.015036    0.691470    
#> 016: 0.619411    1.139528    3.512223    0.446078    0.037925    0.014284    0.701707    
#> 017: 0.649243    1.126850    3.517864    0.423774    0.036029    0.014049    0.698195    
#> 018: 0.628050    1.154805    3.492019    0.402585    0.034227    0.015930    0.686497    
#> 019: 0.554287    1.151457    3.489623    0.407323    0.032516    0.015133    0.682236    
#> 020: 0.596236    1.141169    3.486002    0.454542    0.030890    0.014462    0.679043    
#> 021: 0.614140    1.130367    3.501549    0.431815    0.029346    0.014609    0.671917    
#> 022: 0.653985    1.121927    3.507017    0.491765    0.027878    0.015860    0.668780    
#> 023: 0.745875    1.123457    3.525594    0.526350    0.027458    0.018064    0.675057    
#> 024: 0.718226    1.135548    3.516428    0.549614    0.026085    0.018331    0.658380    
#> 025: 0.695888    1.118155    3.509345    0.527561    0.024781    0.017414    0.683115    
#> 026: 0.685221    1.132995    3.503305    0.501183    0.023542    0.016544    0.692515    
#> 027: 0.601769    1.143450    3.500194    0.476124    0.024126    0.015717    0.714031    
#> 028: 0.685015    1.128543    3.515855    0.452318    0.022920    0.015300    0.681561    
#> 029: 0.708917    1.120947    3.510184    0.489192    0.024018    0.019508    0.690040    
#> 030: 0.691596    1.142912    3.502592    0.464732    0.022817    0.018532    0.691785    
#> 031: 0.670325    1.126186    3.521341    0.541665    0.021784    0.019983    0.680922    
#> 032: 0.634326    1.137756    3.506917    0.549424    0.023115    0.020742    0.672417    
#> 033: 0.659544    1.158505    3.498027    0.544673    0.023550    0.019705    0.665325    
#> 034: 0.690853    1.162217    3.504079    0.563394    0.022373    0.018720    0.690220    
#> 035: 0.630487    1.124667    3.496141    0.535224    0.021254    0.017784    0.675907    
#> 036: 0.617464    1.128393    3.493159    0.508463    0.020192    0.018410    0.687062    
#> 037: 0.635414    1.135389    3.500166    0.483040    0.022902    0.017490    0.698214    
#> 038: 0.673216    1.136050    3.505000    0.458888    0.021757    0.017808    0.688913    
#> 039: 0.677778    1.121964    3.513148    0.446646    0.020669    0.016917    0.680029    
#> 040: 0.625340    1.120189    3.515575    0.424313    0.023040    0.016187    0.689240    
#> 041: 0.599678    1.131052    3.499334    0.447036    0.021888    0.015378    0.672215    
#> 042: 0.623055    1.120011    3.497820    0.457987    0.020794    0.014609    0.673292    
#> 043: 0.556216    1.142646    3.483144    0.435088    0.019754    0.017101    0.671363    
#> 044: 0.583139    1.141166    3.491575    0.413333    0.018898    0.017698    0.687377    
#> 045: 0.595695    1.145532    3.492043    0.436902    0.018110    0.016814    0.679458    
#> 046: 0.625066    1.140334    3.498881    0.415057    0.020238    0.015973    0.666592    
#> 047: 0.619231    1.137748    3.497355    0.399874    0.023208    0.015174    0.659176    
#> 048: 0.639596    1.117844    3.502900    0.453436    0.023930    0.014415    0.674440    
#> 049: 0.664382    1.121525    3.511761    0.430764    0.025213    0.013695    0.683806    
#> 050: 0.694473    1.117982    3.506571    0.445388    0.026632    0.014196    0.678202    
#> 051: 0.624471    1.135277    3.498457    0.423119    0.030299    0.013486    0.693652    
#> 052: 0.620972    1.140791    3.503423    0.401963    0.028941    0.012812    0.677698    
#> 053: 0.634728    1.132327    3.498162    0.422555    0.027494    0.012171    0.673198    
#> 054: 0.609501    1.135096    3.504905    0.401427    0.026119    0.013582    0.684771    
#> 055: 0.605120    1.143529    3.497355    0.381356    0.025094    0.012903    0.683448    
#> 056: 0.640098    1.130919    3.511114    0.381964    0.027058    0.013056    0.687209    
#> 057: 0.651458    1.116004    3.518310    0.457084    0.029167    0.012404    0.694011    
#> 058: 0.614479    1.130248    3.500912    0.434230    0.028920    0.012470    0.696147    
#> 059: 0.626038    1.092336    3.502385    0.412518    0.027474    0.014875    0.708749    
#> 060: 0.659099    1.088825    3.523079    0.391892    0.026100    0.018333    0.714705    
#> 061: 0.719080    1.089187    3.529328    0.480682    0.024795    0.018342    0.707055    
#> 062: 0.686492    1.088735    3.534104    0.474534    0.023556    0.021103    0.723663    
#> 063: 0.678407    1.080412    3.529680    0.450807    0.022378    0.024978    0.719443    
#> 064: 0.689591    1.108579    3.529520    0.428267    0.023142    0.023730    0.686228    
#> 065: 0.668635    1.101812    3.511631    0.458839    0.022277    0.022543    0.682114    
#> 066: 0.690749    1.100483    3.519360    0.449305    0.021163    0.021416    0.673616    
#> 067: 0.627909    1.122333    3.498184    0.433905    0.022313    0.020345    0.670174    
#> 068: 0.636143    1.130200    3.507867    0.452522    0.021197    0.019328    0.686647    
#> 069: 0.643347    1.151995    3.496992    0.429896    0.020630    0.018919    0.700412    
#> 070: 0.633915    1.156440    3.504022    0.501693    0.019599    0.018137    0.682165    
#> 071: 0.627191    1.184708    3.483029    0.476609    0.020203    0.017231    0.694449    
#> 072: 0.583258    1.154460    3.474756    0.452778    0.019193    0.016369    0.672559    
#> 073: 0.621523    1.153280    3.488904    0.456235    0.021914    0.015551    0.684238    
#> 074: 0.594365    1.142412    3.489242    0.449181    0.023685    0.019098    0.687357    
#> 075: 0.621273    1.134304    3.508473    0.455181    0.026346    0.018143    0.670751    
#> 076: 0.642420    1.127929    3.517973    0.432422    0.025029    0.019022    0.678344    
#> 077: 0.716305    1.113634    3.520453    0.410801    0.023778    0.018071    0.695821    
#> 078: 0.710277    1.112425    3.526361    0.432915    0.022589    0.017167    0.695380    
#> 079: 0.639411    1.123324    3.520399    0.411270    0.021701    0.020329    0.718438    
#> 080: 0.678138    1.116671    3.527096    0.392595    0.020616    0.021719    0.729701    
#> 081: 0.663644    1.113079    3.521155    0.384494    0.019586    0.026677    0.695057    
#> 082: 0.679502    1.101759    3.529440    0.439287    0.018606    0.025343    0.689788    
#> 083: 0.679586    1.107549    3.507711    0.587334    0.017676    0.024076    0.690821    
#> 084: 0.654187    1.122799    3.506302    0.557967    0.020346    0.022872    0.676300    
#> 085: 0.645196    1.126130    3.520134    0.530069    0.019329    0.021728    0.690819    
#> 086: 0.697551    1.119219    3.519785    0.503566    0.019177    0.021214    0.685645    
#> 087: 0.668539    1.118924    3.509305    0.478387    0.018218    0.021849    0.701578    
#> 088: 0.619024    1.106692    3.516245    0.476828    0.017307    0.021682    0.705436    
#> 089: 0.641115    1.139692    3.492277    0.461547    0.016442    0.024287    0.676865    
#> 090: 0.620554    1.140374    3.483950    0.450012    0.018911    0.026938    0.705465    
#> 091: 0.646251    1.118689    3.491044    0.434539    0.017965    0.025591    0.693203    
#> 092: 0.612212    1.136603    3.494237    0.414087    0.018222    0.024312    0.676037    
#> 093: 0.595825    1.131188    3.497215    0.445113    0.021431    0.023096    0.669655    
#> 094: 0.649131    1.134429    3.498318    0.446585    0.020360    0.021941    0.685456    
#> 095: 0.626778    1.124050    3.509083    0.443411    0.019342    0.020844    0.687489    
#> 096: 0.563323    1.119684    3.494212    0.474209    0.018375    0.021166    0.663032    
#> 097: 0.604086    1.141576    3.487902    0.452224    0.019205    0.020578    0.659473    
#> 098: 0.639826    1.140126    3.503085    0.441561    0.018244    0.019549    0.679641    
#> 099: 0.616712    1.127189    3.486215    0.419483    0.017332    0.018572    0.698217    
#> 100: 0.589350    1.131998    3.489096    0.398509    0.016466    0.018168    0.696597    
#> 101: 0.556123    1.121773    3.476225    0.415779    0.016861    0.017260    0.692009    
#> 102: 0.566056    1.117918    3.477419    0.429597    0.016018    0.018609    0.688388    
#> 103: 0.628728    1.121832    3.498801    0.414602    0.015217    0.017679    0.680547    
#> 104: 0.638627    1.125373    3.515464    0.442619    0.014456    0.017642    0.712160    
#> 105: 0.665051    1.123284    3.504806    0.475529    0.015674    0.016760    0.709651    
#> 106: 0.637263    1.130283    3.500723    0.451753    0.017509    0.015922    0.701820    
#> 107: 0.641409    1.132060    3.499262    0.429165    0.019146    0.015126    0.685069    
#> 108: 0.616602    1.131871    3.502128    0.407707    0.021771    0.014369    0.687605    
#> 109: 0.646828    1.131391    3.515350    0.442755    0.023426    0.014878    0.665358    
#> 110: 0.647166    1.139025    3.505867    0.420617    0.022254    0.017500    0.667921    
#> 111: 0.655679    1.139234    3.504622    0.399586    0.021142    0.016625    0.662038    
#> 112: 0.637726    1.120693    3.492544    0.415146    0.023106    0.015794    0.664684    
#> 113: 0.635404    1.139977    3.496560    0.466644    0.022621    0.015004    0.661713    
#> 114: 0.674938    1.140887    3.507276    0.443312    0.026509    0.015506    0.676268    
#> 115: 0.653823    1.115785    3.506839    0.421146    0.031180    0.015944    0.682724    
#> 116: 0.630437    1.130100    3.508500    0.400089    0.029621    0.015147    0.678211    
#> 117: 0.642892    1.152397    3.505700    0.380085    0.028206    0.014390    0.681176    
#> 118: 0.673732    1.131864    3.520529    0.385786    0.030745    0.013670    0.689918    
#> 119: 0.666112    1.121198    3.518133    0.437017    0.029381    0.016691    0.689314    
#> 120: 0.619685    1.124517    3.507977    0.415166    0.027912    0.016272    0.681021    
#> 121: 0.632353    1.140527    3.501781    0.394408    0.026516    0.019390    0.682361    
#> 122: 0.638675    1.107418    3.510735    0.494959    0.025393    0.018420    0.688818    
#> 123: 0.700436    1.130532    3.500180    0.595909    0.024263    0.021649    0.697270    
#> 124: 0.661014    1.163228    3.486477    0.569289    0.023050    0.021275    0.679304    
#> 125: 0.648511    1.146685    3.492175    0.540824    0.021897    0.020333    0.680091    
#> 126: 0.613744    1.155296    3.483746    0.513783    0.024911    0.019316    0.691554    
#> 127: 0.661913    1.140636    3.497592    0.488094    0.023665    0.018350    0.696235    
#> 128: 0.628640    1.127532    3.509792    0.463689    0.025931    0.017433    0.689611    
#> 129: 0.669453    1.120486    3.518786    0.440505    0.024802    0.016561    0.682200    
#> 130: 0.710683    1.124160    3.510994    0.472032    0.023562    0.015789    0.681412    
#> 131: 0.688757    1.112332    3.506028    0.448431    0.022384    0.016684    0.672861    
#> 132: 0.632155    1.113914    3.491722    0.426009    0.021265    0.015849    0.687388    
#> 133: 0.641614    1.116146    3.503219    0.465668    0.020202    0.019080    0.665981    
#> 134: 0.689015    1.104597    3.517426    0.509316    0.019192    0.022043    0.664999    
#> 135: 0.675865    1.102068    3.515422    0.493792    0.018232    0.020941    0.666636    
#> 136: 0.653336    1.101689    3.517252    0.519139    0.017320    0.021833    0.668255    
#> 137: 0.725531    1.103167    3.521930    0.493182    0.016454    0.022893    0.687866    
#> 138: 0.649251    1.107238    3.514906    0.468523    0.015632    0.021748    0.684210    
#> 139: 0.648818    1.104081    3.517353    0.453018    0.014850    0.020661    0.683970    
#> 140: 0.639546    1.121217    3.509502    0.430367    0.014108    0.019628    0.695763    
#> 141: 0.621132    1.115259    3.506808    0.408849    0.014903    0.018646    0.686213    
#> 142: 0.653821    1.110461    3.533333    0.388406    0.018531    0.017714    0.689470    
#> 143: 0.647861    1.112151    3.526173    0.368986    0.025419    0.016828    0.691271    
#> 144: 0.679634    1.107477    3.530300    0.350537    0.024481    0.015987    0.680054    
#> 145: 0.640247    1.114500    3.514155    0.397256    0.025725    0.015188    0.678747    
#> 146: 0.620596    1.104384    3.514155    0.406442    0.026740    0.014919    0.695726    
#> 147: 0.609050    1.108508    3.507525    0.408091    0.025403    0.014422    0.689349    
#> 148: 0.616727    1.113831    3.524050    0.387686    0.025703    0.016056    0.688045    
#> 149: 0.616663    1.115164    3.512058    0.368302    0.024418    0.017836    0.694701    
#> 150: 0.647719    1.128734    3.490245    0.360418    0.023197    0.016944    0.691723    
#> 151: 0.590933    1.151857    3.487060    0.373579    0.023872    0.016097    0.690215    
#> 152: 0.603132    1.142442    3.489904    0.436628    0.024414    0.013428    0.680313    
#> 153: 0.629506    1.153982    3.503257    0.443768    0.028131    0.015943    0.678204    
#> 154: 0.681722    1.156026    3.506382    0.461850    0.024518    0.018268    0.701543    
#> 155: 0.657100    1.137052    3.501883    0.471281    0.022556    0.017487    0.675893    
#> 156: 0.655455    1.138001    3.515605    0.444381    0.024438    0.018195    0.695206    
#> 157: 0.664656    1.120903    3.514572    0.474399    0.020599    0.019922    0.683594    
#> 158: 0.664021    1.142347    3.502988    0.435465    0.021545    0.020578    0.684303    
#> 159: 0.598493    1.156356    3.501955    0.417685    0.023214    0.017306    0.681597    
#> 160: 0.670344    1.127945    3.513128    0.445276    0.019371    0.019315    0.688390    
#> 161: 0.627179    1.138144    3.505097    0.389037    0.018618    0.020682    0.698253    
#> 162: 0.630467    1.151436    3.494229    0.402383    0.016154    0.022103    0.702080    
#> 163: 0.631926    1.140565    3.484657    0.420973    0.014150    0.021729    0.680827    
#> 164: 0.620497    1.151795    3.490683    0.436659    0.018261    0.022224    0.681024    
#> 165: 0.608001    1.151790    3.499262    0.457544    0.023366    0.015919    0.673815    
#> 166: 0.643356    1.173340    3.496368    0.481820    0.020814    0.013862    0.678133    
#> 167: 0.642783    1.174574    3.501410    0.507346    0.024424    0.015563    0.685021    
#> 168: 0.681899    1.173842    3.503926    0.491586    0.021943    0.017251    0.680333    
#> 169: 0.632533    1.177173    3.491884    0.443334    0.020116    0.016406    0.683255    
#> 170: 0.635402    1.159563    3.502897    0.408281    0.021965    0.017543    0.666974    
#> 171: 0.635903    1.141079    3.502126    0.388568    0.021304    0.015779    0.668506    
#> 172: 0.617549    1.145172    3.501021    0.435438    0.017299    0.016951    0.686715    
#> 173: 0.599273    1.156606    3.481590    0.410676    0.018255    0.015329    0.689004    
#> 174: 0.618797    1.165224    3.492012    0.345284    0.021369    0.017827    0.690885    
#> 175: 0.622189    1.149044    3.499843    0.397012    0.025181    0.019606    0.680445    
#> 176: 0.658581    1.144056    3.511392    0.422884    0.024391    0.021173    0.671061    
#> 177: 0.643104    1.144482    3.509152    0.404515    0.021248    0.017973    0.680263    
#> 178: 0.653976    1.137623    3.501884    0.393128    0.024772    0.013247    0.690794    
#> 179: 0.655771    1.140483    3.508817    0.445313    0.023580    0.013354    0.681141    
#> 180: 0.650388    1.129803    3.508478    0.390287    0.022431    0.013124    0.676488    
#> 181: 0.663606    1.117214    3.486665    0.465236    0.019801    0.011759    0.680934    
#> 182: 0.608281    1.141519    3.475829    0.434526    0.028387    0.009078    0.691566    
#> 183: 0.604905    1.150246    3.478939    0.337414    0.030191    0.007597    0.691512    
#> 184: 0.607792    1.134647    3.484660    0.362010    0.028060    0.009482    0.694109    
#> 185: 0.576666    1.164001    3.488324    0.326671    0.036342    0.011369    0.696480    
#> 186: 0.587029    1.162965    3.486927    0.337984    0.039158    0.011184    0.691242    
#> 187: 0.587232    1.137826    3.502720    0.345053    0.030255    0.012758    0.688120    
#> 188: 0.597210    1.137509    3.501833    0.337633    0.029651    0.013824    0.696588    
#> 189: 0.640238    1.152273    3.510923    0.378412    0.022707    0.014614    0.685389    
#> 190: 0.642938    1.145125    3.509426    0.357918    0.020191    0.011934    0.680477    
#> 191: 0.622195    1.137189    3.493955    0.448070    0.014614    0.011985    0.684138    
#> 192: 0.620768    1.145381    3.491977    0.482469    0.021840    0.013523    0.688543    
#> 193: 0.641437    1.155964    3.492307    0.455164    0.023149    0.014232    0.681362    
#> 194: 0.596101    1.143943    3.479392    0.426825    0.018874    0.014962    0.702223    
#> 195: 0.572633    1.149398    3.479706    0.361854    0.014415    0.015118    0.697750    
#> 196: 0.600808    1.151176    3.496980    0.383038    0.021722    0.014743    0.684231    
#> 197: 0.570552    1.154431    3.503656    0.360600    0.017084    0.017221    0.706987    
#> 198: 0.603224    1.149861    3.492470    0.322712    0.023540    0.017235    0.699022    
#> 199: 0.613304    1.136579    3.500689    0.377709    0.019059    0.016261    0.680271    
#> 200: 0.606866    1.136818    3.507516    0.343975    0.018673    0.016401    0.695482    
#> 201: 0.610154    1.130312    3.508927    0.354709    0.017628    0.015399    0.695156    
#> 202: 0.619784    1.130649    3.508983    0.390930    0.017662    0.016330    0.697844    
#> 203: 0.637071    1.128533    3.509116    0.399778    0.018314    0.016698    0.695469    
#> 204: 0.640302    1.123273    3.510389    0.418594    0.018942    0.016411    0.695280    
#> 205: 0.638284    1.126759    3.510640    0.421806    0.019116    0.016839    0.695638    
#> 206: 0.643951    1.129714    3.513313    0.432720    0.018574    0.016862    0.697626    
#> 207: 0.644010    1.129015    3.511669    0.428275    0.018928    0.016647    0.695273    
#> 208: 0.645355    1.127525    3.511820    0.425569    0.019299    0.016690    0.693241    
#> 209: 0.647522    1.125825    3.511396    0.426023    0.019353    0.016626    0.690794    
#> 210: 0.647575    1.125075    3.512028    0.422572    0.019194    0.016447    0.690002    
#> 211: 0.652563    1.125416    3.513679    0.417796    0.019158    0.016108    0.689569    
#> 212: 0.657055    1.124564    3.514425    0.416118    0.018960    0.016024    0.689687    
#> 213: 0.660844    1.122223    3.515489    0.419626    0.019142    0.015735    0.691094    
#> 214: 0.664349    1.120606    3.516001    0.421327    0.019488    0.015646    0.691424    
#> 215: 0.665647    1.119212    3.517328    0.420879    0.019705    0.015747    0.691377    
#> 216: 0.670394    1.116603    3.518422    0.424623    0.019633    0.015759    0.691957    
#> 217: 0.672523    1.115245    3.519352    0.425696    0.019167    0.015874    0.691970    
#> 218: 0.672293    1.115520    3.518646    0.428963    0.019433    0.015936    0.692253    
#> 219: 0.670160    1.115756    3.517214    0.429895    0.019592    0.016124    0.692102    
#> 220: 0.668479    1.115689    3.516431    0.432382    0.019803    0.016371    0.692338    
#> 221: 0.667683    1.115183    3.516036    0.431879    0.019768    0.016515    0.692033    
#> 222: 0.667573    1.114913    3.515931    0.430579    0.019455    0.016722    0.692038    
#> 223: 0.669445    1.114828    3.515931    0.432442    0.019231    0.016933    0.691536    
#> 224: 0.671540    1.115036    3.516313    0.433241    0.018955    0.017061    0.691015    
#> 225: 0.671009    1.114771    3.516850    0.431402    0.018981    0.016992    0.691310    
#> 226: 0.670231    1.114247    3.516384    0.430906    0.018862    0.017016    0.691092    
#> 227: 0.669545    1.114043    3.516613    0.428365    0.018749    0.016935    0.690372    
#> 228: 0.669461    1.114030    3.516260    0.427866    0.018588    0.016965    0.690030    
#> 229: 0.667168    1.114108    3.515568    0.427858    0.018515    0.016993    0.689477    
#> 230: 0.666449    1.114445    3.514874    0.429394    0.018523    0.017010    0.688927    
#> 231: 0.666618    1.115078    3.514584    0.429312    0.018565    0.017014    0.688132    
#> 232: 0.666263    1.115481    3.514251    0.432624    0.018734    0.016993    0.687176    
#> 233: 0.666397    1.114991    3.514118    0.435316    0.018846    0.017133    0.686874    
#> 234: 0.666284    1.114647    3.514143    0.435969    0.018831    0.017161    0.686531    
#> 235: 0.666336    1.114571    3.514166    0.433907    0.018918    0.017149    0.686351    
#> 236: 0.665562    1.115037    3.513646    0.433792    0.019017    0.017102    0.686223    
#> 237: 0.665349    1.114949    3.513564    0.435879    0.019147    0.017188    0.686451    
#> 238: 0.665052    1.115310    3.513509    0.436755    0.019231    0.017230    0.686762    
#> 239: 0.662970    1.116097    3.513241    0.435103    0.019245    0.017162    0.687242    
#> 240: 0.661482    1.116217    3.513254    0.434262    0.019186    0.017116    0.687490    
#> 241: 0.661775    1.116160    3.513404    0.432617    0.019235    0.017198    0.687915    
#> 242: 0.661171    1.116171    3.512925    0.431957    0.019387    0.017258    0.688256    
#> 243: 0.660411    1.116632    3.512757    0.430976    0.019597    0.017298    0.688630    
#> 244: 0.660041    1.116639    3.513024    0.431289    0.019713    0.017345    0.689103    
#> 245: 0.660157    1.116294    3.513173    0.429958    0.019685    0.017358    0.689570    
#> 246: 0.659362    1.115840    3.513003    0.428865    0.019647    0.017394    0.690106    
#> 247: 0.658875    1.115477    3.513004    0.428111    0.019684    0.017450    0.690009    
#> 248: 0.659436    1.115533    3.513014    0.428739    0.019648    0.017434    0.689702    
#> 249: 0.658344    1.115660    3.512896    0.428311    0.019704    0.017373    0.689629    
#> 250: 0.658287    1.115934    3.512882    0.427156    0.019680    0.017311    0.689862    
#> 251: 0.658565    1.116356    3.513080    0.426955    0.019751    0.017244    0.689710    
#> 252: 0.659145    1.116537    3.513260    0.427179    0.019768    0.017178    0.689673    
#> 253: 0.659290    1.116785    3.513421    0.427198    0.019741    0.017209    0.689698    
#> 254: 0.659276    1.117160    3.513434    0.427789    0.019644    0.017249    0.689701    
#> 255: 0.660090    1.117029    3.513719    0.427567    0.019612    0.017325    0.689577    
#> 256: 0.660336    1.116789    3.513733    0.427618    0.019597    0.017403    0.689298    
#> 257: 0.660162    1.116444    3.513674    0.427212    0.019507    0.017394    0.689510    
#> 258: 0.660144    1.116187    3.513912    0.427416    0.019532    0.017417    0.689489    
#> 259: 0.659763    1.116346    3.513750    0.427786    0.019563    0.017425    0.689521    
#> 260: 0.659659    1.116622    3.513708    0.427793    0.019506    0.017483    0.689187    
#> 261: 0.660201    1.116657    3.513748    0.428000    0.019460    0.017540    0.689126    
#> 262: 0.659834    1.116800    3.513652    0.427385    0.019449    0.017547    0.689199    
#> 263: 0.658814    1.117066    3.513555    0.426628    0.019416    0.017559    0.689457    
#> 264: 0.657957    1.117236    3.513335    0.426266    0.019461    0.017530    0.689676    
#> 265: 0.657755    1.117465    3.513216    0.426620    0.019526    0.017475    0.689724    
#> 266: 0.657825    1.117739    3.513337    0.426425    0.019546    0.017425    0.689717    
#> 267: 0.657905    1.117681    3.513525    0.426877    0.019514    0.017382    0.689868    
#> 268: 0.657949    1.117603    3.513409    0.427362    0.019532    0.017360    0.689763    
#> 269: 0.658593    1.117504    3.513353    0.428540    0.019582    0.017293    0.689767    
#> 270: 0.658723    1.117635    3.513187    0.429292    0.019621    0.017234    0.689603    
#> 271: 0.658776    1.117700    3.513003    0.429458    0.019577    0.017182    0.689671    
#> 272: 0.658525    1.117833    3.512954    0.428495    0.019568    0.017166    0.690036    
#> 273: 0.657954    1.118114    3.512845    0.428292    0.019662    0.017103    0.690184    
#> 274: 0.657453    1.118455    3.512705    0.426754    0.019729    0.017026    0.689980    
#> 275: 0.656922    1.118573    3.512507    0.426450    0.019739    0.016971    0.689723    
#> 276: 0.656510    1.118687    3.512670    0.426277    0.019663    0.016988    0.689676    
#> 277: 0.656140    1.118725    3.512887    0.426378    0.019607    0.017046    0.689588    
#> 278: 0.655813    1.118814    3.512927    0.426764    0.019571    0.017060    0.689708    
#> 279: 0.655773    1.118814    3.512960    0.427517    0.019509    0.017141    0.689915    
#> 280: 0.655457    1.118876    3.512866    0.427419    0.019494    0.017175    0.689713    
#> 281: 0.654275    1.119078    3.512643    0.427803    0.019455    0.017182    0.689783    
#> 282: 0.653960    1.119440    3.512572    0.426859    0.019453    0.017181    0.689871    
#> 283: 0.653657    1.119664    3.512629    0.426596    0.019477    0.017167    0.690228    
#> 284: 0.653619    1.119559    3.512605    0.426905    0.019543    0.017161    0.690174    
#> 285: 0.653871    1.119437    3.512611    0.426370    0.019632    0.017181    0.690370    
#> 286: 0.653761    1.119476    3.512541    0.426563    0.019618    0.017212    0.690465    
#> 287: 0.653546    1.119662    3.512412    0.426163    0.019597    0.017271    0.690524    
#> 288: 0.653677    1.119619    3.512416    0.425443    0.019577    0.017287    0.690510    
#> 289: 0.653855    1.119616    3.512417    0.424735    0.019554    0.017265    0.690617    
#> 290: 0.653862    1.119551    3.512454    0.424490    0.019586    0.017290    0.690717    
#> 291: 0.653889    1.119710    3.512495    0.424620    0.019639    0.017292    0.690735    
#> 292: 0.654349    1.119782    3.512545    0.425040    0.019658    0.017279    0.690799    
#> 293: 0.654478    1.119639    3.512528    0.425323    0.019653    0.017261    0.690761    
#> 294: 0.654612    1.119815    3.512422    0.425212    0.019653    0.017217    0.690608    
#> 295: 0.654308    1.119656    3.512405    0.425076    0.019666    0.017184    0.690441    
#> 296: 0.654512    1.119499    3.512483    0.424673    0.019701    0.017152    0.690523    
#> 297: 0.654557    1.119461    3.512490    0.424377    0.019709    0.017178    0.690533    
#> 298: 0.654571    1.119393    3.512521    0.424575    0.019685    0.017177    0.690408    
#> 299: 0.654760    1.119508    3.512461    0.424602    0.019695    0.017156    0.690272    
#> 300: 0.654819    1.119533    3.512565    0.424351    0.019680    0.017144    0.690223    
#> 301: 0.654872    1.119383    3.512543    0.424247    0.019653    0.017142    0.690316    
#> 302: 0.654647    1.119383    3.512468    0.424009    0.019635    0.017128    0.690298    
#> 303: 0.654280    1.119465    3.512325    0.423110    0.019646    0.017126    0.690127    
#> 304: 0.654240    1.119632    3.512175    0.422928    0.019675    0.017124    0.690074    
#> 305: 0.653887    1.119492    3.512087    0.422521    0.019689    0.017154    0.690002    
#> 306: 0.653720    1.119362    3.511983    0.422718    0.019650    0.017147    0.689859    
#> 307: 0.653808    1.119260    3.511920    0.423005    0.019650    0.017128    0.690027    
#> 308: 0.653854    1.119160    3.511857    0.424097    0.019656    0.017122    0.690066    
#> 309: 0.653998    1.118902    3.511872    0.424760    0.019637    0.017126    0.690030    
#> 310: 0.654361    1.118936    3.511736    0.425007    0.019659    0.017109    0.690094    
#> 311: 0.654455    1.119018    3.511659    0.425485    0.019658    0.017101    0.689980    
#> 312: 0.653987    1.119028    3.511458    0.426011    0.019649    0.017100    0.689982    
#> 313: 0.653829    1.118932    3.511267    0.426287    0.019636    0.017141    0.690028    
#> 314: 0.653525    1.118884    3.511140    0.426205    0.019602    0.017173    0.690055    
#> 315: 0.653402    1.118876    3.511094    0.426415    0.019544    0.017208    0.689927    
#> 316: 0.653681    1.118909    3.511097    0.426526    0.019506    0.017226    0.689868    
#> 317: 0.654388    1.118884    3.511245    0.427526    0.019535    0.017246    0.689740    
#> 318: 0.654490    1.118849    3.511146    0.427708    0.019551    0.017222    0.689719    
#> 319: 0.654632    1.118714    3.511192    0.427981    0.019543    0.017201    0.689848    
#> 320: 0.654334    1.118749    3.511078    0.427579    0.019539    0.017177    0.689941    
#> 321: 0.654096    1.118955    3.510935    0.426795    0.019547    0.017171    0.690135    
#> 322: 0.653975    1.119030    3.510780    0.426821    0.019538    0.017170    0.690011    
#> 323: 0.653413    1.119100    3.510599    0.426686    0.019512    0.017197    0.690010    
#> 324: 0.653143    1.119292    3.510501    0.427111    0.019552    0.017209    0.689866    
#> 325: 0.652966    1.119478    3.510359    0.427664    0.019537    0.017204    0.689872    
#> 326: 0.652890    1.119351    3.510295    0.427508    0.019538    0.017221    0.689958    
#> 327: 0.653052    1.119357    3.510410    0.427658    0.019525    0.017233    0.690094    
#> 328: 0.653478    1.119446    3.510434    0.427933    0.019513    0.017236    0.690068    
#> 329: 0.653676    1.119447    3.510459    0.427921    0.019513    0.017228    0.689958    
#> 330: 0.653663    1.119444    3.510434    0.428679    0.019496    0.017207    0.689908    
#> 331: 0.653985    1.119607    3.510452    0.429611    0.019524    0.017191    0.689860    
#> 332: 0.654230    1.119555    3.510520    0.429767    0.019535    0.017170    0.689837    
#> 333: 0.654423    1.119553    3.510479    0.429944    0.019572    0.017140    0.689786    
#> 334: 0.654579    1.119591    3.510363    0.430846    0.019635    0.017116    0.689626    
#> 335: 0.654114    1.119643    3.510220    0.430753    0.019689    0.017102    0.689554    
#> 336: 0.653750    1.119800    3.510101    0.431102    0.019769    0.017104    0.689492    
#> 337: 0.653576    1.119974    3.509960    0.431356    0.019812    0.017109    0.689515    
#> 338: 0.653511    1.120298    3.509936    0.432286    0.019843    0.017117    0.689524    
#> 339: 0.653436    1.120512    3.509888    0.432797    0.019871    0.017123    0.689458    
#> 340: 0.653402    1.120511    3.509899    0.432745    0.019878    0.017141    0.689536    
#> 341: 0.653504    1.120491    3.509946    0.432750    0.019877    0.017158    0.689567    
#> 342: 0.653318    1.120404    3.509960    0.432534    0.019855    0.017167    0.689618    
#> 343: 0.652983    1.120324    3.509951    0.432049    0.019844    0.017187    0.689612    
#> 344: 0.652837    1.120207    3.509929    0.431699    0.019828    0.017228    0.689614    
#> 345: 0.652782    1.120127    3.509953    0.431633    0.019806    0.017289    0.689563    
#> 346: 0.652706    1.120211    3.509824    0.432031    0.019793    0.017275    0.689508    
#> 347: 0.652618    1.120143    3.509695    0.432220    0.019794    0.017269    0.689562    
#> 348: 0.652374    1.120212    3.509547    0.432332    0.019772    0.017261    0.689686    
#> 349: 0.652149    1.120177    3.509496    0.432543    0.019765    0.017248    0.689686    
#> 350: 0.651925    1.120202    3.509383    0.432829    0.019766    0.017231    0.689666    
#> 351: 0.651952    1.120189    3.509379    0.432701    0.019758    0.017232    0.689609    
#> 352: 0.651689    1.120120    3.509423    0.432856    0.019759    0.017286    0.689692    
#> 353: 0.652075    1.120029    3.509465    0.433399    0.019762    0.017296    0.689743    
#> 354: 0.652190    1.120051    3.509426    0.433385    0.019799    0.017308    0.689765    
#> 355: 0.652734    1.119916    3.509438    0.433870    0.019822    0.017333    0.689714    
#> 356: 0.652750    1.119866    3.509503    0.433875    0.019825    0.017343    0.689823    
#> 357: 0.652830    1.119878    3.509503    0.433635    0.019780    0.017326    0.689945    
#> 358: 0.652666    1.119884    3.509521    0.433957    0.019791    0.017318    0.689882    
#> 359: 0.652266    1.120031    3.509464    0.433942    0.019797    0.017316    0.689787    
#> 360: 0.652234    1.120152    3.509339    0.433943    0.019784    0.017326    0.689688    
#> 361: 0.651802    1.120216    3.509256    0.433496    0.019790    0.017328    0.689598    
#> 362: 0.651770    1.120279    3.509173    0.433444    0.019822    0.017331    0.689511    
#> 363: 0.651761    1.120293    3.509165    0.433633    0.019813    0.017350    0.689314    
#> 364: 0.652066    1.120382    3.509191    0.433688    0.019823    0.017379    0.689268    
#> 365: 0.651909    1.120343    3.509205    0.433343    0.019865    0.017400    0.689308    
#> 366: 0.651519    1.120455    3.509041    0.432993    0.019872    0.017397    0.689404    
#> 367: 0.651626    1.120386    3.508935    0.433102    0.019857    0.017400    0.689418    
#> 368: 0.651532    1.120488    3.508797    0.432964    0.019828    0.017383    0.689331    
#> 369: 0.651268    1.120522    3.508753    0.432713    0.019807    0.017389    0.689314    
#> 370: 0.650905    1.120707    3.508648    0.432330    0.019827    0.017410    0.689234    
#> 371: 0.650571    1.120769    3.508526    0.432035    0.019823    0.017414    0.689154    
#> 372: 0.650306    1.120940    3.508392    0.432093    0.019826    0.017422    0.689138    
#> 373: 0.650056    1.121110    3.508249    0.432370    0.019831    0.017427    0.689220    
#> 374: 0.650166    1.121146    3.508194    0.432408    0.019816    0.017420    0.689188    
#> 375: 0.650350    1.121132    3.508244    0.432981    0.019828    0.017414    0.689072    
#> 376: 0.650428    1.121104    3.508269    0.433016    0.019810    0.017402    0.688977    
#> 377: 0.650552    1.121176    3.508310    0.432848    0.019821    0.017388    0.689008    
#> 378: 0.650324    1.121200    3.508223    0.432857    0.019802    0.017385    0.689070    
#> 379: 0.650207    1.121112    3.508195    0.432867    0.019785    0.017371    0.689147    
#> 380: 0.649981    1.121072    3.508164    0.432658    0.019789    0.017355    0.689157    
#> 381: 0.649866    1.121054    3.508124    0.432596    0.019754    0.017368    0.689152    
#> 382: 0.649928    1.121102    3.508112    0.432742    0.019720    0.017370    0.689048    
#> 383: 0.649955    1.121071    3.508099    0.433090    0.019705    0.017368    0.688869    
#> 384: 0.649776    1.121113    3.508082    0.433404    0.019685    0.017359    0.688776    
#> 385: 0.649927    1.121168    3.508058    0.433678    0.019685    0.017343    0.688702    
#> 386: 0.649839    1.121356    3.508048    0.433349    0.019715    0.017339    0.688701    
#> 387: 0.650003    1.121432    3.508098    0.433035    0.019707    0.017346    0.688698    
#> 388: 0.650183    1.121451    3.508160    0.432871    0.019688    0.017324    0.688702    
#> 389: 0.650281    1.121263    3.508222    0.432505    0.019696    0.017317    0.688785    
#> 390: 0.650164    1.121247    3.508145    0.432378    0.019679    0.017327    0.688789    
#> 391: 0.650375    1.121218    3.508117    0.432537    0.019674    0.017307    0.688738    
#> 392: 0.650488    1.121238    3.508151    0.432895    0.019663    0.017304    0.688764    
#> 393: 0.650437    1.121281    3.508133    0.432963    0.019680    0.017297    0.688755    
#> 394: 0.650370    1.121306    3.508050    0.433225    0.019667    0.017294    0.688822    
#> 395: 0.650666    1.121395    3.508034    0.433520    0.019665    0.017290    0.688836    
#> 396: 0.650881    1.121446    3.508025    0.433647    0.019688    0.017280    0.688799    
#> 397: 0.650708    1.121429    3.508053    0.433382    0.019697    0.017280    0.688863    
#> 398: 0.650833    1.121362    3.508121    0.433097    0.019697    0.017276    0.688848    
#> 399: 0.650825    1.121396    3.508207    0.432646    0.019677    0.017274    0.688844    
#> 400: 0.650850    1.121432    3.508260    0.432593    0.019652    0.017272    0.688854    
#> 401: 0.650844    1.121545    3.508222    0.432161    0.019644    0.017263    0.688883    
#> 402: 0.650778    1.121608    3.508164    0.432085    0.019638    0.017250    0.688913    
#> 403: 0.650829    1.121630    3.508093    0.432007    0.019648    0.017230    0.688923    
#> 404: 0.650934    1.121703    3.508027    0.432225    0.019671    0.017223    0.688925    
#> 405: 0.650735    1.121778    3.507989    0.432095    0.019705    0.017203    0.688987    
#> 406: 0.650714    1.121800    3.507974    0.432186    0.019726    0.017212    0.689074    
#> 407: 0.650531    1.121853    3.507913    0.432471    0.019735    0.017222    0.689109    
#> 408: 0.650470    1.121982    3.507857    0.432309    0.019754    0.017211    0.689183    
#> 409: 0.650364    1.122080    3.507759    0.432396    0.019743    0.017211    0.689117    
#> 410: 0.650238    1.122122    3.507690    0.432198    0.019727    0.017234    0.688971    
#> 411: 0.650317    1.122042    3.507710    0.432206    0.019711    0.017230    0.688953    
#> 412: 0.650486    1.122028    3.507705    0.432225    0.019689    0.017232    0.688967    
#> 413: 0.650618    1.122035    3.507688    0.432172    0.019670    0.017224    0.689006    
#> 414: 0.650411    1.122040    3.507684    0.432227    0.019641    0.017247    0.689011    
#> 415: 0.650480    1.122032    3.507698    0.432141    0.019621    0.017259    0.689043    
#> 416: 0.650615    1.122013    3.507726    0.431943    0.019601    0.017263    0.689128    
#> 417: 0.650699    1.121947    3.507725    0.431830    0.019575    0.017280    0.689091    
#> 418: 0.650590    1.121958    3.507726    0.431660    0.019559    0.017285    0.689002    
#> 419: 0.650657    1.121987    3.507746    0.431698    0.019533    0.017294    0.688932    
#> 420: 0.650853    1.122020    3.507747    0.431888    0.019515    0.017297    0.688819    
#> 421: 0.650906    1.122019    3.507788    0.431885    0.019497    0.017308    0.688798    
#> 422: 0.650960    1.122002    3.507789    0.431996    0.019490    0.017308    0.688866    
#> 423: 0.651105    1.122028    3.507777    0.432199    0.019484    0.017316    0.688808    
#> 424: 0.650909    1.122040    3.507672    0.432228    0.019487    0.017311    0.688723    
#> 425: 0.650852    1.122112    3.507605    0.432363    0.019493    0.017309    0.688732    
#> 426: 0.651055    1.122143    3.507656    0.432567    0.019496    0.017305    0.688710    
#> 427: 0.651275    1.122142    3.507725    0.432976    0.019490    0.017314    0.688656    
#> 428: 0.651531    1.122139    3.507772    0.433481    0.019485    0.017331    0.688640    
#> 429: 0.651775    1.122098    3.507829    0.433772    0.019468    0.017340    0.688684    
#> 430: 0.651894    1.122060    3.507889    0.433856    0.019462    0.017353    0.688681    
#> 431: 0.651940    1.122075    3.507903    0.433872    0.019443    0.017362    0.688624    
#> 432: 0.651876    1.122109    3.507898    0.434038    0.019435    0.017381    0.688659    
#> 433: 0.651730    1.122134    3.507923    0.433950    0.019445    0.017391    0.688691    
#> 434: 0.651497    1.122138    3.507908    0.433896    0.019439    0.017407    0.688654    
#> 435: 0.651480    1.122149    3.507891    0.433882    0.019433    0.017418    0.688590    
#> 436: 0.651401    1.122088    3.507920    0.433575    0.019419    0.017416    0.688594    
#> 437: 0.651483    1.122095    3.507928    0.433861    0.019405    0.017416    0.688666    
#> 438: 0.651438    1.122223    3.507911    0.433742    0.019397    0.017401    0.688663    
#> 439: 0.651444    1.122286    3.507863    0.433885    0.019381    0.017400    0.688629    
#> 440: 0.651323    1.122356    3.507862    0.433639    0.019370    0.017410    0.688690    
#> 441: 0.651204    1.122333    3.507839    0.433448    0.019370    0.017419    0.688645    
#> 442: 0.650930    1.122337    3.507817    0.433421    0.019348    0.017433    0.688546    
#> 443: 0.650868    1.122350    3.507801    0.433287    0.019358    0.017430    0.688573    
#> 444: 0.650897    1.122364    3.507761    0.433506    0.019380    0.017419    0.688496    
#> 445: 0.650879    1.122359    3.507740    0.433534    0.019398    0.017429    0.688517    
#> 446: 0.650676    1.122406    3.507704    0.433338    0.019411    0.017423    0.688537    
#> 447: 0.650844    1.122424    3.507721    0.433422    0.019426    0.017411    0.688492    
#> 448: 0.650893    1.122418    3.507761    0.433309    0.019432    0.017403    0.688518    
#> 449: 0.650907    1.122476    3.507869    0.433119    0.019466    0.017402    0.688553    
#> 450: 0.650885    1.122499    3.507895    0.432981    0.019485    0.017389    0.688582    
#> 451: 0.650931    1.122559    3.507902    0.432772    0.019507    0.017391    0.688607    
#> 452: 0.650829    1.122601    3.507893    0.432523    0.019514    0.017385    0.688604    
#> 453: 0.650881    1.122673    3.507873    0.432824    0.019516    0.017365    0.688586    
#> 454: 0.650965    1.122798    3.507821    0.433634    0.019528    0.017350    0.688557    
#> 455: 0.650945    1.122888    3.507761    0.434358    0.019545    0.017340    0.688517    
#> 456: 0.650933    1.122879    3.507718    0.434641    0.019561    0.017324    0.688517    
#> 457: 0.650947    1.122860    3.507767    0.434664    0.019552    0.017318    0.688512    
#> 458: 0.650930    1.122931    3.507819    0.434657    0.019544    0.017316    0.688496    
#> 459: 0.650803    1.123001    3.507850    0.434482    0.019544    0.017315    0.688435    
#> 460: 0.650625    1.123026    3.507787    0.434537    0.019537    0.017332    0.688386    
#> 461: 0.650416    1.123068    3.507745    0.434747    0.019540    0.017332    0.688360    
#> 462: 0.650286    1.123139    3.507744    0.434834    0.019534    0.017325    0.688353    
#> 463: 0.650293    1.123164    3.507773    0.434771    0.019521    0.017326    0.688400    
#> 464: 0.650430    1.123185    3.507759    0.434925    0.019512    0.017317    0.688379    
#> 465: 0.650480    1.123104    3.507754    0.435086    0.019528    0.017310    0.688368    
#> 466: 0.650343    1.123132    3.507669    0.434948    0.019542    0.017310    0.688364    
#> 467: 0.650300    1.123181    3.507639    0.434986    0.019542    0.017302    0.688323    
#> 468: 0.650315    1.123211    3.507684    0.434984    0.019548    0.017307    0.688314    
#> 469: 0.650483    1.123238    3.507749    0.435010    0.019578    0.017307    0.688409    
#> 470: 0.650344    1.123262    3.507733    0.434922    0.019607    0.017297    0.688467    
#> 471: 0.650244    1.123214    3.507721    0.434641    0.019614    0.017283    0.688509    
#> 472: 0.650276    1.123214    3.507733    0.434596    0.019627    0.017275    0.688476    
#> 473: 0.650311    1.123261    3.507736    0.434547    0.019638    0.017276    0.688432    
#> 474: 0.650232    1.123276    3.507729    0.434393    0.019641    0.017272    0.688475    
#> 475: 0.650343    1.123308    3.507727    0.434463    0.019654    0.017274    0.688486    
#> 476: 0.650217    1.123299    3.507697    0.434808    0.019661    0.017273    0.688496    
#> 477: 0.650225    1.123309    3.507719    0.435051    0.019657    0.017275    0.688408    
#> 478: 0.650190    1.123344    3.507706    0.435228    0.019685    0.017278    0.688344    
#> 479: 0.650332    1.123344    3.507732    0.435408    0.019722    0.017275    0.688293    
#> 480: 0.650287    1.123398    3.507687    0.435451    0.019734    0.017265    0.688296    
#> 481: 0.650229    1.123418    3.507621    0.435603    0.019730    0.017257    0.688289    
#> 482: 0.650252    1.123419    3.507557    0.436073    0.019737    0.017261    0.688327    
#> 483: 0.650174    1.123448    3.507538    0.436171    0.019718    0.017261    0.688375    
#> 484: 0.650170    1.123408    3.507521    0.436217    0.019708    0.017268    0.688395    
#> 485: 0.650266    1.123439    3.507536    0.436555    0.019704    0.017272    0.688402    
#> 486: 0.650343    1.123465    3.507525    0.437047    0.019692    0.017280    0.688325    
#> 487: 0.650577    1.123472    3.507542    0.437574    0.019676    0.017289    0.688251    
#> 488: 0.650621    1.123406    3.507607    0.437621    0.019672    0.017298    0.688160    
#> 489: 0.650766    1.123357    3.507629    0.437750    0.019665    0.017319    0.688149    
#> 490: 0.650747    1.123423    3.507636    0.437541    0.019661    0.017330    0.688127    
#> 491: 0.650726    1.123514    3.507657    0.437396    0.019682    0.017329    0.688123    
#> 492: 0.650660    1.123623    3.507628    0.437441    0.019696    0.017325    0.688141    
#> 493: 0.650598    1.123651    3.507627    0.437444    0.019714    0.017317    0.688206    
#> 494: 0.650790    1.123690    3.507628    0.437343    0.019698    0.017313    0.688245    
#> 495: 0.650923    1.123737    3.507681    0.437227    0.019697    0.017307    0.688268    
#> 496: 0.651027    1.123810    3.507691    0.436977    0.019701    0.017317    0.688300    
#> 497: 0.651071    1.123809    3.507693    0.436857    0.019695    0.017314    0.688285    
#> 498: 0.650968    1.123835    3.507637    0.436813    0.019679    0.017302    0.688229    
#> 499: 0.650926    1.123848    3.507599    0.436859    0.019673    0.017295    0.688176    
#> 500: 0.650851    1.123848    3.507574    0.436725    0.019681    0.017294    0.688147    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.323887    0.974478    3.446419    0.392401    0.089790    0.016800    1.692721    
#> 002: 0.378024    0.943263    3.474100    0.372781    0.085301    0.015960    1.123314    
#> 003: 0.453482    0.889668    3.473913    0.354142    0.081036    0.015162    0.978870    
#> 004: 0.371120    0.922584    3.456659    0.336435    0.076984    0.014404    0.968485    
#> 005: 0.377567    0.956448    3.439399    0.319613    0.073135    0.013684    0.903287    
#> 006: 0.366258    0.949403    3.424715    0.303633    0.069478    0.013000    0.846911    
#> 007: 0.330451    0.945723    3.422637    0.288451    0.066004    0.013449    0.872244    
#> 008: 0.297311    0.956361    3.403926    0.274029    0.062704    0.013226    0.863685    
#> 009: 0.263748    0.946227    3.398812    0.260327    0.059569    0.012565    0.841135    
#> 010: 0.275480    0.944802    3.394345    0.247311    0.056590    0.011936    0.877946    
#> 011: 0.313178    0.990731    3.390730    0.234945    0.053761    0.011365    0.879722    
#> 012: 0.318277    0.982008    3.387769    0.223198    0.051073    0.010797    0.854976    
#> 013: 0.277619    0.966941    3.394231    0.212038    0.052096    0.010257    0.846105    
#> 014: 0.301348    0.961432    3.401360    0.201436    0.049491    0.011089    0.887472    
#> 015: 0.296626    0.954921    3.407646    0.191364    0.047016    0.010534    0.854178    
#> 016: 0.278971    0.993636    3.399926    0.181796    0.044666    0.010008    0.862735    
#> 017: 0.284333    0.996275    3.397174    0.172706    0.042432    0.009507    0.860161    
#> 018: 0.308497    0.992617    3.388449    0.164071    0.040311    0.009032    0.865126    
#> 019: 0.247354    0.989124    3.386410    0.155867    0.038295    0.008719    0.855622    
#> 020: 0.270542    0.975280    3.391488    0.148074    0.036380    0.008782    0.873320    
#> 021: 0.281723    0.953459    3.397793    0.140670    0.034561    0.009279    0.849825    
#> 022: 0.286000    0.955197    3.405992    0.133637    0.033709    0.008815    0.835762    
#> 023: 0.336932    0.956734    3.414728    0.126955    0.036312    0.008375    0.852511    
#> 024: 0.345880    0.987971    3.410401    0.120607    0.034497    0.007956    0.863883    
#> 025: 0.299479    0.967548    3.402262    0.114577    0.035406    0.008020    0.862792    
#> 026: 0.291357    0.992935    3.396276    0.108848    0.040266    0.007619    0.862488    
#> 027: 0.277798    0.982689    3.397079    0.103406    0.039712    0.008521    0.868397    
#> 028: 0.300685    0.972892    3.401540    0.098235    0.042106    0.008095    0.858731    
#> 029: 0.327739    0.974546    3.392042    0.093324    0.055343    0.008238    0.870709    
#> 030: 0.274734    0.977186    3.394609    0.088657    0.052576    0.008680    0.847990    
#> 031: 0.286505    0.969572    3.412329    0.084225    0.049947    0.008278    0.869616    
#> 032: 0.276724    0.970290    3.411981    0.080013    0.047449    0.007864    0.859509    
#> 033: 0.280248    0.996852    3.396734    0.076013    0.050184    0.007471    0.866602    
#> 034: 0.295018    1.011486    3.392474    0.072212    0.047675    0.007464    0.864969    
#> 035: 0.247007    0.989400    3.386907    0.068601    0.045291    0.010077    0.842106    
#> 036: 0.252285    1.006282    3.379408    0.065171    0.044267    0.009574    0.860466    
#> 037: 0.244285    1.012944    3.379891    0.061913    0.042054    0.009095    0.875563    
#> 038: 0.265248    1.013312    3.365273    0.065480    0.047288    0.008640    0.859663    
#> 039: 0.290986    0.987911    3.383091    0.062206    0.044924    0.008208    0.854926    
#> 040: 0.286530    1.014985    3.384449    0.059915    0.042678    0.007798    0.853633    
#> 041: 0.269585    1.001725    3.387188    0.057486    0.043296    0.008565    0.845456    
#> 042: 0.299188    0.984472    3.384887    0.054612    0.041131    0.008137    0.853735    
#> 043: 0.281149    1.006558    3.381477    0.062816    0.039075    0.008682    0.845481    
#> 044: 0.254076    1.013913    3.379836    0.059676    0.038709    0.008723    0.854059    
#> 045: 0.258231    1.023177    3.375775    0.056692    0.036774    0.008287    0.879953    
#> 046: 0.244601    1.013995    3.377653    0.053857    0.034935    0.007873    0.886669    
#> 047: 0.278890    1.009235    3.379529    0.051164    0.037960    0.009484    0.852667    
#> 048: 0.282131    0.997033    3.380042    0.048606    0.049808    0.009010    0.840083    
#> 049: 0.265942    0.986910    3.394018    0.047931    0.049303    0.008559    0.847738    
#> 050: 0.305784    0.980480    3.391781    0.045535    0.048851    0.008131    0.868995    
#> 051: 0.276122    0.989898    3.392370    0.043258    0.049042    0.007725    0.859814    
#> 052: 0.278624    0.995325    3.396968    0.041095    0.047187    0.007338    0.856901    
#> 053: 0.286463    0.995887    3.398845    0.044687    0.053436    0.006971    0.863289    
#> 054: 0.242403    0.978132    3.396740    0.043267    0.060921    0.006914    0.862369    
#> 055: 0.257432    0.980459    3.393998    0.042097    0.060079    0.006598    0.871260    
#> 056: 0.275135    0.983597    3.395574    0.039992    0.057075    0.006268    0.870709    
#> 057: 0.274078    0.977130    3.400996    0.037992    0.071026    0.005954    0.882089    
#> 058: 0.280584    0.961394    3.388512    0.036093    0.072349    0.005786    0.873946    
#> 059: 0.298387    0.954549    3.399491    0.034288    0.068732    0.006040    0.876151    
#> 060: 0.303370    0.957862    3.410612    0.032574    0.065295    0.008091    0.868631    
#> 061: 0.302717    0.979612    3.402665    0.031472    0.062031    0.009295    0.874054    
#> 062: 0.281910    1.004113    3.407762    0.029898    0.058929    0.009727    0.869325    
#> 063: 0.291464    0.981342    3.395979    0.028403    0.055983    0.009241    0.860134    
#> 064: 0.277968    0.976625    3.397165    0.033352    0.053183    0.009006    0.857970    
#> 065: 0.282334    0.976806    3.390791    0.032395    0.050524    0.008556    0.859215    
#> 066: 0.278977    0.978978    3.393416    0.030775    0.051652    0.008128    0.861808    
#> 067: 0.264757    0.989921    3.381449    0.029236    0.051362    0.007722    0.872184    
#> 068: 0.246555    0.996865    3.389375    0.030277    0.056343    0.007336    0.902002    
#> 069: 0.247792    0.978995    3.384549    0.038554    0.053526    0.006969    0.886255    
#> 070: 0.265818    0.975353    3.401721    0.042730    0.056596    0.006620    0.895717    
#> 071: 0.280472    1.017239    3.387573    0.045210    0.063144    0.006289    0.899849    
#> 072: 0.241048    0.981541    3.385442    0.042950    0.059987    0.005975    0.872149    
#> 073: 0.265471    1.009805    3.392987    0.040802    0.056987    0.005676    0.866521    
#> 074: 0.233995    0.991497    3.389601    0.038762    0.061328    0.005392    0.865265    
#> 075: 0.249868    0.987820    3.394292    0.040520    0.059263    0.005123    0.856426    
#> 076: 0.266188    0.999857    3.400864    0.052591    0.056300    0.004867    0.854467    
#> 077: 0.277623    0.985010    3.384782    0.049961    0.053485    0.005346    0.870802    
#> 078: 0.282200    0.973665    3.389989    0.047463    0.050811    0.005079    0.884860    
#> 079: 0.310991    0.965811    3.394636    0.045090    0.048270    0.005069    0.892129    
#> 080: 0.310926    0.969086    3.397291    0.042836    0.045857    0.006970    0.893579    
#> 081: 0.304216    0.979406    3.407665    0.040694    0.043564    0.008964    0.870230    
#> 082: 0.295475    0.948941    3.416917    0.043517    0.049405    0.008516    0.879669    
#> 083: 0.316485    0.972646    3.417146    0.041342    0.046935    0.008090    0.888643    
#> 084: 0.310393    0.984154    3.403971    0.040420    0.049943    0.007686    0.877857    
#> 085: 0.294579    0.988104    3.416240    0.038399    0.047446    0.007928    0.883662    
#> 086: 0.286767    0.969196    3.404890    0.040096    0.045074    0.008418    0.868856    
#> 087: 0.293480    0.966705    3.408415    0.040813    0.042820    0.008491    0.858979    
#> 088: 0.276587    0.977184    3.405521    0.042543    0.040679    0.008067    0.859481    
#> 089: 0.289253    0.995130    3.383903    0.044074    0.038645    0.008236    0.860648    
#> 090: 0.260960    1.004280    3.388845    0.041870    0.049504    0.007824    0.855050    
#> 091: 0.251470    0.970019    3.382074    0.039777    0.048154    0.007433    0.859213    
#> 092: 0.260658    0.981146    3.388990    0.044916    0.048413    0.007061    0.877120    
#> 093: 0.259202    0.977217    3.393119    0.043483    0.045992    0.007225    0.872615    
#> 094: 0.245026    0.990507    3.382648    0.050818    0.043693    0.006864    0.866962    
#> 095: 0.275310    0.977544    3.405088    0.061965    0.047920    0.006595    0.887733    
#> 096: 0.243938    0.971617    3.403455    0.058867    0.053029    0.006300    0.891317    
#> 097: 0.331437    0.981897    3.413884    0.055924    0.050378    0.005985    0.861833    
#> 098: 0.294532    1.004068    3.411499    0.053128    0.047859    0.005686    0.878459    
#> 099: 0.275270    0.973618    3.393902    0.050471    0.054334    0.005402    0.854514    
#> 100: 0.312609    0.966790    3.407609    0.047948    0.056112    0.005132    0.858281    
#> 101: 0.281696    0.965479    3.398380    0.045550    0.053306    0.004875    0.857068    
#> 102: 0.279066    0.951902    3.386386    0.043273    0.050641    0.004631    0.884155    
#> 103: 0.305427    0.976318    3.396615    0.042559    0.048109    0.004729    0.853537    
#> 104: 0.316604    0.979475    3.401794    0.040431    0.050914    0.004492    0.872917    
#> 105: 0.307734    0.980250    3.400392    0.038409    0.067973    0.004268    0.884024    
#> 106: 0.293575    0.983116    3.389399    0.036489    0.064574    0.004054    0.871057    
#> 107: 0.320796    1.013473    3.387730    0.042123    0.062746    0.005089    0.868893    
#> 108: 0.275752    1.000617    3.379050    0.040687    0.059609    0.004835    0.882134    
#> 109: 0.269881    0.980990    3.394161    0.038653    0.068193    0.004593    0.883850    
#> 110: 0.243037    0.982549    3.372883    0.056021    0.064783    0.004363    0.861091    
#> 111: 0.254167    0.999987    3.374701    0.060232    0.061544    0.004145    0.873841    
#> 112: 0.250020    0.983681    3.374979    0.057220    0.058467    0.003938    0.855351    
#> 113: 0.244721    1.023539    3.368745    0.054359    0.056010    0.003741    0.852014    
#> 114: 0.239211    1.034589    3.372590    0.053919    0.053209    0.003554    0.866460    
#> 115: 0.274193    0.988898    3.368363    0.058851    0.052389    0.003376    0.901183    
#> 116: 0.225377    1.038652    3.374133    0.055908    0.049770    0.004066    0.911298    
#> 117: 0.226301    1.055844    3.368775    0.053113    0.057239    0.003863    0.888787    
#> 118: 0.236916    1.040314    3.373251    0.050457    0.054377    0.003908    0.886251    
#> 119: 0.245155    0.999093    3.370232    0.047934    0.051659    0.003755    0.861404    
#> 120: 0.224590    0.979433    3.372622    0.046034    0.049076    0.004527    0.882125    
#> 121: 0.240051    1.035609    3.365193    0.043733    0.054725    0.005442    0.868277    
#> 122: 0.264125    0.992183    3.375274    0.041546    0.055357    0.005170    0.860794    
#> 123: 0.286498    1.005071    3.376840    0.039469    0.052589    0.004911    0.864225    
#> 124: 0.288569    1.024076    3.375433    0.041592    0.049960    0.004666    0.860700    
#> 125: 0.260848    1.013555    3.378622    0.039513    0.054297    0.004943    0.861055    
#> 126: 0.224971    1.018746    3.365435    0.037628    0.051582    0.006336    0.873264    
#> 127: 0.237270    1.015925    3.356752    0.039900    0.055036    0.006019    0.870487    
#> 128: 0.220224    0.995165    3.367147    0.037905    0.052284    0.006640    0.877478    
#> 129: 0.259379    1.011740    3.379794    0.049605    0.049670    0.007252    0.871152    
#> 130: 0.262267    1.038793    3.376980    0.048670    0.047186    0.006890    0.842394    
#> 131: 0.247779    1.008638    3.366002    0.047432    0.048646    0.006545    0.853312    
#> 132: 0.221194    1.029321    3.352516    0.045060    0.050022    0.006871    0.861670    
#> 133: 0.229343    1.030452    3.358151    0.042807    0.056446    0.006527    0.877231    
#> 134: 0.236179    1.002330    3.368876    0.040667    0.056532    0.006856    0.850435    
#> 135: 0.227139    1.002872    3.370081    0.049132    0.054731    0.006514    0.865244    
#> 136: 0.218112    1.001231    3.371621    0.046675    0.057728    0.006188    0.847959    
#> 137: 0.262413    1.008529    3.378947    0.045955    0.054842    0.005878    0.863426    
#> 138: 0.268468    1.009812    3.373658    0.043657    0.052100    0.005585    0.850040    
#> 139: 0.253821    1.013090    3.376570    0.041474    0.054592    0.005305    0.855537    
#> 140: 0.260308    1.015130    3.383382    0.046137    0.051863    0.005040    0.864829    
#> 141: 0.253248    0.996746    3.390686    0.043830    0.049269    0.004788    0.860901    
#> 142: 0.263428    0.972795    3.400102    0.046490    0.060807    0.005012    0.881364    
#> 143: 0.260926    0.991818    3.403836    0.044166    0.057766    0.005249    0.866927    
#> 144: 0.312175    0.988183    3.405580    0.041958    0.054878    0.004987    0.859871    
#> 145: 0.284945    0.993426    3.391360    0.039860    0.052134    0.004737    0.850313    
#> 146: 0.280217    1.001196    3.395675    0.037867    0.056843    0.005402    0.849238    
#> 147: 0.257908    0.993306    3.394701    0.035973    0.054001    0.005301    0.845126    
#> 148: 0.275289    0.976978    3.396614    0.034428    0.051301    0.005700    0.855466    
#> 149: 0.272386    0.997266    3.392591    0.037046    0.048736    0.006937    0.877878    
#> 150: 0.289710    1.002992    3.385389    0.040365    0.047868    0.006590    0.885059    
#> 151: 0.270129    1.022453    3.380364    0.038347    0.047502    0.006261    0.882632    
#> 152: 0.299323    1.001013    3.392706    0.035361    0.045473    0.005840    0.886462    
#> 153: 0.246404    1.021071    3.387548    0.045318    0.058528    0.005826    0.867518    
#> 154: 0.256504    1.023727    3.379982    0.045584    0.057931    0.006196    0.877748    
#> 155: 0.227005    0.992510    3.369385    0.052446    0.043558    0.005136    0.857574    
#> 156: 0.209944    1.024629    3.374456    0.044747    0.046857    0.004765    0.871701    
#> 157: 0.255398    1.020948    3.388115    0.031446    0.048314    0.005963    0.884217    
#> 158: 0.261788    1.047398    3.380482    0.035496    0.049092    0.007218    0.865206    
#> 159: 0.228894    1.034871    3.375437    0.029410    0.055060    0.004347    0.876347    
#> 160: 0.262082    0.989871    3.385488    0.032928    0.055880    0.004852    0.850523    
#> 161: 0.251229    0.988924    3.393864    0.036749    0.057295    0.005799    0.862752    
#> 162: 0.244037    0.995159    3.377565    0.039562    0.044020    0.005987    0.839525    
#> 163: 0.260895    0.996454    3.375954    0.043295    0.044145    0.006041    0.856237    
#> 164: 0.271995    1.017185    3.371642    0.044478    0.040925    0.007130    0.857026    
#> 165: 0.286989    1.006272    3.386078    0.045883    0.039761    0.007365    0.843385    
#> 166: 0.301860    1.015045    3.388665    0.041139    0.038832    0.005399    0.863100    
#> 167: 0.296804    1.020010    3.395898    0.041651    0.051453    0.006069    0.860191    
#> 168: 0.286858    1.028008    3.395731    0.044928    0.047956    0.004685    0.866737    
#> 169: 0.268426    1.043684    3.382489    0.047838    0.049369    0.005053    0.868295    
#> 170: 0.281556    0.995408    3.379303    0.032108    0.058139    0.005053    0.852605    
#> 171: 0.261640    0.996280    3.388503    0.041793    0.049006    0.004273    0.842864    
#> 172: 0.271765    1.001044    3.388542    0.048324    0.048920    0.004790    0.858000    
#> 173: 0.272543    1.017319    3.373821    0.029010    0.054098    0.004299    0.880835    
#> 174: 0.291644    1.007966    3.380952    0.035352    0.047468    0.005410    0.865620    
#> 175: 0.277139    1.002678    3.376781    0.037509    0.051350    0.005776    0.859199    
#> 176: 0.262419    1.015512    3.382938    0.026644    0.039119    0.004750    0.853727    
#> 177: 0.241693    1.016811    3.383930    0.021831    0.039093    0.005353    0.869730    
#> 178: 0.254694    1.022377    3.378867    0.029248    0.043194    0.005665    0.859352    
#> 179: 0.253864    1.009807    3.382305    0.029818    0.049595    0.005547    0.887440    
#> 180: 0.260936    1.009851    3.387116    0.026627    0.042526    0.004530    0.881996    
#> 181: 0.247340    0.983026    3.373101    0.028107    0.039858    0.004259    0.867180    
#> 182: 0.212163    1.010856    3.365466    0.031766    0.058835    0.004008    0.877112    
#> 183: 0.206782    1.031424    3.363410    0.038968    0.050552    0.004596    0.875391    
#> 184: 0.225802    0.994898    3.371437    0.047773    0.046343    0.004446    0.851572    
#> 185: 0.215846    1.001086    3.363015    0.049921    0.056026    0.002914    0.857883    
#> 186: 0.249789    1.030209    3.367189    0.047317    0.059925    0.002720    0.867736    
#> 187: 0.249938    0.994487    3.376532    0.052300    0.043382    0.003215    0.873616    
#> 188: 0.214508    1.011353    3.371896    0.047699    0.049680    0.003599    0.889732    
#> 189: 0.250715    1.026399    3.377290    0.044318    0.042680    0.002900    0.898181    
#> 190: 0.235812    1.016229    3.373056    0.046956    0.044571    0.002908    0.878110    
#> 191: 0.220669    1.019239    3.365886    0.038185    0.037380    0.003434    0.867556    
#> 192: 0.257926    1.028474    3.377227    0.024865    0.047720    0.004224    0.887250    
#> 193: 0.263991    1.055135    3.376494    0.023872    0.038440    0.005309    0.879418    
#> 194: 0.240604    1.021666    3.361460    0.024474    0.048101    0.004890    0.905608    
#> 195: 0.221051    1.016572    3.364228    0.016585    0.033766    0.005453    0.895881    
#> 196: 0.219576    1.026632    3.377871    0.021976    0.045687    0.004982    0.898388    
#> 197: 0.242759    1.022678    3.398207    0.020980    0.038112    0.005172    0.890578    
#> 198: 0.242232    0.992932    3.369995    0.019642    0.046756    0.006731    0.853730    
#> 199: 0.217953    1.002709    3.367488    0.018883    0.041217    0.006230    0.861556    
#> 200: 0.222684    1.007184    3.366236    0.017327    0.052513    0.006548    0.896929    
#> 201: 0.229853    1.001706    3.369870    0.016218    0.047769    0.006188    0.887514    
#> 202: 0.235147    1.004905    3.367951    0.017716    0.045922    0.006061    0.883928    
#> 203: 0.239400    1.008058    3.367881    0.018528    0.041880    0.006455    0.882504    
#> 204: 0.243791    1.004177    3.368843    0.019566    0.041487    0.006343    0.882004    
#> 205: 0.249310    1.006025    3.370356    0.021174    0.041704    0.006312    0.880974    
#> 206: 0.252232    1.007369    3.372793    0.022154    0.041881    0.006254    0.879337    
#> 207: 0.250127    1.005471    3.371514    0.022546    0.043340    0.006151    0.879166    
#> 208: 0.251756    1.005353    3.372470    0.022612    0.042928    0.006187    0.878216    
#> 209: 0.253130    1.004297    3.372072    0.022704    0.041886    0.006093    0.877205    
#> 210: 0.252324    1.004466    3.371427    0.022691    0.041423    0.005986    0.876289    
#> 211: 0.252532    1.004519    3.372451    0.022789    0.041964    0.005912    0.874989    
#> 212: 0.252343    1.003891    3.373214    0.022873    0.041662    0.005961    0.874730    
#> 213: 0.253391    1.000660    3.373152    0.022596    0.041731    0.005977    0.877009    
#> 214: 0.254329    0.999959    3.372902    0.022529    0.041021    0.005936    0.878545    
#> 215: 0.254413    0.999821    3.373125    0.022180    0.041117    0.006024    0.879831    
#> 216: 0.252449    0.999138    3.373177    0.022535    0.041616    0.005938    0.880586    
#> 217: 0.251106    0.999706    3.372822    0.022533    0.041167    0.005869    0.880595    
#> 218: 0.249373    1.001663    3.371770    0.022651    0.041549    0.005839    0.879611    
#> 219: 0.248194    1.001632    3.370417    0.023346    0.041638    0.005880    0.879884    
#> 220: 0.245302    1.002402    3.369937    0.023557    0.041495    0.005860    0.881553    
#> 221: 0.243850    1.002548    3.369644    0.023500    0.041691    0.005808    0.881722    
#> 222: 0.242216    1.003088    3.369336    0.023775    0.041629    0.005819    0.881276    
#> 223: 0.242744    1.003567    3.369181    0.023824    0.041514    0.005843    0.879949    
#> 224: 0.243870    1.004235    3.369589    0.023984    0.041551    0.005836    0.879081    
#> 225: 0.244240    1.002886    3.370193    0.023871    0.041615    0.005872    0.879149    
#> 226: 0.244591    1.001502    3.370440    0.023786    0.041642    0.005846    0.879360    
#> 227: 0.243637    1.001871    3.370891    0.023658    0.041985    0.005819    0.879417    
#> 228: 0.242994    1.003963    3.370589    0.023972    0.042158    0.005863    0.879634    
#> 229: 0.243145    1.004069    3.370872    0.024323    0.042265    0.005873    0.878795    
#> 230: 0.243735    1.003778    3.371107    0.024281    0.042392    0.005889    0.878507    
#> 231: 0.244121    1.004053    3.371496    0.024324    0.042783    0.005850    0.878526    
#> 232: 0.243599    1.004040    3.372039    0.024237    0.043036    0.005826    0.878597    
#> 233: 0.244614    1.003104    3.372824    0.024112    0.043414    0.005896    0.878290    
#> 234: 0.244767    1.003079    3.373285    0.024082    0.043757    0.005908    0.878115    
#> 235: 0.245812    1.002640    3.373628    0.024000    0.043729    0.005860    0.878502    
#> 236: 0.246437    1.002951    3.373768    0.024012    0.043931    0.005884    0.878668    
#> 237: 0.247399    1.002720    3.374016    0.024301    0.044038    0.005913    0.878655    
#> 238: 0.247604    1.002893    3.374164    0.024242    0.044296    0.005885    0.878594    
#> 239: 0.248036    1.003667    3.374168    0.024317    0.044364    0.005871    0.877733    
#> 240: 0.248565    1.003558    3.374427    0.024405    0.044523    0.005857    0.877947    
#> 241: 0.249438    1.002894    3.374692    0.024443    0.044677    0.005845    0.878179    
#> 242: 0.249422    1.002732    3.374482    0.024421    0.044888    0.005830    0.878366    
#> 243: 0.248823    1.003128    3.374466    0.024578    0.045034    0.005824    0.878461    
#> 244: 0.248294    1.002797    3.374614    0.024613    0.044886    0.005848    0.878693    
#> 245: 0.248407    1.002804    3.374798    0.024751    0.044905    0.005828    0.878424    
#> 246: 0.248176    1.002530    3.374861    0.024890    0.044484    0.005844    0.879047    
#> 247: 0.247653    1.002484    3.374942    0.024994    0.044490    0.005808    0.878584    
#> 248: 0.247804    1.002519    3.374974    0.025003    0.044365    0.005799    0.878417    
#> 249: 0.247916    1.002592    3.375034    0.025114    0.044396    0.005784    0.878540    
#> 250: 0.248407    1.002696    3.375244    0.025169    0.044345    0.005793    0.878570    
#> 251: 0.248541    1.003029    3.375661    0.025211    0.044398    0.005797    0.878361    
#> 252: 0.248994    1.003080    3.376131    0.025191    0.044514    0.005805    0.878398    
#> 253: 0.249161    1.002785    3.376401    0.025213    0.044592    0.005836    0.878364    
#> 254: 0.249137    1.003101    3.376706    0.025103    0.044744    0.005855    0.878663    
#> 255: 0.249506    1.003089    3.377200    0.025055    0.044693    0.005882    0.879073    
#> 256: 0.250004    1.002632    3.377504    0.025077    0.044660    0.005891    0.879140    
#> 257: 0.249884    1.002150    3.377634    0.025267    0.044684    0.005863    0.878900    
#> 258: 0.249927    1.001762    3.377623    0.025298    0.044673    0.005832    0.878465    
#> 259: 0.249950    1.001742    3.377715    0.025253    0.044597    0.005836    0.878811    
#> 260: 0.249889    1.002348    3.377842    0.025284    0.044466    0.005847    0.878502    
#> 261: 0.250199    1.002239    3.378014    0.025242    0.044497    0.005884    0.878302    
#> 262: 0.250499    1.002175    3.378101    0.025168    0.044490    0.005893    0.878502    
#> 263: 0.250322    1.002404    3.378135    0.025073    0.044487    0.005894    0.878431    
#> 264: 0.250485    1.002390    3.378056    0.025079    0.044204    0.005871    0.878818    
#> 265: 0.250764    1.002199    3.378120    0.025098    0.044157    0.005842    0.879082    
#> 266: 0.251538    1.002707    3.378029    0.025224    0.044047    0.005817    0.879457    
#> 267: 0.251598    1.002786    3.378074    0.025303    0.043973    0.005819    0.879696    
#> 268: 0.251363    1.002439    3.377952    0.025432    0.043955    0.005801    0.879793    
#> 269: 0.251637    1.002444    3.377954    0.025429    0.044026    0.005773    0.879737    
#> 270: 0.252124    1.002436    3.377832    0.025551    0.044010    0.005755    0.879771    
#> 271: 0.252235    1.002344    3.377617    0.025671    0.043867    0.005737    0.880247    
#> 272: 0.252207    1.002076    3.377486    0.025788    0.043756    0.005720    0.880491    
#> 273: 0.252068    1.001978    3.377547    0.025760    0.043837    0.005690    0.880652    
#> 274: 0.251725    1.002029    3.377663    0.025767    0.043768    0.005663    0.880719    
#> 275: 0.251666    1.002001    3.377604    0.025818    0.043789    0.005649    0.880538    
#> 276: 0.251708    1.001876    3.377789    0.025796    0.043823    0.005645    0.880457    
#> 277: 0.251665    1.001901    3.377942    0.025834    0.043795    0.005641    0.880376    
#> 278: 0.252019    1.001879    3.378111    0.025845    0.043796    0.005636    0.880468    
#> 279: 0.252092    1.001768    3.378211    0.025915    0.043712    0.005646    0.880516    
#> 280: 0.252316    1.001968    3.378457    0.025819    0.043650    0.005643    0.880428    
#> 281: 0.252346    1.002175    3.378570    0.025760    0.043450    0.005652    0.880288    
#> 282: 0.252240    1.002491    3.378571    0.025776    0.043433    0.005657    0.880395    
#> 283: 0.252375    1.002652    3.378586    0.025827    0.043423    0.005662    0.880381    
#> 284: 0.252176    1.002602    3.378573    0.025796    0.043438    0.005649    0.880136    
#> 285: 0.252291    1.002624    3.378503    0.025826    0.043506    0.005648    0.880048    
#> 286: 0.252110    1.002859    3.378397    0.025886    0.043580    0.005653    0.880292    
#> 287: 0.252013    1.003036    3.378311    0.025939    0.043477    0.005656    0.880203    
#> 288: 0.252011    1.003155    3.378248    0.025940    0.043608    0.005645    0.880345    
#> 289: 0.252241    1.003117    3.378252    0.025975    0.043577    0.005652    0.880289    
#> 290: 0.252245    1.003209    3.378243    0.025963    0.043537    0.005671    0.880300    
#> 291: 0.252569    1.003329    3.378294    0.026037    0.043487    0.005671    0.880257    
#> 292: 0.252703    1.003372    3.378309    0.026099    0.043482    0.005661    0.880108    
#> 293: 0.252752    1.003341    3.378295    0.026175    0.043464    0.005662    0.879923    
#> 294: 0.252587    1.003486    3.378140    0.026279    0.043419    0.005652    0.879754    
#> 295: 0.252556    1.003129    3.378134    0.026344    0.043442    0.005656    0.879501    
#> 296: 0.252466    1.002980    3.378091    0.026392    0.043304    0.005666    0.879489    
#> 297: 0.252331    1.003105    3.378042    0.026479    0.043219    0.005689    0.879439    
#> 298: 0.252233    1.003042    3.378048    0.026569    0.043149    0.005714    0.879373    
#> 299: 0.252237    1.003046    3.378115    0.026642    0.043113    0.005722    0.879075    
#> 300: 0.252501    1.002827    3.378374    0.026693    0.043032    0.005727    0.878923    
#> 301: 0.252801    1.002644    3.378389    0.026627    0.043011    0.005724    0.878990    
#> 302: 0.253017    1.002568    3.378384    0.026690    0.043027    0.005705    0.878990    
#> 303: 0.253102    1.002778    3.378449    0.026667    0.042933    0.005692    0.878843    
#> 304: 0.253370    1.002906    3.378516    0.026658    0.042870    0.005682    0.878873    
#> 305: 0.253486    1.002771    3.378569    0.026711    0.042821    0.005687    0.878815    
#> 306: 0.253493    1.002628    3.378565    0.026754    0.042793    0.005686    0.878782    
#> 307: 0.253440    1.002625    3.378472    0.026748    0.042865    0.005678    0.878828    
#> 308: 0.253399    1.002464    3.378476    0.026802    0.042901    0.005679    0.878866    
#> 309: 0.253463    1.002380    3.378384    0.026786    0.042931    0.005664    0.879032    
#> 310: 0.253673    1.002230    3.378308    0.026726    0.043042    0.005665    0.879028    
#> 311: 0.253520    1.002330    3.378315    0.026776    0.043095    0.005660    0.879067    
#> 312: 0.253309    1.002328    3.378216    0.026806    0.043102    0.005639    0.879005    
#> 313: 0.253103    1.002115    3.378155    0.026826    0.043151    0.005641    0.879041    
#> 314: 0.253049    1.002340    3.378113    0.026839    0.043137    0.005626    0.879042    
#> 315: 0.252821    1.002440    3.378125    0.026821    0.043095    0.005634    0.878949    
#> 316: 0.252784    1.002492    3.378109    0.026811    0.043043    0.005639    0.878709    
#> 317: 0.252751    1.002579    3.378166    0.026728    0.043068    0.005643    0.878718    
#> 318: 0.252691    1.002602    3.378140    0.026730    0.043031    0.005638    0.878701    
#> 319: 0.252659    1.002456    3.378202    0.026731    0.043073    0.005634    0.878774    
#> 320: 0.252400    1.002504    3.378129    0.026728    0.043084    0.005634    0.878848    
#> 321: 0.252163    1.002509    3.378006    0.026751    0.043074    0.005644    0.878891    
#> 322: 0.252128    1.002501    3.377920    0.026767    0.043184    0.005633    0.878794    
#> 323: 0.251753    1.002536    3.377885    0.026876    0.043135    0.005641    0.878732    
#> 324: 0.251637    1.002689    3.377884    0.026861    0.043094    0.005638    0.878671    
#> 325: 0.251649    1.002871    3.377873    0.026857    0.043024    0.005629    0.878738    
#> 326: 0.251803    1.002646    3.377909    0.026911    0.043196    0.005628    0.878593    
#> 327: 0.251773    1.002720    3.377969    0.027000    0.043173    0.005617    0.878634    
#> 328: 0.251878    1.002848    3.377995    0.027000    0.043129    0.005621    0.878669    
#> 329: 0.251978    1.002875    3.378065    0.027060    0.043177    0.005616    0.878593    
#> 330: 0.251963    1.002952    3.378093    0.027122    0.043216    0.005607    0.878746    
#> 331: 0.252072    1.003035    3.378082    0.027123    0.043219    0.005595    0.878854    
#> 332: 0.252077    1.003036    3.378164    0.027138    0.043203    0.005604    0.878742    
#> 333: 0.252144    1.003002    3.378160    0.027216    0.043191    0.005610    0.878644    
#> 334: 0.252183    1.003068    3.378081    0.027194    0.043205    0.005603    0.878589    
#> 335: 0.252147    1.003056    3.377989    0.027189    0.043278    0.005600    0.878458    
#> 336: 0.252126    1.003182    3.377970    0.027200    0.043299    0.005625    0.878360    
#> 337: 0.252129    1.003505    3.377870    0.027316    0.043309    0.005622    0.878330    
#> 338: 0.252249    1.003618    3.377933    0.027344    0.043365    0.005633    0.878294    
#> 339: 0.252134    1.003691    3.377943    0.027368    0.043305    0.005638    0.878361    
#> 340: 0.252005    1.003601    3.377940    0.027345    0.043339    0.005622    0.878560    
#> 341: 0.252124    1.003683    3.377948    0.027332    0.043338    0.005619    0.878732    
#> 342: 0.252089    1.003456    3.377925    0.027345    0.043307    0.005620    0.878647    
#> 343: 0.252113    1.003611    3.377955    0.027391    0.043310    0.005615    0.878420    
#> 344: 0.252384    1.003638    3.378022    0.027501    0.043263    0.005632    0.878292    
#> 345: 0.252580    1.003608    3.378100    0.027525    0.043300    0.005649    0.878098    
#> 346: 0.252620    1.003493    3.378102    0.027513    0.043313    0.005651    0.877968    
#> 347: 0.252672    1.003191    3.378055    0.027476    0.043348    0.005657    0.878183    
#> 348: 0.252611    1.003126    3.378056    0.027478    0.043346    0.005649    0.878318    
#> 349: 0.252551    1.003109    3.378065    0.027520    0.043307    0.005654    0.878163    
#> 350: 0.252524    1.002995    3.378082    0.027520    0.043344    0.005652    0.878269    
#> 351: 0.252415    1.003113    3.378056    0.027552    0.043426    0.005645    0.878245    
#> 352: 0.252324    1.003239    3.378040    0.027647    0.043523    0.005647    0.878124    
#> 353: 0.252405    1.003323    3.378081    0.027759    0.043510    0.005647    0.878023    
#> 354: 0.252594    1.003367    3.378060    0.027851    0.043484    0.005654    0.877932    
#> 355: 0.252958    1.003045    3.378193    0.027891    0.043433    0.005662    0.877852    
#> 356: 0.253068    1.002869    3.378281    0.027867    0.043476    0.005654    0.877950    
#> 357: 0.253266    1.002905    3.378329    0.027881    0.043481    0.005648    0.877870    
#> 358: 0.253348    1.003043    3.378407    0.027887    0.043489    0.005643    0.877852    
#> 359: 0.253251    1.003069    3.378417    0.027926    0.043546    0.005641    0.877758    
#> 360: 0.253057    1.003174    3.378287    0.027916    0.043581    0.005636    0.877641    
#> 361: 0.252747    1.003079    3.378232    0.027923    0.043628    0.005628    0.877553    
#> 362: 0.252768    1.003026    3.378203    0.027932    0.043618    0.005622    0.877449    
#> 363: 0.252755    1.003067    3.378126    0.027990    0.043642    0.005623    0.877271    
#> 364: 0.252877    1.003058    3.378141    0.028046    0.043636    0.005615    0.877247    
#> 365: 0.252898    1.002965    3.378204    0.028127    0.043710    0.005610    0.877164    
#> 366: 0.252894    1.002928    3.378184    0.028200    0.043745    0.005597    0.877144    
#> 367: 0.252949    1.002865    3.378188    0.028173    0.043775    0.005584    0.877224    
#> 368: 0.253141    1.002923    3.378227    0.028145    0.043702    0.005572    0.877205    
#> 369: 0.253206    1.002907    3.378275    0.028138    0.043712    0.005565    0.877064    
#> 370: 0.253093    1.002894    3.378288    0.028135    0.043743    0.005569    0.877117    
#> 371: 0.253141    1.002859    3.378227    0.028115    0.043674    0.005565    0.877128    
#> 372: 0.253093    1.002914    3.378190    0.028129    0.043646    0.005554    0.877180    
#> 373: 0.253015    1.003023    3.378142    0.028091    0.043690    0.005547    0.877327    
#> 374: 0.253011    1.002995    3.378089    0.028064    0.043729    0.005541    0.877279    
#> 375: 0.252887    1.003019    3.378001    0.028022    0.043740    0.005533    0.877356    
#> 376: 0.252834    1.003188    3.377951    0.027988    0.043842    0.005532    0.877438    
#> 377: 0.252900    1.003301    3.377907    0.027953    0.043889    0.005524    0.877430    
#> 378: 0.252610    1.003296    3.377817    0.027987    0.043867    0.005531    0.877389    
#> 379: 0.252423    1.003182    3.377813    0.028010    0.043844    0.005537    0.877279    
#> 380: 0.252278    1.003150    3.377755    0.027968    0.043866    0.005544    0.877258    
#> 381: 0.252219    1.003100    3.377752    0.027947    0.043830    0.005536    0.877162    
#> 382: 0.252267    1.002937    3.377767    0.027912    0.043806    0.005539    0.877042    
#> 383: 0.252435    1.002867    3.377775    0.027881    0.043835    0.005537    0.876988    
#> 384: 0.252409    1.002795    3.377808    0.027875    0.043828    0.005535    0.876985    
#> 385: 0.252378    1.002773    3.377860    0.027869    0.043861    0.005536    0.877169    
#> 386: 0.252498    1.002917    3.377859    0.027839    0.043858    0.005537    0.877302    
#> 387: 0.252470    1.002973    3.377877    0.027897    0.043803    0.005545    0.877268    
#> 388: 0.252464    1.003016    3.377898    0.027931    0.043710    0.005542    0.877168    
#> 389: 0.252508    1.002796    3.377950    0.027936    0.043676    0.005548    0.877275    
#> 390: 0.252459    1.002798    3.377940    0.027941    0.043686    0.005550    0.877212    
#> 391: 0.252479    1.002820    3.377892    0.027967    0.043656    0.005551    0.877133    
#> 392: 0.252491    1.002873    3.377922    0.027982    0.043657    0.005549    0.877179    
#> 393: 0.252396    1.002856    3.377863    0.027986    0.043664    0.005554    0.877176    
#> 394: 0.252435    1.002923    3.377846    0.028001    0.043725    0.005551    0.877148    
#> 395: 0.252632    1.003023    3.377828    0.028026    0.043735    0.005559    0.877193    
#> 396: 0.252813    1.003134    3.377809    0.028058    0.043721    0.005563    0.877074    
#> 397: 0.252939    1.003143    3.377877    0.028095    0.043705    0.005564    0.876978    
#> 398: 0.253092    1.003037    3.377923    0.028169    0.043695    0.005567    0.876882    
#> 399: 0.253227    1.002985    3.377997    0.028220    0.043695    0.005567    0.876770    
#> 400: 0.253415    1.003011    3.378075    0.028255    0.043696    0.005567    0.876818    
#> 401: 0.253487    1.002973    3.378119    0.028257    0.043752    0.005564    0.876859    
#> 402: 0.253439    1.002984    3.378144    0.028247    0.043780    0.005564    0.876856    
#> 403: 0.253590    1.002919    3.378179    0.028275    0.043823    0.005561    0.876928    
#> 404: 0.253599    1.002939    3.378130    0.028271    0.043878    0.005556    0.876953    
#> 405: 0.253567    1.002990    3.378197    0.028322    0.043964    0.005547    0.876896    
#> 406: 0.253592    1.002930    3.378229    0.028324    0.043962    0.005549    0.876999    
#> 407: 0.253757    1.003053    3.378250    0.028346    0.044044    0.005551    0.876970    
#> 408: 0.253784    1.003200    3.378237    0.028379    0.044058    0.005545    0.877014    
#> 409: 0.253697    1.003117    3.378177    0.028393    0.044025    0.005548    0.877009    
#> 410: 0.253569    1.003205    3.378103    0.028375    0.044036    0.005552    0.876995    
#> 411: 0.253441    1.003080    3.378026    0.028384    0.044045    0.005549    0.877019    
#> 412: 0.253358    1.003183    3.377940    0.028358    0.044020    0.005554    0.877019    
#> 413: 0.253299    1.003245    3.377855    0.028369    0.044012    0.005554    0.877008    
#> 414: 0.253233    1.003182    3.377857    0.028393    0.043998    0.005550    0.876944    
#> 415: 0.253240    1.003087    3.377826    0.028425    0.043963    0.005550    0.876878    
#> 416: 0.253341    1.003147    3.377845    0.028412    0.043956    0.005544    0.876769    
#> 417: 0.253518    1.003049    3.377871    0.028418    0.044007    0.005549    0.876728    
#> 418: 0.253392    1.003052    3.377858    0.028468    0.044067    0.005543    0.876719    
#> 419: 0.253409    1.003168    3.377827    0.028485    0.044071    0.005543    0.876734    
#> 420: 0.253471    1.003235    3.377810    0.028506    0.044087    0.005537    0.876656    
#> 421: 0.253401    1.003213    3.377849    0.028493    0.044134    0.005529    0.876599    
#> 422: 0.253279    1.003176    3.377819    0.028529    0.044156    0.005523    0.876591    
#> 423: 0.253278    1.003123    3.377864    0.028530    0.044149    0.005532    0.876478    
#> 424: 0.253245    1.003081    3.377863    0.028516    0.044149    0.005527    0.876485    
#> 425: 0.253415    1.003167    3.377893    0.028573    0.044133    0.005521    0.876641    
#> 426: 0.253501    1.003321    3.377881    0.028567    0.044082    0.005520    0.876709    
#> 427: 0.253512    1.003275    3.377887    0.028573    0.044048    0.005523    0.876674    
#> 428: 0.253337    1.003308    3.377876    0.028585    0.044019    0.005518    0.876704    
#> 429: 0.253221    1.003273    3.377858    0.028585    0.044048    0.005513    0.876733    
#> 430: 0.253323    1.003308    3.377859    0.028639    0.044037    0.005519    0.876626    
#> 431: 0.253348    1.003332    3.377870    0.028663    0.044008    0.005520    0.876580    
#> 432: 0.253407    1.003490    3.377842    0.028695    0.043978    0.005521    0.876558    
#> 433: 0.253511    1.003619    3.377899    0.028704    0.043946    0.005522    0.876603    
#> 434: 0.253500    1.003537    3.377975    0.028718    0.043928    0.005529    0.876584    
#> 435: 0.253592    1.003443    3.378010    0.028725    0.043924    0.005530    0.876539    
#> 436: 0.253512    1.003337    3.378037    0.028744    0.043892    0.005525    0.876619    
#> 437: 0.253548    1.003217    3.378036    0.028756    0.043905    0.005523    0.876703    
#> 438: 0.253585    1.003326    3.378058    0.028786    0.043896    0.005525    0.876646    
#> 439: 0.253698    1.003293    3.378101    0.028821    0.043885    0.005524    0.876560    
#> 440: 0.253656    1.003307    3.378080    0.028811    0.043898    0.005519    0.876486    
#> 441: 0.253605    1.003270    3.378084    0.028799    0.043971    0.005515    0.876475    
#> 442: 0.253440    1.003379    3.378079    0.028798    0.043981    0.005521    0.876398    
#> 443: 0.253449    1.003378    3.378078    0.028850    0.043980    0.005519    0.876380    
#> 444: 0.253388    1.003424    3.378075    0.028836    0.043992    0.005522    0.876337    
#> 445: 0.253388    1.003465    3.378028    0.028846    0.044034    0.005527    0.876285    
#> 446: 0.253370    1.003473    3.377971    0.028875    0.044039    0.005524    0.876215    
#> 447: 0.253409    1.003455    3.377969    0.028870    0.044032    0.005528    0.876233    
#> 448: 0.253416    1.003493    3.377987    0.028847    0.044040    0.005530    0.876268    
#> 449: 0.253429    1.003715    3.378056    0.028848    0.044042    0.005531    0.876372    
#> 450: 0.253490    1.003719    3.378062    0.028840    0.044033    0.005531    0.876339    
#> 451: 0.253549    1.003759    3.378073    0.028853    0.044042    0.005532    0.876339    
#> 452: 0.253492    1.003886    3.377997    0.028834    0.044035    0.005529    0.876355    
#> 453: 0.253452    1.003907    3.377987    0.028781    0.044033    0.005519    0.876371    
#> 454: 0.253554    1.003977    3.378001    0.028739    0.044037    0.005510    0.876370    
#> 455: 0.253539    1.003975    3.377986    0.028720    0.044034    0.005500    0.876431    
#> 456: 0.253435    1.003999    3.377953    0.028737    0.044055    0.005494    0.876423    
#> 457: 0.253345    1.004037    3.377950    0.028775    0.044045    0.005490    0.876378    
#> 458: 0.253377    1.004206    3.378001    0.028813    0.044060    0.005488    0.876371    
#> 459: 0.253323    1.004343    3.378014    0.028800    0.044081    0.005489    0.876336    
#> 460: 0.253288    1.004330    3.377974    0.028767    0.044055    0.005497    0.876327    
#> 461: 0.253206    1.004365    3.377980    0.028757    0.044050    0.005502    0.876238    
#> 462: 0.253187    1.004423    3.377993    0.028759    0.044041    0.005504    0.876248    
#> 463: 0.253237    1.004395    3.378002    0.028757    0.044009    0.005507    0.876213    
#> 464: 0.253322    1.004386    3.378026    0.028761    0.043957    0.005505    0.876167    
#> 465: 0.253346    1.004198    3.378021    0.028751    0.043966    0.005501    0.876254    
#> 466: 0.253330    1.004232    3.377977    0.028734    0.043939    0.005498    0.876244    
#> 467: 0.253311    1.004225    3.377922    0.028717    0.043939    0.005495    0.876148    
#> 468: 0.253370    1.004238    3.377959    0.028731    0.043929    0.005500    0.876103    
#> 469: 0.253410    1.004325    3.377960    0.028735    0.043932    0.005511    0.876074    
#> 470: 0.253374    1.004419    3.377929    0.028721    0.043966    0.005516    0.876002    
#> 471: 0.253212    1.004365    3.377906    0.028742    0.043969    0.005520    0.875974    
#> 472: 0.253171    1.004347    3.377942    0.028759    0.043963    0.005519    0.875936    
#> 473: 0.253067    1.004335    3.377974    0.028749    0.043971    0.005517    0.875910    
#> 474: 0.253058    1.004327    3.377967    0.028738    0.043943    0.005516    0.875962    
#> 475: 0.253096    1.004386    3.377923    0.028726    0.043906    0.005513    0.875994    
#> 476: 0.253169    1.004370    3.377921    0.028743    0.043888    0.005517    0.876004    
#> 477: 0.253210    1.004398    3.377921    0.028724    0.043863    0.005517    0.875970    
#> 478: 0.253187    1.004334    3.377922    0.028697    0.043853    0.005518    0.875953    
#> 479: 0.253203    1.004387    3.377925    0.028673    0.043877    0.005517    0.875970    
#> 480: 0.253248    1.004391    3.377974    0.028674    0.043838    0.005516    0.876125    
#> 481: 0.253203    1.004401    3.377992    0.028662    0.043865    0.005515    0.876103    
#> 482: 0.253265    1.004403    3.377985    0.028644    0.043880    0.005511    0.876157    
#> 483: 0.253251    1.004418    3.377976    0.028639    0.043896    0.005508    0.876193    
#> 484: 0.253295    1.004372    3.377967    0.028676    0.043894    0.005507    0.876134    
#> 485: 0.253357    1.004413    3.377981    0.028685    0.043890    0.005502    0.876105    
#> 486: 0.253447    1.004373    3.378019    0.028678    0.043877    0.005504    0.876084    
#> 487: 0.253630    1.004358    3.378077    0.028670    0.043870    0.005501    0.876092    
#> 488: 0.253593    1.004290    3.378114    0.028682    0.043887    0.005502    0.876090    
#> 489: 0.253634    1.004239    3.378140    0.028682    0.043904    0.005506    0.876062    
#> 490: 0.253770    1.004252    3.378166    0.028675    0.043890    0.005509    0.876018    
#> 491: 0.253805    1.004334    3.378202    0.028663    0.043930    0.005503    0.876010    
#> 492: 0.253772    1.004378    3.378195    0.028634    0.043933    0.005499    0.876127    
#> 493: 0.253693    1.004391    3.378195    0.028613    0.043924    0.005497    0.876223    
#> 494: 0.253741    1.004433    3.378210    0.028601    0.043902    0.005497    0.876221    
#> 495: 0.253811    1.004435    3.378250    0.028621    0.043885    0.005496    0.876193    
#> 496: 0.253865    1.004469    3.378197    0.028633    0.043887    0.005496    0.876181    
#> 497: 0.253855    1.004473    3.378173    0.028613    0.043903    0.005495    0.876167    
#> 498: 0.253840    1.004477    3.378147    0.028604    0.043895    0.005494    0.876140    
#> 499: 0.253824    1.004542    3.378104    0.028603    0.043935    0.005492    0.876140    
#> 500: 0.253829    1.004529    3.378083    0.028579    0.043917    0.005495    0.876188    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.283097    0.962384    3.445384    0.392401    0.085012    0.016800    1.693158    
#> 002: 0.184877    1.004727    3.466600    0.372781    0.080761    0.017689    1.076315    
#> 003: 0.305380    0.975677    3.492864    0.354142    0.097136    0.016804    0.857690    
#> 004: 0.248625    0.986121    3.491158    0.336435    0.094711    0.015964    0.780473    
#> 005: 0.300150    0.988732    3.492361    0.319613    0.089976    0.015166    0.752885    
#> 006: 0.228727    0.999688    3.476633    0.303633    0.085477    0.014408    0.702896    
#> 007: 0.190524    1.013259    3.463966    0.288451    0.093277    0.013687    0.715394    
#> 008: 0.179043    1.007316    3.451725    0.274029    0.090457    0.013003    0.731915    
#> 009: 0.167285    0.995915    3.449835    0.260327    0.085935    0.013599    0.721078    
#> 010: 0.189536    1.003186    3.451282    0.247311    0.081638    0.012919    0.738168    
#> 011: 0.229006    1.001800    3.473379    0.234945    0.110242    0.012305    0.715119    
#> 012: 0.215404    0.998415    3.457191    0.223198    0.104730    0.011690    0.703096    
#> 013: 0.172554    1.014575    3.454252    0.212038    0.099494    0.012795    0.709525    
#> 014: 0.243262    1.001818    3.468582    0.201436    0.094519    0.012156    0.736677    
#> 015: 0.219480    1.021139    3.467656    0.191364    0.098941    0.013499    0.696250    
#> 016: 0.221862    1.030628    3.469448    0.181796    0.100723    0.018105    0.701317    
#> 017: 0.233300    1.019994    3.478032    0.179371    0.095686    0.018610    0.693953    
#> 018: 0.228417    1.013341    3.464763    0.179890    0.110064    0.019656    0.709656    
#> 019: 0.196448    1.007782    3.468688    0.170895    0.104561    0.018674    0.702777    
#> 020: 0.200750    1.015331    3.470018    0.162351    0.099333    0.017740    0.717598    
#> 021: 0.223657    1.016075    3.475027    0.154233    0.094366    0.016853    0.704377    
#> 022: 0.245566    0.987053    3.501332    0.146521    0.089648    0.018097    0.709238    
#> 023: 0.309048    0.965573    3.509445    0.146707    0.085166    0.018897    0.723152    
#> 024: 0.319118    0.985774    3.514404    0.139372    0.080907    0.017952    0.718800    
#> 025: 0.302104    0.968377    3.511294    0.157950    0.076862    0.019682    0.715029    
#> 026: 0.297460    0.997512    3.501664    0.150053    0.073019    0.024197    0.720556    
#> 027: 0.263649    1.017662    3.494203    0.142550    0.069368    0.027758    0.721561    
#> 028: 0.271062    1.001917    3.497285    0.135422    0.065900    0.027770    0.697945    
#> 029: 0.251721    1.008109    3.473746    0.172136    0.073394    0.026382    0.705387    
#> 030: 0.241582    1.014306    3.474271    0.163529    0.069724    0.025063    0.709674    
#> 031: 0.225090    0.998279    3.484937    0.155353    0.073147    0.023810    0.702147    
#> 032: 0.246501    0.972669    3.494372    0.172046    0.069490    0.022619    0.700735    
#> 033: 0.249620    1.017001    3.484937    0.163443    0.066015    0.023537    0.722290    
#> 034: 0.251245    1.021951    3.481612    0.155271    0.065431    0.022360    0.721096    
#> 035: 0.190805    1.010405    3.461490    0.164272    0.062160    0.021242    0.716620    
#> 036: 0.177121    1.024161    3.450056    0.176260    0.070836    0.020180    0.702262    
#> 037: 0.176967    1.018524    3.453419    0.167447    0.067294    0.019171    0.703645    
#> 038: 0.237846    1.034161    3.452918    0.159075    0.070352    0.018212    0.706415    
#> 039: 0.221269    1.026294    3.477266    0.167019    0.090325    0.021307    0.695659    
#> 040: 0.214069    1.020422    3.476454    0.183638    0.085809    0.020242    0.707810    
#> 041: 0.204249    0.995965    3.474950    0.174456    0.083446    0.020768    0.697737    
#> 042: 0.246047    0.987272    3.474787    0.166970    0.079274    0.020761    0.709967    
#> 043: 0.182169    1.012977    3.455706    0.167877    0.075310    0.019723    0.707749    
#> 044: 0.163668    1.039765    3.449509    0.159483    0.075369    0.018737    0.705351    
#> 045: 0.162696    1.048643    3.443075    0.151509    0.071601    0.020374    0.699175    
#> 046: 0.194089    1.040490    3.449957    0.143934    0.083798    0.019356    0.689154    
#> 047: 0.209630    1.029340    3.458714    0.136737    0.079608    0.018388    0.685224    
#> 048: 0.212641    1.024579    3.457111    0.129900    0.075628    0.019578    0.700939    
#> 049: 0.190234    1.050339    3.468213    0.134702    0.077996    0.018599    0.707199    
#> 050: 0.304911    0.983475    3.485857    0.127967    0.074096    0.017669    0.719924    
#> 051: 0.275786    0.986458    3.491346    0.123256    0.075748    0.018933    0.721480    
#> 052: 0.249091    0.988855    3.496758    0.145061    0.071961    0.021207    0.699520    
#> 053: 0.250306    0.994058    3.478971    0.137808    0.068892    0.020147    0.724750    
#> 054: 0.193153    1.009402    3.480061    0.132508    0.082139    0.019984    0.714345    
#> 055: 0.200923    1.000595    3.476635    0.137521    0.078032    0.026428    0.701870    
#> 056: 0.199479    1.009042    3.474107    0.147592    0.074131    0.025107    0.702013    
#> 057: 0.207953    0.995301    3.486215    0.140213    0.070424    0.023851    0.723280    
#> 058: 0.224233    1.004023    3.470285    0.133202    0.080836    0.022659    0.707215    
#> 059: 0.259882    0.981733    3.484202    0.135810    0.081881    0.022984    0.724463    
#> 060: 0.237556    0.969487    3.484013    0.180249    0.077786    0.023054    0.723279    
#> 061: 0.275323    0.982439    3.496526    0.176221    0.073897    0.028326    0.729468    
#> 062: 0.273258    1.019077    3.500360    0.175881    0.100183    0.027078    0.722053    
#> 063: 0.297431    0.974135    3.499549    0.189467    0.095174    0.028693    0.714053    
#> 064: 0.285789    0.965887    3.506459    0.179994    0.090416    0.027259    0.735810    
#> 065: 0.290441    0.965797    3.485871    0.171255    0.085895    0.025896    0.721393    
#> 066: 0.293822    1.008912    3.497695    0.173729    0.083395    0.024601    0.721889    
#> 067: 0.273934    0.981652    3.496192    0.165042    0.079225    0.025561    0.711275    
#> 068: 0.229796    1.000450    3.497229    0.156790    0.079201    0.024283    0.723690    
#> 069: 0.238732    1.016069    3.479245    0.160694    0.075241    0.023475    0.726430    
#> 070: 0.245031    1.013778    3.490205    0.163383    0.071479    0.023552    0.713930    
#> 071: 0.222986    1.020823    3.463724    0.155214    0.086129    0.022374    0.734106    
#> 072: 0.191867    0.982445    3.478329    0.160208    0.081823    0.025252    0.728814    
#> 073: 0.265333    0.994700    3.495127    0.152198    0.077732    0.026254    0.723746    
#> 074: 0.233142    0.994819    3.472465    0.184023    0.082436    0.024941    0.712701    
#> 075: 0.247678    0.999197    3.503005    0.174821    0.081513    0.023694    0.708089    
#> 076: 0.269191    1.001180    3.500084    0.166080    0.077437    0.025593    0.719824    
#> 077: 0.267718    0.989819    3.495297    0.157776    0.073565    0.025038    0.713168    
#> 078: 0.279946    0.990573    3.499144    0.149888    0.073513    0.023786    0.707806    
#> 079: 0.288932    0.991724    3.497989    0.146911    0.088774    0.026071    0.723293    
#> 080: 0.304415    0.998998    3.510608    0.160716    0.093926    0.027641    0.704360    
#> 081: 0.294606    1.007472    3.503515    0.152680    0.089230    0.027600    0.699944    
#> 082: 0.248959    0.991001    3.490730    0.145046    0.091439    0.026220    0.696394    
#> 083: 0.234995    1.015521    3.486978    0.142839    0.086867    0.024909    0.692060    
#> 084: 0.242588    1.007091    3.475770    0.152139    0.082524    0.023663    0.688732    
#> 085: 0.243242    1.008388    3.492894    0.168035    0.078398    0.022480    0.709273    
#> 086: 0.224403    0.998117    3.490114    0.159633    0.078179    0.021356    0.690591    
#> 087: 0.220900    1.006898    3.476823    0.151651    0.074346    0.020288    0.700255    
#> 088: 0.205751    1.005960    3.483258    0.144069    0.070935    0.020186    0.707862    
#> 089: 0.223289    1.023454    3.466915    0.136865    0.087679    0.019321    0.714154    
#> 090: 0.210467    1.025690    3.474454    0.130022    0.087799    0.021311    0.699912    
#> 091: 0.190403    1.025749    3.448081    0.137018    0.083409    0.022114    0.691957    
#> 092: 0.179993    1.029723    3.449799    0.142677    0.079239    0.022322    0.713297    
#> 093: 0.153528    1.025885    3.456828    0.143191    0.075585    0.021206    0.720322    
#> 094: 0.180359    1.034811    3.459590    0.136152    0.074683    0.020146    0.718832    
#> 095: 0.183772    1.037825    3.462587    0.129345    0.070949    0.019138    0.719118    
#> 096: 0.178155    1.045637    3.448850    0.122877    0.067402    0.019706    0.720940    
#> 097: 0.181265    1.042749    3.458889    0.139976    0.064032    0.018721    0.732939    
#> 098: 0.178504    1.042635    3.470850    0.132977    0.071738    0.018015    0.745591    
#> 099: 0.208832    1.018859    3.458762    0.152757    0.079854    0.019045    0.708175    
#> 100: 0.195606    1.030686    3.445519    0.164548    0.087519    0.019074    0.696407    
#> 101: 0.173109    1.022031    3.428006    0.162281    0.083143    0.018121    0.699541    
#> 102: 0.127056    1.037291    3.418686    0.154167    0.086745    0.017215    0.718209    
#> 103: 0.153923    1.045614    3.428317    0.170456    0.082408    0.016354    0.705552    
#> 104: 0.157255    1.048183    3.440470    0.161934    0.081014    0.015536    0.718371    
#> 105: 0.187857    1.026650    3.448675    0.169206    0.090177    0.014759    0.710689    
#> 106: 0.208718    1.036991    3.445697    0.160746    0.094024    0.014021    0.705251    
#> 107: 0.244920    1.028827    3.461164    0.169006    0.089323    0.016952    0.704345    
#> 108: 0.223998    1.008227    3.462415    0.178417    0.084857    0.016104    0.714057    
#> 109: 0.197979    1.017821    3.470963    0.185781    0.080614    0.015875    0.706056    
#> 110: 0.182908    1.027519    3.448866    0.218769    0.080927    0.015749    0.685892    
#> 111: 0.215648    1.019815    3.461824    0.207830    0.081197    0.016103    0.692709    
#> 112: 0.208403    0.993691    3.450206    0.197439    0.081069    0.017513    0.701571    
#> 113: 0.171904    1.048304    3.445428    0.187567    0.087770    0.016638    0.695314    
#> 114: 0.176819    1.049085    3.450553    0.192495    0.084502    0.015806    0.699744    
#> 115: 0.216448    1.012621    3.452883    0.182870    0.081267    0.015015    0.723849    
#> 116: 0.192168    1.034485    3.459881    0.173727    0.081135    0.019893    0.726239    
#> 117: 0.212199    1.033697    3.467222    0.183326    0.085200    0.018898    0.725056    
#> 118: 0.224542    1.014521    3.459602    0.174160    0.080940    0.017953    0.706341    
#> 119: 0.206148    1.012191    3.469922    0.165452    0.076893    0.022963    0.724445    
#> 120: 0.199891    1.012960    3.471264    0.172445    0.073048    0.023556    0.703979    
#> 121: 0.195693    1.050755    3.464919    0.163823    0.069396    0.024709    0.706996    
#> 122: 0.209501    1.025520    3.471958    0.155632    0.081663    0.024436    0.716662    
#> 123: 0.254149    1.040373    3.461401    0.147997    0.077580    0.023215    0.700354    
#> 124: 0.242302    1.065118    3.471632    0.140597    0.073701    0.023262    0.715071    
#> 125: 0.238989    1.019250    3.469635    0.133567    0.070016    0.022099    0.723243    
#> 126: 0.222071    1.033164    3.460938    0.176816    0.066515    0.025247    0.724782    
#> 127: 0.208020    1.023455    3.452527    0.184188    0.063190    0.023984    0.711979    
#> 128: 0.174516    1.023111    3.469681    0.174978    0.077751    0.022785    0.698957    
#> 129: 0.224167    1.029157    3.478479    0.174769    0.080841    0.021646    0.719641    
#> 130: 0.252581    1.043976    3.476136    0.166031    0.085678    0.021886    0.710652    
#> 131: 0.207440    1.021459    3.454125    0.157729    0.086132    0.020792    0.709373    
#> 132: 0.181489    1.044057    3.433903    0.149843    0.085622    0.019752    0.712967    
#> 133: 0.192933    1.014467    3.440551    0.179446    0.082040    0.018765    0.715746    
#> 134: 0.217301    1.008752    3.470882    0.170474    0.088623    0.023606    0.713205    
#> 135: 0.209015    1.007569    3.478237    0.161950    0.091721    0.022425    0.705538    
#> 136: 0.232443    0.991628    3.475209    0.162410    0.087135    0.021304    0.709459    
#> 137: 0.262820    0.995070    3.490744    0.154290    0.082779    0.020239    0.710184    
#> 138: 0.286250    0.994118    3.493350    0.146575    0.078640    0.019227    0.707267    
#> 139: 0.273977    0.987282    3.506097    0.139246    0.074708    0.023558    0.707144    
#> 140: 0.254788    1.011607    3.491974    0.132284    0.072765    0.022380    0.707775    
#> 141: 0.248014    0.997255    3.490015    0.151143    0.088532    0.021261    0.699027    
#> 142: 0.276022    0.984899    3.508389    0.143586    0.101244    0.020198    0.710678    
#> 143: 0.213628    0.998818    3.491092    0.136407    0.096182    0.019188    0.718844    
#> 144: 0.268347    0.999768    3.497758    0.129587    0.091373    0.018229    0.706531    
#> 145: 0.242565    1.010290    3.484013    0.133742    0.086804    0.019853    0.706599    
#> 146: 0.215632    1.012264    3.488873    0.127055    0.082464    0.018861    0.721974    
#> 147: 0.181267    0.999084    3.472222    0.120702    0.078341    0.018785    0.709010    
#> 148: 0.222234    1.014172    3.484944    0.126428    0.074424    0.023531    0.713589    
#> 149: 0.233182    1.007894    3.476700    0.131205    0.072119    0.023214    0.702475    
#> 150: 0.252071    1.002083    3.472674    0.124645    0.085256    0.022253    0.706791    
#> 151: 0.242220    1.021432    3.481782    0.149308    0.080994    0.024092    0.713695    
#> 152: 0.232103    1.009677    3.490731    0.147659    0.067396    0.021796    0.708119    
#> 153: 0.240879    0.997848    3.502344    0.130989    0.068548    0.026941    0.713133    
#> 154: 0.284346    0.998629    3.503922    0.128971    0.059352    0.030335    0.714447    
#> 155: 0.261098    0.983830    3.505313    0.132899    0.072471    0.025985    0.686904    
#> 156: 0.253383    0.999626    3.487730    0.139600    0.067211    0.021238    0.705972    
#> 157: 0.261108    0.997590    3.493498    0.150561    0.075439    0.017656    0.706905    
#> 158: 0.275091    1.009271    3.486040    0.133451    0.069072    0.019307    0.700208    
#> 159: 0.219642    1.012814    3.493787    0.131975    0.075394    0.019326    0.701634    
#> 160: 0.255119    0.968666    3.502007    0.144874    0.092265    0.020406    0.708151    
#> 161: 0.219415    0.997604    3.476830    0.157290    0.085285    0.019764    0.722902    
#> 162: 0.199135    1.048283    3.445396    0.152992    0.081864    0.017763    0.714056    
#> 163: 0.242129    1.029577    3.456461    0.181870    0.083584    0.019977    0.712907    
#> 164: 0.243988    1.009993    3.468959    0.192345    0.062359    0.024167    0.712867    
#> 165: 0.242982    1.015849    3.482960    0.123037    0.063953    0.025164    0.688049    
#> 166: 0.294153    1.028477    3.494301    0.164597    0.063940    0.021700    0.701742    
#> 167: 0.301410    1.020816    3.502291    0.180039    0.068804    0.025156    0.706950    
#> 168: 0.273113    1.027955    3.490848    0.192947    0.075145    0.021552    0.701782    
#> 169: 0.249935    1.050638    3.474561    0.200102    0.076386    0.021570    0.711914    
#> 170: 0.260468    1.007002    3.492266    0.191364    0.069712    0.020546    0.692508    
#> 171: 0.208758    1.014200    3.474215    0.187662    0.072216    0.026513    0.672382    
#> 172: 0.200088    1.034221    3.471751    0.160230    0.068711    0.023373    0.689701    
#> 173: 0.212277    1.042864    3.466770    0.156481    0.066103    0.025999    0.676352    
#> 174: 0.239667    1.023688    3.477454    0.162885    0.044451    0.030085    0.698239    
#> 175: 0.208786    1.027884    3.458973    0.136927    0.047704    0.029043    0.700068    
#> 176: 0.195326    1.053481    3.465376    0.137900    0.052836    0.026204    0.713740    
#> 177: 0.185825    1.043898    3.463794    0.161609    0.051114    0.025394    0.729059    
#> 178: 0.202673    1.011830    3.467483    0.146704    0.055955    0.025808    0.711875    
#> 179: 0.246166    1.029775    3.476282    0.107079    0.066165    0.027517    0.715153    
#> 180: 0.253815    1.001654    3.494806    0.104928    0.061636    0.027193    0.716941    
#> 181: 0.233614    0.977854    3.476991    0.091458    0.057981    0.024111    0.728436    
#> 182: 0.220494    0.984555    3.481750    0.093263    0.059778    0.029379    0.742331    
#> 183: 0.212371    1.000775    3.482892    0.102153    0.058726    0.024146    0.719317    
#> 184: 0.220232    1.005448    3.478865    0.126430    0.063430    0.019893    0.706417    
#> 185: 0.210298    1.018407    3.474852    0.131380    0.076253    0.025596    0.702763    
#> 186: 0.231466    1.035441    3.476869    0.126956    0.078810    0.027728    0.703623    
#> 187: 0.240132    1.025446    3.480160    0.168167    0.070044    0.026910    0.699151    
#> 188: 0.203155    1.045933    3.471922    0.152330    0.070503    0.026794    0.723509    
#> 189: 0.227836    1.046027    3.479066    0.139834    0.072958    0.026529    0.734500    
#> 190: 0.235747    1.014106    3.481303    0.137742    0.063368    0.025910    0.719346    
#> 191: 0.205042    1.035797    3.468811    0.119547    0.063576    0.020538    0.706042    
#> 192: 0.210472    1.049848    3.460030    0.128100    0.064559    0.018566    0.692044    
#> 193: 0.239573    1.056716    3.463230    0.155020    0.082442    0.017298    0.686401    
#> 194: 0.200951    1.034424    3.458243    0.166846    0.077797    0.016572    0.699234    
#> 195: 0.211661    1.015575    3.455939    0.142691    0.063567    0.017111    0.691957    
#> 196: 0.210202    1.017643    3.467621    0.152576    0.070898    0.016050    0.713547    
#> 197: 0.187943    1.011211    3.491173    0.129824    0.075099    0.018590    0.728914    
#> 198: 0.246230    0.997084    3.486147    0.142452    0.077020    0.020056    0.715837    
#> 199: 0.246972    1.002270    3.475179    0.140920    0.087605    0.015995    0.724304    
#> 200: 0.238967    1.022048    3.475946    0.181088    0.101394    0.018111    0.699302    
#> 201: 0.241024    1.016221    3.483983    0.179238    0.095773    0.018092    0.704146    
#> 202: 0.238588    1.013673    3.486257    0.174760    0.084985    0.018616    0.707121    
#> 203: 0.244595    1.011316    3.484985    0.171872    0.082914    0.018731    0.708215    
#> 204: 0.244547    1.005988    3.484550    0.171896    0.080453    0.018496    0.714252    
#> 205: 0.239900    1.010724    3.483578    0.168700    0.079110    0.019048    0.716627    
#> 206: 0.241128    1.011324    3.483998    0.167644    0.078424    0.019109    0.716309    
#> 207: 0.240227    1.009794    3.482046    0.165382    0.079602    0.019151    0.716602    
#> 208: 0.237222    1.010083    3.480578    0.160235    0.077859    0.019327    0.716413    
#> 209: 0.238401    1.009168    3.479143    0.157561    0.077689    0.019208    0.715255    
#> 210: 0.241020    1.007008    3.479299    0.154262    0.077753    0.018872    0.713590    
#> 211: 0.242514    1.007307    3.480188    0.151824    0.078701    0.018827    0.711521    
#> 212: 0.242733    1.007573    3.480888    0.149039    0.079265    0.018629    0.711372    
#> 213: 0.245216    1.004779    3.481512    0.146528    0.078888    0.018495    0.713454    
#> 214: 0.247777    1.003817    3.481910    0.147891    0.079289    0.018264    0.713967    
#> 215: 0.248908    1.003875    3.482851    0.147377    0.079600    0.018034    0.714237    
#> 216: 0.249878    1.003265    3.483465    0.147209    0.080097    0.017738    0.714714    
#> 217: 0.247605    1.004573    3.483504    0.146465    0.080318    0.017372    0.713619    
#> 218: 0.247020    1.005772    3.482895    0.147240    0.080390    0.017106    0.712609    
#> 219: 0.246130    1.005858    3.481613    0.148299    0.079888    0.017102    0.711798    
#> 220: 0.244032    1.006845    3.480957    0.148822    0.079797    0.017284    0.711338    
#> 221: 0.241917    1.007515    3.480047    0.148651    0.079163    0.017391    0.711176    
#> 222: 0.241182    1.008534    3.478977    0.149240    0.079231    0.017664    0.710858    
#> 223: 0.241481    1.008740    3.478673    0.147769    0.078493    0.017928    0.710806    
#> 224: 0.241749    1.008934    3.478832    0.146958    0.078148    0.018237    0.710098    
#> 225: 0.241728    1.007129    3.479280    0.146251    0.077404    0.018486    0.710312    
#> 226: 0.242609    1.005618    3.479269    0.146385    0.077168    0.018560    0.710772    
#> 227: 0.241521    1.005438    3.479417    0.146904    0.077239    0.018574    0.710613    
#> 228: 0.240761    1.006197    3.478761    0.147398    0.077166    0.018620    0.710323    
#> 229: 0.240400    1.006139    3.478407    0.147939    0.076639    0.018721    0.709505    
#> 230: 0.240621    1.006454    3.477989    0.147562    0.076243    0.018688    0.709056    
#> 231: 0.240461    1.006790    3.477978    0.147492    0.075907    0.018716    0.708313    
#> 232: 0.239281    1.007332    3.477918    0.147017    0.075567    0.018783    0.707665    
#> 233: 0.238796    1.006407    3.478002    0.147162    0.075416    0.018693    0.707339    
#> 234: 0.237861    1.007002    3.477825    0.146894    0.075806    0.018724    0.707197    
#> 235: 0.236834    1.006960    3.477199    0.147355    0.075471    0.018714    0.707357    
#> 236: 0.236269    1.007239    3.476891    0.147027    0.075540    0.018688    0.707626    
#> 237: 0.235921    1.007638    3.476758    0.146523    0.075679    0.018636    0.708209    
#> 238: 0.235394    1.008211    3.476577    0.146943    0.076037    0.018439    0.708992    
#> 239: 0.235533    1.009383    3.476323    0.146755    0.076615    0.018340    0.709206    
#> 240: 0.235297    1.009640    3.476194    0.146488    0.076815    0.018285    0.709030    
#> 241: 0.235171    1.009349    3.476360    0.146234    0.076990    0.018209    0.708898    
#> 242: 0.235114    1.009045    3.476192    0.145692    0.076884    0.018129    0.709602    
#> 243: 0.233850    1.009336    3.476048    0.145119    0.076885    0.018090    0.709873    
#> 244: 0.233152    1.009514    3.476109    0.145362    0.076957    0.018055    0.710132    
#> 245: 0.233292    1.009397    3.476368    0.145295    0.077078    0.018084    0.710349    
#> 246: 0.233608    1.008974    3.476730    0.145897    0.077077    0.018110    0.710276    
#> 247: 0.233642    1.008064    3.477261    0.146206    0.077384    0.018140    0.710772    
#> 248: 0.233960    1.008107    3.477374    0.146275    0.077852    0.018086    0.710864    
#> 249: 0.234000    1.008034    3.477387    0.146580    0.077682    0.018058    0.710774    
#> 250: 0.234372    1.008350    3.477548    0.146617    0.077767    0.018082    0.710607    
#> 251: 0.234686    1.008814    3.477634    0.147002    0.077843    0.018068    0.710338    
#> 252: 0.235466    1.009254    3.478079    0.146848    0.077931    0.018048    0.710289    
#> 253: 0.235721    1.009378    3.478207    0.147002    0.078020    0.018016    0.710375    
#> 254: 0.236075    1.009953    3.478369    0.146810    0.078215    0.017949    0.710247    
#> 255: 0.235850    1.010077    3.478519    0.146633    0.078225    0.017966    0.710289    
#> 256: 0.235978    1.009942    3.478584    0.146202    0.078113    0.017969    0.710578    
#> 257: 0.235383    1.009295    3.478473    0.146570    0.078025    0.017905    0.710693    
#> 258: 0.234982    1.008781    3.478518    0.146078    0.077906    0.017896    0.710627    
#> 259: 0.234764    1.008632    3.478596    0.146131    0.077967    0.017932    0.710386    
#> 260: 0.234509    1.008525    3.478660    0.146659    0.077917    0.017986    0.709939    
#> 261: 0.234240    1.008405    3.478716    0.146586    0.078108    0.017988    0.709975    
#> 262: 0.234935    1.008404    3.478857    0.146222    0.078155    0.017997    0.710211    
#> 263: 0.234599    1.008644    3.478867    0.145693    0.078088    0.018024    0.710326    
#> 264: 0.234396    1.008764    3.478719    0.145757    0.078134    0.018023    0.710550    
#> 265: 0.234349    1.008972    3.478711    0.145894    0.078158    0.017970    0.710743    
#> 266: 0.234449    1.009069    3.478723    0.145717    0.078118    0.017924    0.710707    
#> 267: 0.234340    1.009117    3.478854    0.145485    0.078200    0.017932    0.710495    
#> 268: 0.234627    1.008983    3.478846    0.145412    0.078061    0.017925    0.710421    
#> 269: 0.235430    1.008837    3.479013    0.145243    0.078207    0.017926    0.710332    
#> 270: 0.236028    1.008878    3.479102    0.145085    0.078132    0.017925    0.709955    
#> 271: 0.236156    1.008894    3.479069    0.145244    0.078070    0.017993    0.710164    
#> 272: 0.235617    1.008940    3.478851    0.145583    0.078102    0.017982    0.710579    
#> 273: 0.234980    1.009308    3.478773    0.145212    0.078358    0.017944    0.710869    
#> 274: 0.234521    1.009369    3.478884    0.145002    0.078278    0.017942    0.710883    
#> 275: 0.233997    1.009685    3.478709    0.144643    0.078337    0.017933    0.710938    
#> 276: 0.233704    1.009944    3.478858    0.144487    0.078415    0.017988    0.710896    
#> 277: 0.233427    1.010264    3.478982    0.144348    0.078477    0.018016    0.710847    
#> 278: 0.233574    1.010242    3.479200    0.144289    0.078499    0.018009    0.710802    
#> 279: 0.233586    1.009967    3.479399    0.144176    0.078712    0.018023    0.710972    
#> 280: 0.233869    1.010012    3.479474    0.143787    0.078692    0.018037    0.710878    
#> 281: 0.233543    1.010277    3.479504    0.143602    0.078690    0.018052    0.711006    
#> 282: 0.233782    1.010529    3.479567    0.144013    0.078896    0.018021    0.710909    
#> 283: 0.233695    1.010564    3.479702    0.144077    0.078908    0.017987    0.711081    
#> 284: 0.233673    1.010279    3.479758    0.143929    0.078831    0.017963    0.711173    
#> 285: 0.233688    1.010411    3.479449    0.144056    0.078990    0.017923    0.711351    
#> 286: 0.233855    1.010326    3.479398    0.144072    0.079221    0.017916    0.711269    
#> 287: 0.233972    1.010315    3.479277    0.144347    0.079035    0.017925    0.711151    
#> 288: 0.234390    1.010184    3.479323    0.144538    0.079106    0.017957    0.711023    
#> 289: 0.234651    1.009940    3.479380    0.144457    0.079017    0.018007    0.711058    
#> 290: 0.234694    1.009856    3.479427    0.144392    0.079059    0.018007    0.711078    
#> 291: 0.234841    1.009979    3.479532    0.144090    0.079095    0.018007    0.711041    
#> 292: 0.234577    1.010117    3.479426    0.144038    0.079068    0.017994    0.710944    
#> 293: 0.234469    1.010122    3.479352    0.143825    0.078954    0.017975    0.710947    
#> 294: 0.234167    1.010178    3.479216    0.143588    0.078861    0.017946    0.710874    
#> 295: 0.234106    1.009917    3.479135    0.143557    0.078897    0.017955    0.710951    
#> 296: 0.233922    1.009874    3.478992    0.143590    0.078787    0.018001    0.711019    
#> 297: 0.233877    1.010066    3.478999    0.143353    0.078716    0.018035    0.711100    
#> 298: 0.233954    1.009918    3.478956    0.143721    0.078620    0.018039    0.710957    
#> 299: 0.234059    1.010074    3.478866    0.144079    0.078659    0.018031    0.710800    
#> 300: 0.234453    1.009879    3.479029    0.144197    0.078616    0.018012    0.710739    
#> 301: 0.234725    1.009824    3.479043    0.144258    0.078640    0.018012    0.710821    
#> 302: 0.234735    1.009894    3.478965    0.144336    0.078685    0.018008    0.710621    
#> 303: 0.234870    1.010113    3.478989    0.144462    0.078694    0.018043    0.710393    
#> 304: 0.234947    1.010238    3.478938    0.144418    0.078649    0.018067    0.710279    
#> 305: 0.234734    1.010089    3.478809    0.144612    0.078732    0.018093    0.710154    
#> 306: 0.234480    1.009973    3.478725    0.144610    0.078637    0.018090    0.710165    
#> 307: 0.234371    1.010029    3.478604    0.144468    0.078680    0.018102    0.710426    
#> 308: 0.233826    1.010091    3.478427    0.144465    0.078586    0.018119    0.710477    
#> 309: 0.233714    1.009888    3.478365    0.144511    0.078456    0.018143    0.710668    
#> 310: 0.233593    1.009860    3.478170    0.144523    0.078472    0.018154    0.710657    
#> 311: 0.233612    1.009910    3.478158    0.144684    0.078580    0.018159    0.710611    
#> 312: 0.233504    1.009992    3.478053    0.144676    0.078623    0.018153    0.710505    
#> 313: 0.233316    1.009866    3.477955    0.144695    0.078535    0.018142    0.710785    
#> 314: 0.232897    1.010079    3.477729    0.144690    0.078487    0.018133    0.710718    
#> 315: 0.232564    1.010295    3.477681    0.144860    0.078575    0.018140    0.710771    
#> 316: 0.232729    1.010345    3.477716    0.144907    0.078559    0.018148    0.710643    
#> 317: 0.233071    1.010275    3.477816    0.144782    0.078509    0.018128    0.710691    
#> 318: 0.233340    1.010294    3.477826    0.144714    0.078326    0.018120    0.710637    
#> 319: 0.233564    1.010260    3.477920    0.144779    0.078191    0.018159    0.710619    
#> 320: 0.233356    1.010409    3.477832    0.144938    0.078152    0.018175    0.710572    
#> 321: 0.233173    1.010602    3.477696    0.144841    0.078083    0.018190    0.710690    
#> 322: 0.232946    1.010625    3.477574    0.145130    0.078140    0.018208    0.710811    
#> 323: 0.232520    1.010542    3.477566    0.145199    0.078205    0.018260    0.710836    
#> 324: 0.232487    1.010646    3.477571    0.145036    0.078239    0.018262    0.710796    
#> 325: 0.232372    1.010859    3.477509    0.144897    0.078218    0.018272    0.710802    
#> 326: 0.232449    1.010798    3.477451    0.144903    0.078257    0.018258    0.710806    
#> 327: 0.232690    1.010726    3.477522    0.144964    0.078323    0.018235    0.710868    
#> 328: 0.232968    1.010685    3.477604    0.145030    0.078281    0.018205    0.710835    
#> 329: 0.233435    1.010704    3.477736    0.145292    0.078360    0.018174    0.710757    
#> 330: 0.233452    1.010596    3.477835    0.145060    0.078388    0.018175    0.710780    
#> 331: 0.233519    1.010597    3.477933    0.144889    0.078468    0.018178    0.710678    
#> 332: 0.233666    1.010536    3.478087    0.144927    0.078429    0.018192    0.710569    
#> 333: 0.233663    1.010515    3.478124    0.144857    0.078390    0.018194    0.710507    
#> 334: 0.233688    1.010475    3.478062    0.144781    0.078350    0.018198    0.710435    
#> 335: 0.233438    1.010570    3.477943    0.144621    0.078321    0.018198    0.710586    
#> 336: 0.233241    1.010765    3.477866    0.144528    0.078427    0.018200    0.710658    
#> 337: 0.233155    1.011139    3.477774    0.144413    0.078518    0.018209    0.710685    
#> 338: 0.233064    1.011214    3.477766    0.144331    0.078562    0.018190    0.710593    
#> 339: 0.232870    1.011286    3.477731    0.144233    0.078649    0.018180    0.710534    
#> 340: 0.232879    1.011205    3.477759    0.144170    0.078807    0.018170    0.710511    
#> 341: 0.233080    1.011223    3.477841    0.144023    0.078995    0.018161    0.710457    
#> 342: 0.232886    1.011092    3.477809    0.143922    0.079020    0.018144    0.710446    
#> 343: 0.232522    1.011186    3.477751    0.144009    0.079152    0.018112    0.710393    
#> 344: 0.232560    1.011259    3.477727    0.143949    0.079179    0.018093    0.710481    
#> 345: 0.232534    1.011317    3.477715    0.143900    0.079193    0.018062    0.710488    
#> 346: 0.232319    1.011404    3.477591    0.143804    0.079258    0.018020    0.710370    
#> 347: 0.232387    1.011412    3.477537    0.143611    0.079311    0.018013    0.710457    
#> 348: 0.232245    1.011490    3.477476    0.143636    0.079384    0.018005    0.710496    
#> 349: 0.232042    1.011479    3.477385    0.143716    0.079398    0.017976    0.710532    
#> 350: 0.231811    1.011412    3.477226    0.143780    0.079489    0.017946    0.710583    
#> 351: 0.231763    1.011552    3.477111    0.143749    0.079455    0.017922    0.710569    
#> 352: 0.231402    1.011675    3.477011    0.143826    0.079513    0.017919    0.710659    
#> 353: 0.231197    1.011886    3.476871    0.143714    0.079467    0.017940    0.710729    
#> 354: 0.231086    1.012051    3.476690    0.143509    0.079411    0.017938    0.710769    
#> 355: 0.231345    1.011981    3.476695    0.143284    0.079361    0.017959    0.710779    
#> 356: 0.231423    1.011841    3.476769    0.143275    0.079416    0.017974    0.710764    
#> 357: 0.231438    1.011861    3.476756    0.143298    0.079408    0.017984    0.710603    
#> 358: 0.231459    1.011905    3.476766    0.143236    0.079435    0.017990    0.710448    
#> 359: 0.231418    1.011962    3.476827    0.143089    0.079546    0.017980    0.710464    
#> 360: 0.231151    1.011968    3.476682    0.143073    0.079621    0.017952    0.710497    
#> 361: 0.230781    1.011966    3.476550    0.143090    0.079588    0.017936    0.710425    
#> 362: 0.230664    1.011931    3.476452    0.143216    0.079576    0.017939    0.710228    
#> 363: 0.230674    1.011805    3.476446    0.143087    0.079525    0.017930    0.710156    
#> 364: 0.230811    1.011840    3.476475    0.143109    0.079555    0.017963    0.710180    
#> 365: 0.230864    1.011639    3.476568    0.143007    0.079561    0.018009    0.710214    
#> 366: 0.231027    1.011616    3.476602    0.142994    0.079503    0.018045    0.710183    
#> 367: 0.231147    1.011612    3.476682    0.143074    0.079459    0.018080    0.710087    
#> 368: 0.231360    1.011672    3.476712    0.142995    0.079371    0.018128    0.710091    
#> 369: 0.231393    1.011740    3.476671    0.142842    0.079322    0.018156    0.710098    
#> 370: 0.231240    1.011828    3.476610    0.142795    0.079308    0.018229    0.710039    
#> 371: 0.230970    1.011950    3.476489    0.142731    0.079394    0.018229    0.709963    
#> 372: 0.230871    1.012038    3.476406    0.142676    0.079498    0.018231    0.709986    
#> 373: 0.230714    1.012106    3.476362    0.142535    0.079486    0.018219    0.710109    
#> 374: 0.230747    1.012194    3.476286    0.142564    0.079421    0.018233    0.710072    
#> 375: 0.230736    1.012219    3.476296    0.142676    0.079364    0.018245    0.709989    
#> 376: 0.230642    1.012277    3.476319    0.142629    0.079362    0.018248    0.709814    
#> 377: 0.230617    1.012332    3.476309    0.142562    0.079446    0.018238    0.709794    
#> 378: 0.230569    1.012261    3.476264    0.142482    0.079374    0.018238    0.709888    
#> 379: 0.230427    1.012194    3.476202    0.142485    0.079362    0.018226    0.709904    
#> 380: 0.230086    1.012237    3.476041    0.142468    0.079320    0.018216    0.709955    
#> 381: 0.229782    1.012325    3.475932    0.142461    0.079319    0.018203    0.709961    
#> 382: 0.229666    1.012399    3.475892    0.142249    0.079242    0.018210    0.709920    
#> 383: 0.229871    1.012348    3.475916    0.141974    0.079188    0.018210    0.709957    
#> 384: 0.229759    1.012218    3.475938    0.141761    0.079210    0.018214    0.709985    
#> 385: 0.229706    1.012119    3.475971    0.141659    0.079212    0.018226    0.710101    
#> 386: 0.229787    1.012279    3.476053    0.141518    0.079224    0.018238    0.710163    
#> 387: 0.229943    1.012305    3.476192    0.141467    0.079188    0.018273    0.710201    
#> 388: 0.230129    1.012213    3.476286    0.141395    0.079173    0.018303    0.710184    
#> 389: 0.230209    1.012004    3.476339    0.141325    0.079166    0.018323    0.710261    
#> 390: 0.230160    1.011930    3.476322    0.141357    0.079175    0.018317    0.710315    
#> 391: 0.230160    1.011903    3.476327    0.141361    0.079137    0.018316    0.710306    
#> 392: 0.230215    1.011793    3.476363    0.141407    0.079092    0.018300    0.710414    
#> 393: 0.230107    1.011676    3.476345    0.141367    0.079125    0.018303    0.710405    
#> 394: 0.229994    1.011719    3.476279    0.141443    0.079139    0.018307    0.710402    
#> 395: 0.229973    1.011758    3.476228    0.141398    0.079129    0.018312    0.710373    
#> 396: 0.230026    1.011799    3.476210    0.141295    0.079106    0.018312    0.710363    
#> 397: 0.230201    1.011723    3.476293    0.141232    0.079064    0.018348    0.710390    
#> 398: 0.230355    1.011601    3.476451    0.141173    0.079007    0.018409    0.710417    
#> 399: 0.230719    1.011583    3.476640    0.141332    0.078968    0.018452    0.710323    
#> 400: 0.230919    1.011625    3.476737    0.141297    0.078907    0.018484    0.710305    
#> 401: 0.231036    1.011643    3.476801    0.141256    0.078930    0.018501    0.710344    
#> 402: 0.230978    1.011686    3.476827    0.141062    0.078943    0.018506    0.710311    
#> 403: 0.231121    1.011719    3.476831    0.141121    0.079043    0.018506    0.710190    
#> 404: 0.231154    1.011809    3.476749    0.141254    0.079047    0.018505    0.710096    
#> 405: 0.231024    1.011939    3.476693    0.141495    0.079018    0.018507    0.710065    
#> 406: 0.231067    1.012013    3.476653    0.141688    0.078974    0.018527    0.710121    
#> 407: 0.231143    1.012104    3.476641    0.141787    0.078999    0.018529    0.710128    
#> 408: 0.231108    1.012178    3.476610    0.142005    0.079016    0.018524    0.710157    
#> 409: 0.230922    1.012166    3.476521    0.142089    0.078955    0.018512    0.710175    
#> 410: 0.230838    1.012233    3.476423    0.142118    0.078919    0.018508    0.710244    
#> 411: 0.230703    1.012045    3.476349    0.142133    0.078903    0.018498    0.710335    
#> 412: 0.230596    1.012212    3.476255    0.142116    0.078926    0.018480    0.710415    
#> 413: 0.230475    1.012254    3.476181    0.142072    0.078926    0.018473    0.710567    
#> 414: 0.230299    1.012287    3.476158    0.142026    0.078855    0.018462    0.710618    
#> 415: 0.230336    1.012304    3.476122    0.142073    0.078788    0.018460    0.710581    
#> 416: 0.230524    1.012351    3.476146    0.142072    0.078741    0.018480    0.710593    
#> 417: 0.230519    1.012375    3.476132    0.142022    0.078773    0.018478    0.710638    
#> 418: 0.230263    1.012402    3.476105    0.141997    0.078790    0.018475    0.710640    
#> 419: 0.230079    1.012450    3.476042    0.142095    0.078836    0.018468    0.710589    
#> 420: 0.230007    1.012455    3.476031    0.142134    0.078965    0.018441    0.710469    
#> 421: 0.229871    1.012495    3.476033    0.142215    0.079069    0.018417    0.710469    
#> 422: 0.229915    1.012457    3.476031    0.142238    0.079170    0.018387    0.710473    
#> 423: 0.229959    1.012406    3.476043    0.142262    0.079270    0.018377    0.710555    
#> 424: 0.229947    1.012363    3.476042    0.142353    0.079384    0.018357    0.710579    
#> 425: 0.230140    1.012421    3.476037    0.142337    0.079365    0.018351    0.710663    
#> 426: 0.230185    1.012577    3.476020    0.142377    0.079375    0.018351    0.710625    
#> 427: 0.230129    1.012614    3.476034    0.142401    0.079388    0.018345    0.710557    
#> 428: 0.229993    1.012698    3.476066    0.142368    0.079390    0.018350    0.710524    
#> 429: 0.230059    1.012738    3.476139    0.142324    0.079408    0.018365    0.710508    
#> 430: 0.229999    1.012834    3.476089    0.142307    0.079391    0.018362    0.710470    
#> 431: 0.229848    1.012827    3.476021    0.142237    0.079415    0.018347    0.710368    
#> 432: 0.229856    1.012892    3.476017    0.142016    0.079496    0.018340    0.710338    
#> 433: 0.229923    1.013012    3.476049    0.141828    0.079494    0.018351    0.710342    
#> 434: 0.229872    1.012992    3.476067    0.141737    0.079443    0.018373    0.710291    
#> 435: 0.229938    1.012967    3.476113    0.141671    0.079403    0.018381    0.710268    
#> 436: 0.230043    1.012861    3.476199    0.141474    0.079397    0.018377    0.710359    
#> 437: 0.230071    1.012761    3.476213    0.141474    0.079416    0.018353    0.710343    
#> 438: 0.230044    1.012904    3.476180    0.141592    0.079382    0.018349    0.710254    
#> 439: 0.230147    1.013001    3.476201    0.141574    0.079372    0.018350    0.710128    
#> 440: 0.230081    1.013082    3.476220    0.141497    0.079344    0.018368    0.710097    
#> 441: 0.230108    1.013035    3.476280    0.141526    0.079350    0.018382    0.710021    
#> 442: 0.230038    1.013053    3.476316    0.141503    0.079371    0.018384    0.709940    
#> 443: 0.229924    1.013155    3.476224    0.141454    0.079354    0.018376    0.709901    
#> 444: 0.229752    1.013312    3.476097    0.141386    0.079361    0.018365    0.709910    
#> 445: 0.229674    1.013410    3.476025    0.141287    0.079380    0.018357    0.709981    
#> 446: 0.229645    1.013387    3.476001    0.141302    0.079425    0.018351    0.709940    
#> 447: 0.229672    1.013423    3.475993    0.141360    0.079407    0.018358    0.709902    
#> 448: 0.229560    1.013454    3.475998    0.141458    0.079375    0.018360    0.709865    
#> 449: 0.229579    1.013522    3.476101    0.141510    0.079367    0.018379    0.709877    
#> 450: 0.229624    1.013535    3.476101    0.141560    0.079337    0.018395    0.709868    
#> 451: 0.229697    1.013511    3.476097    0.141612    0.079304    0.018421    0.709826    
#> 452: 0.229692    1.013505    3.476063    0.141624    0.079230    0.018438    0.709766    
#> 453: 0.229606    1.013526    3.476002    0.141642    0.079204    0.018434    0.709685    
#> 454: 0.229381    1.013696    3.475912    0.141487    0.079215    0.018433    0.709681    
#> 455: 0.229288    1.013790    3.475850    0.141349    0.079196    0.018434    0.709681    
#> 456: 0.229111    1.013922    3.475764    0.141337    0.079204    0.018446    0.709677    
#> 457: 0.228985    1.013943    3.475727    0.141372    0.079165    0.018445    0.709627    
#> 458: 0.228882    1.014047    3.475720    0.141396    0.079106    0.018450    0.709558    
#> 459: 0.228779    1.014198    3.475655    0.141333    0.079065    0.018437    0.709535    
#> 460: 0.228673    1.014150    3.475581    0.141239    0.079014    0.018448    0.709536    
#> 461: 0.228487    1.014137    3.475571    0.141187    0.079037    0.018457    0.709550    
#> 462: 0.228471    1.014176    3.475611    0.141263    0.079014    0.018459    0.709525    
#> 463: 0.228576    1.014175    3.475632    0.141308    0.079029    0.018448    0.709555    
#> 464: 0.228702    1.014171    3.475646    0.141351    0.079088    0.018430    0.709475    
#> 465: 0.228760    1.014078    3.475694    0.141424    0.079122    0.018407    0.709490    
#> 466: 0.228845    1.014143    3.475672    0.141486    0.079150    0.018406    0.709422    
#> 467: 0.228852    1.014158    3.475681    0.141570    0.079133    0.018398    0.709301    
#> 468: 0.228963    1.014140    3.475732    0.141676    0.079127    0.018423    0.709348    
#> 469: 0.228932    1.014212    3.475729    0.141702    0.079112    0.018466    0.709362    
#> 470: 0.228918    1.014218    3.475714    0.141726    0.079092    0.018508    0.709414    
#> 471: 0.228817    1.014189    3.475685    0.141709    0.079077    0.018528    0.709419    
#> 472: 0.228815    1.014158    3.475722    0.141664    0.079038    0.018551    0.709390    
#> 473: 0.228767    1.014049    3.475737    0.141657    0.079052    0.018560    0.709354    
#> 474: 0.228791    1.013930    3.475777    0.141656    0.079080    0.018581    0.709364    
#> 475: 0.228906    1.013998    3.475786    0.141618    0.079079    0.018579    0.709362    
#> 476: 0.228974    1.014036    3.475774    0.141525    0.079087    0.018580    0.709408    
#> 477: 0.228925    1.014083    3.475787    0.141497    0.079081    0.018591    0.709290    
#> 478: 0.228893    1.014081    3.475774    0.141378    0.079010    0.018600    0.709241    
#> 479: 0.228952    1.014153    3.475772    0.141264    0.079018    0.018608    0.709238    
#> 480: 0.229041    1.014109    3.475832    0.141158    0.079035    0.018609    0.709346    
#> 481: 0.228985    1.014081    3.475857    0.141181    0.079007    0.018618    0.709370    
#> 482: 0.229042    1.014062    3.475855    0.141136    0.078971    0.018621    0.709418    
#> 483: 0.228979    1.014011    3.475854    0.141101    0.079012    0.018613    0.709405    
#> 484: 0.228943    1.013881    3.475846    0.141100    0.079011    0.018609    0.709432    
#> 485: 0.228953    1.013884    3.475826    0.141084    0.079004    0.018599    0.709472    
#> 486: 0.228935    1.013939    3.475840    0.141073    0.078996    0.018595    0.709472    
#> 487: 0.229111    1.013862    3.475927    0.141058    0.078993    0.018611    0.709519    
#> 488: 0.229107    1.013846    3.475918    0.141027    0.078982    0.018607    0.709500    
#> 489: 0.229284    1.013841    3.475908    0.141017    0.078976    0.018603    0.709573    
#> 490: 0.229397    1.013821    3.475939    0.141043    0.078999    0.018611    0.709564    
#> 491: 0.229481    1.013812    3.475960    0.141051    0.079027    0.018614    0.709556    
#> 492: 0.229463    1.013801    3.475972    0.141036    0.078989    0.018613    0.709643    
#> 493: 0.229420    1.013824    3.475992    0.140950    0.078918    0.018629    0.709677    
#> 494: 0.229491    1.013914    3.475966    0.140880    0.078884    0.018639    0.709706    
#> 495: 0.229486    1.013950    3.475932    0.140822    0.078845    0.018652    0.709705    
#> 496: 0.229483    1.014037    3.475863    0.140796    0.078818    0.018653    0.709718    
#> 497: 0.229345    1.014051    3.475810    0.140959    0.078785    0.018648    0.709728    
#> 498: 0.229220    1.014095    3.475691    0.141057    0.078766    0.018649    0.709697    
#> 499: 0.229126    1.014149    3.475610    0.141047    0.078782    0.018645    0.709629    
#> 500: 0.229067    1.014140    3.475533    0.141086    0.078758    0.018651    0.709576    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.242609    0.969225    3.443535    0.392401    0.075561    0.016800    1.648887    
#> 002: 0.120756    0.953130    3.487282    0.372781    0.071783    0.017446    1.071519    
#> 003: 0.150330    0.894395    3.480192    0.354142    0.078970    0.016574    0.791423    
#> 004: 0.064058    0.893709    3.468198    0.336435    0.075021    0.015745    0.728789    
#> 005: 0.123072    0.912975    3.468777    0.319613    0.071270    0.018193    0.708345    
#> 006: 0.053774    0.920900    3.445568    0.303633    0.089440    0.017284    0.653422    
#> 007: 0.004082    0.934179    3.430113    0.288451    0.095148    0.018202    0.642750    
#> 008: 0.009967    0.949404    3.423954    0.274029    0.090391    0.021872    0.656404    
#> 009: -0.041987   0.936989    3.408330    0.260327    0.085871    0.020824    0.659365    
#> 010: -0.035730   0.933653    3.414329    0.247311    0.081578    0.021679    0.671974    
#> 011: 0.003320    0.953007    3.420703    0.234945    0.088084    0.020595    0.667959    
#> 012: 0.006870    0.960130    3.405879    0.223198    0.090287    0.025249    0.642487    
#> 013: -0.037301   0.954922    3.401220    0.212038    0.096896    0.027096    0.621621    
#> 014: -0.012363   0.944879    3.409943    0.201436    0.092051    0.025742    0.639961    
#> 015: -0.014918   0.948409    3.412673    0.191364    0.087448    0.029723    0.629287    
#> 016: -0.005000   0.954439    3.421875    0.181796    0.083076    0.028237    0.640988    
#> 017: 0.004432    0.955332    3.423318    0.172706    0.085762    0.026825    0.630816    
#> 018: 0.004605    0.942521    3.412985    0.164071    0.094100    0.025484    0.651489    
#> 019: -0.013754   0.949992    3.414620    0.155867    0.089395    0.024210    0.632238    
#> 020: -0.012490   0.948401    3.422766    0.148074    0.084925    0.030161    0.643569    
#> 021: 0.035357    0.919767    3.435893    0.140670    0.080679    0.028653    0.632438    
#> 022: 0.031371    0.928472    3.448859    0.133637    0.076645    0.027972    0.631210    
#> 023: 0.079199    0.941933    3.444677    0.126955    0.075723    0.026573    0.647774    
#> 024: 0.061929    0.977345    3.438011    0.120607    0.074390    0.025244    0.656249    
#> 025: 0.036035    0.941168    3.437616    0.114577    0.078846    0.028009    0.630508    
#> 026: 0.033717    0.949216    3.430614    0.108848    0.081145    0.026608    0.632327    
#> 027: 0.013142    0.962270    3.433475    0.103406    0.077087    0.027555    0.620989    
#> 028: 0.044319    0.952493    3.428905    0.106756    0.081521    0.026707    0.619012    
#> 029: 0.056702    0.940553    3.429590    0.124899    0.094628    0.025371    0.630731    
#> 030: 0.047761    0.946791    3.430456    0.126866    0.089897    0.027956    0.621875    
#> 031: -0.006197   0.924479    3.432879    0.127305    0.099100    0.026558    0.614981    
#> 032: 0.014852    0.932941    3.427173    0.120940    0.094145    0.025231    0.617427    
#> 033: 0.010956    0.965570    3.424469    0.114893    0.089438    0.023969    0.630699    
#> 034: 0.010070    0.981616    3.415233    0.127344    0.084966    0.025411    0.631382    
#> 035: -0.044286   0.933473    3.403614    0.141465    0.080717    0.024141    0.621973    
#> 036: -0.023998   0.955794    3.409101    0.134501    0.093872    0.022934    0.632993    
#> 037: -0.043178   0.975389    3.402816    0.127776    0.089178    0.021787    0.646955    
#> 038: -0.031022   0.981066    3.396671    0.132141    0.095838    0.022511    0.651969    
#> 039: -0.024594   0.984510    3.408113    0.125534    0.091046    0.023608    0.636991    
#> 040: -0.007002   0.964737    3.437409    0.119257    0.086494    0.023547    0.634850    
#> 041: -0.036762   0.947578    3.421782    0.133146    0.082169    0.025361    0.631188    
#> 042: 0.019861    0.960013    3.429827    0.126489    0.080721    0.026124    0.626173    
#> 043: -0.019536   0.977071    3.405058    0.120164    0.076685    0.024818    0.628202    
#> 044: -0.054047   0.987672    3.400657    0.114156    0.073606    0.023577    0.639742    
#> 045: -0.038295   0.991437    3.394143    0.108448    0.069925    0.025031    0.650069    
#> 046: -0.020210   0.976470    3.398997    0.114175    0.076089    0.025502    0.641974    
#> 047: -0.030020   0.980402    3.394189    0.112449    0.093350    0.024227    0.625852    
#> 048: -0.020708   0.959755    3.401695    0.106827    0.098034    0.026734    0.635575    
#> 049: -0.032745   0.970760    3.413564    0.128282    0.100397    0.025398    0.639171    
#> 050: 0.020527    0.931090    3.428446    0.126861    0.095377    0.024128    0.653836    
#> 051: -0.007377   0.957178    3.417639    0.120518    0.090608    0.024406    0.647154    
#> 052: -0.022267   0.945124    3.426120    0.114492    0.086078    0.023186    0.624346    
#> 053: 0.002625    0.946400    3.420718    0.108767    0.088994    0.022027    0.633417    
#> 054: -0.018254   0.950332    3.425211    0.103329    0.102996    0.023454    0.644208    
#> 055: -0.020319   0.956592    3.416370    0.106286    0.097846    0.025782    0.632661    
#> 056: -0.020085   0.950920    3.419009    0.105399    0.092954    0.025594    0.639468    
#> 057: 0.009662    0.944357    3.441197    0.100129    0.088306    0.026039    0.653500    
#> 058: 0.001250    0.951074    3.410809    0.102801    0.091751    0.025069    0.641962    
#> 059: -0.001859   0.951424    3.412083    0.117146    0.087163    0.024491    0.634683    
#> 060: -0.007682   0.947950    3.425521    0.122538    0.097081    0.025534    0.638009    
#> 061: 0.017569    0.959343    3.431724    0.135697    0.114366    0.027210    0.653399    
#> 062: 0.005198    0.976688    3.430368    0.134300    0.122643    0.025849    0.639787    
#> 063: 0.009565    0.937590    3.423960    0.144613    0.116511    0.024557    0.626970    
#> 064: 0.033243    0.931807    3.435066    0.140151    0.115972    0.023329    0.645356    
#> 065: 0.021173    0.936390    3.417369    0.133144    0.110173    0.022163    0.629114    
#> 066: 0.020326    0.969052    3.429450    0.126487    0.109318    0.021054    0.623629    
#> 067: 0.031329    0.936320    3.431308    0.120895    0.103852    0.020002    0.627507    
#> 068: -0.002404   0.936203    3.438380    0.129689    0.104794    0.019002    0.648526    
#> 069: 0.006195    0.947504    3.424797    0.142787    0.099555    0.018052    0.637313    
#> 070: 0.013139    0.958549    3.429364    0.143596    0.101296    0.018052    0.626993    
#> 071: -0.001496   0.966424    3.402458    0.157453    0.112025    0.017925    0.621157    
#> 072: -0.041206   0.956216    3.400762    0.159747    0.106424    0.017579    0.624382    
#> 073: -0.000809   0.968845    3.418336    0.159915    0.101103    0.020403    0.623948    
#> 074: -0.025103   0.958662    3.410050    0.151919    0.098273    0.019383    0.614260    
#> 075: 0.010022    0.950157    3.430448    0.144323    0.097255    0.019928    0.619412    
#> 076: 0.015007    0.953601    3.434461    0.137107    0.092392    0.026523    0.620710    
#> 077: 0.042315    0.931767    3.443207    0.130252    0.087773    0.027850    0.628535    
#> 078: 0.051507    0.924250    3.445281    0.123739    0.086311    0.026718    0.615875    
#> 079: 0.047275    0.945575    3.434775    0.117552    0.096850    0.028193    0.631113    
#> 080: 0.039010    0.946457    3.440016    0.141323    0.102674    0.026783    0.628785    
#> 081: 0.025483    0.962186    3.431562    0.134256    0.097540    0.028413    0.629258    
#> 082: -0.011472   0.942914    3.426017    0.140111    0.092663    0.026992    0.641023    
#> 083: 0.004106    0.967704    3.424498    0.133105    0.088030    0.025643    0.639744    
#> 084: -0.015448   0.956640    3.419298    0.126450    0.083629    0.024360    0.626334    
#> 085: -0.018089   0.953234    3.427892    0.121216    0.086440    0.023142    0.636395    
#> 086: -0.020220   0.964742    3.414732    0.116522    0.089181    0.022332    0.621198    
#> 087: -0.029030   0.973126    3.406637    0.110696    0.084722    0.023455    0.618881    
#> 088: -0.074254   0.956371    3.411333    0.119696    0.081452    0.022282    0.640537    
#> 089: -0.069952   0.970170    3.385592    0.119302    0.090650    0.021432    0.635357    
#> 090: -0.075738   0.975231    3.383846    0.113907    0.089097    0.020360    0.640657    
#> 091: -0.087536   0.970275    3.368136    0.118781    0.096535    0.019342    0.638396    
#> 092: -0.096238   0.998889    3.372710    0.153738    0.095306    0.018375    0.617080    
#> 093: -0.111440   0.981629    3.376735    0.146051    0.090541    0.021023    0.636768    
#> 094: -0.079687   0.997164    3.383698    0.138748    0.109232    0.020042    0.641031    
#> 095: -0.085504   0.999986    3.380897    0.131811    0.103770    0.019040    0.650864    
#> 096: -0.090297   0.992037    3.376607    0.125220    0.098581    0.018413    0.649773    
#> 097: -0.058181   1.000036    3.387004    0.119565    0.097359    0.017492    0.631314    
#> 098: -0.059372   1.001315    3.389513    0.141936    0.102479    0.016618    0.628853    
#> 099: -0.062961   0.984822    3.374611    0.134840    0.105403    0.015787    0.621413    
#> 100: -0.095027   0.991926    3.374943    0.136243    0.109259    0.014997    0.617480    
#> 101: -0.101009   0.984727    3.362000    0.129463    0.103796    0.016014    0.630104    
#> 102: -0.098327   1.008225    3.354589    0.131572    0.098606    0.015213    0.650981    
#> 103: -0.063491   0.994831    3.371816    0.124993    0.093676    0.015102    0.649037    
#> 104: -0.049119   0.979531    3.400155    0.132687    0.108451    0.014347    0.667078    
#> 105: -0.038183   0.946740    3.406089    0.126052    0.111311    0.015738    0.642529    
#> 106: -0.022345   0.958164    3.397232    0.123841    0.105746    0.018483    0.641083    
#> 107: -0.022975   0.977863    3.403944    0.127886    0.100458    0.017559    0.642553    
#> 108: -0.022913   0.976851    3.398196    0.122622    0.100509    0.016681    0.648496    
#> 109: -0.043400   0.958572    3.410887    0.117718    0.101079    0.015847    0.651975    
#> 110: -0.047643   0.959740    3.389173    0.123962    0.115712    0.015055    0.635401    
#> 111: -0.052094   0.976133    3.394856    0.123035    0.109927    0.016856    0.623700    
#> 112: -0.060536   0.963904    3.384041    0.116883    0.107818    0.020247    0.625828    
#> 113: -0.042927   0.984743    3.393405    0.113921    0.102427    0.019235    0.618859    
#> 114: -0.048996   0.981041    3.389554    0.116410    0.097306    0.018273    0.623681    
#> 115: -0.038127   0.960936    3.393833    0.132582    0.092441    0.018119    0.660527    
#> 116: -0.027728   0.966624    3.397902    0.125953    0.088139    0.024081    0.663392    
#> 117: -0.064625   1.003741    3.397818    0.119655    0.096404    0.022877    0.649556    
#> 118: -0.045855   0.979087    3.391527    0.113673    0.091584    0.025456    0.650077    
#> 119: -0.040770   0.990522    3.401564    0.107989    0.087005    0.027160    0.646992    
#> 120: -0.045846   0.966987    3.403591    0.102590    0.082655    0.027327    0.652346    
#> 121: -0.037527   0.999597    3.402922    0.097460    0.078522    0.026645    0.652972    
#> 122: -0.024308   0.974850    3.423272    0.101430    0.082086    0.031268    0.633220    
#> 123: -0.003879   0.981076    3.410098    0.121829    0.077981    0.029704    0.638892    
#> 124: -0.016700   0.994537    3.412540    0.120182    0.074082    0.028219    0.640671    
#> 125: 0.011653    0.967684    3.417881    0.114173    0.070378    0.031480    0.635299    
#> 126: -0.015242   0.971250    3.412841    0.111819    0.066859    0.037055    0.648582    
#> 127: -0.007329   0.967813    3.406949    0.124300    0.068806    0.035202    0.641677    
#> 128: -0.047615   0.971353    3.398999    0.119611    0.071881    0.033442    0.625981    
#> 129: -0.034765   0.979104    3.403841    0.149602    0.087723    0.031770    0.621953    
#> 130: -0.012324   0.976912    3.398278    0.142122    0.094071    0.030182    0.614425    
#> 131: -0.035622   0.979455    3.392154    0.154772    0.100823    0.028673    0.618163    
#> 132: -0.055166   0.986798    3.386082    0.147033    0.097858    0.027239    0.631081    
#> 133: -0.062806   0.976200    3.391140    0.164072    0.103097    0.025877    0.616653    
#> 134: -0.041635   0.970973    3.407852    0.164850    0.100607    0.024583    0.637641    
#> 135: -0.049237   0.959780    3.406991    0.172074    0.116953    0.023354    0.629142    
#> 136: -0.020039   0.954659    3.406755    0.190264    0.111105    0.022186    0.623448    
#> 137: 0.024561    0.977739    3.417376    0.184630    0.105550    0.021077    0.624751    
#> 138: -0.027422   0.971012    3.401377    0.175399    0.100272    0.023479    0.621726    
#> 139: -0.000847   0.955495    3.416958    0.166629    0.104189    0.025794    0.634869    
#> 140: -0.026395   0.972208    3.410678    0.158298    0.098979    0.027077    0.641074    
#> 141: -0.025259   0.936625    3.416603    0.150383    0.094030    0.025723    0.632929    
#> 142: 0.039637    0.945075    3.442419    0.142864    0.089329    0.027019    0.637861    
#> 143: -0.011781   0.964180    3.420242    0.135720    0.084862    0.032367    0.631625    
#> 144: 0.020612    0.954953    3.421132    0.128934    0.080619    0.030749    0.615151    
#> 145: -0.029037   0.987356    3.402427    0.126130    0.077287    0.029212    0.607533    
#> 146: -0.031919   0.992434    3.398117    0.134085    0.089227    0.027751    0.616091    
#> 147: -0.063237   0.970573    3.397158    0.127380    0.085016    0.026363    0.617093    
#> 148: -0.055335   0.983042    3.403669    0.121011    0.080766    0.025045    0.630236    
#> 149: -0.056897   0.973066    3.388529    0.114961    0.093992    0.023793    0.634730    
#> 150: -0.045818   0.982969    3.381621    0.109213    0.104672    0.022603    0.631636    
#> 151: -0.068947   0.992505    3.392362    0.111627    0.099438    0.021473    0.627111    
#> 152: -0.076989   0.980340    3.391693    0.154570    0.087184    0.020961    0.613815    
#> 153: -0.053427   0.981174    3.401443    0.143366    0.085940    0.025747    0.625372    
#> 154: -0.005049   0.975860    3.407380    0.117918    0.093335    0.026985    0.642856    
#> 155: -0.038763   0.981684    3.395948    0.121683    0.092225    0.021452    0.619025    
#> 156: -0.053941   0.997117    3.400334    0.122607    0.104365    0.018996    0.643908    
#> 157: -0.031840   1.001353    3.399175    0.133115    0.112381    0.013621    0.644843    
#> 158: -0.035582   1.002815    3.390841    0.129254    0.111379    0.015355    0.615541    
#> 159: -0.070978   0.989051    3.400017    0.135193    0.101958    0.015742    0.617297    
#> 160: -0.031971   0.943073    3.411223    0.143080    0.112229    0.014454    0.627255    
#> 161: -0.052147   0.961817    3.392975    0.158023    0.109178    0.012216    0.636644    
#> 162: -0.064123   0.989359    3.378298    0.164982    0.111601    0.012689    0.633045    
#> 163: -0.041018   1.001191    3.377198    0.163435    0.119151    0.010596    0.625631    
#> 164: -0.064620   0.998315    3.379988    0.155329    0.110477    0.013863    0.630013    
#> 165: -0.030453   0.990588    3.400621    0.146910    0.104850    0.017982    0.617261    
#> 166: -0.028223   0.997178    3.397838    0.139775    0.106027    0.015381    0.635391    
#> 167: 0.002065    0.990224    3.413582    0.133768    0.105059    0.013842    0.649735    
#> 168: -0.010253   0.998909    3.401994    0.143863    0.110767    0.014231    0.638588    
#> 169: -0.036545   1.021787    3.385988    0.152841    0.114025    0.011876    0.648934    
#> 170: -0.045849   0.996475    3.390973    0.151101    0.103576    0.011940    0.629130    
#> 171: -0.079746   0.979384    3.392001    0.125746    0.093946    0.014439    0.622162    
#> 172: -0.066726   1.000420    3.389350    0.101258    0.090377    0.014651    0.620888    
#> 173: -0.044671   1.006716    3.390000    0.101765    0.092892    0.020745    0.612920    
#> 174: -0.042095   0.976079    3.403150    0.110875    0.078349    0.024202    0.625455    
#> 175: -0.053271   0.983594    3.388307    0.111000    0.089197    0.021607    0.645900    
#> 176: -0.034302   0.995147    3.402897    0.109822    0.087095    0.021698    0.633846    
#> 177: -0.025674   0.972232    3.417495    0.094889    0.080202    0.022661    0.634278    
#> 178: -0.003563   0.944122    3.418288    0.095225    0.087356    0.025281    0.617459    
#> 179: 0.019034    0.969713    3.418481    0.098929    0.077070    0.029247    0.619541    
#> 180: -0.011840   0.952802    3.433305    0.086306    0.064919    0.032559    0.643191    
#> 181: -0.012777   0.960161    3.409345    0.080682    0.066162    0.035918    0.639976    
#> 182: -0.050430   0.952039    3.401813    0.088772    0.076012    0.029589    0.651702    
#> 183: -0.041753   0.978981    3.410003    0.090781    0.057677    0.028896    0.651787    
#> 184: -0.028130   0.964124    3.411076    0.096654    0.057677    0.026790    0.643257    
#> 185: -0.026520   0.994015    3.418429    0.094013    0.066325    0.028278    0.657874    
#> 186: -0.005972   0.985134    3.421529    0.093826    0.067070    0.033409    0.634657    
#> 187: -0.016472   0.973045    3.421056    0.105119    0.063257    0.028362    0.627295    
#> 188: -0.059419   0.983814    3.406256    0.099140    0.074982    0.020466    0.638537    
#> 189: -0.017954   0.974326    3.415665    0.110326    0.080676    0.022319    0.652647    
#> 190: -0.044610   0.976958    3.413936    0.136961    0.078652    0.026438    0.631089    
#> 191: -0.055564   0.985455    3.395400    0.115992    0.079886    0.025146    0.638968    
#> 192: -0.041560   0.999228    3.396591    0.121021    0.072599    0.019437    0.614556    
#> 193: -0.029590   0.995370    3.399737    0.123940    0.084480    0.015621    0.633039    
#> 194: -0.083181   0.984278    3.377143    0.131054    0.102123    0.016027    0.632840    
#> 195: -0.098168   0.993346    3.371916    0.122941    0.081224    0.017533    0.624688    
#> 196: -0.087363   1.007097    3.381112    0.121909    0.091362    0.016397    0.643740    
#> 197: -0.089833   0.998392    3.402542    0.113953    0.091215    0.019486    0.645603    
#> 198: -0.052779   0.985068    3.388139    0.117891    0.100107    0.019664    0.632835    
#> 199: -0.062268   0.995542    3.382971    0.143088    0.096834    0.017183    0.623443    
#> 200: -0.081132   1.014837    3.381889    0.132878    0.108348    0.017332    0.631950    
#> 201: -0.079008   0.996791    3.384998    0.138668    0.106813    0.019952    0.627084    
#> 202: -0.077503   0.995682    3.384555    0.135586    0.100271    0.021476    0.626762    
#> 203: -0.062411   0.989987    3.386317    0.136261    0.094388    0.022031    0.625984    
#> 204: -0.053994   0.981400    3.391783    0.140230    0.093200    0.022695    0.628064    
#> 205: -0.048214   0.981579    3.395763    0.142568    0.093810    0.023516    0.631209    
#> 206: -0.043482   0.982144    3.397954    0.141740    0.094757    0.023947    0.631026    
#> 207: -0.042210   0.982272    3.397647    0.145567    0.094565    0.023941    0.631268    
#> 208: -0.040919   0.982301    3.397800    0.145405    0.093600    0.024021    0.629971    
#> 209: -0.037650   0.979173    3.398424    0.144454    0.091178    0.024395    0.630822    
#> 210: -0.033875   0.976145    3.400405    0.142374    0.089948    0.024723    0.629088    
#> 211: -0.031426   0.977023    3.402255    0.140347    0.089007    0.024842    0.628444    
#> 212: -0.027480   0.976333    3.403470    0.138148    0.087206    0.024676    0.628799    
#> 213: -0.023886   0.973195    3.405640    0.137019    0.085429    0.024504    0.628703    
#> 214: -0.020404   0.970874    3.407748    0.135242    0.085320    0.024406    0.628658    
#> 215: -0.018295   0.970089    3.408907    0.133896    0.085287    0.024159    0.628881    
#> 216: -0.016905   0.968913    3.409393    0.131857    0.085858    0.024098    0.629820    
#> 217: -0.015568   0.968610    3.409884    0.130365    0.085546    0.023925    0.630311    
#> 218: -0.014236   0.968763    3.410433    0.130372    0.085345    0.023791    0.629664    
#> 219: -0.014670   0.967528    3.410062    0.130282    0.085104    0.023740    0.629716    
#> 220: -0.015937   0.967532    3.409700    0.131193    0.084815    0.023642    0.629565    
#> 221: -0.016593   0.968444    3.409185    0.130796    0.084751    0.023480    0.629416    
#> 222: -0.016836   0.969423    3.408373    0.129989    0.085653    0.023399    0.629481    
#> 223: -0.016280   0.968808    3.408565    0.129082    0.085934    0.023469    0.629560    
#> 224: -0.014913   0.968596    3.409215    0.128209    0.085903    0.023650    0.629607    
#> 225: -0.014452   0.967335    3.409956    0.126926    0.085311    0.023653    0.630292    
#> 226: -0.014561   0.966180    3.409780    0.126236    0.085377    0.023457    0.631083    
#> 227: -0.015044   0.965614    3.409884    0.125806    0.085610    0.023465    0.631410    
#> 228: -0.015897   0.966101    3.409360    0.125171    0.086138    0.023328    0.631644    
#> 229: -0.016361   0.965964    3.409357    0.124600    0.086531    0.023345    0.631692    
#> 230: -0.015506   0.965695    3.409402    0.123939    0.086478    0.023290    0.631710    
#> 231: -0.015008   0.965680    3.409682    0.123755    0.086587    0.023242    0.631288    
#> 232: -0.015241   0.965491    3.410027    0.122960    0.086209    0.023183    0.631177    
#> 233: -0.015253   0.965033    3.410306    0.121782    0.086087    0.023120    0.631780    
#> 234: -0.015062   0.964697    3.410558    0.121382    0.086133    0.023173    0.631455    
#> 235: -0.014831   0.964139    3.410838    0.120904    0.085375    0.023269    0.631471    
#> 236: -0.014159   0.964228    3.411048    0.120374    0.085351    0.023339    0.631333    
#> 237: -0.013043   0.964563    3.411381    0.120020    0.085784    0.023369    0.631941    
#> 238: -0.012315   0.964545    3.411544    0.120117    0.085978    0.023245    0.632716    
#> 239: -0.012352   0.965186    3.411469    0.119561    0.086120    0.023229    0.632758    
#> 240: -0.012299   0.965198    3.411790    0.119428    0.086047    0.023242    0.632412    
#> 241: -0.012445   0.964707    3.411917    0.119240    0.085850    0.023187    0.632347    
#> 242: -0.013092   0.964540    3.411528    0.119208    0.085511    0.023181    0.632745    
#> 243: -0.014368   0.965227    3.411150    0.119144    0.085209    0.023122    0.633504    
#> 244: -0.015659   0.965824    3.410939    0.119367    0.085053    0.023047    0.633811    
#> 245: -0.015658   0.965394    3.410903    0.119594    0.084903    0.022991    0.634035    
#> 246: -0.016053   0.965468    3.410946    0.119731    0.084413    0.023055    0.634385    
#> 247: -0.015970   0.965677    3.411148    0.119466    0.084213    0.023064    0.634730    
#> 248: -0.015622   0.966026    3.411409    0.118937    0.084138    0.023013    0.634760    
#> 249: -0.015103   0.965984    3.411935    0.119014    0.084264    0.023012    0.634669    
#> 250: -0.014383   0.965702    3.412255    0.118743    0.084368    0.023108    0.634335    
#> 251: -0.013987   0.965886    3.412619    0.118514    0.084529    0.023051    0.634562    
#> 252: -0.013358   0.965964    3.413121    0.118131    0.084819    0.023017    0.634384    
#> 253: -0.013168   0.966188    3.413248    0.118414    0.085089    0.023008    0.634343    
#> 254: -0.013083   0.966426    3.413390    0.118147    0.085253    0.022938    0.634231    
#> 255: -0.013079   0.966806    3.413494    0.118021    0.085304    0.022905    0.634273    
#> 256: -0.012994   0.966830    3.413498    0.117769    0.085278    0.022866    0.634109    
#> 257: -0.013361   0.966514    3.413485    0.117904    0.085237    0.022794    0.634264    
#> 258: -0.013324   0.966039    3.413682    0.117483    0.085060    0.022739    0.634381    
#> 259: -0.013632   0.965659    3.413772    0.117007    0.085045    0.022762    0.634585    
#> 260: -0.013996   0.965697    3.413878    0.116700    0.084963    0.022757    0.634505    
#> 261: -0.013652   0.965640    3.414012    0.116613    0.085152    0.022726    0.634584    
#> 262: -0.012793   0.965574    3.414194    0.116100    0.085349    0.022676    0.634821    
#> 263: -0.012628   0.965755    3.414284    0.115735    0.085545    0.022630    0.634703    
#> 264: -0.012750   0.965403    3.414340    0.115831    0.085551    0.022558    0.634815    
#> 265: -0.012425   0.965163    3.414395    0.115725    0.085531    0.022529    0.634836    
#> 266: -0.011862   0.965172    3.414639    0.115396    0.085275    0.022515    0.635004    
#> 267: -0.011410   0.965110    3.414967    0.115701    0.085433    0.022567    0.635036    
#> 268: -0.010918   0.964918    3.415119    0.115879    0.085516    0.022604    0.635084    
#> 269: -0.010081   0.964820    3.415194    0.115713    0.085939    0.022679    0.635358    
#> 270: -0.009678   0.964924    3.415133    0.115639    0.086148    0.022674    0.635151    
#> 271: -0.009955   0.964962    3.415000    0.115746    0.086352    0.022722    0.635220    
#> 272: -0.009938   0.964765    3.414867    0.115841    0.086367    0.022744    0.635257    
#> 273: -0.010067   0.964924    3.414937    0.115750    0.086493    0.022794    0.635441    
#> 274: -0.010193   0.965108    3.415040    0.115499    0.086522    0.022806    0.635451    
#> 275: -0.010392   0.965237    3.414907    0.115340    0.086440    0.022800    0.635253    
#> 276: -0.010676   0.965556    3.414828    0.115118    0.086372    0.022805    0.634994    
#> 277: -0.011000   0.965856    3.414742    0.115048    0.086240    0.022758    0.634898    
#> 278: -0.011306   0.966012    3.414681    0.115238    0.086244    0.022716    0.634820    
#> 279: -0.011615   0.965953    3.414611    0.115453    0.086396    0.022713    0.634829    
#> 280: -0.011825   0.965976    3.414686    0.115129    0.086264    0.022725    0.634645    
#> 281: -0.012349   0.966021    3.414659    0.114712    0.086100    0.022774    0.634715    
#> 282: -0.012155   0.966153    3.414796    0.114667    0.085978    0.022812    0.634739    
#> 283: -0.012020   0.966131    3.414998    0.114622    0.085830    0.022882    0.634927    
#> 284: -0.011874   0.965953    3.415182    0.114634    0.085705    0.022885    0.634963    
#> 285: -0.011411   0.965901    3.415201    0.114729    0.085717    0.022884    0.634889    
#> 286: -0.011095   0.965869    3.415170    0.114824    0.085782    0.022854    0.634761    
#> 287: -0.011089   0.965896    3.415096    0.114725    0.085778    0.022781    0.634651    
#> 288: -0.010917   0.965976    3.415032    0.114782    0.085874    0.022779    0.634716    
#> 289: -0.010740   0.965867    3.415123    0.114806    0.085769    0.022846    0.634862    
#> 290: -0.010670   0.965867    3.415146    0.114680    0.085745    0.022869    0.635024    
#> 291: -0.010433   0.965865    3.415416    0.114477    0.085687    0.022927    0.635193    
#> 292: -0.010454   0.965741    3.415509    0.114388    0.085648    0.022983    0.635132    
#> 293: -0.010503   0.965692    3.415440    0.114285    0.085529    0.022990    0.635089    
#> 294: -0.010701   0.965604    3.415270    0.114239    0.085482    0.022951    0.635085    
#> 295: -0.010932   0.965434    3.415192    0.114245    0.085517    0.022908    0.634844    
#> 296: -0.010963   0.965369    3.415173    0.114403    0.085414    0.022900    0.634766    
#> 297: -0.010758   0.965556    3.415196    0.114592    0.085304    0.022910    0.634818    
#> 298: -0.010723   0.965363    3.415159    0.114863    0.085203    0.022916    0.634691    
#> 299: -0.010725   0.965367    3.415118    0.115059    0.085171    0.022893    0.634598    
#> 300: -0.010494   0.965208    3.415277    0.115020    0.085096    0.022887    0.634572    
#> 301: -0.010287   0.965120    3.415295    0.115106    0.085103    0.022866    0.634489    
#> 302: -0.010284   0.965117    3.415241    0.115198    0.085200    0.022891    0.634407    
#> 303: -0.010423   0.965117    3.415141    0.115214    0.085169    0.022962    0.634365    
#> 304: -0.010424   0.965321    3.415024    0.115305    0.085023    0.023012    0.634352    
#> 305: -0.010718   0.965184    3.414931    0.115556    0.085184    0.023028    0.634276    
#> 306: -0.010965   0.965201    3.414730    0.115818    0.085251    0.023042    0.634163    
#> 307: -0.011120   0.965188    3.414633    0.115741    0.085419    0.023056    0.634384    
#> 308: -0.011693   0.965092    3.414427    0.115869    0.085492    0.023058    0.634608    
#> 309: -0.011908   0.964823    3.414369    0.115963    0.085323    0.023071    0.634836    
#> 310: -0.012097   0.964951    3.414123    0.116012    0.085323    0.023076    0.634905    
#> 311: -0.012302   0.965141    3.414100    0.115945    0.085235    0.023111    0.634974    
#> 312: -0.012497   0.965229    3.413984    0.115659    0.085139    0.023143    0.635067    
#> 313: -0.012774   0.965117    3.413823    0.115367    0.085063    0.023158    0.635309    
#> 314: -0.013413   0.965345    3.413527    0.115461    0.084995    0.023133    0.635424    
#> 315: -0.014024   0.965569    3.413302    0.115525    0.084986    0.023116    0.635574    
#> 316: -0.014221   0.965847    3.413218    0.115383    0.085188    0.023095    0.635599    
#> 317: -0.014025   0.965750    3.413347    0.115383    0.085129    0.023083    0.635791    
#> 318: -0.013871   0.965674    3.413394    0.115315    0.085070    0.023083    0.635683    
#> 319: -0.013576   0.965503    3.413583    0.115299    0.085109    0.023137    0.635620    
#> 320: -0.013590   0.965375    3.413587    0.115238    0.085195    0.023155    0.635560    
#> 321: -0.013790   0.965395    3.413471    0.115102    0.085236    0.023138    0.635580    
#> 322: -0.014092   0.965401    3.413310    0.115123    0.085329    0.023087    0.635536    
#> 323: -0.014561   0.965445    3.413155    0.115226    0.085250    0.023070    0.635436    
#> 324: -0.014503   0.965527    3.413106    0.115294    0.085294    0.023037    0.635251    
#> 325: -0.014616   0.965706    3.413000    0.115487    0.085316    0.023013    0.635067    
#> 326: -0.014649   0.965587    3.412930    0.115586    0.085411    0.023003    0.634992    
#> 327: -0.014753   0.965619    3.412891    0.115897    0.085660    0.022995    0.634835    
#> 328: -0.014857   0.965728    3.412811    0.116229    0.085752    0.022969    0.634631    
#> 329: -0.014788   0.965829    3.412797    0.116482    0.085854    0.022937    0.634513    
#> 330: -0.014805   0.965752    3.412824    0.116692    0.085772    0.022910    0.634598    
#> 331: -0.014705   0.965700    3.412904    0.116712    0.085687    0.022920    0.634509    
#> 332: -0.014630   0.965479    3.413021    0.116807    0.085569    0.022941    0.634447    
#> 333: -0.014529   0.965453    3.412980    0.116860    0.085485    0.022948    0.634304    
#> 334: -0.014678   0.965199    3.412935    0.116928    0.085397    0.022961    0.634211    
#> 335: -0.014704   0.965141    3.412943    0.116883    0.085352    0.023004    0.634137    
#> 336: -0.014822   0.965319    3.412938    0.116851    0.085368    0.023049    0.634150    
#> 337: -0.014819   0.965622    3.412791    0.117023    0.085330    0.023076    0.634163    
#> 338: -0.014798   0.965704    3.412851    0.116992    0.085311    0.023146    0.634040    
#> 339: -0.014824   0.965820    3.412855    0.116925    0.085334    0.023172    0.634073    
#> 340: -0.014864   0.965694    3.412877    0.117098    0.085432    0.023171    0.633996    
#> 341: -0.014578   0.965562    3.412983    0.117088    0.085537    0.023169    0.633955    
#> 342: -0.014542   0.965182    3.413072    0.116948    0.085605    0.023187    0.633942    
#> 343: -0.014787   0.965107    3.413087    0.116946    0.085644    0.023159    0.633935    
#> 344: -0.014670   0.965057    3.413144    0.116906    0.085701    0.023149    0.634000    
#> 345: -0.014604   0.965062    3.413189    0.116853    0.085770    0.023134    0.634075    
#> 346: -0.014625   0.965102    3.413136    0.116793    0.085699    0.023120    0.634111    
#> 347: -0.014559   0.965027    3.413117    0.116719    0.085746    0.023114    0.634065    
#> 348: -0.014683   0.965032    3.413108    0.116700    0.085910    0.023088    0.634069    
#> 349: -0.014554   0.964930    3.413114    0.116737    0.085939    0.023089    0.634021    
#> 350: -0.014688   0.964836    3.413033    0.116673    0.085915    0.023073    0.633990    
#> 351: -0.014702   0.965007    3.412926    0.116748    0.085893    0.023087    0.633924    
#> 352: -0.015049   0.965171    3.412826    0.116920    0.085994    0.023104    0.633970    
#> 353: -0.015126   0.965315    3.412723    0.117040    0.085920    0.023142    0.633959    
#> 354: -0.015246   0.965407    3.412609    0.117031    0.085807    0.023186    0.633941    
#> 355: -0.015106   0.965252    3.412556    0.116985    0.085754    0.023180    0.633966    
#> 356: -0.015114   0.965083    3.412548    0.116984    0.085814    0.023205    0.634031    
#> 357: -0.015030   0.965094    3.412526    0.117148    0.085844    0.023197    0.634040    
#> 358: -0.014983   0.965168    3.412523    0.117280    0.085833    0.023179    0.633927    
#> 359: -0.014972   0.965249    3.412488    0.117388    0.085865    0.023163    0.633901    
#> 360: -0.015190   0.965351    3.412344    0.117322    0.086016    0.023136    0.633865    
#> 361: -0.015388   0.965456    3.412205    0.117479    0.086068    0.023104    0.633784    
#> 362: -0.015525   0.965475    3.412089    0.117603    0.086078    0.023096    0.633636    
#> 363: -0.015594   0.965421    3.412042    0.117663    0.086089    0.023072    0.633467    
#> 364: -0.015641   0.965474    3.411957    0.117746    0.086183    0.023052    0.633481    
#> 365: -0.015716   0.965399    3.411946    0.117763    0.086141    0.023063    0.633511    
#> 366: -0.015818   0.965422    3.411844    0.117729    0.086130    0.023092    0.633538    
#> 367: -0.015777   0.965475    3.411864    0.117620    0.086164    0.023101    0.633450    
#> 368: -0.015688   0.965543    3.411827    0.117534    0.086148    0.023122    0.633406    
#> 369: -0.015778   0.965681    3.411761    0.117491    0.086268    0.023110    0.633380    
#> 370: -0.015999   0.965758    3.411683    0.117454    0.086263    0.023117    0.633403    
#> 371: -0.016136   0.965854    3.411536    0.117481    0.086300    0.023101    0.633368    
#> 372: -0.016385   0.965886    3.411412    0.117532    0.086386    0.023094    0.633298    
#> 373: -0.016579   0.966093    3.411299    0.117574    0.086477    0.023082    0.633333    
#> 374: -0.016618   0.966164    3.411188    0.117523    0.086449    0.023084    0.633285    
#> 375: -0.016709   0.966336    3.411114    0.117615    0.086459    0.023067    0.633285    
#> 376: -0.016798   0.966554    3.411052    0.117584    0.086591    0.023034    0.633217    
#> 377: -0.016981   0.966708    3.410993    0.117531    0.086716    0.023024    0.633225    
#> 378: -0.017190   0.966706    3.410876    0.117504    0.086816    0.022997    0.633307    
#> 379: -0.017389   0.966667    3.410845    0.117418    0.086844    0.022962    0.633388    
#> 380: -0.017658   0.966632    3.410770    0.117363    0.086888    0.022944    0.633334    
#> 381: -0.017931   0.966627    3.410666    0.117401    0.086932    0.022925    0.633327    
#> 382: -0.018070   0.966627    3.410635    0.117295    0.086972    0.022923    0.633187    
#> 383: -0.017883   0.966628    3.410674    0.117309    0.086958    0.022916    0.633116    
#> 384: -0.017848   0.966616    3.410712    0.117256    0.086918    0.022929    0.633044    
#> 385: -0.017845   0.966601    3.410722    0.117262    0.086916    0.022946    0.632942    
#> 386: -0.017748   0.966692    3.410770    0.117242    0.086879    0.022959    0.632907    
#> 387: -0.017557   0.966722    3.410869    0.117069    0.086892    0.022972    0.632812    
#> 388: -0.017449   0.966708    3.410951    0.116926    0.086867    0.022983    0.632775    
#> 389: -0.017447   0.966582    3.410924    0.116893    0.086777    0.022997    0.632829    
#> 390: -0.017505   0.966577    3.410890    0.116836    0.086676    0.023001    0.632847    
#> 391: -0.017601   0.966487    3.410879    0.116814    0.086571    0.023018    0.632846    
#> 392: -0.017644   0.966518    3.410853    0.116725    0.086511    0.023027    0.632852    
#> 393: -0.017787   0.966486    3.410797    0.116697    0.086442    0.023031    0.632809    
#> 394: -0.017955   0.966511    3.410739    0.116731    0.086389    0.023024    0.632772    
#> 395: -0.017814   0.966634    3.410730    0.116868    0.086398    0.023037    0.632876    
#> 396: -0.017665   0.966686    3.410751    0.116916    0.086347    0.023053    0.632881    
#> 397: -0.017489   0.966652    3.410852    0.117040    0.086256    0.023095    0.632851    
#> 398: -0.017312   0.966594    3.410966    0.117106    0.086228    0.023119    0.632927    
#> 399: -0.017192   0.966600    3.411045    0.117245    0.086254    0.023156    0.632872    
#> 400: -0.017228   0.966561    3.411113    0.117187    0.086289    0.023181    0.632865    
#> 401: -0.017198   0.966659    3.411104    0.117174    0.086295    0.023210    0.632885    
#> 402: -0.017197   0.966837    3.411124    0.117117    0.086263    0.023213    0.632929    
#> 403: -0.017005   0.966911    3.411158    0.117070    0.086280    0.023200    0.632930    
#> 404: -0.016874   0.966922    3.411157    0.116926    0.086265    0.023183    0.632969    
#> 405: -0.016875   0.966967    3.411178    0.116831    0.086239    0.023171    0.632855    
#> 406: -0.016727   0.966921    3.411233    0.116784    0.086226    0.023197    0.632830    
#> 407: -0.016532   0.966861    3.411312    0.116800    0.086293    0.023195    0.632809    
#> 408: -0.016365   0.966807    3.411372    0.116694    0.086352    0.023199    0.632905    
#> 409: -0.016323   0.966713    3.411367    0.116693    0.086343    0.023186    0.632910    
#> 410: -0.016331   0.966766    3.411317    0.116694    0.086386    0.023164    0.632844    
#> 411: -0.016116   0.966563    3.411355    0.116600    0.086434    0.023139    0.632948    
#> 412: -0.016048   0.966583    3.411380    0.116593    0.086486    0.023119    0.632969    
#> 413: -0.016031   0.966586    3.411376    0.116742    0.086515    0.023104    0.633051    
#> 414: -0.016049   0.966541    3.411413    0.116817    0.086498    0.023091    0.633005    
#> 415: -0.015895   0.966480    3.411431    0.116940    0.086466    0.023086    0.632969    
#> 416: -0.015708   0.966479    3.411497    0.117043    0.086498    0.023107    0.632957    
#> 417: -0.015653   0.966450    3.411527    0.117139    0.086560    0.023106    0.632916    
#> 418: -0.015792   0.966432    3.411543    0.117181    0.086632    0.023095    0.632839    
#> 419: -0.015827   0.966540    3.411489    0.117215    0.086690    0.023072    0.632809    
#> 420: -0.015926   0.966664    3.411371    0.117234    0.086778    0.023042    0.632730    
#> 421: -0.016211   0.966692    3.411304    0.117302    0.086897    0.023006    0.632730    
#> 422: -0.016288   0.966661    3.411229    0.117397    0.086960    0.022974    0.632788    
#> 423: -0.016297   0.966608    3.411222    0.117504    0.087027    0.022963    0.632873    
#> 424: -0.016356   0.966576    3.411208    0.117558    0.087042    0.022941    0.632874    
#> 425: -0.016234   0.966578    3.411223    0.117563    0.087007    0.022937    0.632980    
#> 426: -0.016100   0.966586    3.411257    0.117583    0.086963    0.022930    0.632982    
#> 427: -0.016136   0.966544    3.411277    0.117629    0.086920    0.022929    0.632986    
#> 428: -0.016111   0.966505    3.411334    0.117676    0.086914    0.022932    0.632953    
#> 429: -0.016038   0.966514    3.411387    0.117582    0.086925    0.022918    0.632926    
#> 430: -0.015935   0.966509    3.411444    0.117545    0.086962    0.022910    0.632904    
#> 431: -0.015920   0.966455    3.411438    0.117457    0.086921    0.022901    0.632872    
#> 432: -0.015892   0.966443    3.411519    0.117357    0.086882    0.022924    0.632840    
#> 433: -0.015881   0.966439    3.411579    0.117319    0.086808    0.022936    0.632847    
#> 434: -0.015934   0.966381    3.411574    0.117300    0.086800    0.022953    0.632766    
#> 435: -0.015983   0.966450    3.411509    0.117221    0.086778    0.022953    0.632770    
#> 436: -0.016039   0.966476    3.411516    0.117171    0.086718    0.022942    0.632884    
#> 437: -0.016115   0.966429    3.411496    0.117280    0.086759    0.022918    0.632879    
#> 438: -0.016234   0.966482    3.411452    0.117396    0.086754    0.022906    0.632892    
#> 439: -0.016291   0.966594    3.411408    0.117387    0.086734    0.022898    0.632803    
#> 440: -0.016409   0.966666    3.411422    0.117316    0.086696    0.022894    0.632773    
#> 441: -0.016465   0.966732    3.411434    0.117326    0.086745    0.022873    0.632712    
#> 442: -0.016476   0.966801    3.411455    0.117257    0.086839    0.022854    0.632654    
#> 443: -0.016484   0.966888    3.411412    0.117227    0.086848    0.022833    0.632634    
#> 444: -0.016476   0.966980    3.411371    0.117157    0.086904    0.022826    0.632621    
#> 445: -0.016466   0.967009    3.411358    0.117139    0.086929    0.022822    0.632636    
#> 446: -0.016576   0.967069    3.411301    0.117197    0.086928    0.022818    0.632576    
#> 447: -0.016514   0.967066    3.411331    0.117178    0.086873    0.022823    0.632574    
#> 448: -0.016522   0.967019    3.411335    0.117130    0.086877    0.022829    0.632491    
#> 449: -0.016496   0.967073    3.411436    0.117132    0.086847    0.022841    0.632554    
#> 450: -0.016510   0.966996    3.411481    0.117092    0.086803    0.022856    0.632611    
#> 451: -0.016466   0.966898    3.411487    0.117133    0.086812    0.022861    0.632642    
#> 452: -0.016501   0.966898    3.411484    0.117090    0.086822    0.022853    0.632638    
#> 453: -0.016625   0.966908    3.411429    0.117049    0.086818    0.022851    0.632619    
#> 454: -0.016731   0.967050    3.411391    0.117073    0.086824    0.022847    0.632597    
#> 455: -0.016798   0.967147    3.411331    0.117071    0.086799    0.022841    0.632581    
#> 456: -0.016941   0.967175    3.411272    0.117160    0.086693    0.022843    0.632590    
#> 457: -0.017049   0.967156    3.411255    0.117226    0.086659    0.022834    0.632498    
#> 458: -0.017135   0.967275    3.411258    0.117235    0.086626    0.022819    0.632462    
#> 459: -0.017162   0.967396    3.411246    0.117169    0.086626    0.022805    0.632459    
#> 460: -0.017222   0.967397    3.411203    0.117154    0.086607    0.022802    0.632506    
#> 461: -0.017276   0.967412    3.411196    0.117193    0.086610    0.022794    0.632469    
#> 462: -0.017341   0.967420    3.411204    0.117254    0.086617    0.022794    0.632504    
#> 463: -0.017296   0.967496    3.411227    0.117291    0.086638    0.022773    0.632474    
#> 464: -0.017277   0.967498    3.411203    0.117292    0.086656    0.022748    0.632396    
#> 465: -0.017251   0.967385    3.411227    0.117346    0.086632    0.022723    0.632411    
#> 466: -0.017239   0.967375    3.411165    0.117413    0.086693    0.022700    0.632433    
#> 467: -0.017277   0.967373    3.411173    0.117489    0.086710    0.022685    0.632333    
#> 468: -0.017081   0.967271    3.411275    0.117532    0.086710    0.022694    0.632370    
#> 469: -0.016962   0.967248    3.411347    0.117474    0.086669    0.022714    0.632429    
#> 470: -0.016919   0.967247    3.411360    0.117377    0.086641    0.022718    0.632441    
#> 471: -0.016965   0.967215    3.411374    0.117327    0.086594    0.022715    0.632480    
#> 472: -0.017028   0.967239    3.411365    0.117362    0.086581    0.022725    0.632529    
#> 473: -0.017126   0.967291    3.411315    0.117339    0.086580    0.022732    0.632486    
#> 474: -0.017198   0.967254    3.411292    0.117288    0.086546    0.022752    0.632489    
#> 475: -0.017188   0.967374    3.411283    0.117222    0.086464    0.022767    0.632472    
#> 476: -0.017234   0.967345    3.411280    0.117158    0.086419    0.022781    0.632485    
#> 477: -0.017323   0.967272    3.411340    0.117082    0.086350    0.022792    0.632473    
#> 478: -0.017414   0.967236    3.411364    0.117009    0.086276    0.022790    0.632499    
#> 479: -0.017332   0.967285    3.411363    0.116963    0.086238    0.022788    0.632542    
#> 480: -0.017232   0.967284    3.411349    0.116942    0.086186    0.022782    0.632654    
#> 481: -0.017264   0.967290    3.411319    0.116930    0.086210    0.022769    0.632671    
#> 482: -0.017190   0.967303    3.411277    0.116983    0.086247    0.022745    0.632719    
#> 483: -0.017167   0.967242    3.411267    0.116955    0.086311    0.022720    0.632669    
#> 484: -0.017215   0.967224    3.411274    0.117032    0.086331    0.022708    0.632655    
#> 485: -0.017153   0.967214    3.411286    0.117060    0.086369    0.022701    0.632646    
#> 486: -0.017064   0.967243    3.411337    0.117098    0.086386    0.022681    0.632628    
#> 487: -0.016934   0.967201    3.411420    0.117112    0.086391    0.022672    0.632618    
#> 488: -0.016882   0.967201    3.411467    0.117092    0.086403    0.022656    0.632593    
#> 489: -0.016755   0.967166    3.411491    0.117143    0.086436    0.022648    0.632550    
#> 490: -0.016566   0.967130    3.411580    0.117130    0.086406    0.022655    0.632578    
#> 491: -0.016464   0.967109    3.411653    0.117130    0.086467    0.022657    0.632518    
#> 492: -0.016398   0.967157    3.411670    0.117089    0.086463    0.022670    0.632586    
#> 493: -0.016304   0.967161    3.411726    0.117027    0.086416    0.022675    0.632613    
#> 494: -0.016143   0.967224    3.411770    0.116992    0.086382    0.022670    0.632606    
#> 495: -0.016014   0.967197    3.411819    0.117026    0.086345    0.022681    0.632571    
#> 496: -0.015896   0.967240    3.411808    0.117057    0.086301    0.022689    0.632617    
#> 497: -0.015865   0.967244    3.411827    0.117102    0.086346    0.022711    0.632645    
#> 498: -0.015878   0.967224    3.411816    0.117116    0.086372    0.022704    0.632653    
#> 499: -0.015855   0.967256    3.411797    0.117170    0.086483    0.022686    0.632558    
#> 500: -0.015852   0.967296    3.411787    0.117204    0.086490    0.022673    0.632533    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.307828    0.978139    3.438899    0.392401    0.086958    0.016800    1.702626    
#> 002: 0.452842    1.015162    3.453968    0.372781    0.082610    0.018112    1.206074    
#> 003: 0.529178    0.978475    3.460128    0.354142    0.078479    0.017207    0.983349    
#> 004: 0.475794    0.993130    3.448240    0.431638    0.074555    0.016346    0.873620    
#> 005: 0.515729    1.014852    3.420926    0.410056    0.070828    0.015529    0.840561    
#> 006: 0.485745    1.029626    3.415242    0.389553    0.067286    0.014753    0.822341    
#> 007: 0.460589    1.036640    3.404635    0.455047    0.063922    0.014015    0.821774    
#> 008: 0.465302    1.034702    3.398038    0.504435    0.060726    0.013314    0.842183    
#> 009: 0.441315    1.016554    3.407255    0.479213    0.057690    0.012648    0.829509    
#> 010: 0.452505    1.010008    3.403295    0.518264    0.054805    0.012016    0.833908    
#> 011: 0.561723    1.002148    3.426874    0.571000    0.052065    0.012052    0.847370    
#> 012: 0.564607    1.004948    3.422711    0.542450    0.049462    0.012932    0.834152    
#> 013: 0.522434    1.001537    3.429896    0.515328    0.046988    0.012833    0.850866    
#> 014: 0.556591    0.996136    3.430149    0.611965    0.044639    0.012261    0.846573    
#> 015: 0.515668    0.998424    3.451912    0.581367    0.042407    0.011648    0.843128    
#> 016: 0.542646    1.016132    3.449760    0.552299    0.040287    0.011065    0.857911    
#> 017: 0.555865    0.997617    3.445821    0.531673    0.038272    0.011131    0.827019    
#> 018: 0.522386    1.037885    3.420505    0.505089    0.036359    0.010574    0.835201    
#> 019: 0.451743    1.027386    3.412335    0.479835    0.034541    0.010046    0.819365    
#> 020: 0.504129    1.029981    3.420424    0.544821    0.032814    0.010228    0.822011    
#> 021: 0.541747    1.022509    3.435277    0.517580    0.031173    0.010584    0.812827    
#> 022: 0.550505    1.012708    3.441204    0.542065    0.029614    0.010055    0.804978    
#> 023: 0.595139    1.018670    3.446034    0.514962    0.028134    0.009854    0.809134    
#> 024: 0.571499    1.031082    3.445064    0.489214    0.026727    0.011828    0.818423    
#> 025: 0.542402    1.020817    3.423953    0.516205    0.026248    0.011236    0.836771    
#> 026: 0.504433    1.049112    3.418927    0.507333    0.028342    0.010674    0.816237    
#> 027: 0.446759    1.054214    3.410591    0.481966    0.026925    0.010141    0.832329    
#> 028: 0.533717    1.036932    3.417420    0.457868    0.025579    0.011760    0.815736    
#> 029: 0.544404    1.026501    3.412175    0.506144    0.024300    0.013056    0.829228    
#> 030: 0.532242    1.045833    3.408589    0.480837    0.023085    0.012936    0.834150    
#> 031: 0.481954    1.033748    3.423395    0.456795    0.021931    0.014000    0.821216    
#> 032: 0.468555    1.030348    3.429604    0.513080    0.020834    0.015842    0.810159    
#> 033: 0.482461    1.034503    3.413044    0.499254    0.019792    0.016606    0.817876    
#> 034: 0.526745    1.044493    3.409478    0.531248    0.018803    0.017365    0.818295    
#> 035: 0.548264    1.020587    3.421223    0.511294    0.017863    0.016497    0.806438    
#> 036: 0.545752    1.039185    3.420094    0.544241    0.016969    0.015672    0.819122    
#> 037: 0.568427    1.040621    3.430471    0.553810    0.016121    0.014888    0.833367    
#> 038: 0.559793    1.036680    3.422983    0.554919    0.016331    0.014144    0.808991    
#> 039: 0.569152    1.011837    3.440334    0.589026    0.017782    0.013437    0.798859    
#> 040: 0.580065    0.999475    3.438057    0.617088    0.017197    0.013025    0.805803    
#> 041: 0.530704    1.002705    3.429523    0.586233    0.016372    0.012374    0.812330    
#> 042: 0.557480    0.988399    3.434940    0.575632    0.015553    0.011755    0.816089    
#> 043: 0.564405    1.008845    3.418704    0.608670    0.017084    0.011167    0.820437    
#> 044: 0.511882    1.018160    3.430317    0.578236    0.016230    0.011298    0.843662    
#> 045: 0.495913    1.028511    3.416186    0.549324    0.022094    0.011527    0.826438    
#> 046: 0.514925    1.019459    3.416998    0.521858    0.020990    0.011665    0.825019    
#> 047: 0.457754    1.024015    3.404948    0.495765    0.019984    0.011082    0.823658    
#> 048: 0.492870    1.011950    3.416025    0.470977    0.024698    0.010528    0.833566    
#> 049: 0.514017    1.000591    3.428414    0.480412    0.023463    0.010001    0.848161    
#> 050: 0.565228    0.986010    3.430205    0.476456    0.022990    0.009501    0.830054    
#> 051: 0.520498    1.015665    3.416903    0.522782    0.021840    0.009026    0.831066    
#> 052: 0.556449    1.021850    3.434255    0.496643    0.022109    0.008575    0.816762    
#> 053: 0.528891    1.009650    3.433093    0.559004    0.021003    0.008851    0.811943    
#> 054: 0.493845    0.999003    3.448666    0.531054    0.019953    0.009528    0.833512    
#> 055: 0.486593    1.026970    3.423468    0.565633    0.018955    0.010270    0.837786    
#> 056: 0.550448    1.020003    3.424298    0.589084    0.018008    0.010197    0.829275    
#> 057: 0.550825    1.025763    3.425105    0.559630    0.017107    0.009853    0.842400    
#> 058: 0.574819    1.017653    3.425436    0.559803    0.016252    0.011170    0.843525    
#> 059: 0.545161    1.005828    3.431446    0.670257    0.016216    0.012447    0.837982    
#> 060: 0.566582    0.993016    3.444793    0.636744    0.016702    0.013798    0.827264    
#> 061: 0.602382    0.996748    3.442961    0.604907    0.017328    0.013108    0.862231    
#> 062: 0.585916    1.005058    3.446907    0.603909    0.020711    0.012453    0.863701    
#> 063: 0.611420    0.986124    3.442174    0.591812    0.019676    0.011830    0.870263    
#> 064: 0.612623    0.998519    3.446921    0.685180    0.018692    0.011239    0.831375    
#> 065: 0.595424    0.997676    3.422606    0.652613    0.024563    0.010677    0.819154    
#> 066: 0.563156    0.999046    3.426421    0.621259    0.023334    0.010143    0.828632    
#> 067: 0.534269    1.026435    3.412315    0.747536    0.022168    0.010294    0.819682    
#> 068: 0.489893    1.038803    3.419109    0.710159    0.021059    0.009780    0.816224    
#> 069: 0.540988    1.041544    3.403977    0.901654    0.020006    0.009664    0.824984    
#> 070: 0.527451    1.041522    3.408400    0.915825    0.019006    0.009181    0.828306    
#> 071: 0.540136    1.064337    3.387757    0.870033    0.020728    0.010785    0.807825    
#> 072: 0.461149    1.042865    3.396439    0.826532    0.019691    0.010245    0.822175    
#> 073: 0.454618    1.035220    3.416243    0.785205    0.018707    0.010094    0.819162    
#> 074: 0.520596    1.016958    3.416071    0.745945    0.017771    0.009923    0.811298    
#> 075: 0.539005    1.014467    3.434114    0.708648    0.016883    0.009427    0.822923    
#> 076: 0.581997    1.017771    3.443024    0.673215    0.016039    0.008956    0.824269    
#> 077: 0.547965    1.014538    3.430339    0.639555    0.015237    0.008508    0.831391    
#> 078: 0.527142    1.006137    3.434737    0.607577    0.014475    0.009716    0.833127    
#> 079: 0.512414    1.007788    3.439588    0.583027    0.014485    0.009230    0.854581    
#> 080: 0.531909    1.003384    3.430762    0.562698    0.014100    0.008769    0.875359    
#> 081: 0.534898    0.998732    3.432752    0.534563    0.015290    0.010702    0.858609    
#> 082: 0.547331    0.987998    3.431739    0.538093    0.014525    0.010191    0.846580    
#> 083: 0.533142    0.999445    3.433432    0.511189    0.016160    0.009682    0.844530    
#> 084: 0.540347    1.013329    3.421703    0.505990    0.015352    0.009198    0.840827    
#> 085: 0.532784    1.016056    3.431424    0.548622    0.017423    0.008738    0.842904    
#> 086: 0.523626    1.008680    3.433178    0.521191    0.017309    0.008301    0.831247    
#> 087: 0.516747    1.009142    3.425395    0.500398    0.016443    0.008611    0.838886    
#> 088: 0.478306    0.996835    3.428667    0.548352    0.015621    0.009981    0.849844    
#> 089: 0.533665    1.018935    3.415640    0.649362    0.014840    0.009482    0.823194    
#> 090: 0.495850    1.021842    3.410500    0.616894    0.014098    0.009140    0.832376    
#> 091: 0.452703    1.008444    3.396586    0.586049    0.013393    0.009350    0.837343    
#> 092: 0.483947    1.023109    3.399269    0.574872    0.012723    0.009724    0.812413    
#> 093: 0.448678    1.020820    3.397803    0.546128    0.012087    0.011616    0.828318    
#> 094: 0.459462    1.022094    3.394340    0.518822    0.011483    0.013271    0.815707    
#> 095: 0.493803    1.032844    3.411134    0.618115    0.011393    0.013858    0.815971    
#> 096: 0.449417    1.037360    3.400885    0.587209    0.011320    0.013165    0.806864    
#> 097: 0.505391    1.045015    3.413465    0.557849    0.010754    0.012507    0.816577    
#> 098: 0.523967    1.042587    3.428129    0.529956    0.011267    0.011881    0.834406    
#> 099: 0.473948    1.032977    3.405140    0.510653    0.012607    0.011287    0.827171    
#> 100: 0.493629    1.044364    3.408866    0.561546    0.013207    0.010723    0.804979    
#> 101: 0.485952    1.025192    3.391102    0.627916    0.012547    0.010187    0.807017    
#> 102: 0.476462    1.020801    3.389537    0.596520    0.011920    0.010274    0.830556    
#> 103: 0.498006    1.013712    3.408404    0.626689    0.011324    0.009760    0.820514    
#> 104: 0.480477    1.016246    3.416706    0.595355    0.010757    0.010214    0.836401    
#> 105: 0.499651    1.003367    3.412748    0.565587    0.010678    0.010603    0.836370    
#> 106: 0.498881    1.018805    3.407367    0.537308    0.010296    0.011822    0.808482    
#> 107: 0.498956    1.020504    3.414251    0.510442    0.012624    0.011231    0.818639    
#> 108: 0.473863    1.014785    3.405669    0.484920    0.011993    0.010899    0.823690    
#> 109: 0.509468    1.012938    3.423380    0.497896    0.011393    0.010354    0.835195    
#> 110: 0.518950    1.025146    3.404970    0.634632    0.010823    0.010463    0.836994    
#> 111: 0.498052    1.032444    3.408490    0.602900    0.010905    0.009940    0.823341    
#> 112: 0.476891    1.002375    3.399713    0.572755    0.014128    0.009443    0.838963    
#> 113: 0.469158    1.022903    3.408884    0.544117    0.013421    0.010952    0.797730    
#> 114: 0.521864    1.025479    3.417648    0.531268    0.016181    0.010856    0.807219    
#> 115: 0.494308    1.003181    3.416800    0.509573    0.015372    0.010314    0.825791    
#> 116: 0.539702    1.016006    3.431564    0.600334    0.014603    0.010533    0.836685    
#> 117: 0.542240    1.031547    3.433250    0.570317    0.014527    0.010263    0.815991    
#> 118: 0.519708    1.037472    3.425364    0.541801    0.019934    0.009750    0.819611    
#> 119: 0.526705    1.033457    3.429725    0.514711    0.022546    0.009263    0.841519    
#> 120: 0.487859    1.020257    3.421875    0.488975    0.024058    0.008800    0.832051    
#> 121: 0.535121    1.022008    3.418509    0.513283    0.028890    0.008360    0.831519    
#> 122: 0.521141    1.009099    3.423348    0.504921    0.027445    0.007942    0.843135    
#> 123: 0.549126    1.026889    3.422998    0.519615    0.026073    0.007651    0.842587    
#> 124: 0.532357    1.052641    3.407798    0.533791    0.024769    0.007268    0.833154    
#> 125: 0.484810    1.050046    3.402274    0.542328    0.023531    0.007024    0.809501    
#> 126: 0.505152    1.053675    3.402388    0.612931    0.022354    0.006673    0.824421    
#> 127: 0.495468    1.037660    3.391909    0.582284    0.021237    0.006340    0.824911    
#> 128: 0.487417    1.036375    3.406297    0.553170    0.022172    0.008561    0.824762    
#> 129: 0.525815    1.043236    3.407081    0.638247    0.023033    0.008133    0.818839    
#> 130: 0.556088    1.059465    3.402613    0.606335    0.021881    0.008438    0.825841    
#> 131: 0.481345    1.055054    3.397824    0.576018    0.025271    0.010887    0.809594    
#> 132: 0.456380    1.048437    3.391933    0.547217    0.024007    0.010343    0.820369    
#> 133: 0.511886    1.038011    3.397540    0.722383    0.022807    0.009825    0.825732    
#> 134: 0.522599    1.007215    3.424354    0.686264    0.021666    0.009359    0.822670    
#> 135: 0.558783    0.999029    3.422382    0.700680    0.020583    0.010567    0.812795    
#> 136: 0.542251    0.988750    3.424304    0.699180    0.019814    0.010039    0.814477    
#> 137: 0.580694    0.996834    3.428673    0.664221    0.018823    0.010176    0.809411    
#> 138: 0.516326    0.997390    3.426336    0.631010    0.017882    0.009667    0.828787    
#> 139: 0.476276    1.023262    3.420337    0.599459    0.017219    0.009470    0.810426    
#> 140: 0.581868    1.017777    3.421644    0.651745    0.017856    0.011957    0.832961    
#> 141: 0.544191    1.020975    3.428497    0.619158    0.016963    0.012722    0.810932    
#> 142: 0.601974    1.003150    3.444221    0.626326    0.016115    0.013539    0.811701    
#> 143: 0.544211    1.004992    3.442117    0.595010    0.015309    0.016028    0.811129    
#> 144: 0.568880    1.010746    3.443368    0.565259    0.014544    0.015227    0.797274    
#> 145: 0.520421    1.019044    3.418492    0.536996    0.013817    0.014465    0.804734    
#> 146: 0.507863    1.022811    3.433039    0.510146    0.013126    0.013862    0.815907    
#> 147: 0.479593    1.018191    3.412023    0.517409    0.013097    0.013169    0.808164    
#> 148: 0.493382    1.033047    3.418474    0.598106    0.012442    0.016023    0.798087    
#> 149: 0.459531    1.030098    3.412831    0.568200    0.011820    0.017544    0.815383    
#> 150: 0.508181    1.011628    3.412418    0.539790    0.011229    0.016667    0.859870    
#> 151: 0.411810    1.027202    3.400875    0.512801    0.010668    0.015833    0.837678    
#> 152: 0.426943    1.029943    3.409558    0.490941    0.009844    0.012720    0.839763    
#> 153: 0.457809    1.041694    3.409859    0.511299    0.012016    0.013199    0.829243    
#> 154: 0.514495    1.043461    3.414453    0.577274    0.011450    0.012858    0.818854    
#> 155: 0.497561    1.036722    3.413457    0.516579    0.006538    0.012011    0.839273    
#> 156: 0.524318    1.038209    3.436118    0.567175    0.006542    0.014017    0.823367    
#> 157: 0.538484    1.034031    3.440309    0.518989    0.006668    0.016515    0.815696    
#> 158: 0.598846    1.039932    3.435578    0.579720    0.005108    0.015255    0.814166    
#> 159: 0.542344    1.037055    3.429209    0.573387    0.004181    0.013256    0.828129    
#> 160: 0.611820    1.013121    3.439934    0.688587    0.004105    0.012824    0.827385    
#> 161: 0.587331    1.015820    3.435919    0.650546    0.004741    0.015839    0.838156    
#> 162: 0.514073    1.027012    3.412466    0.600325    0.003744    0.015181    0.846361    
#> 163: 0.538351    1.016720    3.417225    0.560957    0.003889    0.015020    0.820115    
#> 164: 0.557959    1.016759    3.419516    0.623792    0.003894    0.013562    0.825470    
#> 165: 0.579801    1.022727    3.427746    0.685449    0.003872    0.012784    0.820850    
#> 166: 0.606910    1.027927    3.427844    0.734052    0.004093    0.014735    0.825825    
#> 167: 0.611025    1.033559    3.439017    0.717892    0.003348    0.014836    0.827530    
#> 168: 0.601017    1.039408    3.431573    0.681111    0.003136    0.017393    0.816842    
#> 169: 0.537766    1.038902    3.415386    0.529446    0.002831    0.017147    0.829819    
#> 170: 0.526762    1.037131    3.420347    0.579703    0.002590    0.018033    0.820997    
#> 171: 0.490530    1.039278    3.411126    0.516072    0.002899    0.015755    0.833025    
#> 172: 0.458785    1.039953    3.411168    0.494036    0.002758    0.016688    0.833698    
#> 173: 0.478120    1.050373    3.399766    0.434250    0.003215    0.016712    0.841083    
#> 174: 0.456148    1.050927    3.408164    0.483076    0.002060    0.013422    0.854099    
#> 175: 0.453341    1.049081    3.403700    0.501061    0.002624    0.015161    0.852008    
#> 176: 0.484528    1.048822    3.418546    0.350685    0.002210    0.015574    0.847746    
#> 177: 0.507381    1.044786    3.427331    0.418244    0.001956    0.014453    0.852698    
#> 178: 0.496944    1.041853    3.422465    0.451028    0.002453    0.013373    0.845209    
#> 179: 0.554604    1.038633    3.427973    0.419729    0.002109    0.014641    0.864924    
#> 180: 0.517389    1.040779    3.432932    0.437498    0.002025    0.017002    0.840107    
#> 181: 0.520757    1.034269    3.406764    0.491040    0.002041    0.016888    0.819293    
#> 182: 0.496860    1.033880    3.388703    0.501854    0.002812    0.018229    0.839729    
#> 183: 0.502800    1.042596    3.393981    0.554295    0.002237    0.018816    0.846543    
#> 184: 0.504949    1.042962    3.392492    0.637833    0.001981    0.020259    0.864876    
#> 185: 0.462129    1.040933    3.403270    0.525613    0.001889    0.015034    0.849338    
#> 186: 0.452754    1.045475    3.403639    0.513115    0.001722    0.015054    0.857831    
#> 187: 0.473830    1.049045    3.415121    0.502051    0.002090    0.013420    0.854012    
#> 188: 0.463830    1.056353    3.400843    0.534588    0.002475    0.013275    0.859731    
#> 189: 0.457436    1.060202    3.414004    0.446311    0.003762    0.013625    0.864618    
#> 190: 0.491956    1.055981    3.425277    0.489929    0.004144    0.011584    0.837445    
#> 191: 0.442189    1.053718    3.399404    0.383505    0.004507    0.013003    0.840854    
#> 192: 0.412897    1.057075    3.394711    0.396697    0.005004    0.012712    0.861630    
#> 193: 0.505345    1.058593    3.409656    0.462233    0.005115    0.012034    0.835181    
#> 194: 0.442279    1.055136    3.398689    0.509517    0.006160    0.014028    0.855428    
#> 195: 0.452008    1.051372    3.392285    0.434993    0.006572    0.014601    0.850761    
#> 196: 0.459734    1.054765    3.395767    0.524191    0.007667    0.010626    0.851712    
#> 197: 0.472574    1.065838    3.412598    0.633806    0.007266    0.011834    0.863316    
#> 198: 0.538593    1.061368    3.403617    0.574377    0.005471    0.011574    0.859524    
#> 199: 0.473410    1.051071    3.407384    0.549701    0.004778    0.011501    0.854040    
#> 200: 0.483215    1.045156    3.413411    0.543711    0.004402    0.011760    0.862025    
#> 201: 0.467835    1.041421    3.414006    0.528440    0.003943    0.014229    0.863221    
#> 202: 0.469771    1.043253    3.414063    0.510498    0.003655    0.014854    0.866863    
#> 203: 0.483022    1.041643    3.414242    0.503809    0.003424    0.014110    0.860316    
#> 204: 0.493632    1.039191    3.416333    0.517590    0.003569    0.014769    0.854442    
#> 205: 0.490623    1.039803    3.416509    0.510813    0.003777    0.014975    0.849710    
#> 206: 0.495165    1.040927    3.417606    0.518519    0.003804    0.015421    0.847064    
#> 207: 0.498792    1.039911    3.416961    0.529057    0.003771    0.015848    0.843780    
#> 208: 0.502868    1.038600    3.418279    0.525835    0.003726    0.016317    0.843548    
#> 209: 0.509291    1.038162    3.418760    0.523467    0.003718    0.016196    0.841894    
#> 210: 0.513492    1.037666    3.419628    0.520581    0.003676    0.016232    0.841169    
#> 211: 0.514584    1.037939    3.419590    0.516476    0.003714    0.016081    0.840044    
#> 212: 0.513915    1.037849    3.419034    0.513398    0.003704    0.016005    0.839321    
#> 213: 0.513969    1.036029    3.417854    0.514626    0.003863    0.015810    0.839385    
#> 214: 0.517900    1.034572    3.418002    0.517502    0.003963    0.015692    0.839126    
#> 215: 0.519005    1.033806    3.418468    0.517021    0.004043    0.015809    0.839412    
#> 216: 0.521948    1.032415    3.418999    0.517303    0.004035    0.015907    0.839521    
#> 217: 0.519427    1.031824    3.419202    0.514622    0.004003    0.016025    0.838555    
#> 218: 0.519427    1.031841    3.418632    0.515803    0.003958    0.015992    0.838517    
#> 219: 0.519150    1.031431    3.417713    0.515814    0.003918    0.015966    0.839539    
#> 220: 0.517197    1.031305    3.417636    0.516123    0.003910    0.016136    0.839378    
#> 221: 0.514955    1.030978    3.417361    0.515844    0.003893    0.016104    0.838642    
#> 222: 0.514973    1.030422    3.417496    0.518480    0.003855    0.016088    0.838608    
#> 223: 0.514147    1.029815    3.417367    0.515331    0.003865    0.016087    0.838119    
#> 224: 0.515655    1.029509    3.417514    0.517165    0.003846    0.016084    0.837434    
#> 225: 0.513272    1.028718    3.417086    0.514333    0.003805    0.016067    0.837873    
#> 226: 0.511196    1.027979    3.416276    0.516126    0.003795    0.016080    0.838018    
#> 227: 0.509761    1.027479    3.416247    0.513554    0.003770    0.016027    0.837965    
#> 228: 0.508514    1.027587    3.415857    0.511933    0.003744    0.015909    0.838457    
#> 229: 0.506171    1.027175    3.415644    0.511146    0.003712    0.015839    0.838611    
#> 230: 0.507285    1.026842    3.415916    0.511004    0.003679    0.015884    0.837785    
#> 231: 0.508752    1.026802    3.416412    0.513118    0.003645    0.015912    0.837260    
#> 232: 0.508715    1.026484    3.416910    0.513285    0.003648    0.015975    0.837304    
#> 233: 0.507678    1.026174    3.417216    0.512701    0.003667    0.016031    0.837608    
#> 234: 0.507904    1.026288    3.417506    0.511863    0.003670    0.016114    0.837910    
#> 235: 0.507724    1.026205    3.417569    0.508011    0.003690    0.016101    0.837736    
#> 236: 0.506575    1.026355    3.417102    0.504710    0.003696    0.016069    0.837356    
#> 237: 0.505617    1.026261    3.416720    0.501350    0.003692    0.016120    0.837375    
#> 238: 0.505019    1.026217    3.416546    0.499039    0.003721    0.016205    0.837595    
#> 239: 0.504845    1.026467    3.416505    0.498414    0.003770    0.016160    0.838106    
#> 240: 0.505299    1.026506    3.416796    0.499910    0.003804    0.016139    0.837932    
#> 241: 0.505803    1.026425    3.417222    0.499845    0.003805    0.016114    0.838299    
#> 242: 0.506173    1.026183    3.417250    0.500252    0.003864    0.016212    0.838194    
#> 243: 0.506650    1.026031    3.417509    0.500646    0.003925    0.016250    0.837947    
#> 244: 0.507320    1.025748    3.417978    0.500822    0.003969    0.016377    0.837976    
#> 245: 0.507509    1.025458    3.418312    0.500870    0.003979    0.016411    0.838194    
#> 246: 0.507655    1.025219    3.418470    0.501201    0.003972    0.016587    0.838072    
#> 247: 0.508042    1.024906    3.418794    0.501817    0.003975    0.016681    0.837843    
#> 248: 0.507369    1.024686    3.418833    0.502222    0.003963    0.016725    0.837333    
#> 249: 0.507275    1.024533    3.418949    0.502919    0.003944    0.016747    0.836983    
#> 250: 0.507891    1.024455    3.419042    0.503496    0.003933    0.016777    0.836788    
#> 251: 0.507748    1.024563    3.419310    0.502822    0.003917    0.016757    0.836860    
#> 252: 0.508163    1.024566    3.419657    0.502460    0.003935    0.016782    0.837080    
#> 253: 0.508361    1.024385    3.419784    0.503081    0.003942    0.016839    0.837388    
#> 254: 0.508830    1.024557    3.420042    0.503394    0.003922    0.016864    0.837883    
#> 255: 0.509661    1.024534    3.420307    0.503236    0.003903    0.016913    0.838078    
#> 256: 0.510186    1.024419    3.420439    0.503825    0.003885    0.017029    0.837962    
#> 257: 0.510758    1.024053    3.420729    0.504938    0.003862    0.017094    0.837536    
#> 258: 0.510819    1.023823    3.420809    0.504620    0.003842    0.017046    0.837351    
#> 259: 0.511051    1.023776    3.420731    0.504379    0.003845    0.016990    0.837292    
#> 260: 0.511273    1.023796    3.420885    0.504449    0.003862    0.016958    0.837111    
#> 261: 0.511504    1.023872    3.421077    0.503776    0.003849    0.016926    0.837047    
#> 262: 0.511853    1.023802    3.421233    0.503037    0.003840    0.016932    0.837143    
#> 263: 0.512175    1.023805    3.421432    0.503481    0.003818    0.016993    0.837258    
#> 264: 0.512851    1.023794    3.421724    0.504381    0.003819    0.017007    0.837102    
#> 265: 0.512879    1.023814    3.421770    0.504959    0.003819    0.016969    0.837096    
#> 266: 0.513334    1.023883    3.421837    0.505739    0.003826    0.016943    0.836973    
#> 267: 0.513561    1.023937    3.422106    0.505314    0.003839    0.016918    0.836970    
#> 268: 0.514105    1.023824    3.422069    0.506053    0.003848    0.016915    0.836637    
#> 269: 0.515107    1.023751    3.422273    0.507135    0.003847    0.016942    0.836307    
#> 270: 0.515757    1.023635    3.422136    0.508511    0.003840    0.016959    0.835966    
#> 271: 0.516105    1.023573    3.422136    0.508673    0.003842    0.016985    0.835987    
#> 272: 0.516226    1.023543    3.422012    0.509871    0.003846    0.016956    0.835839    
#> 273: 0.515899    1.023551    3.421968    0.509732    0.003861    0.016937    0.835861    
#> 274: 0.515392    1.023568    3.421983    0.508044    0.003864    0.016832    0.836064    
#> 275: 0.515260    1.023512    3.421935    0.507777    0.003869    0.016767    0.835879    
#> 276: 0.514708    1.023465    3.422037    0.506767    0.003863    0.016718    0.835987    
#> 277: 0.514520    1.023410    3.422304    0.506062    0.003862    0.016704    0.835911    
#> 278: 0.514378    1.023398    3.422418    0.505612    0.003861    0.016694    0.835814    
#> 279: 0.514322    1.023318    3.422559    0.506343    0.003851    0.016677    0.836077    
#> 280: 0.514094    1.023383    3.422596    0.505543    0.003845    0.016647    0.836208    
#> 281: 0.513995    1.023360    3.422637    0.504869    0.003840    0.016631    0.836091    
#> 282: 0.514643    1.023477    3.422701    0.505125    0.003831    0.016636    0.835857    
#> 283: 0.514342    1.023517    3.422691    0.505412    0.003833    0.016708    0.835990    
#> 284: 0.514346    1.023479    3.422730    0.505364    0.003830    0.016769    0.835683    
#> 285: 0.514646    1.023425    3.422687    0.504462    0.003830    0.016868    0.835773    
#> 286: 0.515102    1.023349    3.422769    0.503814    0.003834    0.016898    0.835741    
#> 287: 0.515199    1.023279    3.422677    0.503694    0.003838    0.016909    0.835747    
#> 288: 0.515121    1.023124    3.422698    0.503551    0.003839    0.016925    0.835826    
#> 289: 0.515123    1.023034    3.422720    0.502729    0.003841    0.016914    0.836006    
#> 290: 0.514752    1.023018    3.422808    0.501611    0.003845    0.016898    0.836196    
#> 291: 0.514761    1.023148    3.422960    0.500535    0.003845    0.016902    0.835965    
#> 292: 0.514872    1.023183    3.422936    0.501456    0.003834    0.016879    0.835796    
#> 293: 0.515100    1.023227    3.422875    0.501927    0.003825    0.016845    0.835680    
#> 294: 0.515281    1.023316    3.422838    0.502590    0.003822    0.016846    0.835668    
#> 295: 0.515585    1.023288    3.422733    0.503509    0.003820    0.016785    0.835518    
#> 296: 0.515638    1.023220    3.422788    0.503243    0.003816    0.016759    0.835716    
#> 297: 0.515875    1.023185    3.422841    0.503539    0.003819    0.016749    0.835883    
#> 298: 0.516146    1.023166    3.422883    0.504427    0.003818    0.016749    0.835684    
#> 299: 0.516323    1.023059    3.422820    0.504692    0.003811    0.016746    0.835605    
#> 300: 0.516217    1.022977    3.422877    0.504213    0.003810    0.016795    0.835441    
#> 301: 0.516380    1.022797    3.422832    0.503536    0.003804    0.016788    0.835507    
#> 302: 0.516477    1.022712    3.422831    0.503491    0.003799    0.016781    0.835461    
#> 303: 0.516360    1.022722    3.422776    0.503103    0.003794    0.016757    0.835310    
#> 304: 0.516446    1.022773    3.422657    0.503130    0.003793    0.016735    0.835305    
#> 305: 0.516209    1.022653    3.422535    0.503764    0.003796    0.016729    0.835317    
#> 306: 0.515952    1.022508    3.422506    0.504277    0.003794    0.016701    0.835188    
#> 307: 0.516058    1.022305    3.422511    0.503471    0.003790    0.016667    0.835260    
#> 308: 0.515746    1.022110    3.422498    0.503961    0.003796    0.016641    0.835297    
#> 309: 0.515837    1.021867    3.422526    0.503792    0.003805    0.016623    0.835253    
#> 310: 0.516447    1.021601    3.422541    0.504312    0.003817    0.016594    0.835376    
#> 311: 0.517239    1.021466    3.422682    0.505609    0.003818    0.016598    0.835444    
#> 312: 0.517542    1.021264    3.422658    0.506226    0.003817    0.016620    0.835526    
#> 313: 0.517189    1.021120    3.422501    0.506127    0.003823    0.016623    0.835698    
#> 314: 0.516456    1.021134    3.422354    0.506427    0.003818    0.016653    0.835847    
#> 315: 0.515991    1.021167    3.422234    0.507632    0.003817    0.016676    0.835828    
#> 316: 0.516085    1.021226    3.422133    0.510153    0.003828    0.016650    0.835703    
#> 317: 0.516048    1.021295    3.422017    0.511089    0.003849    0.016648    0.835616    
#> 318: 0.515529    1.021350    3.421809    0.510878    0.003853    0.016657    0.835457    
#> 319: 0.515146    1.021335    3.421728    0.511104    0.003857    0.016641    0.835453    
#> 320: 0.514649    1.021295    3.421598    0.510744    0.003862    0.016630    0.835621    
#> 321: 0.514279    1.021306    3.421485    0.509951    0.003866    0.016661    0.835725    
#> 322: 0.514312    1.021301    3.421366    0.510082    0.003859    0.016627    0.835694    
#> 323: 0.513913    1.021269    3.421249    0.510015    0.003857    0.016595    0.835753    
#> 324: 0.513877    1.021222    3.421390    0.509606    0.003851    0.016601    0.835668    
#> 325: 0.514205    1.021222    3.421413    0.509406    0.003842    0.016608    0.835613    
#> 326: 0.514533    1.020999    3.421518    0.509704    0.003849    0.016619    0.835702    
#> 327: 0.515253    1.020877    3.421757    0.510408    0.003838    0.016687    0.835620    
#> 328: 0.515969    1.020827    3.421830    0.510828    0.003826    0.016719    0.835559    
#> 329: 0.516312    1.020776    3.421923    0.510965    0.003816    0.016774    0.835396    
#> 330: 0.516044    1.020800    3.421970    0.510518    0.003813    0.016768    0.835367    
#> 331: 0.516274    1.020912    3.422079    0.510023    0.003822    0.016752    0.835312    
#> 332: 0.516519    1.020919    3.422235    0.509796    0.003820    0.016758    0.835347    
#> 333: 0.516447    1.020945    3.422244    0.509601    0.003818    0.016754    0.835299    
#> 334: 0.516221    1.020971    3.422111    0.509474    0.003815    0.016762    0.835342    
#> 335: 0.515960    1.020921    3.422017    0.509300    0.003814    0.016759    0.835394    
#> 336: 0.515768    1.020931    3.422011    0.509273    0.003810    0.016789    0.835500    
#> 337: 0.515693    1.021003    3.421903    0.509922    0.003808    0.016789    0.835480    
#> 338: 0.515791    1.021055    3.421979    0.510098    0.003819    0.016782    0.835450    
#> 339: 0.515944    1.021048    3.422150    0.510000    0.003824    0.016774    0.835391    
#> 340: 0.516082    1.020926    3.422321    0.510029    0.003835    0.016780    0.835347    
#> 341: 0.516405    1.020826    3.422482    0.509885    0.003836    0.016770    0.835345    
#> 342: 0.516326    1.020706    3.422587    0.509242    0.003833    0.016758    0.835418    
#> 343: 0.516304    1.020658    3.422679    0.509251    0.003821    0.016778    0.835388    
#> 344: 0.516915    1.020591    3.422760    0.510322    0.003814    0.016785    0.835456    
#> 345: 0.517077    1.020580    3.422807    0.510544    0.003812    0.016801    0.835306    
#> 346: 0.517116    1.020597    3.422772    0.510327    0.003813    0.016816    0.835270    
#> 347: 0.517145    1.020512    3.422696    0.509104    0.003823    0.016836    0.835414    
#> 348: 0.516821    1.020493    3.422628    0.508699    0.003828    0.016871    0.835401    
#> 349: 0.516767    1.020452    3.422665    0.508493    0.003827    0.016893    0.835323    
#> 350: 0.516406    1.020423    3.422634    0.507923    0.003827    0.016921    0.835339    
#> 351: 0.516320    1.020443    3.422529    0.507581    0.003825    0.016965    0.835377    
#> 352: 0.515916    1.020453    3.422486    0.507746    0.003825    0.016957    0.835576    
#> 353: 0.516206    1.020507    3.422440    0.507924    0.003834    0.016943    0.835633    
#> 354: 0.516193    1.020514    3.422341    0.507549    0.003842    0.016933    0.835631    
#> 355: 0.516529    1.020488    3.422308    0.507817    0.003851    0.016911    0.835580    
#> 356: 0.516629    1.020437    3.422338    0.507508    0.003863    0.016914    0.835592    
#> 357: 0.516962    1.020408    3.422410    0.508231    0.003863    0.016885    0.835572    
#> 358: 0.516884    1.020451    3.422521    0.507843    0.003856    0.016865    0.835547    
#> 359: 0.516772    1.020510    3.422526    0.507484    0.003853    0.016871    0.835438    
#> 360: 0.516658    1.020560    3.422417    0.506781    0.003847    0.016884    0.835399    
#> 361: 0.516540    1.020598    3.422353    0.506798    0.003841    0.016890    0.835372    
#> 362: 0.516663    1.020642    3.422334    0.507048    0.003838    0.016880    0.835376    
#> 363: 0.516722    1.020654    3.422339    0.507242    0.003834    0.016893    0.835193    
#> 364: 0.516831    1.020669    3.422289    0.507018    0.003830    0.016888    0.835213    
#> 365: 0.516554    1.020651    3.422278    0.506696    0.003831    0.016901    0.835297    
#> 366: 0.516382    1.020653    3.422167    0.506776    0.003827    0.016918    0.835351    
#> 367: 0.516106    1.020692    3.422127    0.506069    0.003824    0.016895    0.835387    
#> 368: 0.516114    1.020723    3.422095    0.505779    0.003816    0.016894    0.835481    
#> 369: 0.515805    1.020695    3.422093    0.506004    0.003813    0.016882    0.835476    
#> 370: 0.515738    1.020728    3.422069    0.506077    0.003809    0.016857    0.835439    
#> 371: 0.515341    1.020769    3.421967    0.505855    0.003806    0.016855    0.835469    
#> 372: 0.515276    1.020825    3.421953    0.505686    0.003804    0.016856    0.835538    
#> 373: 0.515029    1.020878    3.421879    0.505494    0.003804    0.016865    0.835587    
#> 374: 0.514647    1.020905    3.421801    0.504897    0.003809    0.016845    0.835675    
#> 375: 0.514392    1.020940    3.421674    0.504667    0.003811    0.016831    0.835617    
#> 376: 0.514330    1.020934    3.421636    0.504157    0.003809    0.016824    0.835671    
#> 377: 0.514328    1.020985    3.421672    0.504035    0.003807    0.016834    0.835643    
#> 378: 0.514099    1.020970    3.421559    0.504093    0.003809    0.016831    0.835638    
#> 379: 0.513946    1.020912    3.421524    0.503798    0.003818    0.016830    0.835575    
#> 380: 0.513663    1.020858    3.421524    0.503278    0.003830    0.016812    0.835474    
#> 381: 0.513506    1.020763    3.421549    0.503110    0.003836    0.016783    0.835461    
#> 382: 0.513455    1.020661    3.421600    0.502754    0.003839    0.016758    0.835411    
#> 383: 0.513784    1.020559    3.421670    0.503084    0.003837    0.016736    0.835273    
#> 384: 0.513677    1.020468    3.421732    0.502667    0.003836    0.016717    0.835302    
#> 385: 0.513858    1.020400    3.421800    0.502946    0.003837    0.016700    0.835318    
#> 386: 0.513910    1.020380    3.421824    0.502945    0.003844    0.016689    0.835302    
#> 387: 0.514229    1.020329    3.421922    0.503074    0.003846    0.016670    0.835334    
#> 388: 0.514338    1.020351    3.421951    0.503193    0.003843    0.016670    0.835292    
#> 389: 0.514356    1.020274    3.421956    0.503094    0.003841    0.016662    0.835359    
#> 390: 0.514123    1.020270    3.421898    0.502831    0.003840    0.016671    0.835465    
#> 391: 0.514190    1.020199    3.421851    0.503205    0.003840    0.016668    0.835494    
#> 392: 0.514406    1.020115    3.421956    0.503248    0.003846    0.016684    0.835497    
#> 393: 0.514546    1.020022    3.422010    0.503554    0.003846    0.016667    0.835586    
#> 394: 0.514896    1.019958    3.422069    0.504227    0.003841    0.016656    0.835581    
#> 395: 0.515425    1.019888    3.422190    0.504835    0.003842    0.016638    0.835564    
#> 396: 0.515857    1.019911    3.422246    0.505484    0.003847    0.016638    0.835434    
#> 397: 0.516010    1.019909    3.422365    0.505307    0.003856    0.016647    0.835493    
#> 398: 0.516267    1.019864    3.422495    0.504911    0.003857    0.016663    0.835512    
#> 399: 0.516438    1.019818    3.422626    0.505099    0.003860    0.016682    0.835474    
#> 400: 0.516700    1.019818    3.422680    0.505217    0.003857    0.016692    0.835493    
#> 401: 0.516760    1.019821    3.422753    0.505124    0.003858    0.016715    0.835441    
#> 402: 0.516833    1.019835    3.422826    0.504715    0.003858    0.016741    0.835375    
#> 403: 0.516941    1.019783    3.422820    0.504980    0.003855    0.016757    0.835308    
#> 404: 0.517031    1.019786    3.422785    0.505242    0.003856    0.016773    0.835267    
#> 405: 0.516993    1.019771    3.422805    0.504913    0.003852    0.016801    0.835292    
#> 406: 0.516917    1.019726    3.422804    0.504703    0.003851    0.016829    0.835359    
#> 407: 0.516958    1.019703    3.422827    0.505046    0.003847    0.016847    0.835340    
#> 408: 0.517001    1.019732    3.422828    0.504794    0.003839    0.016860    0.835415    
#> 409: 0.516836    1.019728    3.422743    0.504571    0.003832    0.016872    0.835381    
#> 410: 0.516605    1.019749    3.422630    0.504544    0.003835    0.016875    0.835403    
#> 411: 0.516617    1.019668    3.422581    0.505002    0.003839    0.016880    0.835493    
#> 412: 0.516289    1.019625    3.422494    0.504867    0.003848    0.016892    0.835482    
#> 413: 0.516073    1.019595    3.422390    0.505227    0.003853    0.016891    0.835499    
#> 414: 0.516051    1.019527    3.422413    0.505782    0.003858    0.016896    0.835412    
#> 415: 0.516187    1.019464    3.422454    0.505648    0.003858    0.016892    0.835386    
#> 416: 0.516413    1.019423    3.422507    0.505624    0.003859    0.016887    0.835328    
#> 417: 0.516453    1.019338    3.422573    0.505358    0.003859    0.016883    0.835301    
#> 418: 0.516411    1.019275    3.422610    0.505359    0.003861    0.016888    0.835251    
#> 419: 0.516515    1.019248    3.422683    0.505342    0.003857    0.016887    0.835249    
#> 420: 0.516779    1.019214    3.422759    0.505327    0.003855    0.016886    0.835145    
#> 421: 0.516848    1.019150    3.422869    0.504853    0.003852    0.016894    0.835143    
#> 422: 0.517292    1.019062    3.422965    0.505281    0.003853    0.016904    0.835077    
#> 423: 0.517398    1.019042    3.423004    0.504921    0.003855    0.016904    0.835047    
#> 424: 0.517321    1.019037    3.422971    0.504556    0.003856    0.016895    0.835026    
#> 425: 0.517396    1.019045    3.423025    0.504267    0.003861    0.016916    0.835043    
#> 426: 0.517321    1.019089    3.423030    0.504444    0.003860    0.016925    0.834949    
#> 427: 0.517211    1.019087    3.423038    0.504895    0.003857    0.016936    0.834916    
#> 428: 0.517222    1.019104    3.423011    0.505098    0.003858    0.016939    0.834932    
#> 429: 0.517294    1.019084    3.423044    0.504933    0.003857    0.016930    0.834936    
#> 430: 0.517397    1.019087    3.423066    0.505218    0.003858    0.016920    0.834942    
#> 431: 0.517447    1.019166    3.423079    0.505538    0.003856    0.016919    0.834892    
#> 432: 0.517365    1.019201    3.423080    0.505620    0.003854    0.016924    0.834879    
#> 433: 0.517394    1.019201    3.423166    0.505385    0.003853    0.016946    0.834922    
#> 434: 0.517471    1.019164    3.423196    0.505492    0.003852    0.016953    0.834779    
#> 435: 0.517510    1.019150    3.423189    0.505444    0.003850    0.016941    0.834686    
#> 436: 0.517468    1.019128    3.423206    0.505506    0.003847    0.016942    0.834651    
#> 437: 0.517427    1.019126    3.423219    0.505619    0.003846    0.016951    0.834659    
#> 438: 0.517455    1.019197    3.423192    0.505845    0.003851    0.016937    0.834620    
#> 439: 0.517653    1.019233    3.423185    0.506400    0.003847    0.016936    0.834581    
#> 440: 0.517394    1.019269    3.423190    0.506163    0.003844    0.016927    0.834652    
#> 441: 0.517543    1.019231    3.423221    0.506040    0.003844    0.016933    0.834686    
#> 442: 0.517534    1.019202    3.423257    0.506088    0.003840    0.016928    0.834720    
#> 443: 0.517661    1.019188    3.423262    0.506223    0.003835    0.016942    0.834685    
#> 444: 0.517474    1.019215    3.423173    0.506121    0.003830    0.016949    0.834664    
#> 445: 0.517312    1.019251    3.423099    0.506353    0.003831    0.016944    0.834656    
#> 446: 0.517254    1.019288    3.423021    0.506718    0.003834    0.016944    0.834600    
#> 447: 0.517303    1.019341    3.423026    0.506980    0.003841    0.016938    0.834572    
#> 448: 0.517187    1.019409    3.423021    0.506977    0.003843    0.016942    0.834614    
#> 449: 0.517150    1.019471    3.423066    0.507244    0.003843    0.016942    0.834688    
#> 450: 0.516939    1.019514    3.423031    0.507324    0.003844    0.016931    0.834760    
#> 451: 0.516733    1.019520    3.422953    0.507487    0.003848    0.016920    0.834819    
#> 452: 0.516451    1.019591    3.422845    0.507500    0.003846    0.016908    0.834801    
#> 453: 0.516244    1.019662    3.422786    0.507275    0.003849    0.016914    0.834783    
#> 454: 0.516050    1.019711    3.422729    0.507320    0.003851    0.016933    0.834728    
#> 455: 0.516069    1.019755    3.422708    0.507132    0.003853    0.016952    0.834762    
#> 456: 0.515960    1.019754    3.422694    0.507100    0.003850    0.016967    0.834861    
#> 457: 0.515940    1.019769    3.422730    0.507600    0.003847    0.016962    0.834814    
#> 458: 0.515807    1.019822    3.422737    0.507936    0.003850    0.016950    0.834829    
#> 459: 0.515451    1.019879    3.422702    0.507706    0.003850    0.016945    0.834886    
#> 460: 0.515127    1.019898    3.422603    0.507488    0.003847    0.016937    0.834939    
#> 461: 0.514987    1.019932    3.422588    0.507339    0.003843    0.016948    0.834961    
#> 462: 0.514869    1.019985    3.422616    0.507280    0.003839    0.016971    0.834980    
#> 463: 0.514854    1.020000    3.422634    0.507272    0.003839    0.016972    0.834974    
#> 464: 0.515021    1.020021    3.422636    0.507336    0.003838    0.016984    0.834854    
#> 465: 0.514979    1.020003    3.422611    0.507129    0.003836    0.016986    0.834813    
#> 466: 0.514930    1.020033    3.422558    0.507198    0.003834    0.016989    0.834829    
#> 467: 0.514905    1.020051    3.422562    0.507723    0.003832    0.016995    0.834803    
#> 468: 0.515146    1.020034    3.422603    0.508203    0.003829    0.016981    0.834843    
#> 469: 0.515450    1.020078    3.422648    0.508706    0.003826    0.016975    0.834936    
#> 470: 0.515546    1.020118    3.422653    0.508815    0.003824    0.016969    0.834950    
#> 471: 0.515363    1.020131    3.422617    0.508627    0.003820    0.016960    0.834999    
#> 472: 0.515419    1.020140    3.422653    0.508624    0.003817    0.016942    0.835088    
#> 473: 0.515330    1.020132    3.422649    0.508354    0.003813    0.016946    0.835094    
#> 474: 0.515286    1.020115    3.422614    0.508189    0.003808    0.016961    0.835245    
#> 475: 0.515293    1.020119    3.422615    0.507905    0.003804    0.016984    0.835227    
#> 476: 0.515286    1.020090    3.422583    0.507860    0.003799    0.016985    0.835333    
#> 477: 0.515295    1.020090    3.422616    0.508109    0.003794    0.016996    0.835308    
#> 478: 0.515261    1.020077    3.422632    0.508197    0.003790    0.016993    0.835313    
#> 479: 0.515411    1.020044    3.422670    0.508595    0.003788    0.016992    0.835369    
#> 480: 0.515672    1.020015    3.422740    0.508533    0.003788    0.017012    0.835419    
#> 481: 0.515751    1.019967    3.422767    0.508361    0.003785    0.017022    0.835451    
#> 482: 0.515781    1.019930    3.422734    0.508243    0.003783    0.017030    0.835442    
#> 483: 0.515644    1.019908    3.422713    0.508508    0.003780    0.017039    0.835418    
#> 484: 0.515638    1.019846    3.422729    0.509098    0.003779    0.017053    0.835349    
#> 485: 0.515926    1.019818    3.422765    0.509580    0.003776    0.017067    0.835317    
#> 486: 0.516029    1.019832    3.422807    0.509793    0.003775    0.017070    0.835268    
#> 487: 0.516120    1.019837    3.422843    0.509765    0.003775    0.017078    0.835186    
#> 488: 0.516126    1.019809    3.422878    0.509830    0.003770    0.017080    0.835168    
#> 489: 0.516319    1.019750    3.422914    0.509819    0.003771    0.017088    0.835208    
#> 490: 0.516510    1.019736    3.422993    0.509634    0.003770    0.017083    0.835258    
#> 491: 0.516518    1.019740    3.423057    0.509465    0.003771    0.017094    0.835216    
#> 492: 0.516475    1.019752    3.423089    0.509349    0.003773    0.017099    0.835262    
#> 493: 0.516348    1.019765    3.423087    0.509220    0.003779    0.017107    0.835319    
#> 494: 0.516591    1.019807    3.423060    0.509353    0.003780    0.017103    0.835303    
#> 495: 0.516884    1.019839    3.423093    0.509643    0.003784    0.017112    0.835243    
#> 496: 0.517031    1.019900    3.423096    0.509774    0.003788    0.017125    0.835150    
#> 497: 0.517083    1.019887    3.423139    0.509803    0.003793    0.017140    0.835056    
#> 498: 0.517163    1.019867    3.423155    0.510000    0.003792    0.017140    0.835000    
#> 499: 0.517208    1.019856    3.423129    0.510066    0.003795    0.017135    0.834914    
#> 500: 0.517374    1.019845    3.423131    0.510287    0.003796    0.017118    0.834865    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.266834    0.982669    3.445818    0.392401    0.092545    0.016800    1.752255    
#> 002: 0.306481    0.996732    3.466738    0.372781    0.087918    0.015960    1.193386    
#> 003: 0.465098    0.969792    3.489051    0.354142    0.083522    0.015162    0.904420    
#> 004: 0.393002    0.963107    3.487792    0.336435    0.079346    0.014404    0.840689    
#> 005: 0.483832    0.985416    3.485269    0.319613    0.082170    0.013684    0.780477    
#> 006: 0.421104    0.986429    3.473725    0.303633    0.094123    0.014005    0.738621    
#> 007: 0.407478    0.969723    3.466463    0.297433    0.096915    0.016837    0.739845    
#> 008: 0.401272    0.961287    3.457903    0.333107    0.111642    0.017772    0.732177    
#> 009: 0.365834    0.964998    3.444370    0.316452    0.118859    0.016883    0.736714    
#> 010: 0.364948    0.954895    3.448504    0.311513    0.112916    0.016110    0.735868    
#> 011: 0.427700    0.961479    3.469493    0.350149    0.107271    0.020504    0.740364    
#> 012: 0.407248    0.980981    3.449636    0.332642    0.101907    0.019479    0.738388    
#> 013: 0.365497    0.969183    3.442572    0.316010    0.096812    0.018505    0.736745    
#> 014: 0.429491    0.974874    3.450242    0.365317    0.091971    0.017580    0.743178    
#> 015: 0.399413    0.994795    3.458057    0.372013    0.087373    0.017529    0.708719    
#> 016: 0.384508    0.991005    3.464206    0.353412    0.083004    0.016652    0.730901    
#> 017: 0.408349    0.999992    3.464900    0.335742    0.078888    0.016688    0.721813    
#> 018: 0.414288    0.993878    3.440063    0.335144    0.080343    0.016426    0.744164    
#> 019: 0.342514    1.006959    3.439436    0.319664    0.087521    0.015604    0.741324    
#> 020: 0.376172    0.999739    3.442970    0.308357    0.088708    0.014824    0.743069    
#> 021: 0.388100    0.974480    3.455468    0.292940    0.093021    0.016188    0.725086    
#> 022: 0.411396    0.990164    3.473671    0.315197    0.093298    0.015379    0.716567    
#> 023: 0.470052    0.995306    3.482355    0.321600    0.108972    0.014610    0.726797    
#> 024: 0.480330    1.005257    3.477759    0.361115    0.103524    0.013879    0.717339    
#> 025: 0.400871    0.975630    3.462618    0.343059    0.107914    0.013185    0.742988    
#> 026: 0.384872    1.017018    3.451543    0.325906    0.102519    0.012526    0.726427    
#> 027: 0.341517    1.030230    3.439411    0.311505    0.102703    0.011900    0.744393    
#> 028: 0.384310    0.997720    3.450069    0.299312    0.097568    0.011305    0.730052    
#> 029: 0.414608    1.003830    3.440368    0.296138    0.096806    0.010739    0.752787    
#> 030: 0.406994    1.002378    3.448053    0.331070    0.091966    0.011116    0.734241    
#> 031: 0.361231    0.990699    3.451479    0.344642    0.091451    0.011139    0.736740    
#> 032: 0.367798    0.978301    3.456648    0.327410    0.094198    0.011002    0.721344    
#> 033: 0.389062    1.005927    3.447545    0.335578    0.099948    0.010452    0.728361    
#> 034: 0.414481    1.008300    3.449304    0.355041    0.094951    0.011828    0.741502    
#> 035: 0.399979    0.971691    3.453389    0.337289    0.093926    0.011854    0.715346    
#> 036: 0.363605    1.007986    3.444294    0.320424    0.090895    0.011261    0.731167    
#> 037: 0.353777    1.012120    3.440138    0.339836    0.087538    0.011539    0.748879    
#> 038: 0.427779    0.994740    3.443529    0.490384    0.104906    0.014003    0.741888    
#> 039: 0.428333    0.968108    3.463587    0.465865    0.099661    0.013303    0.724677    
#> 040: 0.455359    0.988064    3.473080    0.450528    0.097259    0.015048    0.729286    
#> 041: 0.395793    0.985604    3.459136    0.428001    0.092396    0.014296    0.739518    
#> 042: 0.427067    0.974069    3.456050    0.406601    0.091832    0.013581    0.732402    
#> 043: 0.381658    0.998334    3.443698    0.386271    0.089536    0.012902    0.729940    
#> 044: 0.367818    1.007977    3.436330    0.366958    0.092540    0.012257    0.723697    
#> 045: 0.331863    1.005534    3.430683    0.348610    0.087913    0.011644    0.722143    
#> 046: 0.372839    0.994801    3.434959    0.378583    0.083518    0.011062    0.715263    
#> 047: 0.376439    1.033008    3.428654    0.359654    0.099269    0.010511    0.707238    
#> 048: 0.380413    1.022375    3.429067    0.412012    0.103353    0.012079    0.717623    
#> 049: 0.377426    1.008974    3.439580    0.391412    0.103057    0.011475    0.722993    
#> 050: 0.404190    0.973078    3.443197    0.379154    0.097904    0.011113    0.731484    
#> 051: 0.400472    0.997025    3.445340    0.360197    0.102293    0.010656    0.745873    
#> 052: 0.410388    1.001489    3.458980    0.342187    0.097178    0.010123    0.724553    
#> 053: 0.417469    0.982366    3.454613    0.464285    0.106275    0.011306    0.724204    
#> 054: 0.422066    0.961818    3.466006    0.441071    0.100994    0.012867    0.718146    
#> 055: 0.398909    0.974082    3.465270    0.419017    0.095944    0.013676    0.731322    
#> 056: 0.437362    0.952744    3.473816    0.398066    0.091147    0.015195    0.731759    
#> 057: 0.422467    0.981079    3.476508    0.378163    0.099958    0.014723    0.738157    
#> 058: 0.392392    0.978437    3.455241    0.359255    0.097993    0.013987    0.734359    
#> 059: 0.390766    0.953951    3.455702    0.365659    0.093093    0.013560    0.741100    
#> 060: 0.410068    0.960401    3.469416    0.417943    0.095799    0.012882    0.735983    
#> 061: 0.480343    0.953244    3.467648    0.498682    0.091009    0.015176    0.741143    
#> 062: 0.455956    0.980091    3.470555    0.494321    0.086459    0.015524    0.745029    
#> 063: 0.474029    0.943835    3.469889    0.469605    0.082136    0.014748    0.758520    
#> 064: 0.402025    0.960746    3.465696    0.446125    0.087447    0.014011    0.761360    
#> 065: 0.469269    0.943870    3.458696    0.423818    0.086770    0.013555    0.744371    
#> 066: 0.447459    0.977354    3.456403    0.402627    0.085413    0.012877    0.720913    
#> 067: 0.423988    0.994590    3.440968    0.394673    0.093064    0.012234    0.721983    
#> 068: 0.398907    0.989321    3.458444    0.384041    0.096777    0.011622    0.747878    
#> 069: 0.375130    0.994587    3.439996    0.364839    0.103456    0.013491    0.741885    
#> 070: 0.371549    1.005672    3.443697    0.346597    0.102397    0.016064    0.752692    
#> 071: 0.356450    1.015578    3.422557    0.345925    0.097277    0.015261    0.755212    
#> 072: 0.329459    1.009269    3.435339    0.330265    0.092413    0.014498    0.726971    
#> 073: 0.373815    0.996985    3.457252    0.317218    0.087792    0.013773    0.741775    
#> 074: 0.372120    0.990570    3.454870    0.330718    0.093456    0.013931    0.723124    
#> 075: 0.415517    0.977860    3.468786    0.338961    0.101684    0.013235    0.745087    
#> 076: 0.423648    0.979528    3.479745    0.322013    0.096600    0.012573    0.743407    
#> 077: 0.467585    0.959213    3.471466    0.305912    0.091770    0.012673    0.719553    
#> 078: 0.429745    0.979545    3.477259    0.295354    0.089769    0.014086    0.702986    
#> 079: 0.414886    0.999725    3.470833    0.390667    0.085281    0.016458    0.726322    
#> 080: 0.466295    0.967899    3.476852    0.389339    0.081017    0.015635    0.746184    
#> 081: 0.416386    0.997841    3.462740    0.369872    0.076966    0.014854    0.736027    
#> 082: 0.418803    0.969086    3.472626    0.351378    0.073118    0.014111    0.740813    
#> 083: 0.424438    0.987587    3.473389    0.333809    0.074827    0.013405    0.734191    
#> 084: 0.401048    0.976375    3.465452    0.317119    0.095237    0.013893    0.719755    
#> 085: 0.411096    1.001094    3.461960    0.301263    0.090475    0.013459    0.735353    
#> 086: 0.407805    1.015796    3.457300    0.338241    0.085951    0.013032    0.723914    
#> 087: 0.394599    1.016248    3.443035    0.321329    0.081654    0.012800    0.733702    
#> 088: 0.314898    1.003147    3.430990    0.369226    0.077571    0.015590    0.736026    
#> 089: 0.335868    1.034167    3.419621    0.398582    0.076975    0.016161    0.730998    
#> 090: 0.327052    1.020711    3.418086    0.389586    0.073126    0.015353    0.741148    
#> 091: 0.346807    1.022656    3.413433    0.370107    0.086266    0.014585    0.723105    
#> 092: 0.317609    1.046490    3.402363    0.351602    0.084352    0.013856    0.727928    
#> 093: 0.297384    1.027028    3.418468    0.334022    0.091594    0.013385    0.726960    
#> 094: 0.326957    1.033006    3.408233    0.317321    0.095513    0.012716    0.739783    
#> 095: 0.339060    1.034029    3.416726    0.377956    0.096981    0.012080    0.729472    
#> 096: 0.318680    1.013149    3.422406    0.359058    0.097634    0.011476    0.723809    
#> 097: 0.363643    1.018617    3.430318    0.341105    0.092752    0.010902    0.718993    
#> 098: 0.358875    1.031148    3.440783    0.352940    0.088115    0.010515    0.730653    
#> 099: 0.373704    1.002732    3.430899    0.335293    0.083709    0.009989    0.738176    
#> 100: 0.333546    0.990116    3.424899    0.348910    0.097472    0.009489    0.727789    
#> 101: 0.337797    0.995246    3.414775    0.331465    0.092598    0.009224    0.728826    
#> 102: 0.330888    1.019058    3.412204    0.314892    0.087968    0.009520    0.736550    
#> 103: 0.374910    1.018954    3.421577    0.330178    0.102241    0.009044    0.735234    
#> 104: 0.333394    1.034352    3.430300    0.375273    0.115357    0.008592    0.733075    
#> 105: 0.350898    1.000588    3.427112    0.356509    0.117696    0.008162    0.734551    
#> 106: 0.354494    1.006906    3.423977    0.375336    0.111811    0.007754    0.732208    
#> 107: 0.375289    1.015313    3.430276    0.356569    0.112076    0.007367    0.763342    
#> 108: 0.367469    0.990922    3.426204    0.344411    0.117395    0.006998    0.761354    
#> 109: 0.348551    1.005854    3.437324    0.368120    0.126038    0.006648    0.739677    
#> 110: 0.362685    0.992785    3.424994    0.349714    0.119736    0.006316    0.735445    
#> 111: 0.358662    0.990439    3.433111    0.332229    0.113750    0.006000    0.740560    
#> 112: 0.354387    0.981150    3.422089    0.322777    0.114893    0.005700    0.757074    
#> 113: 0.319411    1.026014    3.422198    0.306638    0.109148    0.005415    0.738074    
#> 114: 0.315991    1.021470    3.421330    0.291306    0.112918    0.005144    0.755342    
#> 115: 0.348474    0.996495    3.427974    0.304840    0.119902    0.005633    0.746489    
#> 116: 0.355194    1.006002    3.430551    0.310348    0.113907    0.006888    0.737754    
#> 117: 0.355786    1.032221    3.431869    0.307598    0.108212    0.007600    0.727853    
#> 118: 0.363426    0.989383    3.438345    0.315032    0.102801    0.007220    0.748781    
#> 119: 0.325071    1.014677    3.434871    0.299281    0.098983    0.006859    0.778025    
#> 120: 0.316810    0.981957    3.429322    0.284317    0.105190    0.006989    0.757030    
#> 121: 0.338107    1.032581    3.424772    0.290249    0.119720    0.006640    0.751738    
#> 122: 0.339490    1.005811    3.432627    0.325511    0.113734    0.006308    0.738888    
#> 123: 0.356066    1.032164    3.429573    0.309235    0.108047    0.006132    0.733160    
#> 124: 0.357452    1.034581    3.424253    0.311499    0.102645    0.005826    0.742619    
#> 125: 0.380526    1.047489    3.418438    0.365213    0.114750    0.005782    0.747140    
#> 126: 0.380994    1.027056    3.419863    0.376248    0.114019    0.007000    0.732936    
#> 127: 0.354227    1.009155    3.425822    0.369093    0.109917    0.006650    0.754643    
#> 128: 0.328858    1.010031    3.433696    0.350638    0.104421    0.006655    0.735807    
#> 129: 0.365072    1.013794    3.428783    0.380443    0.099200    0.007310    0.739172    
#> 130: 0.378103    1.030859    3.429275    0.368070    0.094240    0.007134    0.728769    
#> 131: 0.341633    1.011817    3.422452    0.357104    0.100248    0.008476    0.738593    
#> 132: 0.327117    1.017961    3.410208    0.347226    0.095236    0.008873    0.747857    
#> 133: 0.337989    1.023763    3.418645    0.415615    0.095321    0.008429    0.731801    
#> 134: 0.390154    0.986896    3.438765    0.394834    0.090555    0.008888    0.735974    
#> 135: 0.372301    1.006255    3.433209    0.392670    0.087662    0.008444    0.747320    
#> 136: 0.339593    0.971127    3.439495    0.419725    0.107768    0.009552    0.731382    
#> 137: 0.378427    0.996465    3.439335    0.398738    0.102380    0.009667    0.736010    
#> 138: 0.377025    1.011912    3.440164    0.397778    0.097261    0.009184    0.738740    
#> 139: 0.394486    0.998165    3.448753    0.377889    0.110678    0.010122    0.728546    
#> 140: 0.389840    1.018563    3.460895    0.377268    0.105144    0.011933    0.734979    
#> 141: 0.363864    1.010601    3.450568    0.358405    0.099887    0.011336    0.729296    
#> 142: 0.388602    0.989047    3.457540    0.340485    0.094893    0.010769    0.741141    
#> 143: 0.414046    1.008888    3.463800    0.382588    0.092331    0.010231    0.725438    
#> 144: 0.442649    1.004960    3.466256    0.385080    0.089718    0.009719    0.735434    
#> 145: 0.423946    1.008595    3.448994    0.397315    0.090115    0.009233    0.717605    
#> 146: 0.405563    0.999598    3.462599    0.377449    0.101465    0.009015    0.721265    
#> 147: 0.326855    0.990279    3.443821    0.358577    0.101395    0.008564    0.718517    
#> 148: 0.370851    1.009572    3.451534    0.340648    0.096325    0.008136    0.725212    
#> 149: 0.387560    0.992465    3.454416    0.377664    0.091509    0.010137    0.731696    
#> 150: 0.402427    0.978241    3.440210    0.365093    0.086934    0.009630    0.731064    
#> 151: 0.362893    1.011303    3.438879    0.346839    0.092585    0.009149    0.730659    
#> 152: 0.352054    1.019270    3.448250    0.297088    0.098739    0.008617    0.746493    
#> 153: 0.357748    1.004269    3.446076    0.330190    0.102489    0.007600    0.736885    
#> 154: 0.392328    1.024946    3.447077    0.327238    0.107048    0.008672    0.735353    
#> 155: 0.351157    0.990697    3.438466    0.321600    0.084715    0.008546    0.750345    
#> 156: 0.375739    1.014323    3.439387    0.345893    0.085415    0.008748    0.750332    
#> 157: 0.366769    1.005621    3.449843    0.317247    0.097480    0.009988    0.736473    
#> 158: 0.403058    1.017832    3.451397    0.320166    0.097779    0.008599    0.740862    
#> 159: 0.350629    1.014989    3.446888    0.285426    0.097014    0.008378    0.748630    
#> 160: 0.365172    0.986438    3.453506    0.315181    0.094829    0.008588    0.748404    
#> 161: 0.404754    0.988123    3.451495    0.265491    0.091403    0.009242    0.740607    
#> 162: 0.381997    1.019155    3.440297    0.293892    0.078779    0.008656    0.744584    
#> 163: 0.389936    1.000912    3.439716    0.313935    0.091161    0.009517    0.723769    
#> 164: 0.377688    1.018170    3.443938    0.328758    0.091947    0.009179    0.741460    
#> 165: 0.434738    0.982785    3.458085    0.355272    0.091820    0.009830    0.752996    
#> 166: 0.422495    1.018926    3.451709    0.293704    0.102008    0.007350    0.763268    
#> 167: 0.410842    1.015679    3.455708    0.313422    0.101134    0.006667    0.762008    
#> 168: 0.402464    1.024740    3.450041    0.308058    0.113523    0.005883    0.746601    
#> 169: 0.367094    1.039415    3.439082    0.314329    0.117500    0.004792    0.774502    
#> 170: 0.370870    1.022141    3.433497    0.294376    0.104623    0.005494    0.743200    
#> 171: 0.344504    1.005777    3.435103    0.311070    0.112043    0.004839    0.742157    
#> 172: 0.328623    1.019720    3.424996    0.308014    0.116815    0.004503    0.725714    
#> 173: 0.340250    1.017169    3.424331    0.291280    0.104804    0.003921    0.734608    
#> 174: 0.335587    1.004770    3.420394    0.315762    0.112050    0.004197    0.747423    
#> 175: 0.323161    1.011080    3.414151    0.315071    0.105223    0.004604    0.755712    
#> 176: 0.334450    1.041537    3.418308    0.345269    0.114228    0.003577    0.760597    
#> 177: 0.344641    1.013916    3.425284    0.306479    0.123718    0.004439    0.755704    
#> 178: 0.347682    1.010038    3.423823    0.348828    0.132331    0.004160    0.737249    
#> 179: 0.386912    1.043904    3.425957    0.362266    0.099373    0.005041    0.746611    
#> 180: 0.347371    1.013636    3.433233    0.379244    0.106222    0.004056    0.730733    
#> 181: 0.347864    1.011998    3.421977    0.349429    0.090932    0.004121    0.737574    
#> 182: 0.322675    1.022738    3.415179    0.288729    0.118917    0.003408    0.763938    
#> 183: 0.325447    1.027992    3.417689    0.311207    0.113616    0.003768    0.757026    
#> 184: 0.361233    1.006275    3.424665    0.264858    0.113112    0.004009    0.759503    
#> 185: 0.327441    1.019997    3.422127    0.299699    0.103108    0.004003    0.759916    
#> 186: 0.337009    1.032624    3.427706    0.408433    0.116936    0.005772    0.752405    
#> 187: 0.355424    1.015565    3.432285    0.369361    0.103135    0.006070    0.728702    
#> 188: 0.322480    1.033243    3.425577    0.369801    0.092097    0.006288    0.739899    
#> 189: 0.346095    1.031414    3.430196    0.366708    0.099858    0.006374    0.740019    
#> 190: 0.348210    1.024137    3.433833    0.398387    0.093856    0.006622    0.705635    
#> 191: 0.344566    1.020203    3.433949    0.280874    0.085320    0.007031    0.729851    
#> 192: 0.339022    1.018002    3.437920    0.293063    0.086816    0.007948    0.719287    
#> 193: 0.376798    1.012887    3.440879    0.290232    0.081090    0.006196    0.727703    
#> 194: 0.336893    1.018087    3.430118    0.349721    0.091736    0.007817    0.746650    
#> 195: 0.331654    1.027054    3.420674    0.328933    0.086833    0.006220    0.737572    
#> 196: 0.333982    1.030542    3.429644    0.314146    0.106759    0.006076    0.754594    
#> 197: 0.349909    1.021584    3.446612    0.329172    0.099818    0.006481    0.754226    
#> 198: 0.406275    0.987683    3.438210    0.345640    0.104070    0.006555    0.740440    
#> 199: 0.379160    0.990711    3.439481    0.378807    0.108558    0.005915    0.748868    
#> 200: 0.358421    1.001319    3.438498    0.354654    0.088920    0.005296    0.766428    
#> 201: 0.352583    0.997735    3.442936    0.355715    0.092161    0.006158    0.757808    
#> 202: 0.365544    0.998045    3.443409    0.364206    0.099527    0.006704    0.760071    
#> 203: 0.380722    0.997548    3.442439    0.367746    0.096734    0.006635    0.757925    
#> 204: 0.383990    0.990149    3.444884    0.372282    0.100251    0.006571    0.757627    
#> 205: 0.377048    0.994315    3.444691    0.355568    0.101529    0.006661    0.758205    
#> 206: 0.377081    1.000090    3.445479    0.349361    0.101070    0.006662    0.760468    
#> 207: 0.374127    0.999874    3.444151    0.343224    0.103109    0.006541    0.761421    
#> 208: 0.375721    0.999042    3.444518    0.347822    0.102519    0.006560    0.760163    
#> 209: 0.375225    0.997922    3.443063    0.346278    0.101635    0.006515    0.758383    
#> 210: 0.375519    0.995293    3.442588    0.345217    0.101840    0.006505    0.755787    
#> 211: 0.378170    0.996762    3.442788    0.341932    0.101725    0.006547    0.753913    
#> 212: 0.381682    0.996126    3.443570    0.342583    0.101508    0.006665    0.751980    
#> 213: 0.384720    0.995244    3.444075    0.345793    0.101596    0.006817    0.751592    
#> 214: 0.384982    0.994754    3.444582    0.344869    0.101149    0.006932    0.749426    
#> 215: 0.387299    0.993714    3.445572    0.347283    0.101051    0.007050    0.748432    
#> 216: 0.391352    0.992228    3.446849    0.348381    0.101302    0.007079    0.748655    
#> 217: 0.391974    0.991994    3.447597    0.354573    0.101065    0.007052    0.747420    
#> 218: 0.394243    0.992309    3.447743    0.355465    0.101605    0.007014    0.747072    
#> 219: 0.394519    0.991371    3.447176    0.354631    0.101253    0.006981    0.746986    
#> 220: 0.392068    0.991251    3.446698    0.352620    0.101451    0.006944    0.747408    
#> 221: 0.390860    0.991971    3.446397    0.352620    0.101605    0.006929    0.746670    
#> 222: 0.390040    0.991755    3.446074    0.349927    0.101742    0.006951    0.746489    
#> 223: 0.389874    0.992375    3.446052    0.349210    0.102297    0.006947    0.746015    
#> 224: 0.390677    0.992753    3.446277    0.348848    0.102100    0.006927    0.746083    
#> 225: 0.390518    0.991534    3.446564    0.349755    0.102712    0.006909    0.745936    
#> 226: 0.392150    0.991043    3.446653    0.351098    0.102746    0.006857    0.746084    
#> 227: 0.391372    0.990724    3.446860    0.348016    0.102874    0.006780    0.746493    
#> 228: 0.390784    0.991852    3.446637    0.347352    0.102969    0.006814    0.746428    
#> 229: 0.389875    0.991531    3.446379    0.347960    0.103120    0.006868    0.745751    
#> 230: 0.390069    0.991591    3.446285    0.349174    0.103410    0.006883    0.745271    
#> 231: 0.390425    0.992488    3.446240    0.349766    0.103355    0.006898    0.744692    
#> 232: 0.389677    0.992750    3.446278    0.348518    0.102739    0.006925    0.744460    
#> 233: 0.388702    0.992064    3.446318    0.347890    0.102716    0.006941    0.744640    
#> 234: 0.388265    0.991944    3.446421    0.345920    0.102633    0.006968    0.744506    
#> 235: 0.388116    0.992041    3.446383    0.344150    0.102662    0.006996    0.744764    
#> 236: 0.387704    0.992178    3.446242    0.343595    0.102595    0.007022    0.744837    
#> 237: 0.387931    0.992657    3.445960    0.344700    0.102641    0.007087    0.744735    
#> 238: 0.387501    0.992475    3.445747    0.344303    0.102805    0.007148    0.744694    
#> 239: 0.386925    0.992926    3.445466    0.344332    0.103146    0.007187    0.744535    
#> 240: 0.387320    0.992666    3.445385    0.345316    0.103205    0.007186    0.744414    
#> 241: 0.386850    0.992168    3.445266    0.344052    0.103129    0.007153    0.744563    
#> 242: 0.386001    0.992032    3.444949    0.344485    0.103785    0.007191    0.744395    
#> 243: 0.384622    0.992304    3.444582    0.345616    0.104197    0.007216    0.744255    
#> 244: 0.384139    0.992650    3.444567    0.344435    0.104214    0.007308    0.744207    
#> 245: 0.383267    0.992454    3.444393    0.344878    0.104276    0.007341    0.744272    
#> 246: 0.382987    0.992396    3.444303    0.344255    0.103935    0.007386    0.744181    
#> 247: 0.382760    0.992409    3.444481    0.343663    0.103632    0.007435    0.743827    
#> 248: 0.382719    0.992895    3.444501    0.343659    0.103195    0.007452    0.743574    
#> 249: 0.382082    0.992790    3.444621    0.342917    0.103115    0.007470    0.743701    
#> 250: 0.382130    0.992968    3.444832    0.341667    0.103098    0.007490    0.743404    
#> 251: 0.382047    0.993433    3.445072    0.340692    0.102850    0.007468    0.743437    
#> 252: 0.382537    0.993742    3.445393    0.341755    0.102773    0.007457    0.743315    
#> 253: 0.382633    0.993986    3.445570    0.342138    0.102497    0.007451    0.743438    
#> 254: 0.383027    0.994019    3.445805    0.341603    0.102387    0.007444    0.743389    
#> 255: 0.383739    0.994293    3.446089    0.341715    0.102471    0.007445    0.743377    
#> 256: 0.384778    0.993990    3.446231    0.342530    0.102694    0.007468    0.743339    
#> 257: 0.384854    0.993617    3.446352    0.342504    0.102798    0.007483    0.743422    
#> 258: 0.384944    0.993113    3.446357    0.342451    0.102755    0.007482    0.743291    
#> 259: 0.384735    0.993123    3.446447    0.341819    0.102559    0.007471    0.743302    
#> 260: 0.384794    0.993202    3.446547    0.342259    0.102427    0.007448    0.742850    
#> 261: 0.385297    0.992927    3.446800    0.343359    0.102323    0.007459    0.742708    
#> 262: 0.385585    0.993068    3.447047    0.343878    0.102199    0.007479    0.742479    
#> 263: 0.385896    0.993381    3.447204    0.345245    0.102231    0.007524    0.742436    
#> 264: 0.385640    0.993340    3.447145    0.345526    0.102192    0.007530    0.742694    
#> 265: 0.385818    0.993500    3.447285    0.346112    0.102279    0.007541    0.742743    
#> 266: 0.386133    0.993536    3.447401    0.345982    0.102020    0.007572    0.742561    
#> 267: 0.386483    0.993368    3.447598    0.345747    0.101885    0.007593    0.742348    
#> 268: 0.386946    0.993169    3.447675    0.345589    0.101937    0.007608    0.742238    
#> 269: 0.387750    0.993065    3.447769    0.345363    0.101741    0.007621    0.742442    
#> 270: 0.388515    0.993473    3.447649    0.345098    0.101653    0.007586    0.742171    
#> 271: 0.388322    0.993897    3.447493    0.344871    0.101701    0.007552    0.742363    
#> 272: 0.388090    0.993835    3.447310    0.343945    0.101668    0.007540    0.743005    
#> 273: 0.387765    0.994006    3.447172    0.343511    0.101686    0.007521    0.743296    
#> 274: 0.387497    0.994375    3.447111    0.343381    0.101627    0.007476    0.743530    
#> 275: 0.387193    0.994671    3.446913    0.343268    0.101715    0.007437    0.743649    
#> 276: 0.386792    0.994687    3.447018    0.343380    0.101636    0.007425    0.743847    
#> 277: 0.386724    0.994732    3.447149    0.342965    0.101556    0.007425    0.743809    
#> 278: 0.386070    0.994489    3.447274    0.341774    0.101678    0.007426    0.744023    
#> 279: 0.385630    0.994236    3.447284    0.341649    0.101756    0.007426    0.744245    
#> 280: 0.385609    0.994223    3.447358    0.341751    0.101686    0.007418    0.743986    
#> 281: 0.385590    0.994295    3.447415    0.341647    0.101591    0.007410    0.744011    
#> 282: 0.385653    0.994363    3.447447    0.341586    0.101362    0.007431    0.743805    
#> 283: 0.385668    0.994316    3.447502    0.342027    0.101099    0.007483    0.743754    
#> 284: 0.385873    0.994106    3.447556    0.341997    0.100876    0.007519    0.743558    
#> 285: 0.385978    0.994363    3.447519    0.341355    0.100544    0.007582    0.743396    
#> 286: 0.385913    0.994578    3.447596    0.340579    0.100175    0.007622    0.743247    
#> 287: 0.385983    0.994715    3.447574    0.339774    0.100021    0.007647    0.743215    
#> 288: 0.386374    0.994441    3.447673    0.339320    0.099799    0.007687    0.743377    
#> 289: 0.386677    0.994375    3.447766    0.338963    0.099699    0.007699    0.743464    
#> 290: 0.387035    0.994139    3.447755    0.338844    0.099718    0.007694    0.743675    
#> 291: 0.387434    0.994024    3.447998    0.339233    0.099652    0.007718    0.743376    
#> 292: 0.387626    0.993764    3.448174    0.339705    0.099693    0.007743    0.743209    
#> 293: 0.387798    0.993784    3.448252    0.339501    0.099786    0.007763    0.742980    
#> 294: 0.387847    0.993903    3.448205    0.339631    0.099659    0.007776    0.742776    
#> 295: 0.387654    0.993690    3.448153    0.339561    0.099615    0.007778    0.742630    
#> 296: 0.387389    0.993635    3.448164    0.339502    0.099475    0.007824    0.742551    
#> 297: 0.387225    0.993765    3.448055    0.339595    0.099370    0.007844    0.742696    
#> 298: 0.386868    0.993594    3.447980    0.339402    0.099362    0.007851    0.742765    
#> 299: 0.386137    0.993711    3.447851    0.338625    0.099384    0.007842    0.742801    
#> 300: 0.386027    0.993698    3.447882    0.338137    0.099334    0.007858    0.742591    
#> 301: 0.386138    0.993501    3.447845    0.338205    0.099317    0.007864    0.742572    
#> 302: 0.386013    0.993642    3.447768    0.337776    0.099310    0.007882    0.742488    
#> 303: 0.385738    0.993916    3.447616    0.337388    0.099260    0.007877    0.742411    
#> 304: 0.385724    0.994061    3.447503    0.337783    0.099236    0.007893    0.742462    
#> 305: 0.385641    0.993909    3.447542    0.337508    0.099077    0.007946    0.742497    
#> 306: 0.385337    0.993985    3.447427    0.337369    0.099069    0.007979    0.742375    
#> 307: 0.385460    0.994008    3.447440    0.338156    0.098967    0.008005    0.742390    
#> 308: 0.385065    0.993895    3.447354    0.338207    0.098961    0.008033    0.742302    
#> 309: 0.385136    0.993604    3.447274    0.337689    0.098885    0.008057    0.742451    
#> 310: 0.385136    0.993655    3.447137    0.337373    0.098773    0.008077    0.742335    
#> 311: 0.385078    0.993712    3.447171    0.337171    0.098531    0.008127    0.742134    
#> 312: 0.385195    0.993488    3.447212    0.337016    0.098386    0.008171    0.742159    
#> 313: 0.385405    0.993076    3.447322    0.337017    0.098498    0.008209    0.742136    
#> 314: 0.385128    0.993091    3.447323    0.336966    0.098511    0.008222    0.742119    
#> 315: 0.384881    0.993313    3.447242    0.337524    0.098390    0.008259    0.742068    
#> 316: 0.385040    0.993428    3.447164    0.337761    0.098372    0.008267    0.742108    
#> 317: 0.384993    0.993273    3.447172    0.338234    0.098412    0.008280    0.741964    
#> 318: 0.384924    0.993284    3.447072    0.338069    0.098478    0.008288    0.741848    
#> 319: 0.384889    0.993238    3.447093    0.337711    0.098587    0.008296    0.741794    
#> 320: 0.384511    0.993274    3.447023    0.337559    0.098592    0.008300    0.741857    
#> 321: 0.384301    0.993442    3.446852    0.337536    0.098626    0.008313    0.741895    
#> 322: 0.384016    0.993566    3.446675    0.337782    0.098682    0.008321    0.741799    
#> 323: 0.383413    0.993592    3.446491    0.338243    0.098623    0.008339    0.741703    
#> 324: 0.383415    0.993732    3.446502    0.338527    0.098650    0.008360    0.741414    
#> 325: 0.383521    0.993924    3.446438    0.338167    0.098603    0.008370    0.741230    
#> 326: 0.383522    0.993758    3.446393    0.337502    0.098595    0.008380    0.741317    
#> 327: 0.384004    0.993814    3.446471    0.337052    0.098524    0.008397    0.741412    
#> 328: 0.384181    0.993917    3.446536    0.336700    0.098457    0.008430    0.741384    
#> 329: 0.384438    0.993821    3.446691    0.336402    0.098325    0.008470    0.741331    
#> 330: 0.384616    0.993817    3.446803    0.336329    0.098258    0.008488    0.741350    
#> 331: 0.384793    0.993902    3.446834    0.336036    0.098200    0.008476    0.741368    
#> 332: 0.384899    0.993835    3.446924    0.335711    0.098107    0.008467    0.741405    
#> 333: 0.384951    0.993837    3.446886    0.335834    0.098039    0.008471    0.741348    
#> 334: 0.384607    0.993831    3.446758    0.336624    0.097986    0.008473    0.741307    
#> 335: 0.384328    0.994063    3.446560    0.336756    0.098003    0.008477    0.741289    
#> 336: 0.383846    0.994382    3.446397    0.337165    0.097914    0.008489    0.741358    
#> 337: 0.383300    0.994852    3.446182    0.337421    0.097901    0.008499    0.741331    
#> 338: 0.382903    0.994979    3.446145    0.337555    0.097859    0.008498    0.741342    
#> 339: 0.382494    0.995192    3.446061    0.337826    0.097708    0.008505    0.741205    
#> 340: 0.382294    0.994996    3.446009    0.338279    0.097548    0.008530    0.741168    
#> 341: 0.382463    0.994929    3.446085    0.338563    0.097395    0.008570    0.741033    
#> 342: 0.382319    0.994818    3.446124    0.338644    0.097368    0.008602    0.740869    
#> 343: 0.382041    0.994749    3.446166    0.338312    0.097261    0.008626    0.740815    
#> 344: 0.382173    0.994625    3.446275    0.338057    0.097188    0.008657    0.740828    
#> 345: 0.382360    0.994480    3.446409    0.338271    0.097211    0.008699    0.740704    
#> 346: 0.382491    0.994305    3.446445    0.338467    0.097053    0.008724    0.740567    
#> 347: 0.382787    0.994204    3.446410    0.338904    0.096991    0.008745    0.740491    
#> 348: 0.382702    0.994174    3.446370    0.339498    0.096956    0.008758    0.740620    
#> 349: 0.382716    0.994128    3.446313    0.339507    0.096987    0.008765    0.740617    
#> 350: 0.382460    0.994030    3.446283    0.339358    0.096988    0.008754    0.740599    
#> 351: 0.382294    0.994154    3.446194    0.339152    0.097031    0.008746    0.740666    
#> 352: 0.381732    0.994321    3.446133    0.338926    0.097059    0.008748    0.740735    
#> 353: 0.381898    0.994410    3.446162    0.338840    0.097035    0.008745    0.740618    
#> 354: 0.381972    0.994469    3.446105    0.338892    0.096985    0.008750    0.740490    
#> 355: 0.382285    0.994406    3.446057    0.339507    0.096953    0.008750    0.740447    
#> 356: 0.382246    0.994321    3.446087    0.339669    0.096944    0.008754    0.740540    
#> 357: 0.382297    0.994372    3.446097    0.339532    0.096880    0.008746    0.740608    
#> 358: 0.382175    0.994398    3.446148    0.339411    0.096817    0.008749    0.740453    
#> 359: 0.381893    0.994585    3.446101    0.339232    0.096782    0.008752    0.740357    
#> 360: 0.381640    0.994751    3.446027    0.339104    0.096758    0.008756    0.740133    
#> 361: 0.381311    0.994803    3.445906    0.339047    0.096637    0.008765    0.740120    
#> 362: 0.381102    0.994845    3.445777    0.339005    0.096605    0.008766    0.740020    
#> 363: 0.380962    0.994920    3.445665    0.339121    0.096627    0.008779    0.739837    
#> 364: 0.380788    0.995065    3.445576    0.339523    0.096652    0.008787    0.739813    
#> 365: 0.380636    0.995086    3.445504    0.339700    0.096727    0.008800    0.739721    
#> 366: 0.380631    0.995083    3.445357    0.340113    0.096604    0.008814    0.739781    
#> 367: 0.380661    0.995121    3.445262    0.340210    0.096635    0.008813    0.739672    
#> 368: 0.380749    0.995322    3.445181    0.340146    0.096551    0.008814    0.739555    
#> 369: 0.380671    0.995438    3.445143    0.340227    0.096453    0.008840    0.739474    
#> 370: 0.380653    0.995515    3.445131    0.340404    0.096378    0.008869    0.739465    
#> 371: 0.380394    0.995580    3.444996    0.340287    0.096278    0.008885    0.739361    
#> 372: 0.380181    0.995730    3.444944    0.340278    0.096224    0.008886    0.739443    
#> 373: 0.380075    0.995882    3.444893    0.340890    0.096199    0.008894    0.739388    
#> 374: 0.379972    0.995945    3.444837    0.340894    0.096147    0.008884    0.739324    
#> 375: 0.379688    0.996019    3.444773    0.340951    0.096157    0.008872    0.739369    
#> 376: 0.379692    0.996148    3.444759    0.341006    0.096249    0.008868    0.739296    
#> 377: 0.379572    0.996282    3.444695    0.340987    0.096272    0.008859    0.739273    
#> 378: 0.379425    0.996343    3.444629    0.340852    0.096269    0.008843    0.739391    
#> 379: 0.379369    0.996247    3.444632    0.340890    0.096217    0.008848    0.739315    
#> 380: 0.379175    0.996196    3.444629    0.340666    0.096288    0.008852    0.739313    
#> 381: 0.379014    0.996280    3.444569    0.340482    0.096317    0.008848    0.739249    
#> 382: 0.378885    0.996314    3.444546    0.340445    0.096264    0.008845    0.739098    
#> 383: 0.378906    0.996273    3.444539    0.340715    0.096345    0.008836    0.738988    
#> 384: 0.378765    0.996302    3.444547    0.341005    0.096323    0.008830    0.738962    
#> 385: 0.378836    0.996206    3.444564    0.341333    0.096302    0.008841    0.738893    
#> 386: 0.378966    0.996344    3.444608    0.341439    0.096265    0.008851    0.738882    
#> 387: 0.378974    0.996473    3.444599    0.341562    0.096227    0.008859    0.738811    
#> 388: 0.379059    0.996533    3.444618    0.341384    0.096228    0.008874    0.738706    
#> 389: 0.379021    0.996355    3.444596    0.341129    0.096147    0.008876    0.738788    
#> 390: 0.378865    0.996313    3.444577    0.341062    0.096098    0.008884    0.738800    
#> 391: 0.378850    0.996241    3.444537    0.341106    0.096034    0.008892    0.738778    
#> 392: 0.378749    0.996292    3.444527    0.341168    0.096051    0.008893    0.738811    
#> 393: 0.378710    0.996372    3.444470    0.341241    0.096084    0.008889    0.738738    
#> 394: 0.378524    0.996404    3.444424    0.341171    0.096152    0.008874    0.738711    
#> 395: 0.378795    0.996469    3.444493    0.341030    0.096211    0.008859    0.738750    
#> 396: 0.378958    0.996512    3.444556    0.341046    0.096283    0.008849    0.738680    
#> 397: 0.379095    0.996475    3.444648    0.340805    0.096277    0.008841    0.738730    
#> 398: 0.379393    0.996442    3.444725    0.340743    0.096344    0.008840    0.738788    
#> 399: 0.379587    0.996406    3.444859    0.340936    0.096298    0.008839    0.738859    
#> 400: 0.379871    0.996360    3.444955    0.341095    0.096297    0.008846    0.738839    
#> 401: 0.379952    0.996286    3.444985    0.341004    0.096311    0.008854    0.738914    
#> 402: 0.380101    0.996344    3.445015    0.340890    0.096217    0.008876    0.738926    
#> 403: 0.380414    0.996238    3.445087    0.340619    0.096101    0.008895    0.738959    
#> 404: 0.380555    0.996254    3.445116    0.340477    0.096050    0.008908    0.738953    
#> 405: 0.380604    0.996251    3.445219    0.340266    0.096060    0.008926    0.738984    
#> 406: 0.380711    0.996241    3.445292    0.340150    0.096048    0.008941    0.738987    
#> 407: 0.380810    0.996290    3.445341    0.340229    0.096069    0.008940    0.738967    
#> 408: 0.381118    0.996347    3.445381    0.340233    0.096058    0.008940    0.738951    
#> 409: 0.381193    0.996253    3.445386    0.340232    0.096026    0.008939    0.738979    
#> 410: 0.381180    0.996291    3.445318    0.340304    0.096045    0.008946    0.738986    
#> 411: 0.381324    0.996155    3.445306    0.340591    0.096046    0.008951    0.738962    
#> 412: 0.381402    0.996252    3.445299    0.340916    0.095990    0.008953    0.738930    
#> 413: 0.381376    0.996279    3.445263    0.340994    0.095986    0.008942    0.738898    
#> 414: 0.381095    0.996269    3.445226    0.340985    0.096013    0.008939    0.738851    
#> 415: 0.381066    0.996188    3.445195    0.341070    0.096066    0.008939    0.738790    
#> 416: 0.381166    0.996302    3.445198    0.341451    0.096104    0.008939    0.738667    
#> 417: 0.381204    0.996331    3.445171    0.341694    0.096108    0.008936    0.738549    
#> 418: 0.381007    0.996478    3.445085    0.341656    0.096183    0.008928    0.738489    
#> 419: 0.381000    0.996628    3.445002    0.341862    0.096133    0.008927    0.738462    
#> 420: 0.380928    0.996649    3.444967    0.341803    0.096106    0.008917    0.738451    
#> 421: 0.380766    0.996710    3.444968    0.341742    0.096106    0.008915    0.738425    
#> 422: 0.380832    0.996595    3.444991    0.341771    0.096044    0.008923    0.738368    
#> 423: 0.380884    0.996499    3.445015    0.341640    0.095967    0.008932    0.738363    
#> 424: 0.380675    0.996433    3.444969    0.341410    0.095869    0.008937    0.738395    
#> 425: 0.380744    0.996449    3.444935    0.341509    0.095846    0.008943    0.738378    
#> 426: 0.380714    0.996555    3.444918    0.341492    0.095865    0.008941    0.738390    
#> 427: 0.380528    0.996518    3.444919    0.341420    0.095854    0.008947    0.738385    
#> 428: 0.380456    0.996580    3.444893    0.341638    0.095840    0.008947    0.738378    
#> 429: 0.380437    0.996628    3.444903    0.341705    0.095827    0.008945    0.738395    
#> 430: 0.380444    0.996695    3.444904    0.341906    0.095925    0.008946    0.738332    
#> 431: 0.380539    0.996630    3.444899    0.341958    0.095998    0.008947    0.738324    
#> 432: 0.380487    0.996751    3.444900    0.342010    0.095972    0.008960    0.738267    
#> 433: 0.380669    0.996837    3.444939    0.341996    0.095958    0.008960    0.738242    
#> 434: 0.380608    0.996836    3.444945    0.341980    0.095984    0.008966    0.738170    
#> 435: 0.380730    0.996848    3.444953    0.342025    0.095999    0.008968    0.738141    
#> 436: 0.380764    0.996693    3.444977    0.342203    0.095977    0.008974    0.738180    
#> 437: 0.380851    0.996608    3.444992    0.342526    0.095968    0.008986    0.738160    
#> 438: 0.380810    0.996722    3.445004    0.342278    0.095951    0.008983    0.738175    
#> 439: 0.380787    0.996780    3.445014    0.342207    0.095941    0.008978    0.738099    
#> 440: 0.380616    0.996776    3.445044    0.342054    0.095994    0.008965    0.738132    
#> 441: 0.380602    0.996778    3.445073    0.341899    0.096014    0.008958    0.738187    
#> 442: 0.380440    0.996853    3.445074    0.341932    0.096043    0.008946    0.738111    
#> 443: 0.380549    0.996913    3.445081    0.341787    0.096113    0.008940    0.738178    
#> 444: 0.380689    0.996958    3.445094    0.341963    0.096152    0.008944    0.738131    
#> 445: 0.380720    0.997003    3.445063    0.342129    0.096108    0.008954    0.738152    
#> 446: 0.380597    0.997048    3.445040    0.341843    0.096061    0.008960    0.738171    
#> 447: 0.380630    0.997084    3.445036    0.341647    0.096033    0.008969    0.738128    
#> 448: 0.380457    0.997162    3.445025    0.341337    0.096094    0.008966    0.738056    
#> 449: 0.380465    0.997278    3.445082    0.341179    0.096129    0.008960    0.738067    
#> 450: 0.380375    0.997278    3.445094    0.341108    0.096180    0.008954    0.738126    
#> 451: 0.380373    0.997314    3.445049    0.340910    0.096276    0.008952    0.738183    
#> 452: 0.380242    0.997413    3.444969    0.340703    0.096377    0.008940    0.738216    
#> 453: 0.380113    0.997511    3.444889    0.340580    0.096426    0.008929    0.738225    
#> 454: 0.380004    0.997612    3.444835    0.340462    0.096478    0.008919    0.738180    
#> 455: 0.380040    0.997664    3.444804    0.340463    0.096464    0.008913    0.738176    
#> 456: 0.379927    0.997722    3.444767    0.340239    0.096481    0.008916    0.738167    
#> 457: 0.379817    0.997702    3.444790    0.340053    0.096476    0.008915    0.738131    
#> 458: 0.379808    0.997831    3.444821    0.339869    0.096483    0.008920    0.738111    
#> 459: 0.379568    0.998047    3.444811    0.339821    0.096522    0.008929    0.738119    
#> 460: 0.379319    0.998109    3.444730    0.339957    0.096500    0.008936    0.738050    
#> 461: 0.379261    0.998178    3.444723    0.339953    0.096492    0.008950    0.738015    
#> 462: 0.379218    0.998246    3.444745    0.339998    0.096440    0.008960    0.737948    
#> 463: 0.379185    0.998304    3.444749    0.340025    0.096385    0.008962    0.737968    
#> 464: 0.379270    0.998317    3.444740    0.339912    0.096370    0.008961    0.737929    
#> 465: 0.379199    0.998145    3.444728    0.339651    0.096377    0.008961    0.737920    
#> 466: 0.379161    0.998165    3.444681    0.339466    0.096357    0.008950    0.737942    
#> 467: 0.378949    0.998153    3.444647    0.339310    0.096360    0.008947    0.737900    
#> 468: 0.379020    0.998190    3.444654    0.339153    0.096398    0.008939    0.737955    
#> 469: 0.379027    0.998276    3.444667    0.339229    0.096422    0.008935    0.737982    
#> 470: 0.378990    0.998266    3.444667    0.339176    0.096445    0.008945    0.737897    
#> 471: 0.378923    0.998177    3.444634    0.339218    0.096412    0.008943    0.737868    
#> 472: 0.379015    0.998142    3.444648    0.339406    0.096444    0.008948    0.737792    
#> 473: 0.378944    0.998143    3.444660    0.339330    0.096377    0.008964    0.737680    
#> 474: 0.378861    0.998144    3.444674    0.339300    0.096334    0.008978    0.737641    
#> 475: 0.378992    0.998221    3.444683    0.339357    0.096280    0.008983    0.737633    
#> 476: 0.378958    0.998223    3.444658    0.339484    0.096252    0.008984    0.737633    
#> 477: 0.378919    0.998254    3.444660    0.339636    0.096210    0.008990    0.737558    
#> 478: 0.378828    0.998237    3.444629    0.339758    0.096186    0.008989    0.737533    
#> 479: 0.378878    0.998294    3.444622    0.339832    0.096185    0.008990    0.737525    
#> 480: 0.378890    0.998323    3.444656    0.339793    0.096165    0.008993    0.737556    
#> 481: 0.378978    0.998362    3.444651    0.339892    0.096179    0.008990    0.737555    
#> 482: 0.379039    0.998358    3.444633    0.339902    0.096209    0.008999    0.737585    
#> 483: 0.378970    0.998334    3.444630    0.339990    0.096194    0.008995    0.737579    
#> 484: 0.378914    0.998169    3.444653    0.340029    0.096152    0.008996    0.737638    
#> 485: 0.379000    0.998180    3.444673    0.339943    0.096198    0.009003    0.737607    
#> 486: 0.379055    0.998196    3.444722    0.339821    0.096237    0.008999    0.737591    
#> 487: 0.379217    0.998187    3.444785    0.339755    0.096214    0.008995    0.737539    
#> 488: 0.379136    0.998210    3.444798    0.339767    0.096185    0.009005    0.737483    
#> 489: 0.379152    0.998179    3.444797    0.339961    0.096188    0.009024    0.737408    
#> 490: 0.379233    0.998110    3.444846    0.340059    0.096118    0.009030    0.737350    
#> 491: 0.379259    0.998138    3.444908    0.340151    0.096097    0.009041    0.737280    
#> 492: 0.379292    0.998169    3.444935    0.340177    0.096159    0.009041    0.737321    
#> 493: 0.379292    0.998104    3.444971    0.340254    0.096196    0.009049    0.737261    
#> 494: 0.379464    0.998108    3.444969    0.340085    0.096190    0.009049    0.737236    
#> 495: 0.379567    0.998115    3.445008    0.340017    0.096154    0.009057    0.737190    
#> 496: 0.379668    0.998163    3.444989    0.340049    0.096160    0.009066    0.737155    
#> 497: 0.379605    0.998151    3.444984    0.339973    0.096138    0.009079    0.737165    
#> 498: 0.379514    0.998162    3.444944    0.339808    0.096075    0.009089    0.737152    
#> 499: 0.379409    0.998254    3.444889    0.339843    0.096083    0.009097    0.737058    
#> 500: 0.379313    0.998244    3.444833    0.339756    0.096076    0.009104    0.736991    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.330880    0.964213    3.444093    0.392401    0.074073    0.016800    1.712569    
#> 002: 0.508302    1.078555    3.474097    0.372781    0.070370    0.015960    1.116714    
#> 003: 0.710375    1.066179    3.483932    0.354142    0.066851    0.015162    0.824486    
#> 004: 0.701514    1.072177    3.488466    0.516769    0.063509    0.014404    0.729655    
#> 005: 0.839331    1.082394    3.489116    0.755491    0.060333    0.013684    0.666756    
#> 006: 0.840923    1.068973    3.491638    0.782150    0.057317    0.013000    0.622224    
#> 007: 0.826168    1.071468    3.483059    0.830857    0.054451    0.012350    0.617573    
#> 008: 0.814991    1.073275    3.473498    0.845061    0.051728    0.011732    0.622317    
#> 009: 0.789332    1.076031    3.472630    0.898922    0.049142    0.011146    0.616014    
#> 010: 0.803505    1.074107    3.469232    0.919681    0.046685    0.010588    0.618952    
#> 011: 0.844991    1.073609    3.473028    0.903609    0.044350    0.010426    0.613211    
#> 012: 0.853472    1.072994    3.470365    0.997953    0.042133    0.011558    0.612382    
#> 013: 0.916578    1.086055    3.477965    1.193904    0.040026    0.010980    0.626688    
#> 014: 0.910786    1.080253    3.472474    1.239708    0.038025    0.011440    0.636189    
#> 015: 0.871509    1.083220    3.485312    1.177723    0.036124    0.011330    0.611268    
#> 016: 0.856827    1.091681    3.483075    1.118837    0.034318    0.010763    0.627130    
#> 017: 0.894595    1.104243    3.474661    1.078958    0.032602    0.011381    0.612786    
#> 018: 0.904177    1.102722    3.470128    1.087623    0.030972    0.010812    0.606222    
#> 019: 0.874888    1.098134    3.475199    1.042522    0.029423    0.010578    0.588034    
#> 020: 0.892316    1.081769    3.481315    1.006138    0.028801    0.010049    0.593078    
#> 021: 0.871653    1.081097    3.489053    0.955831    0.027361    0.009547    0.596734    
#> 022: 0.860047    1.071830    3.489727    0.908039    0.025993    0.009117    0.594366    
#> 023: 0.913077    1.075922    3.505416    0.881864    0.024693    0.009380    0.607695    
#> 024: 0.909040    1.089585    3.496501    0.933072    0.023458    0.010975    0.596829    
#> 025: 0.865679    1.075184    3.494383    0.934878    0.022285    0.013176    0.605318    
#> 026: 0.866237    1.102136    3.482116    0.910585    0.021171    0.012614    0.617036    
#> 027: 0.848247    1.106384    3.480554    0.881619    0.020394    0.014375    0.606252    
#> 028: 0.867459    1.091544    3.489002    0.852279    0.019374    0.013656    0.594906    
#> 029: 0.841104    1.084565    3.478679    0.809665    0.018416    0.013394    0.612969    
#> 030: 0.889660    1.101076    3.479626    0.988432    0.020051    0.012724    0.598514    
#> 031: 0.847132    1.096555    3.486841    0.939010    0.023416    0.012088    0.598362    
#> 032: 0.815828    1.095292    3.486497    0.892060    0.023279    0.011592    0.594814    
#> 033: 0.824060    1.104935    3.479661    0.873162    0.022115    0.011296    0.600315    
#> 034: 0.837832    1.105679    3.487148    0.873014    0.021009    0.013459    0.592086    
#> 035: 0.833663    1.090902    3.480283    0.841891    0.019959    0.012786    0.590977    
#> 036: 0.852098    1.091800    3.482713    0.799797    0.018961    0.013342    0.607657    
#> 037: 0.882395    1.086279    3.491468    0.969255    0.022379    0.015566    0.610886    
#> 038: 0.916743    1.093837    3.474083    1.345212    0.024919    0.014787    0.605667    
#> 039: 0.896719    1.079275    3.479580    1.277951    0.023673    0.014860    0.608885    
#> 040: 0.839965    1.085644    3.486190    1.214054    0.022489    0.017742    0.611185    
#> 041: 0.745647    1.079985    3.473253    1.153351    0.021365    0.016911    0.619087    
#> 042: 0.853578    1.075617    3.471305    1.095684    0.020297    0.016066    0.605464    
#> 043: 0.862572    1.098395    3.468167    1.040899    0.019282    0.015263    0.583671    
#> 044: 0.858444    1.109159    3.467966    0.988854    0.018318    0.014499    0.587332    
#> 045: 0.845251    1.115278    3.463211    0.951979    0.017402    0.016762    0.583681    
#> 046: 0.824425    1.102838    3.467684    0.938686    0.018459    0.015924    0.585481    
#> 047: 0.828380    1.107657    3.468019    0.907087    0.017536    0.016871    0.594478    
#> 048: 0.807287    1.089946    3.470018    0.943575    0.016660    0.019009    0.596090    
#> 049: 0.792411    1.074031    3.470174    0.896397    0.016825    0.018404    0.610792    
#> 050: 0.848929    1.063283    3.474084    1.013600    0.018018    0.018538    0.627501    
#> 051: 0.824804    1.083080    3.458075    1.061705    0.017117    0.019055    0.632178    
#> 052: 0.904147    1.102263    3.474563    1.132420    0.016261    0.018260    0.601526    
#> 053: 0.932073    1.092083    3.468765    1.271970    0.015448    0.019471    0.598839    
#> 054: 0.831329    1.089932    3.482621    1.208371    0.014676    0.018498    0.605390    
#> 055: 0.817985    1.093718    3.470044    1.147953    0.013942    0.017573    0.606641    
#> 056: 0.860871    1.085785    3.476123    1.093999    0.013245    0.018664    0.622670    
#> 057: 0.883796    1.077226    3.483745    1.208053    0.012583    0.017854    0.626337    
#> 058: 0.914207    1.090874    3.469692    1.157548    0.012662    0.018418    0.622366    
#> 059: 0.918354    1.071018    3.471774    1.215534    0.015539    0.021577    0.611665    
#> 060: 0.883788    1.056379    3.492126    1.154757    0.016651    0.023259    0.619738    
#> 061: 0.933017    1.063452    3.500590    1.152469    0.015818    0.022096    0.608453    
#> 062: 0.863064    1.067138    3.505449    1.094845    0.020585    0.020991    0.617028    
#> 063: 0.941403    1.046792    3.509520    1.067391    0.021029    0.019942    0.608931    
#> 064: 0.848135    1.060089    3.497048    1.014022    0.019977    0.018945    0.609680    
#> 065: 0.930574    1.051145    3.485112    1.095477    0.018979    0.017997    0.607264    
#> 066: 0.906944    1.062875    3.494741    1.040703    0.018486    0.017098    0.609483    
#> 067: 0.885606    1.061569    3.503693    0.988668    0.017562    0.017223    0.605867    
#> 068: 0.835281    1.068573    3.497015    0.939235    0.016684    0.017607    0.613964    
#> 069: 0.871957    1.085543    3.475812    0.903431    0.015850    0.016727    0.632072    
#> 070: 0.880171    1.091233    3.487868    0.989767    0.015057    0.015890    0.618073    
#> 071: 0.886469    1.119681    3.467930    1.160723    0.016812    0.015096    0.619860    
#> 072: 0.902618    1.107374    3.472302    1.225024    0.015972    0.014385    0.614467    
#> 073: 0.917243    1.110131    3.481314    1.303752    0.015173    0.013666    0.610549    
#> 074: 0.860492    1.107145    3.471170    1.238564    0.015991    0.013418    0.615013    
#> 075: 0.868269    1.096125    3.483765    1.176636    0.018206    0.015555    0.623423    
#> 076: 0.854779    1.106956    3.478624    1.117804    0.017295    0.014777    0.609049    
#> 077: 0.906822    1.093378    3.481849    1.061914    0.016764    0.015255    0.587800    
#> 078: 0.875632    1.089431    3.481005    1.036823    0.015926    0.017402    0.590495    
#> 079: 0.913204    1.094226    3.475437    1.051741    0.015129    0.016876    0.608916    
#> 080: 0.905428    1.102582    3.480875    1.127640    0.015314    0.016032    0.610440    
#> 081: 0.860257    1.083649    3.474024    1.071258    0.014548    0.015593    0.603087    
#> 082: 0.841811    1.075550    3.485944    1.025489    0.013821    0.019397    0.603800    
#> 083: 0.867858    1.090991    3.488445    1.132926    0.016786    0.019763    0.608214    
#> 084: 0.869772    1.083235    3.481020    1.076280    0.019329    0.018774    0.596803    
#> 085: 0.832388    1.088288    3.497552    1.022466    0.018362    0.017926    0.591934    
#> 086: 0.876467    1.076913    3.490502    0.982569    0.020452    0.018482    0.593847    
#> 087: 0.933104    1.081926    3.482666    1.199770    0.019795    0.017557    0.576082    
#> 088: 0.903660    1.062319    3.494524    1.139781    0.018805    0.017307    0.582963    
#> 089: 0.894549    1.069114    3.491311    1.082792    0.018063    0.016442    0.580918    
#> 090: 0.926262    1.066769    3.491645    1.028653    0.017160    0.016544    0.585149    
#> 091: 0.863178    1.049145    3.483809    0.977220    0.016387    0.017602    0.594898    
#> 092: 0.816765    1.075209    3.473063    0.928359    0.015646    0.016722    0.595599    
#> 093: 0.812864    1.065124    3.478700    0.881941    0.014864    0.015886    0.620078    
#> 094: 0.848806    1.075468    3.468671    0.878504    0.014121    0.015511    0.618084    
#> 095: 0.877428    1.075052    3.485807    0.982401    0.014494    0.014736    0.613240    
#> 096: 0.839781    1.072277    3.482228    1.027523    0.014400    0.014522    0.604250    
#> 097: 0.859568    1.083145    3.478265    0.976147    0.015646    0.015346    0.602973    
#> 098: 0.885884    1.087859    3.478807    1.110127    0.014863    0.014578    0.601237    
#> 099: 0.919735    1.071169    3.480141    1.081766    0.014120    0.016047    0.584377    
#> 100: 0.936797    1.071960    3.492832    1.210641    0.013414    0.017325    0.586593    
#> 101: 0.848802    1.053674    3.483423    1.150109    0.012843    0.016459    0.588214    
#> 102: 0.820892    1.047704    3.480474    1.092603    0.014231    0.015636    0.580195    
#> 103: 0.885634    1.063010    3.490652    1.037973    0.013519    0.017746    0.586222    
#> 104: 0.838607    1.068050    3.503354    0.986074    0.013315    0.016859    0.624441    
#> 105: 0.882938    1.070158    3.493042    0.936771    0.012746    0.016187    0.617596    
#> 106: 0.898252    1.083854    3.492910    1.030572    0.012109    0.020089    0.592598    
#> 107: 0.959688    1.087535    3.498463    1.086514    0.011503    0.019085    0.605416    
#> 108: 0.891317    1.081364    3.488076    1.032188    0.011593    0.018131    0.615718    
#> 109: 0.854383    1.090818    3.492140    0.980579    0.012930    0.017224    0.616316    
#> 110: 0.836851    1.098945    3.475987    0.931550    0.012283    0.018154    0.613848    
#> 111: 0.862252    1.105490    3.481573    0.884972    0.011669    0.017246    0.595557    
#> 112: 0.837879    1.083743    3.469132    0.900095    0.011401    0.016384    0.603902    
#> 113: 0.843829    1.085826    3.487408    0.915854    0.012521    0.016863    0.589462    
#> 114: 0.858493    1.093736    3.490959    0.870061    0.014468    0.016019    0.587005    
#> 115: 0.870243    1.073674    3.480156    0.939689    0.013744    0.015218    0.621329    
#> 116: 0.938443    1.080829    3.488881    1.083937    0.013804    0.015200    0.616731    
#> 117: 0.908424    1.080720    3.495045    1.043457    0.013114    0.014440    0.611988    
#> 118: 0.933202    1.079555    3.495014    1.121929    0.013045    0.014574    0.599392    
#> 119: 0.951425    1.073547    3.488810    1.236184    0.014361    0.016043    0.604182    
#> 120: 0.917849    1.067266    3.496302    1.174375    0.015031    0.015571    0.594176    
#> 121: 0.930034    1.083236    3.495338    1.115656    0.015317    0.014793    0.596633    
#> 122: 0.879263    1.072133    3.496040    1.059873    0.017864    0.014536    0.599032    
#> 123: 0.943227    1.094530    3.487955    1.040757    0.021101    0.015012    0.587305    
#> 124: 0.898285    1.105658    3.481387    1.034506    0.020943    0.014261    0.598838    
#> 125: 0.878233    1.104725    3.482305    1.016551    0.019896    0.013966    0.588654    
#> 126: 0.845341    1.106665    3.469087    1.039878    0.020142    0.014978    0.593022    
#> 127: 0.845163    1.089034    3.480294    0.987884    0.019225    0.016957    0.599581    
#> 128: 0.829118    1.095540    3.474592    0.979491    0.021969    0.016533    0.591973    
#> 129: 0.902908    1.091952    3.488107    1.071158    0.021040    0.015706    0.596115    
#> 130: 0.889777    1.097122    3.481590    1.017600    0.020547    0.014921    0.585485    
#> 131: 0.885422    1.088680    3.467793    1.085408    0.023932    0.014175    0.583274    
#> 132: 0.807116    1.090550    3.465362    1.031137    0.022735    0.013466    0.596935    
#> 133: 0.784592    1.075379    3.474823    0.979580    0.021598    0.012793    0.606720    
#> 134: 0.823925    1.068239    3.486805    0.930601    0.020519    0.013990    0.597682    
#> 135: 0.811037    1.063237    3.488163    0.884071    0.019493    0.014311    0.610552    
#> 136: 0.871095    1.059297    3.490233    0.861318    0.018518    0.015648    0.597943    
#> 137: 0.883045    1.067222    3.493534    0.926029    0.019180    0.014865    0.607043    
#> 138: 0.898254    1.073981    3.493816    0.956781    0.022168    0.014122    0.593791    
#> 139: 0.884921    1.095169    3.490976    1.155087    0.021060    0.015593    0.602944    
#> 140: 0.900683    1.095026    3.493178    1.145122    0.020007    0.016414    0.623706    
#> 141: 0.881658    1.085003    3.490643    1.087866    0.019007    0.015593    0.603344    
#> 142: 0.940847    1.063340    3.502442    1.124876    0.018056    0.017540    0.597098    
#> 143: 0.884674    1.062803    3.504674    1.068633    0.017153    0.022559    0.599843    
#> 144: 0.915725    1.073641    3.504294    1.015201    0.016296    0.021431    0.598373    
#> 145: 0.901318    1.064252    3.484059    1.011329    0.015481    0.020359    0.620788    
#> 146: 0.888240    1.081726    3.488672    1.023043    0.014707    0.019341    0.635123    
#> 147: 0.852214    1.073419    3.479680    0.971891    0.013972    0.018374    0.610522    
#> 148: 0.838912    1.085901    3.495047    0.923296    0.013936    0.017456    0.599264    
#> 149: 0.839187    1.072032    3.488149    0.924340    0.014560    0.016583    0.609193    
#> 150: 0.870872    1.072136    3.476569    1.114467    0.016231    0.015754    0.605397    
#> 151: 0.890355    1.098842    3.483291    1.306112    0.015857    0.014966    0.600917    
#> 152: 0.902741    1.093331    3.483674    1.300065    0.014734    0.017072    0.602177    
#> 153: 0.902292    1.105008    3.488328    1.320603    0.014037    0.019727    0.618748    
#> 154: 0.920276    1.101343    3.486953    1.131950    0.012278    0.015197    0.618065    
#> 155: 0.883596    1.085821    3.478295    1.100335    0.013184    0.019118    0.623300    
#> 156: 0.880739    1.086988    3.488008    0.921548    0.013028    0.021567    0.608275    
#> 157: 0.840803    1.074300    3.485721    0.808828    0.011702    0.018876    0.603681    
#> 158: 0.854651    1.084413    3.489806    0.804519    0.011674    0.018900    0.604801    
#> 159: 0.831559    1.086933    3.508892    0.733551    0.011578    0.020528    0.617300    
#> 160: 0.916155    1.058682    3.524710    0.779487    0.011596    0.020467    0.629222    
#> 161: 0.854700    1.054431    3.512152    0.722721    0.012216    0.022129    0.621754    
#> 162: 0.854540    1.067449    3.506842    0.735572    0.012756    0.023250    0.619609    
#> 163: 0.847304    1.057546    3.498632    0.774255    0.011144    0.021282    0.614946    
#> 164: 0.866922    1.067890    3.496460    0.888240    0.009901    0.020183    0.610043    
#> 165: 0.881928    1.071288    3.489876    0.936052    0.009380    0.023278    0.619374    
#> 166: 0.920979    1.082620    3.481915    1.009284    0.005891    0.027295    0.639664    
#> 167: 0.917736    1.088052    3.496562    1.014187    0.004822    0.030126    0.627100    
#> 168: 0.901454    1.093421    3.495469    1.126395    0.004416    0.024946    0.613842    
#> 169: 0.912958    1.098244    3.483305    1.106097    0.004806    0.020604    0.616281    
#> 170: 0.859070    1.094019    3.485496    0.931528    0.004727    0.021199    0.604016    
#> 171: 0.863866    1.091432    3.486655    0.969098    0.003418    0.023340    0.606862    
#> 172: 0.829378    1.094155    3.486735    1.007841    0.003401    0.022584    0.619924    
#> 173: 0.853644    1.106814    3.475851    0.904608    0.003332    0.024895    0.618137    
#> 174: 0.849719    1.113699    3.492446    0.878564    0.003086    0.022308    0.636658    
#> 175: 0.872791    1.111409    3.471765    1.116908    0.003287    0.028258    0.627949    
#> 176: 0.831244    1.104285    3.475562    0.924010    0.002795    0.021321    0.628936    
#> 177: 0.881729    1.101456    3.489051    0.986321    0.002877    0.024171    0.617812    
#> 178: 0.866484    1.096070    3.483661    0.841880    0.003850    0.024239    0.618853    
#> 179: 0.877562    1.096371    3.479771    0.980857    0.004761    0.022316    0.625464    
#> 180: 0.866114    1.090578    3.479595    0.994120    0.004958    0.019658    0.620542    
#> 181: 0.920324    1.079812    3.476067    1.024035    0.004947    0.023942    0.608181    
#> 182: 0.883013    1.076509    3.471905    1.043778    0.005119    0.022709    0.624183    
#> 183: 0.826245    1.088221    3.467958    0.743487    0.005785    0.026492    0.630549    
#> 184: 0.813337    1.087680    3.470027    0.809135    0.005436    0.026532    0.634495    
#> 185: 0.813349    1.096881    3.476484    0.847244    0.006562    0.023159    0.619269    
#> 186: 0.822827    1.105364    3.476670    0.881367    0.007592    0.024347    0.635391    
#> 187: 0.863852    1.091336    3.487265    0.974358    0.008780    0.024436    0.630754    
#> 188: 0.847445    1.112362    3.472411    1.024710    0.010731    0.020309    0.633945    
#> 189: 0.848746    1.122518    3.479825    1.048409    0.012195    0.020201    0.623065    
#> 190: 0.814452    1.111252    3.477278    0.889672    0.009651    0.018163    0.594122    
#> 191: 0.810628    1.107588    3.468622    0.985103    0.010206    0.020876    0.593513    
#> 192: 0.837212    1.105033    3.471035    0.913289    0.010109    0.023263    0.600996    
#> 193: 0.883484    1.105106    3.483764    1.032236    0.010482    0.019229    0.593069    
#> 194: 0.815748    1.093296    3.482192    0.797538    0.008280    0.014199    0.614699    
#> 195: 0.765489    1.089519    3.471546    0.814081    0.010428    0.015834    0.597916    
#> 196: 0.845437    1.090295    3.483106    0.915596    0.013832    0.015563    0.603922    
#> 197: 0.814831    1.099895    3.497365    0.847399    0.013997    0.020043    0.616528    
#> 198: 0.900743    1.085678    3.488952    1.052086    0.009134    0.020510    0.612726    
#> 199: 0.815643    1.068021    3.488835    0.796661    0.010542    0.019667    0.611780    
#> 200: 0.855261    1.079756    3.487050    0.909519    0.008899    0.023821    0.601719    
#> 201: 0.869237    1.074367    3.488371    0.959408    0.008828    0.025486    0.598751    
#> 202: 0.877041    1.070231    3.490837    0.966395    0.009206    0.026651    0.603545    
#> 203: 0.900713    1.069650    3.491655    1.017870    0.009502    0.026471    0.603248    
#> 204: 0.894408    1.067239    3.491584    1.007662    0.009507    0.026007    0.605281    
#> 205: 0.890567    1.070738    3.489529    0.995776    0.009674    0.025699    0.605829    
#> 206: 0.891727    1.073713    3.489389    1.007204    0.009659    0.025608    0.605491    
#> 207: 0.883608    1.074342    3.488189    0.981372    0.009494    0.025545    0.605234    
#> 208: 0.879464    1.074876    3.488658    0.958270    0.009390    0.024929    0.606125    
#> 209: 0.882995    1.074469    3.489378    0.960016    0.009524    0.024675    0.606268    
#> 210: 0.884579    1.073990    3.490015    0.964624    0.009492    0.024204    0.605127    
#> 211: 0.886425    1.073662    3.490132    0.967010    0.009628    0.023789    0.604603    
#> 212: 0.886677    1.074257    3.490228    0.968750    0.009670    0.023779    0.603718    
#> 213: 0.883758    1.073262    3.490692    0.957550    0.009773    0.023617    0.604305    
#> 214: 0.882995    1.072421    3.491217    0.947759    0.009766    0.023199    0.604435    
#> 215: 0.881125    1.072051    3.492131    0.936859    0.009645    0.023128    0.605116    
#> 216: 0.884484    1.071051    3.492967    0.941242    0.009542    0.023098    0.605510    
#> 217: 0.885731    1.071000    3.493391    0.946180    0.009466    0.022865    0.605273    
#> 218: 0.886905    1.071271    3.493361    0.946546    0.009283    0.022859    0.605493    
#> 219: 0.888202    1.071276    3.492950    0.954168    0.009162    0.022957    0.605636    
#> 220: 0.885631    1.071484    3.492212    0.957225    0.009143    0.023062    0.605565    
#> 221: 0.882226    1.072005    3.492078    0.954907    0.009149    0.023056    0.605323    
#> 222: 0.880243    1.071773    3.491136    0.954056    0.009077    0.023175    0.605271    
#> 223: 0.880820    1.071919    3.490581    0.956932    0.009113    0.023402    0.605937    
#> 224: 0.881313    1.072144    3.490620    0.954357    0.009070    0.023555    0.606019    
#> 225: 0.882030    1.071339    3.490956    0.954823    0.009061    0.023523    0.605963    
#> 226: 0.883154    1.070477    3.490527    0.958226    0.009110    0.023493    0.606000    
#> 227: 0.882849    1.070062    3.490400    0.958204    0.009124    0.023540    0.605685    
#> 228: 0.881379    1.070602    3.489987    0.955170    0.009156    0.023523    0.605528    
#> 229: 0.878986    1.070881    3.489336    0.950821    0.009088    0.023556    0.605409    
#> 230: 0.879149    1.070975    3.489203    0.948595    0.009049    0.023577    0.605631    
#> 231: 0.880475    1.070880    3.489693    0.949056    0.009013    0.023660    0.605394    
#> 232: 0.879866    1.070676    3.489923    0.946148    0.008991    0.023652    0.605333    
#> 233: 0.879233    1.070149    3.490168    0.943155    0.008952    0.023626    0.605390    
#> 234: 0.879247    1.069949    3.490115    0.940768    0.008882    0.023657    0.605596    
#> 235: 0.880416    1.069502    3.490197    0.943296    0.008840    0.023801    0.605395    
#> 236: 0.882195    1.069470    3.490009    0.948851    0.008771    0.023808    0.604996    
#> 237: 0.883608    1.069366    3.490105    0.951446    0.008703    0.023828    0.604973    
#> 238: 0.885459    1.069463    3.490179    0.955795    0.008642    0.023741    0.605243    
#> 239: 0.885639    1.069609    3.489889    0.958870    0.008676    0.023653    0.605286    
#> 240: 0.888413    1.069717    3.490074    0.969515    0.008725    0.023548    0.605440    
#> 241: 0.891436    1.069371    3.490273    0.978396    0.008811    0.023358    0.605447    
#> 242: 0.892109    1.069206    3.490380    0.980377    0.008884    0.023155    0.605829    
#> 243: 0.892316    1.069148    3.490552    0.980051    0.008984    0.022993    0.606290    
#> 244: 0.891446    1.068894    3.490738    0.976622    0.009027    0.022782    0.606753    
#> 245: 0.890752    1.068866    3.490772    0.974388    0.009145    0.022587    0.606557    
#> 246: 0.889536    1.068816    3.490632    0.970453    0.009300    0.022396    0.606503    
#> 247: 0.889171    1.068798    3.490601    0.971162    0.009431    0.022247    0.606193    
#> 248: 0.889404    1.068753    3.490565    0.971986    0.009512    0.022101    0.605974    
#> 249: 0.888444    1.068740    3.490327    0.973576    0.009619    0.021943    0.605994    
#> 250: 0.889178    1.068918    3.490403    0.976792    0.009670    0.021872    0.606169    
#> 251: 0.887963    1.069116    3.490253    0.973922    0.009748    0.021785    0.605902    
#> 252: 0.888211    1.069438    3.490326    0.974123    0.009817    0.021683    0.605844    
#> 253: 0.887514    1.069826    3.490350    0.971629    0.009902    0.021573    0.605875    
#> 254: 0.886903    1.070646    3.490269    0.969967    0.009965    0.021505    0.606018    
#> 255: 0.885898    1.071139    3.490077    0.967757    0.010002    0.021443    0.606018    
#> 256: 0.885058    1.071419    3.489919    0.966425    0.010077    0.021347    0.606080    
#> 257: 0.884127    1.071368    3.489841    0.965841    0.010121    0.021237    0.605919    
#> 258: 0.883872    1.071114    3.489783    0.965780    0.010207    0.021182    0.605747    
#> 259: 0.883773    1.070989    3.489741    0.967118    0.010263    0.021115    0.605602    
#> 260: 0.883540    1.071126    3.489832    0.965901    0.010327    0.021101    0.605534    
#> 261: 0.883483    1.071087    3.489860    0.967746    0.010383    0.021078    0.605650    
#> 262: 0.885734    1.071122    3.489641    0.977585    0.010422    0.021050    0.605512    
#> 263: 0.886440    1.071293    3.489406    0.984326    0.010415    0.021048    0.605658    
#> 264: 0.887105    1.071426    3.489260    0.989173    0.010496    0.021031    0.605589    
#> 265: 0.886925    1.071452    3.489245    0.988955    0.010581    0.020991    0.605559    
#> 266: 0.888088    1.071467    3.489319    0.990719    0.010653    0.020963    0.605443    
#> 267: 0.888772    1.071437    3.489543    0.992494    0.010668    0.020943    0.605612    
#> 268: 0.889095    1.071433    3.489454    0.994517    0.010688    0.020899    0.605538    
#> 269: 0.890015    1.071361    3.489427    0.997501    0.010687    0.020886    0.605310    
#> 270: 0.890478    1.071317    3.489227    1.000283    0.010695    0.020845    0.605096    
#> 271: 0.889759    1.071158    3.489134    1.000408    0.010723    0.020830    0.605021    
#> 272: 0.889512    1.071091    3.489064    0.999014    0.010740    0.020845    0.605190    
#> 273: 0.888559    1.071274    3.489040    0.996477    0.010763    0.020849    0.605232    
#> 274: 0.887936    1.071310    3.489123    0.993964    0.010773    0.020829    0.605089    
#> 275: 0.887822    1.071285    3.489106    0.992382    0.010791    0.020788    0.604923    
#> 276: 0.888002    1.071333    3.489260    0.990907    0.010797    0.020746    0.604997    
#> 277: 0.888318    1.071339    3.489455    0.991069    0.010828    0.020691    0.604982    
#> 278: 0.888856    1.071460    3.489669    0.992606    0.010891    0.020652    0.604962    
#> 279: 0.889088    1.071442    3.489690    0.995718    0.010925    0.020565    0.605054    
#> 280: 0.889014    1.071578    3.489691    0.996965    0.010989    0.020516    0.604953    
#> 281: 0.888564    1.071727    3.489655    0.995265    0.011105    0.020506    0.604854    
#> 282: 0.888809    1.071989    3.489686    0.996198    0.011179    0.020449    0.604871    
#> 283: 0.888546    1.072309    3.489675    0.994936    0.011270    0.020380    0.604942    
#> 284: 0.887898    1.072438    3.489505    0.993047    0.011327    0.020299    0.604825    
#> 285: 0.887279    1.072566    3.489279    0.992534    0.011379    0.020278    0.604859    
#> 286: 0.887455    1.072746    3.489090    0.992792    0.011468    0.020214    0.604925    
#> 287: 0.887176    1.072912    3.488982    0.992498    0.011544    0.020178    0.605104    
#> 288: 0.887355    1.072920    3.488908    0.993292    0.011607    0.020169    0.605319    
#> 289: 0.887597    1.072908    3.488833    0.995002    0.011659    0.020160    0.605292    
#> 290: 0.887962    1.072868    3.488801    0.996685    0.011681    0.020118    0.605406    
#> 291: 0.888763    1.072968    3.488836    0.998404    0.011684    0.020108    0.605229    
#> 292: 0.888277    1.073109    3.488717    0.997623    0.011686    0.020104    0.605200    
#> 293: 0.888446    1.073208    3.488527    0.997599    0.011677    0.020091    0.605422    
#> 294: 0.887603    1.073443    3.488330    0.997591    0.011697    0.020096    0.605550    
#> 295: 0.887829    1.073388    3.488265    0.998762    0.011706    0.020126    0.605474    
#> 296: 0.888105    1.073317    3.488180    0.999297    0.011714    0.020162    0.605452    
#> 297: 0.888055    1.073296    3.488131    0.999247    0.011705    0.020191    0.605510    
#> 298: 0.887634    1.073209    3.488071    0.997851    0.011699    0.020213    0.605417    
#> 299: 0.887610    1.073258    3.487974    0.998410    0.011679    0.020182    0.605344    
#> 300: 0.887079    1.073294    3.487983    0.997288    0.011673    0.020154    0.605300    
#> 301: 0.887047    1.073311    3.487999    0.996532    0.011663    0.020132    0.605260    
#> 302: 0.887288    1.073408    3.487947    0.996538    0.011661    0.020125    0.605183    
#> 303: 0.887136    1.073603    3.487854    0.996525    0.011647    0.020112    0.605180    
#> 304: 0.887084    1.073784    3.487628    0.997079    0.011650    0.020087    0.605261    
#> 305: 0.886658    1.073734    3.487462    0.996427    0.011652    0.020074    0.605302    
#> 306: 0.885755    1.073674    3.487388    0.994820    0.011641    0.020072    0.605287    
#> 307: 0.885303    1.073551    3.487271    0.994236    0.011635    0.020074    0.605254    
#> 308: 0.884542    1.073471    3.487203    0.992587    0.011633    0.020104    0.605275    
#> 309: 0.884506    1.073293    3.487240    0.992990    0.011652    0.020118    0.605262    
#> 310: 0.884674    1.073258    3.487164    0.993240    0.011674    0.020107    0.605274    
#> 311: 0.884220    1.073275    3.487119    0.993180    0.011689    0.020098    0.605205    
#> 312: 0.884083    1.073208    3.487057    0.993157    0.011713    0.020056    0.605146    
#> 313: 0.883632    1.073036    3.486983    0.992557    0.011727    0.019995    0.605201    
#> 314: 0.883270    1.072930    3.486931    0.992177    0.011739    0.019951    0.605236    
#> 315: 0.883059    1.072868    3.486896    0.991642    0.011744    0.019923    0.605247    
#> 316: 0.882787    1.072874    3.486874    0.990838    0.011748    0.019922    0.605349    
#> 317: 0.882983    1.072936    3.486869    0.990399    0.011751    0.019943    0.605567    
#> 318: 0.883299    1.072997    3.486884    0.990752    0.011733    0.019950    0.605652    
#> 319: 0.883509    1.073052    3.486941    0.990935    0.011713    0.019982    0.605766    
#> 320: 0.883181    1.073006    3.486838    0.991213    0.011699    0.019978    0.605907    
#> 321: 0.882542    1.073059    3.486693    0.991051    0.011683    0.019980    0.606135    
#> 322: 0.882000    1.073056    3.486487    0.991315    0.011671    0.019998    0.606297    
#> 323: 0.881447    1.073078    3.486366    0.991520    0.011689    0.020016    0.606305    
#> 324: 0.881276    1.073179    3.486367    0.991447    0.011682    0.020006    0.606351    
#> 325: 0.881012    1.073275    3.486298    0.991629    0.011678    0.019996    0.606296    
#> 326: 0.881234    1.073150    3.486239    0.992614    0.011658    0.019992    0.606300    
#> 327: 0.881208    1.073137    3.486278    0.992956    0.011639    0.019992    0.606283    
#> 328: 0.880848    1.073150    3.486289    0.992071    0.011638    0.019964    0.606319    
#> 329: 0.880856    1.073224    3.486262    0.990882    0.011617    0.019932    0.606329    
#> 330: 0.880327    1.073264    3.486271    0.989153    0.011613    0.019905    0.606305    
#> 331: 0.879852    1.073447    3.486218    0.988030    0.011650    0.019869    0.606239    
#> 332: 0.879572    1.073464    3.486317    0.986762    0.011669    0.019875    0.606384    
#> 333: 0.879572    1.073504    3.486249    0.987038    0.011667    0.019864    0.606459    
#> 334: 0.879501    1.073527    3.486247    0.986411    0.011672    0.019834    0.606597    
#> 335: 0.879040    1.073580    3.486188    0.985725    0.011689    0.019812    0.606646    
#> 336: 0.878752    1.073724    3.486094    0.985804    0.011696    0.019815    0.606844    
#> 337: 0.878673    1.073971    3.485932    0.986341    0.011695    0.019800    0.606915    
#> 338: 0.878604    1.074219    3.485856    0.986953    0.011720    0.019768    0.606924    
#> 339: 0.878192    1.074331    3.485842    0.985621    0.011752    0.019742    0.606921    
#> 340: 0.878062    1.074268    3.485845    0.985304    0.011780    0.019724    0.606881    
#> 341: 0.878150    1.074230    3.485908    0.984873    0.011809    0.019702    0.606857    
#> 342: 0.877827    1.074133    3.485895    0.983933    0.011833    0.019679    0.606760    
#> 343: 0.877338    1.074126    3.485910    0.982690    0.011853    0.019648    0.606663    
#> 344: 0.877564    1.074091    3.485986    0.982958    0.011859    0.019613    0.606628    
#> 345: 0.877430    1.074133    3.485940    0.982875    0.011867    0.019584    0.606539    
#> 346: 0.877113    1.074253    3.485815    0.981966    0.011874    0.019559    0.606440    
#> 347: 0.876805    1.074242    3.485689    0.982146    0.011902    0.019524    0.606357    
#> 348: 0.876538    1.074332    3.485634    0.982093    0.011949    0.019507    0.606346    
#> 349: 0.876577    1.074384    3.485632    0.982847    0.011971    0.019500    0.606299    
#> 350: 0.876471    1.074407    3.485614    0.982619    0.011977    0.019491    0.606211    
#> 351: 0.876355    1.074553    3.485594    0.982727    0.011968    0.019473    0.606185    
#> 352: 0.876080    1.074583    3.485612    0.981913    0.011958    0.019459    0.606276    
#> 353: 0.876088    1.074655    3.485642    0.980964    0.011969    0.019447    0.606312    
#> 354: 0.876217    1.074721    3.485586    0.980993    0.011973    0.019433    0.606330    
#> 355: 0.876525    1.074653    3.485562    0.981084    0.011972    0.019424    0.606318    
#> 356: 0.876560    1.074632    3.485571    0.981346    0.011967    0.019422    0.606369    
#> 357: 0.877096    1.074668    3.485630    0.982312    0.011966    0.019420    0.606258    
#> 358: 0.876888    1.074723    3.485652    0.981549    0.011968    0.019402    0.606221    
#> 359: 0.876640    1.074772    3.485655    0.979997    0.011960    0.019379    0.606205    
#> 360: 0.876510    1.074752    3.485643    0.978712    0.011954    0.019348    0.606236    
#> 361: 0.876158    1.074836    3.485642    0.977078    0.011945    0.019316    0.606206    
#> 362: 0.876306    1.074863    3.485692    0.976374    0.011951    0.019288    0.606074    
#> 363: 0.876227    1.074810    3.485757    0.975351    0.011941    0.019249    0.605984    
#> 364: 0.876399    1.074735    3.485837    0.974932    0.011949    0.019227    0.605842    
#> 365: 0.876391    1.074613    3.485875    0.974792    0.011955    0.019217    0.605922    
#> 366: 0.876192    1.074593    3.485774    0.974122    0.011956    0.019199    0.606074    
#> 367: 0.875899    1.074625    3.485668    0.973469    0.011940    0.019191    0.606076    
#> 368: 0.875814    1.074698    3.485573    0.973984    0.011930    0.019184    0.605974    
#> 369: 0.875413    1.074728    3.485503    0.974285    0.011926    0.019177    0.605906    
#> 370: 0.875150    1.074882    3.485363    0.975155    0.011933    0.019178    0.605887    
#> 371: 0.874556    1.075040    3.485168    0.974892    0.011947    0.019170    0.605829    
#> 372: 0.874128    1.075167    3.485043    0.974703    0.011968    0.019166    0.605827    
#> 373: 0.873380    1.075355    3.484879    0.973988    0.011982    0.019166    0.605825    
#> 374: 0.873263    1.075404    3.484705    0.974654    0.011966    0.019164    0.605788    
#> 375: 0.872648    1.075457    3.484623    0.973559    0.011958    0.019158    0.605860    
#> 376: 0.872711    1.075494    3.484587    0.974482    0.011955    0.019155    0.605814    
#> 377: 0.872613    1.075521    3.484563    0.974412    0.011945    0.019148    0.605834    
#> 378: 0.872423    1.075495    3.484522    0.973293    0.011939    0.019136    0.605826    
#> 379: 0.872105    1.075442    3.484517    0.972722    0.011946    0.019132    0.605778    
#> 380: 0.871881    1.075443    3.484503    0.972432    0.011950    0.019117    0.605746    
#> 381: 0.871798    1.075439    3.484481    0.972716    0.011954    0.019107    0.605717    
#> 382: 0.871570    1.075444    3.484508    0.971936    0.011952    0.019095    0.605720    
#> 383: 0.871164    1.075468    3.484486    0.970983    0.011965    0.019085    0.605757    
#> 384: 0.871107    1.075467    3.484485    0.971104    0.011951    0.019093    0.605833    
#> 385: 0.871191    1.075484    3.484497    0.970908    0.011957    0.019080    0.605861    
#> 386: 0.871221    1.075544    3.484550    0.970680    0.011970    0.019075    0.605854    
#> 387: 0.871173    1.075632    3.484570    0.970521    0.011978    0.019061    0.605786    
#> 388: 0.871197    1.075683    3.484584    0.971003    0.011990    0.019046    0.605721    
#> 389: 0.871176    1.075578    3.484543    0.971272    0.012001    0.019034    0.605813    
#> 390: 0.870939    1.075579    3.484513    0.970760    0.012018    0.019017    0.605832    
#> 391: 0.870799    1.075511    3.484449    0.970634    0.012030    0.018988    0.605783    
#> 392: 0.870677    1.075540    3.484420    0.970203    0.012043    0.018977    0.605749    
#> 393: 0.870685    1.075530    3.484420    0.970315    0.012055    0.018970    0.605713    
#> 394: 0.870918    1.075571    3.484433    0.971173    0.012049    0.018971    0.605639    
#> 395: 0.871492    1.075683    3.484454    0.972853    0.012044    0.018976    0.605614    
#> 396: 0.871580    1.075801    3.484456    0.973262    0.012047    0.018962    0.605570    
#> 397: 0.871835    1.075806    3.484475    0.975539    0.012050    0.018956    0.605612    
#> 398: 0.872454    1.075785    3.484526    0.978326    0.012054    0.018956    0.605583    
#> 399: 0.873088    1.075822    3.484602    0.980716    0.012074    0.018955    0.605548    
#> 400: 0.873848    1.075930    3.484638    0.983029    0.012099    0.018943    0.605566    
#> 401: 0.873830    1.076083    3.484592    0.983080    0.012113    0.018928    0.605604    
#> 402: 0.873990    1.076173    3.484567    0.983378    0.012132    0.018912    0.605541    
#> 403: 0.874412    1.076209    3.484516    0.984225    0.012156    0.018890    0.605581    
#> 404: 0.874624    1.076337    3.484426    0.984903    0.012168    0.018868    0.605547    
#> 405: 0.874363    1.076363    3.484411    0.985216    0.012166    0.018858    0.605500    
#> 406: 0.874259    1.076362    3.484355    0.985339    0.012163    0.018843    0.605543    
#> 407: 0.874096    1.076420    3.484379    0.985217    0.012160    0.018839    0.605576    
#> 408: 0.874239    1.076553    3.484374    0.985316    0.012159    0.018825    0.605632    
#> 409: 0.874251    1.076640    3.484370    0.985416    0.012146    0.018817    0.605611    
#> 410: 0.874313    1.076682    3.484325    0.985815    0.012141    0.018799    0.605597    
#> 411: 0.874578    1.076588    3.484343    0.987097    0.012146    0.018783    0.605530    
#> 412: 0.874460    1.076603    3.484318    0.986713    0.012144    0.018768    0.605499    
#> 413: 0.874200    1.076645    3.484282    0.985763    0.012143    0.018765    0.605470    
#> 414: 0.874053    1.076604    3.484348    0.985360    0.012144    0.018751    0.605454    
#> 415: 0.874070    1.076545    3.484381    0.985258    0.012141    0.018746    0.605413    
#> 416: 0.873913    1.076550    3.484379    0.984418    0.012141    0.018745    0.605454    
#> 417: 0.873823    1.076512    3.484393    0.983683    0.012143    0.018753    0.605387    
#> 418: 0.873730    1.076516    3.484459    0.983254    0.012136    0.018753    0.605317    
#> 419: 0.873841    1.076546    3.484498    0.982687    0.012131    0.018757    0.605278    
#> 420: 0.873988    1.076536    3.484542    0.982500    0.012127    0.018769    0.605210    
#> 421: 0.873891    1.076500    3.484619    0.981682    0.012121    0.018777    0.605107    
#> 422: 0.874163    1.076417    3.484653    0.982183    0.012118    0.018772    0.605067    
#> 423: 0.874310    1.076340    3.484700    0.982303    0.012117    0.018768    0.605032    
#> 424: 0.874161    1.076319    3.484673    0.981928    0.012125    0.018761    0.605030    
#> 425: 0.874272    1.076385    3.484656    0.982337    0.012141    0.018773    0.605077    
#> 426: 0.874287    1.076455    3.484642    0.982425    0.012157    0.018770    0.605057    
#> 427: 0.873972    1.076483    3.484652    0.981782    0.012156    0.018754    0.605036    
#> 428: 0.873806    1.076522    3.484661    0.981195    0.012152    0.018747    0.604950    
#> 429: 0.873664    1.076568    3.484661    0.981035    0.012156    0.018739    0.604894    
#> 430: 0.873346    1.076637    3.484622    0.980418    0.012150    0.018722    0.604914    
#> 431: 0.873027    1.076674    3.484590    0.979748    0.012149    0.018710    0.604834    
#> 432: 0.873046    1.076721    3.484577    0.979971    0.012158    0.018704    0.604819    
#> 433: 0.873217    1.076783    3.484633    0.980551    0.012172    0.018694    0.604790    
#> 434: 0.873168    1.076769    3.484632    0.980696    0.012171    0.018692    0.604757    
#> 435: 0.873193    1.076773    3.484614    0.980623    0.012170    0.018681    0.604707    
#> 436: 0.873007    1.076780    3.484672    0.979910    0.012186    0.018674    0.604601    
#> 437: 0.873005    1.076767    3.484691    0.979397    0.012184    0.018657    0.604545    
#> 438: 0.873085    1.076874    3.484755    0.979145    0.012184    0.018658    0.604469    
#> 439: 0.873459    1.076911    3.484849    0.979463    0.012183    0.018661    0.604444    
#> 440: 0.873525    1.076929    3.484914    0.978413    0.012183    0.018657    0.604477    
#> 441: 0.873616    1.076868    3.484996    0.977587    0.012172    0.018660    0.604513    
#> 442: 0.873427    1.076822    3.485040    0.976848    0.012166    0.018662    0.604578    
#> 443: 0.873580    1.076832    3.485043    0.977194    0.012158    0.018662    0.604586    
#> 444: 0.873380    1.076892    3.485024    0.976774    0.012150    0.018662    0.604624    
#> 445: 0.873234    1.076939    3.484965    0.976988    0.012159    0.018669    0.604703    
#> 446: 0.872927    1.077009    3.484883    0.977000    0.012170    0.018673    0.604705    
#> 447: 0.872808    1.077099    3.484800    0.977246    0.012190    0.018672    0.604721    
#> 448: 0.872694    1.077193    3.484752    0.977471    0.012186    0.018674    0.604713    
#> 449: 0.872557    1.077313    3.484814    0.977118    0.012183    0.018672    0.604760    
#> 450: 0.872728    1.077392    3.484811    0.977280    0.012189    0.018664    0.604743    
#> 451: 0.872898    1.077416    3.484785    0.977813    0.012195    0.018669    0.604785    
#> 452: 0.873009    1.077448    3.484797    0.977908    0.012202    0.018657    0.604700    
#> 453: 0.872866    1.077494    3.484820    0.977175    0.012209    0.018652    0.604658    
#> 454: 0.872807    1.077536    3.484825    0.977002    0.012214    0.018641    0.604623    
#> 455: 0.872864    1.077564    3.484827    0.977297    0.012213    0.018630    0.604555    
#> 456: 0.872712    1.077580    3.484799    0.976935    0.012207    0.018621    0.604543    
#> 457: 0.872609    1.077570    3.484826    0.976673    0.012203    0.018622    0.604550    
#> 458: 0.872663    1.077617    3.484852    0.976737    0.012205    0.018627    0.604498    
#> 459: 0.872679    1.077655    3.484835    0.976691    0.012191    0.018640    0.604480    
#> 460: 0.872457    1.077668    3.484830    0.976216    0.012186    0.018642    0.604465    
#> 461: 0.872269    1.077695    3.484842    0.976124    0.012174    0.018635    0.604496    
#> 462: 0.872140    1.077740    3.484853    0.976100    0.012167    0.018628    0.604539    
#> 463: 0.872053    1.077813    3.484865    0.976001    0.012173    0.018640    0.604557    
#> 464: 0.871876    1.077902    3.484808    0.975834    0.012175    0.018629    0.604553    
#> 465: 0.871815    1.077893    3.484788    0.975812    0.012175    0.018620    0.604510    
#> 466: 0.871735    1.077911    3.484741    0.975614    0.012170    0.018621    0.604424    
#> 467: 0.871555    1.077950    3.484752    0.975331    0.012167    0.018617    0.604331    
#> 468: 0.871624    1.077938    3.484815    0.975110    0.012164    0.018610    0.604336    
#> 469: 0.871724    1.077957    3.484855    0.975177    0.012179    0.018585    0.604397    
#> 470: 0.871647    1.077969    3.484822    0.975328    0.012184    0.018582    0.604463    
#> 471: 0.871488    1.077992    3.484791    0.975368    0.012180    0.018585    0.604517    
#> 472: 0.871137    1.078042    3.484765    0.974715    0.012187    0.018570    0.604540    
#> 473: 0.870887    1.078069    3.484745    0.973834    0.012180    0.018553    0.604557    
#> 474: 0.871029    1.078073    3.484758    0.974254    0.012171    0.018546    0.604595    
#> 475: 0.871186    1.078132    3.484770    0.974459    0.012166    0.018534    0.604573    
#> 476: 0.871162    1.078133    3.484768    0.974604    0.012167    0.018525    0.604634    
#> 477: 0.871093    1.078143    3.484803    0.974335    0.012174    0.018522    0.604649    
#> 478: 0.870993    1.078093    3.484843    0.973972    0.012174    0.018515    0.604691    
#> 479: 0.870954    1.078101    3.484847    0.973850    0.012168    0.018507    0.604703    
#> 480: 0.870947    1.078118    3.484864    0.973520    0.012173    0.018501    0.604732    
#> 481: 0.870812    1.078107    3.484854    0.972768    0.012178    0.018495    0.604748    
#> 482: 0.870834    1.078092    3.484837    0.972585    0.012181    0.018489    0.604742    
#> 483: 0.870812    1.078091    3.484849    0.972530    0.012191    0.018490    0.604743    
#> 484: 0.870732    1.078050    3.484890    0.972254    0.012202    0.018489    0.604720    
#> 485: 0.870902    1.078084    3.484903    0.972814    0.012210    0.018482    0.604698    
#> 486: 0.870796    1.078135    3.484919    0.972329    0.012211    0.018479    0.604664    
#> 487: 0.870842    1.078188    3.484922    0.971988    0.012222    0.018470    0.604583    
#> 488: 0.871039    1.078195    3.484919    0.972530    0.012219    0.018463    0.604494    
#> 489: 0.871004    1.078182    3.484877    0.972206    0.012208    0.018460    0.604465    
#> 490: 0.871139    1.078238    3.484860    0.972500    0.012211    0.018453    0.604429    
#> 491: 0.871109    1.078300    3.484870    0.972330    0.012201    0.018449    0.604409    
#> 492: 0.871062    1.078343    3.484876    0.972146    0.012193    0.018448    0.604399    
#> 493: 0.870764    1.078343    3.484844    0.971758    0.012197    0.018438    0.604449    
#> 494: 0.870728    1.078373    3.484804    0.971716    0.012199    0.018434    0.604468    
#> 495: 0.870823    1.078445    3.484786    0.972505    0.012209    0.018425    0.604471    
#> 496: 0.871078    1.078525    3.484770    0.973258    0.012204    0.018430    0.604453    
#> 497: 0.871011    1.078522    3.484768    0.973297    0.012200    0.018441    0.604469    
#> 498: 0.870947    1.078536    3.484739    0.973270    0.012199    0.018439    0.604395    
#> 499: 0.870908    1.078588    3.484674    0.973441    0.012194    0.018430    0.604406    
#> 500: 0.870919    1.078597    3.484623    0.973687    0.012193    0.018426    0.604388    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.312391    0.970696    3.452184    0.392401    0.070942    0.016800    1.886388    
#> 002: 0.382740    1.007313    3.477124    0.372781    0.067395    0.015960    1.431223    
#> 003: 0.556491    0.938807    3.472317    0.354142    0.064025    0.015162    1.110841    
#> 004: 0.579697    0.943491    3.477274    0.336435    0.060824    0.014404    0.922252    
#> 005: 0.636947    0.938893    3.465503    0.371173    0.057783    0.013684    0.868962    
#> 006: 0.633603    0.953205    3.451408    0.418967    0.058696    0.013000    0.814242    
#> 007: 0.542181    0.931205    3.442881    0.398019    0.059709    0.012350    0.833358    
#> 008: 0.521195    0.931576    3.425686    0.405908    0.056724    0.016594    0.805482    
#> 009: 0.499628    0.937273    3.426812    0.402577    0.053887    0.015764    0.804993    
#> 010: 0.521708    0.922015    3.428268    0.477952    0.051193    0.019384    0.795537    
#> 011: 0.577854    0.929988    3.430973    0.532343    0.063389    0.018808    0.808242    
#> 012: 0.558651    0.926630    3.425515    0.505725    0.061514    0.017867    0.776718    
#> 013: 0.527415    0.931879    3.422933    0.518614    0.062318    0.018417    0.794493    
#> 014: 0.547345    0.939396    3.427926    0.492684    0.072578    0.017497    0.811011    
#> 015: 0.566171    0.933859    3.451985    0.468049    0.068949    0.016622    0.786569    
#> 016: 0.531779    0.948236    3.441186    0.458543    0.082305    0.018986    0.792744    
#> 017: 0.524647    0.972159    3.430056    0.435616    0.078189    0.018037    0.777987    
#> 018: 0.528760    0.964873    3.413258    0.413835    0.092847    0.017135    0.784885    
#> 019: 0.462934    0.949418    3.413134    0.393143    0.088205    0.016278    0.790738    
#> 020: 0.507432    0.967509    3.426360    0.373486    0.083795    0.015465    0.779628    
#> 021: 0.531059    0.946939    3.433334    0.374367    0.079605    0.014691    0.771715    
#> 022: 0.511489    0.922936    3.439719    0.374895    0.075625    0.015453    0.768124    
#> 023: 0.611605    0.945873    3.454465    0.409750    0.075245    0.014680    0.801871    
#> 024: 0.543420    0.995723    3.436269    0.437373    0.071483    0.014078    0.801975    
#> 025: 0.540044    0.967495    3.426440    0.427375    0.067909    0.013374    0.811743    
#> 026: 0.534613    0.999723    3.412594    0.417569    0.064514    0.013677    0.822252    
#> 027: 0.490500    0.987103    3.412465    0.453643    0.061288    0.016847    0.807782    
#> 028: 0.565231    0.958763    3.432562    0.470319    0.058224    0.016005    0.774936    
#> 029: 0.562329    0.950201    3.424082    0.448650    0.065179    0.018962    0.793833    
#> 030: 0.560727    0.953313    3.422618    0.513524    0.062017    0.018835    0.807026    
#> 031: 0.500466    0.934818    3.425948    0.487848    0.058916    0.018831    0.787388    
#> 032: 0.503390    0.953288    3.430901    0.463456    0.058971    0.017889    0.803869    
#> 033: 0.497426    0.970456    3.423792    0.447058    0.075544    0.017262    0.781083    
#> 034: 0.561271    0.980018    3.418105    0.496956    0.076204    0.016399    0.793822    
#> 035: 0.525008    0.954819    3.412102    0.472108    0.072394    0.015579    0.793760    
#> 036: 0.508703    0.964046    3.408032    0.448503    0.090106    0.014800    0.794413    
#> 037: 0.521783    0.989059    3.419024    0.426078    0.085600    0.014060    0.806263    
#> 038: 0.553870    0.961333    3.424557    0.434308    0.081320    0.013357    0.795789    
#> 039: 0.572838    0.958249    3.437351    0.459086    0.088101    0.012689    0.777586    
#> 040: 0.518177    0.966640    3.430858    0.453256    0.093417    0.012055    0.808945    
#> 041: 0.509987    0.966450    3.422107    0.430593    0.101085    0.011452    0.807697    
#> 042: 0.582968    0.953383    3.427544    0.531662    0.096031    0.011217    0.772285    
#> 043: 0.526837    0.953880    3.415154    0.542985    0.091229    0.010656    0.782402    
#> 044: 0.510788    0.970245    3.416340    0.515835    0.086668    0.010721    0.781026    
#> 045: 0.474966    0.981755    3.405386    0.490044    0.095648    0.011478    0.765700    
#> 046: 0.515335    0.951213    3.420986    0.512574    0.090865    0.012576    0.769956    
#> 047: 0.557247    0.957914    3.432300    0.486946    0.095940    0.011947    0.780815    
#> 048: 0.550679    0.954005    3.425738    0.462598    0.093553    0.011350    0.798005    
#> 049: 0.502328    0.953340    3.429122    0.439468    0.089007    0.010782    0.809876    
#> 050: 0.573601    0.926697    3.427690    0.485077    0.097484    0.010243    0.799636    
#> 051: 0.529287    0.943518    3.420425    0.460823    0.097329    0.010308    0.812650    
#> 052: 0.533363    0.966939    3.422441    0.437782    0.092463    0.009792    0.787445    
#> 053: 0.517662    0.950636    3.419037    0.415893    0.087839    0.009303    0.793264    
#> 054: 0.497085    0.967159    3.422487    0.395098    0.083447    0.008837    0.807419    
#> 055: 0.483245    0.949168    3.417794    0.377120    0.081272    0.008662    0.804222    
#> 056: 0.490308    0.939764    3.419871    0.382233    0.084657    0.011146    0.819345    
#> 057: 0.501493    0.940322    3.419141    0.363121    0.086386    0.011351    0.808629    
#> 058: 0.511716    0.947495    3.421154    0.391537    0.082067    0.011835    0.799447    
#> 059: 0.487980    0.899282    3.433761    0.408452    0.077964    0.013380    0.830041    
#> 060: 0.525500    0.937531    3.435373    0.415238    0.074066    0.015049    0.841334    
#> 061: 0.562110    0.955286    3.429529    0.454747    0.074311    0.014297    0.828346    
#> 062: 0.518482    0.960620    3.425505    0.432010    0.100992    0.013582    0.810543    
#> 063: 0.527805    0.953519    3.416866    0.478822    0.095942    0.016266    0.812202    
#> 064: 0.485621    0.987666    3.418024    0.454881    0.091145    0.016031    0.799605    
#> 065: 0.556728    0.951948    3.416449    0.432137    0.086588    0.016986    0.808747    
#> 066: 0.557756    0.969111    3.419140    0.439271    0.082258    0.016759    0.791891    
#> 067: 0.490376    0.943918    3.411725    0.417308    0.078145    0.017383    0.798400    
#> 068: 0.455738    0.972186    3.416828    0.396442    0.085394    0.016514    0.810901    
#> 069: 0.495524    0.981892    3.409838    0.460085    0.081124    0.015688    0.794415    
#> 070: 0.508442    0.969292    3.426741    0.437081    0.077068    0.015946    0.785904    
#> 071: 0.532953    0.987278    3.410228    0.465262    0.078364    0.015148    0.807246    
#> 072: 0.505686    0.951520    3.408294    0.486688    0.076191    0.014391    0.799782    
#> 073: 0.518582    0.983189    3.422830    0.515100    0.084160    0.015330    0.773954    
#> 074: 0.527277    0.969815    3.416779    0.489345    0.080578    0.016823    0.765494    
#> 075: 0.530758    0.952077    3.431773    0.469559    0.076549    0.015982    0.777909    
#> 076: 0.531848    0.967937    3.444412    0.460707    0.072722    0.017425    0.785102    
#> 077: 0.583576    0.934623    3.438056    0.471368    0.074850    0.016554    0.788555    
#> 078: 0.548070    0.930099    3.445273    0.462227    0.073744    0.016185    0.782437    
#> 079: 0.590443    0.972873    3.442943    0.597046    0.100955    0.015376    0.782125    
#> 080: 0.579998    0.967758    3.431533    0.572421    0.106518    0.014607    0.802250    
#> 081: 0.535637    0.969464    3.426079    0.557393    0.101192    0.016068    0.794538    
#> 082: 0.533126    0.964823    3.428307    0.529523    0.096132    0.015265    0.823861    
#> 083: 0.564197    0.954586    3.429780    0.503047    0.091326    0.014502    0.833967    
#> 084: 0.568716    0.944977    3.431468    0.477895    0.087517    0.013776    0.817586    
#> 085: 0.530447    0.950995    3.435450    0.454000    0.084104    0.013088    0.814912    
#> 086: 0.549449    0.970104    3.436850    0.472810    0.085406    0.012433    0.803510    
#> 087: 0.538097    0.960255    3.420588    0.449170    0.081136    0.011964    0.810250    
#> 088: 0.504989    0.963962    3.417138    0.480121    0.077079    0.012206    0.798953    
#> 089: 0.494764    0.996805    3.405350    0.456115    0.088292    0.011596    0.802488    
#> 090: 0.467170    0.963252    3.412014    0.439693    0.090335    0.011016    0.835843    
#> 091: 0.489599    0.941681    3.396330    0.450249    0.085818    0.010465    0.815168    
#> 092: 0.476680    0.986699    3.398975    0.427737    0.083394    0.012382    0.795715    
#> 093: 0.442708    0.985313    3.398467    0.406350    0.079932    0.012171    0.807213    
#> 094: 0.469841    0.980896    3.404312    0.386033    0.083875    0.013786    0.816415    
#> 095: 0.489981    0.995402    3.419235    0.366731    0.079681    0.013670    0.809882    
#> 096: 0.495512    0.980551    3.413925    0.447923    0.075697    0.013261    0.801663    
#> 097: 0.526005    0.995603    3.407751    0.425527    0.071913    0.012598    0.797263    
#> 098: 0.481882    1.008793    3.399459    0.430598    0.073864    0.012247    0.815682    
#> 099: 0.459976    0.989561    3.395016    0.409068    0.070170    0.011634    0.791939    
#> 100: 0.465201    0.981431    3.398239    0.388615    0.069062    0.011052    0.794891    
#> 101: 0.452966    0.971341    3.389358    0.379338    0.081725    0.010500    0.799542    
#> 102: 0.473963    0.971563    3.395013    0.360371    0.083667    0.009975    0.806246    
#> 103: 0.489875    0.975193    3.410558    0.342352    0.085240    0.009476    0.803711    
#> 104: 0.526342    0.961328    3.423312    0.455754    0.085370    0.009002    0.797622    
#> 105: 0.536084    0.947004    3.417142    0.440666    0.081102    0.008552    0.803668    
#> 106: 0.560116    0.950973    3.424556    0.486508    0.084986    0.008125    0.792661    
#> 107: 0.577014    0.958564    3.433169    0.501764    0.081359    0.011277    0.809733    
#> 108: 0.552174    0.930575    3.427301    0.476676    0.077291    0.013477    0.814511    
#> 109: 0.524225    0.958503    3.425943    0.470916    0.073426    0.012804    0.802299    
#> 110: 0.508124    0.970001    3.409190    0.447370    0.076790    0.012163    0.781256    
#> 111: 0.494091    0.960686    3.412639    0.425002    0.073725    0.011555    0.780751    
#> 112: 0.482816    0.946007    3.405856    0.403752    0.085862    0.011452    0.804507    
#> 113: 0.507199    0.972564    3.419578    0.395937    0.100299    0.010932    0.788512    
#> 114: 0.521664    0.960585    3.428434    0.402790    0.106231    0.011331    0.790416    
#> 115: 0.534241    0.936789    3.427310    0.459817    0.100920    0.010765    0.810020    
#> 116: 0.545774    0.953993    3.421227    0.448052    0.095874    0.014142    0.798494    
#> 117: 0.501742    0.979049    3.409677    0.425649    0.091080    0.013435    0.805661    
#> 118: 0.519933    0.962801    3.412935    0.414154    0.086526    0.013184    0.780978    
#> 119: 0.486274    0.993400    3.406469    0.418819    0.098218    0.012829    0.788946    
#> 120: 0.477376    0.957327    3.413114    0.418348    0.093307    0.012188    0.797459    
#> 121: 0.511236    0.982497    3.413967    0.397431    0.088641    0.011578    0.798899    
#> 122: 0.519126    0.963739    3.419790    0.377559    0.084209    0.010999    0.801099    
#> 123: 0.537877    0.986208    3.417408    0.367130    0.079999    0.010449    0.805619    
#> 124: 0.510298    1.014325    3.407877    0.402697    0.075999    0.012458    0.788103    
#> 125: 0.534611    0.984520    3.409176    0.406636    0.072199    0.012360    0.811665    
#> 126: 0.493479    0.993329    3.397074    0.398964    0.068589    0.011742    0.828713    
#> 127: 0.495973    0.972746    3.395703    0.486112    0.067649    0.012536    0.832583    
#> 128: 0.508445    0.960379    3.413556    0.478183    0.095531    0.011909    0.812894    
#> 129: 0.511870    0.962875    3.427337    0.454274    0.108098    0.011313    0.798177    
#> 130: 0.523557    0.977567    3.420719    0.431560    0.102693    0.010748    0.774462    
#> 131: 0.497444    0.979061    3.407261    0.409982    0.098631    0.010666    0.790628    
#> 132: 0.481764    0.970402    3.397320    0.389483    0.093700    0.010488    0.816976    
#> 133: 0.452679    0.973552    3.407440    0.370009    0.090263    0.010863    0.797967    
#> 134: 0.498029    0.961029    3.416690    0.413599    0.091738    0.010320    0.793298    
#> 135: 0.462770    0.965109    3.414862    0.392919    0.103496    0.009804    0.806848    
#> 136: 0.480347    0.952374    3.408558    0.373273    0.098321    0.009314    0.802391    
#> 137: 0.510065    0.963323    3.412253    0.407922    0.102274    0.008848    0.795844    
#> 138: 0.492225    0.980290    3.405902    0.389321    0.101795    0.008406    0.789842    
#> 139: 0.472279    0.978030    3.412255    0.369855    0.096705    0.007986    0.809565    
#> 140: 0.483410    0.993548    3.410588    0.393220    0.099625    0.009634    0.811711    
#> 141: 0.512751    0.963289    3.425213    0.373559    0.114907    0.009152    0.808805    
#> 142: 0.555894    0.951421    3.439817    0.354881    0.122827    0.008694    0.787187    
#> 143: 0.489500    0.974044    3.427106    0.372640    0.116686    0.008702    0.807324    
#> 144: 0.547731    0.980457    3.435855    0.422153    0.110852    0.008267    0.792859    
#> 145: 0.516651    0.979728    3.423743    0.401045    0.105309    0.007853    0.778857    
#> 146: 0.497164    0.976262    3.431650    0.403709    0.100044    0.008415    0.801724    
#> 147: 0.515012    0.949024    3.436177    0.384279    0.095041    0.011535    0.790597    
#> 148: 0.530481    0.944090    3.448296    0.375680    0.090289    0.012043    0.797495    
#> 149: 0.564040    0.940990    3.443864    0.392125    0.085775    0.011441    0.799233    
#> 150: 0.555443    0.932011    3.432695    0.454551    0.081486    0.010957    0.804463    
#> 151: 0.511248    0.980879    3.423237    0.431824    0.090357    0.010409    0.786569    
#> 152: 0.508345    0.973136    3.429777    0.347462    0.099240    0.007090    0.790998    
#> 153: 0.502107    0.988088    3.426828    0.381084    0.101434    0.006208    0.815007    
#> 154: 0.513626    0.983826    3.431829    0.329120    0.100293    0.007431    0.808793    
#> 155: 0.499750    0.951618    3.427865    0.341796    0.111334    0.005753    0.784621    
#> 156: 0.534819    0.950430    3.441058    0.352034    0.133718    0.005708    0.796944    
#> 157: 0.550495    0.944600    3.446989    0.319273    0.116991    0.006273    0.833484    
#> 158: 0.548878    0.969433    3.441428    0.356527    0.095135    0.005597    0.803347    
#> 159: 0.505754    0.975457    3.438737    0.334862    0.089959    0.005313    0.799553    
#> 160: 0.550118    0.926945    3.444484    0.339807    0.087877    0.005203    0.808707    
#> 161: 0.535491    0.926841    3.445197    0.299185    0.096261    0.004608    0.818523    
#> 162: 0.513541    0.953640    3.428824    0.318536    0.106356    0.004824    0.825124    
#> 163: 0.560585    0.951831    3.430616    0.329836    0.124685    0.002926    0.833703    
#> 164: 0.530057    0.962234    3.420751    0.330233    0.128267    0.003668    0.831286    
#> 165: 0.555332    0.953868    3.429869    0.343297    0.118588    0.004591    0.818513    
#> 166: 0.550928    0.996994    3.430347    0.263603    0.110122    0.004248    0.833246    
#> 167: 0.522572    0.970067    3.432181    0.272917    0.094436    0.003627    0.847977    
#> 168: 0.546517    0.979376    3.433375    0.311060    0.093100    0.003169    0.841868    
#> 169: 0.498348    1.002300    3.421459    0.322255    0.079823    0.003748    0.849314    
#> 170: 0.552104    0.965775    3.425267    0.328648    0.089651    0.004477    0.846950    
#> 171: 0.523551    0.971649    3.432558    0.331209    0.094705    0.004195    0.801997    
#> 172: 0.517428    0.977159    3.425755    0.314424    0.082952    0.005264    0.802749    
#> 173: 0.514842    0.981537    3.417883    0.321336    0.098381    0.006007    0.804478    
#> 174: 0.555839    0.956546    3.425102    0.468166    0.096631    0.006932    0.788327    
#> 175: 0.547960    0.971983    3.417804    0.456078    0.123651    0.006578    0.790466    
#> 176: 0.552515    0.988412    3.429209    0.541269    0.110781    0.006878    0.780202    
#> 177: 0.537238    0.957388    3.429493    0.481617    0.091134    0.007456    0.794478    
#> 178: 0.544669    0.943439    3.424209    0.431654    0.092406    0.007033    0.789726    
#> 179: 0.571538    1.003081    3.420902    0.373087    0.086156    0.009906    0.806887    
#> 180: 0.539857    0.952341    3.437316    0.426383    0.087371    0.011141    0.779642    
#> 181: 0.521084    0.949589    3.418608    0.381712    0.085705    0.011513    0.794694    
#> 182: 0.487556    0.968108    3.408497    0.334707    0.112903    0.010922    0.812438    
#> 183: 0.489381    1.009896    3.404393    0.372699    0.092146    0.010513    0.799132    
#> 184: 0.488517    0.967686    3.416922    0.368258    0.098827    0.010454    0.783620    
#> 185: 0.474110    0.974399    3.408412    0.357931    0.115487    0.012411    0.792844    
#> 186: 0.470899    0.975937    3.415904    0.398145    0.092611    0.014146    0.793933    
#> 187: 0.538406    0.973993    3.424342    0.425091    0.072528    0.011678    0.783554    
#> 188: 0.504642    0.990101    3.419787    0.371599    0.070295    0.010775    0.800565    
#> 189: 0.530081    0.988787    3.425382    0.434945    0.066522    0.010755    0.803212    
#> 190: 0.555885    0.949794    3.433438    0.547122    0.060997    0.009017    0.809889    
#> 191: 0.519789    0.973356    3.420215    0.390858    0.062075    0.009799    0.789746    
#> 192: 0.513545    0.965645    3.425267    0.404376    0.060857    0.011468    0.788098    
#> 193: 0.550432    0.993561    3.422326    0.373640    0.071374    0.007708    0.804413    
#> 194: 0.490679    1.002348    3.410200    0.361481    0.077472    0.008278    0.808476    
#> 195: 0.475568    0.989710    3.416895    0.348479    0.080115    0.008628    0.799887    
#> 196: 0.492664    0.969919    3.422320    0.317634    0.089057    0.007898    0.814634    
#> 197: 0.481458    0.973613    3.436196    0.298245    0.082094    0.008979    0.816648    
#> 198: 0.509741    0.936287    3.433487    0.318455    0.080846    0.012408    0.812540    
#> 199: 0.482396    0.941807    3.429278    0.383527    0.078915    0.013355    0.797401    
#> 200: 0.509731    0.951763    3.432635    0.452021    0.077243    0.013869    0.810000    
#> 201: 0.509872    0.949799    3.430847    0.458842    0.073474    0.014134    0.803547    
#> 202: 0.508829    0.951909    3.430097    0.444131    0.071994    0.014785    0.802477    
#> 203: 0.527954    0.953622    3.426835    0.452809    0.069669    0.015974    0.801536    
#> 204: 0.530118    0.948917    3.428186    0.453478    0.067316    0.016052    0.802720    
#> 205: 0.528901    0.956684    3.426448    0.452424    0.067430    0.016241    0.802627    
#> 206: 0.527150    0.962054    3.426314    0.453743    0.067783    0.016076    0.802985    
#> 207: 0.525028    0.963909    3.424843    0.461851    0.068276    0.015641    0.799647    
#> 208: 0.526647    0.963075    3.423716    0.472933    0.068940    0.015457    0.796102    
#> 209: 0.528295    0.961723    3.423023    0.474236    0.070755    0.015191    0.793858    
#> 210: 0.529405    0.961271    3.421938    0.475641    0.071474    0.014767    0.793588    
#> 211: 0.527584    0.962393    3.422494    0.470518    0.071539    0.014359    0.793300    
#> 212: 0.527710    0.961423    3.422665    0.468816    0.071768    0.014080    0.793557    
#> 213: 0.530343    0.959459    3.422751    0.471540    0.072423    0.013741    0.795304    
#> 214: 0.532810    0.958647    3.423308    0.472116    0.072702    0.013636    0.795342    
#> 215: 0.535799    0.958391    3.424307    0.475362    0.073215    0.013507    0.794392    
#> 216: 0.538002    0.956683    3.425474    0.471177    0.073252    0.013390    0.795736    
#> 217: 0.537843    0.957065    3.425482    0.464296    0.073548    0.013307    0.796194    
#> 218: 0.537599    0.958030    3.424947    0.460819    0.073578    0.013225    0.796503    
#> 219: 0.537374    0.958336    3.424296    0.460161    0.074158    0.013252    0.797340    
#> 220: 0.537685    0.959191    3.423982    0.463730    0.074721    0.013271    0.796662    
#> 221: 0.536271    0.958914    3.423187    0.466293    0.074537    0.013223    0.796412    
#> 222: 0.535558    0.958932    3.423120    0.464072    0.074315    0.013175    0.796469    
#> 223: 0.535915    0.958867    3.423084    0.463996    0.074274    0.013117    0.795480    
#> 224: 0.536530    0.959748    3.423328    0.462233    0.074620    0.013037    0.794638    
#> 225: 0.535296    0.958175    3.423551    0.461173    0.075319    0.012895    0.794743    
#> 226: 0.535149    0.957051    3.423486    0.459059    0.075525    0.012828    0.794871    
#> 227: 0.534108    0.957668    3.423540    0.457472    0.075353    0.012813    0.794536    
#> 228: 0.533597    0.959137    3.423102    0.456581    0.075880    0.012846    0.794662    
#> 229: 0.531799    0.959588    3.422408    0.454931    0.076039    0.012835    0.794417    
#> 230: 0.531682    0.959217    3.422260    0.453373    0.076057    0.012761    0.794512    
#> 231: 0.531378    0.959607    3.422349    0.453759    0.077002    0.012698    0.794175    
#> 232: 0.530516    0.959683    3.422598    0.452260    0.077619    0.012655    0.793929    
#> 233: 0.528699    0.958756    3.422670    0.451309    0.077952    0.012645    0.794144    
#> 234: 0.527856    0.959101    3.422713    0.451705    0.077918    0.012683    0.794010    
#> 235: 0.528453    0.959051    3.422692    0.452356    0.077909    0.012596    0.793700    
#> 236: 0.528477    0.959434    3.422553    0.451644    0.078144    0.012558    0.793901    
#> 237: 0.528941    0.959460    3.422637    0.452397    0.078184    0.012649    0.794289    
#> 238: 0.528073    0.959552    3.422487    0.451095    0.078051    0.012620    0.794933    
#> 239: 0.526528    0.960265    3.422309    0.448848    0.077973    0.012562    0.795728    
#> 240: 0.526667    0.960600    3.422398    0.447245    0.077809    0.012560    0.795940    
#> 241: 0.527582    0.959634    3.422938    0.446531    0.077592    0.012604    0.796094    
#> 242: 0.528172    0.958865    3.423096    0.448946    0.077291    0.012661    0.796550    
#> 243: 0.528792    0.958780    3.423462    0.448782    0.076849    0.012775    0.796655    
#> 244: 0.528239    0.958680    3.423600    0.448397    0.076767    0.012887    0.796937    
#> 245: 0.528325    0.958415    3.423884    0.448273    0.076422    0.012977    0.797433    
#> 246: 0.527999    0.958189    3.424051    0.446688    0.076563    0.013060    0.797703    
#> 247: 0.527687    0.958040    3.424430    0.445879    0.076630    0.013084    0.797911    
#> 248: 0.527666    0.958250    3.424526    0.444744    0.076671    0.013100    0.797771    
#> 249: 0.527869    0.958440    3.424702    0.444480    0.076829    0.013091    0.797654    
#> 250: 0.528799    0.958695    3.425072    0.444852    0.076646    0.013202    0.797929    
#> 251: 0.529612    0.958925    3.425419    0.444550    0.076509    0.013254    0.797750    
#> 252: 0.530943    0.958803    3.425854    0.445309    0.076197    0.013288    0.797834    
#> 253: 0.531282    0.958919    3.426058    0.446258    0.075930    0.013334    0.797949    
#> 254: 0.531668    0.959316    3.426065    0.446211    0.075608    0.013362    0.798016    
#> 255: 0.531665    0.959501    3.426111    0.446848    0.075220    0.013450    0.797848    
#> 256: 0.532255    0.959430    3.426072    0.447787    0.074887    0.013499    0.797702    
#> 257: 0.531964    0.959298    3.425906    0.445846    0.074633    0.013484    0.798130    
#> 258: 0.530886    0.959019    3.425648    0.444424    0.074829    0.013419    0.798532    
#> 259: 0.530350    0.959177    3.425356    0.443561    0.075052    0.013393    0.798370    
#> 260: 0.530180    0.959673    3.425388    0.442500    0.075095    0.013383    0.798106    
#> 261: 0.529684    0.959610    3.425455    0.441773    0.075116    0.013364    0.797966    
#> 262: 0.529576    0.959850    3.425493    0.440829    0.075195    0.013326    0.797632    
#> 263: 0.529243    0.960278    3.425474    0.441405    0.075133    0.013334    0.797442    
#> 264: 0.528922    0.960169    3.425376    0.441363    0.074875    0.013294    0.797672    
#> 265: 0.528348    0.960318    3.425355    0.439716    0.074679    0.013316    0.798154    
#> 266: 0.528547    0.960614    3.425323    0.438294    0.074792    0.013275    0.798387    
#> 267: 0.528374    0.960504    3.425255    0.438911    0.074951    0.013246    0.798465    
#> 268: 0.527977    0.960638    3.424934    0.438542    0.075202    0.013219    0.798634    
#> 269: 0.527828    0.960571    3.424752    0.437655    0.075600    0.013189    0.798513    
#> 270: 0.527452    0.960597    3.424470    0.437913    0.075749    0.013137    0.798211    
#> 271: 0.527017    0.960659    3.424189    0.437716    0.075624    0.013141    0.798439    
#> 272: 0.527152    0.960445    3.423960    0.438076    0.075611    0.013144    0.798798    
#> 273: 0.527103    0.960864    3.423898    0.438042    0.075712    0.013149    0.799052    
#> 274: 0.527147    0.961111    3.423862    0.437994    0.075864    0.013137    0.799221    
#> 275: 0.526906    0.961126    3.423741    0.437406    0.075927    0.013122    0.799269    
#> 276: 0.526778    0.961327    3.423908    0.436985    0.075837    0.013127    0.799365    
#> 277: 0.526237    0.961495    3.424096    0.436004    0.075844    0.013118    0.799375    
#> 278: 0.526221    0.961476    3.424244    0.435790    0.075925    0.013096    0.799384    
#> 279: 0.526006    0.961285    3.424361    0.435712    0.076110    0.013117    0.799532    
#> 280: 0.526061    0.961393    3.424450    0.435691    0.076036    0.013101    0.799515    
#> 281: 0.525621    0.961565    3.424452    0.435795    0.075936    0.013096    0.799363    
#> 282: 0.525370    0.961685    3.424397    0.436228    0.075825    0.013058    0.799336    
#> 283: 0.524942    0.961759    3.424385    0.437092    0.075858    0.013025    0.799754    
#> 284: 0.524767    0.961539    3.424312    0.437123    0.075983    0.013032    0.799662    
#> 285: 0.524568    0.961866    3.424014    0.437396    0.076156    0.013031    0.799556    
#> 286: 0.524264    0.962348    3.423709    0.437419    0.076151    0.013043    0.799563    
#> 287: 0.523809    0.962622    3.423446    0.437446    0.076142    0.013052    0.799645    
#> 288: 0.524067    0.962861    3.423226    0.438189    0.076143    0.013041    0.799820    
#> 289: 0.524395    0.962759    3.423176    0.438309    0.076082    0.013029    0.799885    
#> 290: 0.524660    0.962799    3.423145    0.438397    0.076181    0.013023    0.799858    
#> 291: 0.524637    0.963107    3.423207    0.438188    0.076356    0.012999    0.799751    
#> 292: 0.524056    0.963224    3.423206    0.437093    0.076551    0.012983    0.799802    
#> 293: 0.523879    0.963489    3.423135    0.436188    0.076584    0.012966    0.799751    
#> 294: 0.523656    0.963640    3.423038    0.435904    0.076572    0.012942    0.799750    
#> 295: 0.523442    0.963300    3.423002    0.434812    0.076621    0.012920    0.799583    
#> 296: 0.523788    0.963128    3.423056    0.434683    0.076656    0.012908    0.799584    
#> 297: 0.524101    0.963171    3.423093    0.434968    0.076779    0.012892    0.799337    
#> 298: 0.523836    0.963130    3.423091    0.434628    0.076797    0.012889    0.799201    
#> 299: 0.523961    0.963319    3.423093    0.434322    0.076829    0.012885    0.798909    
#> 300: 0.524239    0.963169    3.423257    0.434659    0.076857    0.012890    0.798590    
#> 301: 0.524561    0.962989    3.423261    0.434449    0.076803    0.012877    0.798612    
#> 302: 0.524806    0.962947    3.423233    0.434325    0.076757    0.012865    0.798642    
#> 303: 0.524595    0.962947    3.423227    0.434140    0.076870    0.012906    0.798484    
#> 304: 0.524423    0.963248    3.423120    0.433679    0.077029    0.012922    0.798355    
#> 305: 0.524228    0.963030    3.423071    0.433607    0.077118    0.012923    0.798219    
#> 306: 0.524092    0.962904    3.423039    0.433085    0.077012    0.012911    0.798184    
#> 307: 0.524086    0.962811    3.423022    0.432820    0.076969    0.012883    0.798201    
#> 308: 0.523629    0.962714    3.422986    0.432313    0.077060    0.012829    0.798244    
#> 309: 0.523321    0.962377    3.422868    0.432030    0.077028    0.012810    0.798437    
#> 310: 0.523213    0.962238    3.422710    0.431701    0.076980    0.012790    0.798604    
#> 311: 0.523235    0.962290    3.422756    0.431830    0.076956    0.012788    0.798522    
#> 312: 0.523035    0.962185    3.422729    0.431313    0.076926    0.012805    0.798446    
#> 313: 0.522839    0.961855    3.422729    0.431612    0.076999    0.012819    0.798485    
#> 314: 0.522394    0.961717    3.422648    0.431315    0.077023    0.012818    0.798597    
#> 315: 0.521984    0.961573    3.422679    0.430870    0.077054    0.012800    0.798496    
#> 316: 0.521984    0.961575    3.422657    0.430682    0.077047    0.012763    0.798453    
#> 317: 0.521975    0.961540    3.422735    0.430190    0.077102    0.012746    0.798458    
#> 318: 0.522146    0.961554    3.422771    0.429896    0.077043    0.012729    0.798381    
#> 319: 0.522193    0.961459    3.422828    0.429537    0.077080    0.012713    0.798453    
#> 320: 0.521843    0.961301    3.422787    0.429407    0.077119    0.012699    0.798462    
#> 321: 0.521606    0.961422    3.422645    0.429600    0.077240    0.012707    0.798420    
#> 322: 0.521141    0.961647    3.422415    0.429199    0.077280    0.012691    0.798616    
#> 323: 0.520357    0.961856    3.422207    0.428999    0.077297    0.012686    0.798612    
#> 324: 0.520202    0.961996    3.422150    0.429545    0.077310    0.012663    0.798541    
#> 325: 0.520012    0.962161    3.422000    0.429687    0.077337    0.012654    0.798432    
#> 326: 0.519850    0.962072    3.421953    0.429689    0.077362    0.012641    0.798507    
#> 327: 0.519916    0.961980    3.422081    0.429392    0.077430    0.012651    0.798612    
#> 328: 0.520333    0.962070    3.422114    0.429263    0.077504    0.012643    0.798546    
#> 329: 0.520457    0.962159    3.422195    0.428904    0.077537    0.012648    0.798373    
#> 330: 0.520126    0.962148    3.422173    0.428608    0.077447    0.012675    0.798400    
#> 331: 0.520315    0.962340    3.422136    0.428508    0.077430    0.012681    0.798371    
#> 332: 0.520329    0.962517    3.422131    0.428492    0.077402    0.012683    0.798542    
#> 333: 0.520377    0.962658    3.422006    0.428935    0.077520    0.012646    0.798559    
#> 334: 0.520283    0.962565    3.421903    0.428941    0.077596    0.012621    0.798567    
#> 335: 0.520260    0.962524    3.421878    0.428588    0.077726    0.012612    0.798422    
#> 336: 0.520038    0.962721    3.421843    0.428475    0.077737    0.012622    0.798420    
#> 337: 0.519770    0.962958    3.421749    0.428463    0.077713    0.012613    0.798503    
#> 338: 0.519710    0.962855    3.421764    0.428549    0.077738    0.012602    0.798556    
#> 339: 0.519443    0.963004    3.421669    0.428282    0.077768    0.012594    0.798496    
#> 340: 0.519549    0.962965    3.421656    0.428184    0.077855    0.012576    0.798458    
#> 341: 0.519796    0.962920    3.421727    0.428331    0.077960    0.012573    0.798368    
#> 342: 0.519681    0.962792    3.421731    0.428245    0.077936    0.012584    0.798276    
#> 343: 0.519437    0.962903    3.421730    0.428119    0.077954    0.012571    0.798245    
#> 344: 0.519541    0.962983    3.421810    0.428230    0.078064    0.012583    0.798288    
#> 345: 0.519687    0.962850    3.421894    0.428026    0.078169    0.012606    0.798218    
#> 346: 0.519779    0.962895    3.421911    0.427960    0.078279    0.012592    0.798109    
#> 347: 0.520030    0.962604    3.421937    0.428141    0.078291    0.012599    0.798087    
#> 348: 0.519998    0.962572    3.421987    0.427849    0.078258    0.012620    0.798172    
#> 349: 0.520034    0.962500    3.421975    0.427901    0.078217    0.012637    0.798028    
#> 350: 0.519779    0.962432    3.421882    0.428015    0.078230    0.012641    0.798023    
#> 351: 0.519644    0.962585    3.421737    0.428228    0.078246    0.012661    0.798091    
#> 352: 0.519183    0.962776    3.421654    0.428014    0.078259    0.012682    0.798120    
#> 353: 0.519130    0.962954    3.421595    0.427445    0.078285    0.012694    0.798177    
#> 354: 0.519063    0.963022    3.421450    0.427255    0.078340    0.012696    0.798203    
#> 355: 0.519455    0.962905    3.421465    0.427686    0.078475    0.012697    0.798189    
#> 356: 0.519683    0.962792    3.421584    0.428285    0.078470    0.012698    0.798224    
#> 357: 0.520021    0.962826    3.421676    0.428313    0.078417    0.012686    0.798212    
#> 358: 0.520321    0.962803    3.421785    0.428428    0.078493    0.012694    0.798035    
#> 359: 0.520446    0.963015    3.421818    0.428589    0.078571    0.012696    0.797889    
#> 360: 0.520242    0.963095    3.421708    0.428403    0.078540    0.012703    0.797784    
#> 361: 0.519904    0.963200    3.421594    0.428153    0.078570    0.012707    0.797707    
#> 362: 0.519916    0.963172    3.421566    0.427772    0.078547    0.012703    0.797501    
#> 363: 0.519703    0.963089    3.421515    0.427349    0.078520    0.012694    0.797387    
#> 364: 0.519769    0.963121    3.421537    0.427179    0.078512    0.012693    0.797272    
#> 365: 0.519779    0.963071    3.421572    0.427063    0.078460    0.012711    0.797235    
#> 366: 0.519696    0.963140    3.421474    0.427068    0.078347    0.012734    0.797235    
#> 367: 0.519778    0.963209    3.421420    0.426963    0.078216    0.012748    0.797309    
#> 368: 0.520014    0.963401    3.421336    0.428130    0.078101    0.012773    0.797135    
#> 369: 0.519942    0.963402    3.421257    0.428545    0.078092    0.012781    0.797028    
#> 370: 0.519920    0.963395    3.421219    0.428535    0.078147    0.012806    0.796963    
#> 371: 0.519699    0.963401    3.421100    0.428157    0.078188    0.012787    0.796920    
#> 372: 0.519465    0.963423    3.420992    0.428115    0.078163    0.012776    0.796868    
#> 373: 0.519150    0.963598    3.420855    0.428165    0.078210    0.012770    0.796904    
#> 374: 0.519132    0.963544    3.420827    0.428335    0.078193    0.012771    0.796822    
#> 375: 0.518991    0.963544    3.420795    0.428303    0.078298    0.012766    0.796782    
#> 376: 0.518979    0.963589    3.420807    0.428035    0.078262    0.012752    0.796668    
#> 377: 0.518750    0.963641    3.420769    0.427800    0.078312    0.012746    0.796493    
#> 378: 0.518668    0.963602    3.420701    0.427397    0.078313    0.012736    0.796560    
#> 379: 0.518368    0.963445    3.420692    0.427167    0.078326    0.012716    0.796549    
#> 380: 0.518089    0.963397    3.420632    0.426693    0.078344    0.012689    0.796565    
#> 381: 0.517997    0.963399    3.420583    0.426723    0.078281    0.012680    0.796502    
#> 382: 0.517974    0.963418    3.420577    0.426952    0.078314    0.012663    0.796394    
#> 383: 0.518172    0.963390    3.420594    0.427253    0.078295    0.012651    0.796413    
#> 384: 0.518088    0.963366    3.420618    0.427110    0.078402    0.012633    0.796355    
#> 385: 0.518359    0.963292    3.420666    0.426868    0.078514    0.012621    0.796336    
#> 386: 0.518677    0.963383    3.420720    0.426876    0.078687    0.012606    0.796357    
#> 387: 0.518974    0.963443    3.420829    0.427015    0.078694    0.012606    0.796330    
#> 388: 0.519054    0.963530    3.420873    0.427227    0.078709    0.012605    0.796245    
#> 389: 0.519246    0.963417    3.420900    0.427412    0.078763    0.012608    0.796218    
#> 390: 0.519322    0.963382    3.420889    0.427956    0.078717    0.012624    0.796226    
#> 391: 0.519237    0.963252    3.420900    0.428004    0.078668    0.012639    0.796146    
#> 392: 0.519326    0.963238    3.420982    0.428187    0.078666    0.012639    0.796220    
#> 393: 0.519230    0.963197    3.420917    0.428003    0.078835    0.012624    0.796243    
#> 394: 0.519331    0.963217    3.420889    0.428450    0.078838    0.012603    0.796229    
#> 395: 0.519723    0.963369    3.420874    0.428801    0.078785    0.012593    0.796168    
#> 396: 0.520117    0.963380    3.420906    0.429463    0.078739    0.012592    0.796097    
#> 397: 0.520261    0.963382    3.420969    0.429729    0.078731    0.012603    0.795972    
#> 398: 0.520386    0.963353    3.420997    0.430099    0.078684    0.012627    0.795993    
#> 399: 0.520403    0.963364    3.421052    0.430277    0.078621    0.012632    0.796004    
#> 400: 0.520533    0.963414    3.421095    0.430545    0.078570    0.012641    0.795974    
#> 401: 0.520490    0.963547    3.421115    0.430470    0.078639    0.012651    0.795944    
#> 402: 0.520435    0.963684    3.421087    0.430457    0.078641    0.012667    0.795864    
#> 403: 0.520608    0.963651    3.421094    0.430329    0.078666    0.012672    0.795832    
#> 404: 0.520616    0.963689    3.421025    0.430442    0.078589    0.012686    0.795740    
#> 405: 0.520625    0.963685    3.421015    0.430207    0.078501    0.012695    0.795745    
#> 406: 0.520679    0.963832    3.420960    0.430405    0.078480    0.012716    0.795726    
#> 407: 0.520709    0.964021    3.420929    0.430539    0.078467    0.012724    0.795744    
#> 408: 0.520821    0.964101    3.420919    0.430506    0.078431    0.012731    0.795773    
#> 409: 0.520769    0.963999    3.420855    0.430622    0.078421    0.012732    0.795713    
#> 410: 0.520811    0.964030    3.420785    0.430679    0.078473    0.012725    0.795692    
#> 411: 0.520752    0.963914    3.420769    0.430447    0.078399    0.012722    0.795833    
#> 412: 0.520639    0.963961    3.420756    0.430434    0.078361    0.012725    0.795867    
#> 413: 0.520741    0.963963    3.420733    0.430582    0.078324    0.012722    0.795796    
#> 414: 0.520669    0.964025    3.420723    0.430312    0.078242    0.012718    0.795803    
#> 415: 0.520752    0.964000    3.420744    0.429926    0.078182    0.012712    0.795847    
#> 416: 0.520800    0.964017    3.420797    0.429959    0.078158    0.012707    0.795742    
#> 417: 0.520809    0.964001    3.420804    0.430082    0.078123    0.012701    0.795771    
#> 418: 0.520629    0.964027    3.420794    0.430133    0.078105    0.012698    0.795782    
#> 419: 0.520554    0.964194    3.420770    0.430123    0.078109    0.012676    0.795861    
#> 420: 0.520567    0.964301    3.420796    0.430184    0.078100    0.012651    0.795863    
#> 421: 0.520543    0.964400    3.420845    0.430282    0.078077    0.012635    0.795923    
#> 422: 0.520748    0.964350    3.420891    0.430070    0.078094    0.012618    0.795980    
#> 423: 0.520951    0.964223    3.420939    0.430088    0.078182    0.012618    0.796078    
#> 424: 0.521009    0.964145    3.420929    0.429918    0.078214    0.012605    0.796132    
#> 425: 0.521290    0.964122    3.420965    0.430203    0.078258    0.012590    0.796219    
#> 426: 0.521450    0.964193    3.420999    0.430500    0.078303    0.012582    0.796128    
#> 427: 0.521358    0.964215    3.420984    0.430488    0.078294    0.012571    0.796002    
#> 428: 0.521179    0.964242    3.420961    0.430256    0.078316    0.012570    0.795960    
#> 429: 0.521250    0.964300    3.420993    0.430090    0.078330    0.012577    0.795949    
#> 430: 0.521197    0.964405    3.421000    0.429890    0.078354    0.012579    0.795952    
#> 431: 0.521063    0.964507    3.420940    0.429854    0.078355    0.012576    0.795894    
#> 432: 0.520956    0.964572    3.420924    0.429896    0.078327    0.012584    0.795807    
#> 433: 0.521014    0.964739    3.420930    0.429871    0.078329    0.012594    0.795716    
#> 434: 0.520911    0.964691    3.420926    0.429818    0.078355    0.012598    0.795606    
#> 435: 0.520909    0.964724    3.420921    0.429906    0.078361    0.012607    0.795462    
#> 436: 0.520972    0.964652    3.420944    0.429908    0.078332    0.012606    0.795520    
#> 437: 0.521004    0.964625    3.420923    0.429591    0.078329    0.012607    0.795604    
#> 438: 0.520834    0.964727    3.420890    0.429339    0.078282    0.012593    0.795626    
#> 439: 0.520813    0.964812    3.420855    0.429166    0.078225    0.012582    0.795616    
#> 440: 0.520772    0.964866    3.420884    0.429186    0.078186    0.012580    0.795601    
#> 441: 0.520832    0.964887    3.420951    0.428948    0.078190    0.012573    0.795560    
#> 442: 0.520834    0.964950    3.421000    0.428495    0.078169    0.012566    0.795554    
#> 443: 0.520857    0.965016    3.420998    0.428006    0.078175    0.012557    0.795604    
#> 444: 0.520717    0.965089    3.420945    0.427753    0.078171    0.012548    0.795599    
#> 445: 0.520558    0.965107    3.420909    0.427514    0.078209    0.012538    0.795642    
#> 446: 0.520476    0.965135    3.420916    0.427199    0.078282    0.012541    0.795624    
#> 447: 0.520627    0.965093    3.420939    0.427012    0.078371    0.012543    0.795591    
#> 448: 0.520580    0.965115    3.420973    0.427028    0.078358    0.012560    0.795547    
#> 449: 0.520676    0.965184    3.421099    0.426872    0.078351    0.012570    0.795540    
#> 450: 0.520644    0.965194    3.421128    0.427006    0.078279    0.012572    0.795554    
#> 451: 0.520710    0.965234    3.421116    0.427180    0.078280    0.012566    0.795534    
#> 452: 0.520564    0.965350    3.421033    0.427421    0.078278    0.012569    0.795525    
#> 453: 0.520300    0.965426    3.420948    0.427248    0.078235    0.012563    0.795566    
#> 454: 0.520121    0.965579    3.420886    0.427324    0.078188    0.012557    0.795517    
#> 455: 0.520057    0.965614    3.420839    0.427626    0.078169    0.012559    0.795471    
#> 456: 0.520009    0.965611    3.420819    0.427554    0.078170    0.012562    0.795489    
#> 457: 0.519925    0.965577    3.420840    0.427306    0.078148    0.012550    0.795491    
#> 458: 0.519863    0.965625    3.420873    0.426968    0.078149    0.012535    0.795480    
#> 459: 0.519741    0.965674    3.420891    0.426783    0.078165    0.012523    0.795452    
#> 460: 0.519607    0.965727    3.420853    0.426587    0.078208    0.012517    0.795428    
#> 461: 0.519397    0.965804    3.420824    0.426331    0.078260    0.012503    0.795481    
#> 462: 0.519105    0.965919    3.420802    0.426050    0.078340    0.012488    0.795491    
#> 463: 0.519090    0.965985    3.420808    0.425832    0.078385    0.012477    0.795460    
#> 464: 0.519130    0.966050    3.420786    0.425629    0.078436    0.012466    0.795406    
#> 465: 0.519197    0.965922    3.420789    0.425429    0.078453    0.012455    0.795366    
#> 466: 0.519312    0.965905    3.420791    0.425480    0.078434    0.012446    0.795339    
#> 467: 0.519325    0.965830    3.420820    0.425438    0.078425    0.012435    0.795305    
#> 468: 0.519443    0.965781    3.420850    0.425755    0.078414    0.012425    0.795347    
#> 469: 0.519529    0.965806    3.420877    0.425750    0.078376    0.012422    0.795476    
#> 470: 0.519531    0.965787    3.420843    0.425985    0.078340    0.012420    0.795441    
#> 471: 0.519430    0.965790    3.420799    0.426189    0.078305    0.012423    0.795430    
#> 472: 0.519446    0.965814    3.420787    0.426533    0.078264    0.012420    0.795423    
#> 473: 0.519339    0.965860    3.420770    0.426425    0.078259    0.012423    0.795358    
#> 474: 0.519263    0.965800    3.420775    0.426312    0.078327    0.012423    0.795439    
#> 475: 0.519446    0.965902    3.420830    0.426165    0.078341    0.012426    0.795439    
#> 476: 0.519326    0.965876    3.420826    0.425965    0.078443    0.012422    0.795507    
#> 477: 0.519200    0.965871    3.420837    0.425877    0.078524    0.012420    0.795434    
#> 478: 0.519061    0.965801    3.420839    0.425771    0.078599    0.012421    0.795524    
#> 479: 0.519032    0.965842    3.420852    0.425592    0.078681    0.012431    0.795562    
#> 480: 0.519149    0.965845    3.420896    0.425766    0.078663    0.012440    0.795582    
#> 481: 0.519224    0.965823    3.420907    0.425765    0.078613    0.012453    0.795587    
#> 482: 0.519422    0.965809    3.420909    0.425836    0.078549    0.012461    0.795611    
#> 483: 0.519400    0.965722    3.420920    0.425842    0.078503    0.012451    0.795700    
#> 484: 0.519344    0.965549    3.420954    0.425742    0.078509    0.012440    0.795774    
#> 485: 0.519504    0.965496    3.421002    0.425756    0.078487    0.012433    0.795850    
#> 486: 0.519559    0.965472    3.421018    0.425655    0.078429    0.012421    0.795877    
#> 487: 0.519879    0.965484    3.421121    0.425561    0.078379    0.012429    0.795901    
#> 488: 0.520029    0.965432    3.421189    0.425731    0.078363    0.012435    0.795828    
#> 489: 0.520132    0.965408    3.421209    0.425777    0.078340    0.012443    0.795808    
#> 490: 0.520289    0.965436    3.421252    0.425843    0.078315    0.012452    0.795780    
#> 491: 0.520367    0.965480    3.421350    0.425671    0.078299    0.012471    0.795750    
#> 492: 0.520342    0.965460    3.421381    0.425460    0.078302    0.012484    0.795837    
#> 493: 0.520301    0.965449    3.421379    0.425385    0.078281    0.012487    0.795859    
#> 494: 0.520497    0.965391    3.421385    0.425546    0.078217    0.012484    0.795842    
#> 495: 0.520568    0.965380    3.421401    0.425360    0.078181    0.012481    0.795838    
#> 496: 0.520692    0.965419    3.421401    0.425476    0.078172    0.012482    0.795845    
#> 497: 0.520679    0.965411    3.421409    0.425354    0.078144    0.012490    0.795858    
#> 498: 0.520729    0.965444    3.421377    0.425284    0.078156    0.012488    0.795831    
#> 499: 0.520672    0.965481    3.421335    0.425307    0.078189    0.012477    0.795849    
#> 500: 0.520702    0.965423    3.421316    0.425362    0.078246    0.012468    0.795805    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.254075    0.964532    3.440992    0.392401    0.078200    0.016800    1.546469    
#> 002: 0.287100    1.051744    3.446827    0.372781    0.074290    0.015960    1.112598    
#> 003: 0.405694    0.981508    3.469806    0.354142    0.070576    0.015162    0.898623    
#> 004: 0.411740    0.986481    3.461802    0.336435    0.067047    0.014404    0.847878    
#> 005: 0.474245    0.997133    3.455302    0.319613    0.063694    0.013684    0.784644    
#> 006: 0.472391    0.998134    3.453899    0.303633    0.080375    0.013000    0.753829    
#> 007: 0.417396    1.000003    3.452617    0.288451    0.085014    0.012350    0.756200    
#> 008: 0.436147    0.997672    3.453866    0.274029    0.080764    0.011732    0.775216    
#> 009: 0.422051    0.981508    3.454820    0.260327    0.076725    0.012048    0.778321    
#> 010: 0.435903    0.986304    3.450672    0.247311    0.072889    0.011446    0.764869    
#> 011: 0.482004    0.997024    3.469070    0.234945    0.072775    0.011203    0.783943    
#> 012: 0.486909    0.980251    3.460816    0.223198    0.069136    0.011146    0.760576    
#> 013: 0.433249    0.981538    3.453611    0.212038    0.065679    0.013559    0.745656    
#> 014: 0.472949    0.983544    3.464955    0.201436    0.062395    0.015416    0.768589    
#> 015: 0.474440    1.005659    3.474093    0.191364    0.068644    0.014645    0.766166    
#> 016: 0.481037    0.994537    3.485292    0.181796    0.080493    0.013913    0.794225    
#> 017: 0.498437    0.990675    3.475140    0.172706    0.079397    0.013217    0.745188    
#> 018: 0.471382    0.991518    3.463010    0.164071    0.077503    0.012556    0.775793    
#> 019: 0.405118    1.008469    3.448811    0.157384    0.073793    0.011928    0.747913    
#> 020: 0.418165    1.026103    3.453417    0.150065    0.070103    0.012015    0.764879    
#> 021: 0.440177    1.000683    3.458783    0.142562    0.072399    0.013726    0.746838    
#> 022: 0.442712    1.005015    3.470017    0.135434    0.074964    0.013040    0.754759    
#> 023: 0.513165    0.990877    3.481048    0.144031    0.081063    0.012388    0.765322    
#> 024: 0.523273    1.011086    3.482438    0.162142    0.077010    0.011768    0.769450    
#> 025: 0.528455    0.986807    3.470046    0.188797    0.073159    0.011180    0.761557    
#> 026: 0.491765    1.003465    3.466061    0.179357    0.073067    0.010645    0.750900    
#> 027: 0.443161    0.999686    3.464923    0.170389    0.088362    0.010113    0.776286    
#> 028: 0.487686    1.003392    3.465660    0.182639    0.090065    0.009607    0.769329    
#> 029: 0.500660    0.987349    3.460430    0.216105    0.085562    0.009731    0.762080    
#> 030: 0.503694    0.992550    3.466194    0.205300    0.081284    0.013442    0.764621    
#> 031: 0.462476    0.994710    3.464671    0.212142    0.077220    0.013097    0.758549    
#> 032: 0.454423    0.967657    3.475248    0.201535    0.073359    0.014794    0.739823    
#> 033: 0.470460    0.981271    3.473971    0.191458    0.070207    0.014055    0.761392    
#> 034: 0.519552    0.975106    3.486860    0.181885    0.066697    0.018033    0.751585    
#> 035: 0.479646    0.955130    3.473844    0.172791    0.063362    0.017132    0.736929    
#> 036: 0.492736    0.984429    3.475126    0.205641    0.066883    0.016275    0.758782    
#> 037: 0.464588    0.988241    3.470120    0.195359    0.066994    0.015461    0.754687    
#> 038: 0.489293    0.998196    3.460084    0.185591    0.068847    0.014688    0.769975    
#> 039: 0.481048    0.992628    3.464411    0.176311    0.065405    0.013954    0.750225    
#> 040: 0.458748    0.995272    3.471251    0.172452    0.070320    0.013256    0.749582    
#> 041: 0.450509    0.982450    3.467929    0.204624    0.066804    0.012593    0.737311    
#> 042: 0.519013    0.980922    3.475426    0.221217    0.065404    0.014917    0.726590    
#> 043: 0.445181    1.005209    3.456552    0.210156    0.076110    0.014171    0.744441    
#> 044: 0.445532    0.980523    3.457464    0.199648    0.072304    0.013463    0.740322    
#> 045: 0.452458    1.022568    3.446473    0.234387    0.073562    0.012790    0.748258    
#> 046: 0.462469    0.999151    3.455546    0.222668    0.070854    0.012150    0.758626    
#> 047: 0.505466    1.015329    3.458988    0.214345    0.070848    0.012818    0.747912    
#> 048: 0.473979    0.996696    3.454631    0.203628    0.074268    0.013137    0.737683    
#> 049: 0.447133    1.004285    3.458647    0.193446    0.070555    0.012480    0.760599    
#> 050: 0.514684    0.990348    3.471143    0.208285    0.070171    0.014920    0.761209    
#> 051: 0.474962    0.991414    3.462337    0.197871    0.076581    0.016048    0.761337    
#> 052: 0.472835    1.017460    3.468568    0.187978    0.077388    0.015246    0.742150    
#> 053: 0.473410    0.999098    3.462271    0.178579    0.082338    0.017761    0.760201    
#> 054: 0.447117    0.994114    3.474558    0.169650    0.078221    0.017024    0.758511    
#> 055: 0.485187    0.976264    3.470614    0.161167    0.074310    0.016173    0.782406    
#> 056: 0.492075    0.964419    3.476887    0.153109    0.076213    0.015364    0.762587    
#> 057: 0.508956    0.951868    3.488400    0.145454    0.072402    0.014596    0.766868    
#> 058: 0.482815    0.974079    3.472921    0.138181    0.068782    0.013866    0.761225    
#> 059: 0.511649    0.967302    3.474773    0.167572    0.072970    0.013173    0.750297    
#> 060: 0.507852    0.975418    3.481782    0.171151    0.073321    0.012514    0.743986    
#> 061: 0.503053    0.976990    3.485125    0.162593    0.069655    0.011889    0.768820    
#> 062: 0.489947    1.004114    3.481393    0.193425    0.076905    0.013890    0.775264    
#> 063: 0.524836    0.961752    3.475777    0.207605    0.073060    0.013195    0.799377    
#> 064: 0.506252    0.968987    3.492021    0.197225    0.070941    0.014118    0.784228    
#> 065: 0.512644    0.954632    3.483913    0.187363    0.088530    0.014511    0.775098    
#> 066: 0.495654    0.981543    3.480781    0.177995    0.084104    0.013786    0.762621    
#> 067: 0.468564    0.973438    3.468117    0.169095    0.079899    0.013096    0.764910    
#> 068: 0.462781    0.996552    3.478910    0.160641    0.075959    0.012967    0.783117    
#> 069: 0.475286    0.997610    3.465995    0.159219    0.072161    0.012318    0.779781    
#> 070: 0.484415    1.002528    3.477258    0.162794    0.089758    0.011703    0.780795    
#> 071: 0.476588    0.992491    3.470351    0.154654    0.086362    0.011117    0.774851    
#> 072: 0.430514    0.952746    3.469878    0.146921    0.082044    0.010562    0.760868    
#> 073: 0.492515    0.983115    3.481381    0.143294    0.077941    0.012077    0.785802    
#> 074: 0.483803    0.965441    3.481379    0.136129    0.074044    0.011474    0.770514    
#> 075: 0.473632    0.980988    3.488090    0.145414    0.070342    0.010900    0.761576    
#> 076: 0.499931    0.992579    3.497482    0.139404    0.081251    0.010355    0.766891    
#> 077: 0.548931    0.972828    3.477512    0.139997    0.077189    0.009837    0.778712    
#> 078: 0.529160    0.969746    3.489932    0.155859    0.073329    0.011800    0.763761    
#> 079: 0.539209    0.987677    3.483789    0.163859    0.069663    0.013122    0.780596    
#> 080: 0.541455    0.976153    3.481909    0.161099    0.066180    0.012466    0.773275    
#> 081: 0.496593    0.982231    3.476516    0.156946    0.062871    0.011843    0.773198    
#> 082: 0.474880    0.963413    3.482622    0.149613    0.065900    0.011251    0.778400    
#> 083: 0.478444    0.973226    3.486819    0.151523    0.062605    0.012814    0.772018    
#> 084: 0.464250    0.994115    3.471381    0.143947    0.073364    0.012173    0.750928    
#> 085: 0.490642    0.989393    3.482695    0.156671    0.077410    0.012197    0.747812    
#> 086: 0.465258    1.002919    3.474563    0.148838    0.073539    0.012934    0.733638    
#> 087: 0.463253    0.990943    3.469161    0.141396    0.069862    0.012287    0.757577    
#> 088: 0.387844    1.008611    3.452704    0.134326    0.066369    0.014238    0.766877    
#> 089: 0.406205    1.025939    3.442908    0.127610    0.063051    0.017018    0.775542    
#> 090: 0.388047    1.016042    3.442479    0.127385    0.061385    0.016167    0.767096    
#> 091: 0.381325    1.006991    3.428886    0.121016    0.060269    0.015359    0.766891    
#> 092: 0.393071    1.023926    3.425683    0.134963    0.059931    0.014591    0.780667    
#> 093: 0.358982    1.015528    3.419846    0.138663    0.056934    0.013862    0.779665    
#> 094: 0.372281    1.035696    3.423867    0.138719    0.054087    0.013391    0.784352    
#> 095: 0.379423    1.041814    3.433615    0.131783    0.073753    0.012807    0.784178    
#> 096: 0.358077    1.034561    3.431154    0.125916    0.079312    0.012167    0.764826    
#> 097: 0.424640    1.055201    3.443535    0.144480    0.075346    0.013414    0.753706    
#> 098: 0.415643    1.050372    3.444532    0.156425    0.075529    0.012743    0.757412    
#> 099: 0.406364    1.010560    3.434526    0.175895    0.077126    0.015309    0.750738    
#> 100: 0.407136    1.038344    3.436535    0.167100    0.081804    0.014543    0.741874    
#> 101: 0.397879    1.010587    3.429171    0.158745    0.077714    0.015676    0.739285    
#> 102: 0.402513    1.006181    3.433399    0.150808    0.073828    0.014892    0.753921    
#> 103: 0.414925    0.999080    3.445086    0.144385    0.070137    0.014147    0.745331    
#> 104: 0.441474    1.010365    3.464707    0.156288    0.081117    0.013440    0.775325    
#> 105: 0.458940    0.983086    3.467730    0.160758    0.077061    0.012997    0.771049    
#> 106: 0.471183    0.996570    3.458542    0.175437    0.073208    0.016019    0.745647    
#> 107: 0.456690    1.008415    3.455957    0.212160    0.069547    0.015218    0.744095    
#> 108: 0.433266    1.024465    3.448532    0.201552    0.072406    0.014457    0.755572    
#> 109: 0.451842    1.015609    3.462510    0.191475    0.068785    0.013734    0.759455    
#> 110: 0.459089    1.008821    3.444838    0.181901    0.065346    0.013119    0.753961    
#> 111: 0.451611    1.012064    3.448560    0.172806    0.062079    0.013833    0.740484    
#> 112: 0.419314    0.984684    3.444079    0.164166    0.063269    0.014633    0.761555    
#> 113: 0.453477    1.012668    3.451953    0.179663    0.065990    0.013901    0.748928    
#> 114: 0.457008    1.011271    3.457151    0.196571    0.062690    0.013762    0.749156    
#> 115: 0.512619    0.968929    3.462040    0.235667    0.059556    0.013074    0.763010    
#> 116: 0.485283    0.990046    3.469447    0.223884    0.067531    0.014663    0.758165    
#> 117: 0.458945    1.013520    3.468491    0.212689    0.068191    0.014242    0.752876    
#> 118: 0.475973    0.999398    3.456761    0.202055    0.068005    0.013530    0.759608    
#> 119: 0.457301    0.996734    3.457196    0.191952    0.068428    0.012853    0.770473    
#> 120: 0.469507    0.982497    3.465006    0.182355    0.081794    0.013030    0.749793    
#> 121: 0.475425    1.018945    3.467048    0.173237    0.090100    0.012379    0.750106    
#> 122: 0.481119    0.978901    3.478631    0.164575    0.085595    0.012227    0.754675    
#> 123: 0.495587    1.004846    3.470225    0.156346    0.081316    0.011840    0.754727    
#> 124: 0.501454    1.015743    3.466290    0.153253    0.077250    0.013188    0.760455    
#> 125: 0.527253    0.999281    3.473473    0.164174    0.073387    0.016011    0.740776    
#> 126: 0.441539    1.006605    3.444450    0.190583    0.069718    0.015682    0.751717    
#> 127: 0.448046    1.018612    3.443188    0.194471    0.066232    0.014898    0.750547    
#> 128: 0.445526    0.992521    3.462716    0.184747    0.074349    0.014153    0.749451    
#> 129: 0.483701    0.991607    3.469057    0.175510    0.070631    0.013446    0.756184    
#> 130: 0.511525    0.996992    3.470542    0.166734    0.077412    0.012773    0.729532    
#> 131: 0.464878    0.994944    3.460695    0.158398    0.073541    0.012135    0.773563    
#> 132: 0.430597    1.004739    3.443800    0.151964    0.069864    0.011528    0.786833    
#> 133: 0.439619    0.985140    3.447947    0.158614    0.066371    0.010952    0.800229    
#> 134: 0.495250    0.975413    3.468231    0.150683    0.065383    0.010404    0.769114    
#> 135: 0.477037    0.975360    3.475340    0.149961    0.082265    0.009929    0.768348    
#> 136: 0.455424    0.969966    3.464397    0.142463    0.097911    0.009432    0.749482    
#> 137: 0.499668    0.968265    3.468978    0.159737    0.093015    0.012008    0.756181    
#> 138: 0.477067    0.990835    3.471223    0.169829    0.088364    0.013807    0.740063    
#> 139: 0.488797    1.012175    3.474327    0.161337    0.083946    0.014810    0.752757    
#> 140: 0.484799    0.987702    3.480535    0.153270    0.083047    0.016658    0.763626    
#> 141: 0.485866    0.962736    3.485788    0.145607    0.078895    0.015825    0.752651    
#> 142: 0.516662    0.961536    3.487944    0.166776    0.074950    0.018640    0.754768    
#> 143: 0.475156    0.993598    3.485372    0.158437    0.071203    0.023785    0.775636    
#> 144: 0.495702    0.988430    3.492288    0.150515    0.067643    0.022596    0.751875    
#> 145: 0.459229    1.006046    3.463667    0.142989    0.064260    0.021466    0.751940    
#> 146: 0.432601    1.006893    3.465690    0.149986    0.063865    0.020393    0.754249    
#> 147: 0.423833    0.981689    3.461561    0.150975    0.064355    0.019373    0.745720    
#> 148: 0.448509    0.990434    3.475277    0.159266    0.067682    0.018405    0.753047    
#> 149: 0.459835    0.981210    3.461810    0.151303    0.064298    0.017484    0.781270    
#> 150: 0.458082    0.983615    3.455436    0.143738    0.067707    0.016610    0.789390    
#> 151: 0.433785    1.014751    3.454980    0.148296    0.064321    0.015780    0.765504    
#> 152: 0.433154    1.015902    3.467485    0.153613    0.064415    0.013596    0.756831    
#> 153: 0.435650    1.019997    3.467385    0.131271    0.082217    0.015128    0.780790    
#> 154: 0.431150    1.034938    3.459764    0.114381    0.082760    0.012737    0.777475    
#> 155: 0.419326    0.984959    3.448783    0.119762    0.071722    0.012083    0.765643    
#> 156: 0.417769    0.984248    3.469505    0.119861    0.071012    0.013988    0.771246    
#> 157: 0.482246    0.980194    3.482536    0.158640    0.076631    0.013614    0.766580    
#> 158: 0.507947    1.010673    3.473560    0.138028    0.070214    0.015374    0.764685    
#> 159: 0.449658    1.014167    3.477282    0.153443    0.065778    0.013983    0.758196    
#> 160: 0.497154    0.975510    3.475791    0.169681    0.062263    0.012046    0.762336    
#> 161: 0.481963    0.983512    3.468154    0.181706    0.067580    0.013731    0.756821    
#> 162: 0.448862    0.999006    3.451531    0.173078    0.061567    0.014373    0.751796    
#> 163: 0.472302    1.002622    3.457832    0.160908    0.062208    0.014630    0.742134    
#> 164: 0.465544    1.024164    3.456840    0.154877    0.069060    0.014638    0.752861    
#> 165: 0.481981    1.003793    3.464038    0.174404    0.066754    0.015139    0.741588    
#> 166: 0.497142    1.014139    3.464305    0.167876    0.075532    0.015659    0.737180    
#> 167: 0.477577    1.013922    3.467128    0.189426    0.061673    0.014423    0.755807    
#> 168: 0.453532    1.023566    3.453785    0.202312    0.080243    0.012734    0.760544    
#> 169: 0.451665    1.057846    3.452112    0.149733    0.075486    0.012923    0.786123    
#> 170: 0.474113    1.009205    3.460399    0.146797    0.072401    0.011116    0.746542    
#> 171: 0.421675    1.009954    3.457762    0.112891    0.057026    0.011629    0.757562    
#> 172: 0.431609    1.021607    3.452724    0.085527    0.063072    0.009609    0.782189    
#> 173: 0.447550    1.025674    3.447482    0.111380    0.078462    0.009482    0.771743    
#> 174: 0.460721    1.003302    3.464889    0.127105    0.071725    0.009061    0.783454    
#> 175: 0.431758    1.028578    3.444040    0.115785    0.081073    0.009707    0.790716    
#> 176: 0.425636    1.027160    3.447888    0.122980    0.069170    0.008296    0.769770    
#> 177: 0.455353    1.014409    3.461331    0.126160    0.070613    0.010307    0.754637    
#> 178: 0.470118    0.998230    3.468926    0.102574    0.076620    0.008299    0.763590    
#> 179: 0.475106    1.007808    3.468763    0.116912    0.080919    0.009126    0.777114    
#> 180: 0.449028    0.994899    3.468127    0.077508    0.073960    0.007040    0.780066    
#> 181: 0.440770    0.974482    3.454340    0.080808    0.071809    0.008803    0.784972    
#> 182: 0.397621    0.993120    3.443147    0.094786    0.080699    0.009233    0.802584    
#> 183: 0.413607    1.006646    3.440131    0.099050    0.072961    0.011875    0.793603    
#> 184: 0.403183    1.015954    3.443872    0.117667    0.079929    0.010070    0.770713    
#> 185: 0.390389    1.033089    3.440091    0.115421    0.070052    0.010037    0.753540    
#> 186: 0.430430    1.029340    3.452635    0.100044    0.065513    0.010783    0.763203    
#> 187: 0.459645    1.011289    3.466394    0.137368    0.071586    0.010985    0.780939    
#> 188: 0.424843    1.024942    3.457959    0.094507    0.075172    0.009611    0.802922    
#> 189: 0.451388    1.030554    3.456769    0.115095    0.075252    0.009293    0.799557    
#> 190: 0.431343    1.012641    3.459046    0.099910    0.071311    0.009810    0.786366    
#> 191: 0.411989    1.003028    3.451061    0.108916    0.059358    0.009980    0.767518    
#> 192: 0.431816    1.030533    3.448568    0.121409    0.065998    0.008752    0.753943    
#> 193: 0.435967    1.037644    3.442685    0.116758    0.063849    0.009346    0.747716    
#> 194: 0.429440    1.025158    3.432024    0.140471    0.068679    0.011061    0.787677    
#> 195: 0.373688    1.017131    3.441118    0.119883    0.085724    0.011465    0.760601    
#> 196: 0.387162    1.014542    3.452319    0.131534    0.085048    0.012918    0.775225    
#> 197: 0.408401    1.020301    3.467102    0.122180    0.073797    0.014027    0.769643    
#> 198: 0.484486    0.995992    3.463547    0.151000    0.061646    0.015580    0.761013    
#> 199: 0.444589    0.984586    3.469923    0.140699    0.051794    0.015136    0.754501    
#> 200: 0.480617    0.970072    3.477792    0.161148    0.060549    0.014884    0.772857    
#> 201: 0.477324    0.964814    3.480910    0.156068    0.054923    0.016727    0.774824    
#> 202: 0.485118    0.967623    3.479498    0.162206    0.056438    0.017191    0.773663    
#> 203: 0.492665    0.968402    3.479583    0.165608    0.057661    0.017483    0.773494    
#> 204: 0.501810    0.963235    3.482661    0.173419    0.060413    0.017803    0.774451    
#> 205: 0.504145    0.967953    3.484664    0.181587    0.060693    0.018401    0.776102    
#> 206: 0.502162    0.972706    3.484225    0.184006    0.060592    0.018795    0.777986    
#> 207: 0.494590    0.972836    3.481765    0.188079    0.060920    0.018757    0.775910    
#> 208: 0.492809    0.974777    3.480374    0.185213    0.061125    0.018521    0.773753    
#> 209: 0.495134    0.973593    3.479722    0.183859    0.061504    0.018388    0.771281    
#> 210: 0.497289    0.973507    3.479720    0.182713    0.060505    0.018215    0.769065    
#> 211: 0.499072    0.974171    3.480348    0.181219    0.060107    0.017961    0.767638    
#> 212: 0.500445    0.973566    3.480466    0.180112    0.059913    0.018004    0.767449    
#> 213: 0.502336    0.971197    3.480922    0.176962    0.059649    0.017866    0.768474    
#> 214: 0.503927    0.970561    3.481526    0.175691    0.058759    0.017550    0.769991    
#> 215: 0.502864    0.971329    3.481157    0.173938    0.057824    0.017362    0.770787    
#> 216: 0.502514    0.971047    3.480548    0.172481    0.058347    0.017363    0.771990    
#> 217: 0.502801    0.972916    3.480684    0.169395    0.058692    0.017381    0.770780    
#> 218: 0.501167    0.974585    3.480061    0.167424    0.059350    0.017356    0.768766    
#> 219: 0.499542    0.975352    3.478526    0.166004    0.059133    0.017209    0.768023    
#> 220: 0.497063    0.977317    3.477582    0.166173    0.059380    0.016903    0.767634    
#> 221: 0.495520    0.978569    3.476568    0.166293    0.060129    0.016738    0.767390    
#> 222: 0.493808    0.978727    3.475623    0.165559    0.060793    0.016701    0.767924    
#> 223: 0.494943    0.978425    3.475408    0.165117    0.060993    0.016589    0.768419    
#> 224: 0.496278    0.979185    3.475398    0.163637    0.061166    0.016467    0.768015    
#> 225: 0.495809    0.977790    3.475709    0.162189    0.061615    0.016385    0.768032    
#> 226: 0.495941    0.976540    3.475548    0.160995    0.061691    0.016299    0.768639    
#> 227: 0.494368    0.977245    3.475410    0.160672    0.061877    0.016145    0.768156    
#> 228: 0.491327    0.978813    3.474206    0.160880    0.062528    0.015971    0.767525    
#> 229: 0.488599    0.979494    3.473471    0.160486    0.062833    0.015959    0.766873    
#> 230: 0.486455    0.979774    3.472746    0.159757    0.063141    0.015982    0.766345    
#> 231: 0.485677    0.981546    3.472094    0.159496    0.063521    0.015837    0.766365    
#> 232: 0.484371    0.982209    3.472001    0.158366    0.063586    0.015798    0.766711    
#> 233: 0.483638    0.981846    3.472022    0.158908    0.063522    0.015809    0.766086    
#> 234: 0.482770    0.981883    3.471935    0.159555    0.063611    0.015885    0.765334    
#> 235: 0.482907    0.981494    3.471983    0.159093    0.063599    0.015942    0.764801    
#> 236: 0.482527    0.981897    3.471984    0.158975    0.063457    0.015971    0.765194    
#> 237: 0.484076    0.981901    3.472331    0.158848    0.063313    0.015925    0.766295    
#> 238: 0.484899    0.981616    3.472647    0.159410    0.063304    0.015985    0.766705    
#> 239: 0.484204    0.982633    3.472480    0.158746    0.063349    0.016089    0.766126    
#> 240: 0.484085    0.982529    3.472667    0.158596    0.063083    0.016110    0.765748    
#> 241: 0.484015    0.982121    3.472846    0.158620    0.062990    0.016068    0.765374    
#> 242: 0.483548    0.981511    3.472605    0.158158    0.063209    0.016025    0.765924    
#> 243: 0.482493    0.981614    3.472742    0.157404    0.063467    0.015946    0.766621    
#> 244: 0.482166    0.981622    3.472898    0.157723    0.063408    0.015916    0.767107    
#> 245: 0.482483    0.981568    3.473161    0.156888    0.063411    0.015804    0.767547    
#> 246: 0.482458    0.981313    3.473318    0.156821    0.063628    0.015742    0.767782    
#> 247: 0.482352    0.981459    3.473665    0.156291    0.063990    0.015704    0.767706    
#> 248: 0.482803    0.981644    3.473750    0.156199    0.064217    0.015645    0.767388    
#> 249: 0.482747    0.981737    3.473767    0.156422    0.064389    0.015579    0.766978    
#> 250: 0.483181    0.982484    3.473876    0.155868    0.064578    0.015564    0.767140    
#> 251: 0.483276    0.982993    3.474095    0.155639    0.064798    0.015494    0.767352    
#> 252: 0.483649    0.982909    3.474570    0.155115    0.064933    0.015463    0.767357    
#> 253: 0.483851    0.982569    3.474922    0.155363    0.064823    0.015524    0.767443    
#> 254: 0.484528    0.982603    3.475298    0.155514    0.064620    0.015525    0.767374    
#> 255: 0.484566    0.982864    3.475337    0.155993    0.064539    0.015466    0.767415    
#> 256: 0.484806    0.982535    3.475403    0.155449    0.064698    0.015456    0.767117    
#> 257: 0.485222    0.982155    3.475498    0.155630    0.064993    0.015472    0.766803    
#> 258: 0.485471    0.981760    3.475575    0.155114    0.065106    0.015457    0.766615    
#> 259: 0.485501    0.981556    3.475575    0.155447    0.065094    0.015413    0.766761    
#> 260: 0.485433    0.981379    3.475881    0.155131    0.065242    0.015384    0.766645    
#> 261: 0.485622    0.981218    3.476110    0.154831    0.065525    0.015345    0.766601    
#> 262: 0.486487    0.981101    3.476389    0.154776    0.065457    0.015282    0.766556    
#> 263: 0.486422    0.981427    3.476410    0.154797    0.065503    0.015222    0.766819    
#> 264: 0.485889    0.981930    3.476184    0.155088    0.065579    0.015215    0.766898    
#> 265: 0.485821    0.982281    3.476110    0.155930    0.065651    0.015206    0.766792    
#> 266: 0.486389    0.982396    3.476128    0.156751    0.065658    0.015238    0.766635    
#> 267: 0.486881    0.982435    3.476241    0.157658    0.065659    0.015214    0.766416    
#> 268: 0.486826    0.982165    3.476135    0.157642    0.065547    0.015163    0.766367    
#> 269: 0.487319    0.982065    3.476174    0.157672    0.065533    0.015203    0.766264    
#> 270: 0.487882    0.982381    3.475973    0.157487    0.065367    0.015212    0.766064    
#> 271: 0.487754    0.982544    3.475758    0.157560    0.065265    0.015237    0.765971    
#> 272: 0.487553    0.982300    3.475568    0.157684    0.065034    0.015258    0.766183    
#> 273: 0.487287    0.982725    3.475400    0.158177    0.064878    0.015276    0.766237    
#> 274: 0.486461    0.983317    3.475103    0.158329    0.064927    0.015265    0.766382    
#> 275: 0.486075    0.983801    3.474769    0.158147    0.064963    0.015264    0.766367    
#> 276: 0.485623    0.984407    3.474717    0.158573    0.064980    0.015244    0.766486    
#> 277: 0.485429    0.984784    3.474819    0.158804    0.065158    0.015221    0.766386    
#> 278: 0.485527    0.984594    3.474948    0.158643    0.065158    0.015220    0.766299    
#> 279: 0.485371    0.984408    3.475004    0.158101    0.065395    0.015187    0.766626    
#> 280: 0.485303    0.984509    3.475077    0.157428    0.065490    0.015190    0.766635    
#> 281: 0.485071    0.984551    3.475109    0.156711    0.065455    0.015218    0.766662    
#> 282: 0.485447    0.984703    3.475277    0.156639    0.065311    0.015235    0.766994    
#> 283: 0.485801    0.984710    3.475352    0.156708    0.065311    0.015282    0.767153    
#> 284: 0.485516    0.984611    3.475360    0.156869    0.065329    0.015295    0.766806    
#> 285: 0.485427    0.984784    3.475064    0.157115    0.065188    0.015324    0.766680    
#> 286: 0.485165    0.985044    3.474914    0.157266    0.065070    0.015351    0.766638    
#> 287: 0.485105    0.985302    3.474841    0.157326    0.064957    0.015337    0.766668    
#> 288: 0.485195    0.985190    3.474838    0.157391    0.064942    0.015375    0.766570    
#> 289: 0.485254    0.985157    3.474718    0.157737    0.065004    0.015404    0.766655    
#> 290: 0.485064    0.985346    3.474588    0.157818    0.065002    0.015431    0.767015    
#> 291: 0.485108    0.985738    3.474549    0.157947    0.065016    0.015444    0.766954    
#> 292: 0.485223    0.985712    3.474540    0.158243    0.064977    0.015439    0.766809    
#> 293: 0.485264    0.985775    3.474469    0.158315    0.064875    0.015435    0.766603    
#> 294: 0.485135    0.985768    3.474359    0.158387    0.064828    0.015429    0.766340    
#> 295: 0.485012    0.985500    3.474233    0.158221    0.064752    0.015406    0.766333    
#> 296: 0.484723    0.985592    3.474153    0.158186    0.064763    0.015392    0.766387    
#> 297: 0.484856    0.985738    3.474132    0.157970    0.064626    0.015398    0.766384    
#> 298: 0.485038    0.985768    3.474060    0.158504    0.064443    0.015420    0.766118    
#> 299: 0.485193    0.986063    3.473918    0.158955    0.064363    0.015428    0.765898    
#> 300: 0.485639    0.986006    3.474035    0.159240    0.064312    0.015450    0.765569    
#> 301: 0.485937    0.985939    3.473998    0.159541    0.064276    0.015435    0.765483    
#> 302: 0.486071    0.985970    3.474011    0.159446    0.064242    0.015385    0.765214    
#> 303: 0.485669    0.986221    3.473892    0.159167    0.064209    0.015334    0.765063    
#> 304: 0.485663    0.986531    3.473762    0.159142    0.064185    0.015310    0.764975    
#> 305: 0.485089    0.986514    3.473640    0.159060    0.064047    0.015307    0.764969    
#> 306: 0.484291    0.986540    3.473484    0.158896    0.064033    0.015320    0.764978    
#> 307: 0.483853    0.986668    3.473231    0.158756    0.063989    0.015321    0.765369    
#> 308: 0.483363    0.986651    3.473154    0.158837    0.063968    0.015303    0.765657    
#> 309: 0.483203    0.986434    3.473040    0.158816    0.064031    0.015272    0.765646    
#> 310: 0.483314    0.986443    3.472917    0.159014    0.064110    0.015240    0.765615    
#> 311: 0.483497    0.986483    3.472954    0.159319    0.064035    0.015218    0.765460    
#> 312: 0.483517    0.986534    3.472893    0.159484    0.064035    0.015198    0.765328    
#> 313: 0.483185    0.986308    3.472833    0.159274    0.064115    0.015166    0.765335    
#> 314: 0.482828    0.986385    3.472755    0.159494    0.064140    0.015126    0.765341    
#> 315: 0.482666    0.986504    3.472729    0.159578    0.064126    0.015109    0.765338    
#> 316: 0.482445    0.986685    3.472594    0.159508    0.064178    0.015066    0.765245    
#> 317: 0.482187    0.986829    3.472462    0.159259    0.064262    0.015022    0.765308    
#> 318: 0.482134    0.987177    3.472262    0.159134    0.064287    0.015017    0.765162    
#> 319: 0.482141    0.987208    3.472255    0.159238    0.064246    0.015019    0.764994    
#> 320: 0.481649    0.987322    3.472109    0.159466    0.064357    0.015008    0.764804    
#> 321: 0.481180    0.987366    3.471989    0.159519    0.064391    0.014996    0.764903    
#> 322: 0.481042    0.987589    3.471844    0.159341    0.064414    0.014970    0.764893    
#> 323: 0.480431    0.987590    3.471750    0.159232    0.064514    0.014969    0.765109    
#> 324: 0.480325    0.987775    3.471692    0.159106    0.064601    0.014954    0.765014    
#> 325: 0.480125    0.987954    3.471540    0.158910    0.064640    0.014941    0.764913    
#> 326: 0.479877    0.987838    3.471457    0.158849    0.064597    0.014937    0.764787    
#> 327: 0.479899    0.987933    3.471499    0.158872    0.064588    0.014952    0.764682    
#> 328: 0.480053    0.988033    3.471515    0.158807    0.064551    0.014955    0.764490    
#> 329: 0.480181    0.988053    3.471535    0.158865    0.064496    0.014969    0.764371    
#> 330: 0.479866    0.988230    3.471409    0.158808    0.064554    0.014979    0.764277    
#> 331: 0.479852    0.988361    3.471352    0.158769    0.064590    0.014958    0.764194    
#> 332: 0.479596    0.988393    3.471352    0.158929    0.064559    0.014957    0.764119    
#> 333: 0.479440    0.988449    3.471269    0.159025    0.064468    0.014945    0.764113    
#> 334: 0.479019    0.988473    3.471001    0.159029    0.064379    0.014952    0.764015    
#> 335: 0.478402    0.988526    3.470794    0.158862    0.064338    0.014960    0.764145    
#> 336: 0.478092    0.988647    3.470718    0.158643    0.064255    0.014983    0.764253    
#> 337: 0.478093    0.988950    3.470734    0.158674    0.064197    0.014975    0.764243    
#> 338: 0.478178    0.988866    3.470863    0.158627    0.064175    0.014989    0.764253    
#> 339: 0.478196    0.989057    3.470901    0.158569    0.064190    0.015000    0.764109    
#> 340: 0.478103    0.989057    3.470889    0.158399    0.064224    0.015008    0.763931    
#> 341: 0.478034    0.989095    3.470883    0.158168    0.064251    0.015000    0.763925    
#> 342: 0.477705    0.988866    3.470900    0.157902    0.064333    0.014990    0.763935    
#> 343: 0.477325    0.988872    3.470879    0.157797    0.064390    0.014984    0.763927    
#> 344: 0.477324    0.988744    3.470866    0.157720    0.064425    0.014972    0.763932    
#> 345: 0.477396    0.988685    3.470866    0.157692    0.064474    0.014974    0.763808    
#> 346: 0.477318    0.988830    3.470759    0.157548    0.064442    0.014970    0.763693    
#> 347: 0.477190    0.988924    3.470655    0.157509    0.064415    0.014989    0.763744    
#> 348: 0.476761    0.989124    3.470547    0.157462    0.064464    0.014988    0.763744    
#> 349: 0.476477    0.989032    3.470485    0.157496    0.064489    0.014989    0.763686    
#> 350: 0.476118    0.988939    3.470318    0.157628    0.064420    0.015007    0.763657    
#> 351: 0.476000    0.989173    3.470202    0.157821    0.064441    0.015017    0.763612    
#> 352: 0.475647    0.989378    3.470091    0.158019    0.064439    0.015027    0.763815    
#> 353: 0.475338    0.989746    3.469958    0.157869    0.064460    0.015035    0.763851    
#> 354: 0.475250    0.989891    3.469780    0.157735    0.064414    0.015049    0.763788    
#> 355: 0.475441    0.989794    3.469769    0.157731    0.064411    0.015060    0.763726    
#> 356: 0.475417    0.989757    3.469777    0.157855    0.064423    0.015071    0.763789    
#> 357: 0.475717    0.989788    3.469832    0.158010    0.064455    0.015064    0.763665    
#> 358: 0.475690    0.989941    3.469815    0.158071    0.064538    0.015042    0.763586    
#> 359: 0.475573    0.990094    3.469760    0.158066    0.064593    0.015015    0.763523    
#> 360: 0.475339    0.990240    3.469608    0.158168    0.064644    0.014987    0.763369    
#> 361: 0.474953    0.990386    3.469478    0.158323    0.064637    0.014961    0.763392    
#> 362: 0.474795    0.990500    3.469320    0.158380    0.064617    0.014943    0.763243    
#> 363: 0.474853    0.990570    3.469269    0.158462    0.064607    0.014950    0.763059    
#> 364: 0.474965    0.990692    3.469285    0.158283    0.064649    0.014934    0.763143    
#> 365: 0.474863    0.990678    3.469311    0.158114    0.064705    0.014919    0.763195    
#> 366: 0.474928    0.990709    3.469298    0.158200    0.064667    0.014915    0.763258    
#> 367: 0.474827    0.990770    3.469288    0.158164    0.064587    0.014893    0.763235    
#> 368: 0.474906    0.990842    3.469243    0.157845    0.064576    0.014899    0.763169    
#> 369: 0.474867    0.990863    3.469205    0.157469    0.064636    0.014891    0.763243    
#> 370: 0.474715    0.991058    3.469140    0.157101    0.064750    0.014866    0.763241    
#> 371: 0.474590    0.991086    3.468987    0.157080    0.064725    0.014852    0.763249    
#> 372: 0.474527    0.991136    3.468944    0.157137    0.064694    0.014845    0.763158    
#> 373: 0.474371    0.991345    3.468852    0.157202    0.064743    0.014844    0.763019    
#> 374: 0.474360    0.991292    3.468789    0.157240    0.064734    0.014829    0.762885    
#> 375: 0.474474    0.991255    3.468812    0.157268    0.064787    0.014818    0.762883    
#> 376: 0.474420    0.991246    3.468788    0.157276    0.064742    0.014812    0.762808    
#> 377: 0.474409    0.991309    3.468794    0.157315    0.064733    0.014803    0.762763    
#> 378: 0.474343    0.991293    3.468803    0.157484    0.064776    0.014789    0.762732    
#> 379: 0.474118    0.991233    3.468786    0.157555    0.064797    0.014783    0.762596    
#> 380: 0.473861    0.991221    3.468738    0.157580    0.064842    0.014768    0.762580    
#> 381: 0.473481    0.991274    3.468596    0.157485    0.064857    0.014744    0.762570    
#> 382: 0.473394    0.991371    3.468520    0.157515    0.064845    0.014731    0.762448    
#> 383: 0.473426    0.991409    3.468504    0.157433    0.064906    0.014717    0.762327    
#> 384: 0.473239    0.991320    3.468525    0.157389    0.064804    0.014717    0.762354    
#> 385: 0.473231    0.991310    3.468567    0.157427    0.064808    0.014726    0.762454    
#> 386: 0.473377    0.991464    3.468622    0.157515    0.064814    0.014736    0.762500    
#> 387: 0.473500    0.991546    3.468687    0.157422    0.064804    0.014728    0.762532    
#> 388: 0.473447    0.991600    3.468711    0.157265    0.064747    0.014713    0.762489    
#> 389: 0.473366    0.991588    3.468670    0.157045    0.064739    0.014697    0.762570    
#> 390: 0.473231    0.991688    3.468605    0.156909    0.064724    0.014695    0.762576    
#> 391: 0.473191    0.991618    3.468633    0.156721    0.064715    0.014683    0.762623    
#> 392: 0.473192    0.991663    3.468664    0.156669    0.064799    0.014683    0.762617    
#> 393: 0.473054    0.991595    3.468578    0.156676    0.064849    0.014675    0.762526    
#> 394: 0.472849    0.991669    3.468441    0.156612    0.064843    0.014664    0.762496    
#> 395: 0.472934    0.991707    3.468368    0.156486    0.064867    0.014646    0.762417    
#> 396: 0.473010    0.991766    3.468336    0.156458    0.064900    0.014630    0.762339    
#> 397: 0.473135    0.991764    3.468359    0.156431    0.064921    0.014613    0.762358    
#> 398: 0.473368    0.991686    3.468392    0.156459    0.064958    0.014606    0.762375    
#> 399: 0.473572    0.991637    3.468469    0.156499    0.065004    0.014600    0.762362    
#> 400: 0.473518    0.991634    3.468507    0.156355    0.065039    0.014588    0.762392    
#> 401: 0.473437    0.991725    3.468480    0.156334    0.065105    0.014569    0.762390    
#> 402: 0.473340    0.991870    3.468459    0.156209    0.065117    0.014561    0.762401    
#> 403: 0.473439    0.991893    3.468421    0.156276    0.065124    0.014539    0.762366    
#> 404: 0.473356    0.991973    3.468328    0.156358    0.065152    0.014518    0.762302    
#> 405: 0.473326    0.992062    3.468327    0.156433    0.065110    0.014518    0.762268    
#> 406: 0.473325    0.992094    3.468268    0.156534    0.065064    0.014509    0.762318    
#> 407: 0.473400    0.992078    3.468327    0.156497    0.065013    0.014502    0.762347    
#> 408: 0.473505    0.992146    3.468379    0.156497    0.064973    0.014484    0.762462    
#> 409: 0.473442    0.992108    3.468343    0.156461    0.064999    0.014469    0.762458    
#> 410: 0.473355    0.992083    3.468255    0.156358    0.065058    0.014450    0.762510    
#> 411: 0.473434    0.991882    3.468233    0.156260    0.065135    0.014435    0.762585    
#> 412: 0.473446    0.991889    3.468197    0.156146    0.065200    0.014406    0.762612    
#> 413: 0.473293    0.991947    3.468126    0.155967    0.065258    0.014378    0.762652    
#> 414: 0.473183    0.991852    3.468190    0.155812    0.065234    0.014387    0.762639    
#> 415: 0.473218    0.991811    3.468203    0.155713    0.065241    0.014378    0.762601    
#> 416: 0.473266    0.991894    3.468205    0.155770    0.065219    0.014378    0.762520    
#> 417: 0.473361    0.991857    3.468239    0.155747    0.065214    0.014386    0.762450    
#> 418: 0.473296    0.991904    3.468274    0.155791    0.065235    0.014391    0.762346    
#> 419: 0.473255    0.991969    3.468279    0.155940    0.065191    0.014402    0.762273    
#> 420: 0.473233    0.991961    3.468277    0.155944    0.065197    0.014395    0.762159    
#> 421: 0.473075    0.991966    3.468300    0.155985    0.065215    0.014383    0.762067    
#> 422: 0.473153    0.991832    3.468324    0.156028    0.065181    0.014374    0.762056    
#> 423: 0.473210    0.991771    3.468334    0.155952    0.065199    0.014361    0.762041    
#> 424: 0.473069    0.991751    3.468299    0.155972    0.065192    0.014346    0.761941    
#> 425: 0.473132    0.991886    3.468268    0.155880    0.065215    0.014347    0.761911    
#> 426: 0.473124    0.991893    3.468263    0.155769    0.065215    0.014332    0.761887    
#> 427: 0.473009    0.991868    3.468256    0.155536    0.065162    0.014317    0.761915    
#> 428: 0.472837    0.991912    3.468258    0.155404    0.065118    0.014294    0.761977    
#> 429: 0.472838    0.992000    3.468286    0.155181    0.065192    0.014268    0.762053    
#> 430: 0.472702    0.992109    3.468251    0.155095    0.065211    0.014251    0.762210    
#> 431: 0.472555    0.992128    3.468201    0.154933    0.065209    0.014236    0.762274    
#> 432: 0.472503    0.992193    3.468166    0.154731    0.065252    0.014226    0.762406    
#> 433: 0.472571    0.992302    3.468204    0.154612    0.065281    0.014231    0.762496    
#> 434: 0.472423    0.992201    3.468209    0.154581    0.065254    0.014228    0.762615    
#> 435: 0.472318    0.992161    3.468174    0.154425    0.065277    0.014214    0.762611    
#> 436: 0.472173    0.992101    3.468188    0.154244    0.065363    0.014199    0.762647    
#> 437: 0.472104    0.992059    3.468217    0.154275    0.065370    0.014196    0.762603    
#> 438: 0.472172    0.992144    3.468248    0.154329    0.065342    0.014190    0.762611    
#> 439: 0.472245    0.992278    3.468272    0.154286    0.065347    0.014180    0.762540    
#> 440: 0.472204    0.992347    3.468247    0.154314    0.065379    0.014164    0.762508    
#> 441: 0.472147    0.992355    3.468232    0.154327    0.065402    0.014162    0.762479    
#> 442: 0.472038    0.992435    3.468218    0.154391    0.065385    0.014154    0.762488    
#> 443: 0.471901    0.992522    3.468136    0.154356    0.065332    0.014147    0.762483    
#> 444: 0.471709    0.992640    3.468032    0.154407    0.065358    0.014154    0.762474    
#> 445: 0.471533    0.992703    3.467930    0.154451    0.065341    0.014174    0.762542    
#> 446: 0.471356    0.992820    3.467824    0.154507    0.065379    0.014176    0.762520    
#> 447: 0.471228    0.992973    3.467766    0.154446    0.065447    0.014168    0.762491    
#> 448: 0.471051    0.993133    3.467724    0.154366    0.065485    0.014158    0.762471    
#> 449: 0.470887    0.993265    3.467744    0.154299    0.065524    0.014142    0.762536    
#> 450: 0.470974    0.993265    3.467737    0.154201    0.065569    0.014144    0.762563    
#> 451: 0.471197    0.993268    3.467726    0.154264    0.065626    0.014135    0.762636    
#> 452: 0.471190    0.993320    3.467693    0.154324    0.065687    0.014126    0.762582    
#> 453: 0.471098    0.993298    3.467656    0.154335    0.065730    0.014122    0.762509    
#> 454: 0.471078    0.993392    3.467632    0.154256    0.065744    0.014109    0.762484    
#> 455: 0.470980    0.993467    3.467611    0.154137    0.065761    0.014098    0.762496    
#> 456: 0.470903    0.993501    3.467599    0.154025    0.065752    0.014083    0.762458    
#> 457: 0.470801    0.993523    3.467614    0.153973    0.065768    0.014076    0.762421    
#> 458: 0.470697    0.993697    3.467607    0.153882    0.065859    0.014072    0.762440    
#> 459: 0.470464    0.993912    3.467515    0.153867    0.065936    0.014074    0.762401    
#> 460: 0.470378    0.993973    3.467448    0.153947    0.065923    0.014069    0.762358    
#> 461: 0.470247    0.994023    3.467423    0.153938    0.065941    0.014065    0.762334    
#> 462: 0.470053    0.994079    3.467419    0.153945    0.065958    0.014064    0.762288    
#> 463: 0.470014    0.994127    3.467409    0.153918    0.065975    0.014061    0.762277    
#> 464: 0.470065    0.994169    3.467428    0.153951    0.065982    0.014056    0.762192    
#> 465: 0.470026    0.993994    3.467453    0.154060    0.065992    0.014048    0.762271    
#> 466: 0.470066    0.993999    3.467423    0.154021    0.066001    0.014035    0.762228    
#> 467: 0.470009    0.993983    3.467394    0.154051    0.065988    0.014025    0.762112    
#> 468: 0.470152    0.994011    3.467415    0.154149    0.065964    0.014013    0.762138    
#> 469: 0.470195    0.994155    3.467419    0.154192    0.065956    0.013993    0.762255    
#> 470: 0.470059    0.994197    3.467386    0.154218    0.065938    0.013981    0.762284    
#> 471: 0.470077    0.994116    3.467407    0.154130    0.065886    0.013976    0.762354    
#> 472: 0.470172    0.994057    3.467484    0.154041    0.065892    0.013971    0.762403    
#> 473: 0.470089    0.994045    3.467501    0.153994    0.065867    0.013970    0.762393    
#> 474: 0.470002    0.993966    3.467484    0.153957    0.065826    0.013987    0.762471    
#> 475: 0.469984    0.994108    3.467464    0.153949    0.065822    0.014000    0.762487    
#> 476: 0.470061    0.994133    3.467457    0.153963    0.065806    0.014007    0.762460    
#> 477: 0.469991    0.994162    3.467475    0.154019    0.065802    0.014006    0.762360    
#> 478: 0.469920    0.994161    3.467499    0.153866    0.065772    0.014004    0.762335    
#> 479: 0.469981    0.994214    3.467509    0.153847    0.065802    0.013994    0.762330    
#> 480: 0.470063    0.994182    3.467529    0.153816    0.065814    0.013993    0.762417    
#> 481: 0.470100    0.994111    3.467551    0.153916    0.065806    0.013984    0.762396    
#> 482: 0.470210    0.994152    3.467531    0.154016    0.065814    0.013970    0.762444    
#> 483: 0.470200    0.994205    3.467527    0.153962    0.065866    0.013959    0.762397    
#> 484: 0.470235    0.994094    3.467537    0.154020    0.065875    0.013957    0.762375    
#> 485: 0.470287    0.994168    3.467548    0.153999    0.065888    0.013966    0.762358    
#> 486: 0.470309    0.994154    3.467575    0.154113    0.065893    0.013973    0.762299    
#> 487: 0.470534    0.994154    3.467636    0.154084    0.065898    0.013970    0.762275    
#> 488: 0.470604    0.994122    3.467687    0.154019    0.065910    0.013961    0.762301    
#> 489: 0.470732    0.994086    3.467683    0.154032    0.065925    0.013953    0.762356    
#> 490: 0.470936    0.994066    3.467764    0.153992    0.065906    0.013954    0.762356    
#> 491: 0.470983    0.994148    3.467806    0.153974    0.065909    0.013958    0.762329    
#> 492: 0.471042    0.994223    3.467811    0.154048    0.065901    0.013964    0.762308    
#> 493: 0.471053    0.994228    3.467818    0.154071    0.065928    0.013959    0.762290    
#> 494: 0.471151    0.994269    3.467796    0.154082    0.065975    0.013942    0.762247    
#> 495: 0.471239    0.994275    3.467811    0.154073    0.066029    0.013938    0.762252    
#> 496: 0.471323    0.994318    3.467784    0.154013    0.066054    0.013931    0.762266    
#> 497: 0.471320    0.994301    3.467817    0.154101    0.066063    0.013943    0.762275    
#> 498: 0.471392    0.994270    3.467801    0.154223    0.066068    0.013944    0.762236    
#> 499: 0.471479    0.994346    3.467784    0.154251    0.066061    0.013937    0.762211    
#> 500: 0.471540    0.994238    3.467795    0.154202    0.066103    0.013933    0.762154    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.329724    0.975466    3.445208    0.392401    0.080996    0.016800    1.664411    
#> 002: 0.450399    1.004022    3.465859    0.372781    0.076946    0.015960    1.144563    
#> 003: 0.614792    0.925022    3.485083    0.354142    0.073099    0.015162    0.865915    
#> 004: 0.604675    0.936664    3.488687    0.409416    0.069444    0.014404    0.772194    
#> 005: 0.680212    0.968742    3.467033    0.475926    0.065972    0.013684    0.717627    
#> 006: 0.677029    0.979707    3.466148    0.519561    0.063701    0.013000    0.655231    
#> 007: 0.642045    0.995014    3.468070    0.502884    0.065992    0.012350    0.664924    
#> 008: 0.657010    0.981820    3.456491    0.601635    0.065189    0.011732    0.655239    
#> 009: 0.610823    0.974035    3.456755    0.573687    0.061929    0.011146    0.657664    
#> 010: 0.606432    0.969136    3.453095    0.611017    0.058833    0.010588    0.650507    
#> 011: 0.674922    0.964444    3.458927    0.661574    0.055891    0.010059    0.660358    
#> 012: 0.716046    0.969929    3.455390    0.822527    0.056191    0.009556    0.658272    
#> 013: 0.630699    0.985198    3.458347    0.781400    0.053381    0.012477    0.668112    
#> 014: 0.684368    0.987560    3.458983    0.742330    0.053123    0.011981    0.660713    
#> 015: 0.655425    0.999867    3.458787    0.705214    0.050466    0.011382    0.650639    
#> 016: 0.672144    0.998624    3.458879    0.702449    0.047943    0.010813    0.655254    
#> 017: 0.694077    0.997355    3.468140    0.681421    0.051764    0.010273    0.642091    
#> 018: 0.688619    1.005602    3.448712    0.728183    0.061324    0.009759    0.648404    
#> 019: 0.625338    0.994764    3.448530    0.691773    0.058258    0.009271    0.644392    
#> 020: 0.649073    0.978878    3.454264    0.678657    0.057680    0.009504    0.642134    
#> 021: 0.661275    0.973698    3.458996    0.665841    0.054796    0.009029    0.637270    
#> 022: 0.639691    0.987147    3.466324    0.632549    0.052056    0.009636    0.647586    
#> 023: 0.729502    0.983754    3.476408    0.746230    0.051101    0.009837    0.646447    
#> 024: 0.723161    0.996237    3.469000    0.751236    0.052796    0.009345    0.639304    
#> 025: 0.678550    0.975470    3.456103    0.780401    0.057086    0.008878    0.648178    
#> 026: 0.672272    1.008142    3.452385    0.741381    0.069302    0.008434    0.664022    
#> 027: 0.686984    1.023925    3.452735    0.741830    0.074910    0.008063    0.665181    
#> 028: 0.703173    1.004648    3.454183    0.789668    0.071164    0.008306    0.646779    
#> 029: 0.663794    1.006036    3.445781    0.750184    0.067606    0.007891    0.657205    
#> 030: 0.648131    0.999544    3.449972    0.719162    0.064226    0.008657    0.657151    
#> 031: 0.664319    0.975658    3.456760    0.818749    0.061014    0.008224    0.654075    
#> 032: 0.657228    0.957566    3.460844    0.777812    0.061577    0.008134    0.661030    
#> 033: 0.618021    0.996501    3.457194    0.738921    0.061119    0.007727    0.661480    
#> 034: 0.661451    0.998695    3.461345    0.701975    0.058063    0.010315    0.638408    
#> 035: 0.661736    0.977771    3.461813    0.666876    0.057559    0.009799    0.633557    
#> 036: 0.694548    0.985831    3.458985    0.766252    0.065223    0.009309    0.646086    
#> 037: 0.679418    0.989477    3.460198    0.727940    0.068970    0.008844    0.657847    
#> 038: 0.688299    0.990252    3.456277    0.691543    0.075890    0.008402    0.656565    
#> 039: 0.675611    0.987656    3.467673    0.656966    0.072096    0.007982    0.655655    
#> 040: 0.716636    0.991977    3.477108    0.624117    0.079295    0.007582    0.675165    
#> 041: 0.735536    0.980959    3.478745    0.712433    0.075331    0.007203    0.659643    
#> 042: 0.754175    0.968342    3.471734    0.706980    0.071564    0.006843    0.678863    
#> 043: 0.681392    0.984036    3.462738    0.671631    0.067986    0.006501    0.661413    
#> 044: 0.685587    0.975483    3.467727    0.699976    0.066378    0.006176    0.656804    
#> 045: 0.687992    1.009449    3.462966    0.664977    0.077724    0.005867    0.655767    
#> 046: 0.655443    0.993516    3.460336    0.631728    0.073837    0.005574    0.649775    
#> 047: 0.683623    1.009973    3.450248    0.666315    0.070146    0.005309    0.645036    
#> 048: 0.676405    1.000480    3.452158    0.675908    0.066638    0.007312    0.639169    
#> 049: 0.672854    0.981089    3.461627    0.763176    0.063306    0.007211    0.645551    
#> 050: 0.674678    0.973974    3.465254    0.725017    0.060141    0.007603    0.673564    
#> 051: 0.672935    0.994512    3.455513    0.711863    0.057134    0.007223    0.670979    
#> 052: 0.666915    0.990801    3.464879    0.676269    0.067455    0.006862    0.644371    
#> 053: 0.663536    0.973759    3.462537    0.642456    0.064082    0.006522    0.646718    
#> 054: 0.658153    0.985199    3.466923    0.645611    0.061746    0.006196    0.649722    
#> 055: 0.675744    0.988282    3.464704    0.613330    0.058659    0.005886    0.663797    
#> 056: 0.672467    0.959177    3.461813    0.674812    0.066220    0.005592    0.675807    
#> 057: 0.693479    0.970880    3.465298    0.711309    0.062909    0.005518    0.688633    
#> 058: 0.667236    0.979994    3.462863    0.675743    0.059764    0.005446    0.670195    
#> 059: 0.604093    0.951686    3.461199    0.641956    0.066670    0.005462    0.669476    
#> 060: 0.639690    0.951140    3.466883    0.609858    0.069387    0.005189    0.667356    
#> 061: 0.691933    0.963881    3.468010    0.579365    0.065917    0.006008    0.665900    
#> 062: 0.666329    0.976330    3.475113    0.560389    0.064039    0.007389    0.678742    
#> 063: 0.698462    0.964850    3.466750    0.672622    0.063948    0.007020    0.678516    
#> 064: 0.695706    0.984386    3.466912    0.731815    0.070698    0.006669    0.668574    
#> 065: 0.720941    0.965832    3.455318    0.774408    0.067163    0.006936    0.652564    
#> 066: 0.682940    0.985468    3.456341    0.735688    0.065038    0.007987    0.627461    
#> 067: 0.694412    0.969114    3.454785    0.766329    0.061786    0.010583    0.644707    
#> 068: 0.665371    0.991144    3.461674    0.728013    0.062407    0.010054    0.659008    
#> 069: 0.688724    0.979731    3.461184    0.691612    0.061288    0.009551    0.660863    
#> 070: 0.656142    0.987902    3.470231    0.657031    0.061521    0.009812    0.653111    
#> 071: 0.630077    1.015778    3.451678    0.624180    0.062922    0.009322    0.672161    
#> 072: 0.606586    0.988304    3.447880    0.592971    0.059776    0.008856    0.658356    
#> 073: 0.666980    1.004306    3.455599    0.669417    0.065287    0.008413    0.661809    
#> 074: 0.681444    0.990595    3.460348    0.661597    0.067316    0.007992    0.647889    
#> 075: 0.671320    0.972806    3.479423    0.682021    0.065731    0.007593    0.660047    
#> 076: 0.698719    0.978358    3.483721    0.705427    0.064101    0.007213    0.659127    
#> 077: 0.683444    0.969502    3.472762    0.670156    0.066024    0.006852    0.649418    
#> 078: 0.672073    0.974304    3.472536    0.636648    0.062723    0.006510    0.652722    
#> 079: 0.682423    1.000114    3.469039    0.604816    0.059587    0.006184    0.683073    
#> 080: 0.674552    0.985490    3.468239    0.574575    0.072548    0.005875    0.674388    
#> 081: 0.659627    0.986756    3.464001    0.545846    0.068921    0.005581    0.679720    
#> 082: 0.662612    0.983163    3.474139    0.611366    0.065475    0.005302    0.688661    
#> 083: 0.712353    1.005815    3.469017    0.785920    0.062201    0.005522    0.674947    
#> 084: 0.721507    1.002847    3.469720    0.746624    0.065614    0.006701    0.667918    
#> 085: 0.660321    0.997205    3.462988    0.709293    0.063042    0.007321    0.656663    
#> 086: 0.644238    0.984106    3.462427    0.673828    0.059890    0.008210    0.648919    
#> 087: 0.654368    0.995537    3.460198    0.640137    0.056895    0.007800    0.645121    
#> 088: 0.659349    0.973737    3.463302    0.693936    0.056336    0.007410    0.660202    
#> 089: 0.647517    0.989541    3.460021    0.659239    0.062114    0.009475    0.654581    
#> 090: 0.602775    0.983329    3.455697    0.626277    0.063556    0.009002    0.667990    
#> 091: 0.620137    0.970572    3.445591    0.594963    0.063850    0.008552    0.664786    
#> 092: 0.629551    1.001832    3.444556    0.687580    0.060658    0.008124    0.659670    
#> 093: 0.591477    0.994197    3.440219    0.653201    0.057625    0.007810    0.653470    
#> 094: 0.633791    1.002640    3.431471    0.665478    0.054744    0.007787    0.646579    
#> 095: 0.627475    1.011361    3.443004    0.633031    0.054149    0.010164    0.645969    
#> 096: 0.591914    1.015365    3.443203    0.601379    0.063807    0.009657    0.647932    
#> 097: 0.606236    1.034910    3.439187    0.571310    0.060617    0.009174    0.642640    
#> 098: 0.640570    1.040582    3.443492    0.604128    0.057586    0.008715    0.653309    
#> 099: 0.644350    0.999839    3.438638    0.573922    0.060311    0.009209    0.653447    
#> 100: 0.622150    1.006769    3.446929    0.563380    0.057296    0.009803    0.658540    
#> 101: 0.584096    0.980996    3.437540    0.613756    0.054431    0.009312    0.655981    
#> 102: 0.609014    0.991672    3.433889    0.642796    0.051709    0.008847    0.653851    
#> 103: 0.622393    1.003128    3.444106    0.649602    0.052512    0.008433    0.644327    
#> 104: 0.618077    1.021045    3.445011    0.667023    0.065989    0.008579    0.635918    
#> 105: 0.638587    1.009437    3.437099    0.696228    0.062690    0.008447    0.649621    
#> 106: 0.648727    0.996094    3.437666    0.678008    0.059555    0.009619    0.639696    
#> 107: 0.663357    1.000735    3.450441    0.728569    0.057949    0.010467    0.648476    
#> 108: 0.655912    1.005811    3.443742    0.692140    0.057465    0.010858    0.657902    
#> 109: 0.596048    0.994320    3.448727    0.657533    0.057791    0.010315    0.657481    
#> 110: 0.652013    0.998419    3.437454    0.624657    0.054978    0.009799    0.664362    
#> 111: 0.640501    1.000649    3.445407    0.593424    0.052230    0.009309    0.644560    
#> 112: 0.621018    0.977849    3.440950    0.688152    0.051079    0.008844    0.645197    
#> 113: 0.652217    0.994863    3.446603    0.749765    0.048525    0.008402    0.636757    
#> 114: 0.685157    0.997125    3.448793    0.808873    0.046099    0.008885    0.644945    
#> 115: 0.685625    0.974511    3.447427    0.858642    0.047608    0.009525    0.649190    
#> 116: 0.729107    0.989823    3.462490    0.815710    0.056086    0.009048    0.633449    
#> 117: 0.712151    0.998963    3.465349    0.774925    0.053282    0.010442    0.645539    
#> 118: 0.715825    0.990660    3.463753    0.761430    0.050618    0.009920    0.650693    
#> 119: 0.683735    0.994574    3.462353    0.805215    0.048087    0.011063    0.665466    
#> 120: 0.694674    1.002827    3.458544    0.764954    0.055745    0.011471    0.653962    
#> 121: 0.704315    1.015190    3.462437    0.726707    0.054977    0.012333    0.672131    
#> 122: 0.706146    0.993854    3.468137    0.775762    0.061932    0.011716    0.674121    
#> 123: 0.762254    1.007578    3.460992    0.925772    0.068911    0.011130    0.652303    
#> 124: 0.699546    1.025981    3.449019    0.918095    0.065465    0.010574    0.650972    
#> 125: 0.695395    1.007060    3.447800    0.877107    0.062192    0.011179    0.646221    
#> 126: 0.667398    1.027122    3.437489    0.833251    0.059083    0.011448    0.644164    
#> 127: 0.652854    1.000404    3.452071    0.791589    0.056128    0.010876    0.650434    
#> 128: 0.662002    1.005037    3.464825    0.752009    0.053322    0.010920    0.661408    
#> 129: 0.685771    0.991445    3.476446    0.714409    0.054181    0.010374    0.654562    
#> 130: 0.716656    0.996770    3.476196    0.695948    0.051472    0.010756    0.633874    
#> 131: 0.707013    0.975002    3.465673    0.661151    0.050696    0.010546    0.628144    
#> 132: 0.677338    0.975619    3.449317    0.721386    0.061937    0.010019    0.637358    
#> 133: 0.639505    0.968957    3.453656    0.685317    0.078604    0.009518    0.650271    
#> 134: 0.669742    0.970593    3.461884    0.651051    0.074674    0.009042    0.659724    
#> 135: 0.690304    0.953352    3.472030    0.618498    0.070940    0.008590    0.670391    
#> 136: 0.649863    0.959161    3.471081    0.587573    0.067393    0.008339    0.652416    
#> 137: 0.718169    0.933834    3.480023    0.587959    0.064023    0.007922    0.660411    
#> 138: 0.683145    0.958734    3.478985    0.558561    0.061606    0.007526    0.657464    
#> 139: 0.681895    0.977458    3.477418    0.623146    0.062456    0.007458    0.641862    
#> 140: 0.673571    0.983641    3.477169    0.591988    0.069129    0.008887    0.651378    
#> 141: 0.690799    0.958052    3.481987    0.631247    0.065672    0.010247    0.646464    
#> 142: 0.728833    0.932736    3.484585    0.650968    0.062389    0.009951    0.655464    
#> 143: 0.627811    0.985590    3.477898    0.618419    0.059269    0.011229    0.647710    
#> 144: 0.711911    0.982299    3.479439    0.663331    0.056306    0.011664    0.647871    
#> 145: 0.651612    0.982332    3.457814    0.653319    0.054440    0.011081    0.646264    
#> 146: 0.684037    0.987110    3.474754    0.633105    0.054079    0.010527    0.657402    
#> 147: 0.685802    0.978951    3.466354    0.700178    0.055977    0.010360    0.643794    
#> 148: 0.676714    0.983771    3.470474    0.688220    0.058944    0.009842    0.641958    
#> 149: 0.685944    0.973409    3.473044    0.675299    0.067301    0.009350    0.641338    
#> 150: 0.692856    0.964198    3.462608    0.641534    0.063936    0.008882    0.653563    
#> 151: 0.665254    0.999710    3.458530    0.703392    0.069113    0.008438    0.634361    
#> 152: 0.668270    1.008894    3.457146    0.765495    0.062237    0.009544    0.653046    
#> 153: 0.648745    1.000342    3.461891    0.689722    0.059084    0.007009    0.664213    
#> 154: 0.703448    0.988878    3.465939    0.660424    0.062022    0.006206    0.661096    
#> 155: 0.643686    0.981246    3.456899    0.662963    0.064300    0.006443    0.668952    
#> 156: 0.656987    0.990268    3.467269    0.591658    0.077431    0.007717    0.673874    
#> 157: 0.672267    0.975848    3.474771    0.701971    0.079079    0.010514    0.670917    
#> 158: 0.710666    0.999493    3.460918    0.754280    0.074059    0.010025    0.648568    
#> 159: 0.639059    0.995584    3.462936    0.629148    0.066801    0.010055    0.660384    
#> 160: 0.675632    0.971290    3.474929    0.589114    0.071306    0.008238    0.661770    
#> 161: 0.673478    0.987823    3.462038    0.608089    0.058001    0.008915    0.667004    
#> 162: 0.674187    0.990430    3.459814    0.607875    0.062516    0.008135    0.662247    
#> 163: 0.675115    0.983777    3.458966    0.654709    0.071747    0.007419    0.642548    
#> 164: 0.691661    0.984064    3.467502    0.523356    0.059229    0.009663    0.641375    
#> 165: 0.710240    0.962152    3.473759    0.679597    0.057797    0.009213    0.642995    
#> 166: 0.708860    0.993713    3.474740    0.558235    0.068712    0.008950    0.648404    
#> 167: 0.669172    1.003780    3.473964    0.523718    0.061878    0.008823    0.653816    
#> 168: 0.701027    0.991085    3.475270    0.573563    0.054211    0.007451    0.651693    
#> 169: 0.658871    1.005740    3.465764    0.436592    0.051862    0.007941    0.683711    
#> 170: 0.685289    0.991599    3.471840    0.528982    0.048999    0.008270    0.661409    
#> 171: 0.654880    0.978905    3.465498    0.559155    0.052124    0.006436    0.652344    
#> 172: 0.618973    0.996018    3.454455    0.605722    0.047173    0.006035    0.653519    
#> 173: 0.633960    1.003203    3.450786    0.641585    0.051819    0.005713    0.642443    
#> 174: 0.640846    0.994395    3.451168    0.622379    0.061821    0.005960    0.643606    
#> 175: 0.631315    1.005371    3.448300    0.612232    0.059409    0.007068    0.653786    
#> 176: 0.642490    1.023880    3.455095    0.618291    0.053842    0.006033    0.658407    
#> 177: 0.683903    1.001815    3.464337    0.607185    0.064227    0.006446    0.655737    
#> 178: 0.676642    0.997445    3.463701    0.567041    0.062662    0.006573    0.653697    
#> 179: 0.685208    1.009417    3.461472    0.555985    0.052646    0.006477    0.675047    
#> 180: 0.619681    1.005658    3.456221    0.525511    0.049040    0.007501    0.666337    
#> 181: 0.628624    0.974952    3.441546    0.531508    0.046009    0.007023    0.668187    
#> 182: 0.621870    1.014374    3.435596    0.694231    0.047056    0.008474    0.669445    
#> 183: 0.635687    1.015878    3.438778    0.601975    0.048627    0.007479    0.662463    
#> 184: 0.634334    0.983887    3.442356    0.656399    0.043627    0.007326    0.675965    
#> 185: 0.631979    1.024210    3.437801    0.611429    0.042932    0.005393    0.676202    
#> 186: 0.611604    1.025255    3.446039    0.578054    0.042786    0.006845    0.674394    
#> 187: 0.638500    1.000299    3.457873    0.563542    0.040936    0.008296    0.654623    
#> 188: 0.605244    1.000059    3.451055    0.528840    0.046908    0.008253    0.665994    
#> 189: 0.654919    1.004561    3.458655    0.626583    0.049690    0.007364    0.671916    
#> 190: 0.655331    1.007172    3.461222    0.555772    0.055136    0.007709    0.653993    
#> 191: 0.688118    1.017391    3.455512    0.665854    0.056274    0.008508    0.644885    
#> 192: 0.658676    1.004134    3.453225    0.788606    0.053396    0.011723    0.636032    
#> 193: 0.711834    1.016517    3.446774    0.821709    0.051692    0.009785    0.634197    
#> 194: 0.647264    1.018993    3.441497    0.646713    0.063688    0.010465    0.628878    
#> 195: 0.602745    1.011284    3.440533    0.639532    0.054736    0.010786    0.636089    
#> 196: 0.612054    1.007399    3.453404    0.575309    0.059871    0.011758    0.653813    
#> 197: 0.595119    0.988654    3.468246    0.564123    0.054644    0.013389    0.665033    
#> 198: 0.656621    0.978619    3.461965    0.590228    0.048428    0.013836    0.642298    
#> 199: 0.609231    0.979410    3.456722    0.582388    0.050023    0.014591    0.647441    
#> 200: 0.625848    0.969431    3.454756    0.636220    0.048932    0.009453    0.663346    
#> 201: 0.635676    0.962116    3.459667    0.653300    0.051656    0.009870    0.659015    
#> 202: 0.649542    0.964885    3.459368    0.680626    0.053201    0.009973    0.654034    
#> 203: 0.667089    0.966919    3.457308    0.717604    0.052324    0.010034    0.652331    
#> 204: 0.671985    0.965006    3.457929    0.730446    0.053346    0.010139    0.652817    
#> 205: 0.683389    0.971687    3.457629    0.778411    0.052696    0.010433    0.651766    
#> 206: 0.684919    0.978088    3.457836    0.796354    0.052548    0.010577    0.652145    
#> 207: 0.681794    0.981993    3.456113    0.792728    0.051784    0.010355    0.650502    
#> 208: 0.681921    0.985320    3.455241    0.790432    0.051271    0.010329    0.647515    
#> 209: 0.687276    0.984824    3.455097    0.802828    0.051005    0.010114    0.647261    
#> 210: 0.687246    0.983855    3.455633    0.803479    0.050792    0.010173    0.646523    
#> 211: 0.691552    0.985776    3.455836    0.808006    0.050213    0.010228    0.645772    
#> 212: 0.690815    0.986072    3.456285    0.802001    0.049907    0.010311    0.645510    
#> 213: 0.691199    0.984495    3.456363    0.797074    0.050691    0.010546    0.645928    
#> 214: 0.694541    0.983639    3.456933    0.795506    0.051085    0.010612    0.645816    
#> 215: 0.695883    0.984287    3.457722    0.791051    0.051783    0.010654    0.645437    
#> 216: 0.697358    0.983479    3.458353    0.788462    0.052504    0.010729    0.645693    
#> 217: 0.694762    0.983738    3.458762    0.777817    0.053085    0.010741    0.644934    
#> 218: 0.693485    0.984751    3.458312    0.770018    0.053502    0.010761    0.644204    
#> 219: 0.690805    0.985054    3.457723    0.763199    0.053672    0.010790    0.644642    
#> 220: 0.687893    0.985756    3.457124    0.763554    0.053670    0.010791    0.644885    
#> 221: 0.686342    0.986784    3.456522    0.763165    0.053723    0.010777    0.644833    
#> 222: 0.686238    0.987094    3.456408    0.760415    0.054147    0.010788    0.644850    
#> 223: 0.687184    0.986851    3.456469    0.761681    0.054214    0.010743    0.644439    
#> 224: 0.690166    0.986723    3.456941    0.764974    0.054198    0.010682    0.644982    
#> 225: 0.691878    0.985392    3.457429    0.768710    0.054437    0.010675    0.645496    
#> 226: 0.692306    0.985010    3.457635    0.762188    0.054754    0.010614    0.645482    
#> 227: 0.691386    0.984765    3.457930    0.756122    0.054610    0.010560    0.645827    
#> 228: 0.690297    0.984944    3.457811    0.753075    0.054745    0.010524    0.645920    
#> 229: 0.689054    0.984489    3.457679    0.752313    0.054898    0.010506    0.645443    
#> 230: 0.688356    0.984551    3.457611    0.749629    0.055005    0.010496    0.645414    
#> 231: 0.687871    0.984527    3.457782    0.748801    0.055125    0.010430    0.645128    
#> 232: 0.686649    0.984377    3.458185    0.745228    0.055038    0.010436    0.645167    
#> 233: 0.686534    0.983652    3.458676    0.744773    0.055077    0.010465    0.645192    
#> 234: 0.686919    0.983469    3.458991    0.742241    0.055015    0.010429    0.645517    
#> 235: 0.685699    0.983006    3.458876    0.737393    0.055295    0.010390    0.645762    
#> 236: 0.685959    0.983146    3.458789    0.737274    0.055492    0.010320    0.646168    
#> 237: 0.685776    0.983298    3.458712    0.737562    0.055554    0.010267    0.647201    
#> 238: 0.685614    0.983061    3.458768    0.738449    0.055857    0.010321    0.647741    
#> 239: 0.684760    0.983324    3.458760    0.735968    0.056125    0.010339    0.647352    
#> 240: 0.684804    0.983345    3.458949    0.732822    0.056006    0.010330    0.647098    
#> 241: 0.685246    0.982650    3.459120    0.732500    0.055775    0.010346    0.647212    
#> 242: 0.684834    0.982028    3.458809    0.733490    0.055651    0.010368    0.647338    
#> 243: 0.683535    0.982122    3.458589    0.732075    0.055502    0.010434    0.647519    
#> 244: 0.683398    0.982093    3.458493    0.734384    0.055326    0.010467    0.647608    
#> 245: 0.682360    0.982070    3.458260    0.732967    0.055325    0.010501    0.648180    
#> 246: 0.681575    0.982436    3.458162    0.731186    0.055287    0.010513    0.648512    
#> 247: 0.681742    0.982312    3.458297    0.729322    0.055097    0.010506    0.648348    
#> 248: 0.681578    0.982844    3.458377    0.726713    0.055132    0.010495    0.648250    
#> 249: 0.681026    0.983246    3.458255    0.725214    0.055297    0.010506    0.648473    
#> 250: 0.680792    0.983674    3.458088    0.725354    0.055285    0.010522    0.648581    
#> 251: 0.680407    0.984352    3.458175    0.724302    0.055178    0.010492    0.648774    
#> 252: 0.681573    0.984439    3.458420    0.727726    0.055128    0.010469    0.649172    
#> 253: 0.681295    0.984618    3.458432    0.729547    0.055198    0.010427    0.649503    
#> 254: 0.681500    0.985107    3.458504    0.730499    0.055207    0.010390    0.649661    
#> 255: 0.681370    0.985413    3.458634    0.732124    0.055092    0.010359    0.649964    
#> 256: 0.681773    0.985163    3.458775    0.732102    0.055063    0.010337    0.650243    
#> 257: 0.682067    0.984757    3.458786    0.731450    0.055064    0.010304    0.650319    
#> 258: 0.681750    0.984415    3.458929    0.730375    0.055050    0.010265    0.650435    
#> 259: 0.681809    0.984331    3.458884    0.728910    0.055055    0.010228    0.650549    
#> 260: 0.681698    0.984518    3.459079    0.726943    0.055019    0.010192    0.650795    
#> 261: 0.682030    0.984613    3.459247    0.725869    0.054879    0.010155    0.650927    
#> 262: 0.681173    0.984895    3.459199    0.723279    0.054775    0.010167    0.650919    
#> 263: 0.680742    0.984983    3.459146    0.720682    0.054789    0.010126    0.651086    
#> 264: 0.680474    0.984978    3.459113    0.718932    0.054896    0.010090    0.651205    
#> 265: 0.680705    0.984910    3.459197    0.718661    0.054887    0.010088    0.651340    
#> 266: 0.681239    0.984909    3.459317    0.718479    0.055106    0.010066    0.651301    
#> 267: 0.681484    0.984668    3.459595    0.718962    0.055103    0.010071    0.651190    
#> 268: 0.681382    0.984302    3.459698    0.717546    0.055280    0.010069    0.650978    
#> 269: 0.682166    0.984176    3.459866    0.716907    0.055201    0.010076    0.650843    
#> 270: 0.682672    0.984280    3.459898    0.718040    0.055185    0.010076    0.650449    
#> 271: 0.682748    0.984257    3.459895    0.718628    0.055249    0.010060    0.650250    
#> 272: 0.682988    0.983886    3.459925    0.718246    0.055255    0.010086    0.650228    
#> 273: 0.682970    0.983849    3.459915    0.718977    0.055226    0.010099    0.650287    
#> 274: 0.682763    0.983872    3.459973    0.719164    0.055147    0.010108    0.650351    
#> 275: 0.683328    0.983719    3.459877    0.720960    0.054981    0.010118    0.650543    
#> 276: 0.683960    0.983602    3.460133    0.722994    0.054868    0.010136    0.650553    
#> 277: 0.684469    0.983528    3.460459    0.725011    0.054810    0.010170    0.650608    
#> 278: 0.684544    0.983388    3.460615    0.724929    0.054805    0.010192    0.650762    
#> 279: 0.684086    0.983276    3.460786    0.722532    0.054927    0.010183    0.650843    
#> 280: 0.683570    0.983468    3.460870    0.719672    0.054971    0.010154    0.650718    
#> 281: 0.683080    0.983776    3.460960    0.717475    0.054903    0.010137    0.650764    
#> 282: 0.683336    0.983901    3.461065    0.717573    0.054875    0.010161    0.650759    
#> 283: 0.683531    0.984128    3.461143    0.718385    0.055015    0.010178    0.650947    
#> 284: 0.683337    0.984082    3.461183    0.717476    0.055103    0.010175    0.650969    
#> 285: 0.684087    0.984043    3.461141    0.719618    0.055131    0.010193    0.650915    
#> 286: 0.684235    0.984115    3.461084    0.719688    0.055159    0.010207    0.651141    
#> 287: 0.684402    0.984209    3.461024    0.720028    0.055239    0.010218    0.651110    
#> 288: 0.684517    0.984189    3.461026    0.719852    0.055103    0.010253    0.651089    
#> 289: 0.684968    0.984357    3.461043    0.719553    0.055109    0.010283    0.650994    
#> 290: 0.685177    0.984265    3.461075    0.719301    0.055087    0.010310    0.651119    
#> 291: 0.685463    0.984344    3.461166    0.718919    0.055030    0.010345    0.651012    
#> 292: 0.685262    0.984354    3.461198    0.717222    0.055076    0.010356    0.650866    
#> 293: 0.684829    0.984513    3.461160    0.715934    0.055043    0.010364    0.650918    
#> 294: 0.684421    0.984742    3.461151    0.714783    0.055000    0.010367    0.650809    
#> 295: 0.684317    0.984633    3.461075    0.714062    0.055005    0.010355    0.650736    
#> 296: 0.684521    0.984667    3.461069    0.713831    0.055118    0.010341    0.650972    
#> 297: 0.684629    0.984760    3.461096    0.714180    0.055175    0.010336    0.651070    
#> 298: 0.684572    0.984626    3.461094    0.713810    0.055220    0.010332    0.651192    
#> 299: 0.684694    0.984873    3.461047    0.714855    0.055218    0.010334    0.650996    
#> 300: 0.684927    0.984778    3.461107    0.715217    0.055188    0.010342    0.650764    
#> 301: 0.685083    0.984634    3.461019    0.715042    0.055200    0.010330    0.650931    
#> 302: 0.684885    0.984748    3.461022    0.714322    0.055179    0.010329    0.650964    
#> 303: 0.684606    0.984853    3.460963    0.713499    0.055322    0.010303    0.650912    
#> 304: 0.684675    0.985104    3.460853    0.713725    0.055425    0.010272    0.650989    
#> 305: 0.684382    0.984990    3.460798    0.713233    0.055474    0.010246    0.651078    
#> 306: 0.683771    0.985089    3.460562    0.713069    0.055470    0.010236    0.651079    
#> 307: 0.683886    0.985135    3.460443    0.714248    0.055477    0.010228    0.650979    
#> 308: 0.684202    0.985176    3.460364    0.716379    0.055507    0.010214    0.650933    
#> 309: 0.684663    0.985050    3.460270    0.718865    0.055564    0.010195    0.650918    
#> 310: 0.685120    0.985088    3.460113    0.721868    0.055545    0.010175    0.650963    
#> 311: 0.685425    0.985140    3.459980    0.724381    0.055445    0.010154    0.651001    
#> 312: 0.685544    0.985141    3.459883    0.726007    0.055456    0.010141    0.650876    
#> 313: 0.685554    0.985035    3.459759    0.727405    0.055472    0.010125    0.651035    
#> 314: 0.684703    0.985055    3.459606    0.726376    0.055519    0.010104    0.651095    
#> 315: 0.683856    0.985181    3.459490    0.725078    0.055533    0.010080    0.651096    
#> 316: 0.683361    0.985305    3.459428    0.724115    0.055621    0.010043    0.651134    
#> 317: 0.683353    0.985388    3.459416    0.723841    0.055665    0.010024    0.651204    
#> 318: 0.683408    0.985513    3.459319    0.724546    0.055692    0.010010    0.651232    
#> 319: 0.683518    0.985519    3.459319    0.725503    0.055747    0.010005    0.651370    
#> 320: 0.683292    0.985513    3.459273    0.726227    0.055798    0.009992    0.651561    
#> 321: 0.683198    0.985509    3.459204    0.726997    0.055897    0.009973    0.651748    
#> 322: 0.683092    0.985643    3.459087    0.726827    0.055997    0.009956    0.651797    
#> 323: 0.682519    0.985818    3.458923    0.726127    0.056044    0.009933    0.651892    
#> 324: 0.682029    0.986035    3.458829    0.725298    0.056021    0.009912    0.651819    
#> 325: 0.681482    0.986304    3.458706    0.724342    0.056058    0.009894    0.651761    
#> 326: 0.681231    0.986349    3.458569    0.724042    0.056016    0.009877    0.651757    
#> 327: 0.680979    0.986420    3.458545    0.723809    0.056012    0.009858    0.651841    
#> 328: 0.680585    0.986517    3.458500    0.723169    0.056049    0.009839    0.651772    
#> 329: 0.680386    0.986611    3.458453    0.722764    0.056070    0.009827    0.651707    
#> 330: 0.679950    0.986718    3.458392    0.722205    0.056067    0.009824    0.651760    
#> 331: 0.679957    0.986934    3.458369    0.721873    0.056069    0.009822    0.651778    
#> 332: 0.679956    0.986898    3.458476    0.721062    0.056084    0.009823    0.651919    
#> 333: 0.679955    0.986799    3.458533    0.720175    0.056080    0.009816    0.652053    
#> 334: 0.679838    0.986684    3.458535    0.719233    0.056055    0.009793    0.652040    
#> 335: 0.679649    0.986776    3.458497    0.718323    0.056037    0.009779    0.651970    
#> 336: 0.679120    0.986913    3.458445    0.717801    0.055958    0.009763    0.652027    
#> 337: 0.678570    0.987225    3.458277    0.717362    0.055962    0.009758    0.652088    
#> 338: 0.678033    0.987321    3.458232    0.716468    0.055929    0.009750    0.652151    
#> 339: 0.677891    0.987480    3.458248    0.715839    0.055976    0.009763    0.652106    
#> 340: 0.677804    0.987317    3.458261    0.715224    0.055994    0.009782    0.652124    
#> 341: 0.677761    0.987296    3.458276    0.714389    0.056039    0.009787    0.652024    
#> 342: 0.677715    0.987120    3.458330    0.713827    0.056071    0.009781    0.651917    
#> 343: 0.677431    0.987058    3.458387    0.713292    0.056102    0.009771    0.651840    
#> 344: 0.677316    0.987084    3.458376    0.713381    0.056117    0.009752    0.651863    
#> 345: 0.677196    0.987093    3.458348    0.713811    0.056169    0.009744    0.651831    
#> 346: 0.677096    0.987153    3.458280    0.714087    0.056199    0.009745    0.651693    
#> 347: 0.677112    0.987050    3.458181    0.715320    0.056212    0.009737    0.651692    
#> 348: 0.676769    0.987137    3.458070    0.715189    0.056274    0.009728    0.651652    
#> 349: 0.676537    0.987084    3.458041    0.715351    0.056284    0.009714    0.651537    
#> 350: 0.676337    0.987007    3.458019    0.715044    0.056322    0.009700    0.651440    
#> 351: 0.676205    0.987130    3.457946    0.714995    0.056360    0.009683    0.651448    
#> 352: 0.675864    0.987269    3.457922    0.714257    0.056386    0.009676    0.651500    
#> 353: 0.675745    0.987441    3.457920    0.713421    0.056426    0.009676    0.651462    
#> 354: 0.675799    0.987474    3.457876    0.712662    0.056411    0.009680    0.651428    
#> 355: 0.676105    0.987389    3.457912    0.711853    0.056426    0.009677    0.651428    
#> 356: 0.676255    0.987274    3.457974    0.711549    0.056398    0.009662    0.651502    
#> 357: 0.676338    0.987299    3.458032    0.711134    0.056339    0.009656    0.651539    
#> 358: 0.676411    0.987251    3.458114    0.710956    0.056344    0.009648    0.651505    
#> 359: 0.676758    0.987244    3.458180    0.711243    0.056313    0.009653    0.651452    
#> 360: 0.677059    0.987267    3.458147    0.712045    0.056281    0.009667    0.651367    
#> 361: 0.676959    0.987327    3.458135    0.712006    0.056198    0.009667    0.651359    
#> 362: 0.676965    0.987454    3.458059    0.711812    0.056171    0.009654    0.651231    
#> 363: 0.677139    0.987426    3.458061    0.712550    0.056142    0.009646    0.651151    
#> 364: 0.677344    0.987533    3.458020    0.713231    0.056181    0.009641    0.651132    
#> 365: 0.677464    0.987517    3.458033    0.713618    0.056185    0.009644    0.651200    
#> 366: 0.677605    0.987592    3.457956    0.713932    0.056259    0.009646    0.651235    
#> 367: 0.677834    0.987641    3.457890    0.714292    0.056240    0.009642    0.651297    
#> 368: 0.677812    0.987790    3.457882    0.714380    0.056224    0.009646    0.651267    
#> 369: 0.677625    0.987824    3.457891    0.713668    0.056240    0.009659    0.651292    
#> 370: 0.677395    0.987900    3.457895    0.712548    0.056231    0.009646    0.651354    
#> 371: 0.677446    0.987994    3.457832    0.712832    0.056199    0.009635    0.651342    
#> 372: 0.677243    0.988079    3.457796    0.712934    0.056150    0.009634    0.651336    
#> 373: 0.676815    0.988223    3.457724    0.712466    0.056110    0.009635    0.651287    
#> 374: 0.676693    0.988252    3.457647    0.712327    0.056049    0.009635    0.651287    
#> 375: 0.676522    0.988335    3.457608    0.711917    0.055999    0.009629    0.651377    
#> 376: 0.676458    0.988428    3.457583    0.712158    0.055982    0.009643    0.651375    
#> 377: 0.676493    0.988529    3.457559    0.712148    0.055885    0.009649    0.651493    
#> 378: 0.676145    0.988589    3.457435    0.711761    0.055830    0.009663    0.651523    
#> 379: 0.675680    0.988549    3.457402    0.710787    0.055810    0.009671    0.651497    
#> 380: 0.675512    0.988491    3.457367    0.710393    0.055834    0.009677    0.651507    
#> 381: 0.675214    0.988500    3.457330    0.710103    0.055850    0.009680    0.651477    
#> 382: 0.675259    0.988581    3.457317    0.710197    0.055849    0.009675    0.651341    
#> 383: 0.675209    0.988634    3.457353    0.709693    0.055840    0.009670    0.651284    
#> 384: 0.675146    0.988626    3.457392    0.709285    0.055838    0.009666    0.651310    
#> 385: 0.675216    0.988626    3.457459    0.709112    0.055875    0.009658    0.651274    
#> 386: 0.675543    0.988723    3.457542    0.709141    0.055937    0.009649    0.651340    
#> 387: 0.675937    0.988821    3.457614    0.709579    0.055968    0.009645    0.651308    
#> 388: 0.676288    0.988788    3.457684    0.709734    0.055956    0.009646    0.651280    
#> 389: 0.676557    0.988661    3.457716    0.710272    0.055937    0.009639    0.651410    
#> 390: 0.676595    0.988746    3.457651    0.710351    0.055931    0.009628    0.651484    
#> 391: 0.676554    0.988689    3.457603    0.710215    0.055934    0.009616    0.651441    
#> 392: 0.676410    0.988760    3.457564    0.710246    0.055919    0.009616    0.651491    
#> 393: 0.676131    0.988814    3.457479    0.709780    0.055948    0.009612    0.651531    
#> 394: 0.676119    0.988829    3.457481    0.709300    0.055952    0.009609    0.651508    
#> 395: 0.676156    0.988935    3.457495    0.709095    0.055972    0.009602    0.651504    
#> 396: 0.676165    0.989004    3.457488    0.709363    0.056007    0.009592    0.651462    
#> 397: 0.676282    0.988926    3.457514    0.709260    0.056050    0.009565    0.651580    
#> 398: 0.676462    0.988835    3.457556    0.709443    0.056123    0.009543    0.651634    
#> 399: 0.676491    0.988906    3.457614    0.709167    0.056176    0.009520    0.651642    
#> 400: 0.676556    0.988940    3.457623    0.708495    0.056192    0.009503    0.651650    
#> 401: 0.676562    0.988961    3.457646    0.707868    0.056236    0.009499    0.651680    
#> 402: 0.676654    0.989052    3.457615    0.707624    0.056261    0.009498    0.651643    
#> 403: 0.676796    0.989065    3.457626    0.707211    0.056227    0.009489    0.651663    
#> 404: 0.676594    0.989128    3.457577    0.706860    0.056231    0.009479    0.651670    
#> 405: 0.676588    0.989201    3.457573    0.707092    0.056215    0.009476    0.651644    
#> 406: 0.676551    0.989246    3.457543    0.707780    0.056218    0.009477    0.651649    
#> 407: 0.676662    0.989266    3.457577    0.708311    0.056312    0.009485    0.651642    
#> 408: 0.676752    0.989395    3.457548    0.707930    0.056406    0.009473    0.651600    
#> 409: 0.676627    0.989390    3.457515    0.707530    0.056433    0.009463    0.651571    
#> 410: 0.676622    0.989404    3.457504    0.707103    0.056479    0.009449    0.651600    
#> 411: 0.676681    0.989182    3.457512    0.706729    0.056509    0.009447    0.651678    
#> 412: 0.676578    0.989234    3.457473    0.706311    0.056546    0.009443    0.651679    
#> 413: 0.676532    0.989262    3.457466    0.705841    0.056559    0.009438    0.651772    
#> 414: 0.676341    0.989224    3.457485    0.705476    0.056566    0.009435    0.651850    
#> 415: 0.676330    0.989225    3.457498    0.705026    0.056576    0.009425    0.651826    
#> 416: 0.676281    0.989295    3.457527    0.704517    0.056567    0.009416    0.651813    
#> 417: 0.676335    0.989234    3.457527    0.704652    0.056558    0.009404    0.651762    
#> 418: 0.676348    0.989237    3.457512    0.704639    0.056565    0.009401    0.651676    
#> 419: 0.676512    0.989243    3.457536    0.704763    0.056586    0.009403    0.651655    
#> 420: 0.676544    0.989233    3.457577    0.704348    0.056577    0.009406    0.651624    
#> 421: 0.676479    0.989250    3.457602    0.704371    0.056540    0.009420    0.651570    
#> 422: 0.676645    0.989232    3.457591    0.704882    0.056515    0.009431    0.651580    
#> 423: 0.676897    0.989170    3.457622    0.705290    0.056530    0.009437    0.651601    
#> 424: 0.677025    0.989095    3.457584    0.705618    0.056473    0.009447    0.651574    
#> 425: 0.677252    0.989064    3.457600    0.706377    0.056420    0.009466    0.651602    
#> 426: 0.677305    0.989136    3.457636    0.706835    0.056350    0.009467    0.651662    
#> 427: 0.677333    0.989114    3.457663    0.707006    0.056343    0.009464    0.651707    
#> 428: 0.677185    0.989126    3.457669    0.706747    0.056378    0.009449    0.651757    
#> 429: 0.677137    0.989124    3.457674    0.706376    0.056395    0.009442    0.651741    
#> 430: 0.677015    0.989240    3.457642    0.706031    0.056395    0.009433    0.651786    
#> 431: 0.676863    0.989215    3.457642    0.705342    0.056389    0.009432    0.651752    
#> 432: 0.676757    0.989263    3.457636    0.705104    0.056390    0.009441    0.651727    
#> 433: 0.676640    0.989377    3.457596    0.705047    0.056352    0.009437    0.651780    
#> 434: 0.676397    0.989331    3.457585    0.704538    0.056329    0.009431    0.651740    
#> 435: 0.676207    0.989360    3.457556    0.704310    0.056342    0.009430    0.651694    
#> 436: 0.676121    0.989338    3.457562    0.704303    0.056351    0.009435    0.651715    
#> 437: 0.675970    0.989294    3.457533    0.704048    0.056382    0.009432    0.651750    
#> 438: 0.675897    0.989423    3.457511    0.704112    0.056404    0.009417    0.651729    
#> 439: 0.675882    0.989467    3.457493    0.703682    0.056370    0.009405    0.651670    
#> 440: 0.675674    0.989517    3.457490    0.703227    0.056388    0.009392    0.651706    
#> 441: 0.675608    0.989544    3.457476    0.703023    0.056366    0.009391    0.651646    
#> 442: 0.675412    0.989587    3.457467    0.702533    0.056394    0.009381    0.651610    
#> 443: 0.675388    0.989703    3.457422    0.702087    0.056424    0.009374    0.651574    
#> 444: 0.675247    0.989790    3.457350    0.701947    0.056413    0.009375    0.651480    
#> 445: 0.675028    0.989885    3.457286    0.701626    0.056422    0.009376    0.651455    
#> 446: 0.674848    0.989993    3.457207    0.701764    0.056395    0.009370    0.651477    
#> 447: 0.674790    0.990154    3.457180    0.701467    0.056396    0.009366    0.651508    
#> 448: 0.674529    0.990205    3.457148    0.701145    0.056404    0.009364    0.651455    
#> 449: 0.674415    0.990280    3.457174    0.700827    0.056413    0.009354    0.651557    
#> 450: 0.674342    0.990259    3.457185    0.700540    0.056494    0.009351    0.651599    
#> 451: 0.674289    0.990238    3.457166    0.700431    0.056580    0.009345    0.651616    
#> 452: 0.674134    0.990245    3.457160    0.700076    0.056625    0.009345    0.651614    
#> 453: 0.674145    0.990274    3.457132    0.699754    0.056626    0.009336    0.651609    
#> 454: 0.674151    0.990317    3.457139    0.699516    0.056597    0.009328    0.651566    
#> 455: 0.674197    0.990333    3.457133    0.699511    0.056585    0.009324    0.651553    
#> 456: 0.674220    0.990295    3.457145    0.699505    0.056604    0.009315    0.651608    
#> 457: 0.674247    0.990306    3.457174    0.699335    0.056668    0.009308    0.651542    
#> 458: 0.674307    0.990386    3.457256    0.698837    0.056712    0.009296    0.651553    
#> 459: 0.674163    0.990419    3.457304    0.698166    0.056782    0.009293    0.651623    
#> 460: 0.674053    0.990427    3.457306    0.697589    0.056784    0.009290    0.651615    
#> 461: 0.674022    0.990434    3.457315    0.697077    0.056727    0.009295    0.651695    
#> 462: 0.673850    0.990521    3.457283    0.696823    0.056698    0.009296    0.651706    
#> 463: 0.673931    0.990566    3.457302    0.696643    0.056683    0.009300    0.651701    
#> 464: 0.674111    0.990640    3.457284    0.696862    0.056659    0.009299    0.651654    
#> 465: 0.674189    0.990511    3.457296    0.697034    0.056638    0.009299    0.651612    
#> 466: 0.674248    0.990502    3.457289    0.696854    0.056607    0.009296    0.651604    
#> 467: 0.674240    0.990473    3.457302    0.696855    0.056627    0.009295    0.651559    
#> 468: 0.674447    0.990439    3.457368    0.697047    0.056639    0.009296    0.651628    
#> 469: 0.674438    0.990509    3.457397    0.696459    0.056667    0.009292    0.651743    
#> 470: 0.674465    0.990559    3.457396    0.696738    0.056701    0.009281    0.651816    
#> 471: 0.674416    0.990593    3.457357    0.696893    0.056700    0.009277    0.651881    
#> 472: 0.674497    0.990604    3.457367    0.697627    0.056701    0.009266    0.651899    
#> 473: 0.674536    0.990641    3.457377    0.697659    0.056717    0.009264    0.651847    
#> 474: 0.674575    0.990627    3.457400    0.697516    0.056729    0.009267    0.651859    
#> 475: 0.674677    0.990694    3.457412    0.697388    0.056739    0.009275    0.651836    
#> 476: 0.674602    0.990678    3.457407    0.697303    0.056703    0.009282    0.651901    
#> 477: 0.674651    0.990656    3.457455    0.697153    0.056673    0.009286    0.651934    
#> 478: 0.674744    0.990619    3.457483    0.697177    0.056690    0.009285    0.652069    
#> 479: 0.674851    0.990668    3.457496    0.697441    0.056663    0.009284    0.652148    
#> 480: 0.674870    0.990684    3.457524    0.697394    0.056689    0.009288    0.652186    
#> 481: 0.675027    0.990686    3.457521    0.697662    0.056707    0.009282    0.652224    
#> 482: 0.675193    0.990679    3.457507    0.697943    0.056747    0.009281    0.652255    
#> 483: 0.675066    0.990623    3.457499    0.697824    0.056768    0.009280    0.652301    
#> 484: 0.675029    0.990490    3.457521    0.697681    0.056762    0.009281    0.652328    
#> 485: 0.674961    0.990538    3.457541    0.697226    0.056752    0.009284    0.652371    
#> 486: 0.674924    0.990614    3.457546    0.697084    0.056745    0.009282    0.652388    
#> 487: 0.675029    0.990682    3.457583    0.697037    0.056720    0.009284    0.652371    
#> 488: 0.674919    0.990696    3.457604    0.696934    0.056705    0.009287    0.652314    
#> 489: 0.674936    0.990638    3.457583    0.697130    0.056703    0.009290    0.652284    
#> 490: 0.674923    0.990633    3.457589    0.697020    0.056689    0.009287    0.652216    
#> 491: 0.674827    0.990705    3.457625    0.696865    0.056657    0.009291    0.652186    
#> 492: 0.674805    0.990744    3.457625    0.696872    0.056671    0.009299    0.652172    
#> 493: 0.674540    0.990747    3.457603    0.696504    0.056662    0.009307    0.652143    
#> 494: 0.674500    0.990798    3.457567    0.696444    0.056652    0.009309    0.652104    
#> 495: 0.674577    0.990836    3.457536    0.696654    0.056651    0.009312    0.652028    
#> 496: 0.674688    0.990907    3.457486    0.696826    0.056637    0.009312    0.652066    
#> 497: 0.674638    0.990912    3.457471    0.696883    0.056633    0.009316    0.652097    
#> 498: 0.674641    0.990868    3.457464    0.697182    0.056610    0.009318    0.652084    
#> 499: 0.674608    0.990901    3.457441    0.697093    0.056623    0.009320    0.652032    
#> 500: 0.674689    0.990854    3.457431    0.697076    0.056590    0.009321    0.652014    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.324702    0.971502    3.443967    0.392401    0.089388    0.016800    1.795527    
#> 002: 0.337074    0.995130    3.471049    0.372781    0.084918    0.015960    1.131662    
#> 003: 0.498894    0.977328    3.485780    0.354142    0.098982    0.015162    0.856190    
#> 004: 0.442323    0.970121    3.486410    0.336435    0.108014    0.014404    0.741423    
#> 005: 0.550490    0.978334    3.494444    0.319613    0.102613    0.013684    0.689310    
#> 006: 0.503969    0.977222    3.485306    0.303633    0.108471    0.013000    0.663399    
#> 007: 0.465712    0.990999    3.478187    0.288451    0.105707    0.013441    0.660694    
#> 008: 0.430841    0.987349    3.471162    0.274029    0.117812    0.014297    0.642518    
#> 009: 0.418992    0.986745    3.463494    0.260327    0.131892    0.013582    0.654013    
#> 010: 0.444139    0.995786    3.469989    0.247311    0.125297    0.012903    0.648860    
#> 011: 0.471487    1.008923    3.472119    0.244628    0.120933    0.013773    0.648447    
#> 012: 0.471874    1.004583    3.464816    0.232396    0.114886    0.013338    0.640235    
#> 013: 0.426636    1.011315    3.457677    0.254490    0.110868    0.013738    0.642532    
#> 014: 0.467091    1.011418    3.466277    0.314479    0.127482    0.014386    0.651432    
#> 015: 0.476986    0.974322    3.480869    0.298755    0.121108    0.013666    0.630042    
#> 016: 0.501113    0.997674    3.480611    0.295648    0.115052    0.014671    0.627134    
#> 017: 0.443842    1.004548    3.476746    0.280865    0.119170    0.013937    0.624807    
#> 018: 0.459168    1.013630    3.461157    0.266822    0.124055    0.017216    0.626792    
#> 019: 0.423606    1.007099    3.465565    0.253481    0.117852    0.016355    0.630951    
#> 020: 0.458581    1.009394    3.477723    0.240807    0.111959    0.016768    0.629079    
#> 021: 0.459908    1.004756    3.479547    0.228767    0.106361    0.015976    0.626179    
#> 022: 0.459267    0.993409    3.485662    0.217328    0.101043    0.017944    0.628016    
#> 023: 0.526745    0.983132    3.496606    0.206462    0.098182    0.019047    0.661077    
#> 024: 0.525706    1.001128    3.498218    0.196139    0.100944    0.018448    0.646573    
#> 025: 0.516091    0.975307    3.485535    0.186332    0.124849    0.017525    0.640365    
#> 026: 0.480592    0.994729    3.479474    0.177015    0.118607    0.016649    0.633388    
#> 027: 0.460581    1.018432    3.473446    0.179666    0.112676    0.016261    0.641377    
#> 028: 0.462696    1.016299    3.478431    0.191139    0.107043    0.015929    0.633104    
#> 029: 0.491941    1.011709    3.479225    0.181582    0.119403    0.017262    0.663566    
#> 030: 0.503547    0.996847    3.478964    0.206988    0.120373    0.017144    0.641157    
#> 031: 0.474382    0.990267    3.483803    0.196639    0.127863    0.016797    0.630826    
#> 032: 0.469185    0.973961    3.490530    0.186807    0.121470    0.015957    0.624802    
#> 033: 0.466214    0.980189    3.484467    0.204027    0.115396    0.015276    0.641104    
#> 034: 0.497122    1.003977    3.482338    0.215085    0.111328    0.014512    0.651845    
#> 035: 0.449046    0.983183    3.469223    0.212250    0.109948    0.014030    0.629746    
#> 036: 0.435275    1.004143    3.467856    0.201638    0.104898    0.016192    0.643677    
#> 037: 0.440950    1.017447    3.470317    0.191556    0.099653    0.017179    0.648384    
#> 038: 0.469992    1.030604    3.469220    0.216653    0.104764    0.017657    0.644283    
#> 039: 0.485061    1.007399    3.484520    0.205820    0.110820    0.018381    0.626648    
#> 040: 0.460568    1.000130    3.480709    0.195529    0.105279    0.017462    0.646202    
#> 041: 0.472386    0.985148    3.484915    0.185753    0.102159    0.018350    0.629244    
#> 042: 0.475277    0.982548    3.480448    0.205737    0.101329    0.019729    0.618097    
#> 043: 0.458173    1.019521    3.462291    0.198330    0.104607    0.019343    0.628158    
#> 044: 0.437477    1.016473    3.459550    0.189957    0.102438    0.021125    0.627698    
#> 045: 0.425395    1.016260    3.462833    0.184868    0.105003    0.021385    0.651877    
#> 046: 0.475651    1.003261    3.466049    0.215528    0.099753    0.020315    0.639463    
#> 047: 0.469113    1.009606    3.467637    0.227483    0.107429    0.019300    0.634784    
#> 048: 0.470811    1.009682    3.475905    0.225490    0.103072    0.018510    0.643441    
#> 049: 0.464302    1.016159    3.483554    0.214216    0.116024    0.017584    0.637795    
#> 050: 0.511695    0.973079    3.494085    0.203505    0.120483    0.016907    0.634214    
#> 051: 0.516533    0.988555    3.488441    0.193330    0.114459    0.017743    0.631927    
#> 052: 0.505334    0.991750    3.496185    0.183663    0.108736    0.016857    0.625029    
#> 053: 0.500893    0.971843    3.494289    0.233815    0.104189    0.018571    0.630759    
#> 054: 0.468913    0.982427    3.497079    0.222124    0.118054    0.017952    0.642962    
#> 055: 0.472910    0.981207    3.485295    0.211018    0.125189    0.017054    0.648824    
#> 056: 0.479224    0.975820    3.487625    0.216554    0.124369    0.016948    0.646096    
#> 057: 0.502162    0.982835    3.490752    0.264410    0.118151    0.017005    0.632822    
#> 058: 0.489363    1.002232    3.473890    0.251189    0.124731    0.016155    0.632665    
#> 059: 0.490927    0.955723    3.487342    0.238630    0.118826    0.015347    0.660176    
#> 060: 0.466952    0.971367    3.490625    0.226698    0.112885    0.017479    0.660652    
#> 061: 0.543623    0.998455    3.503006    0.269209    0.112419    0.021957    0.668681    
#> 062: 0.516012    1.013968    3.499790    0.255749    0.113407    0.020859    0.667372    
#> 063: 0.549815    0.966366    3.495952    0.242961    0.123590    0.020821    0.653351    
#> 064: 0.500529    0.989891    3.495354    0.230813    0.126051    0.019780    0.662248    
#> 065: 0.519807    0.974206    3.488512    0.219272    0.124364    0.018791    0.649921    
#> 066: 0.521459    0.982811    3.494925    0.239374    0.120616    0.017960    0.637030    
#> 067: 0.492664    0.979403    3.483255    0.227405    0.114585    0.019986    0.627313    
#> 068: 0.469750    0.997416    3.486089    0.216035    0.120231    0.018986    0.653259    
#> 069: 0.489662    0.999209    3.481837    0.205233    0.114220    0.018037    0.646688    
#> 070: 0.494122    0.968056    3.499564    0.194972    0.108509    0.018530    0.640222    
#> 071: 0.510624    0.976036    3.486245    0.222362    0.108719    0.017604    0.656775    
#> 072: 0.455300    0.992760    3.477675    0.261050    0.120605    0.020052    0.625484    
#> 073: 0.491853    0.987859    3.490992    0.247997    0.114575    0.019049    0.629471    
#> 074: 0.478265    0.966531    3.479169    0.235868    0.108846    0.018097    0.635256    
#> 075: 0.475705    0.979946    3.504634    0.224074    0.119354    0.018229    0.639103    
#> 076: 0.512105    0.999202    3.504956    0.212871    0.113386    0.017318    0.651853    
#> 077: 0.518535    0.975451    3.495176    0.219416    0.107717    0.016982    0.647789    
#> 078: 0.499943    0.977719    3.486434    0.208445    0.116124    0.016517    0.634410    
#> 079: 0.485341    0.988273    3.479466    0.236352    0.110318    0.017395    0.650571    
#> 080: 0.491423    1.004768    3.484320    0.257352    0.104802    0.018234    0.674179    
#> 081: 0.467109    1.008485    3.483063    0.291679    0.100460    0.020375    0.647606    
#> 082: 0.475542    0.983474    3.490763    0.277095    0.095856    0.019356    0.640316    
#> 083: 0.453146    1.017211    3.479394    0.272614    0.115451    0.018389    0.638293    
#> 084: 0.464197    1.008678    3.478433    0.258983    0.109678    0.017469    0.631502    
#> 085: 0.475144    1.007501    3.491712    0.246034    0.104194    0.016596    0.637515    
#> 086: 0.467116    1.019409    3.488951    0.260582    0.100961    0.017574    0.625106    
#> 087: 0.464729    1.002519    3.473560    0.247553    0.111127    0.016695    0.615081    
#> 088: 0.433995    1.006699    3.471765    0.235175    0.105571    0.016730    0.630172    
#> 089: 0.470500    1.008259    3.471179    0.223416    0.100292    0.016050    0.626421    
#> 090: 0.437660    0.993102    3.463215    0.221649    0.099134    0.016352    0.627368    
#> 091: 0.422920    0.987056    3.456901    0.234050    0.104953    0.015535    0.635330    
#> 092: 0.441009    1.023543    3.457929    0.222348    0.102807    0.016008    0.638262    
#> 093: 0.420941    1.015243    3.463545    0.211230    0.119504    0.015874    0.648627    
#> 094: 0.416036    1.026858    3.449539    0.200669    0.124534    0.015081    0.650717    
#> 095: 0.427697    1.031098    3.459610    0.190635    0.118308    0.014327    0.650171    
#> 096: 0.407491    1.023169    3.460945    0.181104    0.112392    0.014965    0.641528    
#> 097: 0.435189    1.028454    3.467459    0.172048    0.108779    0.014217    0.641794    
#> 098: 0.416104    1.044214    3.465176    0.163446    0.109881    0.013506    0.647621    
#> 099: 0.409185    1.001926    3.449769    0.155851    0.104387    0.012831    0.648894    
#> 100: 0.416578    1.017821    3.454745    0.150112    0.105806    0.012189    0.635615    
#> 101: 0.388841    1.007425    3.439881    0.151216    0.100516    0.012330    0.644035    
#> 102: 0.401620    1.025521    3.442983    0.163422    0.110036    0.016340    0.654792    
#> 103: 0.413346    1.021190    3.456254    0.176677    0.104534    0.015523    0.648702    
#> 104: 0.450557    1.008232    3.479035    0.203249    0.102284    0.014747    0.645090    
#> 105: 0.469568    1.009562    3.479046    0.193087    0.114983    0.014010    0.630182    
#> 106: 0.475360    0.991537    3.477021    0.222105    0.126049    0.013309    0.626490    
#> 107: 0.500691    0.995021    3.481485    0.210999    0.122098    0.013132    0.624234    
#> 108: 0.459425    0.993664    3.482241    0.200449    0.125623    0.012635    0.634685    
#> 109: 0.462219    1.014194    3.486161    0.212098    0.136804    0.012003    0.633942    
#> 110: 0.456419    0.983501    3.476668    0.201493    0.139388    0.011403    0.645228    
#> 111: 0.462839    0.976364    3.480255    0.191419    0.151217    0.011191    0.636330    
#> 112: 0.438164    0.978343    3.472562    0.181848    0.143656    0.011113    0.647371    
#> 113: 0.452596    1.030635    3.479136    0.172755    0.136474    0.010557    0.638173    
#> 114: 0.460377    1.012584    3.481822    0.164118    0.148391    0.010029    0.637557    
#> 115: 0.498606    0.985647    3.486943    0.164779    0.142973    0.011603    0.654841    
#> 116: 0.482809    1.007006    3.485025    0.161069    0.135825    0.011832    0.659233    
#> 117: 0.457634    1.022332    3.479070    0.168481    0.132188    0.011808    0.657721    
#> 118: 0.469912    0.983288    3.481465    0.218760    0.125578    0.013013    0.625708    
#> 119: 0.462172    1.001492    3.476366    0.237523    0.119300    0.015270    0.634705    
#> 120: 0.434543    0.999326    3.464525    0.241459    0.113335    0.016372    0.630715    
#> 121: 0.462664    1.018582    3.477608    0.235840    0.111003    0.015553    0.641378    
#> 122: 0.474554    0.982175    3.489745    0.224048    0.105453    0.016444    0.637198    
#> 123: 0.498509    1.003241    3.479150    0.245124    0.107365    0.018397    0.624609    
#> 124: 0.486369    1.048100    3.473943    0.232868    0.109760    0.020348    0.634435    
#> 125: 0.474237    1.043074    3.468246    0.221224    0.122794    0.021401    0.636970    
#> 126: 0.451232    1.044306    3.461455    0.210163    0.116654    0.020584    0.642415    
#> 127: 0.430707    1.008799    3.449058    0.204885    0.110822    0.019555    0.648953    
#> 128: 0.428321    1.014680    3.469946    0.206176    0.105280    0.022368    0.642406    
#> 129: 0.471160    1.005446    3.475341    0.201255    0.105434    0.023095    0.646497    
#> 130: 0.504669    1.001526    3.477912    0.211108    0.100162    0.025045    0.625672    
#> 131: 0.492674    0.986649    3.482109    0.212260    0.095154    0.027430    0.629002    
#> 132: 0.447764    1.000255    3.462166    0.201647    0.104603    0.026058    0.630448    
#> 133: 0.473096    0.991361    3.477783    0.220238    0.101911    0.024755    0.627807    
#> 134: 0.486301    0.986277    3.492517    0.235226    0.096815    0.025372    0.609473    
#> 135: 0.501060    0.979974    3.493630    0.223464    0.091975    0.026249    0.611110    
#> 136: 0.505784    0.974794    3.494114    0.232962    0.087376    0.027412    0.611063    
#> 137: 0.507954    0.976789    3.494065    0.223193    0.083007    0.026997    0.623122    
#> 138: 0.468615    0.988186    3.483673    0.212033    0.078857    0.027027    0.627461    
#> 139: 0.503412    0.990775    3.497361    0.212803    0.083027    0.027109    0.639827    
#> 140: 0.492686    0.987900    3.492189    0.206699    0.093151    0.025753    0.650131    
#> 141: 0.470657    0.977906    3.497258    0.196364    0.091773    0.024466    0.643624    
#> 142: 0.484215    0.978861    3.501622    0.187591    0.098009    0.023243    0.641209    
#> 143: 0.464303    1.008935    3.477981    0.194244    0.120257    0.022080    0.635545    
#> 144: 0.491908    1.009641    3.481715    0.214356    0.114244    0.020976    0.611999    
#> 145: 0.486212    0.998275    3.477189    0.210689    0.124995    0.019928    0.615861    
#> 146: 0.441436    0.993363    3.480633    0.223002    0.118745    0.020442    0.629043    
#> 147: 0.439774    0.992831    3.469766    0.244215    0.112808    0.019492    0.618985    
#> 148: 0.438666    0.997988    3.480326    0.232753    0.107167    0.018517    0.631905    
#> 149: 0.438386    0.982672    3.481509    0.228466    0.109190    0.021086    0.615586    
#> 150: 0.479917    1.001464    3.473578    0.239842    0.119325    0.020031    0.617856    
#> 151: 0.433653    1.025167    3.471784    0.227850    0.113359    0.019905    0.622097    
#> 152: 0.462886    1.015357    3.479169    0.199390    0.103612    0.022993    0.605811    
#> 153: 0.474225    1.008320    3.482662    0.213885    0.096579    0.025744    0.625772    
#> 154: 0.497184    1.006455    3.481587    0.205014    0.089549    0.024028    0.631964    
#> 155: 0.447940    1.000533    3.478809    0.177821    0.089605    0.023948    0.625474    
#> 156: 0.473616    1.001273    3.469498    0.209414    0.089229    0.023150    0.629001    
#> 157: 0.451113    0.994628    3.474730    0.179329    0.091132    0.025929    0.645859    
#> 158: 0.465546    1.020835    3.466990    0.196605    0.107513    0.025646    0.626550    
#> 159: 0.436334    1.024088    3.472534    0.178316    0.109751    0.023186    0.636474    
#> 160: 0.452677    0.985243    3.484783    0.171194    0.115274    0.026010    0.631020    
#> 161: 0.458012    0.997743    3.481744    0.151722    0.109001    0.028110    0.650191    
#> 162: 0.464263    0.991691    3.475547    0.166651    0.094480    0.029666    0.644959    
#> 163: 0.481238    0.993469    3.483304    0.167067    0.078917    0.026199    0.654096    
#> 164: 0.485814    0.997552    3.481638    0.194518    0.085990    0.021946    0.638773    
#> 165: 0.508875    0.986578    3.492838    0.195250    0.101117    0.021228    0.641505    
#> 166: 0.483150    1.017932    3.471443    0.187229    0.101221    0.017577    0.647057    
#> 167: 0.498551    1.008101    3.491285    0.197058    0.113633    0.019044    0.645751    
#> 168: 0.516841    1.009387    3.501344    0.200750    0.100664    0.020518    0.648382    
#> 169: 0.502844    1.029309    3.486915    0.204701    0.113995    0.019493    0.646694    
#> 170: 0.487831    1.013054    3.487636    0.200353    0.104639    0.020403    0.620583    
#> 171: 0.457017    0.999804    3.475626    0.195754    0.122176    0.018284    0.620113    
#> 172: 0.450165    1.011765    3.469325    0.220300    0.103341    0.018432    0.624045    
#> 173: 0.446587    1.023834    3.467275    0.205319    0.109863    0.018638    0.613580    
#> 174: 0.479131    1.006587    3.480435    0.212413    0.116317    0.021105    0.613833    
#> 175: 0.464200    1.005786    3.475482    0.226744    0.122290    0.020483    0.620736    
#> 176: 0.492386    1.028916    3.489152    0.238789    0.116473    0.018732    0.607431    
#> 177: 0.493380    0.985343    3.495365    0.179446    0.127073    0.019336    0.626520    
#> 178: 0.509453    0.981522    3.494930    0.231251    0.116403    0.019489    0.612011    
#> 179: 0.529018    1.024848    3.489094    0.182799    0.107113    0.016129    0.655951    
#> 180: 0.492818    1.015774    3.485786    0.233598    0.106814    0.015817    0.645705    
#> 181: 0.511572    1.002950    3.477778    0.209731    0.094690    0.015542    0.647342    
#> 182: 0.455522    1.007510    3.463172    0.184865    0.110313    0.012905    0.653012    
#> 183: 0.470451    1.039394    3.469872    0.172606    0.106463    0.012073    0.651859    
#> 184: 0.455697    0.999582    3.473952    0.150270    0.110797    0.011856    0.644772    
#> 185: 0.430331    1.013972    3.468222    0.165951    0.106217    0.012063    0.637574    
#> 186: 0.454772    1.031927    3.472043    0.179960    0.125813    0.013116    0.652166    
#> 187: 0.472164    1.008124    3.477496    0.190506    0.110824    0.014831    0.631731    
#> 188: 0.438020    1.025576    3.473677    0.189481    0.109595    0.013921    0.643563    
#> 189: 0.466961    1.021623    3.475129    0.195760    0.105465    0.016126    0.648231    
#> 190: 0.464886    1.019750    3.476747    0.217101    0.105018    0.016044    0.604748    
#> 191: 0.433613    1.010052    3.469559    0.161247    0.094630    0.015091    0.614736    
#> 192: 0.435098    1.009008    3.478688    0.161216    0.127923    0.014063    0.634015    
#> 193: 0.468037    1.016957    3.477020    0.165726    0.113745    0.013933    0.629946    
#> 194: 0.438836    1.009507    3.473606    0.171276    0.111720    0.012181    0.648714    
#> 195: 0.430412    1.000198    3.458638    0.200262    0.081475    0.013323    0.657526    
#> 196: 0.444874    1.009437    3.471794    0.194232    0.110417    0.012942    0.642646    
#> 197: 0.422290    0.998221    3.486158    0.200240    0.107821    0.015752    0.662264    
#> 198: 0.461253    0.982773    3.477919    0.178887    0.111022    0.017273    0.645469    
#> 199: 0.476612    0.988710    3.482722    0.190293    0.121027    0.015295    0.653147    
#> 200: 0.483174    0.984725    3.492047    0.186086    0.134197    0.016932    0.662719    
#> 201: 0.496387    0.977137    3.498397    0.192134    0.126357    0.016467    0.660723    
#> 202: 0.501915    0.981454    3.496219    0.204743    0.122890    0.018333    0.656404    
#> 203: 0.511925    0.983793    3.496580    0.212568    0.121907    0.018805    0.649873    
#> 204: 0.515156    0.978092    3.497156    0.214650    0.115879    0.018691    0.650272    
#> 205: 0.513120    0.981237    3.498841    0.206282    0.116503    0.019374    0.651218    
#> 206: 0.514247    0.982895    3.500685    0.201365    0.115036    0.019188    0.654350    
#> 207: 0.509458    0.982698    3.498863    0.200150    0.112550    0.019390    0.654277    
#> 208: 0.509269    0.983256    3.498360    0.202167    0.109950    0.020347    0.651883    
#> 209: 0.510995    0.980624    3.498153    0.203098    0.106914    0.021065    0.649995    
#> 210: 0.512014    0.979561    3.498176    0.203446    0.106074    0.021226    0.647438    
#> 211: 0.510650    0.981065    3.498605    0.201887    0.104555    0.021357    0.645997    
#> 212: 0.510743    0.981411    3.498614    0.201061    0.104091    0.021469    0.645554    
#> 213: 0.512915    0.979291    3.499233    0.201072    0.103221    0.021620    0.645303    
#> 214: 0.516022    0.978587    3.500078    0.201324    0.103803    0.022006    0.644535    
#> 215: 0.516051    0.978777    3.500712    0.202017    0.103892    0.022311    0.644026    
#> 216: 0.516159    0.978383    3.500681    0.201366    0.103105    0.022223    0.645675    
#> 217: 0.515308    0.978826    3.500317    0.201698    0.102185    0.022103    0.644981    
#> 218: 0.514423    0.979608    3.499454    0.201710    0.102042    0.022014    0.643732    
#> 219: 0.513400    0.979397    3.498445    0.201791    0.101833    0.021901    0.643380    
#> 220: 0.511895    0.981208    3.497850    0.203361    0.101944    0.021917    0.642985    
#> 221: 0.509836    0.982335    3.497005    0.203967    0.101589    0.021758    0.642554    
#> 222: 0.508894    0.982373    3.496748    0.203770    0.101270    0.021622    0.641951    
#> 223: 0.509205    0.982032    3.496504    0.204423    0.100952    0.021637    0.641507    
#> 224: 0.509949    0.983440    3.496384    0.204260    0.101034    0.021597    0.641194    
#> 225: 0.509528    0.982541    3.496657    0.205631    0.101208    0.021568    0.641100    
#> 226: 0.509201    0.981962    3.496351    0.206089    0.101105    0.021423    0.640969    
#> 227: 0.508231    0.982116    3.496242    0.205675    0.101379    0.021322    0.640195    
#> 228: 0.506774    0.983508    3.495409    0.206287    0.101709    0.021327    0.639434    
#> 229: 0.505801    0.983435    3.494951    0.207493    0.101647    0.021262    0.639161    
#> 230: 0.506212    0.983409    3.494501    0.207706    0.101432    0.021169    0.639104    
#> 231: 0.505875    0.984131    3.494296    0.207973    0.101281    0.021120    0.638348    
#> 232: 0.504110    0.985118    3.493996    0.208746    0.100853    0.021108    0.638205    
#> 233: 0.503389    0.985121    3.493713    0.209430    0.100682    0.021178    0.638125    
#> 234: 0.502458    0.984936    3.493410    0.209720    0.100411    0.021233    0.637855    
#> 235: 0.501244    0.985064    3.492766    0.210088    0.100097    0.021203    0.637392    
#> 236: 0.500562    0.985778    3.492410    0.210401    0.100205    0.021252    0.637574    
#> 237: 0.500190    0.985943    3.492121    0.211304    0.100507    0.021299    0.637719    
#> 238: 0.499783    0.986337    3.491855    0.211365    0.100677    0.021281    0.637984    
#> 239: 0.499433    0.986634    3.491670    0.211536    0.100632    0.021263    0.637588    
#> 240: 0.499009    0.986765    3.491688    0.210754    0.100884    0.021217    0.637297    
#> 241: 0.498568    0.986400    3.491623    0.210060    0.100915    0.021161    0.637313    
#> 242: 0.497808    0.986147    3.491377    0.210538    0.101002    0.021129    0.637354    
#> 243: 0.497088    0.987036    3.490897    0.211474    0.101018    0.021096    0.637382    
#> 244: 0.495491    0.987480    3.490768    0.212056    0.101216    0.021074    0.637373    
#> 245: 0.495387    0.987517    3.490685    0.212527    0.101482    0.020990    0.637556    
#> 246: 0.494760    0.987713    3.490560    0.211887    0.101289    0.021020    0.637479    
#> 247: 0.494205    0.987926    3.490550    0.211694    0.101091    0.021059    0.637404    
#> 248: 0.493872    0.988350    3.490410    0.211609    0.101156    0.021026    0.637202    
#> 249: 0.493365    0.988504    3.490347    0.211624    0.101018    0.020996    0.636987    
#> 250: 0.493665    0.988818    3.490304    0.211957    0.101008    0.020927    0.636810    
#> 251: 0.494377    0.989193    3.490562    0.211827    0.100891    0.020863    0.636738    
#> 252: 0.495344    0.989325    3.491029    0.211790    0.100935    0.020918    0.636685    
#> 253: 0.495681    0.989385    3.491057    0.212118    0.100866    0.020996    0.636416    
#> 254: 0.495376    0.989654    3.491017    0.212198    0.101133    0.020953    0.636079    
#> 255: 0.494992    0.990128    3.490889    0.212785    0.101503    0.020956    0.635896    
#> 256: 0.494989    0.990205    3.490673    0.213434    0.101642    0.020950    0.635680    
#> 257: 0.494348    0.990110    3.490440    0.213457    0.101507    0.020888    0.635703    
#> 258: 0.493831    0.990057    3.490314    0.213920    0.101405    0.020784    0.635748    
#> 259: 0.493133    0.990291    3.490067    0.214521    0.101476    0.020703    0.635584    
#> 260: 0.492643    0.990551    3.489909    0.214812    0.101446    0.020641    0.635359    
#> 261: 0.492654    0.990530    3.489787    0.215442    0.101518    0.020635    0.635165    
#> 262: 0.492853    0.990890    3.489749    0.216012    0.101587    0.020616    0.634873    
#> 263: 0.492149    0.991245    3.489627    0.216732    0.101622    0.020632    0.634778    
#> 264: 0.491900    0.991327    3.489468    0.217232    0.101756    0.020570    0.634912    
#> 265: 0.492039    0.991641    3.489324    0.217038    0.102112    0.020516    0.634802    
#> 266: 0.491814    0.991988    3.489244    0.217134    0.102066    0.020547    0.634835    
#> 267: 0.491721    0.991868    3.489463    0.216989    0.102166    0.020533    0.634894    
#> 268: 0.491771    0.991567    3.489463    0.217165    0.102194    0.020520    0.634825    
#> 269: 0.492499    0.991383    3.489534    0.217496    0.102262    0.020512    0.634847    
#> 270: 0.492555    0.991462    3.489366    0.217284    0.102279    0.020458    0.634711    
#> 271: 0.492239    0.991548    3.489135    0.217579    0.102248    0.020399    0.635081    
#> 272: 0.491781    0.991313    3.488913    0.217725    0.102207    0.020422    0.635405    
#> 273: 0.491449    0.991695    3.488870    0.217957    0.102305    0.020419    0.635595    
#> 274: 0.491114    0.992046    3.488887    0.218375    0.102356    0.020434    0.635427    
#> 275: 0.490984    0.992247    3.488677    0.218432    0.102415    0.020450    0.635396    
#> 276: 0.490551    0.992467    3.488723    0.218677    0.102288    0.020426    0.635242    
#> 277: 0.489943    0.992687    3.488647    0.218676    0.102197    0.020415    0.635342    
#> 278: 0.489448    0.992564    3.488681    0.218392    0.102078    0.020373    0.635345    
#> 279: 0.489167    0.992337    3.488685    0.218359    0.102050    0.020405    0.635249    
#> 280: 0.488897    0.992463    3.488607    0.218366    0.102193    0.020413    0.634995    
#> 281: 0.488356    0.992612    3.488462    0.218551    0.102243    0.020413    0.634949    
#> 282: 0.488082    0.992989    3.488419    0.218283    0.102390    0.020396    0.635098    
#> 283: 0.488202    0.993257    3.488453    0.218221    0.102192    0.020406    0.635408    
#> 284: 0.487825    0.993374    3.488364    0.218349    0.102142    0.020401    0.635436    
#> 285: 0.487234    0.993685    3.488024    0.218243    0.102161    0.020372    0.635748    
#> 286: 0.486616    0.994044    3.487690    0.218029    0.102086    0.020341    0.635827    
#> 287: 0.485999    0.994320    3.487387    0.217704    0.102154    0.020315    0.635756    
#> 288: 0.485838    0.994452    3.487221    0.217568    0.102131    0.020306    0.635879    
#> 289: 0.485981    0.994335    3.487175    0.217414    0.102106    0.020298    0.635933    
#> 290: 0.486145    0.994395    3.487155    0.217408    0.102280    0.020270    0.635997    
#> 291: 0.486229    0.994543    3.487275    0.217304    0.102261    0.020278    0.635773    
#> 292: 0.486141    0.994406    3.487274    0.217332    0.102133    0.020301    0.635625    
#> 293: 0.485942    0.994377    3.487162    0.217298    0.102163    0.020282    0.635511    
#> 294: 0.485698    0.994497    3.486989    0.217224    0.102141    0.020243    0.635485    
#> 295: 0.485635    0.994444    3.486899    0.217003    0.102275    0.020228    0.635335    
#> 296: 0.485510    0.994587    3.486729    0.216808    0.102303    0.020221    0.635305    
#> 297: 0.485424    0.994884    3.486620    0.216701    0.102281    0.020228    0.635143    
#> 298: 0.485410    0.994910    3.486501    0.216286    0.102316    0.020174    0.635054    
#> 299: 0.485188    0.994984    3.486326    0.215927    0.102277    0.020125    0.635015    
#> 300: 0.485199    0.994866    3.486301    0.215661    0.102312    0.020071    0.635061    
#> 301: 0.485540    0.994839    3.486232    0.215411    0.102394    0.020020    0.635154    
#> 302: 0.485578    0.994901    3.486216    0.215251    0.102341    0.019986    0.634999    
#> 303: 0.485356    0.995078    3.486154    0.215082    0.102366    0.019997    0.634765    
#> 304: 0.485320    0.995427    3.485961    0.215103    0.102299    0.019984    0.634716    
#> 305: 0.484899    0.995295    3.485858    0.214831    0.102305    0.019954    0.634658    
#> 306: 0.484334    0.995365    3.485627    0.214699    0.102405    0.019871    0.634673    
#> 307: 0.483927    0.995446    3.485404    0.215090    0.102674    0.019803    0.634868    
#> 308: 0.483498    0.995409    3.485274    0.214975    0.102830    0.019760    0.635064    
#> 309: 0.483386    0.995361    3.485205    0.214572    0.102857    0.019720    0.635247    
#> 310: 0.483406    0.995373    3.485111    0.214541    0.102780    0.019672    0.635367    
#> 311: 0.483338    0.995394    3.485078    0.214531    0.102803    0.019636    0.635316    
#> 312: 0.483189    0.995450    3.485003    0.214226    0.102816    0.019598    0.635262    
#> 313: 0.483305    0.995359    3.484981    0.214264    0.102755    0.019564    0.635396    
#> 314: 0.483109    0.995473    3.484901    0.214044    0.102769    0.019544    0.635528    
#> 315: 0.483051    0.995606    3.484913    0.213730    0.102772    0.019523    0.635570    
#> 316: 0.483138    0.995667    3.484893    0.213437    0.102792    0.019522    0.635613    
#> 317: 0.483205    0.995626    3.484925    0.213326    0.102766    0.019552    0.635612    
#> 318: 0.483202    0.995674    3.484889    0.212952    0.102848    0.019563    0.635605    
#> 319: 0.483171    0.995671    3.484910    0.212623    0.102949    0.019539    0.635683    
#> 320: 0.482889    0.995691    3.484813    0.212632    0.103050    0.019510    0.635722    
#> 321: 0.482528    0.995821    3.484661    0.212529    0.103074    0.019469    0.635821    
#> 322: 0.482335    0.995925    3.484512    0.212251    0.103167    0.019434    0.635890    
#> 323: 0.481758    0.996046    3.484366    0.212125    0.103176    0.019414    0.635871    
#> 324: 0.481610    0.996199    3.484273    0.212032    0.103219    0.019398    0.635752    
#> 325: 0.481302    0.996489    3.484093    0.211714    0.103235    0.019386    0.635701    
#> 326: 0.481064    0.996465    3.483990    0.211441    0.103284    0.019361    0.635676    
#> 327: 0.480940    0.996646    3.483996    0.210974    0.103241    0.019356    0.635758    
#> 328: 0.481026    0.996800    3.483996    0.210760    0.103349    0.019343    0.635657    
#> 329: 0.480948    0.996865    3.483961    0.210552    0.103507    0.019308    0.635593    
#> 330: 0.480759    0.996870    3.483869    0.210411    0.103670    0.019272    0.635869    
#> 331: 0.480661    0.996934    3.483798    0.210300    0.103736    0.019251    0.636009    
#> 332: 0.480437    0.997131    3.483721    0.209855    0.103847    0.019188    0.636313    
#> 333: 0.480071    0.997218    3.483581    0.209638    0.103941    0.019157    0.636397    
#> 334: 0.479679    0.997245    3.483414    0.209458    0.104156    0.019122    0.636445    
#> 335: 0.479260    0.997410    3.483211    0.209080    0.104284    0.019084    0.636372    
#> 336: 0.478739    0.997742    3.483035    0.208810    0.104485    0.019056    0.636369    
#> 337: 0.478453    0.998059    3.482876    0.208523    0.104647    0.019033    0.636400    
#> 338: 0.478287    0.998266    3.482823    0.208387    0.104770    0.019036    0.636411    
#> 339: 0.478086    0.998387    3.482758    0.208248    0.104817    0.019048    0.636387    
#> 340: 0.477977    0.998218    3.482730    0.208358    0.104874    0.019054    0.636316    
#> 341: 0.477813    0.998259    3.482731    0.208517    0.104894    0.019060    0.636311    
#> 342: 0.477659    0.998051    3.482706    0.208531    0.104843    0.019062    0.636230    
#> 343: 0.477475    0.998060    3.482689    0.208583    0.104789    0.019072    0.636154    
#> 344: 0.477631    0.997970    3.482719    0.208580    0.104757    0.019093    0.636123    
#> 345: 0.477684    0.997966    3.482735    0.208678    0.104745    0.019095    0.636028    
#> 346: 0.477523    0.998034    3.482651    0.208827    0.104686    0.019101    0.636023    
#> 347: 0.477424    0.998051    3.482524    0.208913    0.104647    0.019125    0.636089    
#> 348: 0.477336    0.998143    3.482420    0.208973    0.104545    0.019130    0.636186    
#> 349: 0.477118    0.998129    3.482348    0.208935    0.104461    0.019124    0.636155    
#> 350: 0.476980    0.998135    3.482261    0.208948    0.104514    0.019096    0.636137    
#> 351: 0.477017    0.998315    3.482180    0.209094    0.104504    0.019084    0.636146    
#> 352: 0.476794    0.998528    3.482136    0.209181    0.104541    0.019084    0.636214    
#> 353: 0.476626    0.998793    3.481983    0.209150    0.104531    0.019076    0.636295    
#> 354: 0.476443    0.999043    3.481818    0.209183    0.104553    0.019105    0.636233    
#> 355: 0.476733    0.999069    3.481762    0.209473    0.104481    0.019116    0.636242    
#> 356: 0.476618    0.999062    3.481721    0.209622    0.104543    0.019104    0.636380    
#> 357: 0.476611    0.999132    3.481687    0.209535    0.104606    0.019081    0.636371    
#> 358: 0.476467    0.999245    3.481620    0.209423    0.104623    0.019088    0.636270    
#> 359: 0.476124    0.999511    3.481500    0.209230    0.104662    0.019088    0.636204    
#> 360: 0.475779    0.999640    3.481335    0.209040    0.104602    0.019092    0.636108    
#> 361: 0.475627    0.999784    3.481262    0.208836    0.104575    0.019092    0.636079    
#> 362: 0.475503    0.999826    3.481217    0.208710    0.104558    0.019095    0.635977    
#> 363: 0.475327    0.999793    3.481189    0.208700    0.104593    0.019096    0.635839    
#> 364: 0.475459    0.999762    3.481199    0.208824    0.104588    0.019117    0.635808    
#> 365: 0.475416    0.999613    3.481221    0.208834    0.104560    0.019141    0.635839    
#> 366: 0.475375    0.999666    3.481125    0.208931    0.104529    0.019174    0.635932    
#> 367: 0.475364    0.999636    3.481107    0.208974    0.104624    0.019164    0.635982    
#> 368: 0.475613    0.999641    3.481114    0.209072    0.104545    0.019146    0.636013    
#> 369: 0.475751    0.999585    3.481147    0.209118    0.104478    0.019138    0.636036    
#> 370: 0.475809    0.999627    3.481166    0.209140    0.104378    0.019167    0.636063    
#> 371: 0.475821    0.999786    3.481126    0.208868    0.104422    0.019154    0.636052    
#> 372: 0.475783    0.999873    3.481045    0.208744    0.104486    0.019142    0.636081    
#> 373: 0.475678    1.000048    3.480946    0.208847    0.104537    0.019124    0.636128    
#> 374: 0.475656    1.000082    3.480845    0.208964    0.104564    0.019089    0.636154    
#> 375: 0.475379    1.000130    3.480795    0.209045    0.104551    0.019068    0.636184    
#> 376: 0.475228    1.000199    3.480722    0.208932    0.104620    0.019038    0.636098    
#> 377: 0.474905    1.000307    3.480599    0.209030    0.104776    0.018994    0.636070    
#> 378: 0.474558    1.000392    3.480497    0.209046    0.104854    0.018971    0.636093    
#> 379: 0.474274    1.000301    3.480423    0.209185    0.104908    0.018938    0.636105    
#> 380: 0.474144    1.000216    3.480456    0.209045    0.104978    0.018922    0.636098    
#> 381: 0.473999    1.000143    3.480478    0.209160    0.104937    0.018917    0.636118    
#> 382: 0.474082    1.000112    3.480506    0.209279    0.104928    0.018918    0.636032    
#> 383: 0.474148    1.000096    3.480516    0.209388    0.104889    0.018926    0.635913    
#> 384: 0.473983    1.000051    3.480548    0.209586    0.104872    0.018944    0.635877    
#> 385: 0.474036    1.000042    3.480515    0.209719    0.104825    0.018936    0.635769    
#> 386: 0.474087    1.000126    3.480492    0.209809    0.104775    0.018932    0.635780    
#> 387: 0.474212    1.000207    3.480545    0.209971    0.104663    0.018938    0.635778    
#> 388: 0.474354    1.000168    3.480582    0.209820    0.104636    0.018920    0.635850    
#> 389: 0.474320    1.000051    3.480555    0.209724    0.104619    0.018910    0.635922    
#> 390: 0.474335    1.000111    3.480581    0.209779    0.104595    0.018938    0.635859    
#> 391: 0.474435    1.000064    3.480571    0.209840    0.104513    0.018953    0.635735    
#> 392: 0.474596    0.999982    3.480637    0.209883    0.104476    0.018949    0.635798    
#> 393: 0.474635    0.999840    3.480662    0.209744    0.104436    0.018947    0.635760    
#> 394: 0.474654    0.999776    3.480661    0.209765    0.104391    0.018968    0.635712    
#> 395: 0.474947    0.999775    3.480686    0.209841    0.104306    0.018988    0.635772    
#> 396: 0.475041    0.999722    3.480706    0.209721    0.104242    0.019020    0.635734    
#> 397: 0.475118    0.999611    3.480781    0.209684    0.104162    0.019059    0.635684    
#> 398: 0.475355    0.999547    3.480842    0.209751    0.104160    0.019073    0.635550    
#> 399: 0.475519    0.999545    3.480914    0.209739    0.104105    0.019058    0.635502    
#> 400: 0.475687    0.999532    3.480968    0.209682    0.104155    0.019038    0.635507    
#> 401: 0.475710    0.999635    3.480953    0.209716    0.104221    0.019033    0.635565    
#> 402: 0.475669    0.999769    3.480951    0.209721    0.104339    0.019022    0.635606    
#> 403: 0.475874    0.999796    3.480940    0.209645    0.104443    0.018997    0.635617    
#> 404: 0.475990    0.999809    3.480868    0.209639    0.104468    0.018972    0.635549    
#> 405: 0.475935    0.999862    3.480892    0.209525    0.104489    0.018949    0.635556    
#> 406: 0.475971    0.999824    3.480926    0.209647    0.104502    0.018942    0.635637    
#> 407: 0.476066    0.999844    3.480968    0.209622    0.104550    0.018923    0.635573    
#> 408: 0.476134    0.999837    3.480985    0.209641    0.104692    0.018904    0.635540    
#> 409: 0.476082    0.999790    3.480940    0.209799    0.104671    0.018889    0.635493    
#> 410: 0.475986    0.999798    3.480880    0.209964    0.104647    0.018892    0.635530    
#> 411: 0.476036    0.999638    3.480883    0.210049    0.104686    0.018895    0.635610    
#> 412: 0.476116    0.999612    3.480900    0.210151    0.104688    0.018907    0.635618    
#> 413: 0.476121    0.999597    3.480907    0.210203    0.104718    0.018897    0.635649    
#> 414: 0.476168    0.999526    3.480941    0.210148    0.104750    0.018902    0.635561    
#> 415: 0.476331    0.999413    3.480997    0.210071    0.104740    0.018920    0.635480    
#> 416: 0.476530    0.999365    3.481070    0.210114    0.104773    0.018917    0.635415    
#> 417: 0.476598    0.999322    3.481096    0.210042    0.104803    0.018912    0.635352    
#> 418: 0.476441    0.999315    3.481135    0.209905    0.104807    0.018896    0.635270    
#> 419: 0.476395    0.999350    3.481135    0.209631    0.104826    0.018879    0.635324    
#> 420: 0.476450    0.999394    3.481147    0.209454    0.104918    0.018863    0.635290    
#> 421: 0.476449    0.999366    3.481187    0.209299    0.104998    0.018842    0.635277    
#> 422: 0.476626    0.999232    3.481262    0.209254    0.105004    0.018837    0.635320    
#> 423: 0.476842    0.999076    3.481362    0.209315    0.105014    0.018848    0.635369    
#> 424: 0.476865    0.998967    3.481365    0.209290    0.105014    0.018838    0.635432    
#> 425: 0.476977    0.999003    3.481367    0.209366    0.104942    0.018846    0.635464    
#> 426: 0.477035    0.999081    3.481358    0.209362    0.104932    0.018826    0.635428    
#> 427: 0.476999    0.999018    3.481394    0.209305    0.104928    0.018836    0.635349    
#> 428: 0.476974    0.999029    3.481413    0.209475    0.104971    0.018841    0.635279    
#> 429: 0.477010    0.999081    3.481432    0.209547    0.104950    0.018840    0.635227    
#> 430: 0.476941    0.999099    3.481438    0.209483    0.105020    0.018852    0.635213    
#> 431: 0.476767    0.999084    3.481390    0.209481    0.104985    0.018856    0.635264    
#> 432: 0.476728    0.999116    3.481424    0.209626    0.104938    0.018887    0.635267    
#> 433: 0.476706    0.999253    3.481443    0.209659    0.104890    0.018901    0.635271    
#> 434: 0.476575    0.999182    3.481473    0.209654    0.104909    0.018912    0.635208    
#> 435: 0.476529    0.999162    3.481458    0.209659    0.104916    0.018920    0.635135    
#> 436: 0.476530    0.998979    3.481529    0.209686    0.104827    0.018933    0.635157    
#> 437: 0.476464    0.998886    3.481539    0.209614    0.104782    0.018926    0.635139    
#> 438: 0.476394    0.999018    3.481518    0.209475    0.104750    0.018907    0.635132    
#> 439: 0.476356    0.999073    3.481542    0.209200    0.104676    0.018904    0.635120    
#> 440: 0.476388    0.999113    3.481597    0.209057    0.104633    0.018903    0.635123    
#> 441: 0.476489    0.999084    3.481662    0.208885    0.104663    0.018904    0.635123    
#> 442: 0.476460    0.999114    3.481691    0.208828    0.104659    0.018911    0.635089    
#> 443: 0.476384    0.999262    3.481614    0.208581    0.104640    0.018888    0.635110    
#> 444: 0.476272    0.999449    3.481490    0.208402    0.104613    0.018868    0.635200    
#> 445: 0.476003    0.999572    3.481392    0.208172    0.104626    0.018846    0.635170    
#> 446: 0.475782    0.999676    3.481299    0.207857    0.104564    0.018832    0.635152    
#> 447: 0.475791    0.999721    3.481275    0.207724    0.104577    0.018823    0.635126    
#> 448: 0.475863    0.999678    3.481294    0.207617    0.104587    0.018817    0.635096    
#> 449: 0.475899    0.999739    3.481362    0.207504    0.104581    0.018816    0.635172    
#> 450: 0.475828    0.999765    3.481377    0.207423    0.104636    0.018808    0.635202    
#> 451: 0.475824    0.999737    3.481356    0.207286    0.104711    0.018806    0.635255    
#> 452: 0.475790    0.999735    3.481362    0.207179    0.104735    0.018794    0.635266    
#> 453: 0.475718    0.999712    3.481337    0.207061    0.104761    0.018779    0.635280    
#> 454: 0.475734    0.999904    3.481317    0.207028    0.104764    0.018774    0.635277    
#> 455: 0.475795    0.999935    3.481317    0.207096    0.104791    0.018764    0.635229    
#> 456: 0.475707    0.999977    3.481297    0.207134    0.104780    0.018759    0.635210    
#> 457: 0.475680    0.999941    3.481331    0.207107    0.104789    0.018758    0.635134    
#> 458: 0.475743    0.999994    3.481382    0.207073    0.104744    0.018761    0.635113    
#> 459: 0.475695    1.000051    3.481386    0.207057    0.104769    0.018770    0.635085    
#> 460: 0.475690    1.000055    3.481397    0.206992    0.104709    0.018785    0.635064    
#> 461: 0.475673    1.000056    3.481428    0.207013    0.104685    0.018788    0.635011    
#> 462: 0.475678    1.000053    3.481430    0.206997    0.104695    0.018782    0.635005    
#> 463: 0.475749    1.000090    3.481466    0.207003    0.104664    0.018780    0.635041    
#> 464: 0.475760    1.000097    3.481484    0.206969    0.104635    0.018774    0.634980    
#> 465: 0.475776    0.999910    3.481511    0.206923    0.104618    0.018766    0.635017    
#> 466: 0.475882    0.999841    3.481497    0.206888    0.104606    0.018761    0.635051    
#> 467: 0.475940    0.999827    3.481554    0.206846    0.104649    0.018752    0.635042    
#> 468: 0.476151    0.999783    3.481620    0.206837    0.104663    0.018752    0.635094    
#> 469: 0.476222    0.999811    3.481685    0.206770    0.104697    0.018758    0.635131    
#> 470: 0.476121    0.999818    3.481669    0.206680    0.104711    0.018748    0.635108    
#> 471: 0.475988    0.999796    3.481649    0.206659    0.104744    0.018724    0.635057    
#> 472: 0.476016    0.999763    3.481657    0.206666    0.104742    0.018715    0.635000    
#> 473: 0.475952    0.999750    3.481650    0.206588    0.104763    0.018718    0.634962    
#> 474: 0.475842    0.999755    3.481627    0.206468    0.104795    0.018719    0.635045    
#> 475: 0.475920    0.999813    3.481617    0.206457    0.104793    0.018718    0.635016    
#> 476: 0.475925    0.999839    3.481580    0.206383    0.104784    0.018712    0.635058    
#> 477: 0.475817    0.999855    3.481590    0.206320    0.104764    0.018711    0.634987    
#> 478: 0.475737    0.999871    3.481588    0.206390    0.104741    0.018699    0.634962    
#> 479: 0.475761    0.999918    3.481590    0.206468    0.104710    0.018699    0.634927    
#> 480: 0.475838    0.999844    3.481616    0.206585    0.104640    0.018704    0.634881    
#> 481: 0.475782    0.999824    3.481649    0.206564    0.104582    0.018716    0.634849    
#> 482: 0.475806    0.999839    3.481611    0.206666    0.104585    0.018727    0.634818    
#> 483: 0.475748    0.999742    3.481631    0.206607    0.104593    0.018729    0.634781    
#> 484: 0.475734    0.999664    3.481630    0.206507    0.104627    0.018717    0.634778    
#> 485: 0.475788    0.999683    3.481642    0.206427    0.104646    0.018715    0.634812    
#> 486: 0.475847    0.999741    3.481658    0.206334    0.104651    0.018709    0.634768    
#> 487: 0.476041    0.999716    3.481711    0.206362    0.104647    0.018708    0.634731    
#> 488: 0.476182    0.999629    3.481775    0.206411    0.104664    0.018711    0.634678    
#> 489: 0.476322    0.999542    3.481802    0.206336    0.104702    0.018720    0.634669    
#> 490: 0.476374    0.999509    3.481825    0.206341    0.104689    0.018728    0.634622    
#> 491: 0.476510    0.999519    3.481886    0.206392    0.104723    0.018718    0.634530    
#> 492: 0.476494    0.999563    3.481882    0.206355    0.104716    0.018706    0.634532    
#> 493: 0.476491    0.999565    3.481910    0.206380    0.104681    0.018707    0.634555    
#> 494: 0.476577    0.999657    3.481887    0.206411    0.104624    0.018695    0.634604    
#> 495: 0.476650    0.999666    3.481904    0.206400    0.104611    0.018692    0.634585    
#> 496: 0.476672    0.999765    3.481885    0.206461    0.104622    0.018691    0.634603    
#> 497: 0.476583    0.999807    3.481844    0.206508    0.104684    0.018678    0.634666    
#> 498: 0.476529    0.999843    3.481795    0.206535    0.104687    0.018663    0.634673    
#> 499: 0.476475    0.999921    3.481741    0.206554    0.104753    0.018645    0.634636    
#> 500: 0.476433    0.999948    3.481696    0.206497    0.104787    0.018623    0.634598    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.286906    0.964130    3.450558    0.392401    0.076736    0.016800    1.536356    
#> 002: 0.380734    1.017672    3.455091    0.372781    0.072899    0.015960    1.015360    
#> 003: 0.495532    1.018725    3.468605    0.354142    0.082840    0.015162    0.741651    
#> 004: 0.513799    1.060350    3.464710    0.336435    0.078698    0.014404    0.663132    
#> 005: 0.598621    1.039923    3.479050    0.379512    0.084807    0.013684    0.596152    
#> 006: 0.593795    1.027691    3.483832    0.360536    0.085473    0.013000    0.554321    
#> 007: 0.576597    1.038557    3.482848    0.347726    0.085524    0.015361    0.564660    
#> 008: 0.555681    1.047305    3.477057    0.419389    0.084651    0.015034    0.558667    
#> 009: 0.529547    1.021980    3.470738    0.407919    0.094003    0.014283    0.558785    
#> 010: 0.568908    1.032370    3.480185    0.389752    0.098979    0.016733    0.562287    
#> 011: 0.627547    1.045492    3.484838    0.452557    0.094030    0.019898    0.550111    
#> 012: 0.615559    1.041474    3.491337    0.474374    0.090815    0.019551    0.544760    
#> 013: 0.607001    1.045753    3.489742    0.454287    0.086275    0.018624    0.543150    
#> 014: 0.644393    1.034785    3.489073    0.514283    0.081961    0.017693    0.559321    
#> 015: 0.681553    1.031823    3.503163    0.493707    0.077863    0.016808    0.534105    
#> 016: 0.642976    1.029511    3.497329    0.474386    0.073970    0.015968    0.531567    
#> 017: 0.631693    1.049505    3.490085    0.456775    0.079065    0.015532    0.516768    
#> 018: 0.638035    1.053639    3.487136    0.463704    0.083026    0.017038    0.516216    
#> 019: 0.562028    1.044880    3.482768    0.440519    0.078875    0.016186    0.536121    
#> 020: 0.601936    1.039678    3.496125    0.418493    0.075165    0.016656    0.536692    
#> 021: 0.607328    1.028374    3.504183    0.397568    0.075128    0.016008    0.551916    
#> 022: 0.627637    1.033581    3.505966    0.379329    0.083841    0.015228    0.546944    
#> 023: 0.674066    1.030991    3.505091    0.433644    0.079649    0.015849    0.558826    
#> 024: 0.666684    1.048236    3.497302    0.460225    0.078954    0.015057    0.551411    
#> 025: 0.633599    1.041803    3.494516    0.437214    0.080788    0.014304    0.554085    
#> 026: 0.625225    1.069273    3.488336    0.429599    0.086452    0.017482    0.549276    
#> 027: 0.614774    1.063327    3.488431    0.460030    0.091934    0.016760    0.553468    
#> 028: 0.623684    1.049181    3.491765    0.453457    0.087337    0.019698    0.532979    
#> 029: 0.630758    1.048876    3.484590    0.462279    0.082970    0.018713    0.559161    
#> 030: 0.630881    1.057776    3.485873    0.519863    0.082104    0.019801    0.546460    
#> 031: 0.622546    1.037629    3.489956    0.538730    0.085161    0.022110    0.534214    
#> 032: 0.625147    1.032184    3.501915    0.511793    0.080903    0.021774    0.536347    
#> 033: 0.589085    1.036694    3.492454    0.486204    0.076857    0.020685    0.541160    
#> 034: 0.610946    1.050543    3.497759    0.461893    0.080161    0.019790    0.537236    
#> 035: 0.617921    1.026551    3.500087    0.438799    0.082789    0.018801    0.534269    
#> 036: 0.609099    1.038017    3.495237    0.416859    0.082816    0.017929    0.538491    
#> 037: 0.600755    1.036896    3.490847    0.396016    0.078675    0.020766    0.547463    
#> 038: 0.606696    1.055290    3.484690    0.458289    0.074741    0.022455    0.537139    
#> 039: 0.633099    1.042001    3.498017    0.509815    0.071004    0.025566    0.513444    
#> 040: 0.595822    1.042757    3.492302    0.484324    0.070949    0.024288    0.523439    
#> 041: 0.586363    1.040727    3.482199    0.460108    0.067402    0.023435    0.530045    
#> 042: 0.613627    1.035410    3.487299    0.442085    0.073247    0.022263    0.526193    
#> 043: 0.633500    1.036543    3.483985    0.458719    0.072555    0.021150    0.527275    
#> 044: 0.625944    1.043655    3.489340    0.438593    0.078764    0.020668    0.532217    
#> 045: 0.614555    1.045110    3.487893    0.435085    0.074826    0.021680    0.520977    
#> 046: 0.601601    1.048213    3.487759    0.413331    0.071215    0.020596    0.525877    
#> 047: 0.594099    1.055146    3.489562    0.405955    0.071353    0.019566    0.530322    
#> 048: 0.611361    1.049020    3.491570    0.452326    0.081743    0.018588    0.545404    
#> 049: 0.609684    1.030536    3.498022    0.438790    0.077656    0.019052    0.533645    
#> 050: 0.654310    1.006084    3.496794    0.450425    0.075529    0.019603    0.546574    
#> 051: 0.655235    1.025608    3.495180    0.489538    0.072876    0.019599    0.535027    
#> 052: 0.653705    1.033113    3.508672    0.465061    0.079880    0.018619    0.527298    
#> 053: 0.651787    1.018191    3.503071    0.480934    0.082715    0.017688    0.522622    
#> 054: 0.613446    1.026564    3.502068    0.456887    0.084145    0.017145    0.531364    
#> 055: 0.609916    1.035257    3.499699    0.434043    0.079938    0.018129    0.553022    
#> 056: 0.610887    1.018946    3.498871    0.412341    0.085986    0.017223    0.567743    
#> 057: 0.613477    1.026939    3.498742    0.435483    0.081686    0.017279    0.569918    
#> 058: 0.622079    1.031819    3.491635    0.428827    0.077602    0.016646    0.564787    
#> 059: 0.638377    1.006608    3.505192    0.419091    0.087642    0.019224    0.571297    
#> 060: 0.642761    0.998040    3.509152    0.398136    0.090744    0.018263    0.573161    
#> 061: 0.644673    1.030056    3.510767    0.394140    0.086207    0.019375    0.543103    
#> 062: 0.645531    1.029375    3.512551    0.409176    0.081897    0.019737    0.564168    
#> 063: 0.682651    1.013211    3.509115    0.440610    0.081487    0.018750    0.563657    
#> 064: 0.665363    1.025511    3.512169    0.418580    0.085926    0.017812    0.557430    
#> 065: 0.690211    1.012157    3.502237    0.413673    0.082772    0.016922    0.542786    
#> 066: 0.665655    1.029230    3.507240    0.404023    0.078633    0.016356    0.541394    
#> 067: 0.647417    1.026141    3.495258    0.450553    0.074702    0.018657    0.538146    
#> 068: 0.604109    1.051990    3.499745    0.457433    0.088542    0.017724    0.546822    
#> 069: 0.618790    1.055855    3.490950    0.439827    0.084115    0.019173    0.549772    
#> 070: 0.617183    1.047694    3.487985    0.429240    0.079909    0.022503    0.541704    
#> 071: 0.614812    1.047263    3.481995    0.497913    0.075914    0.022906    0.550013    
#> 072: 0.626225    1.026089    3.490977    0.504893    0.072118    0.024058    0.530821    
#> 073: 0.656700    1.034811    3.504169    0.611245    0.068512    0.022855    0.541469    
#> 074: 0.650542    1.022396    3.497092    0.580683    0.067242    0.021712    0.530792    
#> 075: 0.610198    1.027109    3.502404    0.551649    0.071063    0.022803    0.538054    
#> 076: 0.637350    1.026437    3.492087    0.524066    0.069946    0.021662    0.541359    
#> 077: 0.665484    1.021725    3.498038    0.519454    0.066449    0.021123    0.545640    
#> 078: 0.627729    1.054798    3.494911    0.529418    0.066613    0.022418    0.532011    
#> 079: 0.629132    1.038819    3.492052    0.502947    0.065579    0.021888    0.547915    
#> 080: 0.656154    1.038071    3.497379    0.501317    0.065689    0.026861    0.559353    
#> 081: 0.610007    1.040095    3.489959    0.486305    0.063709    0.025518    0.551777    
#> 082: 0.622500    1.041535    3.492130    0.461990    0.063876    0.028450    0.553537    
#> 083: 0.604189    1.050741    3.492540    0.438890    0.066997    0.029120    0.542332    
#> 084: 0.589599    1.062494    3.477678    0.443706    0.068927    0.027664    0.538622    
#> 085: 0.582689    1.062477    3.493038    0.421520    0.065480    0.026281    0.546122    
#> 086: 0.611617    1.031757    3.499733    0.433978    0.065556    0.024967    0.540470    
#> 087: 0.652667    1.033880    3.492718    0.530411    0.071843    0.023719    0.536365    
#> 088: 0.609663    1.036469    3.493343    0.503890    0.068251    0.022533    0.547306    
#> 089: 0.599011    1.043257    3.482832    0.478696    0.071264    0.021406    0.554066    
#> 090: 0.608555    1.019262    3.483800    0.462196    0.068973    0.020589    0.556632    
#> 091: 0.583509    1.026223    3.475351    0.439086    0.073734    0.022748    0.553496    
#> 092: 0.581975    1.053940    3.477160    0.417132    0.070048    0.021611    0.542183    
#> 093: 0.583442    1.038107    3.493608    0.414570    0.066545    0.021290    0.557698    
#> 094: 0.639090    1.044295    3.495327    0.404322    0.074253    0.020226    0.557099    
#> 095: 0.641438    1.048143    3.499865    0.384106    0.077664    0.019214    0.529093    
#> 096: 0.602967    1.046479    3.486621    0.421767    0.084749    0.018385    0.521583    
#> 097: 0.614694    1.071981    3.481366    0.440541    0.080511    0.020176    0.523697    
#> 098: 0.603496    1.060635    3.493306    0.438194    0.077141    0.022002    0.538456    
#> 099: 0.620899    1.028662    3.495013    0.465999    0.073284    0.024750    0.531830    
#> 100: 0.620280    1.025979    3.498417    0.442699    0.069620    0.023797    0.535686    
#> 101: 0.616127    1.025859    3.487248    0.420564    0.066139    0.025223    0.540285    
#> 102: 0.614604    1.032775    3.486870    0.399719    0.062832    0.023962    0.544768    
#> 103: 0.632466    1.043615    3.497237    0.456346    0.065424    0.022764    0.531006    
#> 104: 0.628255    1.048843    3.501694    0.483538    0.070909    0.021725    0.534619    
#> 105: 0.628842    1.028708    3.497600    0.459361    0.072974    0.020638    0.547995    
#> 106: 0.622237    1.027217    3.489622    0.494017    0.074975    0.019791    0.540324    
#> 107: 0.626910    1.056160    3.487498    0.487294    0.083839    0.018801    0.538625    
#> 108: 0.629358    1.033227    3.500404    0.462929    0.088128    0.017861    0.541340    
#> 109: 0.633676    1.039119    3.499907    0.456735    0.083722    0.016968    0.548151    
#> 110: 0.626939    1.007469    3.490200    0.433899    0.082710    0.016120    0.559920    
#> 111: 0.616739    1.016822    3.499298    0.412204    0.084988    0.015314    0.541491    
#> 112: 0.605040    1.007019    3.490819    0.405597    0.080739    0.015677    0.556547    
#> 113: 0.564418    1.035705    3.495789    0.385685    0.076702    0.015752    0.561442    
#> 114: 0.615518    1.034744    3.500596    0.392829    0.079438    0.016176    0.553465    
#> 115: 0.613751    1.024845    3.497123    0.373188    0.078954    0.016904    0.560581    
#> 116: 0.637316    1.042359    3.494182    0.362540    0.090634    0.016059    0.561319    
#> 117: 0.586781    1.066738    3.490826    0.399410    0.091629    0.015256    0.553468    
#> 118: 0.595632    1.043643    3.491455    0.453654    0.087047    0.018023    0.548622    
#> 119: 0.614630    1.043830    3.479616    0.466631    0.082695    0.021293    0.548774    
#> 120: 0.589421    1.036888    3.481159    0.443299    0.080664    0.022441    0.543628    
#> 121: 0.635970    1.064428    3.489239    0.452403    0.084741    0.022121    0.523426    
#> 122: 0.637393    1.031958    3.490701    0.508452    0.080504    0.022279    0.531591    
#> 123: 0.663979    1.062197    3.489292    0.519651    0.080897    0.021165    0.548094    
#> 124: 0.631808    1.062984    3.486380    0.513419    0.079866    0.020533    0.544428    
#> 125: 0.620549    1.040531    3.480650    0.487748    0.079326    0.019506    0.535971    
#> 126: 0.599062    1.073281    3.472560    0.463361    0.085754    0.018531    0.553322    
#> 127: 0.624460    1.041774    3.487966    0.440193    0.085749    0.017817    0.559683    
#> 128: 0.612502    1.033886    3.500436    0.418183    0.081461    0.020539    0.550770    
#> 129: 0.614018    1.028986    3.503492    0.397274    0.077388    0.019513    0.553064    
#> 130: 0.663249    1.025743    3.508062    0.377410    0.073519    0.018537    0.537918    
#> 131: 0.660424    1.021471    3.497314    0.407654    0.080578    0.019458    0.533687    
#> 132: 0.606401    1.052468    3.485036    0.387271    0.076549    0.018485    0.542004    
#> 133: 0.600785    1.046472    3.489763    0.394132    0.072722    0.020080    0.541384    
#> 134: 0.626552    1.034879    3.503840    0.405884    0.069085    0.022955    0.540300    
#> 135: 0.622635    1.031068    3.500510    0.399347    0.065631    0.023850    0.546660    
#> 136: 0.637944    1.028089    3.499923    0.383463    0.074743    0.022658    0.533051    
#> 137: 0.647046    1.017707    3.511427    0.364290    0.071006    0.021572    0.553337    
#> 138: 0.614845    1.040459    3.499354    0.358576    0.067455    0.022572    0.548913    
#> 139: 0.617284    1.035883    3.499402    0.411612    0.064083    0.026081    0.533416    
#> 140: 0.625330    1.036315    3.505559    0.422244    0.060878    0.025965    0.529236    
#> 141: 0.625595    1.019060    3.506603    0.461865    0.057835    0.026576    0.535952    
#> 142: 0.673103    1.012729    3.519547    0.438772    0.061968    0.026819    0.537954    
#> 143: 0.646751    1.025403    3.511202    0.431849    0.067969    0.025478    0.553507    
#> 144: 0.652375    1.035871    3.513860    0.435789    0.064571    0.024782    0.546302    
#> 145: 0.620321    1.036339    3.492194    0.458461    0.061342    0.024554    0.538010    
#> 146: 0.612856    1.051557    3.488231    0.490728    0.067619    0.023326    0.543473    
#> 147: 0.594199    1.053705    3.482468    0.466191    0.080011    0.022160    0.527292    
#> 148: 0.590886    1.048638    3.494552    0.448394    0.076011    0.021052    0.526634    
#> 149: 0.580391    1.047329    3.487843    0.457583    0.072210    0.019999    0.523132    
#> 150: 0.614503    1.048187    3.476725    0.510423    0.072565    0.018999    0.529956    
#> 151: 0.591359    1.067076    3.481906    0.484902    0.074390    0.018049    0.531429    
#> 152: 0.617382    1.042853    3.491530    0.470256    0.067646    0.017664    0.535145    
#> 153: 0.638381    1.031825    3.501655    0.507188    0.068392    0.018133    0.549814    
#> 154: 0.628439    1.029463    3.496262    0.466289    0.062321    0.021191    0.555641    
#> 155: 0.603132    1.019495    3.491198    0.401848    0.054239    0.023998    0.548759    
#> 156: 0.616360    1.029395    3.499640    0.414972    0.055984    0.024369    0.559617    
#> 157: 0.615878    1.029206    3.499370    0.416001    0.057068    0.023036    0.539304    
#> 158: 0.665866    1.040244    3.499259    0.444343    0.070695    0.019702    0.537979    
#> 159: 0.629516    1.028266    3.506312    0.451196    0.071057    0.017945    0.549952    
#> 160: 0.658486    1.000655    3.514802    0.447061    0.077880    0.020271    0.544596    
#> 161: 0.631907    1.028991    3.508024    0.394450    0.081571    0.020553    0.542398    
#> 162: 0.611247    1.014302    3.499268    0.380636    0.079835    0.017313    0.550054    
#> 163: 0.625469    1.028381    3.497563    0.369733    0.093923    0.016027    0.550618    
#> 164: 0.633669    1.019508    3.495064    0.390903    0.075944    0.015567    0.532028    
#> 165: 0.645115    1.029331    3.516580    0.364272    0.073337    0.018139    0.543687    
#> 166: 0.673290    1.047068    3.510107    0.373769    0.075033    0.016746    0.554697    
#> 167: 0.690896    1.048633    3.519355    0.422816    0.075698    0.018682    0.536782    
#> 168: 0.679011    1.038647    3.516298    0.451057    0.079941    0.018476    0.526255    
#> 169: 0.653586    1.062275    3.500607    0.408487    0.081386    0.014233    0.542999    
#> 170: 0.654685    1.041619    3.500056    0.416809    0.075220    0.016082    0.550735    
#> 171: 0.614975    1.026174    3.494783    0.434243    0.079103    0.016386    0.537088    
#> 172: 0.618951    1.032207    3.496757    0.468928    0.086705    0.015922    0.533336    
#> 173: 0.648813    1.045050    3.495918    0.492815    0.078317    0.016054    0.523923    
#> 174: 0.672883    1.032922    3.509802    0.501592    0.078595    0.015163    0.538960    
#> 175: 0.677324    1.020420    3.502923    0.487898    0.064181    0.019418    0.535819    
#> 176: 0.638374    1.037760    3.508943    0.404659    0.059688    0.020830    0.534509    
#> 177: 0.660118    1.034954    3.508450    0.387628    0.071550    0.016739    0.541717    
#> 178: 0.646507    1.019869    3.501599    0.365267    0.063805    0.019278    0.544566    
#> 179: 0.679273    1.053844    3.504641    0.334995    0.069153    0.018002    0.561411    
#> 180: 0.621054    1.037842    3.509238    0.413280    0.073712    0.015024    0.556094    
#> 181: 0.641185    1.037862    3.487332    0.421592    0.072310    0.013653    0.545200    
#> 182: 0.596598    1.042997    3.483865    0.421591    0.071535    0.015085    0.576772    
#> 183: 0.624602    1.052068    3.486042    0.386575    0.063654    0.018785    0.579614    
#> 184: 0.618406    1.032625    3.497373    0.355743    0.070045    0.018390    0.562307    
#> 185: 0.613138    1.050098    3.487197    0.403431    0.070337    0.016450    0.562728    
#> 186: 0.603444    1.047657    3.495047    0.392713    0.076322    0.017538    0.564713    
#> 187: 0.631643    1.026824    3.504376    0.386157    0.074508    0.019377    0.539987    
#> 188: 0.629012    1.043559    3.496908    0.431067    0.072974    0.019639    0.550866    
#> 189: 0.598661    1.052116    3.500497    0.342952    0.075185    0.023565    0.551687    
#> 190: 0.605898    1.042276    3.504244    0.369565    0.070101    0.024611    0.539280    
#> 191: 0.641313    1.045240    3.501169    0.422453    0.069640    0.021028    0.533199    
#> 192: 0.614416    1.052167    3.496661    0.422013    0.060718    0.023287    0.527371    
#> 193: 0.640803    1.064200    3.496686    0.448342    0.065849    0.022127    0.527548    
#> 194: 0.619435    1.050457    3.487091    0.430228    0.074403    0.019463    0.534887    
#> 195: 0.574912    1.042704    3.488732    0.427889    0.067861    0.018213    0.526822    
#> 196: 0.585637    1.033306    3.490961    0.428597    0.069769    0.019181    0.543158    
#> 197: 0.581725    1.025154    3.495947    0.445774    0.071891    0.020889    0.539950    
#> 198: 0.676055    1.024838    3.496663    0.477135    0.075952    0.021381    0.533488    
#> 199: 0.638981    1.029842    3.495153    0.484268    0.085673    0.018047    0.540718    
#> 200: 0.615396    1.033873    3.486853    0.436332    0.074765    0.018412    0.547466    
#> 201: 0.613956    1.039561    3.490990    0.446298    0.080302    0.018749    0.536756    
#> 202: 0.614558    1.038348    3.493345    0.446300    0.082261    0.018531    0.538747    
#> 203: 0.628195    1.042463    3.491025    0.452263    0.085811    0.016831    0.541577    
#> 204: 0.627887    1.042728    3.492843    0.438849    0.086343    0.016709    0.544125    
#> 205: 0.629661    1.046806    3.493420    0.430779    0.086775    0.016533    0.547874    
#> 206: 0.631606    1.049423    3.495033    0.433579    0.084978    0.016817    0.549082    
#> 207: 0.627713    1.049716    3.494288    0.423911    0.083603    0.016718    0.549161    
#> 208: 0.627919    1.048583    3.494114    0.423424    0.083099    0.016612    0.547661    
#> 209: 0.628952    1.045783    3.494535    0.421330    0.080986    0.016824    0.547348    
#> 210: 0.630344    1.042916    3.495542    0.420540    0.080063    0.016822    0.547290    
#> 211: 0.634251    1.041843    3.496410    0.421463    0.079338    0.017164    0.546275    
#> 212: 0.637082    1.040019    3.497539    0.419439    0.078233    0.017274    0.545481    
#> 213: 0.639032    1.036770    3.498784    0.419998    0.078581    0.017723    0.545800    
#> 214: 0.640243    1.035406    3.499357    0.421649    0.078596    0.018005    0.544861    
#> 215: 0.640866    1.034640    3.499979    0.423020    0.078318    0.018406    0.544189    
#> 216: 0.641804    1.033225    3.500541    0.420846    0.077439    0.018750    0.544121    
#> 217: 0.641140    1.033722    3.500834    0.420321    0.076867    0.018835    0.543865    
#> 218: 0.640749    1.033797    3.500611    0.421830    0.076838    0.018972    0.543199    
#> 219: 0.639602    1.033548    3.499666    0.422985    0.076626    0.019167    0.543471    
#> 220: 0.637302    1.033254    3.499235    0.425495    0.076459    0.019298    0.543244    
#> 221: 0.636036    1.033383    3.499124    0.425131    0.076205    0.019435    0.542863    
#> 222: 0.634810    1.033659    3.498538    0.426690    0.075617    0.019678    0.542919    
#> 223: 0.635585    1.032884    3.498440    0.429449    0.075169    0.019896    0.542843    
#> 224: 0.637057    1.032787    3.498376    0.431142    0.074546    0.019971    0.543060    
#> 225: 0.636926    1.031593    3.498833    0.432323    0.074179    0.020167    0.543240    
#> 226: 0.636772    1.031150    3.498512    0.431770    0.073910    0.020138    0.543066    
#> 227: 0.637235    1.031230    3.498455    0.430111    0.074028    0.020224    0.543140    
#> 228: 0.635914    1.032186    3.497899    0.427642    0.073962    0.020155    0.543365    
#> 229: 0.634083    1.031851    3.497739    0.425380    0.074162    0.020063    0.543344    
#> 230: 0.633941    1.031635    3.497599    0.426014    0.074126    0.019949    0.543510    
#> 231: 0.634543    1.032096    3.497656    0.427761    0.073894    0.019882    0.543039    
#> 232: 0.634060    1.032605    3.497463    0.428414    0.073716    0.019776    0.542496    
#> 233: 0.633292    1.032144    3.497398    0.428858    0.073666    0.019780    0.542358    
#> 234: 0.632766    1.032232    3.497294    0.428418    0.073798    0.019745    0.542374    
#> 235: 0.633001    1.032086    3.497233    0.429021    0.073757    0.019761    0.542429    
#> 236: 0.633568    1.032344    3.497175    0.430737    0.073593    0.019812    0.542548    
#> 237: 0.634457    1.032156    3.497208    0.432293    0.073419    0.019893    0.543119    
#> 238: 0.635608    1.032146    3.497313    0.432622    0.073218    0.020015    0.543492    
#> 239: 0.635614    1.032678    3.497016    0.434211    0.073110    0.020163    0.543059    
#> 240: 0.635612    1.032789    3.497007    0.436728    0.073125    0.020225    0.542677    
#> 241: 0.635765    1.032278    3.497103    0.437552    0.072866    0.020212    0.542657    
#> 242: 0.635265    1.031972    3.496840    0.438982    0.072820    0.020198    0.542716    
#> 243: 0.633981    1.032474    3.496457    0.439146    0.072796    0.020177    0.542857    
#> 244: 0.633879    1.032768    3.496599    0.440226    0.072641    0.020192    0.542741    
#> 245: 0.633136    1.032480    3.496502    0.439647    0.072639    0.020188    0.542968    
#> 246: 0.632816    1.032267    3.496583    0.438764    0.072265    0.020197    0.543161    
#> 247: 0.632839    1.032266    3.496758    0.438556    0.072221    0.020195    0.543290    
#> 248: 0.633069    1.032341    3.496976    0.439208    0.072350    0.020173    0.543077    
#> 249: 0.632484    1.032333    3.497081    0.438013    0.072107    0.020210    0.542980    
#> 250: 0.632793    1.032271    3.497084    0.438101    0.072106    0.020165    0.542895    
#> 251: 0.633267    1.032545    3.497426    0.436507    0.072026    0.020160    0.543135    
#> 252: 0.633389    1.032701    3.497789    0.435151    0.072095    0.020184    0.543277    
#> 253: 0.633184    1.032508    3.497889    0.433772    0.072155    0.020151    0.543306    
#> 254: 0.632809    1.032779    3.497888    0.433391    0.072206    0.020098    0.543124    
#> 255: 0.632313    1.033310    3.497650    0.433543    0.072432    0.020039    0.543010    
#> 256: 0.631792    1.033588    3.497435    0.432837    0.072740    0.019964    0.543326    
#> 257: 0.631108    1.033696    3.497354    0.431833    0.072952    0.019997    0.543543    
#> 258: 0.630617    1.033647    3.497322    0.431290    0.073092    0.020004    0.543811    
#> 259: 0.630053    1.033598    3.497150    0.430211    0.073026    0.019957    0.544097    
#> 260: 0.629559    1.033714    3.497075    0.430079    0.073062    0.019943    0.544088    
#> 261: 0.630051    1.033817    3.496973    0.432458    0.073006    0.019943    0.544137    
#> 262: 0.630223    1.034156    3.496782    0.434328    0.072920    0.019936    0.543933    
#> 263: 0.630220    1.034379    3.496621    0.435310    0.072924    0.019967    0.543720    
#> 264: 0.629758    1.034652    3.496485    0.435204    0.073073    0.019979    0.543621    
#> 265: 0.629662    1.034965    3.496335    0.435687    0.073146    0.020022    0.543614    
#> 266: 0.629146    1.035319    3.496151    0.436122    0.073007    0.020090    0.543542    
#> 267: 0.628621    1.035362    3.496121    0.435866    0.072870    0.020157    0.543415    
#> 268: 0.628909    1.035411    3.496029    0.436948    0.072744    0.020242    0.543308    
#> 269: 0.629473    1.035512    3.495979    0.437914    0.072600    0.020306    0.543269    
#> 270: 0.629620    1.035661    3.495815    0.437901    0.072478    0.020334    0.543159    
#> 271: 0.629510    1.035736    3.495740    0.438565    0.072493    0.020303    0.543064    
#> 272: 0.629835    1.035557    3.495741    0.439224    0.072545    0.020287    0.543202    
#> 273: 0.629870    1.035670    3.495703    0.440073    0.072532    0.020265    0.543297    
#> 274: 0.630127    1.036094    3.495717    0.440862    0.072510    0.020274    0.543445    
#> 275: 0.630059    1.036407    3.495603    0.440957    0.072641    0.020284    0.543415    
#> 276: 0.629943    1.036791    3.495626    0.441360    0.072649    0.020313    0.543191    
#> 277: 0.629400    1.037196    3.495557    0.440957    0.072620    0.020308    0.543211    
#> 278: 0.629356    1.037171    3.495622    0.440953    0.072656    0.020295    0.543237    
#> 279: 0.629486    1.036895    3.495691    0.440941    0.072764    0.020267    0.543447    
#> 280: 0.629296    1.036991    3.495646    0.440614    0.072752    0.020224    0.543213    
#> 281: 0.628964    1.037199    3.495559    0.440637    0.072888    0.020183    0.542981    
#> 282: 0.628922    1.037308    3.495686    0.440561    0.072967    0.020204    0.543003    
#> 283: 0.628563    1.037393    3.495821    0.439707    0.073105    0.020224    0.543339    
#> 284: 0.628516    1.037015    3.496037    0.438310    0.073106    0.020236    0.543433    
#> 285: 0.628110    1.037018    3.496037    0.437019    0.073076    0.020230    0.543351    
#> 286: 0.628114    1.036992    3.496031    0.436698    0.073054    0.020217    0.543193    
#> 287: 0.628115    1.037162    3.496007    0.436679    0.073062    0.020240    0.543260    
#> 288: 0.628419    1.036974    3.496036    0.437074    0.072998    0.020277    0.543289    
#> 289: 0.628875    1.037077    3.496035    0.437582    0.073000    0.020316    0.543337    
#> 290: 0.629060    1.037222    3.496021    0.438320    0.073067    0.020307    0.543311    
#> 291: 0.629212    1.037449    3.495999    0.439041    0.073064    0.020284    0.543119    
#> 292: 0.629038    1.037571    3.495907    0.439021    0.073032    0.020266    0.543082    
#> 293: 0.628762    1.037707    3.495798    0.439042    0.072997    0.020257    0.543151    
#> 294: 0.628352    1.037947    3.495620    0.438682    0.072935    0.020247    0.543207    
#> 295: 0.627855    1.037851    3.495441    0.438884    0.072962    0.020231    0.543169    
#> 296: 0.627703    1.037952    3.495324    0.438894    0.072998    0.020219    0.543160    
#> 297: 0.627758    1.038020    3.495325    0.439232    0.072961    0.020228    0.543217    
#> 298: 0.627395    1.037958    3.495284    0.438910    0.073075    0.020199    0.543144    
#> 299: 0.627128    1.038099    3.495164    0.438756    0.073052    0.020216    0.543052    
#> 300: 0.627143    1.037972    3.495198    0.438516    0.072874    0.020268    0.542867    
#> 301: 0.627708    1.037929    3.495167    0.439538    0.072740    0.020295    0.542764    
#> 302: 0.627746    1.037974    3.495069    0.440216    0.072642    0.020319    0.542588    
#> 303: 0.627292    1.038164    3.494962    0.439849    0.072547    0.020297    0.542494    
#> 304: 0.626928    1.038367    3.494809    0.439469    0.072439    0.020300    0.542524    
#> 305: 0.626559    1.038328    3.494679    0.438972    0.072312    0.020297    0.542588    
#> 306: 0.626190    1.038418    3.494547    0.438790    0.072319    0.020316    0.542422    
#> 307: 0.625712    1.038473    3.494457    0.438538    0.072232    0.020347    0.542341    
#> 308: 0.625316    1.038379    3.494347    0.438668    0.072029    0.020384    0.542284    
#> 309: 0.625315    1.038305    3.494282    0.439127    0.072030    0.020419    0.542313    
#> 310: 0.625152    1.038220    3.494205    0.439024    0.071992    0.020436    0.542449    
#> 311: 0.624735    1.038308    3.494051    0.439238    0.071933    0.020433    0.542441    
#> 312: 0.624369    1.038346    3.493930    0.439421    0.071895    0.020445    0.542536    
#> 313: 0.624353    1.038171    3.493853    0.440318    0.071897    0.020456    0.542643    
#> 314: 0.623943    1.038214    3.493717    0.441094    0.071930    0.020470    0.542624    
#> 315: 0.623696    1.038423    3.493585    0.441808    0.071876    0.020502    0.542646    
#> 316: 0.623251    1.038702    3.493470    0.441567    0.071848    0.020543    0.542630    
#> 317: 0.623255    1.038816    3.493495    0.441847    0.071826    0.020582    0.542698    
#> 318: 0.623050    1.038994    3.493401    0.441559    0.071863    0.020617    0.542775    
#> 319: 0.623122    1.039030    3.493440    0.441563    0.071751    0.020669    0.542890    
#> 320: 0.622610    1.039009    3.493371    0.441351    0.071822    0.020679    0.543022    
#> 321: 0.622193    1.039133    3.493201    0.440675    0.071823    0.020667    0.543301    
#> 322: 0.622123    1.039207    3.493208    0.440330    0.071872    0.020688    0.543421    
#> 323: 0.621745    1.039247    3.493178    0.439989    0.071902    0.020686    0.543529    
#> 324: 0.621831    1.039287    3.493227    0.439738    0.071870    0.020703    0.543446    
#> 325: 0.621820    1.039380    3.493205    0.439889    0.071886    0.020677    0.543482    
#> 326: 0.621960    1.039168    3.493220    0.439839    0.071828    0.020669    0.543500    
#> 327: 0.622220    1.039086    3.493358    0.439620    0.071698    0.020688    0.543649    
#> 328: 0.622501    1.039138    3.493444    0.439355    0.071752    0.020696    0.543619    
#> 329: 0.622781    1.039105    3.493515    0.439290    0.071727    0.020687    0.543530    
#> 330: 0.622823    1.038987    3.493534    0.439183    0.071719    0.020680    0.543438    
#> 331: 0.623133    1.038978    3.493606    0.439123    0.071658    0.020671    0.543407    
#> 332: 0.623532    1.038883    3.493808    0.438828    0.071713    0.020653    0.543443    
#> 333: 0.623395    1.038740    3.493873    0.438124    0.071687    0.020689    0.543521    
#> 334: 0.623123    1.038575    3.493823    0.437824    0.071603    0.020720    0.543552    
#> 335: 0.622799    1.038620    3.493745    0.437625    0.071485    0.020752    0.543562    
#> 336: 0.622421    1.038684    3.493669    0.437310    0.071408    0.020788    0.543725    
#> 337: 0.621957    1.038981    3.493539    0.436668    0.071372    0.020836    0.543848    
#> 338: 0.622065    1.039115    3.493595    0.436915    0.071348    0.020890    0.543767    
#> 339: 0.621985    1.039145    3.493570    0.437076    0.071344    0.020926    0.543736    
#> 340: 0.621746    1.038947    3.493566    0.437066    0.071366    0.020964    0.543721    
#> 341: 0.621673    1.038976    3.493551    0.437089    0.071369    0.020988    0.543724    
#> 342: 0.621452    1.038827    3.493557    0.437024    0.071323    0.020985    0.543684    
#> 343: 0.621337    1.038783    3.493576    0.437382    0.071311    0.020981    0.543574    
#> 344: 0.621454    1.038715    3.493605    0.437722    0.071297    0.020973    0.543497    
#> 345: 0.621502    1.038679    3.493650    0.437737    0.071304    0.020974    0.543405    
#> 346: 0.621449    1.038604    3.493668    0.437308    0.071211    0.020978    0.543396    
#> 347: 0.621554    1.038492    3.493685    0.437430    0.071165    0.020985    0.543399    
#> 348: 0.621391    1.038439    3.493656    0.437187    0.071179    0.020964    0.543410    
#> 349: 0.621348    1.038275    3.493670    0.436833    0.071154    0.020964    0.543351    
#> 350: 0.621374    1.038091    3.493702    0.436897    0.071164    0.020981    0.543313    
#> 351: 0.621399    1.038122    3.493749    0.437104    0.071180    0.020984    0.543405    
#> 352: 0.621048    1.038244    3.493701    0.436774    0.071159    0.020992    0.543525    
#> 353: 0.621149    1.038374    3.493701    0.436587    0.071216    0.021001    0.543424    
#> 354: 0.621122    1.038382    3.493701    0.436207    0.071200    0.021019    0.543301    
#> 355: 0.621360    1.038371    3.493699    0.436314    0.071161    0.021026    0.543208    
#> 356: 0.621352    1.038379    3.493688    0.436337    0.071165    0.021014    0.543225    
#> 357: 0.621584    1.038486    3.493710    0.436540    0.071069    0.021030    0.543157    
#> 358: 0.621608    1.038544    3.493659    0.436762    0.070937    0.021054    0.543063    
#> 359: 0.621510    1.038708    3.493596    0.436607    0.070839    0.021076    0.543033    
#> 360: 0.621309    1.038722    3.493497    0.436415    0.070798    0.021094    0.542940    
#> 361: 0.621299    1.038737    3.493465    0.436430    0.070802    0.021083    0.542828    
#> 362: 0.621311    1.038686    3.493465    0.436458    0.070804    0.021073    0.542672    
#> 363: 0.621300    1.038570    3.493514    0.436406    0.070797    0.021062    0.542543    
#> 364: 0.621459    1.038487    3.493557    0.436506    0.070780    0.021059    0.542502    
#> 365: 0.621451    1.038454    3.493607    0.436651    0.070819    0.021074    0.542451    
#> 366: 0.621398    1.038462    3.493577    0.436657    0.070835    0.021091    0.542433    
#> 367: 0.621463    1.038450    3.493587    0.436717    0.070796    0.021102    0.542357    
#> 368: 0.621660    1.038468    3.493575    0.436825    0.070758    0.021107    0.542335    
#> 369: 0.621455    1.038434    3.493534    0.436672    0.070743    0.021111    0.542396    
#> 370: 0.621430    1.038505    3.493498    0.436761    0.070759    0.021124    0.542437    
#> 371: 0.621341    1.038557    3.493420    0.436569    0.070749    0.021124    0.542402    
#> 372: 0.621128    1.038620    3.493394    0.436268    0.070848    0.021119    0.542393    
#> 373: 0.621027    1.038756    3.493356    0.436054    0.070898    0.021136    0.542399    
#> 374: 0.620930    1.038803    3.493289    0.436315    0.070854    0.021142    0.542340    
#> 375: 0.620665    1.038847    3.493240    0.436370    0.070794    0.021151    0.542390    
#> 376: 0.620666    1.039036    3.493168    0.436745    0.070817    0.021166    0.542345    
#> 377: 0.620406    1.039118    3.493114    0.436584    0.070916    0.021129    0.542333    
#> 378: 0.620131    1.039105    3.493049    0.436229    0.070973    0.021097    0.542313    
#> 379: 0.619846    1.038917    3.493053    0.435851    0.070986    0.021067    0.542306    
#> 380: 0.619741    1.038863    3.493047    0.435622    0.071070    0.021053    0.542242    
#> 381: 0.619593    1.038814    3.493043    0.435546    0.071127    0.021043    0.542187    
#> 382: 0.619476    1.038794    3.493071    0.435361    0.071145    0.021031    0.542096    
#> 383: 0.619389    1.038693    3.493097    0.435229    0.071175    0.021028    0.542008    
#> 384: 0.619244    1.038624    3.493133    0.435255    0.071214    0.021035    0.541951    
#> 385: 0.619335    1.038545    3.493202    0.435115    0.071226    0.021026    0.541920    
#> 386: 0.619507    1.038604    3.493276    0.434966    0.071284    0.021011    0.541976    
#> 387: 0.619711    1.038608    3.493369    0.434928    0.071285    0.021032    0.541935    
#> 388: 0.619968    1.038527    3.493446    0.434894    0.071301    0.021038    0.541884    
#> 389: 0.620086    1.038407    3.493479    0.434863    0.071261    0.021039    0.541851    
#> 390: 0.620014    1.038412    3.493504    0.434454    0.071251    0.021020    0.541803    
#> 391: 0.620074    1.038405    3.493484    0.434476    0.071229    0.021032    0.541699    
#> 392: 0.620129    1.038407    3.493505    0.434639    0.071265    0.021036    0.541628    
#> 393: 0.620179    1.038314    3.493507    0.434729    0.071277    0.021043    0.541528    
#> 394: 0.620364    1.038280    3.493488    0.435020    0.071311    0.021056    0.541449    
#> 395: 0.620589    1.038303    3.493458    0.435303    0.071358    0.021056    0.541405    
#> 396: 0.620605    1.038344    3.493445    0.435410    0.071323    0.021061    0.541364    
#> 397: 0.620631    1.038293    3.493507    0.435315    0.071326    0.021067    0.541384    
#> 398: 0.620855    1.038282    3.493568    0.435284    0.071318    0.021068    0.541380    
#> 399: 0.621064    1.038244    3.493656    0.435524    0.071314    0.021073    0.541330    
#> 400: 0.621342    1.038259    3.493660    0.435963    0.071297    0.021071    0.541335    
#> 401: 0.621513    1.038313    3.493631    0.436195    0.071238    0.021065    0.541386    
#> 402: 0.621571    1.038433    3.493634    0.436287    0.071245    0.021063    0.541411    
#> 403: 0.621906    1.038462    3.493642    0.436544    0.071252    0.021054    0.541324    
#> 404: 0.622049    1.038410    3.493607    0.436890    0.071297    0.021038    0.541240    
#> 405: 0.622111    1.038374    3.493654    0.436753    0.071308    0.021048    0.541224    
#> 406: 0.622165    1.038280    3.493676    0.436947    0.071393    0.021053    0.541228    
#> 407: 0.622169    1.038296    3.493714    0.437068    0.071491    0.021050    0.541220    
#> 408: 0.622349    1.038281    3.493731    0.437298    0.071537    0.021025    0.541155    
#> 409: 0.622443    1.038193    3.493774    0.437521    0.071542    0.021002    0.541073    
#> 410: 0.622543    1.038262    3.493753    0.437907    0.071606    0.020978    0.541029    
#> 411: 0.622628    1.038182    3.493723    0.438512    0.071646    0.020952    0.540983    
#> 412: 0.622784    1.038251    3.493698    0.439053    0.071733    0.020940    0.540965    
#> 413: 0.622890    1.038324    3.493679    0.439606    0.071787    0.020919    0.541003    
#> 414: 0.622745    1.038340    3.493715    0.439666    0.071832    0.020913    0.540991    
#> 415: 0.622857    1.038268    3.493750    0.439767    0.071858    0.020921    0.540909    
#> 416: 0.622937    1.038274    3.493797    0.439690    0.071867    0.020935    0.540893    
#> 417: 0.622929    1.038238    3.493825    0.439460    0.071858    0.020945    0.540879    
#> 418: 0.622836    1.038208    3.493842    0.439313    0.071862    0.020951    0.540872    
#> 419: 0.622830    1.038179    3.493877    0.439284    0.071825    0.020958    0.540853    
#> 420: 0.623006    1.038176    3.493924    0.439289    0.071822    0.020964    0.540793    
#> 421: 0.622993    1.038160    3.493982    0.439203    0.071853    0.020968    0.540785    
#> 422: 0.623276    1.038050    3.494076    0.439170    0.071834    0.020985    0.540774    
#> 423: 0.623604    1.037950    3.494129    0.439549    0.071852    0.020988    0.540836    
#> 424: 0.623688    1.037893    3.494129    0.439762    0.071866    0.020985    0.540920    
#> 425: 0.623765    1.037893    3.494134    0.440069    0.071869    0.020995    0.540970    
#> 426: 0.623860    1.037984    3.494111    0.440440    0.071842    0.020996    0.541028    
#> 427: 0.623812    1.037999    3.494109    0.440739    0.071829    0.020986    0.541063    
#> 428: 0.623885    1.038091    3.494074    0.441002    0.071866    0.020955    0.541039    
#> 429: 0.623855    1.038140    3.494055    0.441295    0.071869    0.020938    0.541058    
#> 430: 0.623765    1.038197    3.494014    0.441369    0.071865    0.020917    0.541096    
#> 431: 0.623576    1.038267    3.493938    0.441385    0.071875    0.020907    0.541091    
#> 432: 0.623444    1.038363    3.493882    0.441477    0.071883    0.020909    0.541053    
#> 433: 0.623424    1.038437    3.493864    0.441555    0.071935    0.020904    0.541055    
#> 434: 0.623270    1.038364    3.493876    0.441360    0.071951    0.020893    0.541047    
#> 435: 0.623326    1.038324    3.493896    0.441290    0.071947    0.020874    0.540971    
#> 436: 0.623491    1.038255    3.494012    0.441045    0.071940    0.020867    0.541076    
#> 437: 0.623599    1.038169    3.494091    0.440594    0.071958    0.020868    0.541104    
#> 438: 0.623455    1.038236    3.494108    0.440215    0.071941    0.020859    0.541086    
#> 439: 0.623470    1.038263    3.494128    0.439986    0.071914    0.020849    0.541034    
#> 440: 0.623545    1.038265    3.494180    0.439906    0.071944    0.020826    0.541034    
#> 441: 0.623722    1.038221    3.494220    0.439959    0.071965    0.020821    0.540994    
#> 442: 0.623746    1.038224    3.494264    0.439890    0.071978    0.020817    0.540962    
#> 443: 0.623874    1.038235    3.494278    0.439777    0.071957    0.020808    0.540949    
#> 444: 0.623816    1.038315    3.494263    0.439480    0.071953    0.020794    0.540935    
#> 445: 0.623749    1.038387    3.494230    0.439406    0.071965    0.020781    0.540933    
#> 446: 0.623541    1.038381    3.494202    0.439235    0.071925    0.020773    0.540959    
#> 447: 0.623562    1.038363    3.494189    0.439352    0.071873    0.020771    0.540938    
#> 448: 0.623520    1.038330    3.494207    0.439358    0.071860    0.020776    0.540867    
#> 449: 0.623602    1.038368    3.494282    0.439350    0.071852    0.020776    0.540851    
#> 450: 0.623718    1.038318    3.494303    0.439591    0.071866    0.020779    0.540797    
#> 451: 0.623733    1.038249    3.494314    0.439657    0.071877    0.020787    0.540823    
#> 452: 0.623745    1.038274    3.494313    0.439751    0.071903    0.020800    0.540764    
#> 453: 0.623795    1.038288    3.494296    0.440033    0.071918    0.020811    0.540670    
#> 454: 0.623786    1.038412    3.494277    0.440078    0.071935    0.020816    0.540627    
#> 455: 0.623807    1.038491    3.494259    0.440272    0.071942    0.020813    0.540561    
#> 456: 0.623698    1.038489    3.494255    0.440180    0.071962    0.020810    0.540514    
#> 457: 0.623654    1.038474    3.494279    0.439817    0.072001    0.020798    0.540444    
#> 458: 0.623617    1.038535    3.494283    0.439644    0.071979    0.020795    0.540343    
#> 459: 0.623550    1.038622    3.494254    0.439733    0.071970    0.020792    0.540324    
#> 460: 0.623394    1.038625    3.494214    0.439947    0.071971    0.020797    0.540270    
#> 461: 0.623414    1.038680    3.494204    0.440049    0.071941    0.020819    0.540214    
#> 462: 0.623378    1.038768    3.494199    0.440086    0.071892    0.020829    0.540188    
#> 463: 0.623271    1.038851    3.494192    0.439979    0.071872    0.020822    0.540210    
#> 464: 0.623359    1.038913    3.494187    0.440036    0.071819    0.020827    0.540203    
#> 465: 0.623462    1.038823    3.494201    0.440075    0.071774    0.020832    0.540211    
#> 466: 0.623468    1.038856    3.494195    0.440217    0.071759    0.020835    0.540148    
#> 467: 0.623392    1.038820    3.494236    0.440010    0.071744    0.020840    0.540136    
#> 468: 0.623393    1.038863    3.494267    0.439805    0.071722    0.020856    0.540108    
#> 469: 0.623349    1.038920    3.494261    0.439693    0.071705    0.020863    0.540128    
#> 470: 0.623164    1.038925    3.494192    0.439567    0.071654    0.020862    0.540103    
#> 471: 0.623020    1.038949    3.494141    0.439450    0.071647    0.020861    0.540105    
#> 472: 0.622948    1.038937    3.494101    0.439373    0.071646    0.020865    0.540116    
#> 473: 0.622919    1.038963    3.494067    0.439338    0.071644    0.020864    0.540046    
#> 474: 0.622841    1.039008    3.494060    0.439258    0.071666    0.020876    0.540039    
#> 475: 0.622800    1.039096    3.494014    0.439532    0.071678    0.020875    0.539990    
#> 476: 0.622691    1.039050    3.493996    0.439514    0.071627    0.020872    0.540014    
#> 477: 0.622623    1.039002    3.494004    0.439483    0.071569    0.020878    0.539999    
#> 478: 0.622625    1.038974    3.494018    0.439717    0.071535    0.020882    0.540003    
#> 479: 0.622742    1.038990    3.494014    0.440198    0.071495    0.020892    0.539995    
#> 480: 0.622853    1.039021    3.493999    0.440623    0.071461    0.020905    0.539998    
#> 481: 0.622826    1.039050    3.493958    0.440883    0.071427    0.020911    0.539960    
#> 482: 0.622821    1.039081    3.493887    0.441167    0.071405    0.020911    0.540005    
#> 483: 0.622573    1.039161    3.493804    0.441235    0.071373    0.020925    0.539951    
#> 484: 0.622435    1.039154    3.493765    0.441161    0.071345    0.020935    0.539911    
#> 485: 0.622301    1.039236    3.493726    0.441188    0.071364    0.020943    0.539875    
#> 486: 0.622124    1.039327    3.493712    0.441136    0.071360    0.020951    0.539868    
#> 487: 0.622275    1.039385    3.493719    0.441550    0.071347    0.020952    0.539864    
#> 488: 0.622263    1.039405    3.493701    0.441652    0.071351    0.020963    0.539804    
#> 489: 0.622279    1.039433    3.493678    0.441670    0.071368    0.020965    0.539779    
#> 490: 0.622269    1.039461    3.493668    0.441612    0.071334    0.020970    0.539746    
#> 491: 0.622230    1.039515    3.493651    0.441670    0.071293    0.020979    0.539682    
#> 492: 0.622205    1.039590    3.493614    0.441811    0.071295    0.020979    0.539698    
#> 493: 0.622106    1.039686    3.493597    0.441812    0.071286    0.020978    0.539686    
#> 494: 0.622131    1.039795    3.493546    0.441989    0.071293    0.020980    0.539612    
#> 495: 0.622097    1.039865    3.493519    0.442062    0.071292    0.020984    0.539560    
#> 496: 0.622181    1.039917    3.493490    0.442281    0.071249    0.020977    0.539584    
#> 497: 0.622151    1.039940    3.493487    0.442307    0.071304    0.020959    0.539626    
#> 498: 0.622173    1.039907    3.493479    0.442363    0.071317    0.020951    0.539597    
#> 499: 0.622212    1.039951    3.493474    0.442314    0.071355    0.020947    0.539542    
#> 500: 0.622258    1.039869    3.493480    0.442335    0.071337    0.020943    0.539531    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.346222    0.983886    3.443397    0.392401    0.076170    0.016800    1.820465    
#> 002: 0.417872    0.992817    3.455436    0.372781    0.072361    0.022799    1.286617    
#> 003: 0.577420    0.931082    3.454365    0.354142    0.068743    0.021659    0.984698    
#> 004: 0.573916    0.967006    3.451088    0.355080    0.065306    0.020576    0.881643    
#> 005: 0.615459    0.992930    3.430126    0.410366    0.062041    0.019548    0.798880    
#> 006: 0.613737    1.005661    3.429661    0.457946    0.062209    0.018570    0.771857    
#> 007: 0.575424    1.018580    3.417407    0.435049    0.059099    0.020343    0.780333    
#> 008: 0.549405    0.999463    3.408826    0.437653    0.056144    0.020640    0.778772    
#> 009: 0.522573    1.008495    3.397883    0.452613    0.053337    0.021341    0.780267    
#> 010: 0.509498    0.978129    3.390108    0.559562    0.050670    0.024677    0.775116    
#> 011: 0.622121    1.001831    3.405569    0.632562    0.048136    0.027433    0.764610    
#> 012: 0.601562    0.981486    3.407617    0.671167    0.045729    0.028447    0.740946    
#> 013: 0.548255    0.991572    3.398915    0.637609    0.043443    0.027025    0.757344    
#> 014: 0.603730    0.993194    3.407550    0.605728    0.041271    0.026819    0.753727    
#> 015: 0.625714    0.999709    3.415329    0.575442    0.039207    0.031099    0.738569    
#> 016: 0.616592    1.013040    3.414937    0.590189    0.037247    0.029544    0.772904    
#> 017: 0.616401    0.993833    3.420706    0.605870    0.035385    0.030165    0.731999    
#> 018: 0.608732    1.031852    3.391470    0.656581    0.033615    0.031552    0.725048    
#> 019: 0.564729    1.037220    3.388732    0.629988    0.031935    0.032608    0.713122    
#> 020: 0.571579    1.022574    3.395136    0.598489    0.030338    0.031877    0.729732    
#> 021: 0.592231    1.008744    3.410487    0.655357    0.030385    0.039884    0.700719    
#> 022: 0.588542    1.023296    3.412916    0.641866    0.035047    0.037890    0.703191    
#> 023: 0.676416    1.031199    3.407599    0.757966    0.037079    0.035996    0.713000    
#> 024: 0.656477    1.039242    3.404336    0.720067    0.035225    0.035978    0.697952    
#> 025: 0.613921    1.023545    3.403212    0.749910    0.036271    0.034179    0.713279    
#> 026: 0.604801    1.046948    3.385380    0.712415    0.037457    0.032470    0.726366    
#> 027: 0.579842    1.048635    3.387952    0.676794    0.036377    0.030846    0.724842    
#> 028: 0.639056    1.033673    3.404575    0.748286    0.034559    0.031962    0.692944    
#> 029: 0.640129    1.028593    3.391743    0.797805    0.035132    0.037310    0.727681    
#> 030: 0.643688    1.042651    3.385622    0.950154    0.033376    0.037851    0.725983    
#> 031: 0.599235    1.019680    3.396144    0.902646    0.031707    0.038424    0.712558    
#> 032: 0.576702    1.020257    3.407607    0.857514    0.030222    0.037164    0.714658    
#> 033: 0.580557    1.029692    3.405994    0.814638    0.028711    0.035305    0.726913    
#> 034: 0.601641    1.021438    3.402515    0.773906    0.027275    0.033540    0.723702    
#> 035: 0.639470    1.008573    3.402005    0.735211    0.025912    0.031863    0.710982    
#> 036: 0.620517    1.019657    3.396278    0.734612    0.025100    0.030270    0.724410    
#> 037: 0.628437    1.028557    3.397609    0.697882    0.029800    0.032903    0.735020    
#> 038: 0.588534    1.024918    3.393433    0.662988    0.028787    0.033289    0.732104    
#> 039: 0.581557    1.020180    3.400224    0.629838    0.028566    0.032368    0.740222    
#> 040: 0.609902    1.021809    3.411490    0.689757    0.035525    0.037968    0.722845    
#> 041: 0.615101    1.021185    3.400812    0.815452    0.033749    0.036070    0.717790    
#> 042: 0.678538    1.014253    3.395051    0.971300    0.032061    0.034266    0.713432    
#> 043: 0.644707    1.024668    3.387810    0.922735    0.031603    0.032553    0.711877    
#> 044: 0.618199    1.026725    3.391459    0.876598    0.030023    0.030925    0.717094    
#> 045: 0.582128    1.048436    3.378233    0.832768    0.028723    0.031996    0.709094    
#> 046: 0.612419    1.041189    3.393937    0.791130    0.032070    0.031418    0.707348    
#> 047: 0.607536    1.034171    3.391140    0.771203    0.034068    0.029848    0.702817    
#> 048: 0.590119    1.024678    3.385266    0.732643    0.033357    0.028355    0.717835    
#> 049: 0.597421    1.034248    3.401863    0.696011    0.031690    0.030284    0.733774    
#> 050: 0.682058    1.018852    3.412160    0.751546    0.031590    0.033279    0.731664    
#> 051: 0.637733    1.027257    3.401901    0.713969    0.040794    0.036605    0.734084    
#> 052: 0.649501    1.030182    3.414696    0.685422    0.038755    0.035581    0.732726    
#> 053: 0.576813    1.020389    3.395886    0.651151    0.036817    0.034529    0.728556    
#> 054: 0.571622    1.025388    3.400546    0.641712    0.034976    0.041807    0.740162    
#> 055: 0.589624    1.019159    3.400051    0.622295    0.033227    0.039717    0.738696    
#> 056: 0.586375    1.027822    3.394153    0.591180    0.035984    0.037731    0.732621    
#> 057: 0.578511    1.034000    3.400000    0.561621    0.034185    0.036916    0.749403    
#> 058: 0.603791    1.050582    3.386903    0.593388    0.032475    0.040994    0.736551    
#> 059: 0.555100    1.012236    3.398119    0.650711    0.030852    0.045321    0.742637    
#> 060: 0.583878    1.019654    3.393220    0.618176    0.029309    0.046214    0.736414    
#> 061: 0.613979    1.016792    3.399869    0.699364    0.027844    0.051332    0.737565    
#> 062: 0.558180    1.016730    3.392891    0.664395    0.026451    0.055439    0.762132    
#> 063: 0.587399    0.999397    3.402101    0.631176    0.025129    0.052667    0.774933    
#> 064: 0.587977    1.019139    3.403774    0.655053    0.023872    0.050033    0.741790    
#> 065: 0.622335    1.018379    3.396953    0.663061    0.024598    0.047532    0.727463    
#> 066: 0.622450    1.033414    3.393164    0.777836    0.023369    0.045155    0.719072    
#> 067: 0.580596    1.025751    3.397985    0.738944    0.022200    0.042897    0.731362    
#> 068: 0.584256    1.038918    3.404642    0.701997    0.021090    0.040752    0.749869    
#> 069: 0.620588    1.043541    3.397340    0.798671    0.020036    0.049909    0.734412    
#> 070: 0.613451    1.043149    3.402120    0.758738    0.019034    0.050267    0.710735    
#> 071: 0.579367    1.061825    3.379267    0.720801    0.018082    0.047754    0.742983    
#> 072: 0.555135    1.041341    3.384113    0.684761    0.017178    0.045366    0.741366    
#> 073: 0.634787    1.040290    3.400296    0.862619    0.016319    0.043098    0.740617    
#> 074: 0.571993    1.025171    3.392891    0.819488    0.018267    0.041782    0.724755    
#> 075: 0.585505    1.023782    3.408531    0.778514    0.017840    0.044359    0.730251    
#> 076: 0.623848    1.034401    3.406951    0.741230    0.021032    0.042141    0.726478    
#> 077: 0.669143    1.019806    3.414275    0.752972    0.021182    0.042868    0.735389    
#> 078: 0.615913    1.017239    3.419806    0.748054    0.023662    0.042306    0.726305    
#> 079: 0.640703    1.017968    3.405656    0.789058    0.024919    0.046823    0.720231    
#> 080: 0.677872    1.003849    3.413933    0.850991    0.023674    0.047580    0.739518    
#> 081: 0.652068    0.994881    3.410679    0.808441    0.022490    0.046792    0.731732    
#> 082: 0.641864    0.991230    3.414681    0.796804    0.021365    0.044453    0.725014    
#> 083: 0.636901    1.008813    3.406172    0.756964    0.022144    0.044370    0.723983    
#> 084: 0.632111    1.008243    3.400677    0.719115    0.022808    0.042151    0.718878    
#> 085: 0.602059    1.002326    3.422360    0.683160    0.021668    0.044563    0.729749    
#> 086: 0.604532    1.002285    3.400015    0.649002    0.020584    0.042335    0.741472    
#> 087: 0.557340    1.014627    3.391055    0.616552    0.019555    0.040218    0.724317    
#> 088: 0.548550    1.003699    3.393325    0.683696    0.019363    0.040147    0.724359    
#> 089: 0.588448    1.008399    3.389635    0.686010    0.018395    0.038140    0.723841    
#> 090: 0.612163    1.019914    3.395061    0.728334    0.017475    0.038821    0.735036    
#> 091: 0.591619    1.008896    3.383029    0.706690    0.017757    0.041017    0.737610    
#> 092: 0.606699    1.033340    3.385830    0.748939    0.018562    0.041084    0.727113    
#> 093: 0.573807    1.029667    3.385154    0.711492    0.017634    0.044024    0.748438    
#> 094: 0.619030    1.033326    3.397833    0.710700    0.017240    0.041894    0.739242    
#> 095: 0.591074    1.022620    3.414705    0.675165    0.020297    0.047936    0.740356    
#> 096: 0.598746    1.031794    3.405770    0.669169    0.019282    0.045539    0.724110    
#> 097: 0.632982    1.044388    3.400077    0.706326    0.018318    0.044040    0.710378    
#> 098: 0.647085    1.029396    3.406380    0.671010    0.017402    0.045274    0.734197    
#> 099: 0.617530    1.013260    3.393561    0.663738    0.016532    0.043010    0.738168    
#> 100: 0.566690    1.014330    3.400332    0.636629    0.020670    0.043066    0.745940    
#> 101: 0.553402    1.006637    3.377428    0.637872    0.019636    0.040913    0.744210    
#> 102: 0.554336    1.006092    3.386562    0.682574    0.018654    0.039171    0.758973    
#> 103: 0.642663    1.015242    3.401663    0.741085    0.017914    0.042895    0.719268    
#> 104: 0.612868    1.025613    3.403146    0.816868    0.018235    0.041460    0.740122    
#> 105: 0.622455    1.025044    3.390582    0.853566    0.017792    0.039800    0.741788    
#> 106: 0.645901    1.020412    3.407311    0.843596    0.019353    0.039682    0.739112    
#> 107: 0.703693    1.007044    3.405415    0.951444    0.019816    0.037717    0.736764    
#> 108: 0.645403    1.013275    3.421399    0.903872    0.024014    0.037352    0.745588    
#> 109: 0.627757    1.027424    3.413995    0.858679    0.022813    0.039253    0.731954    
#> 110: 0.644822    1.040476    3.400472    0.815745    0.021746    0.041787    0.723455    
#> 111: 0.627675    1.040748    3.405009    0.774957    0.023463    0.039698    0.731364    
#> 112: 0.592173    1.023580    3.393048    0.736210    0.029343    0.037713    0.729386    
#> 113: 0.601419    1.035862    3.408582    0.699399    0.031147    0.035827    0.723715    
#> 114: 0.657109    1.031027    3.411351    0.792875    0.038977    0.036346    0.706913    
#> 115: 0.659036    1.003255    3.401209    0.793652    0.037083    0.036090    0.727363    
#> 116: 0.644701    1.026326    3.394543    0.753969    0.035229    0.034285    0.739942    
#> 117: 0.577875    1.044209    3.410280    0.716271    0.033699    0.034043    0.756649    
#> 118: 0.575581    1.025474    3.404316    0.680457    0.032868    0.032340    0.755089    
#> 119: 0.618633    1.008190    3.405877    0.646435    0.031224    0.032581    0.754082    
#> 120: 0.608780    0.991127    3.401348    0.722026    0.030279    0.035895    0.733543    
#> 121: 0.634301    1.012836    3.417412    0.685925    0.029045    0.037851    0.737506    
#> 122: 0.641431    0.996055    3.419614    0.672238    0.027593    0.035958    0.743455    
#> 123: 0.642695    1.019613    3.402724    0.674129    0.030165    0.035274    0.740118    
#> 124: 0.618142    1.050762    3.388865    0.727667    0.029804    0.036190    0.737410    
#> 125: 0.616869    1.053505    3.392590    0.730838    0.032330    0.034380    0.729744    
#> 126: 0.611676    1.055857    3.383704    0.694296    0.038026    0.032661    0.730494    
#> 127: 0.656603    1.037833    3.390260    0.769183    0.038468    0.031028    0.715763    
#> 128: 0.648888    1.029828    3.407633    0.730724    0.036545    0.029477    0.725897    
#> 129: 0.651936    1.029235    3.412326    0.708971    0.038863    0.028003    0.735822    
#> 130: 0.624392    1.036660    3.395398    0.713966    0.039080    0.031367    0.739239    
#> 131: 0.590050    1.017614    3.388333    0.678267    0.037126    0.033903    0.745875    
#> 132: 0.582016    1.020077    3.385814    0.721656    0.035270    0.033490    0.735637    
#> 133: 0.539516    1.014816    3.385437    0.685573    0.033506    0.031816    0.747334    
#> 134: 0.585945    1.005475    3.388406    0.704879    0.031831    0.035787    0.732008    
#> 135: 0.587649    1.004029    3.401226    0.669635    0.030240    0.037122    0.738070    
#> 136: 0.541839    1.011044    3.399550    0.636153    0.028962    0.035265    0.718777    
#> 137: 0.640611    1.004314    3.401407    0.738437    0.027514    0.033502    0.719290    
#> 138: 0.613541    1.011094    3.401788    0.701515    0.026138    0.031827    0.728756    
#> 139: 0.561904    1.021110    3.409685    0.666439    0.024831    0.030236    0.732569    
#> 140: 0.579900    1.031463    3.409648    0.633117    0.026201    0.031653    0.744648    
#> 141: 0.565294    1.017729    3.402637    0.601462    0.027763    0.034019    0.722884    
#> 142: 0.567048    1.008332    3.410030    0.595796    0.026801    0.036189    0.729490    
#> 143: 0.579149    1.019669    3.408754    0.618602    0.028755    0.037552    0.731079    
#> 144: 0.633106    1.016963    3.416913    0.700800    0.027317    0.035674    0.727465    
#> 145: 0.608109    1.027075    3.398275    0.697866    0.025952    0.033891    0.710258    
#> 146: 0.595934    1.025334    3.399075    0.684335    0.025867    0.032196    0.703829    
#> 147: 0.598777    1.011197    3.391704    0.697580    0.025465    0.030586    0.705745    
#> 148: 0.584928    1.030949    3.405352    0.662701    0.026938    0.036779    0.714367    
#> 149: 0.571703    1.023098    3.386939    0.635866    0.025591    0.034940    0.724668    
#> 150: 0.585606    1.020172    3.389114    0.649507    0.024312    0.041084    0.726925    
#> 151: 0.562615    1.034951    3.395978    0.643206    0.023096    0.039029    0.716406    
#> 152: 0.587132    1.046469    3.387459    0.743989    0.027275    0.032278    0.728154    
#> 153: 0.555472    1.065232    3.390941    0.642639    0.034253    0.043163    0.738509    
#> 154: 0.599976    1.057187    3.395152    0.655069    0.032271    0.036816    0.724103    
#> 155: 0.610343    1.029526    3.397282    0.649303    0.019735    0.040891    0.720554    
#> 156: 0.645484    1.028957    3.414003    0.715489    0.017355    0.045665    0.752121    
#> 157: 0.642814    1.013844    3.406012    0.734931    0.017825    0.050582    0.724227    
#> 158: 0.643189    1.033337    3.400144    0.729925    0.019335    0.044081    0.719369    
#> 159: 0.576401    1.050458    3.403330    0.681879    0.018546    0.042977    0.734217    
#> 160: 0.582681    1.030064    3.404951    0.584352    0.014998    0.041892    0.765443    
#> 161: 0.610906    1.023579    3.403494    0.623057    0.018400    0.042833    0.770731    
#> 162: 0.621714    1.035118    3.398504    0.679590    0.016873    0.043532    0.756232    
#> 163: 0.636702    1.020178    3.396942    0.738778    0.011176    0.045148    0.731645    
#> 164: 0.620512    1.030674    3.401104    0.573283    0.011508    0.039500    0.726266    
#> 165: 0.618428    1.035254    3.408770    0.614432    0.012247    0.034614    0.734330    
#> 166: 0.615011    1.051880    3.401214    0.573026    0.013932    0.033503    0.749709    
#> 167: 0.566412    1.059886    3.403671    0.545932    0.016326    0.033356    0.750329    
#> 168: 0.610691    1.065351    3.408228    0.645208    0.018033    0.032863    0.737208    
#> 169: 0.617221    1.062193    3.392579    0.654511    0.017709    0.034357    0.727173    
#> 170: 0.627613    1.038957    3.408023    0.709119    0.017191    0.036602    0.715591    
#> 171: 0.604885    1.030859    3.400997    0.559757    0.016515    0.037848    0.727285    
#> 172: 0.596567    1.037467    3.409996    0.545842    0.016781    0.039681    0.722397    
#> 173: 0.590741    1.051352    3.394557    0.591038    0.015165    0.037346    0.734285    
#> 174: 0.609978    1.044955    3.397653    0.611372    0.015078    0.036663    0.744991    
#> 175: 0.606322    1.033461    3.390520    0.669378    0.015591    0.033691    0.749970    
#> 176: 0.633342    1.043295    3.403579    0.786159    0.013432    0.037799    0.715894    
#> 177: 0.633540    1.039588    3.403976    0.727429    0.013263    0.042921    0.733991    
#> 178: 0.645419    1.023422    3.406218    0.690274    0.017153    0.041131    0.737915    
#> 179: 0.649694    1.034331    3.415636    0.578982    0.022700    0.042554    0.745783    
#> 180: 0.609059    1.026970    3.411196    0.575385    0.023566    0.028540    0.756694    
#> 181: 0.588471    1.005698    3.402499    0.510481    0.020163    0.026629    0.755710    
#> 182: 0.584069    1.012939    3.399507    0.509736    0.028729    0.024182    0.756207    
#> 183: 0.604022    1.030140    3.390538    0.568943    0.025762    0.029100    0.750540    
#> 184: 0.590412    1.013285    3.399157    0.603105    0.028386    0.032129    0.725796    
#> 185: 0.576628    1.044163    3.394153    0.622134    0.030544    0.035062    0.733345    
#> 186: 0.564195    1.061889    3.390366    0.565473    0.028512    0.033900    0.747692    
#> 187: 0.605989    1.027846    3.407412    0.588505    0.021659    0.035262    0.754345    
#> 188: 0.590514    1.036049    3.403654    0.599929    0.020398    0.040510    0.752517    
#> 189: 0.651350    1.028541    3.415184    0.769363    0.021655    0.048692    0.730866    
#> 190: 0.640686    1.014239    3.417272    0.801883    0.018503    0.047486    0.749272    
#> 191: 0.612572    1.027691    3.401477    0.680031    0.016725    0.050425    0.746979    
#> 192: 0.588845    1.031719    3.396571    0.712784    0.016133    0.042705    0.742346    
#> 193: 0.693892    1.042545    3.404772    0.839688    0.014720    0.044036    0.757960    
#> 194: 0.616912    1.033598    3.405320    0.706387    0.011658    0.048054    0.752762    
#> 195: 0.599421    1.024230    3.403214    0.734067    0.010017    0.050451    0.744148    
#> 196: 0.566895    1.024415    3.410047    0.590599    0.013701    0.048235    0.749732    
#> 197: 0.543374    1.031201    3.407545    0.549528    0.009594    0.050200    0.753188    
#> 198: 0.625983    1.008269    3.410691    0.590697    0.011303    0.040641    0.730055    
#> 199: 0.603307    0.998528    3.398683    0.692129    0.011259    0.045072    0.727912    
#> 200: 0.643417    0.990900    3.415726    0.762871    0.012770    0.039069    0.739022    
#> 201: 0.644002    0.987652    3.419662    0.735534    0.012034    0.036501    0.741096    
#> 202: 0.646446    0.986821    3.418457    0.767817    0.012147    0.036325    0.744720    
#> 203: 0.659393    0.989346    3.415134    0.778453    0.012945    0.038032    0.742262    
#> 204: 0.660981    0.988281    3.414296    0.793515    0.013758    0.037893    0.737982    
#> 205: 0.662451    0.992295    3.413709    0.799383    0.015039    0.037681    0.734951    
#> 206: 0.652992    0.996739    3.413910    0.787942    0.014753    0.037899    0.735322    
#> 207: 0.647278    0.998662    3.411093    0.780859    0.014461    0.037839    0.733827    
#> 208: 0.647336    0.998997    3.410248    0.777724    0.014486    0.037464    0.732342    
#> 209: 0.650845    0.998170    3.409429    0.789369    0.014450    0.037316    0.732778    
#> 210: 0.650671    0.999774    3.409549    0.790949    0.014328    0.037461    0.730320    
#> 211: 0.648943    1.001046    3.409124    0.777762    0.014831    0.036968    0.729300    
#> 212: 0.645875    1.001615    3.409177    0.764322    0.014789    0.036962    0.728616    
#> 213: 0.646724    1.000168    3.409188    0.762329    0.015149    0.036605    0.730264    
#> 214: 0.649953    0.999660    3.409381    0.765914    0.015210    0.036285    0.730242    
#> 215: 0.649061    0.999613    3.409661    0.765189    0.015381    0.036305    0.731411    
#> 216: 0.650948    0.998356    3.410186    0.760875    0.015362    0.036453    0.732612    
#> 217: 0.646522    0.998331    3.410231    0.754191    0.015305    0.036576    0.732074    
#> 218: 0.645131    0.999651    3.408936    0.754261    0.015845    0.036577    0.731851    
#> 219: 0.644366    1.000443    3.407897    0.753584    0.016386    0.036274    0.732494    
#> 220: 0.644067    1.001345    3.407414    0.763383    0.016805    0.036124    0.732777    
#> 221: 0.642430    1.002228    3.407164    0.762810    0.017116    0.036125    0.731370    
#> 222: 0.641178    1.002563    3.406723    0.760834    0.017193    0.036084    0.731065    
#> 223: 0.642166    1.002732    3.406640    0.762811    0.017267    0.036222    0.730579    
#> 224: 0.643387    1.002976    3.406986    0.764575    0.017379    0.036584    0.729897    
#> 225: 0.642822    1.002830    3.407354    0.765042    0.017435    0.036707    0.729526    
#> 226: 0.642006    1.002242    3.407574    0.759299    0.017313    0.036930    0.729328    
#> 227: 0.641466    1.002209    3.407446    0.756512    0.017292    0.037142    0.728974    
#> 228: 0.639164    1.002916    3.406865    0.754221    0.017199    0.037270    0.729352    
#> 229: 0.635117    1.003246    3.405912    0.747033    0.017109    0.037494    0.729508    
#> 230: 0.633185    1.003661    3.405505    0.745272    0.017145    0.037703    0.729227    
#> 231: 0.631546    1.004448    3.405229    0.742848    0.017239    0.037860    0.728891    
#> 232: 0.630505    1.004434    3.405090    0.740983    0.017341    0.037994    0.728794    
#> 233: 0.628135    1.003964    3.404750    0.739049    0.017457    0.038059    0.728810    
#> 234: 0.627249    1.004030    3.404297    0.740098    0.017569    0.038034    0.729091    
#> 235: 0.627625    1.004192    3.404053    0.742504    0.017581    0.038037    0.728636    
#> 236: 0.627237    1.005199    3.403453    0.743313    0.017691    0.038091    0.728211    
#> 237: 0.627457    1.005544    3.403250    0.744664    0.017656    0.038276    0.728186    
#> 238: 0.627404    1.005905    3.403148    0.745341    0.017674    0.038286    0.728462    
#> 239: 0.624875    1.006785    3.402649    0.740378    0.017608    0.038302    0.729083    
#> 240: 0.622739    1.007315    3.402525    0.735498    0.017516    0.038373    0.729645    
#> 241: 0.622389    1.007465    3.402447    0.733197    0.017540    0.038436    0.730045    
#> 242: 0.622695    1.007571    3.402103    0.734810    0.017668    0.038619    0.730546    
#> 243: 0.622666    1.008040    3.402148    0.732866    0.017774    0.038726    0.730707    
#> 244: 0.622658    1.007938    3.402637    0.732065    0.017743    0.038679    0.730816    
#> 245: 0.623118    1.007706    3.403055    0.732453    0.017650    0.038641    0.731734    
#> 246: 0.623745    1.007475    3.403058    0.731915    0.017559    0.038624    0.732058    
#> 247: 0.624097    1.007024    3.403617    0.729739    0.017537    0.038712    0.732467    
#> 248: 0.624155    1.006813    3.403975    0.726012    0.017540    0.038809    0.732572    
#> 249: 0.623079    1.006671    3.404152    0.724090    0.017510    0.038913    0.733040    
#> 250: 0.624077    1.006700    3.404418    0.724456    0.017538    0.038975    0.733481    
#> 251: 0.624230    1.006909    3.404852    0.724258    0.017542    0.039059    0.733715    
#> 252: 0.625119    1.007106    3.405346    0.725325    0.017496    0.039165    0.733827    
#> 253: 0.625561    1.007084    3.405391    0.727271    0.017397    0.039261    0.734028    
#> 254: 0.626326    1.007567    3.405367    0.729961    0.017341    0.039407    0.734597    
#> 255: 0.627629    1.007736    3.405322    0.733819    0.017347    0.039521    0.734785    
#> 256: 0.627901    1.007711    3.405256    0.734585    0.017358    0.039755    0.734868    
#> 257: 0.627079    1.007617    3.405339    0.732281    0.017307    0.039892    0.734603    
#> 258: 0.625924    1.007374    3.405308    0.729294    0.017264    0.040009    0.734402    
#> 259: 0.625374    1.007358    3.405359    0.727792    0.017210    0.040111    0.734280    
#> 260: 0.624946    1.007501    3.405312    0.726381    0.017187    0.040141    0.734134    
#> 261: 0.625236    1.007464    3.405486    0.726751    0.017192    0.040166    0.734244    
#> 262: 0.624812    1.007268    3.405554    0.724192    0.017173    0.040192    0.734357    
#> 263: 0.624109    1.007388    3.405566    0.722289    0.017140    0.040236    0.734161    
#> 264: 0.623281    1.007602    3.405416    0.720796    0.017135    0.040227    0.734395    
#> 265: 0.623146    1.007664    3.405167    0.719621    0.017215    0.040150    0.734472    
#> 266: 0.623268    1.008012    3.405006    0.719363    0.017230    0.040085    0.734638    
#> 267: 0.623185    1.008227    3.404915    0.721541    0.017282    0.039965    0.734751    
#> 268: 0.622988    1.008400    3.404657    0.720896    0.017301    0.039950    0.734649    
#> 269: 0.622777    1.008515    3.404540    0.720203    0.017281    0.039981    0.734399    
#> 270: 0.622676    1.008809    3.404414    0.720446    0.017252    0.040030    0.733920    
#> 271: 0.622342    1.009010    3.404281    0.721539    0.017231    0.040019    0.733767    
#> 272: 0.621841    1.009110    3.404039    0.721733    0.017212    0.039992    0.733771    
#> 273: 0.621551    1.009389    3.404120    0.721813    0.017229    0.039983    0.733848    
#> 274: 0.621409    1.009671    3.404242    0.721495    0.017259    0.039910    0.733728    
#> 275: 0.621782    1.009683    3.404083    0.721489    0.017301    0.039753    0.733595    
#> 276: 0.621460    1.009803    3.404061    0.720973    0.017327    0.039646    0.733436    
#> 277: 0.620942    1.009880    3.404135    0.719529    0.017306    0.039646    0.733257    
#> 278: 0.620472    1.010013    3.404123    0.718637    0.017324    0.039680    0.733020    
#> 279: 0.619897    1.010056    3.404108    0.718242    0.017271    0.039795    0.733363    
#> 280: 0.619139    1.010270    3.403925    0.718020    0.017217    0.040008    0.733470    
#> 281: 0.618341    1.010428    3.403808    0.717210    0.017180    0.040162    0.733557    
#> 282: 0.618185    1.010601    3.403800    0.717734    0.017118    0.040265    0.733564    
#> 283: 0.618220    1.010639    3.403821    0.718254    0.017041    0.040369    0.733651    
#> 284: 0.617953    1.010532    3.403753    0.718513    0.017005    0.040505    0.733531    
#> 285: 0.617946    1.010636    3.403519    0.720001    0.016940    0.040674    0.733587    
#> 286: 0.618379    1.010811    3.403403    0.721546    0.016878    0.040898    0.733616    
#> 287: 0.618292    1.010916    3.403296    0.721783    0.016837    0.041021    0.733723    
#> 288: 0.618746    1.010839    3.403286    0.723628    0.016785    0.041333    0.734161    
#> 289: 0.619368    1.010791    3.403291    0.725560    0.016737    0.041497    0.734486    
#> 290: 0.619474    1.010774    3.403266    0.725098    0.016718    0.041579    0.734628    
#> 291: 0.619549    1.010930    3.403300    0.724832    0.016701    0.041624    0.734553    
#> 292: 0.619245    1.011072    3.403173    0.724183    0.016667    0.041647    0.734584    
#> 293: 0.618735    1.011167    3.403030    0.723081    0.016647    0.041715    0.734601    
#> 294: 0.618493    1.011225    3.402893    0.722313    0.016640    0.041700    0.734527    
#> 295: 0.618408    1.011157    3.402933    0.721781    0.016630    0.041685    0.734345    
#> 296: 0.618919    1.011207    3.403017    0.723105    0.016641    0.041680    0.734265    
#> 297: 0.619466    1.011314    3.403011    0.725070    0.016635    0.041628    0.734219    
#> 298: 0.619863    1.011299    3.403021    0.726245    0.016643    0.041586    0.734149    
#> 299: 0.620108    1.011335    3.402966    0.726825    0.016631    0.041565    0.733997    
#> 300: 0.620268    1.011330    3.403065    0.728188    0.016574    0.041669    0.733789    
#> 301: 0.620636    1.011236    3.403125    0.728304    0.016516    0.041741    0.733771    
#> 302: 0.620682    1.011268    3.403088    0.728518    0.016474    0.041850    0.733611    
#> 303: 0.620462    1.011351    3.402957    0.728159    0.016406    0.041936    0.733621    
#> 304: 0.620272    1.011588    3.402837    0.728308    0.016377    0.042007    0.733729    
#> 305: 0.619674    1.011572    3.402757    0.727493    0.016325    0.042154    0.733801    
#> 306: 0.619243    1.011498    3.402703    0.726851    0.016272    0.042245    0.733817    
#> 307: 0.618630    1.011383    3.402546    0.726403    0.016234    0.042303    0.734205    
#> 308: 0.618555    1.011175    3.402543    0.726502    0.016218    0.042385    0.734458    
#> 309: 0.618357    1.010909    3.402537    0.726611    0.016249    0.042440    0.734802    
#> 310: 0.618357    1.010728    3.402422    0.727422    0.016299    0.042448    0.734903    
#> 311: 0.618314    1.010642    3.402427    0.728650    0.016319    0.042426    0.734899    
#> 312: 0.618246    1.010552    3.402379    0.729305    0.016326    0.042397    0.735077    
#> 313: 0.618463    1.010330    3.402444    0.729302    0.016393    0.042439    0.735159    
#> 314: 0.618246    1.010294    3.402466    0.729201    0.016385    0.042494    0.734996    
#> 315: 0.617825    1.010364    3.402361    0.728795    0.016379    0.042557    0.734980    
#> 316: 0.617927    1.010489    3.402166    0.729408    0.016355    0.042618    0.734991    
#> 317: 0.617816    1.010558    3.402160    0.729034    0.016374    0.042656    0.734986    
#> 318: 0.617853    1.010631    3.402080    0.729175    0.016379    0.042640    0.734895    
#> 319: 0.618037    1.010566    3.402148    0.729532    0.016368    0.042676    0.734949    
#> 320: 0.618027    1.010672    3.402078    0.730441    0.016358    0.042665    0.735066    
#> 321: 0.618044    1.010834    3.401984    0.730882    0.016365    0.042703    0.735180    
#> 322: 0.618070    1.011029    3.401842    0.731310    0.016360    0.042676    0.735276    
#> 323: 0.617529    1.011158    3.401636    0.731052    0.016347    0.042702    0.735313    
#> 324: 0.617656    1.011352    3.401605    0.732665    0.016359    0.042745    0.735204    
#> 325: 0.617538    1.011598    3.401481    0.733586    0.016351    0.042818    0.735174    
#> 326: 0.617224    1.011591    3.401438    0.733213    0.016368    0.042844    0.735107    
#> 327: 0.617257    1.011670    3.401560    0.733361    0.016402    0.042888    0.735040    
#> 328: 0.617739    1.011642    3.401694    0.733402    0.016439    0.042872    0.735065    
#> 329: 0.618325    1.011561    3.401909    0.733414    0.016447    0.042891    0.734997    
#> 330: 0.618440    1.011439    3.402060    0.732768    0.016483    0.042869    0.735029    
#> 331: 0.618753    1.011538    3.402131    0.733062    0.016515    0.042834    0.734963    
#> 332: 0.618811    1.011570    3.402238    0.732701    0.016524    0.042868    0.734933    
#> 333: 0.618909    1.011492    3.402231    0.732057    0.016528    0.042853    0.734882    
#> 334: 0.618821    1.011412    3.402126    0.731316    0.016505    0.042824    0.734857    
#> 335: 0.618330    1.011395    3.402026    0.729783    0.016498    0.042775    0.734943    
#> 336: 0.618093    1.011539    3.401973    0.729623    0.016489    0.042799    0.734988    
#> 337: 0.618150    1.011805    3.401856    0.730786    0.016492    0.042833    0.734952    
#> 338: 0.618106    1.011979    3.401866    0.730662    0.016514    0.042902    0.734840    
#> 339: 0.618000    1.012001    3.401874    0.729896    0.016537    0.042902    0.734751    
#> 340: 0.617981    1.011962    3.401882    0.729536    0.016565    0.042900    0.734666    
#> 341: 0.617967    1.011878    3.401957    0.729215    0.016581    0.042853    0.734664    
#> 342: 0.617803    1.011805    3.401927    0.728926    0.016571    0.042844    0.734610    
#> 343: 0.617653    1.011818    3.401977    0.728321    0.016549    0.042843    0.734588    
#> 344: 0.617855    1.011757    3.402075    0.727461    0.016577    0.042847    0.734612    
#> 345: 0.618014    1.011718    3.402159    0.726994    0.016581    0.042858    0.734595    
#> 346: 0.618124    1.011792    3.402143    0.726911    0.016560    0.042865    0.734415    
#> 347: 0.618485    1.011691    3.402100    0.728253    0.016559    0.042882    0.734377    
#> 348: 0.617995    1.011795    3.402069    0.727218    0.016549    0.042909    0.734539    
#> 349: 0.617904    1.011837    3.402011    0.727216    0.016548    0.042903    0.734485    
#> 350: 0.617900    1.011802    3.402003    0.727171    0.016554    0.042905    0.734355    
#> 351: 0.618116    1.011939    3.402024    0.727721    0.016549    0.042910    0.734264    
#> 352: 0.618105    1.012031    3.402076    0.728038    0.016540    0.042988    0.734403    
#> 353: 0.618599    1.012131    3.402153    0.728359    0.016556    0.042995    0.734484    
#> 354: 0.618631    1.012153    3.402095    0.728273    0.016559    0.043014    0.734404    
#> 355: 0.618929    1.012057    3.402020    0.728532    0.016579    0.043015    0.734486    
#> 356: 0.619187    1.011987    3.402038    0.729499    0.016603    0.043044    0.734562    
#> 357: 0.619356    1.011983    3.402056    0.729774    0.016597    0.043000    0.734586    
#> 358: 0.619223    1.012045    3.402020    0.730229    0.016591    0.042992    0.734530    
#> 359: 0.619402    1.012190    3.401906    0.731158    0.016607    0.042983    0.734542    
#> 360: 0.619528    1.012257    3.401776    0.731744    0.016599    0.042982    0.734461    
#> 361: 0.619293    1.012341    3.401680    0.731449    0.016596    0.042985    0.734310    
#> 362: 0.619144    1.012366    3.401597    0.731181    0.016575    0.042962    0.734251    
#> 363: 0.619176    1.012330    3.401659    0.730727    0.016570    0.042993    0.734163    
#> 364: 0.619266    1.012345    3.401669    0.730454    0.016535    0.043025    0.734232    
#> 365: 0.619284    1.012287    3.401743    0.729997    0.016523    0.043067    0.734329    
#> 366: 0.619401    1.012247    3.401732    0.729832    0.016485    0.043074    0.734502    
#> 367: 0.619431    1.012225    3.401715    0.729837    0.016455    0.043078    0.734510    
#> 368: 0.619773    1.012257    3.401680    0.731025    0.016432    0.043094    0.734364    
#> 369: 0.619818    1.012289    3.401651    0.731079    0.016433    0.043117    0.734354    
#> 370: 0.619616    1.012391    3.401644    0.730473    0.016444    0.043180    0.734420    
#> 371: 0.619493    1.012486    3.401598    0.730449    0.016437    0.043239    0.734365    
#> 372: 0.619281    1.012626    3.401522    0.730747    0.016453    0.043253    0.734320    
#> 373: 0.619078    1.012822    3.401436    0.730969    0.016483    0.043278    0.734294    
#> 374: 0.619259    1.012876    3.401433    0.731481    0.016505    0.043303    0.734373    
#> 375: 0.619404    1.012901    3.401445    0.732023    0.016518    0.043354    0.734327    
#> 376: 0.619419    1.012916    3.401467    0.732361    0.016533    0.043349    0.734297    
#> 377: 0.619387    1.013037    3.401413    0.733063    0.016564    0.043352    0.734220    
#> 378: 0.619200    1.013124    3.401280    0.733365    0.016574    0.043323    0.734226    
#> 379: 0.618916    1.013096    3.401303    0.732582    0.016598    0.043335    0.734229    
#> 380: 0.618827    1.013088    3.401296    0.732233    0.016645    0.043315    0.734166    
#> 381: 0.618597    1.013035    3.401271    0.731680    0.016673    0.043325    0.734126    
#> 382: 0.618542    1.013000    3.401255    0.731878    0.016676    0.043367    0.733960    
#> 383: 0.618478    1.013003    3.401238    0.731773    0.016699    0.043350    0.733780    
#> 384: 0.618124    1.013063    3.401205    0.731197    0.016692    0.043310    0.733727    
#> 385: 0.618205    1.013151    3.401160    0.731638    0.016681    0.043262    0.733700    
#> 386: 0.618446    1.013277    3.401172    0.732345    0.016707    0.043203    0.733769    
#> 387: 0.618440    1.013353    3.401222    0.732151    0.016739    0.043163    0.733768    
#> 388: 0.618436    1.013397    3.401199    0.732354    0.016779    0.043142    0.733740    
#> 389: 0.618591    1.013290    3.401157    0.732879    0.016816    0.043140    0.733797    
#> 390: 0.618483    1.013302    3.401084    0.733102    0.016816    0.043160    0.733764    
#> 391: 0.618441    1.013299    3.401004    0.733228    0.016806    0.043131    0.733784    
#> 392: 0.618600    1.013285    3.401044    0.733488    0.016830    0.043124    0.733708    
#> 393: 0.618515    1.013243    3.401010    0.733324    0.016858    0.043098    0.733666    
#> 394: 0.618648    1.013250    3.400950    0.733735    0.016864    0.043058    0.733659    
#> 395: 0.618939    1.013357    3.400928    0.734782    0.016893    0.043016    0.733594    
#> 396: 0.619248    1.013479    3.400931    0.736075    0.016926    0.043022    0.733533    
#> 397: 0.619488    1.013494    3.400939    0.736681    0.016963    0.043017    0.733452    
#> 398: 0.619735    1.013489    3.400994    0.737249    0.016999    0.042990    0.733408    
#> 399: 0.619659    1.013561    3.401010    0.736780    0.017022    0.042967    0.733446    
#> 400: 0.619730    1.013653    3.401081    0.736505    0.017046    0.042950    0.733506    
#> 401: 0.619713    1.013779    3.401092    0.735992    0.017078    0.042945    0.733629    
#> 402: 0.619859    1.013881    3.401144    0.735632    0.017086    0.042907    0.733693    
#> 403: 0.619994    1.013931    3.401166    0.735453    0.017090    0.042864    0.733783    
#> 404: 0.619959    1.013982    3.401160    0.735041    0.017104    0.042854    0.733717    
#> 405: 0.619950    1.014026    3.401185    0.734959    0.017137    0.042841    0.733707    
#> 406: 0.620110    1.014090    3.401127    0.735694    0.017182    0.042799    0.733618    
#> 407: 0.620119    1.014183    3.401102    0.736133    0.017204    0.042758    0.733614    
#> 408: 0.620165    1.014305    3.401093    0.736092    0.017215    0.042740    0.733609    
#> 409: 0.619969    1.014367    3.401100    0.735800    0.017236    0.042721    0.733563    
#> 410: 0.619705    1.014461    3.401045    0.735566    0.017252    0.042748    0.733461    
#> 411: 0.619676    1.014425    3.401051    0.735493    0.017277    0.042750    0.733409    
#> 412: 0.619530    1.014415    3.401044    0.735504    0.017294    0.042726    0.733356    
#> 413: 0.619589    1.014495    3.401000    0.735802    0.017326    0.042718    0.733293    
#> 414: 0.619339    1.014547    3.401010    0.735715    0.017347    0.042734    0.733249    
#> 415: 0.619481    1.014527    3.401004    0.735738    0.017343    0.042743    0.733159    
#> 416: 0.619401    1.014526    3.401063    0.735744    0.017337    0.042711    0.733085    
#> 417: 0.619531    1.014493    3.401055    0.735993    0.017342    0.042715    0.733016    
#> 418: 0.619295    1.014507    3.400975    0.735640    0.017339    0.042724    0.732957    
#> 419: 0.619297    1.014611    3.400940    0.735754    0.017338    0.042725    0.732889    
#> 420: 0.619344    1.014716    3.400914    0.736280    0.017337    0.042744    0.732794    
#> 421: 0.619329    1.014773    3.400959    0.736749    0.017344    0.042765    0.732717    
#> 422: 0.619422    1.014759    3.401000    0.736888    0.017336    0.042767    0.732652    
#> 423: 0.619473    1.014745    3.401044    0.736531    0.017320    0.042789    0.732610    
#> 424: 0.619519    1.014702    3.401022    0.736820    0.017306    0.042787    0.732631    
#> 425: 0.619639    1.014815    3.400979    0.737922    0.017312    0.042784    0.732691    
#> 426: 0.619876    1.014928    3.400964    0.739012    0.017311    0.042792    0.732672    
#> 427: 0.619875    1.014993    3.401023    0.738764    0.017293    0.042813    0.732611    
#> 428: 0.619764    1.015075    3.401050    0.738087    0.017273    0.042822    0.732608    
#> 429: 0.619648    1.015101    3.401059    0.737633    0.017264    0.042841    0.732688    
#> 430: 0.619564    1.015130    3.401072    0.737250    0.017270    0.042855    0.732745    
#> 431: 0.619318    1.015135    3.401050    0.736766    0.017243    0.042903    0.732686    
#> 432: 0.619190    1.015257    3.401019    0.736423    0.017245    0.042927    0.732706    
#> 433: 0.619198    1.015372    3.401078    0.736452    0.017258    0.042934    0.732656    
#> 434: 0.619009    1.015400    3.401060    0.735904    0.017249    0.042936    0.732577    
#> 435: 0.619056    1.015450    3.401032    0.735729    0.017247    0.042932    0.732530    
#> 436: 0.619186    1.015434    3.401126    0.735545    0.017247    0.042915    0.732586    
#> 437: 0.619197    1.015411    3.401200    0.735105    0.017236    0.042931    0.732696    
#> 438: 0.619098    1.015493    3.401189    0.734853    0.017227    0.042906    0.732713    
#> 439: 0.618985    1.015574    3.401173    0.734581    0.017237    0.042898    0.732672    
#> 440: 0.618928    1.015649    3.401145    0.734312    0.017247    0.042873    0.732664    
#> 441: 0.619038    1.015702    3.401123    0.734421    0.017265    0.042849    0.732623    
#> 442: 0.618711    1.015835    3.401026    0.733985    0.017273    0.042841    0.732565    
#> 443: 0.618491    1.016005    3.400938    0.733797    0.017291    0.042848    0.732514    
#> 444: 0.618284    1.016176    3.400795    0.733712    0.017306    0.042856    0.732520    
#> 445: 0.618008    1.016383    3.400672    0.733393    0.017322    0.042893    0.732533    
#> 446: 0.617629    1.016575    3.400555    0.733001    0.017339    0.042908    0.732508    
#> 447: 0.617494    1.016703    3.400491    0.732873    0.017355    0.042905    0.732567    
#> 448: 0.617228    1.016811    3.400442    0.732584    0.017361    0.042876    0.732625    
#> 449: 0.617013    1.016938    3.400445    0.732472    0.017378    0.042847    0.732622    
#> 450: 0.617146    1.017046    3.400430    0.732542    0.017383    0.042809    0.732700    
#> 451: 0.617297    1.017219    3.400389    0.733205    0.017416    0.042808    0.732733    
#> 452: 0.617310    1.017357    3.400343    0.733665    0.017432    0.042800    0.732742    
#> 453: 0.617138    1.017496    3.400286    0.733679    0.017460    0.042791    0.732708    
#> 454: 0.617079    1.017657    3.400220    0.733949    0.017476    0.042773    0.732743    
#> 455: 0.617004    1.017752    3.400183    0.733879    0.017476    0.042754    0.732712    
#> 456: 0.616950    1.017750    3.400214    0.733583    0.017470    0.042745    0.732799    
#> 457: 0.617002    1.017718    3.400277    0.733227    0.017449    0.042726    0.732809    
#> 458: 0.617093    1.017750    3.400349    0.732971    0.017446    0.042727    0.732808    
#> 459: 0.616951    1.017824    3.400370    0.732722    0.017458    0.042736    0.732772    
#> 460: 0.616913    1.017857    3.400361    0.732286    0.017468    0.042724    0.732735    
#> 461: 0.616795    1.017894    3.400404    0.731626    0.017479    0.042709    0.732685    
#> 462: 0.616649    1.017952    3.400431    0.731362    0.017493    0.042700    0.732685    
#> 463: 0.616463    1.018024    3.400445    0.730842    0.017485    0.042680    0.732745    
#> 464: 0.616349    1.018132    3.400384    0.730522    0.017489    0.042668    0.732787    
#> 465: 0.616253    1.018110    3.400367    0.729975    0.017499    0.042662    0.732786    
#> 466: 0.616233    1.018166    3.400313    0.729930    0.017501    0.042660    0.732786    
#> 467: 0.616353    1.018159    3.400352    0.730173    0.017489    0.042620    0.732715    
#> 468: 0.616431    1.018173    3.400352    0.730313    0.017489    0.042575    0.732686    
#> 469: 0.616551    1.018240    3.400331    0.730385    0.017495    0.042538    0.732767    
#> 470: 0.616592    1.018299    3.400260    0.731107    0.017494    0.042526    0.732767    
#> 471: 0.616596    1.018297    3.400266    0.731229    0.017484    0.042547    0.732776    
#> 472: 0.616826    1.018277    3.400260    0.731953    0.017476    0.042553    0.732805    
#> 473: 0.616950    1.018282    3.400275    0.732072    0.017472    0.042531    0.732812    
#> 474: 0.616920    1.018280    3.400264    0.731993    0.017482    0.042504    0.732839    
#> 475: 0.616873    1.018315    3.400272    0.731389    0.017491    0.042504    0.732798    
#> 476: 0.616915    1.018309    3.400289    0.731016    0.017499    0.042470    0.732819    
#> 477: 0.617009    1.018288    3.400356    0.730849    0.017500    0.042451    0.732805    
#> 478: 0.617115    1.018258    3.400434    0.730647    0.017487    0.042431    0.732863    
#> 479: 0.617169    1.018222    3.400491    0.730314    0.017502    0.042410    0.732809    
#> 480: 0.617244    1.018208    3.400456    0.730471    0.017494    0.042384    0.732815    
#> 481: 0.617262    1.018184    3.400391    0.730733    0.017477    0.042364    0.732808    
#> 482: 0.617242    1.018145    3.400341    0.731207    0.017471    0.042367    0.732869    
#> 483: 0.617251    1.018121    3.400358    0.731372    0.017456    0.042366    0.732898    
#> 484: 0.617431    1.018053    3.400369    0.731707    0.017443    0.042369    0.732923    
#> 485: 0.617509    1.018105    3.400395    0.731481    0.017456    0.042392    0.732893    
#> 486: 0.617655    1.018192    3.400461    0.731575    0.017467    0.042406    0.732830    
#> 487: 0.618004    1.018261    3.400537    0.732246    0.017475    0.042383    0.732817    
#> 488: 0.618232    1.018272    3.400568    0.732378    0.017484    0.042365    0.732757    
#> 489: 0.618444    1.018232    3.400591    0.732787    0.017495    0.042376    0.732733    
#> 490: 0.618584    1.018248    3.400623    0.732889    0.017500    0.042384    0.732684    
#> 491: 0.618604    1.018358    3.400657    0.732732    0.017518    0.042377    0.732681    
#> 492: 0.618514    1.018437    3.400655    0.732357    0.017551    0.042370    0.732648    
#> 493: 0.618234    1.018451    3.400668    0.731671    0.017587    0.042365    0.732591    
#> 494: 0.618217    1.018497    3.400673    0.731540    0.017604    0.042355    0.732528    
#> 495: 0.618287    1.018558    3.400661    0.731423    0.017612    0.042366    0.732437    
#> 496: 0.618354    1.018634    3.400638    0.731518    0.017622    0.042369    0.732362    
#> 497: 0.618297    1.018638    3.400609    0.731681    0.017628    0.042369    0.732389    
#> 498: 0.618103    1.018693    3.400550    0.731499    0.017640    0.042349    0.732379    
#> 499: 0.617880    1.018786    3.400450    0.731466    0.017663    0.042355    0.732357    
#> 500: 0.617847    1.018810    3.400372    0.731742    0.017679    0.042367    0.732325    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.287785    0.979740    3.450394    0.392401    0.084579    0.016800    1.460773    
#> 002: 0.417639    1.006935    3.474540    0.372781    0.080351    0.015960    1.031363    
#> 003: 0.559139    1.027501    3.491857    0.354142    0.076333    0.015162    0.867525    
#> 004: 0.559369    1.044264    3.491493    0.336435    0.072516    0.014404    0.764042    
#> 005: 0.634632    1.046672    3.487168    0.319613    0.068891    0.013684    0.722328    
#> 006: 0.613369    1.053255    3.482239    0.303633    0.065446    0.013000    0.680164    
#> 007: 0.587656    1.066926    3.482630    0.288451    0.073150    0.012818    0.691691    
#> 008: 0.565973    1.069475    3.476308    0.274029    0.080809    0.012177    0.683238    
#> 009: 0.544199    1.053727    3.475248    0.260327    0.077265    0.012926    0.685045    
#> 010: 0.578458    1.049676    3.481098    0.247311    0.073402    0.012280    0.705907    
#> 011: 0.633974    1.053737    3.488362    0.263109    0.069732    0.013003    0.708338    
#> 012: 0.647058    1.050942    3.483627    0.284261    0.066245    0.012353    0.703192    
#> 013: 0.588992    1.055078    3.477988    0.351737    0.064330    0.011735    0.691117    
#> 014: 0.673488    1.060212    3.484530    0.394355    0.061813    0.011226    0.706047    
#> 015: 0.660580    1.059644    3.497343    0.374637    0.058723    0.012460    0.678563    
#> 016: 0.633078    1.077000    3.500426    0.355905    0.055787    0.017514    0.678835    
#> 017: 0.621245    1.069669    3.493500    0.338110    0.052997    0.016639    0.673423    
#> 018: 0.630495    1.060830    3.487931    0.321204    0.054786    0.015807    0.684287    
#> 019: 0.587772    1.070271    3.485540    0.305144    0.056871    0.015016    0.684187    
#> 020: 0.662293    1.056299    3.501271    0.325299    0.066413    0.015273    0.693707    
#> 021: 0.668117    1.044995    3.517625    0.309034    0.063092    0.014510    0.695216    
#> 022: 0.681019    1.033161    3.521475    0.293582    0.059938    0.013784    0.679402    
#> 023: 0.712887    1.032056    3.518608    0.320287    0.060292    0.013095    0.725904    
#> 024: 0.702576    1.049449    3.514873    0.304273    0.057278    0.012440    0.710722    
#> 025: 0.642395    1.035137    3.504784    0.289059    0.054414    0.013781    0.704360    
#> 026: 0.632644    1.085373    3.490074    0.274606    0.051693    0.013733    0.695685    
#> 027: 0.572968    1.091874    3.478240    0.260876    0.058061    0.015323    0.708485    
#> 028: 0.587647    1.096577    3.476590    0.296472    0.063179    0.015635    0.690394    
#> 029: 0.631226    1.080003    3.482848    0.281648    0.066544    0.014853    0.715122    
#> 030: 0.663567    1.069454    3.502826    0.267566    0.063217    0.016073    0.693381    
#> 031: 0.625816    1.057645    3.505777    0.254188    0.069628    0.015270    0.688674    
#> 032: 0.628013    1.042051    3.499755    0.241478    0.069249    0.014506    0.674054    
#> 033: 0.625439    1.059294    3.492241    0.270362    0.067297    0.013781    0.689263    
#> 034: 0.662983    1.066165    3.501417    0.291677    0.065758    0.013092    0.671082    
#> 035: 0.634712    1.045673    3.496589    0.331794    0.074827    0.012637    0.678865    
#> 036: 0.624678    1.076177    3.493975    0.321821    0.071086    0.014717    0.687863    
#> 037: 0.618851    1.076485    3.487975    0.305730    0.067531    0.014905    0.702700    
#> 038: 0.634080    1.073052    3.484545    0.290443    0.079045    0.014160    0.704119    
#> 039: 0.666757    1.070761    3.501699    0.289177    0.075203    0.016767    0.665594    
#> 040: 0.655432    1.066446    3.503119    0.313160    0.071443    0.015929    0.680861    
#> 041: 0.618412    1.046142    3.497121    0.297502    0.067871    0.017966    0.687206    
#> 042: 0.648866    1.053529    3.494209    0.354497    0.064477    0.017068    0.680931    
#> 043: 0.642559    1.061998    3.480649    0.359741    0.061253    0.016215    0.678432    
#> 044: 0.606463    1.073064    3.483301    0.341754    0.058191    0.015404    0.678272    
#> 045: 0.631243    1.076714    3.485253    0.324666    0.055281    0.015801    0.692230    
#> 046: 0.649775    1.067434    3.481757    0.308433    0.052517    0.016624    0.687063    
#> 047: 0.648733    1.052867    3.484339    0.303695    0.049891    0.019533    0.682786    
#> 048: 0.641561    1.053973    3.497368    0.288510    0.048498    0.020084    0.677183    
#> 049: 0.607611    1.061057    3.497304    0.274084    0.061151    0.019080    0.689717    
#> 050: 0.659510    1.053826    3.497625    0.273513    0.058094    0.018126    0.706851    
#> 051: 0.663992    1.056749    3.504675    0.259837    0.055189    0.017219    0.709563    
#> 052: 0.637966    1.062517    3.508083    0.260786    0.052430    0.016358    0.692663    
#> 053: 0.646510    1.040748    3.508118    0.254092    0.050282    0.016853    0.701496    
#> 054: 0.597465    1.060519    3.504429    0.242054    0.051213    0.019428    0.695222    
#> 055: 0.609313    1.057652    3.500508    0.259937    0.056906    0.018456    0.688841    
#> 056: 0.651344    1.045532    3.495368    0.333320    0.054061    0.017533    0.702336    
#> 057: 0.655098    1.045720    3.504444    0.316654    0.061779    0.016978    0.698991    
#> 058: 0.678171    1.046807    3.493935    0.332722    0.059620    0.016130    0.690712    
#> 059: 0.705282    1.014311    3.508009    0.362658    0.056639    0.019164    0.706803    
#> 060: 0.684518    0.999846    3.526478    0.344525    0.053807    0.021027    0.711232    
#> 061: 0.684717    1.005347    3.530648    0.327299    0.051117    0.021153    0.722536    
#> 062: 0.666959    1.036572    3.516373    0.313746    0.048561    0.020096    0.709405    
#> 063: 0.686425    1.025836    3.513776    0.345763    0.054882    0.019091    0.698777    
#> 064: 0.673434    1.018322    3.523747    0.335488    0.053567    0.018136    0.713705    
#> 065: 0.689018    1.018313    3.502383    0.318714    0.050888    0.018346    0.715863    
#> 066: 0.668884    1.044532    3.511210    0.318238    0.051342    0.017553    0.686857    
#> 067: 0.668069    1.057358    3.492338    0.353855    0.051265    0.017328    0.685832    
#> 068: 0.634518    1.044770    3.497370    0.336163    0.054175    0.016462    0.705617    
#> 069: 0.645785    1.044408    3.497810    0.412973    0.051466    0.018283    0.694390    
#> 070: 0.674553    1.034325    3.505513    0.409415    0.051679    0.020055    0.686370    
#> 071: 0.615779    1.063228    3.485997    0.388944    0.051510    0.019420    0.705277    
#> 072: 0.609386    1.056517    3.494728    0.369497    0.050047    0.019450    0.680777    
#> 073: 0.638541    1.051968    3.514452    0.351022    0.051079    0.018477    0.693004    
#> 074: 0.607491    1.034474    3.500696    0.333471    0.059961    0.017553    0.697910    
#> 075: 0.633977    1.043293    3.524070    0.316797    0.066155    0.017338    0.693783    
#> 076: 0.695869    1.046609    3.532785    0.300957    0.062847    0.020116    0.711929    
#> 077: 0.701047    1.028106    3.513706    0.285909    0.059705    0.019110    0.704208    
#> 078: 0.661533    1.033076    3.516107    0.271614    0.056720    0.018154    0.684553    
#> 079: 0.654063    1.057206    3.511716    0.258761    0.053884    0.021017    0.693955    
#> 080: 0.645972    1.046791    3.499727    0.276131    0.054276    0.021285    0.711771    
#> 081: 0.624034    1.056471    3.491474    0.278672    0.051562    0.020221    0.693224    
#> 082: 0.637566    1.042801    3.501488    0.264739    0.049907    0.019210    0.690752    
#> 083: 0.619506    1.070102    3.504503    0.251502    0.047411    0.018507    0.701846    
#> 084: 0.639528    1.056137    3.491442    0.295645    0.055847    0.018603    0.678517    
#> 085: 0.639257    1.069824    3.504281    0.291809    0.057339    0.017672    0.684494    
#> 086: 0.628203    1.056430    3.505834    0.277219    0.054472    0.020815    0.704203    
#> 087: 0.612763    1.047369    3.494113    0.281293    0.051748    0.019774    0.701241    
#> 088: 0.568200    1.049272    3.491904    0.320721    0.050785    0.018786    0.699582    
#> 089: 0.626296    1.062846    3.488902    0.332573    0.057080    0.017846    0.668143    
#> 090: 0.631600    1.053374    3.489547    0.321158    0.069559    0.017247    0.682610    
#> 091: 0.624085    1.036726    3.475811    0.314566    0.066081    0.017927    0.681877    
#> 092: 0.572073    1.078011    3.470271    0.353134    0.062777    0.017031    0.679546    
#> 093: 0.573026    1.069751    3.475092    0.335477    0.068244    0.016179    0.687402    
#> 094: 0.580106    1.066946    3.481314    0.318703    0.066652    0.015370    0.691376    
#> 095: 0.627302    1.068895    3.494088    0.302768    0.063319    0.014602    0.680896    
#> 096: 0.565233    1.085460    3.481966    0.287630    0.066612    0.013872    0.684296    
#> 097: 0.601956    1.105714    3.479070    0.273248    0.067775    0.014406    0.678643    
#> 098: 0.586277    1.109096    3.485160    0.259586    0.064386    0.016494    0.685958    
#> 099: 0.582432    1.070665    3.469632    0.301607    0.062796    0.015669    0.674938    
#> 100: 0.596343    1.091786    3.477543    0.308466    0.069375    0.015871    0.660807    
#> 101: 0.584020    1.064246    3.462892    0.300239    0.065906    0.015077    0.668420    
#> 102: 0.574601    1.074041    3.466805    0.285227    0.062611    0.014323    0.686925    
#> 103: 0.622377    1.070692    3.481139    0.292721    0.059480    0.017137    0.674517    
#> 104: 0.604377    1.075251    3.491472    0.278085    0.059507    0.016280    0.687509    
#> 105: 0.586587    1.056268    3.488291    0.264181    0.064480    0.015955    0.684486    
#> 106: 0.628810    1.060235    3.486681    0.250971    0.061256    0.015157    0.682777    
#> 107: 0.646375    1.093837    3.488122    0.291746    0.058193    0.014399    0.686344    
#> 108: 0.662097    1.082475    3.486090    0.299556    0.064157    0.013679    0.702602    
#> 109: 0.656305    1.056783    3.504435    0.301726    0.068659    0.012995    0.691899    
#> 110: 0.671278    1.041074    3.489837    0.360766    0.065226    0.013665    0.687165    
#> 111: 0.644330    1.049010    3.497935    0.342728    0.061964    0.012982    0.675292    
#> 112: 0.628915    1.034978    3.483491    0.325592    0.058866    0.012333    0.703867    
#> 113: 0.601258    1.070733    3.484750    0.309312    0.055923    0.011716    0.681701    
#> 114: 0.632141    1.067144    3.488408    0.317865    0.054466    0.013315    0.691015    
#> 115: 0.679366    1.042063    3.500252    0.334105    0.055716    0.016715    0.692950    
#> 116: 0.624579    1.059664    3.489901    0.317400    0.063845    0.016434    0.706893    
#> 117: 0.604842    1.065792    3.497846    0.301530    0.060653    0.015612    0.705104    
#> 118: 0.613352    1.043902    3.497085    0.286453    0.057620    0.014832    0.705414    
#> 119: 0.638670    1.055421    3.489606    0.272131    0.054739    0.015840    0.691312    
#> 120: 0.590767    1.044256    3.488922    0.258524    0.055046    0.020772    0.679217    
#> 121: 0.637925    1.077045    3.485111    0.276693    0.062985    0.020649    0.667782    
#> 122: 0.631557    1.045268    3.500467    0.288472    0.059836    0.021853    0.689283    
#> 123: 0.637288    1.059885    3.485473    0.298942    0.066492    0.020760    0.680259    
#> 124: 0.645298    1.103751    3.490362    0.283995    0.063167    0.019722    0.675299    
#> 125: 0.643245    1.086102    3.487847    0.306510    0.060009    0.018736    0.684160    
#> 126: 0.614091    1.100240    3.480005    0.291185    0.063942    0.017799    0.687508    
#> 127: 0.597558    1.085445    3.465114    0.299186    0.060760    0.016909    0.699203    
#> 128: 0.606641    1.066812    3.491570    0.303587    0.057722    0.016064    0.690487    
#> 129: 0.660968    1.069661    3.493896    0.354042    0.054836    0.015609    0.691586    
#> 130: 0.676120    1.083044    3.492441    0.336340    0.052094    0.015755    0.692652    
#> 131: 0.608285    1.063445    3.478601    0.319523    0.054154    0.014967    0.694794    
#> 132: 0.537045    1.077677    3.461770    0.303547    0.063950    0.017003    0.707099    
#> 133: 0.596877    1.074007    3.471393    0.412979    0.060752    0.016672    0.684036    
#> 134: 0.617140    1.048561    3.487059    0.415165    0.057715    0.023510    0.685603    
#> 135: 0.642802    1.060540    3.496752    0.409326    0.054829    0.022335    0.697846    
#> 136: 0.657240    1.048064    3.494539    0.388860    0.052087    0.021218    0.678260    
#> 137: 0.698258    1.036121    3.499719    0.369417    0.049483    0.020157    0.681208    
#> 138: 0.676885    1.055043    3.503640    0.350946    0.050309    0.019917    0.668721    
#> 139: 0.617078    1.068789    3.503742    0.333398    0.051885    0.021866    0.671534    
#> 140: 0.648539    1.067697    3.507031    0.327167    0.049291    0.022541    0.692771    
#> 141: 0.624141    1.055448    3.502844    0.310809    0.046826    0.021470    0.690531    
#> 142: 0.638595    1.023839    3.512505    0.315302    0.044485    0.020397    0.712894    
#> 143: 0.631522    1.057074    3.506603    0.335972    0.047935    0.019377    0.694930    
#> 144: 0.672963    1.053314    3.512511    0.319174    0.045538    0.018408    0.689817    
#> 145: 0.636767    1.070092    3.493506    0.303215    0.043261    0.017488    0.690919    
#> 146: 0.584075    1.084827    3.499719    0.288054    0.050421    0.016613    0.704259    
#> 147: 0.549995    1.058714    3.485239    0.273652    0.054597    0.016377    0.687121    
#> 148: 0.612772    1.065371    3.494109    0.330470    0.057037    0.015558    0.674201    
#> 149: 0.626816    1.054068    3.495751    0.313946    0.060279    0.014781    0.691191    
#> 150: 0.654643    1.050820    3.494936    0.298249    0.059473    0.014042    0.689527    
#> 151: 0.611109    1.070321    3.502332    0.283337    0.059450    0.015001    0.679391    
#> 152: 0.613679    1.060821    3.503380    0.273969    0.055478    0.014815    0.676648    
#> 153: 0.648824    1.067389    3.507818    0.285935    0.060011    0.016427    0.685067    
#> 154: 0.648315    1.067406    3.506144    0.239245    0.052738    0.021628    0.687991    
#> 155: 0.630853    1.054014    3.503672    0.229863    0.043989    0.022188    0.685387    
#> 156: 0.636179    1.062426    3.504328    0.222170    0.039117    0.018433    0.708927    
#> 157: 0.646189    1.066470    3.517036    0.218300    0.045672    0.017961    0.698177    
#> 158: 0.680003    1.055977    3.504347    0.270380    0.045021    0.017356    0.696979    
#> 159: 0.602190    1.059800    3.506312    0.293068    0.046312    0.018710    0.679598    
#> 160: 0.668681    1.028981    3.514279    0.322673    0.050877    0.021908    0.694228    
#> 161: 0.663483    1.041774    3.506693    0.321936    0.039531    0.024896    0.687292    
#> 162: 0.639095    1.057807    3.496295    0.313191    0.038676    0.026287    0.696871    
#> 163: 0.618920    1.061190    3.488285    0.282613    0.049135    0.022857    0.692236    
#> 164: 0.616906    1.058381    3.486317    0.311485    0.044313    0.025703    0.688129    
#> 165: 0.673146    1.064650    3.493893    0.288665    0.047446    0.023030    0.691863    
#> 166: 0.656598    1.077821    3.496049    0.289722    0.049440    0.021839    0.682200    
#> 167: 0.682104    1.073677    3.505670    0.318734    0.060811    0.019117    0.691126    
#> 168: 0.671588    1.085952    3.502659    0.317569    0.067955    0.019208    0.697749    
#> 169: 0.674851    1.106263    3.503805    0.304017    0.065347    0.020158    0.709365    
#> 170: 0.676919    1.072489    3.507554    0.286943    0.063177    0.021997    0.700486    
#> 171: 0.624656    1.076493    3.489137    0.292958    0.068066    0.017749    0.680725    
#> 172: 0.615406    1.088818    3.487747    0.274662    0.065532    0.014834    0.682354    
#> 173: 0.596539    1.076236    3.476065    0.230565    0.056698    0.015308    0.681486    
#> 174: 0.596217    1.069473    3.490587    0.242940    0.075774    0.015733    0.691534    
#> 175: 0.607966    1.064711    3.481142    0.258884    0.062490    0.017875    0.695599    
#> 176: 0.612019    1.080041    3.493283    0.217238    0.057199    0.015817    0.690353    
#> 177: 0.627100    1.076203    3.502944    0.211621    0.066342    0.013635    0.693060    
#> 178: 0.635855    1.071074    3.501990    0.247408    0.067386    0.015971    0.673370    
#> 179: 0.652661    1.084407    3.501152    0.215430    0.063285    0.018072    0.702494    
#> 180: 0.640159    1.062788    3.497915    0.263986    0.056948    0.014705    0.703580    
#> 181: 0.626230    1.064781    3.477912    0.278400    0.047521    0.013685    0.705266    
#> 182: 0.591684    1.067154    3.465952    0.286676    0.043728    0.014377    0.718754    
#> 183: 0.602627    1.091055    3.471839    0.277990    0.058370    0.015127    0.695039    
#> 184: 0.607801    1.046092    3.484174    0.269528    0.055293    0.013515    0.688274    
#> 185: 0.595070    1.081815    3.480712    0.276176    0.053497    0.013123    0.709107    
#> 186: 0.606083    1.110290    3.482898    0.276214    0.069222    0.013209    0.701809    
#> 187: 0.636201    1.089956    3.489755    0.307703    0.062232    0.015706    0.673476    
#> 188: 0.613808    1.077742    3.491209    0.261300    0.064680    0.014587    0.688240    
#> 189: 0.626539    1.079410    3.506495    0.276117    0.064933    0.017245    0.702888    
#> 190: 0.646638    1.063988    3.507086    0.351698    0.058767    0.016701    0.683001    
#> 191: 0.589889    1.067939    3.486522    0.255124    0.051958    0.016628    0.677328    
#> 192: 0.599031    1.067548    3.488697    0.280189    0.053987    0.016477    0.673049    
#> 193: 0.636168    1.086467    3.489556    0.283347    0.048230    0.017609    0.666063    
#> 194: 0.588590    1.067253    3.476838    0.291908    0.048154    0.016944    0.689140    
#> 195: 0.581966    1.064423    3.478055    0.283891    0.041286    0.017884    0.693698    
#> 196: 0.640025    1.039719    3.503523    0.255842    0.041190    0.022567    0.682601    
#> 197: 0.612564    1.051260    3.524177    0.220740    0.042457    0.023336    0.703233    
#> 198: 0.673529    1.034456    3.511680    0.228214    0.047434    0.020015    0.709123    
#> 199: 0.645661    1.036340    3.500590    0.277951    0.051563    0.012752    0.700605    
#> 200: 0.627499    1.038879    3.494417    0.307482    0.058424    0.011343    0.716689    
#> 201: 0.622402    1.037229    3.497710    0.296605    0.054836    0.012571    0.711576    
#> 202: 0.620021    1.044358    3.496279    0.279703    0.058141    0.013002    0.707256    
#> 203: 0.636450    1.043561    3.497685    0.271197    0.057195    0.012859    0.705502    
#> 204: 0.641561    1.038502    3.500150    0.270365    0.059501    0.012612    0.705700    
#> 205: 0.635513    1.044151    3.499610    0.270116    0.059051    0.012755    0.707952    
#> 206: 0.635353    1.048332    3.500310    0.264974    0.057620    0.012722    0.705966    
#> 207: 0.632068    1.049439    3.498692    0.268659    0.057410    0.012540    0.703636    
#> 208: 0.627935    1.049844    3.497372    0.264213    0.056385    0.012560    0.703181    
#> 209: 0.629317    1.048843    3.497010    0.258283    0.055702    0.012550    0.702267    
#> 210: 0.630278    1.048674    3.496967    0.255952    0.055703    0.012705    0.700223    
#> 211: 0.630774    1.050428    3.497333    0.254180    0.056075    0.012859    0.697994    
#> 212: 0.630028    1.051015    3.497074    0.252101    0.055959    0.013139    0.697344    
#> 213: 0.631156    1.049689    3.497810    0.253864    0.056286    0.013562    0.696078    
#> 214: 0.634347    1.049789    3.498173    0.254815    0.056189    0.013877    0.695919    
#> 215: 0.633070    1.049551    3.498641    0.253414    0.055837    0.014181    0.696701    
#> 216: 0.633827    1.049745    3.498790    0.253390    0.056585    0.014428    0.697997    
#> 217: 0.634195    1.051194    3.498536    0.251033    0.056999    0.014412    0.697371    
#> 218: 0.634363    1.052601    3.498121    0.252516    0.057477    0.014518    0.697072    
#> 219: 0.632049    1.052924    3.496551    0.253989    0.057281    0.014649    0.697410    
#> 220: 0.631077    1.053525    3.496218    0.257849    0.056746    0.014787    0.696541    
#> 221: 0.632313    1.053443    3.496061    0.259076    0.056841    0.014917    0.695660    
#> 222: 0.634050    1.053521    3.496185    0.261276    0.056690    0.015183    0.695685    
#> 223: 0.635062    1.053378    3.496219    0.260177    0.056695    0.015364    0.696032    
#> 224: 0.636782    1.054572    3.496467    0.260051    0.057009    0.015480    0.696068    
#> 225: 0.636177    1.052757    3.497180    0.258308    0.056970    0.015827    0.696839    
#> 226: 0.637336    1.051004    3.497387    0.257557    0.057035    0.016030    0.697399    
#> 227: 0.637083    1.051005    3.497816    0.256764    0.057359    0.016049    0.697135    
#> 228: 0.637036    1.051837    3.497732    0.255838    0.057397    0.016118    0.697053    
#> 229: 0.636220    1.051633    3.497598    0.254650    0.057313    0.016209    0.696418    
#> 230: 0.635422    1.051637    3.497306    0.254086    0.056875    0.016209    0.696564    
#> 231: 0.635020    1.052349    3.497499    0.254730    0.056814    0.016158    0.696518    
#> 232: 0.634326    1.052144    3.497835    0.253714    0.056623    0.016141    0.696387    
#> 233: 0.634425    1.050943    3.498290    0.252276    0.056792    0.016168    0.696607    
#> 234: 0.634384    1.050933    3.498305    0.251978    0.057028    0.016185    0.696596    
#> 235: 0.634349    1.050634    3.498223    0.250768    0.057105    0.016150    0.696344    
#> 236: 0.635209    1.050415    3.498433    0.250490    0.057249    0.016115    0.696329    
#> 237: 0.636920    1.050411    3.498713    0.248969    0.057371    0.016062    0.697230    
#> 238: 0.637016    1.050413    3.499057    0.247209    0.057625    0.016044    0.698113    
#> 239: 0.637606    1.050667    3.499307    0.245794    0.057926    0.016081    0.697677    
#> 240: 0.637678    1.050404    3.499520    0.245959    0.058036    0.015988    0.697092    
#> 241: 0.638053    1.049824    3.499756    0.246196    0.058193    0.015872    0.696829    
#> 242: 0.637982    1.049554    3.499610    0.246627    0.058577    0.015754    0.696832    
#> 243: 0.638126    1.049657    3.499673    0.246962    0.058957    0.015655    0.696790    
#> 244: 0.637827    1.049688    3.499770    0.247536    0.058998    0.015586    0.697143    
#> 245: 0.637514    1.049937    3.499894    0.248183    0.059319    0.015646    0.697287    
#> 246: 0.637208    1.049782    3.500070    0.248646    0.059094    0.015728    0.697797    
#> 247: 0.637582    1.049676    3.500382    0.249516    0.059011    0.015769    0.697754    
#> 248: 0.637900    1.050061    3.500379    0.249424    0.058959    0.015722    0.697604    
#> 249: 0.637978    1.050271    3.500396    0.250696    0.059170    0.015674    0.697365    
#> 250: 0.638423    1.050802    3.500464    0.251017    0.059593    0.015598    0.697478    
#> 251: 0.638980    1.051148    3.500792    0.251163    0.059687    0.015541    0.697800    
#> 252: 0.639434    1.051188    3.501191    0.250434    0.059853    0.015477    0.698044    
#> 253: 0.639536    1.050943    3.501349    0.250872    0.059984    0.015395    0.698130    
#> 254: 0.639894    1.051148    3.501477    0.251599    0.059997    0.015294    0.698146    
#> 255: 0.639518    1.051396    3.501483    0.251609    0.059983    0.015243    0.698151    
#> 256: 0.639923    1.051311    3.501455    0.251388    0.059950    0.015174    0.698199    
#> 257: 0.640206    1.050937    3.501409    0.251438    0.060056    0.015123    0.698400    
#> 258: 0.640028    1.050147    3.501525    0.250903    0.060069    0.015135    0.698333    
#> 259: 0.640018    1.050081    3.501510    0.250917    0.060032    0.015147    0.698276    
#> 260: 0.639744    1.050276    3.501612    0.250906    0.060071    0.015121    0.698212    
#> 261: 0.639872    1.050376    3.501736    0.249945    0.059953    0.015153    0.698165    
#> 262: 0.639774    1.050810    3.501799    0.249332    0.059863    0.015152    0.698315    
#> 263: 0.639491    1.051405    3.501602    0.249577    0.059952    0.015136    0.698279    
#> 264: 0.639181    1.051417    3.501545    0.250333    0.060190    0.015133    0.698436    
#> 265: 0.638830    1.051608    3.501390    0.250295    0.060456    0.015126    0.698655    
#> 266: 0.638578    1.051858    3.501234    0.250142    0.060498    0.015135    0.698646    
#> 267: 0.637781    1.052159    3.501095    0.250236    0.060532    0.015165    0.698710    
#> 268: 0.637277    1.052135    3.500788    0.250539    0.060514    0.015136    0.698755    
#> 269: 0.637349    1.052289    3.500612    0.251007    0.060445    0.015146    0.698603    
#> 270: 0.637466    1.052526    3.500463    0.251294    0.060315    0.015117    0.698372    
#> 271: 0.637590    1.052578    3.500294    0.251541    0.060130    0.015092    0.698709    
#> 272: 0.637795    1.052360    3.500212    0.252197    0.059985    0.015081    0.698801    
#> 273: 0.637742    1.052700    3.500264    0.252232    0.059905    0.015067    0.698852    
#> 274: 0.637771    1.053023    3.500340    0.251700    0.059719    0.015084    0.698803    
#> 275: 0.637632    1.053507    3.500174    0.251189    0.059662    0.015097    0.698869    
#> 276: 0.637278    1.053795    3.500208    0.251038    0.059545    0.015144    0.698778    
#> 277: 0.636970    1.054241    3.500341    0.251227    0.059383    0.015176    0.698772    
#> 278: 0.636901    1.054319    3.500435    0.251689    0.059277    0.015199    0.698398    
#> 279: 0.637049    1.054125    3.500536    0.251873    0.059195    0.015249    0.698378    
#> 280: 0.637271    1.054430    3.500628    0.251533    0.059057    0.015297    0.698257    
#> 281: 0.636862    1.054768    3.500667    0.250922    0.059026    0.015344    0.698315    
#> 282: 0.636700    1.054945    3.500819    0.250473    0.058951    0.015400    0.698312    
#> 283: 0.636983    1.055084    3.500946    0.250461    0.058798    0.015461    0.698360    
#> 284: 0.637312    1.054858    3.501014    0.250919    0.058578    0.015485    0.698366    
#> 285: 0.637326    1.054916    3.500904    0.250974    0.058410    0.015491    0.698372    
#> 286: 0.637096    1.055266    3.500692    0.251377    0.058399    0.015517    0.698567    
#> 287: 0.637161    1.055580    3.500613    0.252108    0.058315    0.015538    0.698504    
#> 288: 0.637677    1.055543    3.500662    0.252357    0.058257    0.015554    0.698613    
#> 289: 0.638163    1.055377    3.500802    0.251890    0.058288    0.015555    0.698667    
#> 290: 0.638403    1.055304    3.500866    0.251489    0.058253    0.015544    0.698944    
#> 291: 0.638706    1.055535    3.500919    0.251051    0.058067    0.015573    0.698913    
#> 292: 0.638854    1.055755    3.500856    0.251685    0.057899    0.015564    0.698768    
#> 293: 0.639388    1.055695    3.500766    0.252192    0.057862    0.015563    0.698569    
#> 294: 0.639895    1.055666    3.500717    0.252669    0.057839    0.015545    0.698424    
#> 295: 0.640089    1.055385    3.500684    0.253296    0.057693    0.015557    0.698336    
#> 296: 0.639954    1.055338    3.500619    0.253305    0.057610    0.015599    0.698481    
#> 297: 0.640205    1.055431    3.500624    0.253393    0.057481    0.015624    0.698516    
#> 298: 0.640200    1.055377    3.500581    0.253564    0.057472    0.015593    0.698431    
#> 299: 0.640148    1.055541    3.500473    0.254109    0.057499    0.015585    0.698271    
#> 300: 0.640189    1.055602    3.500546    0.254143    0.057541    0.015574    0.698100    
#> 301: 0.640421    1.055536    3.500582    0.254174    0.057594    0.015590    0.698123    
#> 302: 0.640417    1.055574    3.500531    0.254074    0.057640    0.015571    0.698036    
#> 303: 0.640164    1.055789    3.500446    0.254028    0.057627    0.015578    0.697839    
#> 304: 0.640231    1.056025    3.500301    0.254167    0.057635    0.015573    0.697837    
#> 305: 0.640046    1.055847    3.500161    0.254684    0.057587    0.015589    0.697738    
#> 306: 0.639725    1.055870    3.500030    0.255086    0.057731    0.015600    0.697655    
#> 307: 0.639211    1.055844    3.499856    0.254972    0.057855    0.015598    0.697734    
#> 308: 0.638686    1.055779    3.499745    0.255358    0.057837    0.015616    0.697689    
#> 309: 0.638533    1.055680    3.499656    0.255635    0.057847    0.015607    0.697714    
#> 310: 0.638287    1.055685    3.499397    0.255906    0.057780    0.015614    0.697695    
#> 311: 0.638066    1.055688    3.499312    0.256342    0.057671    0.015591    0.697611    
#> 312: 0.637720    1.055716    3.499207    0.255972    0.057612    0.015557    0.697677    
#> 313: 0.637295    1.055512    3.499056    0.255560    0.057619    0.015589    0.697882    
#> 314: 0.636824    1.055604    3.498936    0.255804    0.057633    0.015606    0.697937    
#> 315: 0.636653    1.055670    3.498924    0.256054    0.057626    0.015630    0.697868    
#> 316: 0.636731    1.055782    3.498884    0.256306    0.057666    0.015656    0.697796    
#> 317: 0.636881    1.055713    3.498979    0.256508    0.057662    0.015660    0.697856    
#> 318: 0.636957    1.055771    3.498898    0.256383    0.057632    0.015667    0.697841    
#> 319: 0.636880    1.055766    3.498929    0.256009    0.057622    0.015652    0.697867    
#> 320: 0.636562    1.055708    3.498878    0.255759    0.057547    0.015649    0.698025    
#> 321: 0.636074    1.055711    3.498700    0.255475    0.057465    0.015624    0.698246    
#> 322: 0.636013    1.055793    3.498550    0.255572    0.057497    0.015637    0.698133    
#> 323: 0.635453    1.055998    3.498394    0.255509    0.057507    0.015655    0.698042    
#> 324: 0.635207    1.056164    3.498371    0.255387    0.057480    0.015653    0.697882    
#> 325: 0.635148    1.056400    3.498354    0.255391    0.057440    0.015639    0.697835    
#> 326: 0.635146    1.056327    3.498283    0.255731    0.057430    0.015629    0.697677    
#> 327: 0.635419    1.056370    3.498323    0.255690    0.057426    0.015607    0.697800    
#> 328: 0.635565    1.056533    3.498292    0.256099    0.057436    0.015601    0.697731    
#> 329: 0.635927    1.056547    3.498411    0.256421    0.057421    0.015571    0.697846    
#> 330: 0.635411    1.056678    3.498343    0.256432    0.057409    0.015532    0.697860    
#> 331: 0.635547    1.056969    3.498279    0.256723    0.057403    0.015520    0.697859    
#> 332: 0.635465    1.056945    3.498293    0.257010    0.057364    0.015517    0.697907    
#> 333: 0.635212    1.056842    3.498222    0.257264    0.057268    0.015547    0.697825    
#> 334: 0.634749    1.056905    3.497990    0.257430    0.057182    0.015555    0.697740    
#> 335: 0.634416    1.056954    3.497744    0.257276    0.057208    0.015543    0.697873    
#> 336: 0.634047    1.057123    3.497619    0.256904    0.057238    0.015516    0.698012    
#> 337: 0.633965    1.057280    3.497565    0.257007    0.057251    0.015490    0.698052    
#> 338: 0.633982    1.057188    3.497638    0.257081    0.057149    0.015480    0.698081    
#> 339: 0.633899    1.057321    3.497593    0.256960    0.057089    0.015491    0.698082    
#> 340: 0.633956    1.057138    3.497643    0.256836    0.056979    0.015516    0.698026    
#> 341: 0.634105    1.057110    3.497720    0.256976    0.056829    0.015557    0.697947    
#> 342: 0.633846    1.057025    3.497711    0.257135    0.056812    0.015568    0.697920    
#> 343: 0.633454    1.057096    3.497652    0.257319    0.056761    0.015577    0.697915    
#> 344: 0.633530    1.057100    3.497660    0.257914    0.056649    0.015602    0.698054    
#> 345: 0.633532    1.057082    3.497632    0.258180    0.056526    0.015609    0.698098    
#> 346: 0.633508    1.057103    3.497544    0.258381    0.056388    0.015631    0.698084    
#> 347: 0.633664    1.057107    3.497463    0.258225    0.056324    0.015661    0.698227    
#> 348: 0.633422    1.057273    3.497366    0.258305    0.056339    0.015662    0.698285    
#> 349: 0.633248    1.057300    3.497274    0.258274    0.056327    0.015653    0.698321    
#> 350: 0.632808    1.057254    3.497139    0.258044    0.056357    0.015632    0.698405    
#> 351: 0.632623    1.057396    3.496989    0.258109    0.056463    0.015599    0.698424    
#> 352: 0.632193    1.057572    3.496916    0.258234    0.056542    0.015596    0.698516    
#> 353: 0.632088    1.057739    3.496869    0.258329    0.056576    0.015604    0.698502    
#> 354: 0.631895    1.057831    3.496726    0.258342    0.056569    0.015620    0.698378    
#> 355: 0.631881    1.057822    3.496651    0.258364    0.056481    0.015642    0.698351    
#> 356: 0.631836    1.057771    3.496645    0.258452    0.056430    0.015639    0.698464    
#> 357: 0.631956    1.057848    3.496583    0.258826    0.056340    0.015639    0.698402    
#> 358: 0.631944    1.057931    3.496566    0.258868    0.056341    0.015637    0.698404    
#> 359: 0.631756    1.058128    3.496553    0.258642    0.056305    0.015645    0.698485    
#> 360: 0.631352    1.058222    3.496438    0.258232    0.056294    0.015628    0.698558    
#> 361: 0.631048    1.058376    3.496317    0.258200    0.056315    0.015608    0.698512    
#> 362: 0.630819    1.058519    3.496157    0.258382    0.056309    0.015574    0.698422    
#> 363: 0.630791    1.058581    3.496124    0.258377    0.056289    0.015545    0.698320    
#> 364: 0.630743    1.058734    3.496077    0.258053    0.056298    0.015527    0.698347    
#> 365: 0.630594    1.058721    3.496094    0.257908    0.056370    0.015521    0.698405    
#> 366: 0.630602    1.058815    3.496007    0.257864    0.056365    0.015534    0.698385    
#> 367: 0.630635    1.058867    3.495970    0.257613    0.056401    0.015521    0.698301    
#> 368: 0.630927    1.058942    3.496017    0.257386    0.056337    0.015526    0.698207    
#> 369: 0.631067    1.058985    3.496020    0.257284    0.056282    0.015548    0.698085    
#> 370: 0.631021    1.059056    3.496006    0.257149    0.056256    0.015573    0.698033    
#> 371: 0.630959    1.059094    3.495927    0.257067    0.056200    0.015596    0.697991    
#> 372: 0.630734    1.059174    3.495816    0.256882    0.056147    0.015606    0.697955    
#> 373: 0.630466    1.059258    3.495715    0.256951    0.056106    0.015617    0.697942    
#> 374: 0.630465    1.059333    3.495620    0.256957    0.056055    0.015624    0.697965    
#> 375: 0.630377    1.059379    3.495543    0.257327    0.056063    0.015636    0.697930    
#> 376: 0.630208    1.059496    3.495547    0.257221    0.056110    0.015643    0.697784    
#> 377: 0.630058    1.059510    3.495540    0.257340    0.056066    0.015627    0.697784    
#> 378: 0.629861    1.059422    3.495505    0.257382    0.055997    0.015628    0.697892    
#> 379: 0.629806    1.059241    3.495538    0.257320    0.055966    0.015634    0.697788    
#> 380: 0.629621    1.059100    3.495563    0.257108    0.055939    0.015646    0.697802    
#> 381: 0.629324    1.059005    3.495551    0.257133    0.055943    0.015650    0.697727    
#> 382: 0.629403    1.058903    3.495627    0.256992    0.055892    0.015657    0.697599    
#> 383: 0.629576    1.058846    3.495672    0.256975    0.055873    0.015665    0.697417    
#> 384: 0.629394    1.058805    3.495713    0.256746    0.055851    0.015676    0.697335    
#> 385: 0.629351    1.058738    3.495711    0.256703    0.055864    0.015687    0.697231    
#> 386: 0.629366    1.058759    3.495768    0.256709    0.055826    0.015703    0.697195    
#> 387: 0.629683    1.058690    3.495895    0.256677    0.055816    0.015714    0.697098    
#> 388: 0.629817    1.058659    3.495971    0.256698    0.055845    0.015724    0.696999    
#> 389: 0.629846    1.058497    3.495977    0.256688    0.055797    0.015725    0.697115    
#> 390: 0.629886    1.058445    3.495985    0.256656    0.055780    0.015705    0.697250    
#> 391: 0.629972    1.058434    3.495965    0.256593    0.055795    0.015692    0.697248    
#> 392: 0.630120    1.058463    3.496013    0.256272    0.055789    0.015670    0.697363    
#> 393: 0.630087    1.058521    3.495973    0.256244    0.055740    0.015671    0.697311    
#> 394: 0.630009    1.058595    3.495931    0.256411    0.055727    0.015672    0.697202    
#> 395: 0.630246    1.058677    3.495994    0.256369    0.055759    0.015691    0.697130    
#> 396: 0.630516    1.058667    3.496086    0.256283    0.055809    0.015698    0.697063    
#> 397: 0.630675    1.058477    3.496147    0.256415    0.055800    0.015715    0.697138    
#> 398: 0.630804    1.058367    3.496202    0.256499    0.055765    0.015723    0.697120    
#> 399: 0.630983    1.058276    3.496292    0.256719    0.055808    0.015720    0.697090    
#> 400: 0.631079    1.058314    3.496352    0.256480    0.055824    0.015721    0.697075    
#> 401: 0.630991    1.058351    3.496345    0.256385    0.055850    0.015706    0.697169    
#> 402: 0.630881    1.058425    3.496285    0.256216    0.055825    0.015701    0.697241    
#> 403: 0.630867    1.058495    3.496204    0.256347    0.055792    0.015696    0.697184    
#> 404: 0.630761    1.058556    3.496086    0.256607    0.055785    0.015693    0.697177    
#> 405: 0.630693    1.058630    3.496024    0.256573    0.055796    0.015693    0.697196    
#> 406: 0.630688    1.058636    3.495992    0.256777    0.055809    0.015677    0.697235    
#> 407: 0.630655    1.058682    3.495988    0.256999    0.055837    0.015660    0.697152    
#> 408: 0.630573    1.058731    3.495975    0.256972    0.055864    0.015638    0.697253    
#> 409: 0.630389    1.058735    3.495926    0.256982    0.055815    0.015628    0.697290    
#> 410: 0.630284    1.058820    3.495853    0.256865    0.055796    0.015640    0.697210    
#> 411: 0.630152    1.058703    3.495809    0.256719    0.055806    0.015633    0.697288    
#> 412: 0.630069    1.058721    3.495747    0.256798    0.055811    0.015622    0.697331    
#> 413: 0.629954    1.058690    3.495701    0.256918    0.055837    0.015614    0.697384    
#> 414: 0.629854    1.058676    3.495721    0.257171    0.055891    0.015599    0.697372    
#> 415: 0.630134    1.058604    3.495736    0.257208    0.055915    0.015605    0.697343    
#> 416: 0.630325    1.058650    3.495772    0.257364    0.055937    0.015613    0.697261    
#> 417: 0.630316    1.058593    3.495768    0.257227    0.055929    0.015612    0.697239    
#> 418: 0.630083    1.058591    3.495761    0.257177    0.055941    0.015596    0.697166    
#> 419: 0.630022    1.058820    3.495723    0.257185    0.055959    0.015600    0.697136    
#> 420: 0.630040    1.058856    3.495734    0.257226    0.055922    0.015609    0.697033    
#> 421: 0.629946    1.058921    3.495773    0.256950    0.055916    0.015612    0.696985    
#> 422: 0.630075    1.058864    3.495795    0.256977    0.055858    0.015625    0.697024    
#> 423: 0.630136    1.058769    3.495832    0.256962    0.055799    0.015635    0.697040    
#> 424: 0.630006    1.058779    3.495812    0.256779    0.055755    0.015638    0.697064    
#> 425: 0.630369    1.058803    3.495835    0.256620    0.055708    0.015654    0.697143    
#> 426: 0.630538    1.058979    3.495854    0.256569    0.055706    0.015649    0.697103    
#> 427: 0.630458    1.059018    3.495828    0.256561    0.055680    0.015660    0.697082    
#> 428: 0.630288    1.059121    3.495790    0.256706    0.055668    0.015657    0.697115    
#> 429: 0.630262    1.059212    3.495765    0.256526    0.055673    0.015660    0.697106    
#> 430: 0.630171    1.059251    3.495765    0.256586    0.055670    0.015656    0.697149    
#> 431: 0.630072    1.059250    3.495708    0.256649    0.055742    0.015646    0.697109    
#> 432: 0.630095    1.059311    3.495716    0.256725    0.055802    0.015644    0.697061    
#> 433: 0.630183    1.059373    3.495735    0.256673    0.055853    0.015647    0.697034    
#> 434: 0.630208    1.059233    3.495809    0.256747    0.055821    0.015677    0.696954    
#> 435: 0.630404    1.059131    3.495838    0.256658    0.055790    0.015692    0.696916    
#> 436: 0.630437    1.059062    3.495903    0.256597    0.055786    0.015699    0.696865    
#> 437: 0.630438    1.059003    3.495933    0.256675    0.055792    0.015699    0.696867    
#> 438: 0.630397    1.059146    3.495940    0.256865    0.055775    0.015715    0.696728    
#> 439: 0.630464    1.059238    3.495957    0.256862    0.055740    0.015718    0.696617    
#> 440: 0.630372    1.059262    3.495989    0.256852    0.055704    0.015729    0.696575    
#> 441: 0.630337    1.059204    3.496023    0.256880    0.055735    0.015731    0.696524    
#> 442: 0.630181    1.059323    3.496006    0.256884    0.055747    0.015745    0.696467    
#> 443: 0.630177    1.059406    3.495962    0.256878    0.055751    0.015759    0.696477    
#> 444: 0.630253    1.059388    3.495948    0.256720    0.055784    0.015776    0.696497    
#> 445: 0.630220    1.059400    3.495900    0.256650    0.055764    0.015789    0.696500    
#> 446: 0.630075    1.059420    3.495848    0.256790    0.055723    0.015798    0.696473    
#> 447: 0.630197    1.059467    3.495834    0.256899    0.055704    0.015815    0.696421    
#> 448: 0.630187    1.059496    3.495835    0.256968    0.055689    0.015826    0.696341    
#> 449: 0.630335    1.059525    3.495936    0.257013    0.055734    0.015836    0.696365    
#> 450: 0.630373    1.059528    3.495950    0.256983    0.055774    0.015841    0.696339    
#> 451: 0.630466    1.059546    3.495952    0.257087    0.055844    0.015842    0.696350    
#> 452: 0.630392    1.059573    3.495897    0.256982    0.055875    0.015829    0.696309    
#> 453: 0.630173    1.059621    3.495829    0.256875    0.055900    0.015813    0.696290    
#> 454: 0.630047    1.059755    3.495784    0.256895    0.055961    0.015799    0.696233    
#> 455: 0.629957    1.059771    3.495735    0.256941    0.055982    0.015789    0.696264    
#> 456: 0.629877    1.059708    3.495699    0.257141    0.056036    0.015788    0.696225    
#> 457: 0.629800    1.059748    3.495685    0.257353    0.056110    0.015792    0.696150    
#> 458: 0.629824    1.059835    3.495712    0.257488    0.056146    0.015798    0.696109    
#> 459: 0.629745    1.059938    3.495699    0.257571    0.056149    0.015805    0.696117    
#> 460: 0.629690    1.059868    3.495702    0.257552    0.056120    0.015823    0.696092    
#> 461: 0.629665    1.059892    3.495740    0.257467    0.056108    0.015847    0.696018    
#> 462: 0.629599    1.059904    3.495755    0.257478    0.056093    0.015858    0.695953    
#> 463: 0.629576    1.059901    3.495792    0.257556    0.056080    0.015862    0.695922    
#> 464: 0.629687    1.059886    3.495832    0.257675    0.056061    0.015866    0.695849    
#> 465: 0.629751    1.059708    3.495899    0.257663    0.056080    0.015865    0.695865    
#> 466: 0.629907    1.059653    3.495923    0.257602    0.056047    0.015868    0.695847    
#> 467: 0.629840    1.059651    3.495953    0.257625    0.056036    0.015879    0.695732    
#> 468: 0.630051    1.059670    3.496003    0.257770    0.056032    0.015894    0.695671    
#> 469: 0.630134    1.059731    3.496050    0.257781    0.056076    0.015914    0.695654    
#> 470: 0.630106    1.059733    3.496053    0.257806    0.056089    0.015940    0.695584    
#> 471: 0.630007    1.059724    3.496060    0.257844    0.056050    0.015940    0.695549    
#> 472: 0.630011    1.059720    3.496087    0.257883    0.056076    0.015950    0.695474    
#> 473: 0.629930    1.059766    3.496089    0.257892    0.056057    0.015965    0.695439    
#> 474: 0.629884    1.059785    3.496094    0.257739    0.056034    0.015986    0.695435    
#> 475: 0.629893    1.059889    3.496086    0.257649    0.056023    0.015994    0.695439    
#> 476: 0.629815    1.059987    3.496027    0.257524    0.056042    0.015999    0.695461    
#> 477: 0.629728    1.060078    3.496012    0.257683    0.056023    0.016005    0.695362    
#> 478: 0.629586    1.060151    3.496006    0.257759    0.056000    0.016014    0.695337    
#> 479: 0.629575    1.060209    3.495991    0.257899    0.055976    0.016021    0.695377    
#> 480: 0.629584    1.060261    3.496002    0.257859    0.055977    0.016019    0.695459    
#> 481: 0.629423    1.060284    3.495980    0.257800    0.055984    0.016012    0.695478    
#> 482: 0.629614    1.060292    3.496008    0.257934    0.055982    0.016030    0.695450    
#> 483: 0.629473    1.060313    3.495988    0.257911    0.055980    0.016042    0.695422    
#> 484: 0.629432    1.060288    3.495960    0.258158    0.055959    0.016051    0.695384    
#> 485: 0.629404    1.060317    3.495911    0.258429    0.055948    0.016051    0.695346    
#> 486: 0.629377    1.060352    3.495909    0.258528    0.055954    0.016046    0.695298    
#> 487: 0.629472    1.060412    3.495934    0.258504    0.055977    0.016036    0.695248    
#> 488: 0.629425    1.060440    3.495953    0.258526    0.055991    0.016022    0.695241    
#> 489: 0.629396    1.060462    3.495950    0.258367    0.056025    0.016018    0.695315    
#> 490: 0.629463    1.060527    3.496003    0.258343    0.056058    0.016021    0.695350    
#> 491: 0.629604    1.060594    3.496056    0.258441    0.056076    0.016021    0.695333    
#> 492: 0.629652    1.060570    3.496069    0.258199    0.056101    0.016011    0.695463    
#> 493: 0.629600    1.060527    3.496105    0.258068    0.056115    0.016014    0.695515    
#> 494: 0.629745    1.060531    3.496103    0.258070    0.056146    0.016013    0.695445    
#> 495: 0.629777    1.060469    3.496144    0.258029    0.056131    0.016016    0.695400    
#> 496: 0.629828    1.060468    3.496112    0.258035    0.056124    0.016016    0.695371    
#> 497: 0.629651    1.060429    3.496100    0.258016    0.056116    0.016000    0.695434    
#> 498: 0.629557    1.060357    3.496045    0.258076    0.056112    0.015991    0.695410    
#> 499: 0.629456    1.060433    3.495988    0.258142    0.056111    0.015985    0.695359    
#> 500: 0.629413    1.060434    3.495946    0.258144    0.056077    0.015995    0.695322    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.289200    0.987689    3.456188    0.392401    0.083458    0.016800    1.765787    
#> 002: 0.398322    1.123014    3.488066    0.372781    0.079285    0.016599    1.149184    
#> 003: 0.595440    1.138932    3.534683    0.354142    0.075321    0.015769    0.898593    
#> 004: 0.569848    1.167306    3.541362    0.336435    0.071555    0.014981    0.842571    
#> 005: 0.666110    1.161621    3.524488    0.380223    0.067977    0.014232    0.790477    
#> 006: 0.588417    1.174370    3.515643    0.361212    0.064578    0.013520    0.755366    
#> 007: 0.586589    1.185448    3.516143    0.343151    0.061349    0.012844    0.765766    
#> 008: 0.587505    1.201210    3.510690    0.344370    0.060603    0.013713    0.756817    
#> 009: 0.570671    1.149177    3.522068    0.327151    0.057573    0.014216    0.770483    
#> 010: 0.571755    1.153465    3.525333    0.310794    0.054694    0.015306    0.765500    
#> 011: 0.631521    1.176485    3.531920    0.345771    0.051960    0.014951    0.744076    
#> 012: 0.636246    1.170881    3.533609    0.339094    0.049362    0.016001    0.727461    
#> 013: 0.571961    1.173467    3.526798    0.322139    0.046893    0.019311    0.749940    
#> 014: 0.628782    1.186792    3.528874    0.306032    0.044549    0.018345    0.779841    
#> 015: 0.647034    1.186825    3.549289    0.290730    0.043096    0.017532    0.732139    
#> 016: 0.661422    1.198110    3.547607    0.316169    0.043751    0.021257    0.736515    
#> 017: 0.655963    1.182934    3.553498    0.309925    0.041564    0.020229    0.722025    
#> 018: 0.690586    1.182938    3.543125    0.294429    0.043457    0.020491    0.748702    
#> 019: 0.621065    1.172855    3.534864    0.293842    0.041284    0.019752    0.737733    
#> 020: 0.670857    1.152528    3.549653    0.305374    0.039220    0.018765    0.746968    
#> 021: 0.663726    1.152536    3.549965    0.290106    0.037259    0.017826    0.741532    
#> 022: 0.651625    1.138966    3.564648    0.323165    0.035396    0.016935    0.730900    
#> 023: 0.719086    1.143185    3.579118    0.307006    0.033626    0.016088    0.776426    
#> 024: 0.797427    1.160752    3.587537    0.327938    0.031945    0.015284    0.755141    
#> 025: 0.756026    1.137950    3.584547    0.351204    0.030347    0.020176    0.733151    
#> 026: 0.714434    1.147058    3.566809    0.333644    0.028830    0.022264    0.739389    
#> 027: 0.665060    1.167078    3.547096    0.318335    0.027389    0.023448    0.759646    
#> 028: 0.711011    1.145705    3.560745    0.322299    0.026019    0.025986    0.744461    
#> 029: 0.713455    1.155096    3.555614    0.319171    0.026543    0.024687    0.748594    
#> 030: 0.731874    1.184946    3.547557    0.351923    0.025216    0.023917    0.743007    
#> 031: 0.663739    1.160946    3.552445    0.373949    0.024101    0.025254    0.725523    
#> 032: 0.657731    1.163086    3.555982    0.355251    0.024514    0.024668    0.740763    
#> 033: 0.669155    1.170013    3.557648    0.348467    0.023289    0.027824    0.739562    
#> 034: 0.694704    1.169835    3.557976    0.345988    0.024097    0.026433    0.731494    
#> 035: 0.672538    1.131743    3.562296    0.328688    0.022892    0.025111    0.732810    
#> 036: 0.703073    1.138823    3.565856    0.312254    0.030032    0.026370    0.730478    
#> 037: 0.692106    1.156734    3.571006    0.296641    0.035898    0.026736    0.750451    
#> 038: 0.670091    1.163734    3.548472    0.283191    0.036037    0.027605    0.735320    
#> 039: 0.686430    1.166961    3.567257    0.269031    0.034235    0.032633    0.726528    
#> 040: 0.685062    1.153999    3.571705    0.263874    0.032523    0.031002    0.757456    
#> 041: 0.660761    1.128487    3.563794    0.278028    0.030897    0.029960    0.742924    
#> 042: 0.731787    1.129981    3.575622    0.272753    0.029352    0.028462    0.722016    
#> 043: 0.667370    1.161612    3.550737    0.259115    0.028947    0.027039    0.740471    
#> 044: 0.627405    1.168702    3.548456    0.265097    0.035176    0.025687    0.732227    
#> 045: 0.639880    1.190324    3.537727    0.275237    0.036448    0.024402    0.722815    
#> 046: 0.639147    1.170641    3.538159    0.288640    0.041438    0.023182    0.745036    
#> 047: 0.659234    1.189215    3.527650    0.288821    0.039366    0.022023    0.760663    
#> 048: 0.635243    1.169696    3.537456    0.274380    0.037398    0.022005    0.753194    
#> 049: 0.628728    1.170482    3.548356    0.260661    0.035528    0.025198    0.765272    
#> 050: 0.686764    1.132230    3.554090    0.290727    0.033751    0.024114    0.786449    
#> 051: 0.680918    1.139695    3.558406    0.276191    0.033238    0.026350    0.771994    
#> 052: 0.652460    1.170793    3.558812    0.262381    0.035397    0.025033    0.745529    
#> 053: 0.693061    1.148440    3.565022    0.278391    0.033627    0.023781    0.755616    
#> 054: 0.651520    1.146138    3.565562    0.264471    0.031946    0.022592    0.775819    
#> 055: 0.666520    1.149964    3.558054    0.251248    0.030348    0.028928    0.765341    
#> 056: 0.688096    1.142114    3.561140    0.268067    0.030665    0.027482    0.738207    
#> 057: 0.716677    1.132901    3.586424    0.313944    0.029132    0.026528    0.749160    
#> 058: 0.688849    1.144049    3.566374    0.298247    0.027676    0.029447    0.760911    
#> 059: 0.677358    1.125507    3.563508    0.283335    0.036210    0.027974    0.761408    
#> 060: 0.657518    1.118136    3.576254    0.269168    0.036905    0.026576    0.767278    
#> 061: 0.712189    1.099863    3.583890    0.297407    0.038492    0.025247    0.774180    
#> 062: 0.729776    1.123202    3.591640    0.282537    0.050825    0.023985    0.780973    
#> 063: 0.718828    1.103874    3.581354    0.268410    0.048284    0.028413    0.791457    
#> 064: 0.702194    1.123173    3.583704    0.264248    0.045869    0.026992    0.778775    
#> 065: 0.691299    1.123345    3.573464    0.251364    0.043576    0.025643    0.759188    
#> 066: 0.701105    1.134855    3.568937    0.276653    0.041397    0.025077    0.726593    
#> 067: 0.685050    1.156365    3.555616    0.278757    0.039327    0.025925    0.722527    
#> 068: 0.661023    1.179020    3.573089    0.290519    0.037361    0.026078    0.734549    
#> 069: 0.670951    1.194131    3.558654    0.303166    0.035493    0.028251    0.754220    
#> 070: 0.679025    1.182622    3.563012    0.309093    0.033718    0.026838    0.757122    
#> 071: 0.638400    1.216015    3.535111    0.324051    0.034528    0.025496    0.758000    
#> 072: 0.602327    1.195578    3.533885    0.317555    0.032801    0.024222    0.716136    
#> 073: 0.656879    1.199967    3.551560    0.306720    0.031161    0.024970    0.705649    
#> 074: 0.642649    1.186996    3.543600    0.291384    0.029603    0.023721    0.734926    
#> 075: 0.655921    1.177285    3.568412    0.276815    0.031143    0.022535    0.738447    
#> 076: 0.703630    1.159964    3.574487    0.297204    0.029586    0.023123    0.735798    
#> 077: 0.704713    1.147545    3.555154    0.319827    0.028107    0.021967    0.738124    
#> 078: 0.707926    1.150299    3.571100    0.303836    0.029155    0.025123    0.714714    
#> 079: 0.717689    1.153331    3.571277    0.288644    0.029093    0.023867    0.742979    
#> 080: 0.720426    1.153488    3.585493    0.274212    0.037837    0.023136    0.732009    
#> 081: 0.707770    1.121967    3.580035    0.269369    0.035946    0.023024    0.739734    
#> 082: 0.670277    1.138725    3.570336    0.302973    0.034148    0.021872    0.730618    
#> 083: 0.715150    1.152452    3.567229    0.389861    0.032441    0.024529    0.723329    
#> 084: 0.689488    1.171043    3.552536    0.370368    0.032008    0.023302    0.732423    
#> 085: 0.693355    1.171016    3.568994    0.351850    0.033384    0.022137    0.738491    
#> 086: 0.715068    1.160331    3.558005    0.389224    0.040683    0.021030    0.724541    
#> 087: 0.680450    1.165906    3.541972    0.401581    0.038648    0.019979    0.724894    
#> 088: 0.587403    1.155294    3.547252    0.381502    0.036716    0.019663    0.749393    
#> 089: 0.623731    1.171730    3.521775    0.362427    0.035948    0.018680    0.748651    
#> 090: 0.615491    1.165827    3.540730    0.344306    0.036809    0.017746    0.732911    
#> 091: 0.592480    1.167101    3.512176    0.327090    0.034969    0.018533    0.731507    
#> 092: 0.580017    1.200390    3.517353    0.310736    0.033220    0.019991    0.723722    
#> 093: 0.558847    1.195933    3.514287    0.295199    0.031559    0.020211    0.743897    
#> 094: 0.585642    1.196683    3.511455    0.308540    0.029981    0.019200    0.723675    
#> 095: 0.598744    1.183633    3.535970    0.326829    0.032542    0.018240    0.735981    
#> 096: 0.599240    1.179012    3.537875    0.314211    0.032456    0.019836    0.730422    
#> 097: 0.675934    1.170140    3.555407    0.298501    0.030833    0.020721    0.747616    
#> 098: 0.676246    1.176310    3.558068    0.331436    0.029292    0.023881    0.737321    
#> 099: 0.655049    1.157420    3.549256    0.314864    0.035002    0.023472    0.734355    
#> 100: 0.639849    1.152577    3.562304    0.299121    0.033252    0.024764    0.740350    
#> 101: 0.623051    1.162215    3.533008    0.316155    0.031590    0.023526    0.718177    
#> 102: 0.627767    1.144037    3.530655    0.338863    0.030010    0.022349    0.718821    
#> 103: 0.689798    1.158818    3.552861    0.321920    0.028510    0.022648    0.729202    
#> 104: 0.652718    1.160740    3.555229    0.312933    0.031394    0.023788    0.752495    
#> 105: 0.650295    1.170172    3.551947    0.297287    0.032066    0.022698    0.751577    
#> 106: 0.668775    1.182559    3.541993    0.282422    0.031019    0.025612    0.731978    
#> 107: 0.681825    1.163102    3.560130    0.268301    0.030065    0.028278    0.746279    
#> 108: 0.628432    1.154368    3.556818    0.254886    0.030077    0.026865    0.769809    
#> 109: 0.659834    1.151219    3.570921    0.276206    0.028573    0.025521    0.760888    
#> 110: 0.680904    1.161044    3.553869    0.262396    0.027144    0.024245    0.733940    
#> 111: 0.660952    1.167066    3.562673    0.262913    0.025787    0.023033    0.737667    
#> 112: 0.631982    1.154804    3.538167    0.260817    0.024498    0.022048    0.743781    
#> 113: 0.672015    1.169053    3.554217    0.308407    0.024321    0.023347    0.726968    
#> 114: 0.681689    1.171684    3.560609    0.292986    0.024969    0.024568    0.725853    
#> 115: 0.708135    1.161859    3.560936    0.290304    0.026081    0.023340    0.739708    
#> 116: 0.707038    1.166291    3.570160    0.275789    0.027950    0.029457    0.734241    
#> 117: 0.667479    1.177981    3.568025    0.273529    0.026553    0.027984    0.730564    
#> 118: 0.711614    1.184210    3.567702    0.260350    0.026568    0.026585    0.728195    
#> 119: 0.685737    1.155599    3.562031    0.273521    0.025239    0.027674    0.725481    
#> 120: 0.637175    1.151455    3.553439    0.259845    0.024516    0.026290    0.726119    
#> 121: 0.666884    1.184440    3.547948    0.283558    0.031925    0.024976    0.736428    
#> 122: 0.675473    1.163840    3.558544    0.315636    0.037210    0.025987    0.729610    
#> 123: 0.740805    1.169453    3.558785    0.341718    0.035349    0.024688    0.733135    
#> 124: 0.688878    1.197026    3.551515    0.332451    0.033582    0.024812    0.726401    
#> 125: 0.709920    1.195063    3.541975    0.347100    0.031903    0.023572    0.728603    
#> 126: 0.622527    1.189583    3.526290    0.329745    0.030308    0.026382    0.746234    
#> 127: 0.669714    1.181204    3.539854    0.313258    0.028792    0.027467    0.763997    
#> 128: 0.647111    1.174721    3.562428    0.297595    0.029037    0.026446    0.744549    
#> 129: 0.668781    1.178796    3.568569    0.282715    0.027585    0.025124    0.747323    
#> 130: 0.711344    1.181185    3.564220    0.297829    0.029217    0.027348    0.710331    
#> 131: 0.684824    1.167194    3.551212    0.282938    0.031767    0.025981    0.723475    
#> 132: 0.641819    1.168331    3.534003    0.268791    0.031165    0.024682    0.729004    
#> 133: 0.655427    1.154295    3.549563    0.255351    0.030237    0.026442    0.747639    
#> 134: 0.689945    1.140736    3.571692    0.260721    0.034950    0.025120    0.714032    
#> 135: 0.665335    1.141153    3.566460    0.292594    0.038555    0.024801    0.722545    
#> 136: 0.690735    1.141016    3.565450    0.311049    0.036627    0.023561    0.723545    
#> 137: 0.675529    1.159450    3.550071    0.368368    0.034796    0.022383    0.732906    
#> 138: 0.657175    1.159762    3.547705    0.349950    0.033407    0.024767    0.725351    
#> 139: 0.689760    1.140014    3.565986    0.332452    0.031736    0.025585    0.734646    
#> 140: 0.683203    1.155542    3.566300    0.315830    0.032862    0.028723    0.749965    
#> 141: 0.680555    1.140919    3.572354    0.300038    0.035427    0.027286    0.742310    
#> 142: 0.723336    1.137146    3.596199    0.285036    0.038335    0.027160    0.747695    
#> 143: 0.702229    1.148329    3.582417    0.270784    0.036418    0.029808    0.749568    
#> 144: 0.728235    1.150693    3.600835    0.257245    0.034597    0.028318    0.745954    
#> 145: 0.674832    1.149400    3.573047    0.264296    0.032867    0.026902    0.738505    
#> 146: 0.658218    1.161645    3.564338    0.311389    0.031224    0.025557    0.757167    
#> 147: 0.670133    1.154913    3.559670    0.295820    0.030109    0.024279    0.730785    
#> 148: 0.658762    1.163660    3.564276    0.301168    0.028603    0.025980    0.739169    
#> 149: 0.662931    1.177207    3.550148    0.286110    0.031636    0.024681    0.728833    
#> 150: 0.668400    1.163769    3.546028    0.271804    0.032616    0.024730    0.735163    
#> 151: 0.607923    1.195947    3.533298    0.258214    0.032091    0.023494    0.737235    
#> 152: 0.628618    1.185565    3.545238    0.273066    0.027321    0.021089    0.727640    
#> 153: 0.642571    1.190683    3.563912    0.228099    0.032609    0.021755    0.748693    
#> 154: 0.671297    1.191545    3.549514    0.255551    0.028580    0.019822    0.754288    
#> 155: 0.661319    1.173664    3.546030    0.288669    0.026149    0.022894    0.739722    
#> 156: 0.675273    1.194120    3.546105    0.321275    0.034902    0.023725    0.732324    
#> 157: 0.721465    1.173309    3.559104    0.320530    0.036785    0.025332    0.748873    
#> 158: 0.700106    1.197846    3.554577    0.299063    0.038014    0.022695    0.724207    
#> 159: 0.633138    1.199785    3.555036    0.337924    0.034720    0.021152    0.722843    
#> 160: 0.706134    1.151417    3.574575    0.277303    0.036783    0.020878    0.726743    
#> 161: 0.673512    1.157970    3.561225    0.303770    0.034860    0.021476    0.735340    
#> 162: 0.651659    1.175207    3.548054    0.299230    0.037505    0.017699    0.744966    
#> 163: 0.694401    1.142486    3.550341    0.272774    0.045855    0.014640    0.739397    
#> 164: 0.689726    1.162593    3.557426    0.222026    0.038595    0.017291    0.731199    
#> 165: 0.704943    1.167851    3.571791    0.261986    0.036527    0.023770    0.728125    
#> 166: 0.712743    1.195861    3.563979    0.296542    0.032901    0.028024    0.730172    
#> 167: 0.685129    1.195487    3.574617    0.258287    0.031036    0.026493    0.742125    
#> 168: 0.720078    1.200937    3.571472    0.261594    0.027195    0.025289    0.748537    
#> 169: 0.703375    1.191974    3.558392    0.260604    0.028814    0.023884    0.752806    
#> 170: 0.697708    1.179599    3.557636    0.254947    0.029796    0.018549    0.745362    
#> 171: 0.647593    1.185363    3.547635    0.265751    0.031448    0.020726    0.725931    
#> 172: 0.635772    1.192641    3.546392    0.289347    0.029749    0.021826    0.733087    
#> 173: 0.654978    1.202837    3.543990    0.260786    0.034333    0.029308    0.730004    
#> 174: 0.675319    1.186778    3.556609    0.201513    0.023090    0.029620    0.752026    
#> 175: 0.681894    1.182848    3.554729    0.209280    0.028258    0.028953    0.753771    
#> 176: 0.674717    1.183290    3.566641    0.286667    0.026896    0.025394    0.734556    
#> 177: 0.692241    1.174544    3.568991    0.238409    0.023219    0.026219    0.735007    
#> 178: 0.708946    1.167599    3.569378    0.263150    0.021901    0.027703    0.727448    
#> 179: 0.698349    1.168429    3.552212    0.296664    0.025758    0.026669    0.735162    
#> 180: 0.671652    1.167007    3.556895    0.251883    0.028128    0.026483    0.737984    
#> 181: 0.641068    1.144220    3.532155    0.271199    0.026652    0.028576    0.746827    
#> 182: 0.643641    1.146964    3.540629    0.285456    0.022465    0.032596    0.758744    
#> 183: 0.670430    1.174871    3.543971    0.232018    0.025009    0.027302    0.748761    
#> 184: 0.651284    1.169597    3.557283    0.249206    0.021191    0.023921    0.743698    
#> 185: 0.638704    1.168604    3.549170    0.218254    0.020568    0.027088    0.749497    
#> 186: 0.638728    1.176899    3.549398    0.207106    0.016612    0.037860    0.760164    
#> 187: 0.650773    1.185483    3.550394    0.203204    0.023588    0.030387    0.761358    
#> 188: 0.602886    1.207917    3.542994    0.221775    0.026820    0.023319    0.753662    
#> 189: 0.655188    1.207807    3.550616    0.270533    0.033223    0.018761    0.749985    
#> 190: 0.640216    1.167810    3.563700    0.278349    0.023898    0.020828    0.735679    
#> 191: 0.624214    1.180488    3.538473    0.315010    0.027426    0.016529    0.741151    
#> 192: 0.632250    1.174935    3.547073    0.365621    0.026733    0.021276    0.719962    
#> 193: 0.661334    1.203698    3.546222    0.333280    0.031666    0.018529    0.735986    
#> 194: 0.607975    1.198944    3.532851    0.270474    0.034531    0.017563    0.757716    
#> 195: 0.584893    1.207290    3.527885    0.238015    0.033792    0.020976    0.750424    
#> 196: 0.637421    1.201094    3.551720    0.238606    0.032893    0.019803    0.771763    
#> 197: 0.575551    1.224329    3.562431    0.226520    0.035540    0.020584    0.766598    
#> 198: 0.646577    1.196339    3.545759    0.229566    0.028157    0.028057    0.754647    
#> 199: 0.643292    1.166071    3.554890    0.221758    0.037074    0.026265    0.742605    
#> 200: 0.660470    1.157772    3.560946    0.203606    0.037080    0.030035    0.731493    
#> 201: 0.670472    1.153130    3.569743    0.214005    0.035071    0.031867    0.733667    
#> 202: 0.678178    1.153800    3.570998    0.235307    0.033511    0.030683    0.731003    
#> 203: 0.696751    1.152122    3.570786    0.249012    0.031752    0.029499    0.731375    
#> 204: 0.700825    1.146797    3.573719    0.256259    0.029131    0.030000    0.734544    
#> 205: 0.700610    1.148410    3.573697    0.258231    0.027282    0.030323    0.739952    
#> 206: 0.699352    1.151749    3.574904    0.262498    0.026597    0.030397    0.740943    
#> 207: 0.698087    1.152611    3.573253    0.262860    0.025893    0.030369    0.739739    
#> 208: 0.696311    1.152855    3.573128    0.266505    0.025904    0.030306    0.738449    
#> 209: 0.696523    1.150759    3.571717    0.268337    0.026279    0.030289    0.737234    
#> 210: 0.697682    1.150084    3.571034    0.270060    0.026208    0.029433    0.736451    
#> 211: 0.698471    1.150326    3.571245    0.270205    0.026204    0.029106    0.737129    
#> 212: 0.702238    1.150926    3.571539    0.270108    0.026344    0.028568    0.737534    
#> 213: 0.704466    1.148104    3.572404    0.273059    0.026868    0.028254    0.737088    
#> 214: 0.705247    1.146973    3.572827    0.271381    0.027166    0.028254    0.737159    
#> 215: 0.705513    1.146566    3.573310    0.272316    0.027171    0.028055    0.737479    
#> 216: 0.705639    1.145034    3.573548    0.275764    0.027339    0.028116    0.739198    
#> 217: 0.703193    1.144812    3.573634    0.275551    0.027581    0.027736    0.738628    
#> 218: 0.702206    1.146098    3.572527    0.275046    0.027652    0.027389    0.738135    
#> 219: 0.700531    1.146571    3.570970    0.277452    0.027674    0.027254    0.738304    
#> 220: 0.699976    1.148088    3.570709    0.280459    0.027609    0.027640    0.737682    
#> 221: 0.699234    1.148557    3.570380    0.281495    0.027467    0.027606    0.737350    
#> 222: 0.697935    1.148746    3.569650    0.280946    0.027601    0.027546    0.737254    
#> 223: 0.699781    1.148682    3.569495    0.280967    0.027511    0.027532    0.736864    
#> 224: 0.700935    1.148594    3.569813    0.280204    0.027335    0.027524    0.737463    
#> 225: 0.701643    1.147715    3.570418    0.280321    0.027208    0.027612    0.738209    
#> 226: 0.702342    1.146943    3.570153    0.280048    0.027313    0.027484    0.738605    
#> 227: 0.701191    1.146901    3.570472    0.278874    0.027198    0.027411    0.738486    
#> 228: 0.700232    1.147741    3.569746    0.276896    0.027339    0.027396    0.738648    
#> 229: 0.699349    1.147820    3.569519    0.275273    0.027375    0.027394    0.738259    
#> 230: 0.700358    1.147190    3.569546    0.274386    0.027316    0.027314    0.738734    
#> 231: 0.700078    1.146945    3.569877    0.273195    0.027387    0.027307    0.738968    
#> 232: 0.699297    1.146192    3.570218    0.274110    0.027225    0.027326    0.738767    
#> 233: 0.699974    1.144971    3.570676    0.274382    0.027067    0.027274    0.739152    
#> 234: 0.698512    1.144750    3.571060    0.275689    0.026907    0.027489    0.739684    
#> 235: 0.698348    1.144568    3.571018    0.274116    0.026582    0.027527    0.739946    
#> 236: 0.697362    1.145103    3.570543    0.274221    0.026384    0.027526    0.740063    
#> 237: 0.698214    1.145327    3.570460    0.276048    0.026263    0.027413    0.740720    
#> 238: 0.697956    1.145816    3.570281    0.278210    0.026197    0.027329    0.740817    
#> 239: 0.697203    1.146391    3.569817    0.278780    0.026274    0.027229    0.740601    
#> 240: 0.697154    1.146229    3.569885    0.278350    0.026245    0.027240    0.740396    
#> 241: 0.696986    1.146029    3.569662    0.277595    0.026230    0.027222    0.740663    
#> 242: 0.696012    1.145902    3.569292    0.276748    0.026260    0.027145    0.741502    
#> 243: 0.694269    1.146668    3.569040    0.276197    0.026423    0.027102    0.741919    
#> 244: 0.693162    1.146493    3.569256    0.276815    0.026445    0.027124    0.742298    
#> 245: 0.692810    1.146237    3.569468    0.276444    0.026505    0.027118    0.742373    
#> 246: 0.692866    1.145726    3.569555    0.276568    0.026525    0.027133    0.742518    
#> 247: 0.692363    1.145593    3.569479    0.275508    0.026579    0.027131    0.742745    
#> 248: 0.691314    1.146279    3.569110    0.274795    0.026672    0.027172    0.742737    
#> 249: 0.690369    1.146626    3.568989    0.275361    0.026810    0.027206    0.742644    
#> 250: 0.690699    1.147014    3.569280    0.275175    0.026955    0.027389    0.742974    
#> 251: 0.691482    1.147213    3.569499    0.275185    0.027167    0.027376    0.742829    
#> 252: 0.691926    1.147604    3.569900    0.276577    0.027279    0.027317    0.742553    
#> 253: 0.691620    1.148018    3.569689    0.277096    0.027315    0.027311    0.742294    
#> 254: 0.691923    1.148732    3.569753    0.277752    0.027324    0.027294    0.742275    
#> 255: 0.692417    1.148943    3.569864    0.278322    0.027129    0.027356    0.742528    
#> 256: 0.692998    1.148749    3.569929    0.278465    0.027024    0.027335    0.742951    
#> 257: 0.693022    1.148536    3.569957    0.278032    0.026994    0.027282    0.742912    
#> 258: 0.692857    1.147955    3.569996    0.277539    0.026955    0.027243    0.742995    
#> 259: 0.692640    1.147620    3.569982    0.277670    0.026983    0.027307    0.742941    
#> 260: 0.692571    1.147688    3.570029    0.277335    0.026984    0.027319    0.742866    
#> 261: 0.692475    1.147733    3.570026    0.278038    0.026965    0.027297    0.742959    
#> 262: 0.692724    1.147915    3.569966    0.278389    0.026994    0.027326    0.742971    
#> 263: 0.692571    1.148032    3.569915    0.277929    0.026884    0.027378    0.743229    
#> 264: 0.691443    1.148355    3.569579    0.277584    0.026927    0.027338    0.743249    
#> 265: 0.691336    1.148522    3.569532    0.277537    0.026856    0.027333    0.743395    
#> 266: 0.691501    1.148911    3.569480    0.276930    0.026877    0.027310    0.743305    
#> 267: 0.692169    1.149086    3.569680    0.277587    0.026853    0.027316    0.743181    
#> 268: 0.691794    1.148999    3.569405    0.277262    0.026885    0.027287    0.743133    
#> 269: 0.692361    1.148791    3.569337    0.277690    0.026896    0.027293    0.743042    
#> 270: 0.692375    1.149035    3.569130    0.278340    0.026881    0.027295    0.742775    
#> 271: 0.692607    1.148926    3.569079    0.278668    0.026851    0.027328    0.742644    
#> 272: 0.691855    1.148745    3.568955    0.278527    0.026797    0.027336    0.742829    
#> 273: 0.691564    1.148687    3.568820    0.278504    0.026862    0.027364    0.742855    
#> 274: 0.691016    1.148786    3.568812    0.278246    0.026863    0.027397    0.742815    
#> 275: 0.690875    1.148737    3.568693    0.278157    0.026788    0.027456    0.742840    
#> 276: 0.690706    1.148634    3.568806    0.278030    0.026851    0.027457    0.742679    
#> 277: 0.690584    1.148555    3.568933    0.278036    0.026862    0.027447    0.742651    
#> 278: 0.690924    1.148480    3.569130    0.277860    0.026865    0.027455    0.742736    
#> 279: 0.690936    1.148501    3.569034    0.278386    0.026888    0.027446    0.742543    
#> 280: 0.690741    1.148797    3.568882    0.278184    0.026942    0.027400    0.742398    
#> 281: 0.689959    1.149097    3.568752    0.277932    0.027035    0.027366    0.742535    
#> 282: 0.689683    1.149629    3.568668    0.277532    0.027197    0.027279    0.742642    
#> 283: 0.689721    1.150068    3.568649    0.278418    0.027473    0.027160    0.742791    
#> 284: 0.689434    1.150317    3.568429    0.279167    0.027585    0.027025    0.742672    
#> 285: 0.689362    1.150513    3.568064    0.279877    0.027681    0.026890    0.742496    
#> 286: 0.689232    1.150845    3.567925    0.280309    0.027827    0.026837    0.742246    
#> 287: 0.689168    1.151058    3.567838    0.280087    0.027931    0.026816    0.742229    
#> 288: 0.689459    1.151282    3.567870    0.279780    0.028035    0.026791    0.742211    
#> 289: 0.689891    1.151349    3.567895    0.279947    0.028079    0.026772    0.742149    
#> 290: 0.689740    1.151582    3.567837    0.279750    0.028109    0.026728    0.742177    
#> 291: 0.689227    1.152081    3.567723    0.279828    0.028134    0.026740    0.741992    
#> 292: 0.688818    1.152301    3.567571    0.279878    0.028103    0.026725    0.741820    
#> 293: 0.688753    1.152434    3.567405    0.279820    0.027973    0.026701    0.741681    
#> 294: 0.688152    1.152645    3.567173    0.279878    0.027939    0.026678    0.741647    
#> 295: 0.688004    1.152368    3.567106    0.279808    0.027873    0.026679    0.741469    
#> 296: 0.687844    1.152251    3.567122    0.279395    0.027857    0.026681    0.741582    
#> 297: 0.688010    1.152317    3.567066    0.279936    0.027914    0.026677    0.741459    
#> 298: 0.688060    1.152228    3.567063    0.280506    0.027931    0.026651    0.741378    
#> 299: 0.688152    1.152416    3.566926    0.280978    0.027906    0.026605    0.741364    
#> 300: 0.688277    1.152364    3.567055    0.281269    0.027883    0.026558    0.741377    
#> 301: 0.688357    1.152223    3.566939    0.281341    0.027835    0.026521    0.741601    
#> 302: 0.688101    1.152347    3.566800    0.281221    0.027767    0.026572    0.741449    
#> 303: 0.687582    1.152536    3.566609    0.281107    0.027744    0.026610    0.741287    
#> 304: 0.687443    1.152810    3.566457    0.281112    0.027758    0.026585    0.741276    
#> 305: 0.687251    1.152717    3.566435    0.280893    0.027784    0.026518    0.741266    
#> 306: 0.686853    1.152766    3.566249    0.280849    0.027784    0.026491    0.741428    
#> 307: 0.686946    1.152761    3.566167    0.281009    0.027806    0.026495    0.741554    
#> 308: 0.686785    1.152597    3.566117    0.281462    0.027793    0.026469    0.741763    
#> 309: 0.687016    1.152386    3.566139    0.281502    0.027766    0.026495    0.741849    
#> 310: 0.687150    1.152332    3.566108    0.281542    0.027754    0.026494    0.741957    
#> 311: 0.686765    1.152321    3.566111    0.281364    0.027727    0.026484    0.742002    
#> 312: 0.686300    1.152239    3.565945    0.281144    0.027709    0.026451    0.742012    
#> 313: 0.685817    1.152139    3.565677    0.281070    0.027668    0.026413    0.742181    
#> 314: 0.684995    1.152216    3.565433    0.281069    0.027684    0.026405    0.742079    
#> 315: 0.684526    1.152260    3.565396    0.280888    0.027700    0.026361    0.742042    
#> 316: 0.684339    1.152335    3.565311    0.280084    0.027747    0.026331    0.742107    
#> 317: 0.684498    1.152294    3.565325    0.280410    0.027784    0.026301    0.742222    
#> 318: 0.684587    1.152387    3.565173    0.280095    0.027736    0.026281    0.742183    
#> 319: 0.684440    1.152340    3.565089    0.280471    0.027751    0.026277    0.742250    
#> 320: 0.684370    1.152510    3.565001    0.280188    0.027794    0.026299    0.742380    
#> 321: 0.684123    1.152672    3.564868    0.279747    0.027820    0.026279    0.742474    
#> 322: 0.683420    1.152909    3.564658    0.279726    0.027828    0.026278    0.742501    
#> 323: 0.682548    1.153042    3.564467    0.279608    0.027864    0.026250    0.742593    
#> 324: 0.682276    1.153209    3.564361    0.279530    0.027833    0.026186    0.742584    
#> 325: 0.682043    1.153435    3.564183    0.279690    0.027851    0.026166    0.742523    
#> 326: 0.681819    1.153549    3.563954    0.279768    0.027840    0.026136    0.742652    
#> 327: 0.681573    1.153717    3.563793    0.280048    0.027840    0.026103    0.742625    
#> 328: 0.681445    1.153929    3.563551    0.280465    0.027830    0.026055    0.742525    
#> 329: 0.681347    1.154224    3.563458    0.280602    0.027827    0.026014    0.742483    
#> 330: 0.681029    1.154473    3.563398    0.281018    0.027847    0.026034    0.742419    
#> 331: 0.681421    1.154724    3.563397    0.281741    0.027868    0.026041    0.742283    
#> 332: 0.681649    1.154723    3.563472    0.281931    0.027836    0.026079    0.742347    
#> 333: 0.681630    1.154890    3.563371    0.281724    0.027799    0.026099    0.742411    
#> 334: 0.681598    1.154960    3.563182    0.281876    0.027776    0.026075    0.742338    
#> 335: 0.681249    1.155057    3.563059    0.281880    0.027723    0.026069    0.742328    
#> 336: 0.680790    1.155227    3.562921    0.281692    0.027691    0.026071    0.742321    
#> 337: 0.680713    1.155533    3.562864    0.281539    0.027700    0.026049    0.742419    
#> 338: 0.680823    1.155657    3.562892    0.281838    0.027745    0.026033    0.742411    
#> 339: 0.680549    1.155936    3.562770    0.281780    0.027858    0.025992    0.742352    
#> 340: 0.680435    1.156025    3.562730    0.281254    0.027931    0.025942    0.742265    
#> 341: 0.680542    1.156046    3.562759    0.280803    0.028060    0.025912    0.742237    
#> 342: 0.680349    1.155891    3.562764    0.280377    0.028111    0.025921    0.742178    
#> 343: 0.680036    1.155870    3.562749    0.280007    0.028125    0.025920    0.742176    
#> 344: 0.680087    1.155812    3.562759    0.279715    0.028127    0.025924    0.742440    
#> 345: 0.680092    1.155923    3.562665    0.279958    0.028151    0.025918    0.742443    
#> 346: 0.679832    1.156103    3.562510    0.280330    0.028178    0.025859    0.742293    
#> 347: 0.679813    1.156092    3.562403    0.280509    0.028231    0.025826    0.742205    
#> 348: 0.679556    1.156301    3.562287    0.280571    0.028318    0.025800    0.742244    
#> 349: 0.679328    1.156545    3.562127    0.280802    0.028364    0.025795    0.742141    
#> 350: 0.679029    1.156633    3.562008    0.280887    0.028406    0.025790    0.742062    
#> 351: 0.679088    1.156812    3.561919    0.280957    0.028411    0.025791    0.741878    
#> 352: 0.678697    1.156931    3.561815    0.281307    0.028397    0.025778    0.741929    
#> 353: 0.678740    1.157152    3.561785    0.281436    0.028397    0.025803    0.741935    
#> 354: 0.679028    1.157104    3.561693    0.281706    0.028390    0.025786    0.741968    
#> 355: 0.679331    1.156927    3.561688    0.281719    0.028419    0.025760    0.742022    
#> 356: 0.679375    1.156890    3.561764    0.281741    0.028485    0.025738    0.742065    
#> 357: 0.679451    1.156926    3.561762    0.281949    0.028512    0.025734    0.741975    
#> 358: 0.679424    1.156995    3.561783    0.282175    0.028553    0.025729    0.741848    
#> 359: 0.679149    1.157171    3.561762    0.282143    0.028634    0.025715    0.741950    
#> 360: 0.678980    1.157401    3.561612    0.282577    0.028737    0.025706    0.741824    
#> 361: 0.678833    1.157572    3.561540    0.282664    0.028801    0.025695    0.741859    
#> 362: 0.679047    1.157560    3.561492    0.282809    0.028787    0.025700    0.741761    
#> 363: 0.679109    1.157483    3.561516    0.283070    0.028743    0.025672    0.741751    
#> 364: 0.679354    1.157363    3.561547    0.283203    0.028744    0.025662    0.741744    
#> 365: 0.679329    1.157289    3.561585    0.283139    0.028746    0.025685    0.741875    
#> 366: 0.679486    1.157321    3.561519    0.282950    0.028724    0.025693    0.741853    
#> 367: 0.679665    1.157389    3.561480    0.282932    0.028694    0.025714    0.741817    
#> 368: 0.679766    1.157455    3.561411    0.282847    0.028667    0.025725    0.741720    
#> 369: 0.679686    1.157445    3.561338    0.282900    0.028690    0.025678    0.741768    
#> 370: 0.679626    1.157594    3.561247    0.282899    0.028696    0.025664    0.741788    
#> 371: 0.679493    1.157702    3.561092    0.283004    0.028728    0.025619    0.741633    
#> 372: 0.679330    1.157806    3.560982    0.283135    0.028772    0.025595    0.741591    
#> 373: 0.678941    1.158029    3.560808    0.283551    0.028764    0.025595    0.741656    
#> 374: 0.679006    1.158054    3.560821    0.284020    0.028689    0.025590    0.741734    
#> 375: 0.678951    1.158050    3.560855    0.284338    0.028637    0.025600    0.741751    
#> 376: 0.679027    1.158124    3.560892    0.284439    0.028601    0.025604    0.741663    
#> 377: 0.678989    1.158178    3.560872    0.284590    0.028589    0.025600    0.741552    
#> 378: 0.678696    1.158259    3.560759    0.284620    0.028604    0.025603    0.741535    
#> 379: 0.678478    1.158198    3.560749    0.284520    0.028615    0.025569    0.741536    
#> 380: 0.678269    1.158156    3.560686    0.284444    0.028606    0.025545    0.741475    
#> 381: 0.678032    1.158089    3.560611    0.284370    0.028583    0.025514    0.741429    
#> 382: 0.678006    1.158020    3.560577    0.284677    0.028568    0.025488    0.741314    
#> 383: 0.678129    1.157962    3.560542    0.284800    0.028553    0.025463    0.741155    
#> 384: 0.677917    1.157940    3.560514    0.285115    0.028520    0.025482    0.741090    
#> 385: 0.677855    1.158007    3.560502    0.285267    0.028526    0.025501    0.741056    
#> 386: 0.677845    1.158125    3.560557    0.284984    0.028546    0.025523    0.741067    
#> 387: 0.678041    1.158130    3.560659    0.284562    0.028569    0.025516    0.741024    
#> 388: 0.677960    1.158097    3.560646    0.284415    0.028538    0.025520    0.740987    
#> 389: 0.677885    1.157867    3.560619    0.284361    0.028536    0.025522    0.741055    
#> 390: 0.677664    1.157848    3.560525    0.284500    0.028555    0.025510    0.741131    
#> 391: 0.677769    1.157704    3.560532    0.284579    0.028545    0.025513    0.741152    
#> 392: 0.677926    1.157650    3.560586    0.284611    0.028527    0.025518    0.741272    
#> 393: 0.677890    1.157551    3.560540    0.284624    0.028523    0.025532    0.741283    
#> 394: 0.677798    1.157601    3.560429    0.284733    0.028516    0.025527    0.741276    
#> 395: 0.678018    1.157699    3.560390    0.284902    0.028526    0.025515    0.741305    
#> 396: 0.678107    1.157742    3.560424    0.285055    0.028553    0.025506    0.741297    
#> 397: 0.678302    1.157752    3.560501    0.284974    0.028548    0.025520    0.741342    
#> 398: 0.678451    1.157786    3.560520    0.285107    0.028557    0.025541    0.741290    
#> 399: 0.678567    1.157838    3.560599    0.284781    0.028580    0.025539    0.741216    
#> 400: 0.678655    1.158034    3.560555    0.284615    0.028575    0.025520    0.741203    
#> 401: 0.678673    1.158274    3.560499    0.284507    0.028613    0.025519    0.741233    
#> 402: 0.678469    1.158417    3.560450    0.284475    0.028686    0.025499    0.741081    
#> 403: 0.678615    1.158508    3.560383    0.284265    0.028737    0.025494    0.741028    
#> 404: 0.678692    1.158562    3.560271    0.284124    0.028776    0.025466    0.741022    
#> 405: 0.678562    1.158598    3.560263    0.284207    0.028719    0.025465    0.741027    
#> 406: 0.678528    1.158628    3.560201    0.284182    0.028667    0.025471    0.741062    
#> 407: 0.678529    1.158708    3.560204    0.284304    0.028633    0.025469    0.741022    
#> 408: 0.678761    1.158790    3.560315    0.284071    0.028632    0.025478    0.741105    
#> 409: 0.678930    1.158751    3.560327    0.283890    0.028600    0.025479    0.741127    
#> 410: 0.678911    1.158755    3.560320    0.283775    0.028595    0.025454    0.741177    
#> 411: 0.679039    1.158579    3.560359    0.283498    0.028546    0.025457    0.741294    
#> 412: 0.679118    1.158485    3.560369    0.283519    0.028526    0.025436    0.741343    
#> 413: 0.679088    1.158494    3.560295    0.283449    0.028513    0.025428    0.741357    
#> 414: 0.678856    1.158515    3.560283    0.283331    0.028478    0.025412    0.741376    
#> 415: 0.679001    1.158524    3.560266    0.283393    0.028444    0.025389    0.741420    
#> 416: 0.678974    1.158533    3.560264    0.283337    0.028445    0.025390    0.741443    
#> 417: 0.678774    1.158483    3.560199    0.283190    0.028428    0.025400    0.741496    
#> 418: 0.678469    1.158482    3.560164    0.283026    0.028402    0.025404    0.741485    
#> 419: 0.678258    1.158651    3.560100    0.283244    0.028411    0.025386    0.741520    
#> 420: 0.678271    1.158802    3.560055    0.283361    0.028432    0.025371    0.741451    
#> 421: 0.678252    1.158858    3.560096    0.283367    0.028422    0.025358    0.741344    
#> 422: 0.678473    1.158770    3.560118    0.283520    0.028420    0.025333    0.741331    
#> 423: 0.678764    1.158651    3.560162    0.283830    0.028474    0.025306    0.741226    
#> 424: 0.678778    1.158590    3.560139    0.284128    0.028552    0.025261    0.741171    
#> 425: 0.678934    1.158618    3.560130    0.284311    0.028601    0.025242    0.741278    
#> 426: 0.678948    1.158600    3.560123    0.284614    0.028665    0.025223    0.741305    
#> 427: 0.678723    1.158563    3.560092    0.284843    0.028675    0.025191    0.741337    
#> 428: 0.678656    1.158588    3.560104    0.284995    0.028674    0.025182    0.741283    
#> 429: 0.678686    1.158575    3.560118    0.285017    0.028660    0.025190    0.741259    
#> 430: 0.678707    1.158553    3.560116    0.284859    0.028630    0.025188    0.741239    
#> 431: 0.678652    1.158508    3.560109    0.284683    0.028623    0.025175    0.741209    
#> 432: 0.678576    1.158563    3.560130    0.284699    0.028622    0.025178    0.741150    
#> 433: 0.678415    1.158691    3.560116    0.284710    0.028591    0.025186    0.741149    
#> 434: 0.678245    1.158709    3.560054    0.284612    0.028590    0.025165    0.741171    
#> 435: 0.678255    1.158702    3.560029    0.284700    0.028586    0.025141    0.741119    
#> 436: 0.678200    1.158643    3.560036    0.284661    0.028606    0.025121    0.741054    
#> 437: 0.678192    1.158624    3.560030    0.284605    0.028629    0.025077    0.741056    
#> 438: 0.678206    1.158778    3.560004    0.284617    0.028646    0.025042    0.741087    
#> 439: 0.678216    1.158838    3.559978    0.284579    0.028644    0.025021    0.741071    
#> 440: 0.678167    1.158926    3.559983    0.284473    0.028637    0.025027    0.741090    
#> 441: 0.678206    1.158962    3.560000    0.284551    0.028629    0.025044    0.741043    
#> 442: 0.678060    1.158965    3.560013    0.284528    0.028633    0.025040    0.741003    
#> 443: 0.677862    1.159068    3.559930    0.284639    0.028632    0.025033    0.740990    
#> 444: 0.677812    1.159181    3.559840    0.284912    0.028623    0.025015    0.740938    
#> 445: 0.677850    1.159249    3.559824    0.285023    0.028635    0.025001    0.740988    
#> 446: 0.677609    1.159322    3.559725    0.285130    0.028633    0.024982    0.740995    
#> 447: 0.677696    1.159376    3.559740    0.285146    0.028620    0.024989    0.740961    
#> 448: 0.677676    1.159427    3.559746    0.284967    0.028613    0.025020    0.740897    
#> 449: 0.677637    1.159502    3.559814    0.285018    0.028585    0.025064    0.740899    
#> 450: 0.677714    1.159523    3.559849    0.284897    0.028554    0.025097    0.740844    
#> 451: 0.677870    1.159564    3.559864    0.284898    0.028528    0.025118    0.740860    
#> 452: 0.677990    1.159618    3.559906    0.284831    0.028512    0.025144    0.740824    
#> 453: 0.677981    1.159725    3.559848    0.284770    0.028504    0.025155    0.740749    
#> 454: 0.677989    1.159880    3.559788    0.285173    0.028496    0.025167    0.740722    
#> 455: 0.678035    1.159970    3.559777    0.285539    0.028504    0.025166    0.740741    
#> 456: 0.677994    1.159983    3.559759    0.285697    0.028494    0.025155    0.740739    
#> 457: 0.677866    1.159979    3.559759    0.285638    0.028514    0.025142    0.740705    
#> 458: 0.677704    1.160098    3.559738    0.285648    0.028546    0.025130    0.740683    
#> 459: 0.677358    1.160216    3.559668    0.285639    0.028542    0.025105    0.740733    
#> 460: 0.677233    1.160255    3.559557    0.285661    0.028536    0.025098    0.740788    
#> 461: 0.676975    1.160334    3.559470    0.285976    0.028517    0.025093    0.740828    
#> 462: 0.676751    1.160491    3.559363    0.286193    0.028518    0.025084    0.740774    
#> 463: 0.676797    1.160575    3.559353    0.286348    0.028536    0.025074    0.740713    
#> 464: 0.676986    1.160699    3.559324    0.286579    0.028519    0.025067    0.740642    
#> 465: 0.676974    1.160659    3.559312    0.286750    0.028507    0.025055    0.740579    
#> 466: 0.676992    1.160769    3.559263    0.286694    0.028500    0.025062    0.740529    
#> 467: 0.676938    1.160779    3.559235    0.286808    0.028503    0.025062    0.740457    
#> 468: 0.677096    1.160764    3.559284    0.286814    0.028479    0.025063    0.740511    
#> 469: 0.677058    1.160788    3.559308    0.286620    0.028478    0.025067    0.740632    
#> 470: 0.676939    1.160831    3.559244    0.286786    0.028471    0.025079    0.740681    
#> 471: 0.676741    1.160896    3.559190    0.286588    0.028460    0.025078    0.740678    
#> 472: 0.676784    1.160892    3.559163    0.286598    0.028452    0.025062    0.740792    
#> 473: 0.676671    1.161005    3.559103    0.286632    0.028458    0.025044    0.740786    
#> 474: 0.676596    1.161041    3.559083    0.286644    0.028469    0.025034    0.740795    
#> 475: 0.676569    1.161130    3.559040    0.286490    0.028479    0.025011    0.740794    
#> 476: 0.676497    1.161138    3.559030    0.286618    0.028475    0.025002    0.740858    
#> 477: 0.676505    1.161214    3.559041    0.286792    0.028476    0.024986    0.740853    
#> 478: 0.676483    1.161242    3.559036    0.286879    0.028472    0.024981    0.740862    
#> 479: 0.676575    1.161264    3.559012    0.287024    0.028466    0.024963    0.740864    
#> 480: 0.676628    1.161339    3.558972    0.287309    0.028495    0.024952    0.740859    
#> 481: 0.676668    1.161377    3.558965    0.287215    0.028500    0.024938    0.740844    
#> 482: 0.676725    1.161385    3.558926    0.287276    0.028496    0.024920    0.740861    
#> 483: 0.676597    1.161365    3.558900    0.287229    0.028551    0.024899    0.740859    
#> 484: 0.676580    1.161301    3.558907    0.287210    0.028600    0.024885    0.740820    
#> 485: 0.676599    1.161322    3.558912    0.287157    0.028609    0.024863    0.740847    
#> 486: 0.676679    1.161365    3.558932    0.287161    0.028625    0.024837    0.740849    
#> 487: 0.676946    1.161375    3.558975    0.287418    0.028649    0.024823    0.740798    
#> 488: 0.677063    1.161342    3.559018    0.287360    0.028640    0.024800    0.740792    
#> 489: 0.677266    1.161283    3.559048    0.287449    0.028650    0.024786    0.740833    
#> 490: 0.677274    1.161330    3.559079    0.287422    0.028666    0.024790    0.740844    
#> 491: 0.677318    1.161390    3.559123    0.287503    0.028656    0.024796    0.740847    
#> 492: 0.677313    1.161473    3.559122    0.287439    0.028663    0.024818    0.740844    
#> 493: 0.677288    1.161477    3.559141    0.287535    0.028666    0.024820    0.740872    
#> 494: 0.677514    1.161465    3.559165    0.287428    0.028644    0.024819    0.740828    
#> 495: 0.677745    1.161454    3.559205    0.287444    0.028632    0.024818    0.740819    
#> 496: 0.677826    1.161442    3.559177    0.287461    0.028612    0.024813    0.740861    
#> 497: 0.677653    1.161359    3.559146    0.287417    0.028608    0.024827    0.740956    
#> 498: 0.677692    1.161388    3.559080    0.287377    0.028645    0.024819    0.740938    
#> 499: 0.677665    1.161439    3.559050    0.287368    0.028668    0.024799    0.740897    
#> 500: 0.677677    1.161442    3.559008    0.287248    0.028676    0.024780    0.740912    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.316581    0.970798    3.450588    0.392401    0.077513    0.016800    1.609509    
#> 002: 0.429541    1.056151    3.486275    0.372781    0.073637    0.015960    1.078879    
#> 003: 0.614712    1.071219    3.497647    0.354142    0.069955    0.015162    0.771567    
#> 004: 0.561551    1.094857    3.500742    0.336435    0.066458    0.014404    0.657499    
#> 005: 0.666520    1.087335    3.515088    0.335871    0.063135    0.013684    0.569775    
#> 006: 0.641069    1.090586    3.515199    0.388516    0.059978    0.013000    0.540268    
#> 007: 0.611792    1.119421    3.499500    0.468437    0.056979    0.012350    0.553498    
#> 008: 0.619893    1.108699    3.501451    0.445015    0.054130    0.011732    0.537175    
#> 009: 0.596302    1.098978    3.500243    0.422764    0.051424    0.011146    0.538208    
#> 010: 0.617471    1.095313    3.507722    0.445844    0.048852    0.011199    0.542308    
#> 011: 0.705241    1.081705    3.513574    0.519995    0.046410    0.012585    0.541012    
#> 012: 0.725391    1.083835    3.523901    0.563338    0.044089    0.012820    0.528688    
#> 013: 0.653029    1.094372    3.508993    0.535171    0.041885    0.014181    0.533604    
#> 014: 0.647364    1.089679    3.511676    0.508413    0.039791    0.013472    0.537091    
#> 015: 0.653544    1.096409    3.511734    0.482992    0.037801    0.012798    0.518049    
#> 016: 0.656809    1.112854    3.513575    0.480567    0.035911    0.012341    0.527714    
#> 017: 0.606764    1.114388    3.508986    0.457305    0.034116    0.012632    0.522191    
#> 018: 0.642229    1.110303    3.504191    0.456539    0.032410    0.012001    0.524218    
#> 019: 0.625383    1.119428    3.499314    0.438483    0.030789    0.011400    0.521686    
#> 020: 0.650113    1.116363    3.505145    0.441936    0.029250    0.012155    0.517282    
#> 021: 0.639045    1.112918    3.506941    0.469901    0.027787    0.014089    0.509998    
#> 022: 0.657748    1.104901    3.515641    0.501732    0.026398    0.013385    0.499486    
#> 023: 0.690299    1.110245    3.518015    0.518108    0.025078    0.013618    0.515465    
#> 024: 0.681833    1.121006    3.516648    0.505198    0.023824    0.012937    0.503506    
#> 025: 0.664408    1.110810    3.505878    0.509085    0.022633    0.012290    0.502574    
#> 026: 0.620331    1.127340    3.498963    0.489776    0.021501    0.012981    0.516175    
#> 027: 0.636123    1.133687    3.499883    0.505543    0.020426    0.013008    0.522048    
#> 028: 0.662979    1.125296    3.500411    0.546356    0.019405    0.012357    0.508581    
#> 029: 0.668398    1.116623    3.499610    0.538355    0.018435    0.012340    0.534523    
#> 030: 0.664662    1.127562    3.500817    0.609151    0.019463    0.014578    0.535825    
#> 031: 0.628330    1.114309    3.501305    0.578694    0.018490    0.014011    0.517759    
#> 032: 0.616713    1.119470    3.501244    0.549759    0.017565    0.013854    0.513903    
#> 033: 0.631788    1.130957    3.493023    0.524477    0.016687    0.013161    0.532603    
#> 034: 0.640072    1.127630    3.500656    0.537046    0.015853    0.013163    0.510702    
#> 035: 0.647067    1.102108    3.500273    0.575740    0.015060    0.012505    0.507431    
#> 036: 0.627096    1.105057    3.505451    0.546953    0.014307    0.011880    0.543727    
#> 037: 0.636731    1.107884    3.512442    0.519606    0.013592    0.011286    0.551283    
#> 038: 0.661354    1.113591    3.502441    0.533405    0.012912    0.010945    0.550455    
#> 039: 0.661214    1.113275    3.505467    0.550677    0.012266    0.011755    0.545741    
#> 040: 0.661731    1.115834    3.512899    0.567585    0.012365    0.011407    0.528421    
#> 041: 0.651392    1.115218    3.504565    0.545643    0.012862    0.011928    0.529784    
#> 042: 0.681047    1.107701    3.504248    0.602334    0.013741    0.011331    0.521857    
#> 043: 0.655940    1.121546    3.495075    0.579697    0.014130    0.010765    0.528504    
#> 044: 0.625092    1.130485    3.491248    0.550712    0.013424    0.010578    0.535538    
#> 045: 0.622086    1.128895    3.488937    0.523176    0.013757    0.010172    0.531963    
#> 046: 0.655725    1.103072    3.504264    0.560866    0.013069    0.009830    0.541586    
#> 047: 0.640938    1.102546    3.501523    0.557618    0.012416    0.009339    0.532999    
#> 048: 0.639070    1.094708    3.498878    0.584064    0.014090    0.009930    0.530616    
#> 049: 0.636746    1.096372    3.511485    0.554861    0.013386    0.011776    0.529459    
#> 050: 0.672751    1.092714    3.508693    0.570217    0.013940    0.015479    0.531494    
#> 051: 0.644058    1.101990    3.508566    0.541706    0.013528    0.014705    0.537716    
#> 052: 0.677799    1.109310    3.522007    0.514621    0.015542    0.013970    0.518778    
#> 053: 0.656734    1.098034    3.509196    0.511467    0.017704    0.013272    0.513436    
#> 054: 0.631657    1.105586    3.508658    0.495736    0.017801    0.012608    0.536702    
#> 055: 0.618213    1.102601    3.504859    0.522011    0.016995    0.012245    0.539105    
#> 056: 0.668689    1.101210    3.504775    0.548313    0.018503    0.011645    0.526413    
#> 057: 0.656457    1.101827    3.507479    0.520898    0.017578    0.011062    0.532863    
#> 058: 0.672268    1.113642    3.506284    0.542986    0.016699    0.010509    0.534349    
#> 059: 0.640808    1.094849    3.507239    0.558267    0.015864    0.011592    0.538611    
#> 060: 0.678719    1.088506    3.510639    0.544051    0.015071    0.012339    0.531795    
#> 061: 0.696866    1.101477    3.513970    0.571989    0.014317    0.013144    0.527707    
#> 062: 0.645088    1.107196    3.515079    0.543390    0.013601    0.014446    0.549567    
#> 063: 0.686416    1.093502    3.507455    0.516220    0.012921    0.013729    0.550310    
#> 064: 0.642723    1.103895    3.505101    0.490409    0.012275    0.014101    0.529255    
#> 065: 0.628850    1.107170    3.493632    0.465889    0.014195    0.013396    0.534385    
#> 066: 0.662406    1.117586    3.503577    0.489073    0.013485    0.012726    0.528926    
#> 067: 0.611340    1.116101    3.497841    0.466960    0.012811    0.013009    0.521615    
#> 068: 0.593977    1.119879    3.503711    0.444638    0.012171    0.014399    0.546939    
#> 069: 0.603362    1.122730    3.496965    0.535548    0.013270    0.013679    0.549047    
#> 070: 0.595401    1.126249    3.494634    0.565237    0.015632    0.014256    0.539011    
#> 071: 0.600152    1.146151    3.479625    0.536975    0.015190    0.014812    0.541410    
#> 072: 0.585668    1.132800    3.477577    0.543672    0.014430    0.014071    0.543851    
#> 073: 0.606553    1.129277    3.496339    0.553057    0.013709    0.014416    0.544174    
#> 074: 0.614798    1.124212    3.494874    0.525404    0.013023    0.013695    0.547175    
#> 075: 0.609205    1.119640    3.508147    0.523794    0.012372    0.013010    0.541772    
#> 076: 0.662831    1.127516    3.509340    0.517165    0.011754    0.012360    0.539592    
#> 077: 0.660262    1.107765    3.501473    0.516562    0.011569    0.012820    0.525960    
#> 078: 0.634816    1.105428    3.508927    0.552528    0.010990    0.015321    0.510220    
#> 079: 0.643933    1.111233    3.502033    0.602703    0.010441    0.016761    0.531387    
#> 080: 0.669466    1.103564    3.497427    0.647626    0.009919    0.015923    0.532586    
#> 081: 0.661530    1.109484    3.498999    0.658443    0.009423    0.016061    0.519177    
#> 082: 0.657352    1.103291    3.509237    0.625520    0.008952    0.015258    0.518421    
#> 083: 0.660586    1.106265    3.508511    0.594244    0.008504    0.017113    0.530506    
#> 084: 0.689478    1.109252    3.504919    0.600199    0.009354    0.016258    0.535204    
#> 085: 0.643892    1.113994    3.512373    0.570189    0.011494    0.015445    0.519568    
#> 086: 0.670753    1.109586    3.511448    0.541680    0.010919    0.014673    0.526240    
#> 087: 0.622451    1.109253    3.492953    0.514596    0.010373    0.013939    0.531875    
#> 088: 0.589612    1.108270    3.497084    0.493692    0.009855    0.015231    0.538823    
#> 089: 0.621756    1.114018    3.487746    0.503146    0.009362    0.015149    0.529411    
#> 090: 0.615935    1.113407    3.484687    0.527469    0.008894    0.016021    0.528869    
#> 091: 0.612020    1.112333    3.484124    0.532611    0.008449    0.015220    0.526040    
#> 092: 0.598752    1.130664    3.475231    0.541710    0.008027    0.015031    0.528140    
#> 093: 0.576048    1.128035    3.480263    0.514624    0.008558    0.015890    0.545052    
#> 094: 0.574246    1.136113    3.473114    0.488893    0.008130    0.016224    0.537452    
#> 095: 0.605331    1.140229    3.490789    0.516563    0.008926    0.015509    0.543120    
#> 096: 0.601675    1.147882    3.483798    0.570145    0.012298    0.015170    0.532684    
#> 097: 0.636350    1.142915    3.491809    0.613824    0.012932    0.014908    0.524980    
#> 098: 0.635994    1.139225    3.499858    0.583132    0.012286    0.016101    0.530534    
#> 099: 0.640854    1.121470    3.501221    0.553976    0.011671    0.016359    0.529349    
#> 100: 0.678937    1.111351    3.513416    0.584017    0.011805    0.017232    0.519003    
#> 101: 0.641781    1.094305    3.496158    0.554816    0.011215    0.017007    0.533493    
#> 102: 0.610929    1.107889    3.488326    0.535995    0.010654    0.016157    0.527281    
#> 103: 0.637192    1.103979    3.494861    0.534614    0.010635    0.015349    0.525056    
#> 104: 0.627549    1.113116    3.505251    0.527684    0.010260    0.014581    0.529685    
#> 105: 0.639034    1.115655    3.498718    0.573440    0.010511    0.013852    0.529491    
#> 106: 0.644050    1.121373    3.499508    0.637106    0.009985    0.013160    0.529764    
#> 107: 0.672840    1.117649    3.499035    0.605250    0.010434    0.012502    0.539912    
#> 108: 0.622059    1.110276    3.504072    0.574988    0.012555    0.011877    0.545023    
#> 109: 0.673143    1.103374    3.517473    0.546238    0.011928    0.011410    0.531752    
#> 110: 0.665869    1.108184    3.503465    0.518927    0.011331    0.010839    0.530793    
#> 111: 0.661990    1.110013    3.506642    0.492980    0.010765    0.010586    0.521609    
#> 112: 0.634389    1.092683    3.497815    0.468331    0.010226    0.010057    0.536896    
#> 113: 0.617831    1.102677    3.511544    0.444915    0.009715    0.011061    0.524405    
#> 114: 0.645684    1.106931    3.511683    0.448973    0.011403    0.010508    0.524810    
#> 115: 0.674680    1.083644    3.508434    0.503916    0.011452    0.009982    0.543317    
#> 116: 0.651760    1.092883    3.504748    0.524704    0.011478    0.009483    0.538309    
#> 117: 0.622621    1.104858    3.511054    0.498469    0.011731    0.011776    0.538652    
#> 118: 0.656358    1.104956    3.510531    0.477695    0.011145    0.013451    0.528967    
#> 119: 0.658119    1.106704    3.504756    0.502144    0.010587    0.013816    0.541941    
#> 120: 0.664395    1.103097    3.510910    0.552299    0.010148    0.013125    0.532976    
#> 121: 0.663854    1.111645    3.511426    0.524684    0.011827    0.013757    0.528808    
#> 122: 0.639851    1.094564    3.508737    0.498450    0.011278    0.014377    0.529802    
#> 123: 0.656204    1.103279    3.507563    0.473528    0.015901    0.013658    0.524462    
#> 124: 0.634551    1.124720    3.501608    0.449851    0.017586    0.012975    0.525952    
#> 125: 0.658818    1.120043    3.505263    0.516176    0.016707    0.013144    0.529376    
#> 126: 0.643089    1.138298    3.489575    0.513794    0.015871    0.012487    0.541432    
#> 127: 0.646843    1.129383    3.487592    0.497434    0.015078    0.011863    0.535019    
#> 128: 0.625770    1.128393    3.487797    0.601696    0.014324    0.012487    0.527822    
#> 129: 0.646092    1.131926    3.493435    0.571611    0.013608    0.013591    0.528968    
#> 130: 0.654489    1.129141    3.501769    0.543031    0.012927    0.014066    0.521562    
#> 131: 0.636746    1.118622    3.494037    0.515879    0.012281    0.013654    0.513776    
#> 132: 0.597717    1.115710    3.492282    0.490085    0.011667    0.012972    0.533964    
#> 133: 0.617122    1.114972    3.499012    0.486666    0.011083    0.012323    0.536091    
#> 134: 0.651440    1.103020    3.516213    0.474518    0.010529    0.011867    0.528314    
#> 135: 0.686510    1.097243    3.518721    0.470228    0.010003    0.012089    0.532395    
#> 136: 0.654064    1.092347    3.518494    0.479990    0.013393    0.011485    0.521092    
#> 137: 0.685766    1.079147    3.517378    0.576199    0.012724    0.012464    0.529187    
#> 138: 0.682014    1.081482    3.519555    0.547389    0.012087    0.011904    0.528522    
#> 139: 0.684785    1.085964    3.532698    0.520019    0.011483    0.013990    0.540129    
#> 140: 0.693118    1.092578    3.526951    0.517216    0.012133    0.014170    0.545035    
#> 141: 0.660189    1.083063    3.522920    0.491355    0.012835    0.013462    0.539754    
#> 142: 0.708446    1.073401    3.534674    0.488260    0.012194    0.013198    0.539609    
#> 143: 0.654819    1.092362    3.520912    0.497793    0.011584    0.013044    0.537706    
#> 144: 0.716584    1.098534    3.533738    0.548584    0.011005    0.014462    0.520243    
#> 145: 0.676549    1.100839    3.518706    0.545309    0.010455    0.013739    0.529983    
#> 146: 0.628798    1.102757    3.517535    0.518043    0.011386    0.013052    0.534865    
#> 147: 0.630450    1.100515    3.503975    0.497126    0.011628    0.012399    0.524409    
#> 148: 0.643865    1.107839    3.516484    0.472270    0.011046    0.013260    0.530622    
#> 149: 0.624550    1.095629    3.514084    0.473800    0.010494    0.012597    0.540047    
#> 150: 0.647768    1.101785    3.494766    0.557648    0.012811    0.011967    0.545914    
#> 151: 0.589500    1.117856    3.491648    0.529766    0.012171    0.011368    0.526164    
#> 152: 0.623034    1.123775    3.502713    0.511746    0.011878    0.012642    0.512338    
#> 153: 0.627370    1.131198    3.510671    0.454931    0.013944    0.011677    0.521053    
#> 154: 0.621685    1.139778    3.501401    0.464373    0.015599    0.011513    0.533075    
#> 155: 0.619227    1.117801    3.496327    0.551614    0.015684    0.011321    0.530621    
#> 156: 0.625986    1.126136    3.500897    0.513172    0.017449    0.008569    0.541114    
#> 157: 0.638522    1.118028    3.506124    0.505918    0.018171    0.012570    0.543173    
#> 158: 0.630744    1.123487    3.497294    0.425467    0.016226    0.012316    0.531224    
#> 159: 0.626157    1.132302    3.506619    0.464502    0.014344    0.011826    0.536068    
#> 160: 0.643912    1.112158    3.512554    0.470845    0.013385    0.011240    0.544145    
#> 161: 0.642794    1.117796    3.507883    0.472873    0.013266    0.010742    0.543817    
#> 162: 0.629158    1.131824    3.499565    0.515273    0.011477    0.012549    0.545590    
#> 163: 0.662136    1.117178    3.498655    0.550713    0.010883    0.012898    0.522963    
#> 164: 0.641636    1.124196    3.501881    0.479973    0.010318    0.012436    0.521471    
#> 165: 0.650764    1.124785    3.503322    0.493296    0.009418    0.011429    0.531957    
#> 166: 0.660264    1.130390    3.504471    0.455862    0.010799    0.010580    0.540950    
#> 167: 0.643968    1.136759    3.507514    0.509796    0.007845    0.009222    0.554301    
#> 168: 0.685266    1.144143    3.516432    0.530716    0.009719    0.010512    0.533911    
#> 169: 0.667168    1.146053    3.500946    0.543432    0.011377    0.009089    0.545488    
#> 170: 0.669042    1.118404    3.503842    0.587008    0.010781    0.009182    0.536801    
#> 171: 0.660538    1.119047    3.506538    0.556334    0.008785    0.010825    0.516091    
#> 172: 0.633002    1.129307    3.498222    0.520854    0.008812    0.011588    0.507829    
#> 173: 0.658827    1.133483    3.492258    0.529537    0.008537    0.012009    0.512279    
#> 174: 0.668561    1.128352    3.500582    0.543032    0.008874    0.013133    0.524889    
#> 175: 0.652942    1.125266    3.494309    0.607916    0.010164    0.013910    0.522311    
#> 176: 0.645822    1.129308    3.506152    0.597061    0.008039    0.012494    0.530100    
#> 177: 0.650199    1.123641    3.505167    0.542396    0.009586    0.014285    0.535163    
#> 178: 0.638439    1.114372    3.500592    0.532013    0.009304    0.013744    0.538682    
#> 179: 0.652432    1.125261    3.498479    0.510944    0.009717    0.013153    0.539030    
#> 180: 0.650534    1.120889    3.499417    0.540582    0.008896    0.012319    0.541085    
#> 181: 0.633975    1.107469    3.486471    0.516227    0.008334    0.012494    0.518742    
#> 182: 0.615002    1.112339    3.488870    0.490674    0.008883    0.013593    0.533199    
#> 183: 0.602287    1.114307    3.488270    0.519247    0.007168    0.011182    0.552348    
#> 184: 0.600303    1.115912    3.486288    0.506585    0.007721    0.011600    0.540649    
#> 185: 0.602204    1.126554    3.490189    0.522974    0.008325    0.010375    0.540883    
#> 186: 0.595778    1.137473    3.484106    0.563503    0.006570    0.011035    0.552312    
#> 187: 0.642435    1.128464    3.502672    0.540283    0.008083    0.011366    0.536145    
#> 188: 0.615341    1.148830    3.497011    0.497789    0.010883    0.010161    0.546966    
#> 189: 0.612463    1.149891    3.497757    0.536445    0.010864    0.011413    0.553039    
#> 190: 0.665856    1.133313    3.497428    0.662967    0.007599    0.010444    0.537802    
#> 191: 0.611732    1.137472    3.490916    0.460457    0.006828    0.011205    0.541108    
#> 192: 0.609937    1.135849    3.497407    0.465465    0.008123    0.011947    0.539636    
#> 193: 0.671354    1.131296    3.505072    0.515578    0.006154    0.012634    0.550884    
#> 194: 0.628115    1.119632    3.506611    0.487128    0.007264    0.011218    0.550533    
#> 195: 0.606673    1.111970    3.494894    0.492467    0.008281    0.008383    0.539338    
#> 196: 0.622443    1.114756    3.499656    0.466501    0.010756    0.008209    0.545181    
#> 197: 0.607817    1.122374    3.514293    0.425307    0.009663    0.010574    0.545136    
#> 198: 0.672519    1.106991    3.511391    0.436720    0.007968    0.010249    0.542647    
#> 199: 0.655060    1.101367    3.515848    0.484991    0.005895    0.010525    0.543137    
#> 200: 0.645708    1.104476    3.512154    0.580780    0.006419    0.011418    0.548109    
#> 201: 0.642556    1.098275    3.511947    0.534022    0.006481    0.012266    0.541296    
#> 202: 0.642332    1.095819    3.512427    0.507291    0.006216    0.013126    0.544142    
#> 203: 0.653696    1.096006    3.509715    0.505458    0.006108    0.013499    0.545050    
#> 204: 0.653732    1.093627    3.510934    0.502643    0.006405    0.013497    0.544356    
#> 205: 0.652754    1.095426    3.512382    0.491428    0.006761    0.013652    0.544539    
#> 206: 0.649747    1.097832    3.513278    0.482986    0.006927    0.013939    0.546153    
#> 207: 0.648522    1.099795    3.512092    0.489194    0.006949    0.013790    0.543873    
#> 208: 0.650548    1.100913    3.511385    0.489049    0.006842    0.013683    0.542924    
#> 209: 0.649987    1.100310    3.511091    0.486745    0.006693    0.013845    0.542330    
#> 210: 0.651601    1.099832    3.511550    0.490390    0.006519    0.013996    0.540411    
#> 211: 0.652764    1.099858    3.511730    0.493635    0.006413    0.013996    0.540200    
#> 212: 0.652253    1.099742    3.511786    0.493605    0.006422    0.014163    0.539735    
#> 213: 0.654222    1.097750    3.512069    0.494960    0.006588    0.014227    0.539610    
#> 214: 0.656852    1.096707    3.512486    0.492612    0.006700    0.014301    0.540350    
#> 215: 0.658473    1.096243    3.513398    0.494649    0.006716    0.014363    0.541401    
#> 216: 0.660614    1.095025    3.514275    0.491636    0.006722    0.014374    0.542497    
#> 217: 0.660255    1.094730    3.515021    0.487557    0.006710    0.014267    0.542414    
#> 218: 0.660828    1.094830    3.514856    0.486681    0.006719    0.014225    0.542675    
#> 219: 0.660722    1.094689    3.513841    0.488394    0.006775    0.014183    0.542830    
#> 220: 0.658649    1.095064    3.513657    0.489824    0.006773    0.014031    0.543139    
#> 221: 0.657726    1.095503    3.513248    0.490876    0.006853    0.013930    0.542228    
#> 222: 0.656456    1.095895    3.512587    0.491522    0.006901    0.013901    0.541450    
#> 223: 0.656318    1.096128    3.512475    0.493058    0.006878    0.013931    0.541119    
#> 224: 0.657440    1.096134    3.512552    0.492257    0.006910    0.014011    0.540446    
#> 225: 0.656067    1.095712    3.512366    0.494148    0.006894    0.014028    0.540422    
#> 226: 0.655188    1.095138    3.511708    0.494685    0.006869    0.014060    0.540665    
#> 227: 0.655053    1.095111    3.511548    0.496088    0.006868    0.014070    0.540446    
#> 228: 0.654297    1.095982    3.510921    0.496080    0.006953    0.014011    0.540353    
#> 229: 0.652266    1.096329    3.510379    0.494929    0.006966    0.014002    0.540143    
#> 230: 0.652401    1.096447    3.510074    0.493024    0.006990    0.013969    0.540296    
#> 231: 0.652695    1.096498    3.510484    0.492954    0.007029    0.013866    0.540066    
#> 232: 0.653905    1.096364    3.510768    0.493387    0.007019    0.013784    0.540379    
#> 233: 0.653715    1.095813    3.511136    0.493489    0.007046    0.013768    0.540646    
#> 234: 0.653818    1.095236    3.511345    0.494808    0.007124    0.013823    0.540736    
#> 235: 0.654217    1.094711    3.511487    0.497433    0.007210    0.013804    0.540791    
#> 236: 0.653852    1.094725    3.511189    0.496474    0.007259    0.013788    0.540641    
#> 237: 0.654478    1.094635    3.511141    0.497055    0.007282    0.013805    0.540570    
#> 238: 0.655079    1.094768    3.511280    0.496402    0.007345    0.013846    0.540792    
#> 239: 0.654806    1.095194    3.511345    0.494604    0.007427    0.013835    0.540589    
#> 240: 0.654544    1.095268    3.511562    0.493104    0.007503    0.013841    0.540284    
#> 241: 0.654760    1.095374    3.511628    0.492147    0.007513    0.013808    0.540185    
#> 242: 0.655203    1.095593    3.511591    0.492586    0.007627    0.013809    0.540215    
#> 243: 0.655622    1.096148    3.511665    0.492973    0.007719    0.013812    0.540454    
#> 244: 0.655753    1.096282    3.511788    0.492193    0.007772    0.013794    0.540349    
#> 245: 0.655825    1.096308    3.511918    0.490701    0.007824    0.013790    0.540722    
#> 246: 0.656046    1.096330    3.511981    0.490424    0.007833    0.013801    0.540838    
#> 247: 0.655934    1.096343    3.512170    0.489727    0.007858    0.013788    0.540717    
#> 248: 0.655915    1.096554    3.512040    0.490040    0.007885    0.013792    0.540452    
#> 249: 0.655820    1.096693    3.511973    0.491860    0.007873    0.013824    0.540224    
#> 250: 0.656124    1.096790    3.511982    0.491535    0.007875    0.013796    0.540171    
#> 251: 0.656234    1.096839    3.512023    0.490563    0.007876    0.013809    0.540069    
#> 252: 0.656828    1.096903    3.512249    0.491205    0.007889    0.013831    0.539977    
#> 253: 0.656909    1.097095    3.512327    0.491542    0.007919    0.013836    0.539966    
#> 254: 0.656907    1.097725    3.512314    0.491909    0.007950    0.013858    0.540013    
#> 255: 0.657115    1.098067    3.512353    0.491706    0.007981    0.013869    0.539715    
#> 256: 0.657370    1.098152    3.512269    0.492655    0.007985    0.013882    0.539453    
#> 257: 0.657029    1.098042    3.512215    0.492321    0.007990    0.013880    0.539182    
#> 258: 0.656613    1.097797    3.512117    0.492552    0.007996    0.013850    0.539147    
#> 259: 0.656009    1.097775    3.511895    0.493047    0.007978    0.013788    0.539185    
#> 260: 0.655310    1.097933    3.511804    0.492642    0.007982    0.013732    0.539097    
#> 261: 0.654932    1.097865    3.511733    0.492598    0.007983    0.013688    0.538970    
#> 262: 0.654320    1.098017    3.511639    0.491747    0.008013    0.013654    0.538930    
#> 263: 0.654180    1.098064    3.511628    0.492761    0.007994    0.013666    0.538910    
#> 264: 0.654029    1.098206    3.511539    0.493382    0.008013    0.013670    0.538836    
#> 265: 0.653920    1.098281    3.511498    0.492972    0.008032    0.013691    0.538808    
#> 266: 0.654050    1.098416    3.511580    0.492792    0.008041    0.013706    0.538924    
#> 267: 0.654471    1.098390    3.511868    0.493414    0.008037    0.013756    0.539062    
#> 268: 0.654772    1.098474    3.511856    0.492968    0.008046    0.013776    0.539141    
#> 269: 0.655199    1.098454    3.511773    0.492927    0.008028    0.013809    0.539131    
#> 270: 0.655002    1.098474    3.511580    0.492674    0.007992    0.013817    0.539026    
#> 271: 0.654968    1.098476    3.511467    0.492836    0.007993    0.013834    0.538989    
#> 272: 0.654797    1.098536    3.511226    0.492953    0.008002    0.013806    0.539205    
#> 273: 0.654173    1.098755    3.511123    0.492744    0.008014    0.013791    0.539102    
#> 274: 0.654155    1.098845    3.511172    0.492494    0.008009    0.013765    0.538866    
#> 275: 0.654117    1.098965    3.511023    0.492810    0.008011    0.013764    0.538574    
#> 276: 0.653858    1.099170    3.511008    0.492779    0.008050    0.013782    0.538490    
#> 277: 0.653360    1.099408    3.510982    0.492322    0.008079    0.013805    0.538545    
#> 278: 0.652683    1.099631    3.510935    0.492655    0.008102    0.013839    0.538615    
#> 279: 0.652507    1.099671    3.510871    0.493812    0.008130    0.013886    0.538660    
#> 280: 0.652345    1.099806    3.510962    0.494366    0.008139    0.013897    0.538729    
#> 281: 0.652007    1.099952    3.510898    0.494510    0.008157    0.013902    0.538631    
#> 282: 0.651743    1.100122    3.510903    0.494240    0.008130    0.013924    0.538728    
#> 283: 0.651929    1.100167    3.510974    0.494767    0.008108    0.013952    0.538923    
#> 284: 0.651718    1.100202    3.510915    0.495350    0.008095    0.014013    0.538811    
#> 285: 0.651266    1.100304    3.510723    0.495560    0.008067    0.014045    0.538852    
#> 286: 0.651379    1.100447    3.510573    0.495839    0.008035    0.014062    0.538993    
#> 287: 0.650707    1.100650    3.510354    0.496163    0.008036    0.014060    0.539120    
#> 288: 0.650684    1.100732    3.510246    0.496921    0.008021    0.014100    0.539193    
#> 289: 0.650685    1.100796    3.510128    0.497816    0.008017    0.014084    0.539223    
#> 290: 0.650782    1.100856    3.510045    0.498104    0.008023    0.014076    0.539286    
#> 291: 0.650751    1.101011    3.510029    0.497697    0.008031    0.014066    0.539198    
#> 292: 0.650680    1.101232    3.509935    0.497767    0.008041    0.014056    0.539003    
#> 293: 0.650620    1.101360    3.509839    0.496947    0.008032    0.014050    0.538919    
#> 294: 0.650445    1.101498    3.509682    0.497337    0.008026    0.014047    0.538874    
#> 295: 0.650182    1.101408    3.509539    0.497390    0.008047    0.014016    0.538761    
#> 296: 0.650073    1.101335    3.509407    0.497956    0.008076    0.013987    0.538731    
#> 297: 0.650031    1.101352    3.509311    0.498489    0.008087    0.013958    0.538764    
#> 298: 0.649791    1.101275    3.509211    0.498183    0.008090    0.013962    0.538748    
#> 299: 0.649735    1.101319    3.509156    0.498418    0.008065    0.013968    0.538679    
#> 300: 0.649819    1.101296    3.509122    0.498908    0.008059    0.013981    0.538559    
#> 301: 0.649811    1.101230    3.509051    0.498885    0.008050    0.013982    0.538467    
#> 302: 0.649919    1.101226    3.509017    0.498941    0.008049    0.013983    0.538336    
#> 303: 0.649807    1.101356    3.508911    0.498994    0.008039    0.013984    0.538169    
#> 304: 0.649707    1.101493    3.508807    0.498724    0.008032    0.013990    0.538092    
#> 305: 0.649634    1.101393    3.508774    0.498928    0.008015    0.013987    0.537984    
#> 306: 0.649449    1.101261    3.508788    0.498615    0.008001    0.013988    0.538009    
#> 307: 0.649350    1.101106    3.508792    0.498838    0.007991    0.014007    0.538026    
#> 308: 0.648919    1.100993    3.508749    0.498545    0.007987    0.014037    0.538056    
#> 309: 0.648841    1.100907    3.508714    0.498688    0.007990    0.014058    0.538100    
#> 310: 0.648999    1.100855    3.508629    0.498852    0.007995    0.014042    0.538155    
#> 311: 0.649138    1.100802    3.508694    0.499407    0.008002    0.014028    0.538206    
#> 312: 0.648526    1.100726    3.508615    0.499066    0.008001    0.014027    0.538370    
#> 313: 0.648449    1.100631    3.508560    0.499134    0.008007    0.014006    0.538380    
#> 314: 0.648281    1.100603    3.508555    0.499046    0.008009    0.013998    0.538325    
#> 315: 0.648137    1.100581    3.508628    0.498742    0.008007    0.013990    0.538266    
#> 316: 0.648449    1.100599    3.508718    0.498689    0.008015    0.013970    0.538204    
#> 317: 0.648468    1.100577    3.508788    0.498197    0.008029    0.013961    0.538288    
#> 318: 0.648678    1.100558    3.508764    0.498127    0.008047    0.013963    0.538162    
#> 319: 0.648736    1.100596    3.508786    0.497895    0.008059    0.013981    0.538186    
#> 320: 0.648154    1.100605    3.508644    0.497720    0.008096    0.013986    0.538217    
#> 321: 0.647914    1.100643    3.508488    0.498206    0.008109    0.013991    0.538307    
#> 322: 0.647730    1.100709    3.508297    0.498704    0.008108    0.013985    0.538324    
#> 323: 0.647092    1.100746    3.508170    0.498414    0.008114    0.013975    0.538387    
#> 324: 0.647038    1.100852    3.508190    0.498844    0.008129    0.013984    0.538346    
#> 325: 0.647021    1.100936    3.508176    0.498586    0.008130    0.013977    0.538322    
#> 326: 0.647100    1.100827    3.508205    0.498816    0.008133    0.013962    0.538348    
#> 327: 0.647513    1.100836    3.508327    0.498901    0.008135    0.013986    0.538325    
#> 328: 0.647812    1.100888    3.508409    0.498731    0.008139    0.013989    0.538231    
#> 329: 0.648093    1.100952    3.508427    0.498217    0.008143    0.013992    0.538113    
#> 330: 0.648238    1.100985    3.508484    0.497729    0.008163    0.013988    0.538055    
#> 331: 0.648572    1.101134    3.508556    0.498199    0.008180    0.013988    0.538030    
#> 332: 0.648753    1.101167    3.508661    0.497839    0.008191    0.013981    0.538096    
#> 333: 0.649153    1.101163    3.508636    0.498478    0.008187    0.013968    0.538142    
#> 334: 0.649241    1.101139    3.508610    0.498452    0.008175    0.013969    0.538179    
#> 335: 0.649275    1.101124    3.508514    0.498497    0.008170    0.013975    0.538163    
#> 336: 0.649016    1.101168    3.508416    0.498303    0.008156    0.013993    0.538232    
#> 337: 0.648925    1.101254    3.508340    0.498830    0.008143    0.014014    0.538213    
#> 338: 0.649002    1.101284    3.508348    0.498952    0.008141    0.014027    0.538202    
#> 339: 0.649047    1.101259    3.508373    0.498643    0.008132    0.014028    0.538080    
#> 340: 0.649262    1.101244    3.508420    0.499060    0.008143    0.014028    0.537881    
#> 341: 0.649444    1.101294    3.508469    0.499104    0.008144    0.014015    0.537827    
#> 342: 0.649444    1.101267    3.508506    0.498973    0.008139    0.013994    0.537744    
#> 343: 0.649241    1.101271    3.508537    0.498472    0.008137    0.013977    0.537763    
#> 344: 0.649141    1.101256    3.508602    0.497852    0.008148    0.013965    0.537794    
#> 345: 0.649195    1.101256    3.508647    0.497528    0.008152    0.013949    0.537710    
#> 346: 0.649260    1.101285    3.508633    0.497550    0.008148    0.013949    0.537697    
#> 347: 0.649346    1.101260    3.508609    0.497570    0.008149    0.013973    0.537772    
#> 348: 0.649233    1.101306    3.508635    0.497086    0.008151    0.013993    0.537737    
#> 349: 0.649401    1.101294    3.508678    0.497227    0.008141    0.014011    0.537774    
#> 350: 0.649306    1.101362    3.508627    0.497589    0.008116    0.014050    0.537782    
#> 351: 0.649532    1.101468    3.508609    0.498063    0.008106    0.014075    0.537703    
#> 352: 0.649435    1.101569    3.508629    0.497945    0.008114    0.014084    0.537706    
#> 353: 0.649460    1.101708    3.508561    0.498108    0.008121    0.014094    0.537654    
#> 354: 0.649528    1.101821    3.508479    0.498511    0.008114    0.014116    0.537664    
#> 355: 0.649535    1.101867    3.508424    0.498789    0.008105    0.014108    0.537533    
#> 356: 0.649614    1.101962    3.508372    0.499464    0.008117    0.014090    0.537490    
#> 357: 0.649723    1.102073    3.508323    0.499923    0.008132    0.014063    0.537366    
#> 358: 0.649697    1.102148    3.508300    0.499992    0.008147    0.014059    0.537371    
#> 359: 0.649623    1.102300    3.508256    0.499808    0.008166    0.014041    0.537370    
#> 360: 0.649535    1.102366    3.508191    0.499407    0.008165    0.014029    0.537276    
#> 361: 0.649477    1.102420    3.508136    0.499198    0.008149    0.014021    0.537150    
#> 362: 0.649467    1.102480    3.508096    0.499007    0.008132    0.014018    0.537009    
#> 363: 0.649418    1.102414    3.508151    0.498641    0.008136    0.014023    0.536954    
#> 364: 0.649590    1.102395    3.508232    0.498088    0.008139    0.014018    0.536899    
#> 365: 0.649649    1.102362    3.508306    0.497719    0.008145    0.014018    0.536926    
#> 366: 0.649483    1.102363    3.508217    0.497309    0.008157    0.014007    0.536963    
#> 367: 0.649341    1.102404    3.508128    0.497411    0.008167    0.013995    0.536928    
#> 368: 0.649678    1.102473    3.508062    0.498683    0.008172    0.013995    0.536860    
#> 369: 0.649814    1.102547    3.507986    0.499378    0.008185    0.013974    0.536885    
#> 370: 0.649667    1.102619    3.507935    0.499529    0.008204    0.013964    0.536953    
#> 371: 0.649514    1.102671    3.507844    0.499606    0.008231    0.013952    0.536888    
#> 372: 0.649423    1.102740    3.507812    0.499734    0.008255    0.013938    0.536832    
#> 373: 0.649258    1.102797    3.507739    0.500633    0.008283    0.013938    0.536772    
#> 374: 0.649423    1.102794    3.507742    0.501326    0.008293    0.013941    0.536754    
#> 375: 0.649258    1.102796    3.507688    0.501573    0.008288    0.013936    0.536773    
#> 376: 0.649106    1.102837    3.507644    0.501679    0.008284    0.013936    0.536711    
#> 377: 0.649155    1.102884    3.507640    0.502152    0.008286    0.013940    0.536679    
#> 378: 0.648928    1.102933    3.507524    0.502193    0.008282    0.013943    0.536665    
#> 379: 0.648794    1.102957    3.507503    0.502366    0.008280    0.013950    0.536622    
#> 380: 0.648615    1.102970    3.507397    0.502553    0.008293    0.013968    0.536539    
#> 381: 0.648531    1.102978    3.507333    0.502969    0.008315    0.013962    0.536422    
#> 382: 0.648417    1.102947    3.507328    0.503189    0.008320    0.013953    0.536300    
#> 383: 0.648443    1.102956    3.507311    0.503206    0.008327    0.013940    0.536148    
#> 384: 0.648189    1.102987    3.507274    0.502891    0.008321    0.013955    0.536091    
#> 385: 0.648203    1.103074    3.507231    0.503249    0.008307    0.013969    0.536046    
#> 386: 0.648275    1.103197    3.507223    0.503427    0.008297    0.013969    0.536077    
#> 387: 0.648434    1.103253    3.507236    0.503778    0.008286    0.013980    0.536069    
#> 388: 0.648455    1.103274    3.507202    0.504145    0.008276    0.013984    0.536039    
#> 389: 0.648539    1.103154    3.507188    0.504473    0.008273    0.013990    0.535958    
#> 390: 0.648479    1.103120    3.507164    0.504616    0.008278    0.013984    0.535849    
#> 391: 0.648416    1.103060    3.507134    0.504401    0.008277    0.013982    0.535804    
#> 392: 0.648389    1.103037    3.507158    0.504179    0.008280    0.013982    0.535751    
#> 393: 0.648343    1.103001    3.507111    0.504159    0.008283    0.013976    0.535693    
#> 394: 0.648502    1.102954    3.507088    0.504548    0.008271    0.013969    0.535642    
#> 395: 0.648829    1.103013    3.507091    0.505286    0.008276    0.013959    0.535594    
#> 396: 0.649067    1.103102    3.507105    0.506227    0.008294    0.013951    0.535535    
#> 397: 0.649019    1.103115    3.507118    0.506607    0.008318    0.013946    0.535557    
#> 398: 0.649330    1.103070    3.507180    0.506825    0.008322    0.013939    0.535552    
#> 399: 0.649469    1.103059    3.507213    0.507117    0.008317    0.013931    0.535554    
#> 400: 0.649500    1.103092    3.507170    0.507482    0.008314    0.013934    0.535511    
#> 401: 0.649468    1.103188    3.507139    0.507642    0.008311    0.013942    0.535516    
#> 402: 0.649414    1.103281    3.507100    0.507527    0.008302    0.013948    0.535531    
#> 403: 0.649535    1.103337    3.507094    0.507374    0.008302    0.013951    0.535543    
#> 404: 0.649394    1.103403    3.507005    0.507265    0.008309    0.013962    0.535481    
#> 405: 0.649149    1.103430    3.506956    0.507234    0.008311    0.013971    0.535463    
#> 406: 0.649188    1.103496    3.506917    0.507337    0.008314    0.013987    0.535451    
#> 407: 0.649224    1.103602    3.506923    0.507467    0.008313    0.014002    0.535468    
#> 408: 0.649239    1.103693    3.506919    0.507311    0.008309    0.014015    0.535422    
#> 409: 0.649199    1.103730    3.506887    0.507392    0.008298    0.014030    0.535362    
#> 410: 0.648970    1.103808    3.506795    0.507337    0.008296    0.014035    0.535328    
#> 411: 0.648691    1.103786    3.506741    0.507210    0.008301    0.014040    0.535298    
#> 412: 0.648467    1.103783    3.506682    0.507171    0.008307    0.014041    0.535238    
#> 413: 0.648281    1.103835    3.506612    0.507104    0.008316    0.014043    0.535293    
#> 414: 0.647933    1.103863    3.506562    0.506993    0.008320    0.014062    0.535290    
#> 415: 0.648008    1.103890    3.506531    0.506939    0.008317    0.014075    0.535295    
#> 416: 0.648056    1.103942    3.506538    0.507263    0.008313    0.014081    0.535225    
#> 417: 0.648020    1.103955    3.506507    0.507286    0.008316    0.014079    0.535206    
#> 418: 0.648059    1.103956    3.506549    0.507242    0.008323    0.014079    0.535129    
#> 419: 0.648062    1.104005    3.506543    0.507236    0.008319    0.014066    0.535155    
#> 420: 0.648097    1.104034    3.506556    0.507017    0.008316    0.014053    0.535120    
#> 421: 0.647991    1.104040    3.506588    0.506645    0.008319    0.014045    0.535057    
#> 422: 0.648074    1.103981    3.506623    0.506518    0.008314    0.014047    0.535013    
#> 423: 0.648172    1.103929    3.506631    0.506834    0.008313    0.014037    0.534952    
#> 424: 0.648190    1.103894    3.506613    0.506992    0.008311    0.014037    0.534939    
#> 425: 0.648352    1.103908    3.506607    0.507330    0.008311    0.014046    0.535035    
#> 426: 0.648344    1.103968    3.506548    0.507599    0.008307    0.014041    0.535015    
#> 427: 0.648253    1.103948    3.506532    0.507715    0.008301    0.014044    0.534948    
#> 428: 0.648205    1.104006    3.506509    0.507842    0.008298    0.014044    0.534933    
#> 429: 0.648155    1.104052    3.506468    0.508076    0.008300    0.014037    0.534940    
#> 430: 0.648161    1.104065    3.506434    0.508006    0.008299    0.014037    0.534962    
#> 431: 0.648148    1.104078    3.506402    0.508224    0.008290    0.014026    0.534908    
#> 432: 0.648196    1.104134    3.506369    0.508573    0.008288    0.014014    0.534898    
#> 433: 0.648245    1.104216    3.506359    0.509111    0.008286    0.014023    0.534875    
#> 434: 0.648172    1.104244    3.506329    0.509191    0.008284    0.014025    0.534848    
#> 435: 0.648181    1.104258    3.506289    0.509233    0.008287    0.014029    0.534855    
#> 436: 0.648175    1.104260    3.506287    0.509205    0.008294    0.014014    0.534836    
#> 437: 0.648226    1.104253    3.506292    0.508929    0.008293    0.014006    0.534848    
#> 438: 0.648123    1.104343    3.506272    0.508774    0.008297    0.014001    0.534848    
#> 439: 0.648036    1.104374    3.506231    0.508652    0.008299    0.013998    0.534827    
#> 440: 0.647957    1.104420    3.506216    0.508780    0.008302    0.013989    0.534802    
#> 441: 0.647976    1.104395    3.506235    0.508526    0.008310    0.013987    0.534786    
#> 442: 0.647962    1.104408    3.506231    0.508207    0.008312    0.013980    0.534764    
#> 443: 0.647917    1.104444    3.506209    0.507915    0.008313    0.013969    0.534781    
#> 444: 0.647687    1.104470    3.506125    0.507707    0.008312    0.013965    0.534750    
#> 445: 0.647664    1.104503    3.506071    0.507866    0.008318    0.013977    0.534754    
#> 446: 0.647575    1.104543    3.506038    0.507964    0.008323    0.013982    0.534742    
#> 447: 0.647629    1.104588    3.506017    0.508108    0.008325    0.013984    0.534749    
#> 448: 0.647574    1.104623    3.506018    0.507790    0.008324    0.013986    0.534752    
#> 449: 0.647523    1.104675    3.506063    0.507573    0.008322    0.013978    0.534725    
#> 450: 0.647445    1.104724    3.506050    0.507507    0.008321    0.013973    0.534724    
#> 451: 0.647511    1.104802    3.506030    0.507565    0.008324    0.013965    0.534718    
#> 452: 0.647488    1.104843    3.506041    0.507305    0.008326    0.013962    0.534697    
#> 453: 0.647383    1.104897    3.506048    0.506903    0.008333    0.013967    0.534677    
#> 454: 0.647429    1.105003    3.506029    0.507300    0.008336    0.013976    0.534666    
#> 455: 0.647411    1.105078    3.505989    0.507741    0.008339    0.013984    0.534646    
#> 456: 0.647355    1.105085    3.505979    0.507704    0.008332    0.013987    0.534698    
#> 457: 0.647305    1.105107    3.506007    0.507566    0.008333    0.013990    0.534694    
#> 458: 0.647344    1.105210    3.506030    0.507532    0.008356    0.013986    0.534717    
#> 459: 0.647194    1.105324    3.506019    0.507438    0.008383    0.013977    0.534684    
#> 460: 0.647073    1.105401    3.505966    0.507187    0.008398    0.013973    0.534723    
#> 461: 0.647006    1.105499    3.505953    0.507281    0.008415    0.013974    0.534731    
#> 462: 0.646869    1.105593    3.505944    0.507423    0.008419    0.013969    0.534700    
#> 463: 0.646727    1.105688    3.505887    0.507502    0.008427    0.013969    0.534712    
#> 464: 0.646654    1.105730    3.505803    0.507568    0.008427    0.013972    0.534701    
#> 465: 0.646406    1.105726    3.505736    0.507365    0.008429    0.013968    0.534706    
#> 466: 0.646474    1.105712    3.505721    0.507613    0.008430    0.013961    0.534672    
#> 467: 0.646453    1.105710    3.505768    0.507558    0.008433    0.013961    0.534603    
#> 468: 0.646674    1.105692    3.505806    0.508014    0.008430    0.013956    0.534633    
#> 469: 0.646868    1.105713    3.505848    0.508131    0.008424    0.013958    0.534723    
#> 470: 0.646885    1.105710    3.505827    0.508167    0.008410    0.013961    0.534765    
#> 471: 0.646890    1.105676    3.505839    0.508167    0.008401    0.013961    0.534796    
#> 472: 0.646910    1.105657    3.505867    0.508081    0.008394    0.013961    0.534796    
#> 473: 0.646802    1.105696    3.505878    0.507876    0.008389    0.013963    0.534819    
#> 474: 0.646816    1.105737    3.505900    0.507822    0.008382    0.013975    0.534818    
#> 475: 0.646887    1.105818    3.505924    0.507590    0.008382    0.013985    0.534800    
#> 476: 0.646919    1.105823    3.505911    0.507481    0.008388    0.013985    0.534785    
#> 477: 0.647010    1.105855    3.505942    0.507599    0.008394    0.013990    0.534750    
#> 478: 0.646939    1.105893    3.505935    0.507658    0.008393    0.013994    0.534787    
#> 479: 0.646814    1.105933    3.505927    0.507549    0.008395    0.013996    0.534787    
#> 480: 0.646789    1.105932    3.505916    0.507474    0.008402    0.013997    0.534792    
#> 481: 0.646776    1.105915    3.505917    0.507361    0.008402    0.013997    0.534795    
#> 482: 0.646785    1.105893    3.505921    0.507330    0.008401    0.013994    0.534834    
#> 483: 0.646670    1.105899    3.505899    0.507247    0.008406    0.013995    0.534831    
#> 484: 0.646609    1.105843    3.505893    0.507207    0.008410    0.014001    0.534821    
#> 485: 0.646658    1.105878    3.505893    0.507252    0.008413    0.014007    0.534797    
#> 486: 0.646720    1.105923    3.505927    0.507033    0.008410    0.014004    0.534792    
#> 487: 0.646853    1.105985    3.505987    0.506873    0.008412    0.014001    0.534759    
#> 488: 0.646878    1.105980    3.506012    0.506845    0.008410    0.013993    0.534739    
#> 489: 0.646945    1.105938    3.506025    0.506696    0.008417    0.013987    0.534769    
#> 490: 0.647067    1.105969    3.506046    0.506852    0.008427    0.013985    0.534765    
#> 491: 0.647125    1.106021    3.506082    0.506986    0.008434    0.013977    0.534783    
#> 492: 0.647051    1.106035    3.506100    0.506705    0.008442    0.013967    0.534790    
#> 493: 0.647021    1.106052    3.506130    0.506570    0.008465    0.013956    0.534778    
#> 494: 0.647118    1.106096    3.506134    0.506471    0.008491    0.013948    0.534699    
#> 495: 0.647188    1.106149    3.506147    0.506447    0.008508    0.013942    0.534626    
#> 496: 0.647373    1.106221    3.506148    0.506508    0.008523    0.013927    0.534561    
#> 497: 0.647406    1.106239    3.506158    0.506691    0.008544    0.013918    0.534514    
#> 498: 0.647423    1.106249    3.506143    0.506786    0.008554    0.013910    0.534482    
#> 499: 0.647402    1.106277    3.506103    0.506840    0.008565    0.013912    0.534412    
#> 500: 0.647389    1.106288    3.506062    0.506932    0.008577    0.013907    0.534365    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.255213    0.963036    3.442078    0.392401    0.072221    0.016800    1.625048    
#> 002: 0.236528    0.972680    3.487708    0.372781    0.068610    0.015960    1.114046    
#> 003: 0.308394    0.935022    3.498917    0.354142    0.065180    0.015325    0.851585    
#> 004: 0.270022    0.958202    3.490011    0.336435    0.065230    0.015741    0.770239    
#> 005: 0.324506    0.964098    3.488757    0.319613    0.080796    0.014954    0.715975    
#> 006: 0.279591    0.988625    3.477626    0.303633    0.076756    0.014206    0.692019    
#> 007: 0.241295    1.005230    3.462882    0.288451    0.075043    0.014995    0.691082    
#> 008: 0.206481    1.018376    3.447153    0.274029    0.078111    0.014246    0.674117    
#> 009: 0.186690    1.011689    3.434168    0.260327    0.089582    0.013533    0.676993    
#> 010: 0.187284    1.014893    3.431344    0.247311    0.085103    0.012857    0.689710    
#> 011: 0.240858    1.013740    3.447954    0.234945    0.080848    0.015677    0.696745    
#> 012: 0.261793    1.015499    3.437523    0.241698    0.076805    0.016802    0.688882    
#> 013: 0.190805    1.026783    3.429158    0.259027    0.072965    0.017271    0.690388    
#> 014: 0.231331    1.026003    3.448408    0.246076    0.076013    0.016407    0.688453    
#> 015: 0.232680    1.016002    3.465169    0.233772    0.072212    0.015587    0.672951    
#> 016: 0.255519    1.019566    3.468000    0.241824    0.076242    0.014807    0.668176    
#> 017: 0.270494    1.025474    3.464209    0.296876    0.075899    0.015374    0.666149    
#> 018: 0.263926    1.020954    3.452988    0.282032    0.072104    0.015153    0.676962    
#> 019: 0.235893    1.018302    3.453278    0.267930    0.068499    0.014647    0.676160    
#> 020: 0.270227    1.004908    3.464779    0.254534    0.065074    0.017741    0.680527    
#> 021: 0.300100    0.997140    3.477915    0.255109    0.063191    0.016854    0.653683    
#> 022: 0.288926    1.000644    3.480922    0.242354    0.067239    0.016011    0.658076    
#> 023: 0.337021    1.002932    3.493491    0.230236    0.067139    0.020393    0.669415    
#> 024: 0.347560    1.006451    3.492835    0.253648    0.063782    0.019850    0.662495    
#> 025: 0.309611    0.994039    3.484166    0.284139    0.060593    0.020590    0.664772    
#> 026: 0.252429    1.026862    3.459947    0.269932    0.057563    0.022270    0.671287    
#> 027: 0.236142    1.051020    3.444979    0.286148    0.054685    0.021157    0.674401    
#> 028: 0.269064    1.031377    3.458986    0.271840    0.059691    0.023592    0.656965    
#> 029: 0.279076    1.030327    3.452022    0.258248    0.056707    0.022412    0.680261    
#> 030: 0.311561    1.021558    3.463816    0.299193    0.061333    0.021973    0.660554    
#> 031: 0.252462    1.001880    3.466581    0.300710    0.059733    0.021151    0.662295    
#> 032: 0.234382    1.016117    3.463442    0.285674    0.058896    0.020094    0.647114    
#> 033: 0.253179    1.020496    3.462994    0.271390    0.055951    0.024247    0.656190    
#> 034: 0.290520    1.015658    3.468411    0.276896    0.053154    0.023688    0.661422    
#> 035: 0.244819    1.001904    3.455237    0.263051    0.054257    0.023158    0.651844    
#> 036: 0.253240    1.020866    3.460732    0.256613    0.051544    0.022129    0.675817    
#> 037: 0.229441    1.024263    3.454085    0.254666    0.048967    0.021022    0.688116    
#> 038: 0.249089    1.007409    3.449960    0.262469    0.051174    0.022711    0.686589    
#> 039: 0.259191    1.003973    3.462906    0.249346    0.061298    0.022240    0.685550    
#> 040: 0.251153    1.023720    3.463371    0.293445    0.059511    0.022270    0.685291    
#> 041: 0.239589    1.002961    3.450384    0.330026    0.058276    0.022968    0.663302    
#> 042: 0.256964    1.022661    3.450978    0.338217    0.057496    0.022519    0.667239    
#> 043: 0.237524    1.037594    3.445935    0.321306    0.059050    0.021999    0.664554    
#> 044: 0.196492    1.037636    3.438743    0.305241    0.061116    0.020899    0.654361    
#> 045: 0.202753    1.037194    3.430021    0.312108    0.058060    0.019854    0.665257    
#> 046: 0.213305    1.013600    3.447195    0.296502    0.055157    0.019041    0.680877    
#> 047: 0.224065    1.040362    3.440474    0.281677    0.054860    0.019528    0.668430    
#> 048: 0.228969    1.025356    3.439530    0.267593    0.065536    0.018552    0.690898    
#> 049: 0.203305    1.023814    3.444287    0.254214    0.068196    0.018530    0.665646    
#> 050: 0.269397    0.994425    3.459317    0.281581    0.074871    0.018348    0.692028    
#> 051: 0.233290    1.015353    3.443373    0.267502    0.076285    0.019611    0.686423    
#> 052: 0.248797    1.020559    3.458139    0.254126    0.072470    0.018631    0.671731    
#> 053: 0.231570    1.010199    3.453277    0.241420    0.073408    0.017699    0.665946    
#> 054: 0.216806    1.007725    3.468145    0.249687    0.069737    0.022729    0.686649    
#> 055: 0.230134    1.010468    3.463672    0.237202    0.066250    0.024238    0.680985    
#> 056: 0.266601    1.001536    3.476565    0.225342    0.062938    0.023026    0.688567    
#> 057: 0.280527    0.981398    3.488257    0.214075    0.069627    0.023376    0.695440    
#> 058: 0.282728    0.998642    3.479881    0.203778    0.066391    0.022207    0.676979    
#> 059: 0.271554    0.967850    3.482011    0.232433    0.063071    0.032272    0.692860    
#> 060: 0.293805    0.966365    3.492507    0.232491    0.059918    0.030659    0.689826    
#> 061: 0.322409    0.977648    3.500667    0.220866    0.056922    0.031868    0.712961    
#> 062: 0.258690    0.992167    3.482829    0.280089    0.054076    0.034301    0.709987    
#> 063: 0.302254    0.967650    3.482870    0.287269    0.051372    0.032586    0.715170    
#> 064: 0.292085    0.986463    3.483773    0.295721    0.048803    0.030957    0.697997    
#> 065: 0.331367    0.990814    3.467465    0.311776    0.054395    0.029409    0.683224    
#> 066: 0.312261    0.999745    3.470990    0.296187    0.051676    0.027938    0.679243    
#> 067: 0.239428    1.003282    3.465424    0.281378    0.060170    0.026542    0.655348    
#> 068: 0.217674    0.998384    3.470184    0.267309    0.060939    0.025214    0.666192    
#> 069: 0.218250    1.024438    3.447387    0.253943    0.057892    0.023954    0.682424    
#> 070: 0.257742    1.027250    3.462763    0.270577    0.061801    0.026168    0.682100    
#> 071: 0.212060    1.051478    3.435662    0.257048    0.067019    0.025535    0.671620    
#> 072: 0.197175    1.011456    3.438418    0.270284    0.063668    0.024258    0.681395    
#> 073: 0.235909    1.020075    3.464385    0.298596    0.060485    0.023045    0.674194    
#> 074: 0.200086    0.990000    3.456121    0.283667    0.057460    0.022022    0.681674    
#> 075: 0.282649    0.987821    3.485152    0.309485    0.054587    0.021264    0.667103    
#> 076: 0.308255    0.998073    3.493686    0.294010    0.060721    0.024342    0.680069    
#> 077: 0.354155    0.982250    3.497017    0.279310    0.057685    0.023125    0.680088    
#> 078: 0.316741    0.976457    3.493725    0.265344    0.054801    0.021969    0.668455    
#> 079: 0.328195    0.996816    3.493070    0.332813    0.052061    0.024397    0.678777    
#> 080: 0.328417    0.980210    3.486842    0.316173    0.049458    0.026356    0.703848    
#> 081: 0.277320    0.987997    3.472875    0.300364    0.046985    0.027466    0.677572    
#> 082: 0.268129    0.988557    3.466513    0.285346    0.044636    0.030310    0.692078    
#> 083: 0.272751    1.015799    3.457254    0.297863    0.047567    0.028877    0.665186    
#> 084: 0.247572    1.024787    3.453036    0.282970    0.049178    0.027433    0.670447    
#> 085: 0.253122    1.018606    3.471612    0.268822    0.052214    0.028669    0.671475    
#> 086: 0.253939    1.006018    3.468053    0.258955    0.049604    0.027236    0.672207    
#> 087: 0.235674    0.993319    3.459734    0.246007    0.047257    0.025874    0.675716    
#> 088: 0.215433    0.990328    3.465070    0.256321    0.048271    0.024580    0.694303    
#> 089: 0.238153    1.017782    3.449137    0.243505    0.057211    0.023351    0.679588    
#> 090: 0.232897    1.022291    3.449413    0.234568    0.059772    0.024053    0.676464    
#> 091: 0.197001    1.010326    3.439837    0.231239    0.056784    0.022851    0.678694    
#> 092: 0.211711    1.027810    3.428497    0.223210    0.060010    0.022183    0.687656    
#> 093: 0.184512    1.022905    3.438752    0.226389    0.067221    0.021074    0.687717    
#> 094: 0.188707    1.035861    3.439333    0.221007    0.063860    0.021543    0.700211    
#> 095: 0.226941    1.029001    3.448949    0.277638    0.060667    0.023312    0.677490    
#> 096: 0.180151    1.058245    3.429875    0.263756    0.067292    0.022147    0.657640    
#> 097: 0.197329    1.055100    3.430567    0.259314    0.069726    0.021039    0.655195    
#> 098: 0.227847    1.046096    3.453751    0.246349    0.066240    0.023656    0.660257    
#> 099: 0.203960    1.031128    3.434071    0.234031    0.063522    0.022473    0.655282    
#> 100: 0.215365    1.032255    3.439702    0.256476    0.071252    0.021349    0.658638    
#> 101: 0.181820    1.023633    3.424583    0.280637    0.067690    0.020282    0.658552    
#> 102: 0.218501    1.028635    3.431595    0.269379    0.064305    0.019268    0.660626    
#> 103: 0.221666    1.021264    3.445666    0.255910    0.063944    0.018304    0.681435    
#> 104: 0.200204    1.028025    3.455005    0.265778    0.060746    0.021635    0.720481    
#> 105: 0.233538    1.028978    3.452717    0.300088    0.062039    0.021042    0.690664    
#> 106: 0.266775    1.021169    3.449003    0.285083    0.066816    0.021045    0.674378    
#> 107: 0.242725    1.038121    3.448428    0.313057    0.064082    0.023689    0.663681    
#> 108: 0.210856    1.012512    3.442028    0.297404    0.062922    0.022504    0.666723    
#> 109: 0.206794    1.005563    3.449064    0.282534    0.063055    0.021379    0.671619    
#> 110: 0.273295    1.007228    3.462419    0.268407    0.059902    0.022248    0.659970    
#> 111: 0.238455    1.009782    3.458633    0.255664    0.056907    0.022649    0.651067    
#> 112: 0.226043    0.997435    3.454048    0.253227    0.054062    0.023666    0.678568    
#> 113: 0.225257    1.028118    3.452611    0.253788    0.051359    0.023066    0.662742    
#> 114: 0.243052    1.036201    3.450788    0.255362    0.050065    0.021912    0.661456    
#> 115: 0.253898    1.007710    3.441629    0.298863    0.059971    0.020817    0.678518    
#> 116: 0.293021    1.013969    3.452102    0.283920    0.064562    0.019776    0.670388    
#> 117: 0.213728    1.022633    3.454023    0.269724    0.061334    0.018787    0.680142    
#> 118: 0.246490    1.015928    3.453208    0.256238    0.065030    0.017848    0.677207    
#> 119: 0.264188    1.022097    3.461561    0.262256    0.061778    0.016955    0.694775    
#> 120: 0.250787    1.009672    3.453056    0.274135    0.058689    0.020030    0.665151    
#> 121: 0.241726    1.043595    3.445399    0.260428    0.065330    0.019029    0.666766    
#> 122: 0.254895    1.008271    3.458191    0.247407    0.062063    0.018767    0.667240    
#> 123: 0.262750    1.039192    3.447028    0.235037    0.059960    0.017829    0.674435    
#> 124: 0.250885    1.057523    3.450012    0.252366    0.059748    0.018158    0.660577    
#> 125: 0.262796    1.037193    3.453238    0.287601    0.056761    0.021449    0.666428    
#> 126: 0.229425    1.049748    3.436638    0.273221    0.067692    0.020376    0.666399    
#> 127: 0.251127    1.039899    3.445666    0.297906    0.064308    0.019357    0.670888    
#> 128: 0.226713    1.032266    3.458940    0.294971    0.061092    0.018389    0.670391    
#> 129: 0.260618    1.025834    3.460101    0.280222    0.058038    0.020963    0.672984    
#> 130: 0.298874    1.034145    3.462379    0.266211    0.055136    0.022305    0.664421    
#> 131: 0.259859    1.012096    3.451542    0.254165    0.052379    0.024890    0.672381    
#> 132: 0.190167    1.025674    3.434635    0.249417    0.059638    0.024090    0.686664    
#> 133: 0.186468    1.019305    3.443397    0.236946    0.056657    0.027966    0.695349    
#> 134: 0.215963    0.996070    3.460776    0.251460    0.053824    0.030082    0.690442    
#> 135: 0.230941    0.990379    3.467165    0.246765    0.051133    0.028578    0.690413    
#> 136: 0.238643    0.993623    3.462560    0.259300    0.048977    0.027149    0.681764    
#> 137: 0.271945    0.991331    3.469056    0.283409    0.046528    0.028066    0.670822    
#> 138: 0.245758    1.013122    3.456180    0.281838    0.051855    0.028121    0.667988    
#> 139: 0.256107    1.037354    3.466979    0.285692    0.049262    0.028864    0.673565    
#> 140: 0.255040    1.025131    3.466900    0.271407    0.046799    0.031482    0.690498    
#> 141: 0.229604    1.010288    3.454068    0.258991    0.044459    0.029908    0.678709    
#> 142: 0.279845    0.994198    3.476248    0.274800    0.045697    0.028413    0.682696    
#> 143: 0.229066    1.011332    3.463881    0.261060    0.051438    0.026992    0.675717    
#> 144: 0.246306    1.025741    3.465919    0.255064    0.056932    0.025643    0.655309    
#> 145: 0.215745    1.033463    3.437791    0.265425    0.054086    0.024360    0.656053    
#> 146: 0.190555    1.035142    3.445074    0.281556    0.061437    0.023142    0.671904    
#> 147: 0.177058    1.027859    3.438051    0.267478    0.058365    0.021985    0.660377    
#> 148: 0.207296    1.045327    3.453586    0.254105    0.061643    0.020886    0.666216    
#> 149: 0.202974    1.014343    3.455933    0.241399    0.058561    0.019957    0.697754    
#> 150: 0.264412    1.007375    3.459849    0.229329    0.055633    0.019681    0.695459    
#> 151: 0.203100    1.033875    3.444006    0.217863    0.060177    0.018697    0.683096    
#> 152: 0.222033    1.048208    3.453839    0.213036    0.061516    0.015887    0.691767    
#> 153: 0.227910    1.039356    3.464373    0.210403    0.073072    0.015624    0.678080    
#> 154: 0.258275    1.022531    3.464091    0.187752    0.058205    0.020596    0.673004    
#> 155: 0.243766    0.993077    3.462832    0.220774    0.055419    0.018695    0.666960    
#> 156: 0.272496    1.005298    3.468914    0.222453    0.053746    0.015839    0.697258    
#> 157: 0.279315    1.006698    3.474221    0.231684    0.060921    0.015761    0.685315    
#> 158: 0.294734    1.020403    3.477220    0.228418    0.060747    0.015577    0.669488    
#> 159: 0.281052    1.021355    3.479978    0.229387    0.059848    0.017204    0.670116    
#> 160: 0.298416    0.980563    3.496168    0.223986    0.059476    0.025326    0.679832    
#> 161: 0.309054    0.992476    3.491532    0.231894    0.053070    0.026819    0.680510    
#> 162: 0.262126    1.003927    3.464613    0.218790    0.053759    0.023820    0.686918    
#> 163: 0.252730    1.007196    3.458201    0.220666    0.050728    0.027163    0.682460    
#> 164: 0.248110    1.010763    3.459637    0.217242    0.047976    0.025350    0.686224    
#> 165: 0.273098    1.005467    3.465275    0.299451    0.061167    0.025599    0.661907    
#> 166: 0.296748    1.047457    3.467575    0.283848    0.063229    0.029282    0.667527    
#> 167: 0.273598    1.030358    3.460959    0.302559    0.056391    0.028665    0.663432    
#> 168: 0.301115    1.041744    3.470959    0.345332    0.054100    0.029307    0.656411    
#> 169: 0.278221    1.058743    3.456026    0.312976    0.052581    0.029222    0.668206    
#> 170: 0.254620    1.035049    3.457066    0.256661    0.050043    0.027288    0.649266    
#> 171: 0.240633    1.010647    3.455661    0.265296    0.058332    0.021096    0.645370    
#> 172: 0.215488    1.044583    3.451910    0.219662    0.066003    0.018257    0.667435    
#> 173: 0.214363    1.053869    3.433855    0.247286    0.060891    0.019556    0.659510    
#> 174: 0.220957    1.036577    3.444770    0.246460    0.063760    0.016749    0.664413    
#> 175: 0.192246    1.033069    3.430601    0.245163    0.067845    0.013746    0.668431    
#> 176: 0.191082    1.053121    3.438632    0.264067    0.071776    0.016397    0.669635    
#> 177: 0.222919    1.028857    3.453535    0.269286    0.066145    0.012407    0.673756    
#> 178: 0.250159    1.022808    3.456855    0.239889    0.059064    0.015019    0.678389    
#> 179: 0.294416    1.045062    3.457468    0.288994    0.060288    0.020197    0.675437    
#> 180: 0.238573    1.037398    3.458477    0.214667    0.060936    0.016945    0.692480    
#> 181: 0.281753    0.995215    3.462753    0.190816    0.049557    0.012461    0.687082    
#> 182: 0.211715    1.007227    3.439574    0.227952    0.062042    0.012943    0.701284    
#> 183: 0.235307    1.035615    3.434780    0.223229    0.076150    0.012561    0.685450    
#> 184: 0.197227    1.021585    3.438484    0.189830    0.077630    0.011933    0.687150    
#> 185: 0.182768    1.045281    3.428083    0.204289    0.081129    0.011400    0.676504    
#> 186: 0.210361    1.060649    3.435741    0.233809    0.085067    0.011819    0.689681    
#> 187: 0.240078    1.007509    3.453835    0.265692    0.074160    0.013387    0.686125    
#> 188: 0.192563    1.034519    3.447836    0.212053    0.089787    0.014515    0.691633    
#> 189: 0.265990    1.043903    3.461360    0.208794    0.087470    0.017628    0.678526    
#> 190: 0.238033    1.033206    3.458594    0.199284    0.061409    0.016774    0.688976    
#> 191: 0.208070    1.038238    3.450698    0.214717    0.060797    0.016745    0.679124    
#> 192: 0.223017    1.025847    3.449050    0.243147    0.069518    0.018673    0.673194    
#> 193: 0.279488    1.046735    3.456844    0.271768    0.058261    0.019892    0.671376    
#> 194: 0.213742    1.037773    3.454590    0.273921    0.062514    0.020854    0.684664    
#> 195: 0.217052    1.046122    3.430557    0.245406    0.068617    0.015854    0.692319    
#> 196: 0.190435    1.044121    3.442356    0.221465    0.070100    0.014386    0.689679    
#> 197: 0.185212    1.037736    3.445956    0.196448    0.065035    0.016928    0.706309    
#> 198: 0.218702    1.031873    3.440937    0.229151    0.061791    0.017787    0.680461    
#> 199: 0.239642    1.019788    3.447592    0.246227    0.063656    0.018795    0.681457    
#> 200: 0.221306    1.028490    3.447691    0.302055    0.067962    0.018761    0.676340    
#> 201: 0.209895    1.029874    3.448834    0.306584    0.063931    0.019958    0.671170    
#> 202: 0.216208    1.031232    3.443360    0.325719    0.064465    0.021253    0.673429    
#> 203: 0.231090    1.031062    3.442748    0.329914    0.066115    0.020750    0.674814    
#> 204: 0.227780    1.028504    3.443740    0.326557    0.067706    0.020562    0.676205    
#> 205: 0.228683    1.032899    3.443690    0.331075    0.067004    0.020583    0.677406    
#> 206: 0.225877    1.038416    3.443946    0.335806    0.065892    0.020550    0.677987    
#> 207: 0.225147    1.040199    3.442304    0.336013    0.066829    0.019933    0.676725    
#> 208: 0.225796    1.041449    3.442506    0.329372    0.066087    0.019362    0.677233    
#> 209: 0.229512    1.039232    3.443215    0.325886    0.064871    0.019095    0.676113    
#> 210: 0.230693    1.037276    3.444136    0.323384    0.064138    0.018854    0.674828    
#> 211: 0.233735    1.035991    3.445138    0.320161    0.063628    0.018627    0.674234    
#> 212: 0.236168    1.034508    3.446496    0.313406    0.063675    0.018676    0.673551    
#> 213: 0.240165    1.031403    3.448393    0.308501    0.064142    0.019055    0.674168    
#> 214: 0.244109    1.029409    3.450269    0.304883    0.064048    0.019105    0.674105    
#> 215: 0.246074    1.028067    3.451725    0.303303    0.063813    0.019117    0.674102    
#> 216: 0.250310    1.026381    3.452923    0.301305    0.063624    0.019163    0.674368    
#> 217: 0.251603    1.026755    3.453447    0.298340    0.063832    0.019088    0.674167    
#> 218: 0.250964    1.027345    3.453275    0.295894    0.064538    0.019033    0.673116    
#> 219: 0.250212    1.026343    3.452395    0.295817    0.063792    0.018870    0.672733    
#> 220: 0.247732    1.026534    3.451878    0.295660    0.063810    0.018888    0.672180    
#> 221: 0.245730    1.026772    3.451016    0.295163    0.063545    0.018906    0.672076    
#> 222: 0.244226    1.026688    3.450341    0.293210    0.063116    0.018983    0.672439    
#> 223: 0.244015    1.026775    3.449794    0.293121    0.062641    0.019118    0.671997    
#> 224: 0.243545    1.027987    3.449522    0.292178    0.062788    0.019132    0.671515    
#> 225: 0.241155    1.026613    3.449359    0.292373    0.062630    0.019132    0.671528    
#> 226: 0.240572    1.025918    3.448831    0.291814    0.062344    0.019054    0.672345    
#> 227: 0.239568    1.026042    3.448397    0.291530    0.062530    0.018960    0.672551    
#> 228: 0.237793    1.027742    3.447409    0.292125    0.062641    0.018893    0.672865    
#> 229: 0.236620    1.028464    3.446722    0.290292    0.062476    0.018859    0.672428    
#> 230: 0.236889    1.028794    3.446596    0.288847    0.062039    0.018712    0.672786    
#> 231: 0.237028    1.029153    3.446761    0.287167    0.061963    0.018620    0.672285    
#> 232: 0.236673    1.029478    3.446994    0.285659    0.061807    0.018581    0.672032    
#> 233: 0.236877    1.028513    3.447120    0.286170    0.061827    0.018604    0.671944    
#> 234: 0.236762    1.028568    3.447237    0.286546    0.061970    0.018644    0.671794    
#> 235: 0.236514    1.028415    3.447286    0.285400    0.061992    0.018595    0.671760    
#> 236: 0.236731    1.028389    3.447309    0.285774    0.061975    0.018533    0.671744    
#> 237: 0.237291    1.028265    3.447603    0.285189    0.062206    0.018504    0.672284    
#> 238: 0.238233    1.028130    3.447857    0.286117    0.062320    0.018510    0.672695    
#> 239: 0.237581    1.028744    3.447343    0.286463    0.062491    0.018480    0.672839    
#> 240: 0.237451    1.028697    3.447347    0.286523    0.062713    0.018422    0.672807    
#> 241: 0.237426    1.028097    3.447536    0.285807    0.062599    0.018389    0.672467    
#> 242: 0.237351    1.027573    3.447360    0.284571    0.062777    0.018400    0.672664    
#> 243: 0.236740    1.027671    3.447485    0.282457    0.062903    0.018435    0.672826    
#> 244: 0.236745    1.027300    3.447833    0.281132    0.062718    0.018512    0.673044    
#> 245: 0.237146    1.026731    3.448216    0.279479    0.062788    0.018491    0.673411    
#> 246: 0.236991    1.026298    3.448291    0.277845    0.062697    0.018451    0.673611    
#> 247: 0.237048    1.025772    3.448519    0.276187    0.062832    0.018394    0.673659    
#> 248: 0.237504    1.025820    3.448687    0.274786    0.062946    0.018321    0.673810    
#> 249: 0.237600    1.026005    3.448872    0.273983    0.063103    0.018220    0.673978    
#> 250: 0.238006    1.026201    3.449019    0.273009    0.063279    0.018142    0.674424    
#> 251: 0.238408    1.026651    3.449266    0.271911    0.063198    0.018116    0.674718    
#> 252: 0.238824    1.026667    3.449597    0.271711    0.063178    0.018080    0.674939    
#> 253: 0.238772    1.026823    3.449764    0.271809    0.063212    0.018060    0.675280    
#> 254: 0.238654    1.027396    3.449660    0.272017    0.063230    0.018053    0.675205    
#> 255: 0.238486    1.027945    3.449761    0.272024    0.063356    0.018014    0.675442    
#> 256: 0.238238    1.027872    3.449743    0.271225    0.063508    0.017952    0.675452    
#> 257: 0.238101    1.027813    3.449679    0.271165    0.063812    0.017978    0.675242    
#> 258: 0.237599    1.027732    3.449759    0.270620    0.063802    0.017938    0.675277    
#> 259: 0.237321    1.027634    3.449717    0.269736    0.063698    0.017866    0.675241    
#> 260: 0.237241    1.027816    3.449790    0.269828    0.063653    0.017810    0.675274    
#> 261: 0.237278    1.027529    3.449945    0.270088    0.063796    0.017781    0.675287    
#> 262: 0.237820    1.027424    3.450222    0.270109    0.063658    0.017790    0.675305    
#> 263: 0.238322    1.027404    3.450400    0.269783    0.063672    0.017848    0.675627    
#> 264: 0.238523    1.027405    3.450559    0.269385    0.064003    0.017899    0.675663    
#> 265: 0.238691    1.027151    3.450603    0.270244    0.064320    0.017915    0.675915    
#> 266: 0.238967    1.026933    3.450543    0.270841    0.064384    0.017933    0.675905    
#> 267: 0.239160    1.026945    3.450663    0.271964    0.064380    0.018036    0.675686    
#> 268: 0.238986    1.026731    3.450504    0.271876    0.064319    0.018066    0.675626    
#> 269: 0.239180    1.026553    3.450457    0.271816    0.064197    0.018094    0.675505    
#> 270: 0.239452    1.026529    3.450437    0.272037    0.063992    0.018071    0.675254    
#> 271: 0.239604    1.026364    3.450481    0.271941    0.063846    0.018055    0.675146    
#> 272: 0.239698    1.026054    3.450502    0.271496    0.063734    0.017995    0.675787    
#> 273: 0.239438    1.026050    3.450544    0.271286    0.063708    0.017963    0.675974    
#> 274: 0.239241    1.026199    3.450692    0.271286    0.063651    0.017918    0.676116    
#> 275: 0.238785    1.026247    3.450570    0.271318    0.063792    0.017870    0.676154    
#> 276: 0.238344    1.026357    3.450690    0.272007    0.063753    0.017892    0.676127    
#> 277: 0.238155    1.026531    3.450926    0.271963    0.063749    0.017934    0.675997    
#> 278: 0.238067    1.026625    3.451068    0.272165    0.063623    0.017989    0.675783    
#> 279: 0.237937    1.026495    3.451112    0.271985    0.063540    0.018023    0.675856    
#> 280: 0.237951    1.026592    3.451072    0.271813    0.063468    0.018024    0.675664    
#> 281: 0.237671    1.026799    3.451126    0.271440    0.063402    0.017985    0.675709    
#> 282: 0.237654    1.026808    3.451226    0.271132    0.063357    0.017990    0.675747    
#> 283: 0.237990    1.026762    3.451302    0.271054    0.063338    0.018034    0.675870    
#> 284: 0.238076    1.026645    3.451376    0.271507    0.063216    0.018088    0.675777    
#> 285: 0.237700    1.026954    3.451155    0.271709    0.063096    0.018144    0.675637    
#> 286: 0.237720    1.027282    3.451077    0.271615    0.062848    0.018242    0.675630    
#> 287: 0.237514    1.027343    3.451043    0.271261    0.062596    0.018374    0.675652    
#> 288: 0.237719    1.027429    3.451033    0.271500    0.062573    0.018490    0.675642    
#> 289: 0.238136    1.027311    3.451058    0.272029    0.062661    0.018520    0.675847    
#> 290: 0.238354    1.027241    3.451081    0.272062    0.062677    0.018543    0.676079    
#> 291: 0.238482    1.027210    3.451193    0.272082    0.062663    0.018547    0.675918    
#> 292: 0.238412    1.027043    3.451256    0.271948    0.062493    0.018580    0.675945    
#> 293: 0.238364    1.026960    3.451202    0.271559    0.062412    0.018593    0.675780    
#> 294: 0.238362    1.027017    3.451150    0.271535    0.062372    0.018593    0.675675    
#> 295: 0.238580    1.026701    3.451079    0.271414    0.062339    0.018586    0.675554    
#> 296: 0.238628    1.026576    3.451084    0.271651    0.062309    0.018599    0.675499    
#> 297: 0.238919    1.026461    3.451103    0.271737    0.062166    0.018634    0.675500    
#> 298: 0.239156    1.026333    3.451133    0.272097    0.062082    0.018704    0.675370    
#> 299: 0.239290    1.026335    3.451216    0.272208    0.061915    0.018748    0.675163    
#> 300: 0.239430    1.026222    3.451316    0.272277    0.061879    0.018768    0.674992    
#> 301: 0.239614    1.026026    3.451322    0.272216    0.061787    0.018805    0.674956    
#> 302: 0.239682    1.026006    3.451193    0.271925    0.061747    0.018791    0.674798    
#> 303: 0.239523    1.026063    3.451024    0.271591    0.061661    0.018781    0.674656    
#> 304: 0.239518    1.026253    3.450951    0.271279    0.061703    0.018771    0.674682    
#> 305: 0.239264    1.026076    3.450956    0.271214    0.061624    0.018775    0.674799    
#> 306: 0.239020    1.026001    3.450790    0.271036    0.061667    0.018778    0.674826    
#> 307: 0.238416    1.025909    3.450577    0.271254    0.061643    0.018824    0.674945    
#> 308: 0.237701    1.025773    3.450369    0.271488    0.061587    0.018865    0.675161    
#> 309: 0.237593    1.025520    3.450375    0.271466    0.061643    0.018883    0.675266    
#> 310: 0.237525    1.025340    3.450284    0.271487    0.061662    0.018859    0.675480    
#> 311: 0.237318    1.025229    3.450249    0.271233    0.061675    0.018835    0.675359    
#> 312: 0.237258    1.025091    3.450218    0.271034    0.061665    0.018792    0.675277    
#> 313: 0.237059    1.024829    3.450217    0.270817    0.061712    0.018797    0.675330    
#> 314: 0.236979    1.024664    3.450268    0.270523    0.061730    0.018820    0.675315    
#> 315: 0.236733    1.024739    3.450158    0.270267    0.061776    0.018855    0.675302    
#> 316: 0.236533    1.024821    3.450072    0.269633    0.061770    0.018858    0.675282    
#> 317: 0.236462    1.024947    3.450018    0.269388    0.061772    0.018834    0.675353    
#> 318: 0.236462    1.025197    3.449873    0.269228    0.061853    0.018839    0.675235    
#> 319: 0.236679    1.025229    3.449923    0.269177    0.061843    0.018845    0.675208    
#> 320: 0.236416    1.025231    3.449827    0.269291    0.061824    0.018853    0.675147    
#> 321: 0.236110    1.025368    3.449753    0.269350    0.061778    0.018862    0.675189    
#> 322: 0.236340    1.025363    3.449756    0.269137    0.061762    0.018874    0.675166    
#> 323: 0.235861    1.025430    3.449654    0.269125    0.061748    0.018889    0.675266    
#> 324: 0.235700    1.025609    3.449646    0.269103    0.061740    0.018908    0.675193    
#> 325: 0.235615    1.025688    3.449592    0.268950    0.061673    0.018900    0.675190    
#> 326: 0.235671    1.025614    3.449651    0.268684    0.061663    0.018908    0.675157    
#> 327: 0.235901    1.025542    3.449816    0.268680    0.061575    0.018949    0.675278    
#> 328: 0.236108    1.025583    3.449871    0.268374    0.061501    0.018958    0.675282    
#> 329: 0.236119    1.025660    3.449883    0.268275    0.061433    0.018940    0.675088    
#> 330: 0.235892    1.025676    3.449901    0.267776    0.061469    0.018924    0.675018    
#> 331: 0.236145    1.025705    3.450018    0.268013    0.061441    0.018941    0.674983    
#> 332: 0.236283    1.025485    3.450126    0.268153    0.061428    0.018955    0.674962    
#> 333: 0.236422    1.025410    3.450147    0.268113    0.061411    0.018970    0.675019    
#> 334: 0.236324    1.025326    3.450072    0.268247    0.061378    0.018971    0.675010    
#> 335: 0.236264    1.025396    3.449920    0.268463    0.061340    0.018955    0.675063    
#> 336: 0.235994    1.025615    3.449774    0.268564    0.061393    0.018962    0.675012    
#> 337: 0.235808    1.025951    3.449630    0.268888    0.061417    0.018963    0.675061    
#> 338: 0.235724    1.025929    3.449643    0.269015    0.061397    0.018990    0.675143    
#> 339: 0.235632    1.026084    3.449575    0.269002    0.061402    0.018987    0.675137    
#> 340: 0.235665    1.025895    3.449620    0.268654    0.061418    0.018982    0.675098    
#> 341: 0.235778    1.025857    3.449692    0.268470    0.061383    0.018978    0.675111    
#> 342: 0.235622    1.025730    3.449686    0.268181    0.061375    0.018955    0.675028    
#> 343: 0.235670    1.025669    3.449808    0.267712    0.061352    0.018949    0.675078    
#> 344: 0.235891    1.025596    3.449897    0.267388    0.061400    0.018937    0.675084    
#> 345: 0.235996    1.025558    3.449948    0.267140    0.061435    0.018910    0.675111    
#> 346: 0.235954    1.025584    3.449864    0.266869    0.061399    0.018893    0.675103    
#> 347: 0.236009    1.025487    3.449851    0.267079    0.061259    0.018908    0.675178    
#> 348: 0.235914    1.025495    3.449870    0.267180    0.061163    0.018911    0.675151    
#> 349: 0.235852    1.025379    3.449867    0.267146    0.061090    0.018902    0.675067    
#> 350: 0.235653    1.025224    3.449835    0.267347    0.061070    0.018907    0.675008    
#> 351: 0.235733    1.025231    3.449773    0.267515    0.061116    0.018914    0.674917    
#> 352: 0.235409    1.025349    3.449714    0.267622    0.061112    0.018950    0.674981    
#> 353: 0.235314    1.025518    3.449647    0.267470    0.061095    0.018959    0.674872    
#> 354: 0.235165    1.025691    3.449475    0.267675    0.061078    0.018969    0.674754    
#> 355: 0.235137    1.025625    3.449374    0.267668    0.061021    0.018965    0.674632    
#> 356: 0.235100    1.025638    3.449359    0.267676    0.061054    0.018939    0.674582    
#> 357: 0.235235    1.025842    3.449353    0.267848    0.061047    0.018921    0.674481    
#> 358: 0.234973    1.026039    3.449292    0.267854    0.061034    0.018919    0.674415    
#> 359: 0.234730    1.026218    3.449173    0.267744    0.061098    0.018915    0.674361    
#> 360: 0.234585    1.026354    3.449014    0.267695    0.061063    0.018906    0.674336    
#> 361: 0.234364    1.026421    3.448906    0.267384    0.061044    0.018876    0.674298    
#> 362: 0.234280    1.026555    3.448823    0.267029    0.061020    0.018850    0.674161    
#> 363: 0.234109    1.026638    3.448798    0.266691    0.061001    0.018830    0.674033    
#> 364: 0.234098    1.026758    3.448752    0.266410    0.060967    0.018813    0.673964    
#> 365: 0.234049    1.026697    3.448759    0.266115    0.061050    0.018791    0.673956    
#> 366: 0.234087    1.026743    3.448701    0.265797    0.061053    0.018760    0.674004    
#> 367: 0.234208    1.026755    3.448716    0.265745    0.061092    0.018741    0.673931    
#> 368: 0.234290    1.026769    3.448673    0.265681    0.061109    0.018736    0.673855    
#> 369: 0.234308    1.026682    3.448607    0.265668    0.061089    0.018718    0.673932    
#> 370: 0.234227    1.026719    3.448550    0.265581    0.061169    0.018701    0.673992    
#> 371: 0.234133    1.026695    3.448459    0.265511    0.061159    0.018683    0.673996    
#> 372: 0.233955    1.026759    3.448369    0.265542    0.061171    0.018653    0.673910    
#> 373: 0.233754    1.026967    3.448268    0.265616    0.061286    0.018639    0.673865    
#> 374: 0.233514    1.027038    3.448210    0.265593    0.061302    0.018648    0.673750    
#> 375: 0.233365    1.027096    3.448165    0.265534    0.061320    0.018647    0.673739    
#> 376: 0.233271    1.027243    3.448097    0.265602    0.061373    0.018644    0.673628    
#> 377: 0.233161    1.027403    3.448047    0.265493    0.061385    0.018637    0.673618    
#> 378: 0.233024    1.027463    3.447996    0.265464    0.061347    0.018658    0.673680    
#> 379: 0.232940    1.027337    3.448032    0.265325    0.061261    0.018679    0.673691    
#> 380: 0.232995    1.027304    3.448090    0.265224    0.061196    0.018712    0.673587    
#> 381: 0.232828    1.027343    3.448059    0.265069    0.061190    0.018700    0.673555    
#> 382: 0.232739    1.027386    3.448083    0.265062    0.061118    0.018712    0.673466    
#> 383: 0.232606    1.027425    3.448029    0.265010    0.061149    0.018694    0.673378    
#> 384: 0.232461    1.027489    3.448008    0.265043    0.061204    0.018698    0.673402    
#> 385: 0.232610    1.027505    3.448012    0.265202    0.061190    0.018707    0.673444    
#> 386: 0.232727    1.027598    3.448038    0.265290    0.061210    0.018712    0.673495    
#> 387: 0.232737    1.027680    3.448081    0.265312    0.061139    0.018723    0.673472    
#> 388: 0.232701    1.027663    3.448096    0.265256    0.061096    0.018732    0.673470    
#> 389: 0.232694    1.027503    3.448105    0.265183    0.061077    0.018742    0.673592    
#> 390: 0.232495    1.027488    3.448070    0.265110    0.061057    0.018728    0.673644    
#> 391: 0.232634    1.027404    3.448117    0.264847    0.061014    0.018732    0.673640    
#> 392: 0.232557    1.027424    3.448130    0.264755    0.061031    0.018739    0.673596    
#> 393: 0.232479    1.027462    3.448080    0.264811    0.061017    0.018740    0.673535    
#> 394: 0.232557    1.027496    3.448088    0.264712    0.061054    0.018727    0.673577    
#> 395: 0.232750    1.027586    3.448086    0.264718    0.061131    0.018699    0.673556    
#> 396: 0.232857    1.027611    3.448131    0.264658    0.061157    0.018696    0.673503    
#> 397: 0.232862    1.027582    3.448143    0.264853    0.061173    0.018692    0.673557    
#> 398: 0.233261    1.027415    3.448290    0.264995    0.061104    0.018704    0.673631    
#> 399: 0.233564    1.027361    3.448406    0.265082    0.061049    0.018709    0.673589    
#> 400: 0.233901    1.027215    3.448570    0.264964    0.061054    0.018719    0.673579    
#> 401: 0.234153    1.027148    3.448619    0.264894    0.061105    0.018711    0.673703    
#> 402: 0.234383    1.027125    3.448681    0.264809    0.061192    0.018715    0.673766    
#> 403: 0.234683    1.027072    3.448717    0.264675    0.061236    0.018720    0.673793    
#> 404: 0.234788    1.027045    3.448722    0.264329    0.061228    0.018724    0.673759    
#> 405: 0.234873    1.027070    3.448797    0.264464    0.061177    0.018737    0.673770    
#> 406: 0.234978    1.027131    3.448781    0.264662    0.061186    0.018734    0.673845    
#> 407: 0.234925    1.027137    3.448804    0.264553    0.061155    0.018722    0.673915    
#> 408: 0.234984    1.027162    3.448799    0.264490    0.061141    0.018712    0.673985    
#> 409: 0.234950    1.027093    3.448784    0.264400    0.061078    0.018710    0.673926    
#> 410: 0.234952    1.027137    3.448748    0.264325    0.061033    0.018710    0.673912    
#> 411: 0.234903    1.027060    3.448734    0.264431    0.061023    0.018714    0.673964    
#> 412: 0.234908    1.027063    3.448756    0.264517    0.060968    0.018703    0.674028    
#> 413: 0.234943    1.027034    3.448754    0.264393    0.060997    0.018693    0.674037    
#> 414: 0.234724    1.026985    3.448729    0.264219    0.061007    0.018695    0.674004    
#> 415: 0.234878    1.026917    3.448766    0.263987    0.061086    0.018694    0.673974    
#> 416: 0.234965    1.026909    3.448841    0.263930    0.061126    0.018697    0.673894    
#> 417: 0.235028    1.026902    3.448855    0.263798    0.061113    0.018681    0.673903    
#> 418: 0.234931    1.026880    3.448878    0.263695    0.061133    0.018662    0.673942    
#> 419: 0.234814    1.026917    3.448846    0.263880    0.061134    0.018650    0.673995    
#> 420: 0.234675    1.026893    3.448802    0.263815    0.061099    0.018649    0.674001    
#> 421: 0.234537    1.026948    3.448800    0.263728    0.061115    0.018645    0.673966    
#> 422: 0.234730    1.026862    3.448808    0.263677    0.061109    0.018651    0.673945    
#> 423: 0.234851    1.026810    3.448821    0.263595    0.061088    0.018645    0.673981    
#> 424: 0.234782    1.026773    3.448773    0.263630    0.061102    0.018637    0.673968    
#> 425: 0.234786    1.026765    3.448748    0.263697    0.061135    0.018645    0.673989    
#> 426: 0.234827    1.026836    3.448740    0.263558    0.061159    0.018636    0.673967    
#> 427: 0.234674    1.026815    3.448762    0.263348    0.061108    0.018634    0.673946    
#> 428: 0.234600    1.026798    3.448794    0.263170    0.061047    0.018626    0.674084    
#> 429: 0.234712    1.026761    3.448870    0.263014    0.061024    0.018618    0.674082    
#> 430: 0.234752    1.026764    3.448922    0.262925    0.060999    0.018621    0.674137    
#> 431: 0.234672    1.026684    3.448941    0.262650    0.061006    0.018611    0.674136    
#> 432: 0.234687    1.026684    3.449009    0.262431    0.061040    0.018605    0.674098    
#> 433: 0.234796    1.026724    3.449066    0.262447    0.061050    0.018615    0.674106    
#> 434: 0.234812    1.026609    3.449105    0.262580    0.061018    0.018631    0.674085    
#> 435: 0.235029    1.026502    3.449169    0.262543    0.060997    0.018655    0.674038    
#> 436: 0.235097    1.026383    3.449224    0.262447    0.060996    0.018659    0.674074    
#> 437: 0.235081    1.026303    3.449238    0.262258    0.060978    0.018685    0.674138    
#> 438: 0.235023    1.026353    3.449237    0.262194    0.060948    0.018690    0.674129    
#> 439: 0.235091    1.026410    3.449298    0.262201    0.060903    0.018703    0.674084    
#> 440: 0.234997    1.026434    3.449309    0.262240    0.060910    0.018690    0.674070    
#> 441: 0.234976    1.026434    3.449301    0.262212    0.060949    0.018686    0.674055    
#> 442: 0.234866    1.026558    3.449271    0.262230    0.060931    0.018669    0.674064    
#> 443: 0.234852    1.026633    3.449219    0.262265    0.060884    0.018690    0.674063    
#> 444: 0.234762    1.026682    3.449136    0.262456    0.060867    0.018711    0.674009    
#> 445: 0.234705    1.026755    3.449067    0.262744    0.060847    0.018733    0.673959    
#> 446: 0.234550    1.026752    3.449024    0.262934    0.060820    0.018735    0.673932    
#> 447: 0.234709    1.026771    3.449052    0.262763    0.060828    0.018733    0.673881    
#> 448: 0.234604    1.026799    3.449057    0.262807    0.060844    0.018740    0.673833    
#> 449: 0.234687    1.026875    3.449138    0.262822    0.060899    0.018739    0.673807    
#> 450: 0.234759    1.026801    3.449187    0.262826    0.060942    0.018742    0.673824    
#> 451: 0.234894    1.026778    3.449221    0.262910    0.060995    0.018771    0.673850    
#> 452: 0.234911    1.026767    3.449226    0.262981    0.061023    0.018761    0.673812    
#> 453: 0.234898    1.026791    3.449223    0.263013    0.061092    0.018749    0.673742    
#> 454: 0.234877    1.026876    3.449234    0.262943    0.061140    0.018749    0.673678    
#> 455: 0.234934    1.026906    3.449251    0.262746    0.061190    0.018756    0.673668    
#> 456: 0.234835    1.026868    3.449286    0.262556    0.061249    0.018757    0.673669    
#> 457: 0.234881    1.026769    3.449389    0.262362    0.061284    0.018770    0.673644    
#> 458: 0.235008    1.026769    3.449534    0.262212    0.061321    0.018780    0.673634    
#> 459: 0.235054    1.026783    3.449636    0.262142    0.061351    0.018781    0.673621    
#> 460: 0.235088    1.026657    3.449685    0.261902    0.061354    0.018785    0.673589    
#> 461: 0.235222    1.026605    3.449786    0.261779    0.061384    0.018796    0.673518    
#> 462: 0.235288    1.026617    3.449860    0.261725    0.061363    0.018796    0.673479    
#> 463: 0.235435    1.026654    3.449930    0.261610    0.061350    0.018792    0.673442    
#> 464: 0.235560    1.026677    3.449923    0.261674    0.061338    0.018792    0.673378    
#> 465: 0.235668    1.026574    3.449959    0.261737    0.061362    0.018779    0.673310    
#> 466: 0.235838    1.026558    3.449986    0.261758    0.061353    0.018769    0.673319    
#> 467: 0.235962    1.026472    3.450032    0.261721    0.061308    0.018796    0.673238    
#> 468: 0.236205    1.026390    3.450119    0.261774    0.061263    0.018815    0.673269    
#> 469: 0.236271    1.026373    3.450207    0.261790    0.061235    0.018843    0.673350    
#> 470: 0.236279    1.026421    3.450203    0.261840    0.061212    0.018871    0.673349    
#> 471: 0.236119    1.026420    3.450177    0.261839    0.061202    0.018875    0.673426    
#> 472: 0.235963    1.026397    3.450170    0.261673    0.061187    0.018882    0.673419    
#> 473: 0.235985    1.026365    3.450202    0.261610    0.061185    0.018902    0.673438    
#> 474: 0.235991    1.026371    3.450219    0.261658    0.061182    0.018912    0.673441    
#> 475: 0.236044    1.026426    3.450211    0.261749    0.061220    0.018914    0.673399    
#> 476: 0.236072    1.026369    3.450200    0.261857    0.061263    0.018908    0.673494    
#> 477: 0.236081    1.026342    3.450226    0.261799    0.061265    0.018924    0.673482    
#> 478: 0.236020    1.026313    3.450222    0.261750    0.061230    0.018927    0.673494    
#> 479: 0.236108    1.026341    3.450235    0.261854    0.061224    0.018931    0.673442    
#> 480: 0.236130    1.026314    3.450236    0.261933    0.061217    0.018939    0.673536    
#> 481: 0.236243    1.026310    3.450279    0.262132    0.061225    0.018954    0.673555    
#> 482: 0.236392    1.026335    3.450297    0.262369    0.061203    0.018974    0.673637    
#> 483: 0.236455    1.026284    3.450297    0.262389    0.061187    0.018988    0.673635    
#> 484: 0.236392    1.026208    3.450290    0.262581    0.061172    0.018991    0.673653    
#> 485: 0.236398    1.026263    3.450297    0.262541    0.061201    0.018993    0.673672    
#> 486: 0.236398    1.026298    3.450337    0.262631    0.061214    0.018990    0.673637    
#> 487: 0.236636    1.026270    3.450428    0.262750    0.061194    0.018995    0.673648    
#> 488: 0.236755    1.026250    3.450503    0.262738    0.061182    0.019000    0.673679    
#> 489: 0.236868    1.026223    3.450507    0.262881    0.061196    0.018994    0.673727    
#> 490: 0.236911    1.026295    3.450519    0.263005    0.061242    0.018983    0.673715    
#> 491: 0.236908    1.026421    3.450520    0.263185    0.061264    0.018974    0.673731    
#> 492: 0.236834    1.026507    3.450464    0.263419    0.061282    0.018966    0.673818    
#> 493: 0.236843    1.026524    3.450464    0.263362    0.061313    0.018956    0.673878    
#> 494: 0.236871    1.026557    3.450455    0.263172    0.061361    0.018944    0.673863    
#> 495: 0.237031    1.026589    3.450469    0.263146    0.061398    0.018924    0.673839    
#> 496: 0.237060    1.026649    3.450427    0.263153    0.061435    0.018905    0.673826    
#> 497: 0.236938    1.026690    3.450360    0.263304    0.061478    0.018898    0.673842    
#> 498: 0.236846    1.026713    3.450301    0.263417    0.061500    0.018891    0.673802    
#> 499: 0.236727    1.026772    3.450242    0.263370    0.061515    0.018883    0.673776    
#> 500: 0.236636    1.026783    3.450185    0.263301    0.061515    0.018879    0.673752    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.306471    0.971310    3.435430    0.392401    0.093557    0.016800    1.880814    
#> 002: 0.340301    0.934305    3.414236    0.372781    0.088879    0.015960    1.213495    
#> 003: 0.510607    0.805917    3.416591    0.354142    0.084435    0.015162    0.841809    
#> 004: 0.524143    0.787095    3.423313    0.347114    0.080213    0.014404    0.757818    
#> 005: 0.585073    0.790276    3.412371    0.436363    0.076202    0.013684    0.692711    
#> 006: 0.548767    0.797971    3.398690    0.519576    0.074908    0.013000    0.639168    
#> 007: 0.526529    0.796619    3.393220    0.493597    0.071163    0.012350    0.651584    
#> 008: 0.509897    0.816618    3.382690    0.536084    0.067604    0.013231    0.643410    
#> 009: 0.530793    0.804345    3.378240    0.600638    0.064224    0.014550    0.636226    
#> 010: 0.496121    0.793328    3.378172    0.632607    0.062069    0.018697    0.630290    
#> 011: 0.553812    0.797631    3.384337    0.667944    0.058966    0.019735    0.627588    
#> 012: 0.524841    0.800125    3.383094    0.634547    0.056018    0.018748    0.630181    
#> 013: 0.494764    0.808068    3.375950    0.602820    0.056734    0.017811    0.633676    
#> 014: 0.546445    0.812043    3.375034    0.706967    0.055397    0.016920    0.642787    
#> 015: 0.551682    0.820163    3.384430    0.671619    0.052627    0.016074    0.631643    
#> 016: 0.548475    0.820150    3.390449    0.638038    0.049996    0.015271    0.640496    
#> 017: 0.561292    0.821447    3.390916    0.688335    0.055321    0.014507    0.604414    
#> 018: 0.546263    0.806674    3.384085    0.653918    0.056185    0.013782    0.620139    
#> 019: 0.510730    0.808469    3.380979    0.621222    0.053376    0.013720    0.616554    
#> 020: 0.579701    0.810868    3.393415    0.596825    0.051920    0.016853    0.621600    
#> 021: 0.526481    0.802492    3.389756    0.628366    0.050134    0.018324    0.608418    
#> 022: 0.581174    0.811761    3.402635    0.700020    0.050795    0.017408    0.598238    
#> 023: 0.639085    0.817060    3.401504    0.777089    0.048255    0.016537    0.636165    
#> 024: 0.597992    0.839849    3.391349    0.744881    0.048525    0.015710    0.610513    
#> 025: 0.544536    0.822158    3.377608    0.707637    0.060647    0.014925    0.614791    
#> 026: 0.540697    0.838034    3.378146    0.672255    0.062318    0.014179    0.619416    
#> 027: 0.532542    0.849671    3.379249    0.638643    0.063336    0.015463    0.627028    
#> 028: 0.548050    0.840697    3.380970    0.672536    0.060169    0.014690    0.617775    
#> 029: 0.532523    0.829747    3.369575    0.657350    0.057161    0.014978    0.632090    
#> 030: 0.543918    0.830340    3.367874    0.624483    0.054303    0.014797    0.624111    
#> 031: 0.532333    0.811632    3.384324    0.625736    0.056657    0.016075    0.619572    
#> 032: 0.562319    0.798911    3.392307    0.775951    0.053824    0.016481    0.612435    
#> 033: 0.570151    0.813987    3.393863    0.765948    0.051133    0.015657    0.618611    
#> 034: 0.628020    0.820132    3.395221    0.783570    0.057903    0.017518    0.601210    
#> 035: 0.576430    0.795533    3.384503    0.744392    0.055008    0.016642    0.606333    
#> 036: 0.565149    0.813447    3.392979    0.707172    0.052257    0.015810    0.633966    
#> 037: 0.562705    0.819416    3.394872    0.671814    0.049644    0.015019    0.647853    
#> 038: 0.586906    0.819465    3.392703    0.705953    0.050229    0.015968    0.631387    
#> 039: 0.567987    0.815352    3.394671    0.670655    0.047718    0.016126    0.614609    
#> 040: 0.549281    0.802558    3.405999    0.637122    0.046577    0.017592    0.631904    
#> 041: 0.538907    0.800485    3.398072    0.605266    0.044248    0.016712    0.632039    
#> 042: 0.562117    0.801327    3.396422    0.612571    0.046786    0.015877    0.616729    
#> 043: 0.535324    0.816387    3.375718    0.611853    0.047848    0.015083    0.620330    
#> 044: 0.552657    0.823804    3.379462    0.635529    0.045455    0.014329    0.611534    
#> 045: 0.509062    0.842689    3.376886    0.603752    0.047962    0.013962    0.620140    
#> 046: 0.505669    0.825936    3.382550    0.573565    0.054224    0.013264    0.623778    
#> 047: 0.525272    0.826242    3.375476    0.562179    0.055036    0.012601    0.617853    
#> 048: 0.508108    0.823226    3.378509    0.568314    0.060753    0.014186    0.608163    
#> 049: 0.512686    0.810506    3.386443    0.539898    0.060634    0.013670    0.617358    
#> 050: 0.541894    0.790898    3.388501    0.617101    0.057602    0.016417    0.637487    
#> 051: 0.548780    0.804486    3.382918    0.674490    0.063554    0.016883    0.637534    
#> 052: 0.621085    0.799102    3.394781    0.812231    0.067250    0.016039    0.620570    
#> 053: 0.599549    0.800165    3.391505    0.789099    0.072215    0.015237    0.614036    
#> 054: 0.511290    0.816972    3.380638    0.749644    0.075162    0.014899    0.629216    
#> 055: 0.515193    0.813041    3.388665    0.712162    0.071404    0.014154    0.618642    
#> 056: 0.559796    0.817355    3.388078    0.696675    0.067833    0.015635    0.642536    
#> 057: 0.588470    0.814604    3.391379    0.734377    0.064442    0.014853    0.630276    
#> 058: 0.562442    0.811834    3.387231    0.697658    0.062150    0.014111    0.638395    
#> 059: 0.505032    0.779785    3.388187    0.662775    0.070064    0.013886    0.655689    
#> 060: 0.509655    0.800898    3.379333    0.629636    0.085655    0.013192    0.653527    
#> 061: 0.573375    0.831986    3.388787    0.655890    0.084218    0.012532    0.638170    
#> 062: 0.574554    0.819621    3.394967    0.623095    0.080007    0.012197    0.633750    
#> 063: 0.592458    0.784758    3.400398    0.591941    0.076007    0.011587    0.630633    
#> 064: 0.553296    0.812483    3.400954    0.562344    0.073356    0.011008    0.649240    
#> 065: 0.560885    0.809361    3.386781    0.551710    0.074807    0.010457    0.636913    
#> 066: 0.537059    0.812396    3.392891    0.524124    0.071067    0.010074    0.632575    
#> 067: 0.526664    0.798371    3.383647    0.539515    0.067513    0.010119    0.637083    
#> 068: 0.491926    0.804745    3.388340    0.559643    0.070475    0.009613    0.656060    
#> 069: 0.507023    0.810205    3.384112    0.565605    0.073023    0.009707    0.665353    
#> 070: 0.532577    0.816031    3.384984    0.629453    0.072081    0.010434    0.630504    
#> 071: 0.523430    0.830817    3.372641    0.602244    0.070851    0.010267    0.645898    
#> 072: 0.498029    0.814548    3.371185    0.577050    0.072084    0.012173    0.642022    
#> 073: 0.519825    0.815921    3.396366    0.548355    0.071772    0.013136    0.642091    
#> 074: 0.517968    0.786728    3.389839    0.545632    0.069821    0.012479    0.625459    
#> 075: 0.528513    0.795793    3.400007    0.548094    0.069080    0.011855    0.633670    
#> 076: 0.580334    0.803868    3.408539    0.529608    0.065626    0.011263    0.641792    
#> 077: 0.635958    0.792307    3.413828    0.641253    0.062344    0.012048    0.634991    
#> 078: 0.662070    0.803366    3.416125    0.735491    0.062009    0.013852    0.616652    
#> 079: 0.598168    0.811526    3.411720    0.698716    0.070250    0.015572    0.644223    
#> 080: 0.591697    0.810490    3.402327    0.726142    0.066737    0.015595    0.644381    
#> 081: 0.590806    0.822208    3.385592    0.736890    0.063401    0.014816    0.641475    
#> 082: 0.615307    0.804236    3.398862    0.774355    0.060231    0.016014    0.627577    
#> 083: 0.646935    0.816934    3.398742    0.936248    0.057219    0.018380    0.636253    
#> 084: 0.584842    0.824632    3.389367    0.889436    0.054358    0.017461    0.645770    
#> 085: 0.611249    0.822897    3.401173    0.844964    0.051640    0.016588    0.645524    
#> 086: 0.608444    0.808927    3.399869    0.802716    0.049058    0.015758    0.648000    
#> 087: 0.586360    0.805282    3.391394    0.762580    0.046605    0.014970    0.634958    
#> 088: 0.479980    0.801715    3.380205    0.724451    0.051545    0.014222    0.643250    
#> 089: 0.505176    0.818468    3.376174    0.688229    0.057236    0.013650    0.642473    
#> 090: 0.522665    0.814031    3.372140    0.653817    0.055077    0.012967    0.638723    
#> 091: 0.530406    0.824504    3.366265    0.698565    0.063859    0.012319    0.633932    
#> 092: 0.490377    0.833766    3.361732    0.663636    0.068286    0.011703    0.641367    
#> 093: 0.478437    0.826164    3.362004    0.630455    0.064872    0.014436    0.632445    
#> 094: 0.493645    0.838164    3.368606    0.601171    0.064881    0.013714    0.641121    
#> 095: 0.538878    0.834025    3.383001    0.676138    0.061637    0.013028    0.638330    
#> 096: 0.528723    0.817291    3.379500    0.715906    0.058555    0.013702    0.623519    
#> 097: 0.517330    0.834769    3.375630    0.680110    0.059151    0.013806    0.615282    
#> 098: 0.561840    0.843980    3.379906    0.646105    0.057562    0.013115    0.605262    
#> 099: 0.556692    0.826110    3.376214    0.660264    0.056006    0.012545    0.604081    
#> 100: 0.530522    0.827200    3.386971    0.627250    0.059192    0.013615    0.610576    
#> 101: 0.523496    0.808432    3.373813    0.607690    0.056233    0.014858    0.607232    
#> 102: 0.522959    0.815407    3.371690    0.577305    0.053421    0.014115    0.635308    
#> 103: 0.533633    0.815147    3.379061    0.634396    0.050750    0.013409    0.634776    
#> 104: 0.523844    0.821793    3.394370    0.607578    0.052612    0.012739    0.619772    
#> 105: 0.542505    0.815861    3.385735    0.681531    0.060546    0.012102    0.633296    
#> 106: 0.532344    0.812170    3.388196    0.647454    0.057519    0.013246    0.614670    
#> 107: 0.535423    0.828938    3.385477    0.615081    0.054643    0.012942    0.621354    
#> 108: 0.531684    0.812276    3.387361    0.584327    0.057426    0.012295    0.633890    
#> 109: 0.573568    0.806118    3.400146    0.559787    0.054555    0.011680    0.632925    
#> 110: 0.567240    0.795267    3.390273    0.531798    0.060162    0.011096    0.642396    
#> 111: 0.563722    0.806372    3.400336    0.511705    0.063468    0.010541    0.624572    
#> 112: 0.542614    0.798612    3.386438    0.526542    0.069912    0.010014    0.634093    
#> 113: 0.545355    0.830617    3.389678    0.615925    0.066416    0.009514    0.619846    
#> 114: 0.564054    0.819094    3.390207    0.585129    0.063095    0.009038    0.636482    
#> 115: 0.554163    0.808101    3.390292    0.555873    0.063260    0.008586    0.640009    
#> 116: 0.558883    0.815937    3.392336    0.535398    0.065937    0.009971    0.622101    
#> 117: 0.552327    0.824044    3.391832    0.594767    0.063175    0.012486    0.619386    
#> 118: 0.545545    0.806443    3.381295    0.670830    0.060016    0.015992    0.625518    
#> 119: 0.521270    0.816348    3.373698    0.638299    0.057015    0.018757    0.626982    
#> 120: 0.516786    0.828351    3.382192    0.606385    0.060081    0.017819    0.616365    
#> 121: 0.538193    0.857472    3.369393    0.621606    0.061518    0.016928    0.626874    
#> 122: 0.509368    0.836404    3.377453    0.725178    0.063112    0.017460    0.633263    
#> 123: 0.574739    0.854209    3.372124    0.791479    0.059956    0.016587    0.644158    
#> 124: 0.538508    0.868439    3.368189    0.751905    0.056958    0.015758    0.634457    
#> 125: 0.550735    0.863662    3.368759    0.714309    0.060097    0.015271    0.632206    
#> 126: 0.490916    0.851910    3.366444    0.678594    0.057092    0.015418    0.630520    
#> 127: 0.522852    0.828553    3.373154    0.644664    0.067007    0.014647    0.628498    
#> 128: 0.508022    0.826326    3.382592    0.612431    0.063657    0.013914    0.645170    
#> 129: 0.539705    0.820476    3.394883    0.581809    0.067620    0.013219    0.627430    
#> 130: 0.589874    0.816803    3.394134    0.600713    0.067287    0.012558    0.620771    
#> 131: 0.545704    0.803798    3.386214    0.570677    0.070194    0.011930    0.616801    
#> 132: 0.529068    0.808811    3.385864    0.542144    0.066685    0.011333    0.631079    
#> 133: 0.507227    0.798721    3.390647    0.515036    0.073439    0.010767    0.631842    
#> 134: 0.548977    0.784493    3.400115    0.531649    0.069767    0.010228    0.641790    
#> 135: 0.558623    0.781352    3.400222    0.508640    0.066278    0.009717    0.632240    
#> 136: 0.527878    0.780333    3.398007    0.489164    0.069265    0.009231    0.631832    
#> 137: 0.557702    0.794388    3.398449    0.464706    0.065802    0.009389    0.645370    
#> 138: 0.535487    0.803932    3.398005    0.473520    0.062512    0.008919    0.650033    
#> 139: 0.531672    0.810093    3.395006    0.519145    0.066693    0.008606    0.630251    
#> 140: 0.544090    0.819168    3.391785    0.615169    0.067581    0.011847    0.621187    
#> 141: 0.528526    0.816210    3.392389    0.594204    0.069734    0.011255    0.623117    
#> 142: 0.569801    0.798118    3.396540    0.564493    0.071679    0.010692    0.622205    
#> 143: 0.539805    0.817999    3.396617    0.557841    0.079547    0.011932    0.628998    
#> 144: 0.570758    0.825115    3.400111    0.554150    0.075570    0.011335    0.624952    
#> 145: 0.526543    0.831772    3.385396    0.526442    0.071791    0.010768    0.636557    
#> 146: 0.553395    0.811138    3.400740    0.500120    0.074072    0.010230    0.632486    
#> 147: 0.552277    0.795330    3.397419    0.558906    0.075259    0.010210    0.618521    
#> 148: 0.563700    0.793781    3.406065    0.596380    0.071496    0.011258    0.621273    
#> 149: 0.560374    0.785415    3.402765    0.566561    0.068409    0.011727    0.621707    
#> 150: 0.560150    0.805631    3.393575    0.539180    0.069271    0.011140    0.642470    
#> 151: 0.520271    0.814622    3.393426    0.512221    0.074203    0.010583    0.633037    
#> 152: 0.509616    0.807756    3.391131    0.559780    0.066802    0.008657    0.633655    
#> 153: 0.516009    0.821173    3.392232    0.543207    0.064566    0.009498    0.636456    
#> 154: 0.585937    0.817326    3.399944    0.582101    0.077105    0.011229    0.643933    
#> 155: 0.544095    0.806170    3.385263    0.613818    0.060764    0.011126    0.634012    
#> 156: 0.570749    0.815595    3.392021    0.561152    0.069622    0.010669    0.649248    
#> 157: 0.543525    0.805551    3.394591    0.518685    0.089383    0.010055    0.628081    
#> 158: 0.563844    0.826467    3.391906    0.545232    0.076584    0.009383    0.636164    
#> 159: 0.546936    0.814736    3.391637    0.554268    0.057079    0.009366    0.638067    
#> 160: 0.555723    0.787172    3.398021    0.541816    0.068640    0.008380    0.645860    
#> 161: 0.557922    0.796913    3.397394    0.564048    0.071917    0.007418    0.640246    
#> 162: 0.552657    0.816172    3.388342    0.567350    0.080119    0.007859    0.663206    
#> 163: 0.575382    0.827982    3.384377    0.623158    0.093260    0.007293    0.645328    
#> 164: 0.553933    0.832790    3.388027    0.614912    0.071064    0.006872    0.629595    
#> 165: 0.573144    0.805734    3.394434    0.601183    0.068807    0.009558    0.626620    
#> 166: 0.603236    0.833793    3.391224    0.613923    0.079105    0.008646    0.635887    
#> 167: 0.560083    0.823072    3.391839    0.542116    0.066686    0.008537    0.641606    
#> 168: 0.556833    0.822962    3.391785    0.540608    0.067096    0.009251    0.628725    
#> 169: 0.545574    0.839866    3.384010    0.520464    0.062181    0.006890    0.634496    
#> 170: 0.554772    0.819648    3.389400    0.540983    0.060376    0.009124    0.638035    
#> 171: 0.524050    0.820011    3.384239    0.507996    0.057639    0.010737    0.621343    
#> 172: 0.507550    0.840746    3.379563    0.586944    0.061177    0.011438    0.614125    
#> 173: 0.514337    0.826972    3.369854    0.512714    0.063324    0.012245    0.626454    
#> 174: 0.530091    0.828219    3.383095    0.512204    0.058569    0.011112    0.635413    
#> 175: 0.512908    0.828032    3.375233    0.541812    0.055652    0.013439    0.632893    
#> 176: 0.515332    0.836038    3.384102    0.571808    0.060515    0.012278    0.632486    
#> 177: 0.559100    0.818609    3.395218    0.632334    0.066786    0.014975    0.631565    
#> 178: 0.549589    0.815746    3.394852    0.585333    0.067447    0.014592    0.629928    
#> 179: 0.551781    0.820102    3.384905    0.587635    0.066955    0.015149    0.633974    
#> 180: 0.514560    0.832468    3.378790    0.543766    0.059339    0.015157    0.627243    
#> 181: 0.557557    0.822120    3.373984    0.548615    0.051879    0.011636    0.641704    
#> 182: 0.530227    0.834363    3.370417    0.514759    0.061641    0.011596    0.642398    
#> 183: 0.515164    0.836188    3.373172    0.496163    0.041091    0.011886    0.645672    
#> 184: 0.504667    0.822081    3.379326    0.565382    0.045428    0.010961    0.654100    
#> 185: 0.477278    0.835696    3.373579    0.529926    0.047631    0.011743    0.648994    
#> 186: 0.525628    0.835387    3.385799    0.539144    0.038533    0.017715    0.635052    
#> 187: 0.530533    0.811816    3.391588    0.576246    0.042269    0.017169    0.636259    
#> 188: 0.562975    0.836459    3.392228    0.607472    0.047602    0.014213    0.642646    
#> 189: 0.578855    0.831886    3.396169    0.705235    0.050199    0.014924    0.628330    
#> 190: 0.532669    0.836914    3.397112    0.555910    0.048066    0.016045    0.617706    
#> 191: 0.534792    0.831114    3.373839    0.689684    0.051082    0.015004    0.607935    
#> 192: 0.547812    0.836224    3.376904    0.695231    0.043807    0.011800    0.619782    
#> 193: 0.542257    0.839826    3.378251    0.686135    0.049661    0.010990    0.627805    
#> 194: 0.534513    0.820631    3.378604    0.569311    0.056964    0.011554    0.635283    
#> 195: 0.509736    0.818832    3.379774    0.575217    0.045495    0.013097    0.627829    
#> 196: 0.556132    0.826661    3.390646    0.656810    0.056808    0.011914    0.654295    
#> 197: 0.506232    0.823558    3.396790    0.575339    0.063002    0.013216    0.643256    
#> 198: 0.578178    0.810106    3.393497    0.633079    0.068746    0.013939    0.630956    
#> 199: 0.547460    0.811493    3.391257    0.553331    0.062774    0.012931    0.635395    
#> 200: 0.515722    0.804147    3.387660    0.536643    0.061899    0.012337    0.651978    
#> 201: 0.517557    0.805016    3.391847    0.531108    0.063771    0.012456    0.650415    
#> 202: 0.532888    0.807282    3.396269    0.557161    0.061931    0.012469    0.645320    
#> 203: 0.546845    0.808198    3.393898    0.567029    0.061180    0.012521    0.641188    
#> 204: 0.548969    0.803084    3.394558    0.574168    0.063036    0.012671    0.639163    
#> 205: 0.546599    0.809340    3.393575    0.567978    0.063906    0.013201    0.639274    
#> 206: 0.550360    0.813552    3.393804    0.584014    0.063997    0.013273    0.638933    
#> 207: 0.547310    0.814933    3.392456    0.571446    0.063053    0.013278    0.638970    
#> 208: 0.545382    0.815486    3.392229    0.563400    0.062444    0.013185    0.637128    
#> 209: 0.549436    0.814613    3.391586    0.573886    0.061356    0.013361    0.634576    
#> 210: 0.552717    0.812229    3.391942    0.578306    0.062394    0.013454    0.632031    
#> 211: 0.555615    0.812093    3.392707    0.581471    0.063553    0.013496    0.630842    
#> 212: 0.555938    0.811823    3.393063    0.577938    0.063105    0.013429    0.631196    
#> 213: 0.558404    0.810540    3.393343    0.580264    0.062715    0.013320    0.632148    
#> 214: 0.560787    0.809289    3.394032    0.581401    0.062836    0.013274    0.631792    
#> 215: 0.562066    0.808224    3.395273    0.578863    0.063105    0.013093    0.631163    
#> 216: 0.566930    0.806827    3.396302    0.585322    0.063443    0.013019    0.631373    
#> 217: 0.568571    0.807436    3.397154    0.587409    0.063867    0.012958    0.630669    
#> 218: 0.569644    0.807955    3.397128    0.590813    0.064002    0.012881    0.630617    
#> 219: 0.569077    0.807986    3.396527    0.593106    0.063836    0.012940    0.630929    
#> 220: 0.566652    0.808313    3.396115    0.591669    0.063926    0.012878    0.631082    
#> 221: 0.564529    0.808674    3.395803    0.588552    0.064215    0.012804    0.630678    
#> 222: 0.563950    0.809266    3.395321    0.591638    0.064454    0.012736    0.630872    
#> 223: 0.562951    0.809024    3.394993    0.589944    0.063922    0.012711    0.630162    
#> 224: 0.563161    0.809848    3.394766    0.591074    0.063634    0.012742    0.629897    
#> 225: 0.562715    0.809068    3.394597    0.592004    0.063032    0.012755    0.629765    
#> 226: 0.561691    0.807877    3.394350    0.594098    0.062577    0.012735    0.630104    
#> 227: 0.562311    0.807446    3.394313    0.598498    0.062555    0.012699    0.629934    
#> 228: 0.560809    0.808066    3.393821    0.597649    0.062498    0.012608    0.630199    
#> 229: 0.560286    0.808297    3.393366    0.599773    0.062674    0.012541    0.629313    
#> 230: 0.560144    0.808365    3.393109    0.599006    0.062758    0.012529    0.629384    
#> 231: 0.560445    0.808524    3.393247    0.599940    0.062652    0.012531    0.628945    
#> 232: 0.560824    0.808211    3.393429    0.603617    0.062287    0.012544    0.628719    
#> 233: 0.561089    0.807273    3.393632    0.606374    0.061898    0.012543    0.628865    
#> 234: 0.560321    0.806909    3.393408    0.607663    0.061737    0.012607    0.629083    
#> 235: 0.560119    0.806838    3.393355    0.608439    0.061441    0.012612    0.628969    
#> 236: 0.559760    0.807009    3.393066    0.609056    0.061378    0.012662    0.629047    
#> 237: 0.560168    0.807198    3.393024    0.611903    0.061480    0.012756    0.629122    
#> 238: 0.560681    0.807060    3.393116    0.613608    0.061659    0.012853    0.629436    
#> 239: 0.561041    0.807434    3.392962    0.615560    0.061727    0.012908    0.629233    
#> 240: 0.561502    0.807292    3.393042    0.616212    0.061713    0.012990    0.628794    
#> 241: 0.561461    0.806675    3.393032    0.616678    0.061397    0.013016    0.628944    
#> 242: 0.560635    0.806756    3.392838    0.615427    0.061372    0.013076    0.629291    
#> 243: 0.559997    0.807423    3.392592    0.615409    0.061502    0.013154    0.629586    
#> 244: 0.559595    0.807948    3.392380    0.615026    0.061340    0.013223    0.629646    
#> 245: 0.558775    0.807904    3.392292    0.613085    0.061135    0.013298    0.630001    
#> 246: 0.558535    0.807711    3.392337    0.614221    0.060849    0.013408    0.630067    
#> 247: 0.558734    0.807643    3.392337    0.614242    0.060447    0.013448    0.629891    
#> 248: 0.558883    0.808102    3.392179    0.616158    0.060214    0.013516    0.629612    
#> 249: 0.558312    0.808312    3.392022    0.617078    0.059964    0.013606    0.629501    
#> 250: 0.558843    0.808518    3.392173    0.617949    0.059852    0.013653    0.629391    
#> 251: 0.559747    0.808842    3.392395    0.620642    0.059722    0.013665    0.629266    
#> 252: 0.560749    0.808902    3.392666    0.622839    0.059646    0.013701    0.629375    
#> 253: 0.560425    0.809059    3.392587    0.622525    0.059520    0.013699    0.629582    
#> 254: 0.560383    0.809475    3.392665    0.621738    0.059456    0.013676    0.629677    
#> 255: 0.560121    0.809784    3.392649    0.620925    0.059464    0.013677    0.629717    
#> 256: 0.559906    0.809939    3.392529    0.619957    0.059515    0.013694    0.629468    
#> 257: 0.559622    0.809786    3.392490    0.619849    0.059590    0.013680    0.629378    
#> 258: 0.559794    0.809513    3.392345    0.620218    0.059583    0.013634    0.629475    
#> 259: 0.559939    0.809448    3.392389    0.619669    0.059514    0.013585    0.629696    
#> 260: 0.559921    0.809736    3.392468    0.618011    0.059541    0.013529    0.629719    
#> 261: 0.559872    0.809475    3.392587    0.616900    0.059440    0.013491    0.629925    
#> 262: 0.560051    0.809605    3.392651    0.617423    0.059582    0.013482    0.629661    
#> 263: 0.559795    0.809720    3.392636    0.617390    0.059626    0.013486    0.629525    
#> 264: 0.559488    0.809914    3.392531    0.617351    0.059553    0.013461    0.629869    
#> 265: 0.559555    0.810004    3.392515    0.617120    0.059528    0.013475    0.630079    
#> 266: 0.560343    0.810111    3.392572    0.618369    0.059568    0.013497    0.630025    
#> 267: 0.561478    0.809888    3.392810    0.621357    0.059651    0.013500    0.630039    
#> 268: 0.562271    0.809603    3.392837    0.623955    0.059660    0.013483    0.629964    
#> 269: 0.563238    0.809379    3.392942    0.626432    0.059558    0.013466    0.630004    
#> 270: 0.564304    0.809582    3.392968    0.628457    0.059514    0.013425    0.629954    
#> 271: 0.564917    0.809614    3.392968    0.630121    0.059580    0.013399    0.630066    
#> 272: 0.565193    0.809564    3.392871    0.629692    0.059670    0.013398    0.630298    
#> 273: 0.565084    0.809746    3.392851    0.629331    0.059772    0.013388    0.630468    
#> 274: 0.564767    0.809883    3.392937    0.627588    0.059882    0.013350    0.630565    
#> 275: 0.564718    0.809995    3.392910    0.626878    0.059936    0.013319    0.630502    
#> 276: 0.564829    0.810077    3.392996    0.626630    0.059990    0.013265    0.630455    
#> 277: 0.564286    0.810334    3.393019    0.626038    0.059919    0.013226    0.630573    
#> 278: 0.564021    0.810389    3.393031    0.626086    0.059893    0.013193    0.630636    
#> 279: 0.563810    0.810297    3.392975    0.626651    0.059881    0.013215    0.630609    
#> 280: 0.563439    0.810515    3.392815    0.626834    0.059740    0.013251    0.630418    
#> 281: 0.563220    0.810753    3.392710    0.627219    0.059641    0.013291    0.630228    
#> 282: 0.563425    0.810928    3.392757    0.628167    0.059550    0.013325    0.630203    
#> 283: 0.563103    0.811175    3.392761    0.628549    0.059636    0.013353    0.630292    
#> 284: 0.562788    0.811112    3.392651    0.629195    0.059599    0.013371    0.630139    
#> 285: 0.562460    0.811149    3.392421    0.628941    0.059499    0.013416    0.630143    
#> 286: 0.561967    0.811367    3.392168    0.629052    0.059465    0.013413    0.630096    
#> 287: 0.561120    0.811744    3.391903    0.629382    0.059549    0.013390    0.630080    
#> 288: 0.560708    0.811711    3.391740    0.628661    0.059426    0.013397    0.630137    
#> 289: 0.560679    0.811774    3.391689    0.628181    0.059422    0.013386    0.629960    
#> 290: 0.560470    0.811832    3.391573    0.628018    0.059531    0.013362    0.629977    
#> 291: 0.560543    0.812105    3.391518    0.628971    0.059466    0.013364    0.629667    
#> 292: 0.560229    0.812338    3.391346    0.629899    0.059475    0.013364    0.629709    
#> 293: 0.560237    0.812567    3.391206    0.631169    0.059461    0.013347    0.629641    
#> 294: 0.560267    0.812713    3.391084    0.632227    0.059354    0.013341    0.629636    
#> 295: 0.560764    0.812530    3.391016    0.633531    0.059378    0.013310    0.629554    
#> 296: 0.560486    0.812551    3.390944    0.632559    0.059499    0.013288    0.629697    
#> 297: 0.560204    0.812693    3.390922    0.631784    0.059562    0.013265    0.629862    
#> 298: 0.559720    0.812648    3.390808    0.630521    0.059589    0.013240    0.629805    
#> 299: 0.559558    0.812618    3.390688    0.630385    0.059563    0.013236    0.629771    
#> 300: 0.559368    0.812445    3.390677    0.630834    0.059440    0.013260    0.629741    
#> 301: 0.559377    0.812281    3.390655    0.630496    0.059449    0.013242    0.629767    
#> 302: 0.559593    0.812216    3.390551    0.631089    0.059429    0.013233    0.629754    
#> 303: 0.559451    0.812251    3.390463    0.630774    0.059382    0.013225    0.629695    
#> 304: 0.559569    0.812526    3.390337    0.631010    0.059386    0.013212    0.629751    
#> 305: 0.559625    0.812428    3.390370    0.630869    0.059385    0.013213    0.629796    
#> 306: 0.559608    0.812321    3.390287    0.630933    0.059442    0.013197    0.629847    
#> 307: 0.560080    0.812291    3.390347    0.630980    0.059452    0.013207    0.630097    
#> 308: 0.560353    0.812225    3.390359    0.631854    0.059490    0.013195    0.630352    
#> 309: 0.560331    0.812043    3.390320    0.631910    0.059439    0.013186    0.630712    
#> 310: 0.560328    0.811953    3.390208    0.631457    0.059440    0.013177    0.630879    
#> 311: 0.560249    0.811942    3.390182    0.631445    0.059461    0.013180    0.630781    
#> 312: 0.560322    0.811787    3.390132    0.632193    0.059405    0.013209    0.630704    
#> 313: 0.560102    0.811586    3.390095    0.632135    0.059357    0.013231    0.630697    
#> 314: 0.559722    0.811673    3.389945    0.632175    0.059331    0.013262    0.630713    
#> 315: 0.559439    0.811876    3.389831    0.632589    0.059249    0.013289    0.630632    
#> 316: 0.559154    0.812064    3.389728    0.632586    0.059250    0.013300    0.630600    
#> 317: 0.559108    0.812245    3.389677    0.632527    0.059283    0.013327    0.630745    
#> 318: 0.559055    0.812466    3.389579    0.632339    0.059303    0.013354    0.630839    
#> 319: 0.559066    0.812675    3.389535    0.632682    0.059367    0.013375    0.630941    
#> 320: 0.558603    0.812823    3.389444    0.632104    0.059458    0.013387    0.631156    
#> 321: 0.558246    0.813151    3.389266    0.631982    0.059595    0.013402    0.631254    
#> 322: 0.557952    0.813215    3.389072    0.632399    0.059667    0.013403    0.631276    
#> 323: 0.557477    0.813343    3.388890    0.632543    0.059697    0.013412    0.631158    
#> 324: 0.557409    0.813522    3.388880    0.632266    0.059721    0.013418    0.631005    
#> 325: 0.557622    0.813685    3.388880    0.632380    0.059808    0.013428    0.630914    
#> 326: 0.557669    0.813572    3.388837    0.632283    0.059857    0.013420    0.630768    
#> 327: 0.557937    0.813562    3.388832    0.633153    0.059816    0.013428    0.630578    
#> 328: 0.558232    0.813634    3.388801    0.634113    0.059786    0.013420    0.630423    
#> 329: 0.558249    0.813624    3.388822    0.634845    0.059789    0.013436    0.630219    
#> 330: 0.558433    0.813595    3.388873    0.635885    0.059760    0.013442    0.630077    
#> 331: 0.558825    0.813654    3.388924    0.637003    0.059717    0.013426    0.630024    
#> 332: 0.559021    0.813584    3.389036    0.636341    0.059673    0.013411    0.630111    
#> 333: 0.559052    0.813550    3.389052    0.636071    0.059625    0.013396    0.630085    
#> 334: 0.559156    0.813519    3.388941    0.636537    0.059577    0.013394    0.630020    
#> 335: 0.559236    0.813650    3.388845    0.636962    0.059498    0.013396    0.629929    
#> 336: 0.558820    0.813807    3.388727    0.636091    0.059433    0.013404    0.629894    
#> 337: 0.558417    0.814139    3.388571    0.635940    0.059445    0.013416    0.629874    
#> 338: 0.558579    0.814275    3.388525    0.636833    0.059495    0.013426    0.629894    
#> 339: 0.558523    0.814474    3.388463    0.636480    0.059536    0.013435    0.629965    
#> 340: 0.558247    0.814382    3.388462    0.636080    0.059645    0.013445    0.630040    
#> 341: 0.558379    0.814376    3.388468    0.636050    0.059725    0.013447    0.630119    
#> 342: 0.558259    0.814263    3.388480    0.635674    0.059743    0.013449    0.630161    
#> 343: 0.558289    0.814216    3.388510    0.635800    0.059729    0.013444    0.630229    
#> 344: 0.558527    0.814042    3.388626    0.635880    0.059769    0.013444    0.630323    
#> 345: 0.558598    0.814079    3.388651    0.636296    0.059840    0.013444    0.630299    
#> 346: 0.558811    0.814119    3.388576    0.637409    0.059841    0.013442    0.630223    
#> 347: 0.558815    0.814108    3.388497    0.637593    0.059861    0.013444    0.630171    
#> 348: 0.558760    0.814223    3.388409    0.637927    0.059872    0.013434    0.630157    
#> 349: 0.558615    0.814261    3.388364    0.638402    0.059941    0.013430    0.630234    
#> 350: 0.558455    0.814139    3.388324    0.638539    0.059979    0.013432    0.630238    
#> 351: 0.558380    0.814108    3.388312    0.638443    0.059997    0.013433    0.630189    
#> 352: 0.558020    0.814149    3.388279    0.638131    0.060048    0.013433    0.630235    
#> 353: 0.557996    0.814235    3.388269    0.638031    0.060053    0.013442    0.630214    
#> 354: 0.558001    0.814274    3.388183    0.637746    0.060036    0.013447    0.630175    
#> 355: 0.558205    0.814174    3.388134    0.638017    0.060092    0.013427    0.630232    
#> 356: 0.558226    0.814144    3.388184    0.637708    0.060153    0.013409    0.630427    
#> 357: 0.558480    0.814163    3.388208    0.637833    0.060112    0.013373    0.630472    
#> 358: 0.558623    0.814244    3.388245    0.638020    0.060053    0.013370    0.630501    
#> 359: 0.558442    0.814458    3.388183    0.637597    0.060015    0.013376    0.630462    
#> 360: 0.558356    0.814583    3.388011    0.637512    0.060008    0.013378    0.630404    
#> 361: 0.558037    0.814565    3.387933    0.637266    0.059974    0.013384    0.630248    
#> 362: 0.557971    0.814528    3.387884    0.637494    0.059942    0.013385    0.630128    
#> 363: 0.557973    0.814539    3.387851    0.637605    0.059940    0.013404    0.630041    
#> 364: 0.557966    0.814589    3.387762    0.637849    0.059887    0.013421    0.630031    
#> 365: 0.557716    0.814666    3.387763    0.637704    0.059806    0.013465    0.630053    
#> 366: 0.557560    0.814780    3.387661    0.637635    0.059738    0.013504    0.630075    
#> 367: 0.557765    0.814879    3.387601    0.638743    0.059678    0.013543    0.630004    
#> 368: 0.557937    0.814848    3.387561    0.639213    0.059638    0.013571    0.629846    
#> 369: 0.557864    0.814846    3.387492    0.639555    0.059590    0.013604    0.629809    
#> 370: 0.557608    0.814805    3.387398    0.639718    0.059535    0.013642    0.629824    
#> 371: 0.557150    0.814840    3.387249    0.639468    0.059448    0.013660    0.629867    
#> 372: 0.556691    0.814970    3.387168    0.639603    0.059390    0.013689    0.629795    
#> 373: 0.556396    0.815240    3.387020    0.640083    0.059322    0.013720    0.629789    
#> 374: 0.556325    0.815342    3.386931    0.640126    0.059278    0.013742    0.629744    
#> 375: 0.555868    0.815430    3.386810    0.639664    0.059223    0.013761    0.629898    
#> 376: 0.555901    0.815594    3.386717    0.640303    0.059227    0.013783    0.629875    
#> 377: 0.555623    0.815762    3.386575    0.640422    0.059239    0.013810    0.629843    
#> 378: 0.555488    0.815955    3.386466    0.640545    0.059237    0.013822    0.629830    
#> 379: 0.555149    0.815939    3.386431    0.640297    0.059212    0.013831    0.629833    
#> 380: 0.554862    0.815985    3.386382    0.639722    0.059279    0.013847    0.629791    
#> 381: 0.554738    0.815981    3.386306    0.639673    0.059296    0.013866    0.629709    
#> 382: 0.554481    0.816044    3.386207    0.639638    0.059301    0.013881    0.629616    
#> 383: 0.554305    0.816099    3.386153    0.639433    0.059267    0.013893    0.629497    
#> 384: 0.554060    0.816146    3.386160    0.638993    0.059270    0.013897    0.629515    
#> 385: 0.554082    0.816163    3.386158    0.638753    0.059235    0.013914    0.629431    
#> 386: 0.554285    0.816230    3.386194    0.638594    0.059264    0.013910    0.629411    
#> 387: 0.554102    0.816381    3.386238    0.637734    0.059268    0.013914    0.629382    
#> 388: 0.554032    0.816481    3.386234    0.637569    0.059227    0.013913    0.629332    
#> 389: 0.554035    0.816403    3.386216    0.637530    0.059173    0.013912    0.629450    
#> 390: 0.553939    0.816457    3.386168    0.637192    0.059121    0.013906    0.629499    
#> 391: 0.553806    0.816518    3.386102    0.637060    0.059111    0.013913    0.629450    
#> 392: 0.553758    0.816576    3.386084    0.636984    0.059095    0.013910    0.629396    
#> 393: 0.553668    0.816479    3.386050    0.636979    0.059062    0.013918    0.629379    
#> 394: 0.553800    0.816409    3.386072    0.637433    0.059015    0.013915    0.629506    
#> 395: 0.554096    0.816479    3.386081    0.637905    0.059039    0.013902    0.629535    
#> 396: 0.554136    0.816523    3.386088    0.638182    0.059023    0.013902    0.629538    
#> 397: 0.554204    0.816521    3.386156    0.638147    0.059016    0.013908    0.629614    
#> 398: 0.554397    0.816518    3.386199    0.637948    0.059032    0.013901    0.629639    
#> 399: 0.554400    0.816509    3.386261    0.637552    0.059015    0.013886    0.629619    
#> 400: 0.554443    0.816565    3.386289    0.637354    0.059008    0.013874    0.629632    
#> 401: 0.554418    0.816681    3.386275    0.637218    0.058980    0.013880    0.629656    
#> 402: 0.554437    0.816844    3.386256    0.637212    0.058929    0.013890    0.629780    
#> 403: 0.554561    0.816930    3.386244    0.637276    0.058896    0.013884    0.629810    
#> 404: 0.554563    0.817074    3.386195    0.637485    0.058931    0.013881    0.629852    
#> 405: 0.554532    0.817143    3.386230    0.637723    0.058984    0.013876    0.629861    
#> 406: 0.554375    0.817190    3.386210    0.637489    0.059082    0.013889    0.629788    
#> 407: 0.554432    0.817149    3.386202    0.637569    0.059232    0.013877    0.629756    
#> 408: 0.554592    0.817220    3.386232    0.637482    0.059327    0.013863    0.629727    
#> 409: 0.554607    0.817163    3.386212    0.637297    0.059377    0.013845    0.629720    
#> 410: 0.554527    0.817127    3.386164    0.636883    0.059436    0.013830    0.629766    
#> 411: 0.554598    0.816986    3.386159    0.636748    0.059516    0.013811    0.629844    
#> 412: 0.554593    0.817037    3.386165    0.636647    0.059582    0.013804    0.629846    
#> 413: 0.554622    0.817041    3.386176    0.636377    0.059638    0.013787    0.629981    
#> 414: 0.554404    0.817027    3.386217    0.636473    0.059676    0.013780    0.630053    
#> 415: 0.554391    0.817009    3.386219    0.636597    0.059645    0.013767    0.630098    
#> 416: 0.554279    0.817070    3.386258    0.636103    0.059648    0.013750    0.630139    
#> 417: 0.554294    0.817037    3.386277    0.635869    0.059645    0.013732    0.630175    
#> 418: 0.554160    0.816949    3.386293    0.635668    0.059669    0.013721    0.630175    
#> 419: 0.554141    0.816969    3.386305    0.635535    0.059661    0.013707    0.630238    
#> 420: 0.554286    0.816960    3.386300    0.635703    0.059674    0.013685    0.630190    
#> 421: 0.554255    0.816995    3.386340    0.635770    0.059704    0.013678    0.630125    
#> 422: 0.554297    0.816955    3.386369    0.635599    0.059721    0.013671    0.630105    
#> 423: 0.554500    0.816881    3.386386    0.635950    0.059801    0.013669    0.630071    
#> 424: 0.554460    0.816884    3.386334    0.636195    0.059830    0.013668    0.630034    
#> 425: 0.554399    0.816977    3.386283    0.636323    0.059852    0.013680    0.630015    
#> 426: 0.554388    0.817108    3.386219    0.636821    0.059828    0.013698    0.630001    
#> 427: 0.554399    0.817166    3.386197    0.637105    0.059807    0.013701    0.629934    
#> 428: 0.554251    0.817242    3.386150    0.637277    0.059839    0.013696    0.629954    
#> 429: 0.554180    0.817274    3.386122    0.637393    0.059847    0.013681    0.629961    
#> 430: 0.553950    0.817331    3.386067    0.636877    0.059875    0.013676    0.629992    
#> 431: 0.553869    0.817347    3.386038    0.636706    0.059874    0.013678    0.629937    
#> 432: 0.553803    0.817452    3.386020    0.636769    0.059842    0.013687    0.629863    
#> 433: 0.553890    0.817533    3.386053    0.636997    0.059820    0.013709    0.629765    
#> 434: 0.553702    0.817499    3.386048    0.636683    0.059843    0.013713    0.629695    
#> 435: 0.553633    0.817456    3.386035    0.636516    0.059820    0.013714    0.629663    
#> 436: 0.553480    0.817451    3.386039    0.636067    0.059818    0.013707    0.629702    
#> 437: 0.553665    0.817396    3.386070    0.636278    0.059802    0.013703    0.629689    
#> 438: 0.553686    0.817452    3.386062    0.636208    0.059780    0.013690    0.629637    
#> 439: 0.553647    0.817519    3.386054    0.635923    0.059784    0.013674    0.629559    
#> 440: 0.553679    0.817529    3.386073    0.635518    0.059788    0.013654    0.629471    
#> 441: 0.553841    0.817434    3.386136    0.635386    0.059821    0.013641    0.629428    
#> 442: 0.553835    0.817478    3.386146    0.635571    0.059865    0.013631    0.629363    
#> 443: 0.553891    0.817507    3.386136    0.635736    0.059859    0.013620    0.629307    
#> 444: 0.553849    0.817593    3.386059    0.635919    0.059853    0.013607    0.629266    
#> 445: 0.553742    0.817679    3.386009    0.636272    0.059846    0.013596    0.629308    
#> 446: 0.553566    0.817758    3.385970    0.636335    0.059814    0.013582    0.629354    
#> 447: 0.553628    0.817742    3.386002    0.636519    0.059762    0.013579    0.629371    
#> 448: 0.553633    0.817720    3.386028    0.636387    0.059788    0.013576    0.629338    
#> 449: 0.553635    0.817740    3.386113    0.636092    0.059733    0.013571    0.629419    
#> 450: 0.553641    0.817701    3.386151    0.635679    0.059690    0.013557    0.629504    
#> 451: 0.553744    0.817681    3.386177    0.635350    0.059683    0.013541    0.629627    
#> 452: 0.553906    0.817624    3.386239    0.635037    0.059693    0.013528    0.629632    
#> 453: 0.553953    0.817558    3.386261    0.634730    0.059705    0.013516    0.629607    
#> 454: 0.554135    0.817604    3.386284    0.635235    0.059669    0.013510    0.629567    
#> 455: 0.554447    0.817555    3.386301    0.636134    0.059607    0.013506    0.629566    
#> 456: 0.554464    0.817489    3.386322    0.636232    0.059586    0.013506    0.629587    
#> 457: 0.554588    0.817394    3.386387    0.636466    0.059595    0.013502    0.629582    
#> 458: 0.554689    0.817404    3.386450    0.636630    0.059565    0.013493    0.629580    
#> 459: 0.554557    0.817450    3.386464    0.636474    0.059557    0.013485    0.629601    
#> 460: 0.554318    0.817472    3.386409    0.636015    0.059565    0.013490    0.629620    
#> 461: 0.554274    0.817520    3.386411    0.635967    0.059537    0.013500    0.629621    
#> 462: 0.554239    0.817573    3.386443    0.635965    0.059521    0.013504    0.629573    
#> 463: 0.554245    0.817619    3.386450    0.635861    0.059514    0.013493    0.629596    
#> 464: 0.554353    0.817653    3.386436    0.635980    0.059482    0.013488    0.629598    
#> 465: 0.554447    0.817534    3.386443    0.636232    0.059447    0.013489    0.629575    
#> 466: 0.554396    0.817542    3.386418    0.636041    0.059435    0.013483    0.629556    
#> 467: 0.554256    0.817514    3.386471    0.635786    0.059425    0.013471    0.629523    
#> 468: 0.554305    0.817513    3.386514    0.635700    0.059421    0.013458    0.629582    
#> 469: 0.554393    0.817560    3.386551    0.635432    0.059413    0.013455    0.629660    
#> 470: 0.554346    0.817583    3.386526    0.635480    0.059412    0.013451    0.629745    
#> 471: 0.554267    0.817618    3.386500    0.635327    0.059406    0.013437    0.629809    
#> 472: 0.554169    0.817621    3.386504    0.635095    0.059383    0.013427    0.629851    
#> 473: 0.554041    0.817595    3.386499    0.634647    0.059354    0.013416    0.629811    
#> 474: 0.553996    0.817564    3.386493    0.634401    0.059378    0.013415    0.629811    
#> 475: 0.554163    0.817636    3.386498    0.634531    0.059344    0.013416    0.629770    
#> 476: 0.554143    0.817634    3.386493    0.634546    0.059310    0.013415    0.629759    
#> 477: 0.554167    0.817604    3.386539    0.634440    0.059258    0.013422    0.629701    
#> 478: 0.554101    0.817574    3.386575    0.634248    0.059201    0.013426    0.629713    
#> 479: 0.554243    0.817556    3.386600    0.634463    0.059173    0.013430    0.629690    
#> 480: 0.554307    0.817558    3.386616    0.634709    0.059173    0.013442    0.629738    
#> 481: 0.554243    0.817529    3.386600    0.634868    0.059157    0.013446    0.629736    
#> 482: 0.554223    0.817548    3.386562    0.635325    0.059143    0.013445    0.629746    
#> 483: 0.554042    0.817510    3.386531    0.635499    0.059141    0.013444    0.629784    
#> 484: 0.553840    0.817438    3.386521    0.635113    0.059155    0.013441    0.629817    
#> 485: 0.553813    0.817460    3.386490    0.635225    0.059156    0.013445    0.629818    
#> 486: 0.553799    0.817448    3.386507    0.635193    0.059175    0.013441    0.629796    
#> 487: 0.553860    0.817443    3.386550    0.635205    0.059182    0.013440    0.629743    
#> 488: 0.553808    0.817476    3.386550    0.635170    0.059182    0.013451    0.629666    
#> 489: 0.553777    0.817502    3.386534    0.635180    0.059185    0.013461    0.629603    
#> 490: 0.553803    0.817535    3.386531    0.635305    0.059146    0.013463    0.629555    
#> 491: 0.553751    0.817594    3.386549    0.635196    0.059122    0.013471    0.629465    
#> 492: 0.553758    0.817654    3.386530    0.635439    0.059149    0.013482    0.629429    
#> 493: 0.553678    0.817645    3.386530    0.635497    0.059141    0.013499    0.629426    
#> 494: 0.553809    0.817678    3.386517    0.635483    0.059155    0.013500    0.629411    
#> 495: 0.553904    0.817715    3.386511    0.635535    0.059135    0.013512    0.629406    
#> 496: 0.554018    0.817760    3.386491    0.635523    0.059106    0.013512    0.629418    
#> 497: 0.553992    0.817817    3.386479    0.635763    0.059091    0.013521    0.629422    
#> 498: 0.553955    0.817783    3.386469    0.635686    0.059065    0.013522    0.629417    
#> 499: 0.553990    0.817804    3.386445    0.635813    0.059076    0.013519    0.629354    
#> 500: 0.554005    0.817776    3.386418    0.635769    0.059074    0.013516    0.629329    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.315306    0.978431    3.450355    0.392401    0.090074    0.016800    1.778644    
#> 002: 0.267527    0.964826    3.461169    0.372781    0.085570    0.015968    1.117554    
#> 003: 0.406200    0.933113    3.484083    0.354142    0.087865    0.015170    0.857088    
#> 004: 0.347969    0.961910    3.465779    0.336435    0.083472    0.014411    0.776024    
#> 005: 0.388774    0.956183    3.460845    0.319613    0.079298    0.013691    0.725318    
#> 006: 0.382145    0.968039    3.448611    0.336461    0.075333    0.013006    0.668528    
#> 007: 0.326802    0.962806    3.442379    0.338503    0.071566    0.014069    0.689490    
#> 008: 0.330160    0.983102    3.436245    0.336394    0.067988    0.014232    0.695785    
#> 009: 0.293567    0.953235    3.426550    0.351656    0.064589    0.013520    0.684246    
#> 010: 0.280744    0.985932    3.421956    0.348940    0.061423    0.014693    0.693356    
#> 011: 0.335038    0.987286    3.429318    0.421093    0.058352    0.018904    0.677602    
#> 012: 0.353528    0.984130    3.439384    0.400038    0.059503    0.017959    0.664855    
#> 013: 0.293032    0.971377    3.426657    0.380036    0.059933    0.017243    0.689483    
#> 014: 0.329103    0.990878    3.429375    0.361034    0.070900    0.016380    0.697965    
#> 015: 0.346918    0.989336    3.436937    0.383058    0.067355    0.016257    0.684561    
#> 016: 0.366033    1.008529    3.440155    0.363905    0.063987    0.015445    0.688108    
#> 017: 0.334616    1.015188    3.449555    0.383359    0.064725    0.014672    0.677608    
#> 018: 0.380944    0.991368    3.442102    0.364192    0.063403    0.016920    0.672013    
#> 019: 0.344960    0.979193    3.440499    0.345982    0.060233    0.018753    0.671394    
#> 020: 0.301452    0.980614    3.441477    0.328683    0.057221    0.020020    0.671874    
#> 021: 0.348269    0.976541    3.442278    0.383477    0.054360    0.021627    0.656431    
#> 022: 0.368158    0.974676    3.458750    0.364303    0.051642    0.020545    0.662693    
#> 023: 0.408819    0.987985    3.457465    0.380026    0.052576    0.019518    0.688041    
#> 024: 0.403371    1.001224    3.457172    0.361025    0.049947    0.021249    0.670642    
#> 025: 0.371249    0.992561    3.449323    0.342974    0.054416    0.020187    0.684795    
#> 026: 0.361506    1.020336    3.449446    0.325825    0.068464    0.019177    0.669996    
#> 027: 0.339664    1.028220    3.434101    0.364820    0.065040    0.018218    0.686993    
#> 028: 0.351872    1.014042    3.421521    0.390483    0.061788    0.017553    0.662138    
#> 029: 0.349517    1.019686    3.415320    0.442466    0.067221    0.019900    0.667928    
#> 030: 0.350551    1.025132    3.421887    0.461714    0.063860    0.020374    0.666973    
#> 031: 0.288698    1.013170    3.420055    0.440667    0.060667    0.019355    0.673073    
#> 032: 0.299022    0.998277    3.421454    0.418634    0.057633    0.018388    0.653799    
#> 033: 0.289479    1.015735    3.413942    0.397702    0.054752    0.018158    0.659136    
#> 034: 0.334345    1.026769    3.428539    0.393022    0.060380    0.017250    0.676236    
#> 035: 0.345219    0.998404    3.432694    0.373371    0.057361    0.016388    0.660449    
#> 036: 0.331152    1.015372    3.426784    0.380251    0.057889    0.015841    0.669023    
#> 037: 0.314227    1.007462    3.430704    0.410135    0.054995    0.019308    0.683853    
#> 038: 0.367189    0.997788    3.435335    0.389629    0.052245    0.020241    0.677965    
#> 039: 0.384305    0.973262    3.447028    0.399505    0.052583    0.019240    0.666341    
#> 040: 0.341922    0.999378    3.432969    0.470834    0.063278    0.018278    0.660524    
#> 041: 0.354064    1.003619    3.427872    0.447293    0.060114    0.017364    0.665667    
#> 042: 0.351158    0.993592    3.427222    0.424928    0.057109    0.016496    0.660616    
#> 043: 0.340047    1.009199    3.428200    0.403682    0.054253    0.016420    0.651690    
#> 044: 0.296320    1.016704    3.426241    0.383498    0.052769    0.015833    0.661068    
#> 045: 0.330798    1.021751    3.423268    0.397953    0.050130    0.015041    0.662116    
#> 046: 0.325870    0.999617    3.430592    0.378055    0.053875    0.016553    0.664462    
#> 047: 0.327615    1.013734    3.428010    0.359152    0.054488    0.015725    0.666044    
#> 048: 0.318312    1.004533    3.424637    0.343487    0.066277    0.014939    0.680092    
#> 049: 0.318774    1.011766    3.433147    0.336799    0.062963    0.014192    0.677098    
#> 050: 0.371025    0.979890    3.441918    0.345485    0.062865    0.016178    0.693215    
#> 051: 0.382457    0.972934    3.435783    0.415679    0.059722    0.016131    0.682857    
#> 052: 0.425259    0.984679    3.448842    0.495438    0.056736    0.018468    0.672762    
#> 053: 0.391929    0.980410    3.445930    0.470666    0.055856    0.020819    0.662139    
#> 054: 0.307774    0.989680    3.438268    0.447133    0.059440    0.021699    0.682144    
#> 055: 0.350315    0.991170    3.441764    0.424776    0.057831    0.020615    0.690734    
#> 056: 0.355709    0.988891    3.439246    0.403537    0.054940    0.019584    0.680670    
#> 057: 0.322449    0.996126    3.444015    0.383360    0.052193    0.019754    0.703490    
#> 058: 0.354592    0.996420    3.430248    0.364192    0.053476    0.018766    0.703261    
#> 059: 0.346270    0.959862    3.441648    0.397728    0.050802    0.023448    0.702875    
#> 060: 0.348836    0.946170    3.452572    0.377841    0.048262    0.025165    0.689772    
#> 061: 0.441462    0.966203    3.466777    0.426030    0.053443    0.025864    0.708650    
#> 062: 0.400901    0.990797    3.451279    0.404729    0.052135    0.024570    0.715060    
#> 063: 0.452117    0.956279    3.463606    0.415653    0.049529    0.023342    0.708317    
#> 064: 0.354607    0.985304    3.452250    0.394870    0.063635    0.022175    0.681880    
#> 065: 0.366130    0.980344    3.429532    0.383851    0.060454    0.021066    0.661009    
#> 066: 0.345417    1.011662    3.433747    0.397383    0.057431    0.020013    0.666152    
#> 067: 0.335234    1.005455    3.434676    0.377514    0.054559    0.019012    0.660879    
#> 068: 0.308754    1.001526    3.434636    0.358638    0.053293    0.018061    0.674165    
#> 069: 0.294855    1.016402    3.417202    0.378882    0.058695    0.025135    0.682827    
#> 070: 0.311777    1.001404    3.425350    0.424007    0.056103    0.028065    0.665456    
#> 071: 0.275381    1.019370    3.405608    0.402807    0.053298    0.026662    0.675992    
#> 072: 0.280733    0.999154    3.407418    0.442779    0.050633    0.025329    0.676442    
#> 073: 0.297309    1.016594    3.418481    0.440751    0.048102    0.024062    0.677559    
#> 074: 0.297181    1.007270    3.411506    0.418714    0.045696    0.024986    0.669256    
#> 075: 0.333237    0.999749    3.436749    0.397778    0.043412    0.028218    0.667070    
#> 076: 0.364745    1.012703    3.449123    0.433901    0.041241    0.026807    0.670695    
#> 077: 0.388722    0.987553    3.456919    0.445059    0.041867    0.025770    0.681755    
#> 078: 0.370255    0.969739    3.463590    0.422806    0.044662    0.024482    0.669496    
#> 079: 0.392143    0.983642    3.460506    0.411947    0.049862    0.024835    0.672751    
#> 080: 0.375523    0.981398    3.446505    0.470500    0.047369    0.024762    0.690039    
#> 081: 0.365877    0.997273    3.447103    0.465876    0.045000    0.026606    0.656292    
#> 082: 0.371276    0.990487    3.447796    0.492167    0.046347    0.025275    0.666206    
#> 083: 0.355361    1.017629    3.439796    0.467559    0.049751    0.024012    0.662569    
#> 084: 0.378789    1.013721    3.441155    0.444181    0.055194    0.025546    0.673179    
#> 085: 0.351062    1.017704    3.452387    0.421972    0.052434    0.025583    0.666044    
#> 086: 0.374701    0.998453    3.442694    0.400873    0.049812    0.025857    0.664195    
#> 087: 0.356936    0.973686    3.437761    0.380830    0.050728    0.024564    0.679677    
#> 088: 0.307388    0.973655    3.455008    0.361788    0.049024    0.026648    0.679474    
#> 089: 0.341245    0.992854    3.437544    0.351620    0.051234    0.025316    0.684211    
#> 090: 0.340029    0.987449    3.428080    0.384352    0.048672    0.026938    0.675698    
#> 091: 0.332972    0.968391    3.424696    0.383929    0.053279    0.025797    0.665378    
#> 092: 0.340541    0.996676    3.426685    0.374541    0.050615    0.025915    0.677364    
#> 093: 0.333750    0.985171    3.431331    0.364573    0.048085    0.024619    0.674956    
#> 094: 0.360248    1.004029    3.434922    0.431791    0.046393    0.023388    0.656528    
#> 095: 0.344984    1.004717    3.438315    0.410202    0.048115    0.027515    0.651990    
#> 096: 0.282553    1.009818    3.421586    0.389692    0.045709    0.026139    0.652921    
#> 097: 0.345208    1.013099    3.425671    0.437091    0.043424    0.024832    0.653903    
#> 098: 0.348627    1.021244    3.426764    0.435911    0.041252    0.023590    0.657013    
#> 099: 0.311604    0.998013    3.411428    0.447474    0.039190    0.022411    0.679897    
#> 100: 0.330352    1.006745    3.428441    0.475393    0.041280    0.021290    0.684995    
#> 101: 0.308740    0.997875    3.405726    0.451623    0.041925    0.020226    0.664897    
#> 102: 0.324864    0.991490    3.417174    0.436463    0.039828    0.021466    0.670638    
#> 103: 0.370306    1.004239    3.422935    0.476789    0.041911    0.021648    0.668999    
#> 104: 0.357150    1.010273    3.433270    0.544294    0.039815    0.021637    0.666834    
#> 105: 0.335999    1.007708    3.431309    0.517079    0.044038    0.020555    0.657886    
#> 106: 0.317380    1.008121    3.415805    0.491225    0.043726    0.019528    0.657336    
#> 107: 0.324196    1.012540    3.417792    0.466664    0.041540    0.018551    0.662688    
#> 108: 0.331693    0.998097    3.427629    0.443331    0.047331    0.020829    0.670128    
#> 109: 0.328157    0.983427    3.441774    0.473100    0.046138    0.021288    0.672680    
#> 110: 0.367422    0.990575    3.433122    0.488052    0.044316    0.024009    0.652901    
#> 111: 0.388108    0.994392    3.441306    0.463650    0.044179    0.023418    0.651713    
#> 112: 0.397542    0.976280    3.441867    0.440467    0.051584    0.025674    0.659569    
#> 113: 0.369456    1.000112    3.448472    0.418444    0.049072    0.024390    0.651948    
#> 114: 0.353247    1.001589    3.437268    0.412526    0.056059    0.023171    0.650896    
#> 115: 0.366251    0.985860    3.431145    0.432802    0.053624    0.022012    0.656359    
#> 116: 0.355115    0.994772    3.433492    0.425185    0.050943    0.020912    0.678874    
#> 117: 0.355826    1.001657    3.448817    0.450469    0.055739    0.019866    0.664387    
#> 118: 0.394280    0.978928    3.459244    0.427946    0.063348    0.018873    0.667821    
#> 119: 0.375451    0.974701    3.451503    0.406548    0.060181    0.024158    0.672077    
#> 120: 0.314685    0.956398    3.445448    0.386221    0.057172    0.022950    0.679599    
#> 121: 0.351227    0.993303    3.430310    0.423111    0.066336    0.021803    0.682558    
#> 122: 0.357938    0.974419    3.440630    0.419962    0.063019    0.026250    0.664063    
#> 123: 0.349393    1.016093    3.424733    0.398964    0.059868    0.024937    0.685370    
#> 124: 0.310111    1.036588    3.416111    0.379016    0.056875    0.023691    0.685843    
#> 125: 0.313379    1.040519    3.409153    0.368715    0.068394    0.022506    0.673831    
#> 126: 0.290421    1.031656    3.406823    0.379845    0.067813    0.021381    0.684806    
#> 127: 0.348185    1.015982    3.416599    0.404926    0.069480    0.020312    0.694265    
#> 128: 0.345637    0.982088    3.434880    0.384680    0.066006    0.019296    0.698649    
#> 129: 0.341153    1.004259    3.433475    0.400369    0.079849    0.018331    0.685081    
#> 130: 0.361041    1.014756    3.428485    0.380351    0.075857    0.017415    0.687514    
#> 131: 0.319187    1.009641    3.420638    0.361333    0.072064    0.021330    0.680717    
#> 132: 0.282843    1.015328    3.408883    0.356839    0.068461    0.021184    0.688688    
#> 133: 0.274810    1.026485    3.407704    0.400157    0.065038    0.020124    0.685895    
#> 134: 0.275556    1.015300    3.406611    0.409513    0.061786    0.019118    0.677782    
#> 135: 0.311517    0.995111    3.423476    0.389037    0.058696    0.018162    0.658491    
#> 136: 0.353389    0.987867    3.431710    0.435850    0.055762    0.017654    0.660257    
#> 137: 0.393602    0.990503    3.443295    0.492953    0.052974    0.020597    0.681172    
#> 138: 0.385619    0.990721    3.441266    0.468305    0.050325    0.019567    0.681363    
#> 139: 0.377101    0.993721    3.455443    0.444890    0.051547    0.019315    0.686651    
#> 140: 0.392383    0.992323    3.453865    0.423991    0.054052    0.020046    0.686197    
#> 141: 0.329054    0.979094    3.443488    0.402791    0.051349    0.019044    0.681232    
#> 142: 0.353688    0.961288    3.453920    0.382652    0.061517    0.018091    0.679934    
#> 143: 0.301034    0.995830    3.443141    0.363519    0.063446    0.017187    0.696145    
#> 144: 0.357590    0.995287    3.456982    0.345343    0.060274    0.016328    0.672375    
#> 145: 0.333822    1.009465    3.429953    0.328076    0.057260    0.015511    0.677547    
#> 146: 0.314186    0.999550    3.438784    0.311672    0.064108    0.017787    0.686463    
#> 147: 0.317571    1.003921    3.431247    0.296089    0.060903    0.020097    0.664275    
#> 148: 0.303723    1.022711    3.434185    0.324002    0.057857    0.021969    0.663982    
#> 149: 0.331889    1.011333    3.434797    0.397834    0.054965    0.024933    0.662940    
#> 150: 0.361212    1.004626    3.420412    0.425955    0.052216    0.023686    0.666499    
#> 151: 0.301501    1.021389    3.419702    0.422372    0.051305    0.022502    0.672860    
#> 152: 0.292390    1.022032    3.416656    0.381249    0.057877    0.020535    0.667269    
#> 153: 0.304355    1.013352    3.430716    0.382439    0.051467    0.026267    0.673230    
#> 154: 0.375075    1.001640    3.436889    0.414758    0.045389    0.026817    0.679498    
#> 155: 0.333490    0.979217    3.435584    0.395674    0.039284    0.024953    0.679554    
#> 156: 0.366639    0.988253    3.442261    0.452822    0.032884    0.031481    0.701577    
#> 157: 0.351146    0.985161    3.431033    0.511185    0.031533    0.032930    0.684482    
#> 158: 0.349618    0.994675    3.429244    0.450427    0.034035    0.032682    0.662087    
#> 159: 0.314698    1.010154    3.432040    0.409245    0.040405    0.033341    0.673266    
#> 160: 0.348786    0.972978    3.444868    0.406375    0.047337    0.031018    0.662366    
#> 161: 0.351332    0.986920    3.439057    0.433522    0.052908    0.035105    0.669162    
#> 162: 0.369082    0.988069    3.434952    0.530106    0.039938    0.033327    0.678277    
#> 163: 0.355101    0.991952    3.424342    0.498752    0.047224    0.033169    0.673475    
#> 164: 0.353798    1.001545    3.426190    0.449245    0.043395    0.029198    0.659157    
#> 165: 0.363640    1.001401    3.428961    0.460343    0.043785    0.023356    0.683759    
#> 166: 0.388873    1.019196    3.431652    0.612338    0.046484    0.018685    0.684873    
#> 167: 0.363767    1.029161    3.433574    0.476740    0.047030    0.022430    0.681109    
#> 168: 0.394130    1.015827    3.448716    0.475410    0.043142    0.025313    0.654723    
#> 169: 0.435388    1.016641    3.444072    0.518122    0.042102    0.023144    0.659495    
#> 170: 0.428068    0.993705    3.456903    0.581509    0.042313    0.024477    0.652380    
#> 171: 0.398640    0.990260    3.448904    0.486006    0.041985    0.019528    0.655754    
#> 172: 0.370555    1.021279    3.443960    0.440671    0.040916    0.020693    0.655015    
#> 173: 0.365803    1.022258    3.425979    0.382818    0.039338    0.019075    0.657488    
#> 174: 0.378813    1.010133    3.438984    0.515810    0.035971    0.016968    0.673922    
#> 175: 0.367545    1.011170    3.431251    0.421589    0.046089    0.016178    0.682450    
#> 176: 0.351545    1.024192    3.434704    0.445722    0.048287    0.018797    0.661621    
#> 177: 0.354435    1.003453    3.437202    0.432427    0.048692    0.020203    0.673308    
#> 178: 0.336983    1.000861    3.429947    0.399125    0.050987    0.017333    0.670109    
#> 179: 0.399604    1.013699    3.432381    0.461497    0.052273    0.018807    0.669926    
#> 180: 0.373448    1.005849    3.440343    0.468019    0.058037    0.019355    0.670569    
#> 181: 0.351762    0.991760    3.424157    0.393583    0.048488    0.018006    0.675904    
#> 182: 0.330054    1.007437    3.415206    0.375166    0.056216    0.013444    0.692432    
#> 183: 0.332155    1.037756    3.415379    0.388245    0.045740    0.016129    0.686063    
#> 184: 0.345969    0.992494    3.425265    0.458654    0.047306    0.020456    0.668223    
#> 185: 0.327230    1.028840    3.426854    0.364353    0.048306    0.019960    0.678838    
#> 186: 0.308721    1.047971    3.413663    0.354714    0.054205    0.016284    0.695153    
#> 187: 0.322725    1.002938    3.432766    0.443722    0.040114    0.017900    0.685714    
#> 188: 0.328537    1.011926    3.431358    0.410235    0.037403    0.019101    0.680678    
#> 189: 0.333861    1.016611    3.441391    0.368973    0.041847    0.021371    0.667426    
#> 190: 0.318660    1.012094    3.443032    0.356600    0.044841    0.019555    0.678177    
#> 191: 0.300509    1.011134    3.422774    0.345135    0.046596    0.019009    0.658605    
#> 192: 0.268714    1.029865    3.407167    0.371010    0.042537    0.017260    0.677337    
#> 193: 0.291153    1.044703    3.406602    0.414619    0.050775    0.015084    0.662365    
#> 194: 0.314054    1.024646    3.410717    0.429631    0.051456    0.017673    0.681935    
#> 195: 0.274141    1.029725    3.401292    0.463520    0.040243    0.018946    0.670971    
#> 196: 0.282197    1.016172    3.405961    0.416870    0.046321    0.017422    0.681904    
#> 197: 0.288157    1.030114    3.421844    0.380393    0.048845    0.016518    0.694668    
#> 198: 0.324739    1.020351    3.418354    0.373037    0.050593    0.015034    0.668152    
#> 199: 0.302446    1.005940    3.419742    0.340302    0.045817    0.015922    0.685921    
#> 200: 0.319909    0.987969    3.433722    0.366065    0.048217    0.016693    0.694455    
#> 201: 0.314259    0.991907    3.431589    0.365324    0.046864    0.015455    0.684078    
#> 202: 0.318865    0.993355    3.431561    0.371490    0.046625    0.015423    0.682784    
#> 203: 0.326631    0.994418    3.430422    0.354628    0.048798    0.015573    0.679295    
#> 204: 0.328246    0.991419    3.433325    0.361509    0.050883    0.015342    0.678077    
#> 205: 0.328365    0.998423    3.433124    0.366707    0.053080    0.015541    0.677807    
#> 206: 0.332432    1.003952    3.434505    0.374416    0.052507    0.015695    0.680657    
#> 207: 0.329371    1.006413    3.433165    0.369461    0.051188    0.015580    0.679806    
#> 208: 0.328361    1.007753    3.432305    0.371892    0.050725    0.015680    0.677794    
#> 209: 0.331156    1.006253    3.431477    0.375934    0.049907    0.016025    0.677400    
#> 210: 0.332622    1.004463    3.431712    0.377855    0.049895    0.016002    0.675637    
#> 211: 0.335651    1.004636    3.432758    0.375843    0.049771    0.016057    0.674542    
#> 212: 0.340144    1.003090    3.433543    0.376713    0.049445    0.016103    0.675010    
#> 213: 0.342731    0.999880    3.434590    0.376728    0.049065    0.016296    0.676644    
#> 214: 0.343492    0.999062    3.434688    0.377493    0.049025    0.016503    0.676775    
#> 215: 0.344104    0.999509    3.435293    0.379883    0.048809    0.016888    0.676761    
#> 216: 0.345941    0.997575    3.435791    0.379674    0.048241    0.017041    0.680727    
#> 217: 0.346260    0.997212    3.436227    0.379399    0.047330    0.017270    0.680953    
#> 218: 0.346672    0.996912    3.435997    0.380997    0.047168    0.017408    0.680719    
#> 219: 0.345702    0.996875    3.434856    0.384035    0.047277    0.017423    0.679626    
#> 220: 0.344349    0.997638    3.434716    0.384843    0.047543    0.017574    0.678301    
#> 221: 0.344575    0.997327    3.434685    0.387396    0.047611    0.017615    0.677124    
#> 222: 0.345641    0.996479    3.434845    0.391199    0.047214    0.017911    0.676401    
#> 223: 0.346348    0.996030    3.435176    0.392124    0.047103    0.018215    0.675319    
#> 224: 0.348871    0.996065    3.435902    0.392877    0.047065    0.018393    0.675014    
#> 225: 0.348709    0.994896    3.436538    0.395976    0.047051    0.018548    0.675347    
#> 226: 0.349422    0.993622    3.436473    0.396743    0.046814    0.018619    0.675469    
#> 227: 0.348484    0.993546    3.436398    0.398598    0.047011    0.018599    0.675831    
#> 228: 0.348679    0.993976    3.436266    0.402353    0.046724    0.018731    0.675462    
#> 229: 0.348031    0.993719    3.436101    0.403086    0.046849    0.018748    0.675135    
#> 230: 0.348571    0.993407    3.436058    0.402630    0.046925    0.018676    0.675372    
#> 231: 0.348189    0.993712    3.436305    0.402515    0.046980    0.018749    0.675327    
#> 232: 0.347487    0.993411    3.436225    0.402597    0.047021    0.018758    0.675160    
#> 233: 0.346025    0.992931    3.436081    0.402612    0.046997    0.018845    0.675154    
#> 234: 0.345526    0.992703    3.436157    0.402203    0.046999    0.018853    0.675250    
#> 235: 0.345802    0.992344    3.436070    0.402714    0.046699    0.018828    0.675105    
#> 236: 0.345180    0.992887    3.435807    0.400256    0.046581    0.018848    0.675101    
#> 237: 0.344875    0.993225    3.435702    0.400606    0.046706    0.018905    0.675232    
#> 238: 0.344681    0.993637    3.435557    0.401781    0.046781    0.018985    0.675759    
#> 239: 0.344413    0.993992    3.435292    0.402208    0.046683    0.019054    0.676222    
#> 240: 0.344545    0.993728    3.435648    0.400765    0.046894    0.019063    0.675754    
#> 241: 0.345283    0.993297    3.436097    0.400046    0.047034    0.019146    0.675529    
#> 242: 0.345207    0.992850    3.436148    0.398805    0.047160    0.019240    0.675728    
#> 243: 0.344517    0.993397    3.435989    0.397075    0.047320    0.019230    0.676176    
#> 244: 0.344084    0.993660    3.435950    0.398248    0.047336    0.019275    0.676329    
#> 245: 0.343550    0.993662    3.435791    0.399696    0.047244    0.019277    0.676755    
#> 246: 0.343965    0.993641    3.436000    0.400468    0.047046    0.019327    0.676870    
#> 247: 0.343444    0.993792    3.436002    0.400056    0.046981    0.019437    0.676773    
#> 248: 0.342922    0.994330    3.435667    0.400063    0.047144    0.019479    0.676814    
#> 249: 0.342804    0.994737    3.435603    0.399910    0.047147    0.019481    0.676957    
#> 250: 0.343153    0.995208    3.435686    0.399765    0.047074    0.019522    0.677260    
#> 251: 0.343631    0.995648    3.435784    0.400616    0.047036    0.019494    0.677452    
#> 252: 0.343917    0.995888    3.436137    0.400922    0.046932    0.019503    0.677782    
#> 253: 0.343986    0.996087    3.436108    0.400728    0.046967    0.019537    0.677647    
#> 254: 0.344409    0.996486    3.436047    0.400073    0.046952    0.019594    0.677868    
#> 255: 0.344315    0.996670    3.436172    0.398468    0.047029    0.019639    0.677835    
#> 256: 0.344349    0.996621    3.436223    0.397719    0.047107    0.019718    0.677629    
#> 257: 0.344315    0.996298    3.436219    0.397815    0.047195    0.019738    0.677339    
#> 258: 0.344219    0.995758    3.436223    0.397155    0.047213    0.019695    0.677316    
#> 259: 0.344566    0.995490    3.436218    0.397324    0.047386    0.019638    0.677196    
#> 260: 0.344663    0.995854    3.436138    0.397884    0.047539    0.019555    0.676971    
#> 261: 0.345150    0.995888    3.436166    0.399425    0.047728    0.019518    0.676774    
#> 262: 0.345458    0.996003    3.436407    0.398940    0.047871    0.019512    0.676633    
#> 263: 0.345535    0.996271    3.436661    0.398562    0.047953    0.019581    0.676469    
#> 264: 0.345281    0.996439    3.436561    0.398951    0.047952    0.019595    0.676372    
#> 265: 0.345048    0.996731    3.436468    0.398473    0.047991    0.019595    0.676448    
#> 266: 0.344746    0.996856    3.436429    0.397969    0.047999    0.019561    0.676524    
#> 267: 0.344825    0.996948    3.436449    0.398050    0.048079    0.019529    0.676624    
#> 268: 0.345184    0.997098    3.436314    0.397932    0.048230    0.019511    0.676605    
#> 269: 0.345920    0.997057    3.436316    0.398794    0.048344    0.019490    0.676521    
#> 270: 0.346095    0.997174    3.436196    0.399075    0.048352    0.019444    0.676355    
#> 271: 0.346120    0.997250    3.436100    0.399146    0.048410    0.019400    0.676325    
#> 272: 0.346156    0.997026    3.436094    0.399652    0.048439    0.019352    0.676462    
#> 273: 0.345789    0.997266    3.436048    0.399961    0.048553    0.019326    0.676718    
#> 274: 0.345579    0.997345    3.435953    0.400161    0.048677    0.019240    0.676722    
#> 275: 0.345405    0.997406    3.435801    0.400732    0.048839    0.019169    0.676431    
#> 276: 0.344942    0.997604    3.435783    0.400488    0.048853    0.019136    0.676439    
#> 277: 0.344675    0.997718    3.435854    0.400517    0.048769    0.019132    0.676233    
#> 278: 0.344471    0.997717    3.435911    0.400633    0.048765    0.019109    0.676091    
#> 279: 0.344437    0.997598    3.435849    0.400949    0.048725    0.019141    0.676051    
#> 280: 0.344260    0.997807    3.435786    0.401117    0.048741    0.019158    0.675897    
#> 281: 0.343848    0.997928    3.435713    0.401752    0.048746    0.019147    0.675909    
#> 282: 0.343654    0.998181    3.435707    0.401885    0.048773    0.019182    0.675672    
#> 283: 0.343683    0.998455    3.435648    0.402615    0.048786    0.019257    0.675662    
#> 284: 0.343357    0.998402    3.435564    0.403085    0.048801    0.019312    0.675561    
#> 285: 0.343563    0.998580    3.435459    0.404051    0.048743    0.019382    0.675395    
#> 286: 0.343636    0.998675    3.435344    0.404192    0.048695    0.019415    0.675376    
#> 287: 0.342956    0.998966    3.435088    0.404006    0.048695    0.019463    0.675279    
#> 288: 0.342713    0.999071    3.434955    0.404225    0.048571    0.019493    0.675222    
#> 289: 0.342791    0.999158    3.434833    0.404071    0.048542    0.019501    0.675121    
#> 290: 0.342818    0.999200    3.434801    0.404259    0.048647    0.019487    0.675108    
#> 291: 0.343180    0.999476    3.434888    0.404829    0.048709    0.019469    0.674982    
#> 292: 0.342925    0.999629    3.434811    0.404946    0.048730    0.019439    0.674961    
#> 293: 0.342684    0.999636    3.434712    0.404311    0.048723    0.019436    0.675050    
#> 294: 0.342497    0.999689    3.434636    0.404006    0.048698    0.019420    0.675146    
#> 295: 0.342415    0.999461    3.434566    0.404226    0.048727    0.019405    0.674979    
#> 296: 0.342531    0.999275    3.434645    0.404495    0.048726    0.019372    0.674977    
#> 297: 0.342464    0.999218    3.434679    0.404247    0.048746    0.019356    0.674894    
#> 298: 0.342772    0.999059    3.434713    0.404324    0.048829    0.019330    0.674874    
#> 299: 0.342972    0.999197    3.434682    0.404562    0.048926    0.019283    0.674795    
#> 300: 0.343225    0.999064    3.434779    0.404655    0.048856    0.019284    0.674708    
#> 301: 0.343189    0.999000    3.434629    0.404351    0.048816    0.019260    0.674770    
#> 302: 0.343116    0.999185    3.434506    0.404249    0.048882    0.019245    0.674722    
#> 303: 0.342864    0.999318    3.434345    0.403862    0.048916    0.019237    0.674516    
#> 304: 0.342586    0.999533    3.434141    0.403575    0.048913    0.019226    0.674456    
#> 305: 0.341906    0.999471    3.433954    0.403160    0.048988    0.019231    0.674487    
#> 306: 0.341242    0.999452    3.433730    0.402451    0.049065    0.019219    0.674631    
#> 307: 0.341016    0.999426    3.433569    0.401991    0.049084    0.019218    0.674682    
#> 308: 0.340459    0.999365    3.433372    0.401638    0.049053    0.019216    0.674790    
#> 309: 0.340132    0.999302    3.433306    0.401573    0.049077    0.019227    0.674866    
#> 310: 0.340140    0.999275    3.433193    0.402080    0.049120    0.019202    0.674933    
#> 311: 0.340119    0.999251    3.433205    0.402626    0.049151    0.019192    0.674790    
#> 312: 0.339778    0.999164    3.433110    0.403155    0.049170    0.019173    0.674910    
#> 313: 0.339604    0.998999    3.432997    0.403724    0.049184    0.019177    0.675126    
#> 314: 0.339156    0.998931    3.432883    0.403535    0.049124    0.019195    0.675111    
#> 315: 0.338954    0.999012    3.432762    0.403620    0.049029    0.019231    0.674951    
#> 316: 0.338979    0.999142    3.432710    0.403349    0.049015    0.019257    0.674857    
#> 317: 0.339137    0.999087    3.432775    0.403058    0.049049    0.019287    0.674885    
#> 318: 0.339118    0.999084    3.432723    0.403571    0.049076    0.019306    0.674816    
#> 319: 0.339291    0.998959    3.432855    0.403975    0.049036    0.019313    0.674867    
#> 320: 0.339037    0.998890    3.432789    0.404051    0.049009    0.019284    0.675139    
#> 321: 0.338813    0.998849    3.432658    0.404660    0.048987    0.019238    0.675154    
#> 322: 0.338763    0.998887    3.432525    0.405034    0.049053    0.019207    0.675018    
#> 323: 0.338458    0.998935    3.432397    0.404923    0.049017    0.019194    0.674904    
#> 324: 0.338348    0.999161    3.432365    0.405112    0.049070    0.019187    0.674728    
#> 325: 0.338203    0.999445    3.432256    0.404820    0.049067    0.019184    0.674689    
#> 326: 0.338056    0.999385    3.432134    0.404627    0.049078    0.019180    0.674672    
#> 327: 0.337945    0.999530    3.432133    0.404340    0.049049    0.019191    0.674800    
#> 328: 0.338000    0.999707    3.432102    0.404008    0.049094    0.019169    0.674817    
#> 329: 0.338255    0.999848    3.432088    0.403927    0.049106    0.019152    0.674745    
#> 330: 0.338010    0.999995    3.432046    0.403483    0.049186    0.019120    0.674789    
#> 331: 0.338052    1.000182    3.432118    0.402895    0.049235    0.019078    0.674833    
#> 332: 0.337774    1.000174    3.432110    0.402500    0.049288    0.019036    0.674914    
#> 333: 0.337675    1.000205    3.432045    0.402304    0.049370    0.019002    0.674941    
#> 334: 0.337424    1.000167    3.431864    0.402445    0.049413    0.018958    0.674929    
#> 335: 0.337270    1.000194    3.431755    0.402335    0.049460    0.018920    0.674933    
#> 336: 0.336705    1.000380    3.431646    0.402059    0.049489    0.018917    0.675019    
#> 337: 0.336232    1.000821    3.431416    0.401823    0.049583    0.018909    0.674998    
#> 338: 0.335775    1.001173    3.431239    0.401563    0.049683    0.018891    0.674965    
#> 339: 0.335300    1.001396    3.430977    0.401822    0.049757    0.018874    0.674892    
#> 340: 0.334859    1.001415    3.430835    0.402025    0.049821    0.018890    0.674831    
#> 341: 0.334708    1.001401    3.430740    0.402019    0.049803    0.018896    0.674904    
#> 342: 0.334429    1.001212    3.430694    0.401726    0.049728    0.018905    0.674910    
#> 343: 0.334112    1.001157    3.430702    0.401658    0.049676    0.018955    0.675038    
#> 344: 0.334190    1.001138    3.430735    0.401670    0.049678    0.018987    0.675054    
#> 345: 0.334164    1.001255    3.430726    0.401969    0.049787    0.018988    0.675084    
#> 346: 0.333922    1.001394    3.430592    0.401948    0.049833    0.018981    0.674990    
#> 347: 0.333915    1.001349    3.430436    0.402146    0.049838    0.018980    0.675038    
#> 348: 0.333710    1.001515    3.430327    0.402273    0.049833    0.018976    0.675140    
#> 349: 0.333681    1.001537    3.430265    0.402475    0.049890    0.018975    0.675134    
#> 350: 0.333742    1.001518    3.430197    0.402989    0.049932    0.018960    0.675078    
#> 351: 0.333650    1.001608    3.430107    0.402792    0.049949    0.018968    0.675052    
#> 352: 0.333369    1.001694    3.430066    0.402598    0.050004    0.019010    0.675148    
#> 353: 0.333367    1.001825    3.430048    0.402390    0.050082    0.019011    0.675113    
#> 354: 0.333374    1.001876    3.430004    0.402370    0.050171    0.019009    0.675118    
#> 355: 0.333614    1.001786    3.429937    0.402768    0.050244    0.019003    0.675114    
#> 356: 0.333541    1.001749    3.429902    0.402664    0.050292    0.019007    0.675319    
#> 357: 0.333494    1.001801    3.429863    0.402966    0.050271    0.018983    0.675413    
#> 358: 0.333525    1.001902    3.429862    0.403396    0.050227    0.018974    0.675351    
#> 359: 0.333489    1.002114    3.429793    0.403537    0.050228    0.018980    0.675244    
#> 360: 0.333355    1.002208    3.429661    0.403406    0.050182    0.018999    0.675158    
#> 361: 0.333230    1.002334    3.429601    0.403291    0.050228    0.019035    0.675062    
#> 362: 0.333309    1.002379    3.429591    0.403249    0.050232    0.019039    0.674850    
#> 363: 0.333183    1.002339    3.429594    0.402942    0.050210    0.019066    0.674624    
#> 364: 0.333272    1.002385    3.429565    0.402637    0.050133    0.019111    0.674613    
#> 365: 0.333255    1.002397    3.429558    0.402285    0.050123    0.019183    0.674591    
#> 366: 0.333082    1.002496    3.429437    0.402341    0.050075    0.019224    0.674638    
#> 367: 0.333149    1.002565    3.429386    0.402804    0.050063    0.019235    0.674591    
#> 368: 0.333347    1.002614    3.429332    0.403078    0.050088    0.019219    0.674480    
#> 369: 0.333343    1.002613    3.429283    0.403050    0.050068    0.019208    0.674520    
#> 370: 0.333233    1.002564    3.429242    0.403190    0.050103    0.019217    0.674553    
#> 371: 0.333046    1.002639    3.429094    0.403309    0.050140    0.019213    0.674510    
#> 372: 0.332931    1.002708    3.428997    0.403751    0.050174    0.019188    0.674391    
#> 373: 0.332648    1.002830    3.428816    0.404141    0.050238    0.019165    0.674361    
#> 374: 0.332519    1.002943    3.428684    0.404789    0.050300    0.019130    0.674290    
#> 375: 0.332406    1.003033    3.428612    0.405141    0.050342    0.019106    0.674267    
#> 376: 0.332313    1.003133    3.428521    0.405294    0.050410    0.019073    0.674223    
#> 377: 0.332069    1.003256    3.428456    0.405269    0.050471    0.019041    0.674213    
#> 378: 0.331687    1.003328    3.428361    0.405056    0.050482    0.019018    0.674259    
#> 379: 0.331364    1.003306    3.428283    0.404892    0.050513    0.019001    0.674288    
#> 380: 0.331186    1.003343    3.428248    0.404788    0.050574    0.018981    0.674360    
#> 381: 0.330929    1.003407    3.428196    0.404896    0.050572    0.018981    0.674329    
#> 382: 0.330755    1.003456    3.428133    0.405178    0.050568    0.018979    0.674199    
#> 383: 0.330687    1.003448    3.428132    0.404893    0.050530    0.018988    0.674100    
#> 384: 0.330535    1.003421    3.428104    0.404887    0.050540    0.018975    0.674119    
#> 385: 0.330556    1.003394    3.428097    0.404644    0.050518    0.018954    0.674143    
#> 386: 0.330617    1.003501    3.428132    0.404457    0.050582    0.018945    0.674167    
#> 387: 0.330850    1.003543    3.428214    0.404491    0.050568    0.018936    0.674096    
#> 388: 0.331081    1.003557    3.428280    0.404513    0.050579    0.018916    0.673971    
#> 389: 0.331161    1.003415    3.428323    0.404476    0.050584    0.018911    0.673953    
#> 390: 0.331068    1.003481    3.428311    0.404254    0.050546    0.018910    0.673981    
#> 391: 0.331154    1.003489    3.428266    0.404021    0.050524    0.018914    0.673935    
#> 392: 0.331221    1.003491    3.428320    0.403925    0.050520    0.018901    0.673907    
#> 393: 0.331139    1.003475    3.428302    0.403612    0.050526    0.018883    0.673842    
#> 394: 0.331093    1.003558    3.428235    0.403410    0.050513    0.018878    0.673899    
#> 395: 0.331102    1.003656    3.428190    0.403127    0.050523    0.018880    0.673944    
#> 396: 0.331140    1.003720    3.428169    0.402936    0.050439    0.018891    0.673945    
#> 397: 0.331061    1.003691    3.428220    0.402557    0.050417    0.018892    0.673940    
#> 398: 0.331235    1.003569    3.428296    0.402634    0.050427    0.018879    0.673997    
#> 399: 0.331438    1.003473    3.428392    0.402830    0.050445    0.018858    0.673962    
#> 400: 0.331592    1.003423    3.428476    0.402655    0.050458    0.018849    0.673943    
#> 401: 0.331751    1.003403    3.428513    0.402739    0.050429    0.018856    0.673937    
#> 402: 0.331759    1.003447    3.428555    0.402446    0.050426    0.018858    0.673973    
#> 403: 0.331941    1.003521    3.428573    0.402457    0.050489    0.018852    0.673980    
#> 404: 0.332034    1.003606    3.428512    0.402505    0.050578    0.018844    0.673958    
#> 405: 0.332021    1.003700    3.428491    0.402744    0.050676    0.018833    0.673952    
#> 406: 0.332111    1.003789    3.428493    0.402523    0.050764    0.018832    0.674075    
#> 407: 0.332083    1.003870    3.428538    0.402050    0.050788    0.018822    0.674148    
#> 408: 0.332338    1.003945    3.428597    0.401730    0.050770    0.018809    0.674156    
#> 409: 0.332374    1.003919    3.428636    0.401215    0.050772    0.018800    0.674160    
#> 410: 0.332313    1.003864    3.428622    0.401023    0.050827    0.018803    0.674159    
#> 411: 0.332191    1.003726    3.428583    0.400979    0.050860    0.018787    0.674274    
#> 412: 0.332262    1.003708    3.428547    0.401337    0.050854    0.018805    0.674255    
#> 413: 0.332408    1.003676    3.428544    0.401523    0.050864    0.018805    0.674263    
#> 414: 0.332431    1.003629    3.428571    0.401772    0.050881    0.018813    0.674178    
#> 415: 0.332852    1.003569    3.428625    0.402131    0.050881    0.018820    0.674127    
#> 416: 0.333112    1.003585    3.428711    0.402260    0.050904    0.018822    0.674090    
#> 417: 0.333283    1.003461    3.428747    0.402257    0.050905    0.018829    0.674028    
#> 418: 0.333214    1.003391    3.428795    0.402023    0.050921    0.018826    0.673977    
#> 419: 0.333426    1.003430    3.428850    0.402162    0.050898    0.018815    0.673938    
#> 420: 0.333674    1.003396    3.428904    0.402151    0.050850    0.018808    0.673850    
#> 421: 0.333794    1.003369    3.428975    0.402150    0.050863    0.018823    0.673760    
#> 422: 0.334060    1.003196    3.429097    0.402055    0.050832    0.018846    0.673689    
#> 423: 0.334465    1.003076    3.429193    0.402448    0.050812    0.018859    0.673642    
#> 424: 0.334596    1.003005    3.429209    0.402690    0.050793    0.018854    0.673606    
#> 425: 0.334643    1.003011    3.429189    0.403089    0.050790    0.018839    0.673673    
#> 426: 0.334724    1.003086    3.429174    0.403236    0.050760    0.018838    0.673683    
#> 427: 0.334638    1.003090    3.429208    0.403118    0.050719    0.018866    0.673661    
#> 428: 0.334468    1.003098    3.429222    0.402950    0.050692    0.018891    0.673609    
#> 429: 0.334654    1.003023    3.429305    0.402970    0.050645    0.018912    0.673566    
#> 430: 0.334813    1.003022    3.429363    0.403020    0.050623    0.018945    0.673493    
#> 431: 0.334829    1.002999    3.429330    0.402915    0.050574    0.018963    0.673434    
#> 432: 0.334710    1.003063    3.429318    0.402657    0.050551    0.018988    0.673357    
#> 433: 0.334654    1.003143    3.429356    0.402611    0.050573    0.019008    0.673399    
#> 434: 0.334474    1.003106    3.429335    0.402569    0.050579    0.019026    0.673384    
#> 435: 0.334600    1.003118    3.429328    0.402846    0.050547    0.019043    0.673364    
#> 436: 0.334685    1.003126    3.429355    0.402718    0.050496    0.019063    0.673363    
#> 437: 0.334690    1.003117    3.429339    0.402711    0.050438    0.019073    0.673317    
#> 438: 0.334662    1.003255    3.429298    0.402857    0.050434    0.019066    0.673295    
#> 439: 0.334775    1.003307    3.429290    0.403054    0.050416    0.019064    0.673243    
#> 440: 0.334788    1.003382    3.429293    0.403094    0.050409    0.019061    0.673178    
#> 441: 0.334821    1.003353    3.429268    0.402895    0.050420    0.019064    0.673102    
#> 442: 0.334781    1.003412    3.429296    0.402749    0.050418    0.019077    0.673067    
#> 443: 0.334865    1.003552    3.429253    0.402937    0.050429    0.019090    0.673120    
#> 444: 0.334806    1.003643    3.429175    0.403023    0.050415    0.019102    0.673083    
#> 445: 0.334785    1.003730    3.429121    0.403217    0.050447    0.019102    0.673112    
#> 446: 0.334625    1.003790    3.429076    0.403211    0.050446    0.019104    0.673092    
#> 447: 0.334676    1.003754    3.429081    0.403430    0.050419    0.019103    0.673147    
#> 448: 0.334759    1.003765    3.429100    0.403619    0.050436    0.019105    0.673187    
#> 449: 0.334809    1.003847    3.429155    0.403645    0.050440    0.019123    0.673222    
#> 450: 0.334899    1.003861    3.429159    0.403727    0.050409    0.019119    0.673237    
#> 451: 0.335051    1.003943    3.429164    0.403811    0.050391    0.019133    0.673263    
#> 452: 0.335023    1.003986    3.429188    0.403531    0.050410    0.019139    0.673281    
#> 453: 0.334888    1.004046    3.429181    0.403346    0.050462    0.019146    0.673293    
#> 454: 0.334773    1.004126    3.429167    0.403110    0.050448    0.019142    0.673309    
#> 455: 0.334817    1.004126    3.429188    0.402951    0.050421    0.019137    0.673311    
#> 456: 0.334751    1.004091    3.429253    0.402820    0.050404    0.019155    0.673323    
#> 457: 0.334857    1.004031    3.429351    0.402611    0.050347    0.019174    0.673251    
#> 458: 0.334894    1.004086    3.429391    0.402499    0.050285    0.019199    0.673211    
#> 459: 0.334865    1.004160    3.429399    0.402752    0.050275    0.019222    0.673200    
#> 460: 0.334858    1.004233    3.429380    0.403024    0.050277    0.019234    0.673118    
#> 461: 0.334858    1.004266    3.429407    0.403215    0.050253    0.019248    0.673030    
#> 462: 0.334866    1.004305    3.429421    0.403598    0.050219    0.019269    0.673029    
#> 463: 0.334835    1.004365    3.429432    0.403745    0.050189    0.019276    0.673124    
#> 464: 0.334955    1.004409    3.429420    0.403880    0.050172    0.019278    0.673188    
#> 465: 0.334975    1.004346    3.429428    0.404165    0.050151    0.019280    0.673172    
#> 466: 0.335005    1.004375    3.429390    0.404464    0.050132    0.019275    0.673127    
#> 467: 0.334830    1.004328    3.429394    0.404398    0.050087    0.019287    0.673110    
#> 468: 0.334936    1.004307    3.429460    0.404499    0.050081    0.019284    0.673097    
#> 469: 0.335014    1.004359    3.429507    0.404386    0.050086    0.019288    0.673138    
#> 470: 0.334993    1.004386    3.429496    0.404335    0.050081    0.019303    0.673170    
#> 471: 0.334882    1.004358    3.429489    0.404096    0.050105    0.019294    0.673139    
#> 472: 0.334819    1.004358    3.429499    0.403922    0.050083    0.019298    0.673105    
#> 473: 0.334897    1.004387    3.429493    0.404079    0.050043    0.019308    0.673043    
#> 474: 0.334867    1.004405    3.429472    0.404143    0.050054    0.019306    0.673071    
#> 475: 0.334912    1.004517    3.429432    0.404233    0.050042    0.019307    0.673056    
#> 476: 0.334911    1.004497    3.429420    0.404393    0.050062    0.019304    0.673090    
#> 477: 0.334874    1.004500    3.429456    0.404426    0.050059    0.019302    0.673049    
#> 478: 0.334884    1.004414    3.429490    0.404253    0.050075    0.019301    0.673128    
#> 479: 0.335092    1.004436    3.429546    0.404233    0.050089    0.019299    0.673145    
#> 480: 0.335242    1.004368    3.429596    0.404238    0.050062    0.019294    0.673157    
#> 481: 0.335225    1.004315    3.429589    0.404214    0.050048    0.019302    0.673109    
#> 482: 0.335231    1.004309    3.429541    0.404237    0.050037    0.019321    0.673067    
#> 483: 0.335060    1.004293    3.429496    0.404151    0.049989    0.019330    0.673054    
#> 484: 0.334985    1.004150    3.429522    0.404065    0.049955    0.019340    0.673068    
#> 485: 0.334965    1.004166    3.429528    0.403954    0.049986    0.019363    0.673094    
#> 486: 0.334957    1.004249    3.429523    0.404029    0.049984    0.019379    0.673080    
#> 487: 0.335043    1.004297    3.429571    0.403993    0.049966    0.019399    0.673071    
#> 488: 0.335138    1.004290    3.429642    0.403797    0.049942    0.019430    0.673074    
#> 489: 0.335282    1.004256    3.429673    0.403655    0.049915    0.019460    0.673024    
#> 490: 0.335446    1.004215    3.429718    0.403769    0.049874    0.019485    0.672965    
#> 491: 0.335499    1.004215    3.429783    0.403726    0.049860    0.019485    0.672912    
#> 492: 0.335480    1.004232    3.429784    0.403715    0.049832    0.019485    0.672918    
#> 493: 0.335514    1.004188    3.429864    0.403711    0.049801    0.019510    0.672936    
#> 494: 0.335647    1.004145    3.429911    0.403502    0.049764    0.019524    0.672927    
#> 495: 0.335859    1.004111    3.429950    0.403414    0.049723    0.019537    0.672899    
#> 496: 0.336014    1.004135    3.429954    0.403543    0.049707    0.019555    0.672898    
#> 497: 0.335995    1.004100    3.429953    0.403796    0.049710    0.019552    0.672919    
#> 498: 0.335922    1.004086    3.429904    0.404110    0.049704    0.019540    0.672903    
#> 499: 0.335896    1.004127    3.429845    0.404156    0.049718    0.019532    0.672883    
#> 500: 0.335886    1.004074    3.429802    0.404183    0.049726    0.019521    0.672866    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.284180    0.960571    3.442907    0.392401    0.077246    0.016800    1.554507    
#> 002: 0.428631    1.022744    3.459348    0.372781    0.073384    0.015960    1.154085    
#> 003: 0.583354    0.970322    3.471773    0.354142    0.069715    0.015162    0.863502    
#> 004: 0.570836    0.935649    3.471745    0.336435    0.066229    0.014404    0.752842    
#> 005: 0.617078    0.934978    3.465186    0.319613    0.069494    0.013684    0.704207    
#> 006: 0.607528    0.936421    3.460198    0.303633    0.071087    0.013000    0.682384    
#> 007: 0.585994    0.931204    3.459854    0.341269    0.070441    0.012350    0.695266    
#> 008: 0.544775    0.910201    3.457692    0.324206    0.067921    0.011732    0.732793    
#> 009: 0.529989    0.896241    3.468340    0.307995    0.064525    0.011146    0.735513    
#> 010: 0.590305    0.903107    3.465031    0.292596    0.064772    0.010588    0.733678    
#> 011: 0.592175    0.932813    3.460826    0.277966    0.075923    0.010059    0.733956    
#> 012: 0.599885    0.910636    3.460313    0.264068    0.080043    0.009556    0.719760    
#> 013: 0.551451    0.909558    3.454478    0.250864    0.076041    0.009078    0.709785    
#> 014: 0.579253    0.912974    3.464867    0.238321    0.084963    0.008624    0.728670    
#> 015: 0.591380    0.914199    3.475005    0.226405    0.080715    0.008193    0.710984    
#> 016: 0.589657    0.925313    3.474798    0.253017    0.082226    0.007783    0.707439    
#> 017: 0.563734    0.948582    3.459485    0.283551    0.078115    0.007394    0.698532    
#> 018: 0.571851    0.949897    3.444352    0.271263    0.078275    0.007025    0.707090    
#> 019: 0.531665    0.931073    3.443489    0.257700    0.082580    0.006673    0.693252    
#> 020: 0.546062    0.959688    3.450896    0.244815    0.100539    0.006340    0.699405    
#> 021: 0.573555    0.926822    3.456757    0.232574    0.095512    0.006417    0.694067    
#> 022: 0.520544    0.924269    3.458848    0.220945    0.090737    0.006097    0.696997    
#> 023: 0.594698    0.938434    3.471881    0.230642    0.099956    0.005792    0.713642    
#> 024: 0.614626    0.932512    3.471662    0.232046    0.094958    0.005502    0.687975    
#> 025: 0.569583    0.926692    3.461682    0.274589    0.090210    0.005227    0.695928    
#> 026: 0.598156    0.954513    3.457630    0.271646    0.085700    0.004966    0.702165    
#> 027: 0.565738    0.967949    3.457293    0.285319    0.081415    0.004717    0.722202    
#> 028: 0.603229    0.939529    3.464481    0.331387    0.087512    0.004482    0.687593    
#> 029: 0.621567    0.951009    3.463313    0.350903    0.089481    0.004257    0.703258    
#> 030: 0.608868    0.952309    3.458798    0.333358    0.085007    0.004465    0.694612    
#> 031: 0.532205    0.922785    3.456620    0.316690    0.080757    0.004242    0.709016    
#> 032: 0.550458    0.912846    3.460173    0.300856    0.082795    0.004030    0.695849    
#> 033: 0.567942    0.935806    3.455323    0.285813    0.095120    0.003828    0.685895    
#> 034: 0.590274    0.935202    3.458493    0.276808    0.090364    0.003637    0.702475    
#> 035: 0.548093    0.924850    3.452203    0.262968    0.085846    0.003455    0.698983    
#> 036: 0.527261    0.946961    3.447326    0.253002    0.086623    0.003282    0.713736    
#> 037: 0.555789    0.960946    3.450718    0.271882    0.102657    0.003118    0.711425    
#> 038: 0.589624    0.942526    3.444294    0.258288    0.097524    0.002962    0.718868    
#> 039: 0.592128    0.940201    3.452339    0.272897    0.092648    0.002814    0.700596    
#> 040: 0.549225    0.947211    3.452324    0.297881    0.088016    0.002673    0.701399    
#> 041: 0.555252    0.927947    3.456172    0.320197    0.083615    0.002540    0.705383    
#> 042: 0.599083    0.932607    3.458374    0.353123    0.083579    0.002413    0.688651    
#> 043: 0.533190    0.930967    3.451594    0.335467    0.080796    0.002402    0.705049    
#> 044: 0.544966    0.946276    3.450808    0.318694    0.080964    0.002282    0.707653    
#> 045: 0.570160    0.952818    3.447764    0.409937    0.083137    0.002168    0.698823    
#> 046: 0.564411    0.941413    3.444587    0.389440    0.092977    0.002060    0.706679    
#> 047: 0.590879    0.955262    3.442902    0.369968    0.088329    0.002029    0.695088    
#> 048: 0.562508    0.928223    3.448172    0.351469    0.094178    0.001928    0.705020    
#> 049: 0.534233    0.932902    3.452643    0.333896    0.091751    0.001832    0.735599    
#> 050: 0.612671    0.908250    3.454736    0.317201    0.098307    0.002108    0.720505    
#> 051: 0.590193    0.939697    3.455830    0.301341    0.104696    0.002295    0.712324    
#> 052: 0.575723    0.936903    3.462734    0.286274    0.099461    0.002218    0.695232    
#> 053: 0.599676    0.928825    3.464012    0.271960    0.094488    0.002107    0.696958    
#> 054: 0.551960    0.936690    3.466979    0.258362    0.089764    0.002490    0.706253    
#> 055: 0.564525    0.926924    3.464909    0.245444    0.085275    0.002690    0.703023    
#> 056: 0.586487    0.912351    3.463495    0.259714    0.086105    0.002827    0.717510    
#> 057: 0.565531    0.909707    3.474477    0.246729    0.094553    0.002686    0.733048    
#> 058: 0.583134    0.912956    3.463703    0.234392    0.089825    0.002629    0.725449    
#> 059: 0.582499    0.892400    3.463101    0.265509    0.085334    0.002945    0.715264    
#> 060: 0.586998    0.911121    3.466974    0.252234    0.092481    0.003742    0.704976    
#> 061: 0.614875    0.932581    3.468029    0.239622    0.087857    0.003787    0.728546    
#> 062: 0.590295    0.923241    3.472289    0.260954    0.083464    0.004861    0.720938    
#> 063: 0.617786    0.902369    3.475071    0.261087    0.079291    0.004618    0.717485    
#> 064: 0.564501    0.911270    3.468560    0.248033    0.075326    0.004387    0.700591    
#> 065: 0.612710    0.904291    3.468301    0.235631    0.074646    0.004168    0.697035    
#> 066: 0.598758    0.936332    3.463367    0.233209    0.075949    0.003959    0.702378    
#> 067: 0.579423    0.927944    3.455383    0.233166    0.085423    0.003761    0.696891    
#> 068: 0.567474    0.929018    3.471987    0.241021    0.081152    0.003573    0.711010    
#> 069: 0.567775    0.911574    3.467385    0.228970    0.087065    0.003395    0.716263    
#> 070: 0.566485    0.930768    3.478510    0.218642    0.082711    0.003225    0.712924    
#> 071: 0.578816    0.938374    3.471668    0.207710    0.086401    0.003064    0.742125    
#> 072: 0.549726    0.902866    3.471046    0.197324    0.082081    0.002910    0.743251    
#> 073: 0.608343    0.922645    3.485106    0.256635    0.082489    0.002765    0.721428    
#> 074: 0.584618    0.891955    3.488058    0.243804    0.083132    0.003195    0.718714    
#> 075: 0.621660    0.892431    3.501988    0.268807    0.083788    0.003035    0.710387    
#> 076: 0.623167    0.907721    3.502960    0.279811    0.084933    0.004226    0.715383    
#> 077: 0.661394    0.870962    3.486850    0.265820    0.091168    0.004015    0.713110    
#> 078: 0.652902    0.905299    3.490891    0.258277    0.091561    0.003814    0.693674    
#> 079: 0.650014    0.917736    3.490595    0.282172    0.096423    0.003624    0.718897    
#> 080: 0.621582    0.907688    3.481290    0.296166    0.091602    0.003798    0.741748    
#> 081: 0.595715    0.928900    3.472697    0.281358    0.087022    0.004237    0.711391    
#> 082: 0.621673    0.920274    3.478001    0.267290    0.093590    0.004025    0.729901    
#> 083: 0.583407    0.960219    3.466392    0.253926    0.090953    0.003824    0.712138    
#> 084: 0.562651    0.941378    3.454244    0.255691    0.105857    0.003632    0.700881    
#> 085: 0.560862    0.939874    3.460187    0.242906    0.100564    0.003451    0.707465    
#> 086: 0.561761    0.935010    3.461938    0.230761    0.095536    0.003278    0.705178    
#> 087: 0.555759    0.921914    3.458215    0.219223    0.090759    0.003114    0.710612    
#> 088: 0.499157    0.939246    3.460151    0.224487    0.086221    0.002959    0.734895    
#> 089: 0.560000    0.940854    3.453284    0.213263    0.081910    0.002876    0.731638    
#> 090: 0.537742    0.940688    3.452556    0.202600    0.099121    0.003277    0.718911    
#> 091: 0.530442    0.928596    3.437944    0.231141    0.107860    0.003113    0.699873    
#> 092: 0.521904    0.963699    3.436595    0.219584    0.102467    0.002958    0.711270    
#> 093: 0.538177    0.952552    3.441439    0.216242    0.097344    0.002810    0.694331    
#> 094: 0.527268    0.946850    3.440399    0.205430    0.092827    0.002669    0.707075    
#> 095: 0.520326    0.947564    3.450955    0.215285    0.088186    0.002536    0.708446    
#> 096: 0.497252    0.940877    3.450675    0.250278    0.103897    0.002409    0.724587    
#> 097: 0.549302    0.961335    3.451484    0.271670    0.098702    0.002289    0.702920    
#> 098: 0.573378    0.951935    3.455729    0.258087    0.098817    0.002174    0.716189    
#> 099: 0.577750    0.915254    3.449829    0.256920    0.093876    0.002066    0.716693    
#> 100: 0.548400    0.938698    3.448033    0.258933    0.091789    0.001962    0.697591    
#> 101: 0.542675    0.923493    3.446459    0.249857    0.098361    0.001864    0.684053    
#> 102: 0.552946    0.924995    3.443242    0.237364    0.093443    0.001771    0.695164    
#> 103: 0.582614    0.938736    3.448991    0.233073    0.090774    0.001683    0.701152    
#> 104: 0.548091    0.939163    3.453515    0.252971    0.095197    0.001765    0.701044    
#> 105: 0.559009    0.937039    3.449277    0.254274    0.090437    0.001676    0.725069    
#> 106: 0.551449    0.932484    3.447057    0.271670    0.085916    0.001997    0.691166    
#> 107: 0.562566    0.957402    3.445308    0.267316    0.093760    0.001897    0.703448    
#> 108: 0.557391    0.933399    3.444306    0.264444    0.100228    0.001802    0.702872    
#> 109: 0.544967    0.942112    3.449358    0.289434    0.102462    0.001712    0.707788    
#> 110: 0.543127    0.941919    3.438880    0.274962    0.097339    0.001894    0.710565    
#> 111: 0.551029    0.952627    3.442395    0.261214    0.092472    0.001799    0.692992    
#> 112: 0.492718    0.938535    3.434965    0.248153    0.087849    0.001709    0.703152    
#> 113: 0.521598    0.950899    3.434063    0.241377    0.095281    0.001624    0.701724    
#> 114: 0.545555    0.933910    3.437517    0.266303    0.096851    0.001542    0.700412    
#> 115: 0.577509    0.918088    3.445537    0.269919    0.092009    0.001465    0.721467    
#> 116: 0.579166    0.956761    3.446452    0.275540    0.097774    0.001392    0.698637    
#> 117: 0.548446    0.952131    3.444518    0.261763    0.092885    0.001322    0.703712    
#> 118: 0.570305    0.924881    3.445335    0.258162    0.096812    0.001256    0.708868    
#> 119: 0.565743    0.935473    3.445986    0.293966    0.092050    0.001303    0.700011    
#> 120: 0.548179    0.923623    3.447140    0.279268    0.087448    0.001259    0.704688    
#> 121: 0.554306    0.961831    3.449355    0.265305    0.098328    0.001196    0.702458    
#> 122: 0.559120    0.914621    3.451096    0.252039    0.093411    0.001136    0.714572    
#> 123: 0.600239    0.947188    3.446874    0.244672    0.088741    0.001079    0.729230    
#> 124: 0.568575    0.962262    3.444451    0.238009    0.087732    0.001025    0.722543    
#> 125: 0.561875    0.963229    3.441788    0.313632    0.097801    0.000974    0.684666    
#> 126: 0.563190    0.960429    3.438796    0.338331    0.104935    0.000925    0.692937    
#> 127: 0.551318    0.936928    3.438281    0.323964    0.099688    0.000879    0.710446    
#> 128: 0.543297    0.939687    3.443436    0.307766    0.111050    0.000835    0.700421    
#> 129: 0.585127    0.943057    3.447965    0.292378    0.105498    0.000910    0.725225    
#> 130: 0.595946    0.941190    3.450641    0.277759    0.100223    0.000897    0.705670    
#> 131: 0.569227    0.927715    3.447134    0.280946    0.097967    0.000981    0.724881    
#> 132: 0.540003    0.952901    3.441010    0.266899    0.095753    0.000932    0.720073    
#> 133: 0.521642    0.945696    3.440527    0.271131    0.090966    0.000885    0.729963    
#> 134: 0.536895    0.940623    3.443798    0.257575    0.092806    0.000860    0.718727    
#> 135: 0.515523    0.946477    3.438120    0.244696    0.088166    0.000817    0.728639    
#> 136: 0.521847    0.940946    3.437685    0.232461    0.090545    0.000827    0.718900    
#> 137: 0.542826    0.962511    3.436527    0.222057    0.111864    0.000786    0.700979    
#> 138: 0.540475    0.961089    3.435380    0.257393    0.106970    0.000746    0.696622    
#> 139: 0.560803    0.972096    3.441025    0.244523    0.110787    0.000709    0.704534    
#> 140: 0.545002    0.958588    3.445521    0.232297    0.105247    0.000673    0.702812    
#> 141: 0.538935    0.928297    3.447720    0.239722    0.099985    0.000640    0.710062    
#> 142: 0.560072    0.920705    3.450226    0.230489    0.098816    0.000608    0.712430    
#> 143: 0.511201    0.941533    3.451725    0.249954    0.100615    0.000608    0.714608    
#> 144: 0.571883    0.954733    3.454810    0.237456    0.097539    0.000578    0.710448    
#> 145: 0.566132    0.944087    3.452703    0.257217    0.092662    0.000549    0.711391    
#> 146: 0.535890    0.937391    3.456890    0.272682    0.100313    0.000522    0.699516    
#> 147: 0.521463    0.918518    3.454831    0.259048    0.095780    0.000496    0.705239    
#> 148: 0.519546    0.926147    3.454623    0.246096    0.124292    0.000471    0.706237    
#> 149: 0.538289    0.899575    3.457209    0.247931    0.118078    0.000536    0.726451    
#> 150: 0.547903    0.906490    3.456684    0.235534    0.112174    0.000510    0.735803    
#> 151: 0.511066    0.939200    3.451967    0.226231    0.106565    0.000484    0.723752    
#> 152: 0.533080    0.937451    3.452706    0.243498    0.111152    0.000278    0.708321    
#> 153: 0.547922    0.928031    3.453953    0.240569    0.092113    0.000273    0.723058    
#> 154: 0.577960    0.943721    3.455513    0.245436    0.111850    0.000240    0.720705    
#> 155: 0.532799    0.929744    3.453341    0.210276    0.089370    0.000240    0.717901    
#> 156: 0.556920    0.927175    3.456292    0.212266    0.088889    0.000221    0.733047    
#> 157: 0.584264    0.931723    3.457748    0.226233    0.089795    0.000196    0.747446    
#> 158: 0.583019    0.951736    3.458143    0.189369    0.094681    0.000191    0.739979    
#> 159: 0.552271    0.936470    3.457687    0.241393    0.103120    0.000120    0.695779    
#> 160: 0.584571    0.907277    3.459377    0.258441    0.096237    0.000142    0.705284    
#> 161: 0.584315    0.933359    3.460031    0.276301    0.100802    0.000170    0.701261    
#> 162: 0.556879    0.937547    3.455359    0.240376    0.096479    0.000144    0.716440    
#> 163: 0.580354    0.919683    3.455724    0.216795    0.095645    0.000128    0.725353    
#> 164: 0.575074    0.931095    3.454280    0.239250    0.098841    0.000171    0.722015    
#> 165: 0.574102    0.914473    3.456260    0.261939    0.093402    0.000166    0.710833    
#> 166: 0.601916    0.962892    3.457031    0.302966    0.081504    0.000156    0.723842    
#> 167: 0.579825    0.942707    3.457938    0.321656    0.111315    0.000137    0.714399    
#> 168: 0.600361    0.947941    3.459409    0.328613    0.102294    0.000150    0.726858    
#> 169: 0.589541    0.950706    3.458488    0.324168    0.115553    0.000133    0.725806    
#> 170: 0.594047    0.947608    3.457142    0.296037    0.120318    0.000116    0.707903    
#> 171: 0.555567    0.929149    3.457130    0.229202    0.098540    0.000117    0.726903    
#> 172: 0.550892    0.946863    3.454820    0.186873    0.109234    0.000083    0.725447    
#> 173: 0.561056    0.942319    3.454529    0.237914    0.100751    0.000107    0.700814    
#> 174: 0.567814    0.921642    3.455691    0.240216    0.103042    0.000120    0.701388    
#> 175: 0.544522    0.931643    3.452563    0.240079    0.112343    0.000124    0.719139    
#> 176: 0.562091    0.961065    3.453466    0.250730    0.110513    0.000104    0.721880    
#> 177: 0.574587    0.933941    3.453451    0.210152    0.084841    0.000074    0.719355    
#> 178: 0.584457    0.933273    3.453578    0.206184    0.105519    0.000067    0.734742    
#> 179: 0.601104    0.950731    3.453047    0.287256    0.094481    0.000062    0.728857    
#> 180: 0.557473    0.949454    3.453553    0.233510    0.107760    0.000056    0.718554    
#> 181: 0.566961    0.930455    3.451651    0.271274    0.098626    0.000051    0.693346    
#> 182: 0.544574    0.946219    3.451258    0.257108    0.100922    0.000046    0.727573    
#> 183: 0.559037    0.951221    3.451205    0.261347    0.114235    0.000046    0.698997    
#> 184: 0.536015    0.936297    3.450429    0.238991    0.120803    0.000032    0.720410    
#> 185: 0.559055    0.941698    3.449832    0.243564    0.115897    0.000032    0.710639    
#> 186: 0.519498    0.947681    3.449553    0.252489    0.110762    0.000031    0.710766    
#> 187: 0.530990    0.939465    3.450260    0.264168    0.104087    0.000034    0.707943    
#> 188: 0.525102    0.945579    3.448500    0.208156    0.110850    0.000043    0.723155    
#> 189: 0.553566    0.950271    3.448814    0.208425    0.095128    0.000042    0.723744    
#> 190: 0.526534    0.926286    3.450194    0.198616    0.103836    0.000037    0.724039    
#> 191: 0.517631    0.930614    3.450105    0.282599    0.092171    0.000034    0.714500    
#> 192: 0.529117    0.948890    3.451368    0.251445    0.088463    0.000034    0.720761    
#> 193: 0.577551    0.939376    3.451105    0.266061    0.086102    0.000037    0.711868    
#> 194: 0.564676    0.935922    3.449525    0.262372    0.082844    0.000048    0.715137    
#> 195: 0.520923    0.942892    3.448797    0.195334    0.101047    0.000041    0.705775    
#> 196: 0.529913    0.926610    3.450052    0.220490    0.099805    0.000034    0.717746    
#> 197: 0.525865    0.920421    3.452163    0.258893    0.101688    0.000032    0.709841    
#> 198: 0.590738    0.915844    3.451398    0.289857    0.108906    0.000034    0.700616    
#> 199: 0.560407    0.929024    3.452538    0.321495    0.097497    0.000037    0.703374    
#> 200: 0.575730    0.935078    3.452911    0.297951    0.098472    0.000039    0.722128    
#> 201: 0.564344    0.927141    3.453212    0.274274    0.097102    0.000038    0.711824    
#> 202: 0.562334    0.925747    3.453349    0.272122    0.103347    0.000040    0.716514    
#> 203: 0.564229    0.922992    3.453331    0.270306    0.107959    0.000041    0.714647    
#> 204: 0.562530    0.919241    3.453516    0.277717    0.108664    0.000041    0.713029    
#> 205: 0.563482    0.921591    3.453474    0.282302    0.106942    0.000040    0.715111    
#> 206: 0.563708    0.925706    3.453556    0.279124    0.105817    0.000039    0.716943    
#> 207: 0.562987    0.927460    3.453532    0.279397    0.107310    0.000038    0.715689    
#> 208: 0.561818    0.927435    3.453525    0.272625    0.107716    0.000037    0.715531    
#> 209: 0.563136    0.925610    3.453496    0.266497    0.107423    0.000038    0.714514    
#> 210: 0.565628    0.924080    3.453460    0.266409    0.107220    0.000037    0.713336    
#> 211: 0.567040    0.925373    3.453411    0.267813    0.108144    0.000036    0.712244    
#> 212: 0.570325    0.925312    3.453406    0.268655    0.107642    0.000035    0.712195    
#> 213: 0.572160    0.923636    3.453364    0.267730    0.107884    0.000035    0.714256    
#> 214: 0.573663    0.924062    3.453326    0.265615    0.106539    0.000035    0.714449    
#> 215: 0.574271    0.924668    3.453289    0.264834    0.105568    0.000035    0.713944    
#> 216: 0.574745    0.925036    3.453278    0.262561    0.105064    0.000034    0.714567    
#> 217: 0.574420    0.926864    3.453246    0.260734    0.105136    0.000034    0.714285    
#> 218: 0.574943    0.927185    3.453138    0.258343    0.105353    0.000034    0.714271    
#> 219: 0.573791    0.926591    3.453025    0.256678    0.105193    0.000034    0.714410    
#> 220: 0.570591    0.926585    3.453008    0.256588    0.104562    0.000034    0.714907    
#> 221: 0.568608    0.927236    3.452932    0.256851    0.104879    0.000034    0.714491    
#> 222: 0.567496    0.927190    3.452898    0.256791    0.104965    0.000034    0.714678    
#> 223: 0.568536    0.927590    3.452830    0.257597    0.105055    0.000033    0.714695    
#> 224: 0.568341    0.928944    3.452795    0.257373    0.105269    0.000033    0.715106    
#> 225: 0.568450    0.927149    3.452814    0.257645    0.106044    0.000033    0.715431    
#> 226: 0.568954    0.926651    3.452820    0.257268    0.106445    0.000033    0.715385    
#> 227: 0.568738    0.926307    3.452841    0.256724    0.106727    0.000033    0.715343    
#> 228: 0.568181    0.927621    3.452805    0.254959    0.106212    0.000032    0.715611    
#> 229: 0.567690    0.927330    3.452793    0.254166    0.105955    0.000032    0.715570    
#> 230: 0.567595    0.927044    3.452783    0.252941    0.105674    0.000032    0.715806    
#> 231: 0.567809    0.926896    3.452788    0.252161    0.105376    0.000031    0.716155    
#> 232: 0.566453    0.927060    3.452827    0.250947    0.105140    0.000031    0.716045    
#> 233: 0.565463    0.926250    3.452855    0.251202    0.105457    0.000031    0.716541    
#> 234: 0.564599    0.926151    3.452872    0.252526    0.105090    0.000031    0.716301    
#> 235: 0.564530    0.926427    3.452875    0.251880    0.105404    0.000031    0.716537    
#> 236: 0.564358    0.926837    3.452865    0.251089    0.105373    0.000031    0.717057    
#> 237: 0.564615    0.926774    3.452853    0.250298    0.105084    0.000031    0.717706    
#> 238: 0.564630    0.927064    3.452835    0.250224    0.105160    0.000031    0.717768    
#> 239: 0.564232    0.927366    3.452843    0.250931    0.105220    0.000031    0.717812    
#> 240: 0.564055    0.927133    3.452821    0.251700    0.105036    0.000030    0.717751    
#> 241: 0.564269    0.926364    3.452837    0.252774    0.105394    0.000030    0.717587    
#> 242: 0.564054    0.925687    3.452824    0.252365    0.105609    0.000030    0.718048    
#> 243: 0.563327    0.925642    3.452819    0.251125    0.105738    0.000030    0.718381    
#> 244: 0.562663    0.925569    3.452805    0.251056    0.105529    0.000030    0.718223    
#> 245: 0.562332    0.925693    3.452800    0.250785    0.105722    0.000030    0.718460    
#> 246: 0.562435    0.925444    3.452807    0.250523    0.106136    0.000030    0.718188    
#> 247: 0.562419    0.925230    3.452816    0.250358    0.106498    0.000030    0.718043    
#> 248: 0.561953    0.925472    3.452810    0.250351    0.106626    0.000030    0.717707    
#> 249: 0.561665    0.925519    3.452820    0.250335    0.106980    0.000030    0.717457    
#> 250: 0.561751    0.925556    3.452807    0.249616    0.107064    0.000030    0.717283    
#> 251: 0.562154    0.926512    3.452811    0.249144    0.107033    0.000030    0.717687    
#> 252: 0.562325    0.927102    3.452827    0.248639    0.106968    0.000029    0.717918    
#> 253: 0.561561    0.927629    3.452835    0.248084    0.106723    0.000029    0.717828    
#> 254: 0.561790    0.927723    3.452847    0.248199    0.106600    0.000029    0.717465    
#> 255: 0.561699    0.928236    3.452878    0.248706    0.106548    0.000030    0.717204    
#> 256: 0.561875    0.928050    3.452886    0.248045    0.106417    0.000030    0.717376    
#> 257: 0.561866    0.927646    3.452882    0.248560    0.106667    0.000030    0.717422    
#> 258: 0.562046    0.927292    3.452867    0.248740    0.106811    0.000029    0.717294    
#> 259: 0.562273    0.927259    3.452853    0.249241    0.106645    0.000029    0.717087    
#> 260: 0.561952    0.927458    3.452855    0.248997    0.106529    0.000030    0.716675    
#> 261: 0.561910    0.927477    3.452863    0.249197    0.106509    0.000030    0.716704    
#> 262: 0.561823    0.927702    3.452853    0.249970    0.106316    0.000030    0.716651    
#> 263: 0.561031    0.927986    3.452842    0.250281    0.106487    0.000030    0.716589    
#> 264: 0.560330    0.928176    3.452820    0.250650    0.106761    0.000030    0.716578    
#> 265: 0.560698    0.928443    3.452802    0.252177    0.106962    0.000030    0.716443    
#> 266: 0.560931    0.928516    3.452782    0.253159    0.106938    0.000030    0.716065    
#> 267: 0.560940    0.928774    3.452773    0.253927    0.106862    0.000030    0.715941    
#> 268: 0.561220    0.928479    3.452751    0.254614    0.106857    0.000030    0.716026    
#> 269: 0.561769    0.928392    3.452750    0.255141    0.106829    0.000030    0.715993    
#> 270: 0.562227    0.928473    3.452728    0.255328    0.106643    0.000030    0.715980    
#> 271: 0.562142    0.928549    3.452699    0.255194    0.106432    0.000030    0.716412    
#> 272: 0.561968    0.928415    3.452679    0.254498    0.106225    0.000030    0.716656    
#> 273: 0.561867    0.928659    3.452664    0.254787    0.105912    0.000030    0.716907    
#> 274: 0.561692    0.928726    3.452658    0.254518    0.105892    0.000030    0.717061    
#> 275: 0.561518    0.928727    3.452642    0.254481    0.105977    0.000030    0.716832    
#> 276: 0.561348    0.928833    3.452654    0.254595    0.106021    0.000030    0.716832    
#> 277: 0.561135    0.929060    3.452663    0.254371    0.105986    0.000030    0.716708    
#> 278: 0.560862    0.929000    3.452668    0.254468    0.106079    0.000030    0.716750    
#> 279: 0.560683    0.928915    3.452660    0.254474    0.105968    0.000030    0.716996    
#> 280: 0.560588    0.929027    3.452659    0.255122    0.105978    0.000030    0.716767    
#> 281: 0.560245    0.929221    3.452656    0.254991    0.105976    0.000030    0.716680    
#> 282: 0.560273    0.929344    3.452656    0.254873    0.105872    0.000030    0.716684    
#> 283: 0.560231    0.929445    3.452667    0.255149    0.106037    0.000030    0.716716    
#> 284: 0.559982    0.929350    3.452678    0.255194    0.106198    0.000030    0.716791    
#> 285: 0.559907    0.929511    3.452673    0.254776    0.106068    0.000030    0.716949    
#> 286: 0.560106    0.929703    3.452673    0.254361    0.106065    0.000031    0.716902    
#> 287: 0.560306    0.929883    3.452664    0.254166    0.105917    0.000031    0.716930    
#> 288: 0.560605    0.929733    3.452658    0.254177    0.106130    0.000031    0.716876    
#> 289: 0.561049    0.929615    3.452659    0.254513    0.106187    0.000031    0.716838    
#> 290: 0.561281    0.929614    3.452652    0.254344    0.106004    0.000031    0.716987    
#> 291: 0.561356    0.929831    3.452644    0.254432    0.105800    0.000031    0.716700    
#> 292: 0.561321    0.929933    3.452638    0.254503    0.105642    0.000031    0.716645    
#> 293: 0.561152    0.929829    3.452619    0.254568    0.105634    0.000031    0.716443    
#> 294: 0.561017    0.929910    3.452603    0.254494    0.105638    0.000031    0.716413    
#> 295: 0.560848    0.929628    3.452595    0.254187    0.105570    0.000031    0.716443    
#> 296: 0.560604    0.929583    3.452597    0.254080    0.105530    0.000031    0.716457    
#> 297: 0.560504    0.929624    3.452595    0.253715    0.105477    0.000031    0.716567    
#> 298: 0.560533    0.929613    3.452601    0.253728    0.105419    0.000031    0.716462    
#> 299: 0.560673    0.929559    3.452612    0.253837    0.105488    0.000031    0.716354    
#> 300: 0.560675    0.929437    3.452625    0.253853    0.105503    0.000031    0.716223    
#> 301: 0.561000    0.929266    3.452634    0.254045    0.105481    0.000031    0.716155    
#> 302: 0.560803    0.929381    3.452638    0.253829    0.105504    0.000031    0.716152    
#> 303: 0.560689    0.929463    3.452645    0.253619    0.105489    0.000031    0.715982    
#> 304: 0.561058    0.929601    3.452639    0.253701    0.105538    0.000031    0.715902    
#> 305: 0.561136    0.929328    3.452639    0.253848    0.105507    0.000032    0.715850    
#> 306: 0.561126    0.929186    3.452632    0.253861    0.105516    0.000032    0.715749    
#> 307: 0.561334    0.929108    3.452627    0.254270    0.105334    0.000031    0.715828    
#> 308: 0.560845    0.928899    3.452622    0.254408    0.105320    0.000031    0.715996    
#> 309: 0.560615    0.928664    3.452614    0.254920    0.105412    0.000031    0.716031    
#> 310: 0.560656    0.928641    3.452597    0.254607    0.105431    0.000031    0.716008    
#> 311: 0.560542    0.928692    3.452592    0.254432    0.105396    0.000031    0.715975    
#> 312: 0.560141    0.928596    3.452587    0.254642    0.105378    0.000031    0.715979    
#> 313: 0.559988    0.928407    3.452582    0.254758    0.105584    0.000031    0.715999    
#> 314: 0.559759    0.928472    3.452573    0.254814    0.105594    0.000031    0.715999    
#> 315: 0.559368    0.928556    3.452571    0.254875    0.105576    0.000031    0.716011    
#> 316: 0.559419    0.928586    3.452571    0.254882    0.105473    0.000031    0.716064    
#> 317: 0.559353    0.928614    3.452571    0.255164    0.105394    0.000031    0.716112    
#> 318: 0.559288    0.928744    3.452557    0.255219    0.105329    0.000031    0.716118    
#> 319: 0.559311    0.928664    3.452546    0.255513    0.105236    0.000031    0.716012    
#> 320: 0.559138    0.928611    3.452531    0.255482    0.105161    0.000031    0.716078    
#> 321: 0.558885    0.928779    3.452511    0.255168    0.105224    0.000031    0.716049    
#> 322: 0.558748    0.928714    3.452497    0.254791    0.105225    0.000031    0.716042    
#> 323: 0.558224    0.928627    3.452491    0.254572    0.105148    0.000031    0.716095    
#> 324: 0.558237    0.928663    3.452493    0.254653    0.105086    0.000031    0.715992    
#> 325: 0.558138    0.928704    3.452493    0.254625    0.105014    0.000031    0.715940    
#> 326: 0.558096    0.928427    3.452487    0.254700    0.105069    0.000031    0.715940    
#> 327: 0.558154    0.928567    3.452489    0.254507    0.105012    0.000031    0.716074    
#> 328: 0.558330    0.928547    3.452491    0.254470    0.104918    0.000031    0.716057    
#> 329: 0.558464    0.928540    3.452502    0.254679    0.104811    0.000031    0.716060    
#> 330: 0.558318    0.928565    3.452507    0.254624    0.104814    0.000031    0.715982    
#> 331: 0.558366    0.928714    3.452510    0.254789    0.104875    0.000031    0.715893    
#> 332: 0.558592    0.928652    3.452514    0.255106    0.104997    0.000031    0.715757    
#> 333: 0.558601    0.928654    3.452514    0.255294    0.105100    0.000031    0.715598    
#> 334: 0.558593    0.928484    3.452510    0.255373    0.105289    0.000031    0.715559    
#> 335: 0.558526    0.928535    3.452504    0.255440    0.105290    0.000031    0.715392    
#> 336: 0.558267    0.928780    3.452501    0.255672    0.105240    0.000031    0.715364    
#> 337: 0.558107    0.929067    3.452493    0.255526    0.105163    0.000031    0.715320    
#> 338: 0.557926    0.929158    3.452493    0.255523    0.105117    0.000031    0.715354    
#> 339: 0.557975    0.929431    3.452493    0.255713    0.105102    0.000031    0.715383    
#> 340: 0.557955    0.929325    3.452498    0.255578    0.104956    0.000031    0.715571    
#> 341: 0.558164    0.929380    3.452505    0.255364    0.104956    0.000031    0.715605    
#> 342: 0.558011    0.929274    3.452503    0.255307    0.104915    0.000031    0.715491    
#> 343: 0.557751    0.929212    3.452508    0.255255    0.104853    0.000031    0.715554    
#> 344: 0.557799    0.929213    3.452514    0.255307    0.104842    0.000031    0.715575    
#> 345: 0.557828    0.929238    3.452523    0.255316    0.104805    0.000031    0.715631    
#> 346: 0.557875    0.929309    3.452528    0.255309    0.104793    0.000031    0.715535    
#> 347: 0.557980    0.929317    3.452521    0.255304    0.104731    0.000031    0.715478    
#> 348: 0.557862    0.929392    3.452514    0.255293    0.104725    0.000031    0.715378    
#> 349: 0.558062    0.929292    3.452505    0.255458    0.104802    0.000031    0.715280    
#> 350: 0.558045    0.929135    3.452500    0.255684    0.104806    0.000031    0.715286    
#> 351: 0.558241    0.929216    3.452490    0.255805    0.104734    0.000031    0.715250    
#> 352: 0.558024    0.929275    3.452486    0.255448    0.104721    0.000031    0.715269    
#> 353: 0.558177    0.929305    3.452483    0.255216    0.104841    0.000031    0.715289    
#> 354: 0.558370    0.929190    3.452470    0.255070    0.104950    0.000031    0.715215    
#> 355: 0.558565    0.929084    3.452460    0.254803    0.105005    0.000031    0.715294    
#> 356: 0.558472    0.928941    3.452454    0.255059    0.104944    0.000031    0.715339    
#> 357: 0.558640    0.929002    3.452451    0.255264    0.104995    0.000031    0.715329    
#> 358: 0.558583    0.929082    3.452453    0.255354    0.105123    0.000031    0.715374    
#> 359: 0.558591    0.929232    3.452457    0.255255    0.105019    0.000031    0.715427    
#> 360: 0.558563    0.929221    3.452453    0.255125    0.104975    0.000031    0.715400    
#> 361: 0.558400    0.929132    3.452449    0.255183    0.104970    0.000031    0.715378    
#> 362: 0.558455    0.929107    3.452446    0.255065    0.104927    0.000031    0.715361    
#> 363: 0.558439    0.929091    3.452444    0.255088    0.104850    0.000031    0.715311    
#> 364: 0.558513    0.929121    3.452436    0.255150    0.104852    0.000031    0.715354    
#> 365: 0.558540    0.928930    3.452433    0.255314    0.104964    0.000031    0.715351    
#> 366: 0.558510    0.928984    3.452429    0.255242    0.104865    0.000031    0.715342    
#> 367: 0.558596    0.928967    3.452425    0.255093    0.104866    0.000031    0.715417    
#> 368: 0.558529    0.929021    3.452418    0.254858    0.104883    0.000031    0.715415    
#> 369: 0.558588    0.929073    3.452416    0.254777    0.104875    0.000031    0.715442    
#> 370: 0.558515    0.929200    3.452417    0.254720    0.104966    0.000031    0.715449    
#> 371: 0.558462    0.929258    3.452412    0.254747    0.104932    0.000031    0.715419    
#> 372: 0.558619    0.929318    3.452406    0.254946    0.104888    0.000031    0.715522    
#> 373: 0.558461    0.929398    3.452397    0.254914    0.104897    0.000031    0.715617    
#> 374: 0.558532    0.929458    3.452386    0.254745    0.104924    0.000031    0.715599    
#> 375: 0.558548    0.929492    3.452378    0.254554    0.104958    0.000031    0.715626    
#> 376: 0.558416    0.929568    3.452373    0.254457    0.104897    0.000031    0.715677    
#> 377: 0.558271    0.929636    3.452370    0.254433    0.104760    0.000031    0.715724    
#> 378: 0.558072    0.929654    3.452367    0.254582    0.104749    0.000031    0.715717    
#> 379: 0.557971    0.929542    3.452367    0.254550    0.104726    0.000031    0.715698    
#> 380: 0.557896    0.929555    3.452365    0.254436    0.104711    0.000031    0.715678    
#> 381: 0.557754    0.929517    3.452361    0.254227    0.104759    0.000031    0.715705    
#> 382: 0.557864    0.929431    3.452360    0.254408    0.104645    0.000031    0.715685    
#> 383: 0.557980    0.929394    3.452358    0.254594    0.104635    0.000031    0.715656    
#> 384: 0.557941    0.929324    3.452365    0.254555    0.104537    0.000031    0.715690    
#> 385: 0.557921    0.929302    3.452367    0.254391    0.104577    0.000031    0.715732    
#> 386: 0.558028    0.929547    3.452365    0.254358    0.104657    0.000031    0.715787    
#> 387: 0.558068    0.929652    3.452369    0.254182    0.104642    0.000031    0.715716    
#> 388: 0.558182    0.929736    3.452376    0.254126    0.104618    0.000031    0.715698    
#> 389: 0.558131    0.929647    3.452378    0.253910    0.104622    0.000031    0.715751    
#> 390: 0.558106    0.929810    3.452373    0.253550    0.104603    0.000031    0.715808    
#> 391: 0.558146    0.929741    3.452370    0.253225    0.104586    0.000031    0.715808    
#> 392: 0.558236    0.929759    3.452371    0.253212    0.104577    0.000031    0.715782    
#> 393: 0.558242    0.929724    3.452367    0.253386    0.104553    0.000031    0.715715    
#> 394: 0.558284    0.929710    3.452362    0.253412    0.104525    0.000031    0.715627    
#> 395: 0.558457    0.929773    3.452357    0.253352    0.104494    0.000031    0.715623    
#> 396: 0.558560    0.929872    3.452359    0.253308    0.104531    0.000031    0.715597    
#> 397: 0.558585    0.929845    3.452361    0.253353    0.104488    0.000031    0.715582    
#> 398: 0.558617    0.929854    3.452361    0.253427    0.104470    0.000031    0.715514    
#> 399: 0.558614    0.929861    3.452366    0.253591    0.104436    0.000031    0.715457    
#> 400: 0.558723    0.929918    3.452369    0.253601    0.104402    0.000031    0.715379    
#> 401: 0.558728    0.929946    3.452372    0.253942    0.104402    0.000031    0.715308    
#> 402: 0.558778    0.930136    3.452375    0.254055    0.104387    0.000031    0.715304    
#> 403: 0.558993    0.930136    3.452375    0.254111    0.104312    0.000031    0.715382    
#> 404: 0.559072    0.930169    3.452370    0.254117    0.104358    0.000031    0.715361    
#> 405: 0.559162    0.930197    3.452370    0.254067    0.104455    0.000031    0.715363    
#> 406: 0.559245    0.930193    3.452367    0.254046    0.104453    0.000031    0.715408    
#> 407: 0.559306    0.930224    3.452370    0.254000    0.104443    0.000031    0.715322    
#> 408: 0.559358    0.930293    3.452374    0.253991    0.104359    0.000031    0.715320    
#> 409: 0.559296    0.930224    3.452372    0.253985    0.104337    0.000031    0.715268    
#> 410: 0.559413    0.930252    3.452369    0.254158    0.104307    0.000031    0.715283    
#> 411: 0.559709    0.930111    3.452366    0.254510    0.104366    0.000031    0.715309    
#> 412: 0.559918    0.930232    3.452361    0.254581    0.104339    0.000031    0.715362    
#> 413: 0.559970    0.930250    3.452356    0.254706    0.104301    0.000031    0.715373    
#> 414: 0.559874    0.930235    3.452352    0.254724    0.104263    0.000030    0.715328    
#> 415: 0.559878    0.930150    3.452350    0.254775    0.104200    0.000030    0.715345    
#> 416: 0.559879    0.930172    3.452347    0.254739    0.104167    0.000030    0.715320    
#> 417: 0.559878    0.930239    3.452341    0.254664    0.104122    0.000030    0.715268    
#> 418: 0.559744    0.930352    3.452334    0.254554    0.104099    0.000030    0.715298    
#> 419: 0.559865    0.930449    3.452328    0.254635    0.104043    0.000030    0.715248    
#> 420: 0.559946    0.930505    3.452320    0.254589    0.104004    0.000030    0.715257    
#> 421: 0.559843    0.930556    3.452318    0.254548    0.103922    0.000030    0.715288    
#> 422: 0.559974    0.930454    3.452318    0.254456    0.103876    0.000030    0.715345    
#> 423: 0.560111    0.930425    3.452319    0.254239    0.103741    0.000030    0.715560    
#> 424: 0.560041    0.930433    3.452318    0.254054    0.103752    0.000030    0.715584    
#> 425: 0.560166    0.930534    3.452316    0.253902    0.103844    0.000030    0.715603    
#> 426: 0.560139    0.930541    3.452313    0.253743    0.103887    0.000030    0.715641    
#> 427: 0.560131    0.930474    3.452307    0.253550    0.103837    0.000030    0.715628    
#> 428: 0.559906    0.930558    3.452303    0.253404    0.103772    0.000030    0.715589    
#> 429: 0.559863    0.930628    3.452300    0.253242    0.103733    0.000030    0.715553    
#> 430: 0.559872    0.930708    3.452296    0.253221    0.103735    0.000030    0.715505    
#> 431: 0.559795    0.930699    3.452292    0.253313    0.103671    0.000030    0.715454    
#> 432: 0.559701    0.930752    3.452290    0.253304    0.103702    0.000030    0.715385    
#> 433: 0.559705    0.930776    3.452289    0.253323    0.103714    0.000030    0.715361    
#> 434: 0.559525    0.930712    3.452287    0.253332    0.103625    0.000030    0.715416    
#> 435: 0.559583    0.930722    3.452285    0.253408    0.103666    0.000030    0.715416    
#> 436: 0.559568    0.930589    3.452285    0.253413    0.103793    0.000030    0.715480    
#> 437: 0.559482    0.930546    3.452279    0.253416    0.103799    0.000030    0.715448    
#> 438: 0.559389    0.930648    3.452277    0.253426    0.103753    0.000030    0.715482    
#> 439: 0.559262    0.930756    3.452272    0.253454    0.103759    0.000030    0.715434    
#> 440: 0.559171    0.930781    3.452272    0.253602    0.103802    0.000030    0.715409    
#> 441: 0.559277    0.930721    3.452274    0.253788    0.103860    0.000030    0.715335    
#> 442: 0.559310    0.930773    3.452276    0.253977    0.103841    0.000030    0.715262    
#> 443: 0.559411    0.930889    3.452276    0.254198    0.103823    0.000030    0.715248    
#> 444: 0.559438    0.930934    3.452279    0.254515    0.103872    0.000030    0.715193    
#> 445: 0.559399    0.930892    3.452278    0.254726    0.103869    0.000030    0.715152    
#> 446: 0.559289    0.930981    3.452274    0.254856    0.103948    0.000030    0.715073    
#> 447: 0.559355    0.931018    3.452270    0.254843    0.103975    0.000030    0.715055    
#> 448: 0.559330    0.931003    3.452269    0.255002    0.103965    0.000030    0.714949    
#> 449: 0.559353    0.931074    3.452275    0.254987    0.104021    0.000030    0.714902    
#> 450: 0.559281    0.931067    3.452278    0.254875    0.104071    0.000030    0.714924    
#> 451: 0.559279    0.931169    3.452279    0.254924    0.104104    0.000030    0.714909    
#> 452: 0.559266    0.931229    3.452274    0.255155    0.104054    0.000030    0.714835    
#> 453: 0.559282    0.931169    3.452274    0.255316    0.104015    0.000030    0.714809    
#> 454: 0.559186    0.931233    3.452271    0.255292    0.104021    0.000030    0.714782    
#> 455: 0.559282    0.931278    3.452267    0.255181    0.103988    0.000030    0.714826    
#> 456: 0.559288    0.931270    3.452265    0.255077    0.104097    0.000030    0.714830    
#> 457: 0.559272    0.931209    3.452266    0.255002    0.104105    0.000030    0.714797    
#> 458: 0.559223    0.931290    3.452268    0.254738    0.104158    0.000030    0.714821    
#> 459: 0.559054    0.931370    3.452270    0.254815    0.104161    0.000030    0.714799    
#> 460: 0.558842    0.931357    3.452269    0.254914    0.104172    0.000030    0.714815    
#> 461: 0.558726    0.931361    3.452269    0.254897    0.104192    0.000030    0.714825    
#> 462: 0.558620    0.931404    3.452273    0.255002    0.104178    0.000030    0.714780    
#> 463: 0.558533    0.931517    3.452271    0.254852    0.104123    0.000030    0.714788    
#> 464: 0.558506    0.931593    3.452271    0.254847    0.104094    0.000030    0.714750    
#> 465: 0.558509    0.931458    3.452270    0.254888    0.104111    0.000030    0.714697    
#> 466: 0.558595    0.931474    3.452266    0.254800    0.104097    0.000030    0.714673    
#> 467: 0.558556    0.931394    3.452263    0.254804    0.104112    0.000030    0.714596    
#> 468: 0.558734    0.931412    3.452264    0.254886    0.104157    0.000030    0.714611    
#> 469: 0.558808    0.931493    3.452265    0.254882    0.104252    0.000030    0.714651    
#> 470: 0.558774    0.931557    3.452265    0.254873    0.104240    0.000030    0.714651    
#> 471: 0.558711    0.931523    3.452267    0.254769    0.104230    0.000030    0.714662    
#> 472: 0.558698    0.931547    3.452271    0.254678    0.104283    0.000030    0.714634    
#> 473: 0.558661    0.931527    3.452271    0.254721    0.104229    0.000030    0.714658    
#> 474: 0.558683    0.931548    3.452272    0.254637    0.104171    0.000030    0.714684    
#> 475: 0.558786    0.931589    3.452270    0.254552    0.104147    0.000030    0.714673    
#> 476: 0.558930    0.931581    3.452264    0.254678    0.104187    0.000030    0.714733    
#> 477: 0.558926    0.931539    3.452261    0.254760    0.104220    0.000030    0.714660    
#> 478: 0.558898    0.931506    3.452262    0.254765    0.104282    0.000030    0.714635    
#> 479: 0.558918    0.931479    3.452264    0.254820    0.104366    0.000030    0.714608    
#> 480: 0.558883    0.931482    3.452269    0.254710    0.104366    0.000030    0.714650    
#> 481: 0.558833    0.931441    3.452272    0.254721    0.104397    0.000030    0.714619    
#> 482: 0.558998    0.931424    3.452274    0.254891    0.104461    0.000030    0.714623    
#> 483: 0.559018    0.931293    3.452273    0.255057    0.104462    0.000030    0.714599    
#> 484: 0.559026    0.931193    3.452274    0.255036    0.104451    0.000030    0.714623    
#> 485: 0.559210    0.931235    3.452276    0.255277    0.104487    0.000030    0.714663    
#> 486: 0.559322    0.931239    3.452275    0.255330    0.104564    0.000030    0.714681    
#> 487: 0.559448    0.931260    3.452278    0.255339    0.104550    0.000030    0.714622    
#> 488: 0.559475    0.931291    3.452281    0.255499    0.104597    0.000030    0.714581    
#> 489: 0.559615    0.931292    3.452285    0.255552    0.104591    0.000030    0.714581    
#> 490: 0.559676    0.931296    3.452288    0.255457    0.104609    0.000030    0.714617    
#> 491: 0.559703    0.931357    3.452293    0.255442    0.104628    0.000030    0.714594    
#> 492: 0.559727    0.931429    3.452294    0.255385    0.104698    0.000030    0.714673    
#> 493: 0.559688    0.931449    3.452294    0.255470    0.104807    0.000030    0.714734    
#> 494: 0.559675    0.931489    3.452291    0.255375    0.104815    0.000030    0.714703    
#> 495: 0.559785    0.931442    3.452289    0.255306    0.104788    0.000030    0.714728    
#> 496: 0.559893    0.931511    3.452285    0.255220    0.104812    0.000030    0.714709    
#> 497: 0.559847    0.931526    3.452281    0.255230    0.104803    0.000031    0.714704    
#> 498: 0.559860    0.931544    3.452276    0.255339    0.104829    0.000031    0.714657    
#> 499: 0.559901    0.931538    3.452274    0.255291    0.104786    0.000031    0.714703    
#> 500: 0.560013    0.931506    3.452268    0.255509    0.104840    0.000031    0.714717    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.307914    0.966561    3.444007    0.392401    0.092311    0.016800    1.712924    
#> 002: 0.285391    1.060428    3.465454    0.372781    0.087696    0.015960    1.107061    
#> 003: 0.424416    1.039826    3.503855    0.354142    0.083311    0.015304    0.880593    
#> 004: 0.373544    1.077602    3.508906    0.336435    0.082294    0.015333    0.780146    
#> 005: 0.445478    1.073885    3.503629    0.319613    0.087676    0.014566    0.755409    
#> 006: 0.446807    1.063231    3.516770    0.303633    0.083292    0.013838    0.725875    
#> 007: 0.440994    1.077435    3.512599    0.288451    0.085349    0.013146    0.746576    
#> 008: 0.402226    1.071747    3.498576    0.274029    0.090534    0.014458    0.739603    
#> 009: 0.371189    1.061285    3.494046    0.260327    0.091551    0.015512    0.753534    
#> 010: 0.388673    1.063167    3.499871    0.247311    0.091602    0.016646    0.742390    
#> 011: 0.482356    1.081454    3.515217    0.234945    0.087022    0.018012    0.753714    
#> 012: 0.473987    1.069311    3.501360    0.223198    0.082671    0.022195    0.736518    
#> 013: 0.368045    1.064147    3.493074    0.212038    0.078538    0.024156    0.732716    
#> 014: 0.425007    1.065010    3.505418    0.238666    0.105330    0.022948    0.727746    
#> 015: 0.470220    1.052060    3.519236    0.226733    0.100063    0.021801    0.716101    
#> 016: 0.457717    1.080897    3.522088    0.231372    0.095060    0.026935    0.737953    
#> 017: 0.443825    1.079201    3.512593    0.219803    0.090307    0.025589    0.726552    
#> 018: 0.448427    1.097046    3.494505    0.216138    0.085792    0.026347    0.743271    
#> 019: 0.422620    1.099524    3.502041    0.215007    0.081502    0.025030    0.725759    
#> 020: 0.439489    1.064818    3.520925    0.204257    0.082907    0.028462    0.726303    
#> 021: 0.489918    1.049467    3.532136    0.199639    0.078762    0.027039    0.726417    
#> 022: 0.487581    1.044596    3.537067    0.205028    0.074823    0.025816    0.728330    
#> 023: 0.552509    1.057343    3.543593    0.208604    0.071082    0.026822    0.732836    
#> 024: 0.534967    1.081566    3.538274    0.198174    0.067528    0.026189    0.726215    
#> 025: 0.531559    1.063034    3.531958    0.197807    0.072619    0.025180    0.736544    
#> 026: 0.463220    1.080768    3.519728    0.187917    0.068988    0.025937    0.743396    
#> 027: 0.406290    1.106078    3.507610    0.207914    0.065539    0.028020    0.745694    
#> 028: 0.457180    1.091295    3.526228    0.209861    0.062262    0.027248    0.733468    
#> 029: 0.472862    1.073380    3.508746    0.200987    0.063956    0.025886    0.761098    
#> 030: 0.493383    1.112293    3.502004    0.190938    0.078141    0.024592    0.732551    
#> 031: 0.436188    1.074085    3.509241    0.181391    0.074234    0.023362    0.741855    
#> 032: 0.425429    1.072275    3.519630    0.172322    0.070522    0.022194    0.729307    
#> 033: 0.436084    1.082746    3.509905    0.209114    0.066996    0.021939    0.721847    
#> 034: 0.459980    1.078876    3.509207    0.221655    0.063646    0.020842    0.726766    
#> 035: 0.417534    1.085327    3.497366    0.260436    0.064546    0.019800    0.701646    
#> 036: 0.415783    1.093253    3.500268    0.247414    0.065353    0.018810    0.723340    
#> 037: 0.401064    1.096717    3.498265    0.235043    0.062086    0.017869    0.736180    
#> 038: 0.443169    1.081307    3.487625    0.223291    0.058981    0.017588    0.741446    
#> 039: 0.430189    1.080770    3.504399    0.236779    0.061307    0.018453    0.720207    
#> 040: 0.435163    1.089760    3.508078    0.224940    0.058242    0.017530    0.742190    
#> 041: 0.402996    1.095762    3.499545    0.213693    0.069885    0.018354    0.734486    
#> 042: 0.441367    1.067998    3.501024    0.223578    0.066390    0.017436    0.723891    
#> 043: 0.411850    1.095315    3.485546    0.246811    0.063071    0.020319    0.724644    
#> 044: 0.363751    1.119515    3.473708    0.234470    0.066626    0.019303    0.747424    
#> 045: 0.386173    1.130284    3.467251    0.222746    0.071385    0.018338    0.749743    
#> 046: 0.385391    1.104503    3.473880    0.220089    0.067815    0.017421    0.750437    
#> 047: 0.408762    1.115312    3.463707    0.209084    0.064425    0.016813    0.743493    
#> 048: 0.419585    1.117739    3.473833    0.198630    0.067811    0.015972    0.745821    
#> 049: 0.392507    1.091556    3.491050    0.202529    0.070234    0.018374    0.742320    
#> 050: 0.460268    1.069969    3.503608    0.192403    0.077281    0.017456    0.757679    
#> 051: 0.433408    1.077170    3.510272    0.182783    0.075209    0.018615    0.751164    
#> 052: 0.413921    1.096995    3.503141    0.191167    0.073601    0.017684    0.717259    
#> 053: 0.432893    1.078269    3.503228    0.195025    0.087316    0.016800    0.725996    
#> 054: 0.402837    1.068425    3.504525    0.185274    0.082950    0.016177    0.750905    
#> 055: 0.452825    1.050111    3.521410    0.239101    0.078802    0.016994    0.746553    
#> 056: 0.503279    1.032828    3.526329    0.227965    0.078116    0.017449    0.744873    
#> 057: 0.500825    1.038721    3.539221    0.216567    0.074210    0.019559    0.753382    
#> 058: 0.531589    1.015205    3.537540    0.205738    0.070499    0.018783    0.755231    
#> 059: 0.513241    1.000648    3.547519    0.240078    0.066974    0.024342    0.751022    
#> 060: 0.504494    0.977892    3.550323    0.268527    0.063989    0.025387    0.762530    
#> 061: 0.552679    1.016975    3.552568    0.268386    0.067483    0.024118    0.778357    
#> 062: 0.532001    1.021230    3.555944    0.254966    0.077177    0.024654    0.779887    
#> 063: 0.539384    1.003495    3.547913    0.283039    0.073318    0.027626    0.759538    
#> 064: 0.484974    1.035609    3.540616    0.268887    0.069652    0.026244    0.750107    
#> 065: 0.492522    1.054270    3.524061    0.255442    0.074102    0.024932    0.745655    
#> 066: 0.496266    1.068223    3.531454    0.246042    0.070397    0.024687    0.740521    
#> 067: 0.482002    1.063446    3.525162    0.233739    0.066877    0.027544    0.719049    
#> 068: 0.406732    1.067483    3.515752    0.222052    0.072335    0.028265    0.747108    
#> 069: 0.452722    1.065285    3.513938    0.231385    0.068718    0.026852    0.746957    
#> 070: 0.452409    1.084450    3.518476    0.227811    0.066550    0.027167    0.739240    
#> 071: 0.403735    1.118197    3.490610    0.241286    0.081463    0.026169    0.743302    
#> 072: 0.405285    1.091656    3.496624    0.254084    0.077390    0.024861    0.740088    
#> 073: 0.428978    1.101420    3.509721    0.273443    0.073521    0.025769    0.746886    
#> 074: 0.401737    1.062049    3.506326    0.260073    0.069845    0.024481    0.727617    
#> 075: 0.482494    1.029679    3.547361    0.247069    0.066352    0.023257    0.728570    
#> 076: 0.498771    1.058628    3.543435    0.259167    0.063035    0.027724    0.730125    
#> 077: 0.527695    1.054523    3.541580    0.246209    0.062541    0.026337    0.750120    
#> 078: 0.498069    1.060999    3.532755    0.233899    0.059414    0.025021    0.740412    
#> 079: 0.516822    1.059717    3.536097    0.222204    0.069969    0.023769    0.732777    
#> 080: 0.493200    1.054811    3.535029    0.233375    0.066470    0.022821    0.748577    
#> 081: 0.509276    1.053899    3.528073    0.246820    0.063147    0.026771    0.720660    
#> 082: 0.477895    1.055795    3.530626    0.234479    0.063161    0.025433    0.747459    
#> 083: 0.489547    1.069650    3.526729    0.222755    0.063325    0.024161    0.727620    
#> 084: 0.475520    1.072026    3.510777    0.215064    0.073675    0.022953    0.723029    
#> 085: 0.458577    1.081358    3.520757    0.231807    0.092007    0.021805    0.734116    
#> 086: 0.453915    1.061594    3.506877    0.243117    0.087407    0.020715    0.724237    
#> 087: 0.420781    1.066084    3.503401    0.230961    0.087236    0.019679    0.722203    
#> 088: 0.373630    1.086257    3.488978    0.240890    0.082874    0.018695    0.735777    
#> 089: 0.401225    1.093288    3.484314    0.250611    0.092545    0.017761    0.729642    
#> 090: 0.397321    1.071216    3.494394    0.238080    0.087918    0.020717    0.756994    
#> 091: 0.400875    1.068904    3.485979    0.226176    0.083522    0.021369    0.738922    
#> 092: 0.393742    1.092368    3.482044    0.220460    0.079346    0.021865    0.740613    
#> 093: 0.397510    1.073886    3.493021    0.231212    0.075379    0.023144    0.752632    
#> 094: 0.414818    1.087839    3.489086    0.219651    0.071610    0.025027    0.747115    
#> 095: 0.428320    1.064441    3.517109    0.208668    0.068029    0.023776    0.750242    
#> 096: 0.388692    1.093888    3.503468    0.198235    0.083054    0.022587    0.731539    
#> 097: 0.421410    1.104816    3.500511    0.188323    0.081181    0.021458    0.725723    
#> 098: 0.400574    1.130954    3.511005    0.178907    0.077122    0.020385    0.759280    
#> 099: 0.408547    1.088889    3.490912    0.169962    0.083671    0.019366    0.730715    
#> 100: 0.409497    1.088136    3.499887    0.161464    0.079488    0.018398    0.739325    
#> 101: 0.382256    1.076075    3.485844    0.156810    0.075513    0.017478    0.741618    
#> 102: 0.355072    1.100161    3.474257    0.148970    0.071738    0.016604    0.749876    
#> 103: 0.422823    1.090607    3.491505    0.187831    0.073281    0.015774    0.729572    
#> 104: 0.442214    1.066341    3.523182    0.178440    0.069617    0.017779    0.741874    
#> 105: 0.451569    1.067049    3.522770    0.174907    0.071481    0.017890    0.725576    
#> 106: 0.464507    1.065145    3.520332    0.188849    0.069304    0.017403    0.720906    
#> 107: 0.499824    1.073485    3.535051    0.195064    0.065838    0.019925    0.737547    
#> 108: 0.482667    1.075010    3.525804    0.185311    0.069824    0.018929    0.747393    
#> 109: 0.453747    1.046977    3.533704    0.187610    0.066333    0.017982    0.750194    
#> 110: 0.474877    1.036580    3.523243    0.193636    0.063016    0.017083    0.749968    
#> 111: 0.484555    1.044146    3.528643    0.183954    0.059866    0.016229    0.735094    
#> 112: 0.448618    1.026016    3.511750    0.174757    0.056872    0.019148    0.748394    
#> 113: 0.437492    1.081318    3.504562    0.178612    0.054029    0.018190    0.720921    
#> 114: 0.442674    1.078492    3.509894    0.169845    0.062131    0.018430    0.720543    
#> 115: 0.463310    1.066756    3.505888    0.178481    0.062700    0.017508    0.749673    
#> 116: 0.428521    1.084742    3.506156    0.169557    0.072068    0.016633    0.768819    
#> 117: 0.444532    1.089138    3.512765    0.161079    0.080408    0.015801    0.763607    
#> 118: 0.477172    1.066418    3.516656    0.153025    0.090448    0.015628    0.727178    
#> 119: 0.464770    1.072133    3.520140    0.145374    0.085926    0.014847    0.752535    
#> 120: 0.439815    1.053644    3.512990    0.154209    0.082241    0.014104    0.747946    
#> 121: 0.461640    1.103326    3.513538    0.155624    0.095849    0.014924    0.732588    
#> 122: 0.454182    1.054892    3.516185    0.151309    0.091056    0.014775    0.735784    
#> 123: 0.468667    1.096307    3.511257    0.167323    0.086503    0.014036    0.751054    
#> 124: 0.487523    1.110153    3.519717    0.159254    0.093994    0.016287    0.719312    
#> 125: 0.501062    1.084476    3.518027    0.182522    0.089294    0.017460    0.746215    
#> 126: 0.440217    1.108027    3.498245    0.175038    0.086352    0.016587    0.751183    
#> 127: 0.452517    1.085725    3.502425    0.218819    0.082035    0.018495    0.750378    
#> 128: 0.433566    1.066164    3.512133    0.207878    0.077933    0.018895    0.743559    
#> 129: 0.446434    1.095873    3.515301    0.199306    0.076301    0.021057    0.745995    
#> 130: 0.491839    1.090137    3.512790    0.189340    0.074299    0.020004    0.737194    
#> 131: 0.418423    1.070704    3.504135    0.179873    0.075602    0.022212    0.732534    
#> 132: 0.403899    1.090861    3.490086    0.170880    0.071822    0.022515    0.744138    
#> 133: 0.411522    1.085572    3.492401    0.214052    0.068231    0.024711    0.733559    
#> 134: 0.462918    1.040374    3.516989    0.217787    0.064819    0.025613    0.744164    
#> 135: 0.454305    1.048079    3.527657    0.206897    0.061578    0.025919    0.736830    
#> 136: 0.455549    1.048069    3.522320    0.196553    0.058499    0.024623    0.716336    
#> 137: 0.492704    1.022909    3.530425    0.186725    0.056854    0.023528    0.733040    
#> 138: 0.493693    1.034008    3.537515    0.177389    0.056312    0.023003    0.729385    
#> 139: 0.493183    1.080261    3.537436    0.168519    0.062498    0.024065    0.722321    
#> 140: 0.499485    1.089878    3.538787    0.189253    0.059373    0.026950    0.746147    
#> 141: 0.459271    1.072882    3.534683    0.179790    0.056404    0.025603    0.755034    
#> 142: 0.501880    1.041263    3.551092    0.185409    0.058170    0.025187    0.736180    
#> 143: 0.468963    1.050095    3.534998    0.207243    0.055261    0.026593    0.755762    
#> 144: 0.506617    1.067082    3.549946    0.231402    0.057634    0.025264    0.731357    
#> 145: 0.470563    1.075446    3.527145    0.219831    0.059484    0.024001    0.739423    
#> 146: 0.481890    1.079990    3.539526    0.208840    0.061306    0.022801    0.756932    
#> 147: 0.438928    1.067328    3.521577    0.198398    0.059960    0.021661    0.734650    
#> 148: 0.456825    1.076254    3.527199    0.203945    0.056962    0.023757    0.722345    
#> 149: 0.423660    1.078053    3.508366    0.214019    0.054114    0.025744    0.737202    
#> 150: 0.456079    1.070845    3.505468    0.214932    0.053015    0.024457    0.751639    
#> 151: 0.383703    1.094657    3.498346    0.204186    0.050364    0.023234    0.735536    
#> 152: 0.392058    1.098197    3.500628    0.176431    0.051390    0.024549    0.725182    
#> 153: 0.420549    1.106081    3.509398    0.191084    0.066092    0.018220    0.735090    
#> 154: 0.433231    1.092615    3.509367    0.167490    0.054019    0.018246    0.733491    
#> 155: 0.437118    1.068749    3.505240    0.138694    0.067604    0.014584    0.729534    
#> 156: 0.429102    1.084222    3.513002    0.158560    0.055212    0.017384    0.750544    
#> 157: 0.458952    1.063425    3.521259    0.169517    0.066614    0.018239    0.762004    
#> 158: 0.480973    1.078746    3.507928    0.200523    0.064408    0.016779    0.754923    
#> 159: 0.416785    1.088659    3.517933    0.184812    0.066201    0.019660    0.757038    
#> 160: 0.465739    1.045305    3.524761    0.193934    0.069472    0.019913    0.752680    
#> 161: 0.473147    1.060158    3.524506    0.188002    0.068663    0.021022    0.756923    
#> 162: 0.426801    1.090867    3.503890    0.182548    0.065835    0.018767    0.753844    
#> 163: 0.476603    1.077991    3.512384    0.201628    0.075376    0.019654    0.743346    
#> 164: 0.482712    1.073069    3.513725    0.221579    0.065781    0.015959    0.739619    
#> 165: 0.483974    1.055759    3.530804    0.167851    0.057552    0.018121    0.730667    
#> 166: 0.482559    1.098481    3.524550    0.153477    0.069239    0.018480    0.733726    
#> 167: 0.478143    1.080143    3.535427    0.175483    0.059629    0.017749    0.739301    
#> 168: 0.467250    1.099613    3.521045    0.210589    0.061764    0.017659    0.741752    
#> 169: 0.479394    1.102420    3.515436    0.188846    0.064872    0.014586    0.751806    
#> 170: 0.470769    1.073205    3.520597    0.212035    0.071785    0.014826    0.738693    
#> 171: 0.426514    1.093295    3.510791    0.195634    0.069536    0.014967    0.701871    
#> 172: 0.432625    1.104010    3.512727    0.170886    0.075508    0.015812    0.699134    
#> 173: 0.434234    1.112906    3.497668    0.176490    0.071715    0.015694    0.720125    
#> 174: 0.427528    1.096199    3.505803    0.196269    0.067369    0.014266    0.733761    
#> 175: 0.417562    1.091117    3.486777    0.217134    0.066245    0.013291    0.740033    
#> 176: 0.392623    1.123504    3.485860    0.184513    0.067641    0.012556    0.736927    
#> 177: 0.401287    1.093147    3.497561    0.174563    0.070589    0.008255    0.747910    
#> 178: 0.391754    1.101779    3.491665    0.196600    0.068773    0.011638    0.739268    
#> 179: 0.409368    1.101952    3.491875    0.160723    0.081054    0.013542    0.761951    
#> 180: 0.415819    1.101117    3.490719    0.207621    0.082955    0.013914    0.727946    
#> 181: 0.434861    1.094919    3.484134    0.187347    0.078249    0.011693    0.741190    
#> 182: 0.405675    1.099635    3.476052    0.152977    0.073598    0.012565    0.765776    
#> 183: 0.382280    1.131910    3.475141    0.175324    0.088312    0.012163    0.765521    
#> 184: 0.369282    1.098776    3.483023    0.176687    0.075973    0.012825    0.768998    
#> 185: 0.396610    1.129368    3.487522    0.196379    0.087166    0.012482    0.752178    
#> 186: 0.397319    1.128260    3.488577    0.201722    0.086845    0.014748    0.745257    
#> 187: 0.399488    1.098480    3.501927    0.217451    0.081152    0.010514    0.738561    
#> 188: 0.389918    1.098427    3.498311    0.201737    0.080448    0.012897    0.745425    
#> 189: 0.422543    1.100432    3.496511    0.216855    0.079547    0.015154    0.738842    
#> 190: 0.405083    1.099014    3.498455    0.255411    0.063270    0.012162    0.748554    
#> 191: 0.396200    1.092587    3.491348    0.173780    0.068158    0.012579    0.732772    
#> 192: 0.420152    1.093068    3.503148    0.189656    0.066545    0.016769    0.717798    
#> 193: 0.476588    1.113207    3.505782    0.195108    0.067756    0.018491    0.724741    
#> 194: 0.443881    1.084188    3.507457    0.186015    0.071945    0.019785    0.738042    
#> 195: 0.442438    1.081727    3.511954    0.216618    0.067404    0.018553    0.722859    
#> 196: 0.436156    1.089735    3.512572    0.166200    0.058613    0.017936    0.745858    
#> 197: 0.373480    1.083098    3.524027    0.170079    0.069900    0.017704    0.750076    
#> 198: 0.431318    1.078682    3.495507    0.153832    0.063799    0.020319    0.746924    
#> 199: 0.421095    1.070496    3.498604    0.196846    0.062483    0.022369    0.711947    
#> 200: 0.417379    1.081180    3.501982    0.219683    0.055136    0.024739    0.737390    
#> 201: 0.425447    1.076561    3.511609    0.220368    0.052363    0.026758    0.730803    
#> 202: 0.429604    1.073534    3.513592    0.208989    0.053611    0.024523    0.728911    
#> 203: 0.442697    1.072973    3.509019    0.202958    0.056814    0.022800    0.729135    
#> 204: 0.453526    1.063111    3.514451    0.199531    0.060385    0.023050    0.728359    
#> 205: 0.460714    1.065680    3.518622    0.193414    0.062511    0.023323    0.733940    
#> 206: 0.464558    1.066713    3.522064    0.190100    0.061087    0.024235    0.737458    
#> 207: 0.463679    1.065289    3.521360    0.194019    0.060043    0.024283    0.739525    
#> 208: 0.466543    1.064773    3.522481    0.194046    0.058732    0.024724    0.740804    
#> 209: 0.469850    1.062206    3.523053    0.192964    0.058931    0.024826    0.739622    
#> 210: 0.474418    1.061144    3.523807    0.191415    0.059203    0.024684    0.739002    
#> 211: 0.475250    1.061355    3.524498    0.188443    0.059636    0.024559    0.738409    
#> 212: 0.474753    1.061192    3.524206    0.187922    0.061207    0.024167    0.736800    
#> 213: 0.476998    1.058464    3.525119    0.188023    0.062917    0.024194    0.736246    
#> 214: 0.480411    1.058183    3.525688    0.187528    0.063730    0.024239    0.736474    
#> 215: 0.479683    1.058515    3.526573    0.187383    0.063611    0.024314    0.736934    
#> 216: 0.480181    1.057620    3.526912    0.186236    0.063928    0.024027    0.738893    
#> 217: 0.479992    1.058502    3.526780    0.185560    0.064291    0.023708    0.739260    
#> 218: 0.480039    1.058745    3.526244    0.186164    0.064619    0.023299    0.738710    
#> 219: 0.479340    1.058604    3.525961    0.187300    0.064474    0.023259    0.738572    
#> 220: 0.479097    1.059644    3.525880    0.189112    0.065196    0.023328    0.737597    
#> 221: 0.478912    1.060107    3.525789    0.190101    0.065603    0.023197    0.737512    
#> 222: 0.478340    1.060406    3.525157    0.190740    0.065511    0.023276    0.738134    
#> 223: 0.479641    1.060318    3.525400    0.190057    0.065048    0.023253    0.738039    
#> 224: 0.480975    1.060915    3.525555    0.188860    0.064773    0.023098    0.737916    
#> 225: 0.479941    1.059255    3.525672    0.187816    0.064423    0.022999    0.738312    
#> 226: 0.479066    1.058406    3.525110    0.187687    0.064339    0.022790    0.738785    
#> 227: 0.476983    1.058769    3.524634    0.188043    0.064508    0.022572    0.738164    
#> 228: 0.474750    1.059962    3.523385    0.188693    0.064964    0.022443    0.737971    
#> 229: 0.472966    1.060219    3.522405    0.188508    0.065150    0.022164    0.737556    
#> 230: 0.471793    1.060762    3.521531    0.188653    0.065206    0.021860    0.737787    
#> 231: 0.470794    1.061705    3.521060    0.189521    0.065379    0.021619    0.737911    
#> 232: 0.469270    1.061568    3.521064    0.189273    0.065282    0.021501    0.738154    
#> 233: 0.468062    1.061117    3.521068    0.187845    0.065270    0.021443    0.738262    
#> 234: 0.466883    1.061435    3.520878    0.187678    0.065335    0.021337    0.737981    
#> 235: 0.466155    1.061280    3.520493    0.187644    0.065269    0.021185    0.737863    
#> 236: 0.465944    1.062165    3.520160    0.187223    0.065452    0.021142    0.738300    
#> 237: 0.466371    1.062896    3.519954    0.185797    0.065445    0.021100    0.738901    
#> 238: 0.466530    1.063278    3.520084    0.183792    0.065638    0.021137    0.740064    
#> 239: 0.465056    1.064237    3.519624    0.182676    0.065817    0.021190    0.740120    
#> 240: 0.464688    1.064536    3.519662    0.182070    0.066076    0.021160    0.739762    
#> 241: 0.464172    1.063822    3.519771    0.181889    0.065814    0.021165    0.740116    
#> 242: 0.464123    1.063651    3.519746    0.182185    0.065645    0.021160    0.740428    
#> 243: 0.464114    1.063988    3.519905    0.182336    0.065551    0.021198    0.740895    
#> 244: 0.462925    1.064236    3.519885    0.182313    0.065205    0.021290    0.741492    
#> 245: 0.463105    1.063919    3.520212    0.182348    0.064989    0.021266    0.741997    
#> 246: 0.463247    1.063759    3.520397    0.181939    0.065188    0.021306    0.742225    
#> 247: 0.463180    1.063482    3.520791    0.181787    0.065187    0.021262    0.742292    
#> 248: 0.463805    1.063567    3.521112    0.181007    0.065116    0.021224    0.742163    
#> 249: 0.463596    1.063577    3.521367    0.180604    0.064934    0.021234    0.742048    
#> 250: 0.464034    1.063835    3.521651    0.180377    0.064697    0.021244    0.742277    
#> 251: 0.464632    1.064620    3.521957    0.180014    0.064467    0.021276    0.742703    
#> 252: 0.464848    1.064788    3.522103    0.179254    0.064156    0.021304    0.742708    
#> 253: 0.464726    1.065364    3.521944    0.179484    0.064067    0.021340    0.742746    
#> 254: 0.464225    1.065982    3.521919    0.179286    0.063923    0.021368    0.742449    
#> 255: 0.464160    1.066426    3.521855    0.179233    0.063740    0.021418    0.742764    
#> 256: 0.463446    1.066521    3.521488    0.179113    0.063722    0.021410    0.742785    
#> 257: 0.462820    1.066258    3.521093    0.178832    0.064077    0.021443    0.742547    
#> 258: 0.462442    1.065891    3.520809    0.178665    0.064315    0.021359    0.742419    
#> 259: 0.461992    1.065899    3.520720    0.178693    0.064461    0.021264    0.742243    
#> 260: 0.461704    1.066121    3.520826    0.178526    0.064537    0.021228    0.741731    
#> 261: 0.461746    1.066097    3.520832    0.178288    0.064587    0.021155    0.741715    
#> 262: 0.462411    1.066193    3.520966    0.177942    0.064586    0.021140    0.741916    
#> 263: 0.462028    1.066569    3.520825    0.178198    0.064522    0.021130    0.741695    
#> 264: 0.461698    1.066709    3.520748    0.178363    0.064552    0.021126    0.741878    
#> 265: 0.461772    1.066535    3.520782    0.177660    0.064557    0.021095    0.742288    
#> 266: 0.461983    1.066635    3.520743    0.177276    0.064589    0.021091    0.742413    
#> 267: 0.462058    1.066519    3.520963    0.176940    0.064582    0.021079    0.742460    
#> 268: 0.462098    1.066328    3.520929    0.177434    0.064557    0.021039    0.742508    
#> 269: 0.462126    1.066428    3.520804    0.177743    0.064464    0.021089    0.742263    
#> 270: 0.462164    1.066599    3.520567    0.177669    0.064171    0.021095    0.742058    
#> 271: 0.461982    1.066655    3.520386    0.178138    0.064036    0.021085    0.742168    
#> 272: 0.461650    1.066611    3.520273    0.178483    0.064043    0.021025    0.742572    
#> 273: 0.461326    1.066918    3.520226    0.178218    0.064222    0.021014    0.742673    
#> 274: 0.460634    1.067291    3.520076    0.178269    0.064169    0.020981    0.742504    
#> 275: 0.460526    1.067370    3.519978    0.177895    0.064166    0.020929    0.742344    
#> 276: 0.460613    1.067600    3.520119    0.178134    0.064123    0.020962    0.742165    
#> 277: 0.460864    1.067672    3.520318    0.178337    0.064144    0.020991    0.741955    
#> 278: 0.460948    1.067668    3.520344    0.178573    0.064138    0.021020    0.741830    
#> 279: 0.460678    1.067551    3.520229    0.178766    0.064298    0.021015    0.741896    
#> 280: 0.460325    1.067689    3.520155    0.178562    0.064413    0.020902    0.741911    
#> 281: 0.459895    1.067928    3.520081    0.178587    0.064587    0.020808    0.741881    
#> 282: 0.459820    1.068135    3.520060    0.178777    0.064763    0.020745    0.742120    
#> 283: 0.459479    1.068413    3.519960    0.178628    0.065100    0.020720    0.742232    
#> 284: 0.459249    1.068314    3.519878    0.178597    0.065156    0.020676    0.742161    
#> 285: 0.459058    1.068667    3.519700    0.178394    0.065247    0.020617    0.742203    
#> 286: 0.459332    1.068856    3.519689    0.178362    0.065414    0.020559    0.742122    
#> 287: 0.459381    1.069176    3.519659    0.178261    0.065407    0.020558    0.742237    
#> 288: 0.459371    1.069276    3.519795    0.178211    0.065386    0.020545    0.742517    
#> 289: 0.459916    1.069136    3.519936    0.178140    0.065561    0.020550    0.742671    
#> 290: 0.460044    1.069007    3.519979    0.178057    0.065882    0.020512    0.742820    
#> 291: 0.460082    1.069179    3.520133    0.177605    0.065950    0.020467    0.742822    
#> 292: 0.460210    1.069270    3.520179    0.177940    0.065905    0.020422    0.742656    
#> 293: 0.460086    1.069422    3.520025    0.178208    0.065859    0.020364    0.742578    
#> 294: 0.459798    1.069547    3.519800    0.178560    0.065848    0.020316    0.742318    
#> 295: 0.459491    1.069283    3.519688    0.178511    0.065816    0.020245    0.742149    
#> 296: 0.459497    1.069122    3.519574    0.178650    0.065792    0.020170    0.742145    
#> 297: 0.459672    1.069316    3.519580    0.178995    0.065806    0.020107    0.742146    
#> 298: 0.459896    1.069375    3.519599    0.179044    0.065905    0.020095    0.742085    
#> 299: 0.460232    1.069521    3.519608    0.178980    0.065823    0.020121    0.742012    
#> 300: 0.460328    1.069371    3.519723    0.178947    0.065851    0.020109    0.741969    
#> 301: 0.460513    1.069114    3.519669    0.178902    0.065755    0.020100    0.741994    
#> 302: 0.460703    1.069094    3.519624    0.179068    0.065595    0.020035    0.742238    
#> 303: 0.460883    1.069125    3.519620    0.178823    0.065457    0.020021    0.742256    
#> 304: 0.461374    1.069109    3.519718    0.178716    0.065490    0.020028    0.742178    
#> 305: 0.461252    1.068651    3.519735    0.178741    0.065473    0.020052    0.742071    
#> 306: 0.460871    1.068324    3.519721    0.178861    0.065372    0.020106    0.742073    
#> 307: 0.460523    1.068319    3.519593    0.179101    0.065241    0.020129    0.742112    
#> 308: 0.460092    1.068334    3.519438    0.179422    0.065138    0.020139    0.742260    
#> 309: 0.460051    1.068116    3.519442    0.179649    0.065060    0.020167    0.742280    
#> 310: 0.460325    1.067848    3.519329    0.179777    0.064913    0.020167    0.742384    
#> 311: 0.460321    1.067834    3.519323    0.180390    0.064891    0.020194    0.742332    
#> 312: 0.460240    1.067859    3.519231    0.180340    0.064811    0.020198    0.742156    
#> 313: 0.459928    1.067773    3.519087    0.180355    0.064712    0.020193    0.742193    
#> 314: 0.459411    1.067866    3.519005    0.180340    0.064700    0.020196    0.742140    
#> 315: 0.459196    1.067993    3.518971    0.180834    0.064780    0.020195    0.741997    
#> 316: 0.459310    1.068208    3.518982    0.181175    0.064841    0.020181    0.742021    
#> 317: 0.459602    1.068278    3.519090    0.181383    0.064882    0.020175    0.742211    
#> 318: 0.459890    1.068358    3.519088    0.181338    0.064989    0.020172    0.742132    
#> 319: 0.459826    1.068325    3.519092    0.181168    0.064966    0.020170    0.742004    
#> 320: 0.459121    1.068511    3.518914    0.181230    0.065010    0.020203    0.742150    
#> 321: 0.458419    1.068750    3.518641    0.181092    0.065068    0.020175    0.742381    
#> 322: 0.457834    1.068866    3.518406    0.181075    0.065032    0.020151    0.742317    
#> 323: 0.457389    1.068975    3.518272    0.181113    0.065018    0.020113    0.742212    
#> 324: 0.457734    1.068960    3.518413    0.181290    0.064909    0.020107    0.742260    
#> 325: 0.457633    1.068997    3.518435    0.181150    0.064898    0.020090    0.742247    
#> 326: 0.457725    1.068823    3.518439    0.181130    0.064987    0.020085    0.742206    
#> 327: 0.457739    1.068875    3.518503    0.180726    0.064934    0.020083    0.742157    
#> 328: 0.457849    1.069002    3.518536    0.180724    0.064882    0.020083    0.741918    
#> 329: 0.457785    1.069068    3.518503    0.180859    0.064814    0.020068    0.741816    
#> 330: 0.457621    1.068992    3.518494    0.180750    0.064786    0.020085    0.741861    
#> 331: 0.457739    1.069051    3.518471    0.180586    0.064720    0.020103    0.741854    
#> 332: 0.457902    1.068902    3.518617    0.180463    0.064698    0.020102    0.742160    
#> 333: 0.458124    1.069032    3.518573    0.180444    0.064728    0.020110    0.742361    
#> 334: 0.458067    1.068977    3.518466    0.180420    0.064677    0.020087    0.742468    
#> 335: 0.457824    1.068868    3.518354    0.180146    0.064552    0.020085    0.742458    
#> 336: 0.457649    1.069006    3.518273    0.180158    0.064505    0.020091    0.742592    
#> 337: 0.457584    1.069189    3.518186    0.180036    0.064456    0.020089    0.742564    
#> 338: 0.457882    1.069182    3.518270    0.180006    0.064415    0.020060    0.742496    
#> 339: 0.457792    1.069156    3.518308    0.180057    0.064577    0.020021    0.742469    
#> 340: 0.457652    1.069094    3.518312    0.180331    0.064710    0.020001    0.742378    
#> 341: 0.457798    1.069078    3.518350    0.180575    0.064754    0.019966    0.742374    
#> 342: 0.457568    1.069053    3.518308    0.180579    0.064795    0.019915    0.742363    
#> 343: 0.457341    1.069130    3.518320    0.180765    0.064894    0.019875    0.742250    
#> 344: 0.457597    1.069108    3.518398    0.180806    0.064927    0.019828    0.742225    
#> 345: 0.457946    1.069127    3.518451    0.180874    0.064990    0.019797    0.742135    
#> 346: 0.457948    1.069208    3.518384    0.180844    0.065028    0.019756    0.741996    
#> 347: 0.457954    1.069194    3.518352    0.180654    0.064973    0.019757    0.742002    
#> 348: 0.457849    1.069274    3.518295    0.180700    0.064951    0.019751    0.741958    
#> 349: 0.457741    1.069099    3.518246    0.180730    0.064996    0.019754    0.741970    
#> 350: 0.457507    1.069033    3.518152    0.180630    0.065035    0.019772    0.741944    
#> 351: 0.457625    1.069362    3.518070    0.180558    0.065169    0.019783    0.741842    
#> 352: 0.457335    1.069635    3.517991    0.180538    0.065254    0.019801    0.741925    
#> 353: 0.457163    1.069965    3.517865    0.180482    0.065329    0.019822    0.741794    
#> 354: 0.456976    1.070142    3.517698    0.180416    0.065351    0.019833    0.741670    
#> 355: 0.457279    1.070123    3.517727    0.180397    0.065398    0.019811    0.741714    
#> 356: 0.457246    1.070037    3.517761    0.180597    0.065443    0.019794    0.741742    
#> 357: 0.457472    1.070118    3.517756    0.180937    0.065407    0.019780    0.741605    
#> 358: 0.457602    1.070163    3.517798    0.180987    0.065300    0.019784    0.741518    
#> 359: 0.457471    1.070380    3.517688    0.180818    0.065406    0.019773    0.741536    
#> 360: 0.457038    1.070498    3.517440    0.180786    0.065397    0.019779    0.741475    
#> 361: 0.456698    1.070630    3.517280    0.180969    0.065468    0.019784    0.741399    
#> 362: 0.456647    1.070635    3.517233    0.181275    0.065503    0.019793    0.741161    
#> 363: 0.456546    1.070709    3.517185    0.181290    0.065464    0.019795    0.740969    
#> 364: 0.456503    1.070822    3.517114    0.181234    0.065418    0.019780    0.740987    
#> 365: 0.456340    1.070747    3.517062    0.181226    0.065455    0.019779    0.741060    
#> 366: 0.456064    1.070786    3.516896    0.181245    0.065417    0.019780    0.741087    
#> 367: 0.455932    1.070844    3.516878    0.181195    0.065378    0.019758    0.741106    
#> 368: 0.456034    1.070897    3.516811    0.181493    0.065407    0.019745    0.740957    
#> 369: 0.455969    1.070793    3.516769    0.181419    0.065394    0.019710    0.741086    
#> 370: 0.455841    1.070816    3.516721    0.181448    0.065479    0.019691    0.741158    
#> 371: 0.455520    1.070884    3.516549    0.181220    0.065619    0.019659    0.741207    
#> 372: 0.455368    1.070954    3.516481    0.181059    0.065748    0.019643    0.741289    
#> 373: 0.455110    1.070983    3.516415    0.181177    0.065804    0.019618    0.741307    
#> 374: 0.455092    1.071022    3.516325    0.181347    0.065788    0.019639    0.741212    
#> 375: 0.454974    1.071051    3.516330    0.181648    0.065793    0.019640    0.741227    
#> 376: 0.454991    1.071129    3.516290    0.181557    0.065778    0.019629    0.741157    
#> 377: 0.454923    1.071254    3.516259    0.181554    0.065836    0.019609    0.741034    
#> 378: 0.454680    1.071229    3.516175    0.181448    0.065838    0.019603    0.741010    
#> 379: 0.454655    1.071180    3.516162    0.181415    0.065830    0.019593    0.740954    
#> 380: 0.454487    1.071149    3.516147    0.181324    0.065848    0.019594    0.740859    
#> 381: 0.454331    1.071150    3.516158    0.181310    0.065824    0.019575    0.740898    
#> 382: 0.454329    1.071122    3.516181    0.181289    0.065764    0.019566    0.740844    
#> 383: 0.454533    1.071111    3.516211    0.181336    0.065740    0.019577    0.740809    
#> 384: 0.454305    1.071114    3.516214    0.181219    0.065753    0.019578    0.740828    
#> 385: 0.454427    1.071105    3.516214    0.181188    0.065784    0.019588    0.740849    
#> 386: 0.454456    1.071309    3.516192    0.181176    0.065860    0.019575    0.740837    
#> 387: 0.454729    1.071405    3.516300    0.181277    0.065890    0.019556    0.740834    
#> 388: 0.454758    1.071433    3.516317    0.181375    0.065954    0.019543    0.740778    
#> 389: 0.454591    1.071270    3.516264    0.181367    0.066020    0.019512    0.740754    
#> 390: 0.454314    1.071334    3.516160    0.181448    0.066081    0.019487    0.740821    
#> 391: 0.454306    1.071246    3.516180    0.181388    0.066122    0.019475    0.740776    
#> 392: 0.454404    1.071292    3.516227    0.181188    0.066224    0.019485    0.740889    
#> 393: 0.454249    1.071319    3.516146    0.181032    0.066241    0.019487    0.740892    
#> 394: 0.454173    1.071338    3.516088    0.181091    0.066284    0.019498    0.740894    
#> 395: 0.454384    1.071444    3.516113    0.181031    0.066352    0.019486    0.740874    
#> 396: 0.454460    1.071514    3.516132    0.180870    0.066350    0.019481    0.740871    
#> 397: 0.454712    1.071546    3.516187    0.180818    0.066368    0.019468    0.740883    
#> 398: 0.454849    1.071479    3.516218    0.180795    0.066313    0.019454    0.740910    
#> 399: 0.455040    1.071458    3.516267    0.180776    0.066263    0.019460    0.740784    
#> 400: 0.455167    1.071433    3.516314    0.180664    0.066201    0.019460    0.740744    
#> 401: 0.455186    1.071422    3.516323    0.180515    0.066204    0.019477    0.740896    
#> 402: 0.455126    1.071527    3.516309    0.180310    0.066200    0.019491    0.740888    
#> 403: 0.455374    1.071608    3.516321    0.180269    0.066184    0.019505    0.740882    
#> 404: 0.455431    1.071713    3.516257    0.180428    0.066173    0.019529    0.740805    
#> 405: 0.455347    1.071791    3.516246    0.180497    0.066117    0.019552    0.740863    
#> 406: 0.455226    1.071946    3.516183    0.180673    0.066223    0.019541    0.740924    
#> 407: 0.455261    1.072057    3.516169    0.180714    0.066198    0.019533    0.741026    
#> 408: 0.455136    1.072182    3.516128    0.180760    0.066173    0.019524    0.741160    
#> 409: 0.454959    1.072211    3.516049    0.180708    0.066104    0.019525    0.741138    
#> 410: 0.454896    1.072208    3.515992    0.180730    0.066118    0.019504    0.741190    
#> 411: 0.454811    1.072013    3.515999    0.180509    0.066158    0.019494    0.741302    
#> 412: 0.454720    1.072031    3.515939    0.180547    0.066109    0.019489    0.741340    
#> 413: 0.454581    1.072094    3.515861    0.180581    0.066112    0.019486    0.741338    
#> 414: 0.454353    1.072193    3.515807    0.180609    0.066099    0.019487    0.741310    
#> 415: 0.454207    1.072246    3.515767    0.180555    0.066127    0.019490    0.741235    
#> 416: 0.454257    1.072329    3.515778    0.180599    0.066084    0.019499    0.741159    
#> 417: 0.454370    1.072298    3.515792    0.180545    0.066047    0.019496    0.741137    
#> 418: 0.454251    1.072283    3.515801    0.180539    0.065985    0.019486    0.741095    
#> 419: 0.454198    1.072358    3.515785    0.180397    0.065962    0.019467    0.741114    
#> 420: 0.454282    1.072345    3.515809    0.180411    0.065917    0.019473    0.741029    
#> 421: 0.454162    1.072391    3.515820    0.180451    0.065925    0.019472    0.740986    
#> 422: 0.454190    1.072355    3.515835    0.180307    0.065956    0.019477    0.740965    
#> 423: 0.454391    1.072291    3.515891    0.180264    0.066068    0.019460    0.740946    
#> 424: 0.454477    1.072282    3.515899    0.180242    0.066160    0.019438    0.740945    
#> 425: 0.454645    1.072321    3.515936    0.180377    0.066268    0.019426    0.740960    
#> 426: 0.454803    1.072366    3.515982    0.180478    0.066370    0.019401    0.740896    
#> 427: 0.454806    1.072327    3.516043    0.180558    0.066368    0.019382    0.740832    
#> 428: 0.454798    1.072364    3.516058    0.180660    0.066327    0.019369    0.740808    
#> 429: 0.454841    1.072338    3.516095    0.180601    0.066304    0.019353    0.740770    
#> 430: 0.454768    1.072390    3.516019    0.180615    0.066287    0.019341    0.740752    
#> 431: 0.454584    1.072382    3.515930    0.180675    0.066319    0.019318    0.740657    
#> 432: 0.454474    1.072469    3.515901    0.180854    0.066353    0.019308    0.740582    
#> 433: 0.454516    1.072573    3.515926    0.180823    0.066421    0.019312    0.740533    
#> 434: 0.454391    1.072532    3.515921    0.180724    0.066486    0.019297    0.740539    
#> 435: 0.454384    1.072548    3.515908    0.180657    0.066531    0.019294    0.740529    
#> 436: 0.454130    1.072610    3.515859    0.180704    0.066598    0.019269    0.740583    
#> 437: 0.453994    1.072668    3.515791    0.180710    0.066596    0.019265    0.740605    
#> 438: 0.453881    1.072842    3.515742    0.180720    0.066602    0.019250    0.740568    
#> 439: 0.453880    1.072932    3.515753    0.180550    0.066580    0.019250    0.740531    
#> 440: 0.453800    1.072992    3.515740    0.180561    0.066595    0.019244    0.740501    
#> 441: 0.453691    1.073015    3.515740    0.180682    0.066603    0.019257    0.740423    
#> 442: 0.453453    1.073125    3.515703    0.180636    0.066603    0.019254    0.740348    
#> 443: 0.453276    1.073210    3.515610    0.180498    0.066503    0.019275    0.740331    
#> 444: 0.453101    1.073274    3.515518    0.180359    0.066418    0.019300    0.740334    
#> 445: 0.452912    1.073354    3.515420    0.180282    0.066354    0.019303    0.740378    
#> 446: 0.452630    1.073398    3.515312    0.180123    0.066274    0.019300    0.740387    
#> 447: 0.452646    1.073471    3.515280    0.180033    0.066237    0.019298    0.740389    
#> 448: 0.452606    1.073559    3.515286    0.179962    0.066207    0.019317    0.740288    
#> 449: 0.452490    1.073581    3.515336    0.179859    0.066222    0.019328    0.740293    
#> 450: 0.452409    1.073631    3.515300    0.179908    0.066181    0.019340    0.740346    
#> 451: 0.452423    1.073684    3.515242    0.179961    0.066178    0.019332    0.740406    
#> 452: 0.452309    1.073765    3.515176    0.179904    0.066190    0.019318    0.740422    
#> 453: 0.452235    1.073848    3.515113    0.179845    0.066212    0.019313    0.740348    
#> 454: 0.452191    1.074080    3.515058    0.179899    0.066235    0.019320    0.740254    
#> 455: 0.452167    1.074249    3.515013    0.179963    0.066274    0.019326    0.740180    
#> 456: 0.452024    1.074295    3.514967    0.180074    0.066326    0.019333    0.740108    
#> 457: 0.452005    1.074282    3.514982    0.180118    0.066365    0.019331    0.739982    
#> 458: 0.451953    1.074381    3.515022    0.180080    0.066387    0.019324    0.739927    
#> 459: 0.451749    1.074545    3.514947    0.180130    0.066368    0.019308    0.739883    
#> 460: 0.451579    1.074638    3.514820    0.180068    0.066394    0.019307    0.739912    
#> 461: 0.451367    1.074728    3.514772    0.179997    0.066399    0.019308    0.739965    
#> 462: 0.451176    1.074781    3.514764    0.179883    0.066352    0.019313    0.739963    
#> 463: 0.451173    1.074837    3.514792    0.179912    0.066379    0.019305    0.739938    
#> 464: 0.451230    1.074926    3.514794    0.179896    0.066349    0.019313    0.739844    
#> 465: 0.451311    1.074780    3.514817    0.179851    0.066341    0.019300    0.739781    
#> 466: 0.451388    1.074798    3.514778    0.179929    0.066324    0.019289    0.739706    
#> 467: 0.451391    1.074816    3.514806    0.180040    0.066282    0.019298    0.739628    
#> 468: 0.451514    1.074859    3.514847    0.180285    0.066228    0.019307    0.739629    
#> 469: 0.451581    1.074946    3.514887    0.180442    0.066185    0.019335    0.739683    
#> 470: 0.451606    1.074971    3.514862    0.180517    0.066151    0.019358    0.739643    
#> 471: 0.451399    1.074978    3.514789    0.180674    0.066172    0.019355    0.739582    
#> 472: 0.451333    1.075001    3.514769    0.180797    0.066171    0.019356    0.739528    
#> 473: 0.451174    1.075070    3.514700    0.180818    0.066165    0.019351    0.739479    
#> 474: 0.451039    1.075053    3.514665    0.180860    0.066186    0.019351    0.739453    
#> 475: 0.450997    1.075181    3.514621    0.180809    0.066210    0.019359    0.739386    
#> 476: 0.450905    1.075224    3.514576    0.180643    0.066229    0.019365    0.739448    
#> 477: 0.450850    1.075316    3.514556    0.180630    0.066220    0.019375    0.739371    
#> 478: 0.450696    1.075390    3.514516    0.180630    0.066183    0.019376    0.739318    
#> 479: 0.450738    1.075471    3.514471    0.180510    0.066163    0.019368    0.739302    
#> 480: 0.450735    1.075486    3.514434    0.180522    0.066168    0.019380    0.739336    
#> 481: 0.450668    1.075491    3.514421    0.180431    0.066149    0.019391    0.739267    
#> 482: 0.450776    1.075488    3.514403    0.180503    0.066077    0.019401    0.739315    
#> 483: 0.450666    1.075484    3.514389    0.180526    0.066056    0.019412    0.739264    
#> 484: 0.450633    1.075392    3.514383    0.180491    0.066052    0.019420    0.739225    
#> 485: 0.450619    1.075429    3.514348    0.180542    0.066082    0.019416    0.739157    
#> 486: 0.450546    1.075465    3.514339    0.180522    0.066071    0.019412    0.739107    
#> 487: 0.450782    1.075493    3.514385    0.180570    0.066051    0.019412    0.739044    
#> 488: 0.450814    1.075421    3.514415    0.180692    0.066021    0.019414    0.738978    
#> 489: 0.450849    1.075413    3.514387    0.180649    0.065984    0.019402    0.739024    
#> 490: 0.450853    1.075424    3.514402    0.180678    0.065964    0.019397    0.738975    
#> 491: 0.450858    1.075483    3.514428    0.180689    0.065909    0.019403    0.738989    
#> 492: 0.450813    1.075526    3.514431    0.180593    0.065840    0.019403    0.739057    
#> 493: 0.450756    1.075558    3.514417    0.180577    0.065853    0.019400    0.739051    
#> 494: 0.450862    1.075605    3.514406    0.180629    0.065877    0.019390    0.738999    
#> 495: 0.450945    1.075677    3.514403    0.180601    0.065919    0.019384    0.738922    
#> 496: 0.451019    1.075725    3.514383    0.180614    0.065892    0.019371    0.738979    
#> 497: 0.451040    1.075719    3.514372    0.180646    0.065891    0.019362    0.738951    
#> 498: 0.451101    1.075676    3.514370    0.180688    0.065875    0.019372    0.738876    
#> 499: 0.451114    1.075678    3.514374    0.180724    0.065855    0.019377    0.738863    
#> 500: 0.451204    1.075703    3.514343    0.180759    0.065877    0.019368    0.738821    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.309867    0.968775    3.447375    0.392401    0.081790    0.016800    1.796371    
#> 002: 0.371810    0.939442    3.450299    0.372781    0.077700    0.015960    1.042388    
#> 003: 0.454553    0.921133    3.447462    0.387467    0.077374    0.015162    0.810130    
#> 004: 0.446749    0.950696    3.442319    0.429915    0.090506    0.014404    0.687755    
#> 005: 0.474238    0.978522    3.422517    0.640265    0.085981    0.013684    0.598925    
#> 006: 0.483180    0.969814    3.420718    0.697079    0.081682    0.013476    0.546645    
#> 007: 0.473008    0.974211    3.411754    0.711548    0.077598    0.015627    0.558928    
#> 008: 0.490738    0.987302    3.408990    0.848112    0.073718    0.019838    0.535259    
#> 009: 0.457750    0.951906    3.412049    0.805707    0.070032    0.020820    0.527344    
#> 010: 0.447987    0.955268    3.410400    0.765421    0.066530    0.023719    0.527514    
#> 011: 0.474321    0.947002    3.407858    0.737075    0.064350    0.022533    0.523912    
#> 012: 0.470691    0.969576    3.404318    0.730326    0.061133    0.021407    0.539663    
#> 013: 0.441295    0.988973    3.398177    0.764732    0.058488    0.020336    0.538378    
#> 014: 0.494015    0.988751    3.405069    0.889275    0.072236    0.019320    0.526656    
#> 015: 0.536576    0.993828    3.408921    0.961874    0.068624    0.019338    0.515051    
#> 016: 0.512502    0.974000    3.419328    0.913780    0.065193    0.021975    0.501104    
#> 017: 0.504768    0.992994    3.406598    0.905362    0.061933    0.020877    0.502120    
#> 018: 0.502024    0.991341    3.397689    0.917933    0.058837    0.019833    0.512710    
#> 019: 0.450225    0.987380    3.402727    0.872036    0.057819    0.018841    0.507917    
#> 020: 0.482798    0.992611    3.399497    0.828434    0.066530    0.020452    0.503127    
#> 021: 0.469872    0.982377    3.406312    0.803849    0.063204    0.019429    0.508042    
#> 022: 0.487853    0.983556    3.416043    0.776764    0.060044    0.021344    0.504078    
#> 023: 0.556024    0.987137    3.418675    0.910448    0.057042    0.022460    0.522706    
#> 024: 0.512042    0.988960    3.411801    0.896172    0.054189    0.021337    0.497432    
#> 025: 0.492417    0.966679    3.406974    0.851364    0.051480    0.020270    0.488734    
#> 026: 0.473991    0.978665    3.407801    0.808795    0.057023    0.021474    0.486646    
#> 027: 0.486652    0.998233    3.403296    0.853519    0.054172    0.022878    0.493741    
#> 028: 0.472366    0.996098    3.405557    0.894189    0.053552    0.024129    0.490383    
#> 029: 0.471376    0.996548    3.393316    0.898518    0.053319    0.023370    0.511814    
#> 030: 0.474256    1.000973    3.392451    0.888607    0.050653    0.026500    0.499297    
#> 031: 0.486100    0.983473    3.404328    0.943507    0.051336    0.025669    0.505691    
#> 032: 0.459667    0.981157    3.400570    0.896331    0.048769    0.025188    0.511863    
#> 033: 0.430190    1.007528    3.391771    0.851515    0.050300    0.026972    0.509509    
#> 034: 0.431809    1.008582    3.394937    0.808939    0.065119    0.025624    0.506598    
#> 035: 0.490037    0.980646    3.403979    0.813378    0.061863    0.026097    0.495861    
#> 036: 0.491359    0.979053    3.408492    0.848807    0.058770    0.026904    0.513268    
#> 037: 0.479225    0.989653    3.412525    0.827474    0.055832    0.025559    0.515017    
#> 038: 0.521697    0.975864    3.405786    0.938188    0.053040    0.027357    0.514432    
#> 039: 0.522337    0.987731    3.413600    0.945063    0.054455    0.027357    0.519482    
#> 040: 0.473614    0.984404    3.411137    0.897810    0.051732    0.028172    0.521253    
#> 041: 0.489948    0.985083    3.408867    0.955288    0.049145    0.027775    0.516707    
#> 042: 0.491185    0.982054    3.400984    0.933624    0.046688    0.026386    0.506547    
#> 043: 0.467720    0.989750    3.389154    0.892654    0.051936    0.025067    0.505064    
#> 044: 0.461309    0.989364    3.395828    0.848021    0.049340    0.026342    0.496377    
#> 045: 0.449052    1.004253    3.387961    0.846023    0.047486    0.025025    0.496838    
#> 046: 0.437874    0.989639    3.400408    0.803722    0.045132    0.025010    0.498968    
#> 047: 0.444110    0.995242    3.398484    0.763536    0.043228    0.024713    0.507070    
#> 048: 0.454649    0.987814    3.397024    0.805212    0.043568    0.025630    0.506446    
#> 049: 0.472128    0.973018    3.412509    0.792293    0.055656    0.024348    0.506939    
#> 050: 0.476843    0.959430    3.409384    0.786835    0.054787    0.023131    0.529348    
#> 051: 0.494424    0.972121    3.408755    0.873091    0.063356    0.021974    0.530360    
#> 052: 0.506782    0.983218    3.416157    0.894701    0.060188    0.020876    0.521168    
#> 053: 0.511704    0.973660    3.408744    0.920312    0.058365    0.021140    0.516475    
#> 054: 0.447485    0.986286    3.406605    0.874296    0.055854    0.024001    0.516168    
#> 055: 0.493847    0.985980    3.417528    0.830582    0.053061    0.023261    0.530942    
#> 056: 0.475103    0.977703    3.406859    0.789052    0.050408    0.022098    0.510542    
#> 057: 0.485364    0.979103    3.412000    0.763768    0.051756    0.020993    0.525827    
#> 058: 0.450578    0.977760    3.398311    0.725580    0.049168    0.019943    0.521578    
#> 059: 0.460049    0.959046    3.407525    0.738393    0.048111    0.018946    0.527694    
#> 060: 0.483160    0.970392    3.413800    0.701473    0.059414    0.017999    0.520266    
#> 061: 0.545958    0.971595    3.429739    0.756766    0.056443    0.021721    0.518496    
#> 062: 0.531531    0.978009    3.428157    0.757597    0.055657    0.025959    0.523988    
#> 063: 0.554426    0.965696    3.413839    0.876245    0.056089    0.024661    0.529402    
#> 064: 0.503514    0.971965    3.425149    0.832433    0.053285    0.023428    0.542397    
#> 065: 0.483438    0.965717    3.406604    0.790811    0.050621    0.023688    0.523289    
#> 066: 0.492856    0.972810    3.410301    0.811690    0.048090    0.025686    0.504958    
#> 067: 0.458858    0.972830    3.403307    0.800546    0.051818    0.025088    0.509176    
#> 068: 0.462620    0.987787    3.418640    0.771215    0.060576    0.024071    0.505819    
#> 069: 0.461166    0.984421    3.413600    0.732654    0.060860    0.025304    0.509262    
#> 070: 0.464094    0.977946    3.420234    0.822821    0.057817    0.026274    0.522070    
#> 071: 0.504629    0.995202    3.405328    0.962464    0.054926    0.027524    0.515032    
#> 072: 0.536639    0.966047    3.416133    1.029373    0.052180    0.029999    0.507053    
#> 073: 0.574329    0.988670    3.419839    1.215962    0.051171    0.028499    0.510570    
#> 074: 0.570867    0.969644    3.409717    1.155164    0.048612    0.027074    0.516509    
#> 075: 0.541442    0.962484    3.421280    1.097406    0.050874    0.029865    0.524718    
#> 076: 0.591441    0.985451    3.418877    1.159472    0.051698    0.028860    0.503468    
#> 077: 0.571383    0.974464    3.420373    1.234274    0.061019    0.027417    0.508422    
#> 078: 0.531473    0.974286    3.420802    1.172561    0.057968    0.026046    0.489455    
#> 079: 0.532917    0.989853    3.402842    1.113933    0.061137    0.024744    0.505393    
#> 080: 0.547441    0.985116    3.401527    1.168856    0.059282    0.030498    0.521117    
#> 081: 0.537241    0.987199    3.399573    1.185970    0.056318    0.028974    0.517842    
#> 082: 0.479485    0.960550    3.406785    1.126671    0.055980    0.027525    0.528469    
#> 083: 0.473584    0.987027    3.399728    1.070338    0.056933    0.026149    0.516289    
#> 084: 0.467563    0.987880    3.399262    1.016821    0.054087    0.025136    0.520733    
#> 085: 0.475455    0.990209    3.412245    0.965980    0.055825    0.023979    0.512451    
#> 086: 0.516869    0.986421    3.407392    0.934640    0.054234    0.025502    0.513490    
#> 087: 0.565254    0.977897    3.404836    1.144465    0.051771    0.025270    0.501672    
#> 088: 0.502947    0.984524    3.404250    1.087241    0.049183    0.025122    0.506160    
#> 089: 0.501820    0.985604    3.399568    1.032879    0.060779    0.023865    0.502651    
#> 090: 0.489103    0.974350    3.400573    0.981235    0.057740    0.022672    0.512464    
#> 091: 0.513930    0.970598    3.402247    0.933683    0.055758    0.024953    0.511455    
#> 092: 0.479360    0.995780    3.402021    0.886999    0.056996    0.023705    0.504855    
#> 093: 0.461787    0.990058    3.402566    0.842649    0.054146    0.023728    0.529656    
#> 094: 0.496222    0.987158    3.404390    0.850542    0.051844    0.023853    0.529561    
#> 095: 0.494868    0.995396    3.410841    0.810513    0.050624    0.026286    0.508083    
#> 096: 0.504292    0.995824    3.403288    0.904388    0.052629    0.024971    0.494649    
#> 097: 0.523344    1.001652    3.403297    0.957824    0.055213    0.023723    0.503252    
#> 098: 0.505355    1.008425    3.406967    0.931163    0.052452    0.024370    0.511362    
#> 099: 0.492213    0.984830    3.400610    0.980216    0.056642    0.023151    0.499366    
#> 100: 0.482330    0.998360    3.400283    0.931205    0.056743    0.021994    0.506484    
#> 101: 0.422548    0.993828    3.380716    0.884645    0.056319    0.020894    0.499647    
#> 102: 0.458786    0.998479    3.389308    0.859913    0.056917    0.020006    0.504279    
#> 103: 0.485556    1.003553    3.394440    0.945968    0.054071    0.022904    0.507918    
#> 104: 0.510345    0.998631    3.414807    1.021504    0.055432    0.021759    0.507342    
#> 105: 0.486695    0.976646    3.410895    0.970429    0.058468    0.020671    0.515912    
#> 106: 0.486493    0.969147    3.407304    0.921908    0.055545    0.020422    0.515409    
#> 107: 0.478777    0.972808    3.413315    0.875812    0.052768    0.022618    0.522486    
#> 108: 0.497698    0.967698    3.419529    0.875858    0.055144    0.021487    0.519240    
#> 109: 0.497577    0.977168    3.419721    0.927509    0.052387    0.024416    0.519423    
#> 110: 0.530071    0.966329    3.418345    0.897341    0.052590    0.023865    0.514541    
#> 111: 0.515936    0.965393    3.427226    0.852474    0.051109    0.022671    0.502852    
#> 112: 0.504250    0.955488    3.413228    0.809851    0.053833    0.023885    0.507038    
#> 113: 0.479872    0.991977    3.410420    0.810618    0.051141    0.024739    0.502300    
#> 114: 0.503967    0.975984    3.408632    0.813559    0.048584    0.027425    0.513350    
#> 115: 0.510061    0.960919    3.401482    0.833817    0.046155    0.026053    0.537654    
#> 116: 0.508411    0.963640    3.406038    0.792126    0.048208    0.024751    0.533142    
#> 117: 0.462210    0.974677    3.409110    0.855489    0.049807    0.023513    0.528319    
#> 118: 0.520714    0.966904    3.416037    0.976430    0.054206    0.024131    0.521301    
#> 119: 0.510195    0.970887    3.402246    0.961144    0.054403    0.027817    0.535017    
#> 120: 0.453916    0.975585    3.405837    0.913087    0.051683    0.027692    0.512619    
#> 121: 0.504598    1.006144    3.408786    0.867433    0.052137    0.030903    0.507800    
#> 122: 0.493565    0.979873    3.413176    0.824061    0.049530    0.029358    0.512919    
#> 123: 0.506139    0.995642    3.406738    0.800237    0.049325    0.027890    0.526486    
#> 124: 0.490222    1.010620    3.408885    0.823137    0.053579    0.026496    0.515643    
#> 125: 0.475732    1.012064    3.398705    0.781980    0.050900    0.025171    0.517125    
#> 126: 0.440055    1.017922    3.392556    0.742881    0.051460    0.023912    0.521821    
#> 127: 0.478745    0.998817    3.389123    0.777980    0.052684    0.022717    0.525101    
#> 128: 0.474353    1.011842    3.401108    0.778138    0.052057    0.023894    0.530606    
#> 129: 0.493659    0.994447    3.410634    0.823690    0.058223    0.027303    0.515450    
#> 130: 0.488877    0.992110    3.414209    0.782505    0.055312    0.028519    0.502020    
#> 131: 0.513909    0.968678    3.412275    0.831553    0.054519    0.029936    0.501515    
#> 132: 0.481822    0.975959    3.406434    0.789975    0.053515    0.028440    0.495450    
#> 133: 0.465688    0.974135    3.411242    0.839195    0.053224    0.027620    0.503949    
#> 134: 0.520377    0.950831    3.421571    0.880221    0.050562    0.026301    0.516747    
#> 135: 0.542905    0.953888    3.432503    0.836210    0.050821    0.027687    0.528530    
#> 136: 0.568202    0.960987    3.428934    0.994387    0.048280    0.030496    0.516261    
#> 137: 0.500204    0.971078    3.420618    0.944667    0.046284    0.028971    0.523908    
#> 138: 0.510655    0.974210    3.430685    0.897434    0.056675    0.027523    0.529094    
#> 139: 0.505622    0.969459    3.433309    0.852562    0.055183    0.026147    0.528975    
#> 140: 0.528869    0.969083    3.427099    0.826459    0.052424    0.027507    0.523864    
#> 141: 0.511946    0.963772    3.434078    0.844401    0.050761    0.026132    0.526700    
#> 142: 0.529679    0.948563    3.442057    0.826040    0.048223    0.024825    0.529676    
#> 143: 0.508089    0.964712    3.427977    0.797310    0.051625    0.023584    0.530634    
#> 144: 0.558092    0.969456    3.435253    0.841176    0.049044    0.023233    0.503894    
#> 145: 0.506700    0.965636    3.421813    0.799117    0.046592    0.025435    0.511724    
#> 146: 0.503787    0.973574    3.431306    0.759161    0.049856    0.026452    0.533150    
#> 147: 0.492128    0.959093    3.423871    0.783578    0.050343    0.028246    0.507280    
#> 148: 0.500678    0.965979    3.432069    0.797758    0.052335    0.026833    0.511753    
#> 149: 0.555175    0.973739    3.425333    0.999637    0.049718    0.025950    0.512710    
#> 150: 0.567784    0.970561    3.409006    1.103819    0.048446    0.027154    0.511864    
#> 151: 0.577424    0.987490    3.414643    1.244959    0.048345    0.025796    0.505923    
#> 152: 0.559129    0.983228    3.413784    1.191652    0.042402    0.024498    0.501335    
#> 153: 0.543759    0.981743    3.414583    1.120909    0.043939    0.023538    0.517522    
#> 154: 0.515955    0.989071    3.411972    0.954850    0.044891    0.024675    0.519028    
#> 155: 0.442258    0.984359    3.404851    0.649656    0.057261    0.021738    0.531258    
#> 156: 0.456816    0.983144    3.408856    0.730869    0.044775    0.021528    0.532337    
#> 157: 0.467877    0.982656    3.411714    0.789779    0.055262    0.019498    0.533710    
#> 158: 0.443011    0.995971    3.398433    0.775761    0.051976    0.018114    0.529639    
#> 159: 0.449837    1.005798    3.412836    0.762355    0.051952    0.020765    0.535692    
#> 160: 0.451830    0.979024    3.408775    0.739777    0.054806    0.022718    0.524891    
#> 161: 0.449869    0.988144    3.405256    0.721009    0.058015    0.021631    0.521830    
#> 162: 0.466221    0.992979    3.406410    0.852193    0.060125    0.020506    0.520101    
#> 163: 0.523058    0.971798    3.403874    0.979659    0.056688    0.020160    0.518710    
#> 164: 0.548458    0.981914    3.407273    1.024251    0.049261    0.020967    0.508740    
#> 165: 0.506579    0.978695    3.415059    0.926207    0.053572    0.022932    0.504887    
#> 166: 0.606111    0.993806    3.416905    1.186792    0.052282    0.027143    0.511945    
#> 167: 0.593602    1.011931    3.418963    1.064638    0.050345    0.023058    0.514516    
#> 168: 0.579879    0.990686    3.418018    1.108064    0.050198    0.022222    0.504622    
#> 169: 0.568461    1.007508    3.416740    1.095885    0.049959    0.023943    0.503887    
#> 170: 0.564217    0.989213    3.412905    1.117239    0.051231    0.024293    0.509569    
#> 171: 0.552628    0.998523    3.397207    1.233368    0.054391    0.024021    0.501328    
#> 172: 0.536537    1.016405    3.397447    1.181379    0.055871    0.026139    0.503323    
#> 173: 0.528624    1.016991    3.389700    1.159547    0.051522    0.023693    0.519877    
#> 174: 0.569730    1.007637    3.404473    1.170994    0.046103    0.024590    0.523874    
#> 175: 0.543062    1.001272    3.390002    1.095925    0.043322    0.026277    0.524353    
#> 176: 0.517171    1.009985    3.415813    0.966260    0.047928    0.026856    0.503909    
#> 177: 0.499882    0.993117    3.407642    0.851297    0.045006    0.024135    0.509639    
#> 178: 0.491341    0.977190    3.407394    0.763747    0.043718    0.022953    0.519508    
#> 179: 0.528138    1.008136    3.408930    0.804546    0.049644    0.024552    0.524448    
#> 180: 0.516379    0.990563    3.416246    0.831319    0.050551    0.026315    0.516575    
#> 181: 0.530945    0.980387    3.411117    0.833902    0.052967    0.024260    0.527019    
#> 182: 0.496880    0.985695    3.401397    0.832076    0.047707    0.021987    0.532612    
#> 183: 0.501277    1.008578    3.411607    0.801077    0.045056    0.022435    0.529639    
#> 184: 0.489304    0.986071    3.416426    0.764739    0.050283    0.022120    0.515993    
#> 185: 0.447216    1.000437    3.398729    0.810422    0.049524    0.024384    0.510724    
#> 186: 0.453262    1.000597    3.402724    0.820859    0.057680    0.020408    0.507239    
#> 187: 0.483758    0.991706    3.400961    0.904699    0.056323    0.020575    0.513297    
#> 188: 0.456348    0.992368    3.408577    0.766645    0.054407    0.021039    0.513748    
#> 189: 0.432580    0.997968    3.403669    0.733638    0.062013    0.019234    0.507957    
#> 190: 0.436478    0.994738    3.401247    0.741204    0.053877    0.018608    0.492435    
#> 191: 0.442095    0.999827    3.395649    0.717583    0.054571    0.016785    0.487093    
#> 192: 0.452511    1.006247    3.407449    0.694838    0.057562    0.019275    0.497741    
#> 193: 0.498158    1.003733    3.415222    0.805212    0.058782    0.018665    0.501703    
#> 194: 0.486310    0.981414    3.413840    0.758075    0.058858    0.018613    0.506707    
#> 195: 0.467639    0.980192    3.404885    0.780932    0.053510    0.021767    0.506987    
#> 196: 0.473652    0.967482    3.414645    0.863522    0.049251    0.021955    0.513188    
#> 197: 0.476261    0.974965    3.425327    0.826917    0.060721    0.021403    0.515101    
#> 198: 0.529322    0.960812    3.411891    0.835426    0.053751    0.024649    0.520641    
#> 199: 0.486175    0.964272    3.408587    0.829116    0.058108    0.020555    0.517276    
#> 200: 0.468861    0.973737    3.404287    0.800528    0.058191    0.020664    0.518557    
#> 201: 0.467513    0.974203    3.409210    0.819789    0.058269    0.021892    0.510941    
#> 202: 0.467307    0.974224    3.412350    0.822547    0.055232    0.023020    0.514715    
#> 203: 0.472806    0.977001    3.411401    0.821606    0.055389    0.022583    0.514516    
#> 204: 0.466540    0.975955    3.412334    0.806212    0.056673    0.022324    0.514029    
#> 205: 0.464988    0.981621    3.411023    0.803691    0.057658    0.022055    0.513585    
#> 206: 0.470217    0.985554    3.409938    0.834093    0.057185    0.022308    0.512569    
#> 207: 0.469860    0.988256    3.408429    0.827706    0.054657    0.022615    0.512276    
#> 208: 0.472635    0.989613    3.407679    0.832853    0.053587    0.022741    0.510645    
#> 209: 0.477148    0.987728    3.407512    0.842803    0.053355    0.022829    0.509088    
#> 210: 0.480277    0.986192    3.408228    0.843878    0.053545    0.023193    0.508437    
#> 211: 0.482590    0.985814    3.409051    0.844870    0.053633    0.023309    0.507508    
#> 212: 0.483706    0.985983    3.408849    0.848074    0.053625    0.023204    0.507047    
#> 213: 0.484206    0.984944    3.408925    0.852119    0.053799    0.023277    0.507206    
#> 214: 0.484966    0.984926    3.409085    0.853486    0.053771    0.023343    0.507198    
#> 215: 0.485710    0.985049    3.409410    0.852910    0.053616    0.023458    0.507516    
#> 216: 0.486762    0.984165    3.409495    0.855751    0.053934    0.023557    0.508731    
#> 217: 0.487533    0.984483    3.409683    0.853061    0.054156    0.023558    0.508835    
#> 218: 0.487163    0.984387    3.409435    0.851652    0.054492    0.023386    0.508941    
#> 219: 0.486249    0.984021    3.408819    0.854138    0.054758    0.023238    0.509143    
#> 220: 0.484774    0.984211    3.408406    0.856667    0.055123    0.023277    0.509884    
#> 221: 0.484664    0.984607    3.408117    0.862098    0.055514    0.023302    0.509865    
#> 222: 0.484413    0.984927    3.407218    0.869290    0.055682    0.023307    0.509896    
#> 223: 0.484395    0.984895    3.406598    0.869053    0.055695    0.023304    0.510070    
#> 224: 0.485879    0.985009    3.406214    0.871272    0.055674    0.023286    0.510010    
#> 225: 0.486390    0.984791    3.406132    0.875957    0.055357    0.023462    0.510308    
#> 226: 0.485752    0.984448    3.405759    0.875762    0.055262    0.023517    0.510780    
#> 227: 0.484917    0.984409    3.405560    0.873982    0.055508    0.023635    0.510950    
#> 228: 0.484487    0.984712    3.405028    0.877459    0.055537    0.023688    0.510882    
#> 229: 0.483288    0.984451    3.404737    0.874183    0.055635    0.023670    0.510918    
#> 230: 0.483289    0.984110    3.404807    0.873459    0.055593    0.023665    0.510750    
#> 231: 0.483022    0.984229    3.404900    0.872990    0.055705    0.023720    0.510966    
#> 232: 0.482617    0.984361    3.404919    0.871854    0.055538    0.023876    0.511154    
#> 233: 0.482391    0.984133    3.404800    0.869235    0.055303    0.024041    0.511220    
#> 234: 0.481599    0.984209    3.404495    0.867016    0.055453    0.024187    0.511108    
#> 235: 0.481770    0.983982    3.404451    0.867543    0.055435    0.024276    0.511109    
#> 236: 0.481443    0.983949    3.404189    0.868951    0.055273    0.024288    0.511137    
#> 237: 0.481755    0.984045    3.403950    0.871662    0.055233    0.024416    0.511362    
#> 238: 0.481431    0.984258    3.403560    0.874556    0.055306    0.024623    0.511404    
#> 239: 0.480669    0.984823    3.403079    0.875218    0.055466    0.024582    0.511341    
#> 240: 0.481466    0.984753    3.403086    0.878212    0.055561    0.024562    0.511067    
#> 241: 0.481753    0.984087    3.403197    0.877409    0.055460    0.024519    0.510948    
#> 242: 0.481671    0.983526    3.403157    0.879080    0.055338    0.024476    0.511281    
#> 243: 0.481231    0.983551    3.403199    0.878086    0.055346    0.024526    0.511269    
#> 244: 0.482178    0.983487    3.403503    0.880370    0.055262    0.024577    0.510983    
#> 245: 0.482581    0.983244    3.403718    0.880088    0.055152    0.024616    0.511098    
#> 246: 0.482446    0.983147    3.403771    0.878352    0.055021    0.024615    0.510992    
#> 247: 0.481937    0.982904    3.403798    0.875849    0.054812    0.024560    0.510900    
#> 248: 0.481382    0.983227    3.403722    0.873825    0.054709    0.024485    0.510866    
#> 249: 0.480714    0.983149    3.403813    0.871079    0.054723    0.024421    0.510933    
#> 250: 0.480852    0.983260    3.404060    0.869177    0.054689    0.024393    0.511106    
#> 251: 0.481928    0.983545    3.404410    0.868870    0.054564    0.024422    0.511273    
#> 252: 0.482272    0.983634    3.404741    0.867798    0.054537    0.024367    0.511476    
#> 253: 0.482321    0.983731    3.404909    0.866380    0.054522    0.024372    0.511635    
#> 254: 0.482703    0.983910    3.405166    0.864745    0.054486    0.024409    0.511753    
#> 255: 0.482907    0.984093    3.405246    0.864932    0.054318    0.024483    0.511603    
#> 256: 0.483032    0.983956    3.405245    0.865560    0.054235    0.024544    0.511749    
#> 257: 0.483359    0.983670    3.405186    0.868083    0.054438    0.024610    0.511996    
#> 258: 0.482572    0.983269    3.405082    0.867356    0.054454    0.024659    0.512209    
#> 259: 0.482983    0.983208    3.405119    0.867065    0.054448    0.024686    0.512337    
#> 260: 0.483151    0.983169    3.405225    0.865623    0.054569    0.024677    0.512430    
#> 261: 0.483930    0.982976    3.405343    0.868498    0.054554    0.024602    0.512596    
#> 262: 0.484301    0.982891    3.405417    0.869803    0.054691    0.024566    0.512575    
#> 263: 0.485267    0.982854    3.405492    0.872475    0.054672    0.024591    0.512484    
#> 264: 0.485419    0.983187    3.405436    0.873196    0.054778    0.024533    0.512563    
#> 265: 0.485400    0.983212    3.405512    0.872835    0.054836    0.024475    0.512746    
#> 266: 0.485529    0.983405    3.405720    0.872193    0.054950    0.024415    0.512660    
#> 267: 0.485256    0.983464    3.405926    0.869931    0.055048    0.024343    0.512596    
#> 268: 0.485798    0.983304    3.406022    0.870351    0.055009    0.024279    0.512648    
#> 269: 0.486637    0.983055    3.406194    0.871313    0.054950    0.024252    0.512747    
#> 270: 0.487348    0.983061    3.406382    0.871063    0.054872    0.024246    0.512654    
#> 271: 0.487838    0.982974    3.406503    0.870136    0.054867    0.024237    0.512526    
#> 272: 0.488700    0.982664    3.406633    0.870271    0.054863    0.024240    0.512596    
#> 273: 0.489299    0.982558    3.406874    0.870103    0.054874    0.024229    0.512636    
#> 274: 0.489941    0.982501    3.407128    0.871163    0.054903    0.024208    0.512714    
#> 275: 0.489840    0.982412    3.407152    0.870258    0.054991    0.024186    0.512752    
#> 276: 0.490137    0.982480    3.407277    0.870483    0.055009    0.024220    0.512621    
#> 277: 0.490126    0.982700    3.407373    0.870039    0.054986    0.024227    0.512686    
#> 278: 0.490269    0.982636    3.407473    0.869739    0.055011    0.024235    0.512661    
#> 279: 0.490483    0.982346    3.407581    0.869666    0.055050    0.024226    0.512570    
#> 280: 0.490158    0.982455    3.407513    0.868496    0.054953    0.024168    0.512461    
#> 281: 0.489856    0.982616    3.407466    0.868265    0.055027    0.024114    0.512344    
#> 282: 0.490027    0.982641    3.407524    0.868426    0.055198    0.024108    0.512408    
#> 283: 0.489792    0.982738    3.407559    0.868059    0.055391    0.024099    0.512602    
#> 284: 0.489236    0.982543    3.407600    0.866835    0.055336    0.024055    0.512676    
#> 285: 0.488901    0.982703    3.407544    0.865765    0.055366    0.024004    0.512648    
#> 286: 0.488597    0.982800    3.407469    0.864349    0.055427    0.023964    0.512748    
#> 287: 0.488200    0.982890    3.407343    0.864430    0.055426    0.023968    0.512742    
#> 288: 0.488402    0.982851    3.407266    0.866152    0.055438    0.023999    0.512784    
#> 289: 0.488388    0.982762    3.407165    0.866831    0.055471    0.024026    0.512795    
#> 290: 0.488501    0.982699    3.407197    0.867491    0.055523    0.024007    0.512837    
#> 291: 0.488780    0.982674    3.407327    0.867256    0.055493    0.023987    0.512736    
#> 292: 0.488600    0.982719    3.407149    0.867000    0.055474    0.024014    0.512686    
#> 293: 0.488463    0.982919    3.406989    0.867100    0.055479    0.024018    0.512629    
#> 294: 0.488058    0.983122    3.406853    0.866301    0.055503    0.023994    0.512644    
#> 295: 0.487815    0.983133    3.406741    0.866482    0.055519    0.023962    0.512668    
#> 296: 0.487918    0.983252    3.406714    0.866776    0.055555    0.023920    0.512671    
#> 297: 0.488004    0.983334    3.406738    0.866696    0.055572    0.023870    0.512763    
#> 298: 0.487889    0.983413    3.406771    0.865781    0.055584    0.023837    0.512656    
#> 299: 0.487826    0.983461    3.406783    0.865253    0.055483    0.023844    0.512608    
#> 300: 0.487973    0.983269    3.406852    0.864815    0.055428    0.023871    0.512578    
#> 301: 0.488432    0.983125    3.406914    0.865758    0.055373    0.023881    0.512567    
#> 302: 0.488915    0.983207    3.406834    0.867012    0.055369    0.023896    0.512545    
#> 303: 0.488814    0.983269    3.406852    0.866596    0.055243    0.023916    0.512520    
#> 304: 0.488725    0.983602    3.406795    0.866156    0.055219    0.023931    0.512487    
#> 305: 0.488488    0.983538    3.406774    0.864917    0.055128    0.023945    0.512357    
#> 306: 0.488238    0.983569    3.406712    0.864136    0.055063    0.023988    0.512173    
#> 307: 0.488180    0.983602    3.406646    0.864404    0.054987    0.024039    0.512061    
#> 308: 0.487832    0.983618    3.406597    0.863631    0.054897    0.024074    0.512086    
#> 309: 0.487712    0.983535    3.406592    0.863819    0.054850    0.024070    0.512257    
#> 310: 0.487893    0.983516    3.406495    0.864787    0.054812    0.024057    0.512348    
#> 311: 0.487409    0.983618    3.406444    0.863930    0.054747    0.024048    0.512315    
#> 312: 0.487418    0.983630    3.406390    0.864150    0.054653    0.024051    0.512222    
#> 313: 0.487577    0.983432    3.406305    0.865476    0.054583    0.024050    0.512221    
#> 314: 0.487543    0.983455    3.406272    0.865867    0.054554    0.024063    0.512166    
#> 315: 0.487737    0.983496    3.406221    0.866824    0.054561    0.024084    0.512179    
#> 316: 0.487638    0.983541    3.406147    0.867526    0.054489    0.024083    0.512141    
#> 317: 0.487784    0.983595    3.406108    0.868062    0.054448    0.024069    0.512292    
#> 318: 0.487789    0.983724    3.405992    0.868994    0.054471    0.024051    0.512212    
#> 319: 0.487819    0.983753    3.405943    0.869974    0.054512    0.024042    0.512192    
#> 320: 0.487501    0.983642    3.405922    0.869985    0.054502    0.024036    0.512192    
#> 321: 0.487178    0.983728    3.405792    0.869422    0.054536    0.023997    0.512285    
#> 322: 0.486950    0.983819    3.405716    0.869368    0.054575    0.023997    0.512203    
#> 323: 0.486500    0.983818    3.405647    0.868793    0.054595    0.023973    0.512227    
#> 324: 0.486379    0.983804    3.405658    0.868594    0.054623    0.023956    0.512282    
#> 325: 0.486354    0.983974    3.405590    0.868407    0.054667    0.023939    0.512263    
#> 326: 0.486295    0.983886    3.405557    0.868143    0.054722    0.023928    0.512186    
#> 327: 0.486149    0.983877    3.405587    0.867866    0.054758    0.023915    0.512202    
#> 328: 0.485817    0.983968    3.405576    0.866913    0.054745    0.023911    0.512116    
#> 329: 0.485989    0.983982    3.405663    0.866796    0.054673    0.023888    0.512125    
#> 330: 0.486130    0.983855    3.405772    0.866073    0.054627    0.023872    0.512125    
#> 331: 0.486408    0.983849    3.405948    0.865192    0.054559    0.023866    0.512119    
#> 332: 0.486556    0.983798    3.406094    0.863651    0.054494    0.023856    0.512219    
#> 333: 0.486606    0.983706    3.406121    0.862630    0.054418    0.023862    0.512248    
#> 334: 0.486609    0.983631    3.406072    0.862438    0.054348    0.023854    0.512311    
#> 335: 0.486420    0.983661    3.406003    0.861753    0.054299    0.023852    0.512304    
#> 336: 0.486102    0.983819    3.405978    0.860819    0.054225    0.023861    0.512335    
#> 337: 0.485594    0.984055    3.405902    0.859651    0.054221    0.023863    0.512475    
#> 338: 0.485344    0.984165    3.405865    0.859165    0.054245    0.023847    0.512489    
#> 339: 0.485165    0.984332    3.405766    0.859052    0.054285    0.023827    0.512599    
#> 340: 0.485074    0.984197    3.405756    0.858928    0.054303    0.023808    0.512677    
#> 341: 0.485333    0.984089    3.405841    0.859462    0.054268    0.023801    0.512671    
#> 342: 0.485423    0.983974    3.405864    0.859690    0.054265    0.023787    0.512677    
#> 343: 0.485403    0.984012    3.405907    0.859105    0.054317    0.023784    0.512654    
#> 344: 0.485299    0.983972    3.405883    0.858443    0.054308    0.023774    0.512722    
#> 345: 0.485249    0.984023    3.405874    0.857931    0.054323    0.023755    0.512714    
#> 346: 0.485284    0.984125    3.405821    0.857839    0.054337    0.023731    0.512659    
#> 347: 0.485436    0.984107    3.405808    0.858588    0.054334    0.023730    0.512640    
#> 348: 0.485423    0.984148    3.405737    0.859236    0.054414    0.023730    0.512598    
#> 349: 0.485316    0.984049    3.405703    0.859544    0.054488    0.023728    0.512618    
#> 350: 0.485383    0.984063    3.405653    0.860022    0.054487    0.023719    0.512659    
#> 351: 0.485316    0.984194    3.405574    0.859787    0.054527    0.023733    0.512712    
#> 352: 0.485141    0.984235    3.405579    0.858818    0.054580    0.023742    0.512716    
#> 353: 0.485132    0.984285    3.405576    0.858544    0.054598    0.023779    0.512678    
#> 354: 0.484828    0.984299    3.405542    0.857615    0.054600    0.023786    0.512736    
#> 355: 0.484908    0.984212    3.405538    0.857524    0.054592    0.023800    0.512836    
#> 356: 0.484971    0.984187    3.405603    0.856856    0.054570    0.023787    0.512987    
#> 357: 0.485220    0.984137    3.405687    0.857395    0.054546    0.023801    0.512976    
#> 358: 0.485299    0.984181    3.405675    0.857348    0.054487    0.023813    0.512986    
#> 359: 0.484939    0.984259    3.405652    0.856328    0.054451    0.023813    0.513106    
#> 360: 0.484697    0.984275    3.405562    0.855581    0.054371    0.023798    0.513123    
#> 361: 0.484343    0.984312    3.405513    0.854585    0.054424    0.023794    0.513133    
#> 362: 0.484218    0.984198    3.405540    0.853778    0.054403    0.023802    0.513019    
#> 363: 0.483954    0.984146    3.405517    0.852954    0.054368    0.023796    0.512949    
#> 364: 0.483777    0.984198    3.405459    0.852652    0.054329    0.023793    0.513006    
#> 365: 0.483629    0.984198    3.405459    0.852498    0.054259    0.023785    0.513036    
#> 366: 0.483492    0.984227    3.405355    0.852520    0.054201    0.023777    0.513082    
#> 367: 0.483395    0.984342    3.405269    0.852527    0.054155    0.023762    0.513020    
#> 368: 0.483507    0.984451    3.405210    0.852993    0.054158    0.023741    0.512923    
#> 369: 0.483333    0.984481    3.405148    0.852925    0.054113    0.023731    0.512915    
#> 370: 0.483395    0.984620    3.405121    0.853348    0.054116    0.023727    0.512902    
#> 371: 0.483057    0.984711    3.405035    0.852850    0.054117    0.023714    0.512879    
#> 372: 0.482781    0.984815    3.404983    0.852836    0.054131    0.023702    0.512923    
#> 373: 0.482533    0.984955    3.404891    0.852582    0.054116    0.023702    0.512988    
#> 374: 0.482741    0.984991    3.404878    0.853519    0.054097    0.023728    0.512944    
#> 375: 0.482680    0.984990    3.404875    0.853734    0.054095    0.023762    0.512926    
#> 376: 0.482785    0.985042    3.404887    0.854227    0.054107    0.023779    0.512842    
#> 377: 0.482812    0.985127    3.404864    0.854235    0.054094    0.023779    0.512787    
#> 378: 0.482697    0.985224    3.404854    0.853806    0.054041    0.023777    0.512744    
#> 379: 0.482568    0.985161    3.404854    0.853429    0.054026    0.023771    0.512628    
#> 380: 0.482496    0.985080    3.404826    0.853293    0.053976    0.023791    0.512542    
#> 381: 0.482480    0.985006    3.404807    0.853164    0.053961    0.023806    0.512486    
#> 382: 0.482351    0.985050    3.404785    0.853062    0.053927    0.023801    0.512444    
#> 383: 0.482334    0.985034    3.404727    0.852663    0.053905    0.023799    0.512452    
#> 384: 0.482283    0.985111    3.404744    0.852306    0.053933    0.023795    0.512441    
#> 385: 0.482057    0.985126    3.404733    0.851289    0.053939    0.023788    0.512503    
#> 386: 0.481927    0.985284    3.404732    0.850344    0.053937    0.023784    0.512552    
#> 387: 0.481890    0.985364    3.404784    0.850081    0.053934    0.023785    0.512510    
#> 388: 0.481838    0.985355    3.404848    0.849660    0.053973    0.023783    0.512479    
#> 389: 0.481975    0.985215    3.404912    0.849895    0.053963    0.023777    0.512576    
#> 390: 0.481882    0.985232    3.404943    0.849611    0.053944    0.023769    0.512636    
#> 391: 0.482134    0.985232    3.404985    0.849634    0.053919    0.023764    0.512562    
#> 392: 0.482394    0.985198    3.405019    0.850016    0.053896    0.023756    0.512501    
#> 393: 0.482420    0.985136    3.405015    0.849656    0.053908    0.023741    0.512459    
#> 394: 0.482603    0.985149    3.405057    0.849992    0.053896    0.023711    0.512440    
#> 395: 0.482747    0.985196    3.405069    0.850178    0.053930    0.023695    0.512461    
#> 396: 0.482546    0.985256    3.405085    0.849425    0.053870    0.023684    0.512490    
#> 397: 0.482505    0.985232    3.405123    0.849013    0.053862    0.023680    0.512522    
#> 398: 0.482753    0.985178    3.405180    0.848911    0.053828    0.023695    0.512603    
#> 399: 0.482708    0.985103    3.405229    0.848552    0.053809    0.023691    0.512609    
#> 400: 0.482724    0.985066    3.405279    0.848172    0.053772    0.023700    0.512620    
#> 401: 0.482918    0.985045    3.405308    0.848097    0.053714    0.023708    0.512700    
#> 402: 0.483071    0.985036    3.405327    0.848180    0.053665    0.023712    0.512707    
#> 403: 0.483308    0.985019    3.405337    0.848399    0.053654    0.023691    0.512658    
#> 404: 0.483515    0.985020    3.405319    0.849125    0.053652    0.023670    0.512579    
#> 405: 0.483543    0.985006    3.405337    0.849633    0.053648    0.023659    0.512515    
#> 406: 0.483744    0.984975    3.405349    0.849933    0.053672    0.023643    0.512513    
#> 407: 0.483835    0.984976    3.405392    0.849761    0.053675    0.023620    0.512532    
#> 408: 0.484084    0.984990    3.405445    0.849646    0.053678    0.023612    0.512551    
#> 409: 0.484114    0.984946    3.405470    0.849670    0.053692    0.023608    0.512541    
#> 410: 0.484224    0.984936    3.405453    0.850179    0.053708    0.023611    0.512481    
#> 411: 0.484330    0.984833    3.405484    0.850723    0.053703    0.023620    0.512498    
#> 412: 0.484326    0.984952    3.405464    0.850939    0.053692    0.023634    0.512471    
#> 413: 0.484517    0.985022    3.405446    0.851702    0.053683    0.023640    0.512408    
#> 414: 0.484522    0.985063    3.405467    0.851925    0.053678    0.023626    0.512366    
#> 415: 0.484810    0.985065    3.405495    0.852619    0.053654    0.023625    0.512286    
#> 416: 0.485106    0.985105    3.405517    0.853390    0.053624    0.023625    0.512185    
#> 417: 0.485131    0.985133    3.405510    0.853963    0.053587    0.023621    0.512140    
#> 418: 0.484980    0.985118    3.405487    0.853617    0.053533    0.023633    0.512077    
#> 419: 0.484883    0.985151    3.405460    0.853404    0.053497    0.023648    0.512034    
#> 420: 0.484835    0.985223    3.405466    0.853306    0.053466    0.023659    0.512008    
#> 421: 0.484821    0.985242    3.405476    0.853433    0.053458    0.023683    0.511980    
#> 422: 0.484868    0.985237    3.405500    0.853388    0.053450    0.023706    0.511964    
#> 423: 0.484969    0.985182    3.405502    0.853607    0.053437    0.023717    0.511991    
#> 424: 0.484986    0.985176    3.405472    0.853962    0.053441    0.023718    0.511965    
#> 425: 0.484941    0.985200    3.405438    0.854376    0.053468    0.023729    0.511973    
#> 426: 0.484858    0.985255    3.405341    0.854689    0.053489    0.023741    0.511957    
#> 427: 0.484698    0.985331    3.405310    0.854916    0.053503    0.023748    0.511937    
#> 428: 0.484575    0.985319    3.405295    0.854839    0.053497    0.023756    0.511948    
#> 429: 0.484428    0.985353    3.405291    0.854679    0.053491    0.023777    0.511940    
#> 430: 0.484379    0.985406    3.405287    0.854734    0.053449    0.023788    0.511972    
#> 431: 0.484229    0.985407    3.405252    0.854596    0.053426    0.023772    0.511967    
#> 432: 0.484111    0.985430    3.405251    0.854363    0.053415    0.023762    0.511989    
#> 433: 0.484001    0.985532    3.405229    0.854043    0.053456    0.023754    0.512018    
#> 434: 0.483748    0.985592    3.405183    0.853429    0.053473    0.023743    0.511997    
#> 435: 0.483719    0.985636    3.405167    0.853261    0.053463    0.023739    0.511998    
#> 436: 0.483714    0.985617    3.405216    0.852957    0.053465    0.023749    0.512064    
#> 437: 0.483696    0.985574    3.405250    0.852492    0.053427    0.023753    0.512140    
#> 438: 0.483581    0.985663    3.405271    0.852093    0.053378    0.023761    0.512152    
#> 439: 0.483585    0.985783    3.405275    0.851848    0.053349    0.023766    0.512110    
#> 440: 0.483650    0.985794    3.405322    0.851246    0.053323    0.023783    0.512112    
#> 441: 0.483681    0.985729    3.405376    0.850568    0.053312    0.023794    0.512153    
#> 442: 0.483460    0.985771    3.405379    0.849781    0.053320    0.023798    0.512177    
#> 443: 0.483441    0.985826    3.405373    0.849457    0.053310    0.023804    0.512215    
#> 444: 0.483296    0.985872    3.405379    0.848914    0.053291    0.023821    0.512274    
#> 445: 0.483266    0.985867    3.405355    0.848700    0.053257    0.023841    0.512344    
#> 446: 0.483078    0.985900    3.405319    0.848374    0.053212    0.023861    0.512390    
#> 447: 0.483030    0.985921    3.405332    0.848402    0.053176    0.023879    0.512478    
#> 448: 0.483146    0.985894    3.405362    0.848962    0.053165    0.023887    0.512505    
#> 449: 0.483355    0.985885    3.405440    0.849336    0.053139    0.023900    0.512553    
#> 450: 0.483710    0.985822    3.405484    0.850376    0.053091    0.023909    0.512562    
#> 451: 0.483865    0.985775    3.405532    0.850449    0.053053    0.023915    0.512640    
#> 452: 0.483890    0.985772    3.405549    0.850208    0.053047    0.023927    0.512620    
#> 453: 0.483987    0.985795    3.405591    0.850116    0.053038    0.023932    0.512578    
#> 454: 0.483976    0.985851    3.405631    0.849743    0.053043    0.023936    0.512532    
#> 455: 0.484035    0.985864    3.405653    0.849899    0.053035    0.023939    0.512470    
#> 456: 0.484006    0.985803    3.405732    0.849656    0.053016    0.023946    0.512420    
#> 457: 0.484023    0.985725    3.405811    0.849225    0.052998    0.023955    0.512363    
#> 458: 0.484014    0.985784    3.405823    0.848949    0.052979    0.023960    0.512361    
#> 459: 0.483890    0.985854    3.405807    0.848984    0.052955    0.023957    0.512380    
#> 460: 0.483849    0.985859    3.405793    0.849156    0.052959    0.023958    0.512327    
#> 461: 0.483901    0.985886    3.405792    0.849571    0.052929    0.023980    0.512283    
#> 462: 0.483856    0.985917    3.405785    0.849798    0.052884    0.024007    0.512236    
#> 463: 0.483893    0.985962    3.405806    0.849830    0.052853    0.024019    0.512195    
#> 464: 0.483934    0.986004    3.405818    0.849723    0.052808    0.024035    0.512151    
#> 465: 0.484131    0.985938    3.405833    0.850287    0.052775    0.024048    0.512115    
#> 466: 0.484269    0.985985    3.405803    0.850704    0.052725    0.024069    0.512112    
#> 467: 0.484196    0.985974    3.405837    0.850424    0.052651    0.024098    0.512114    
#> 468: 0.484254    0.985958    3.405860    0.850265    0.052599    0.024134    0.512113    
#> 469: 0.484305    0.986004    3.405887    0.850316    0.052560    0.024171    0.512130    
#> 470: 0.484096    0.986016    3.405862    0.850097    0.052515    0.024208    0.512141    
#> 471: 0.484080    0.986000    3.405870    0.849884    0.052481    0.024230    0.512172    
#> 472: 0.484006    0.986002    3.405856    0.849718    0.052466    0.024248    0.512132    
#> 473: 0.484037    0.986018    3.405835    0.849848    0.052434    0.024259    0.512147    
#> 474: 0.484062    0.986057    3.405789    0.850287    0.052471    0.024262    0.512174    
#> 475: 0.484217    0.986145    3.405796    0.850952    0.052512    0.024264    0.512210    
#> 476: 0.484243    0.986161    3.405795    0.851092    0.052522    0.024267    0.512254    
#> 477: 0.484213    0.986175    3.405817    0.850747    0.052526    0.024282    0.512247    
#> 478: 0.484166    0.986164    3.405846    0.850773    0.052479    0.024289    0.512324    
#> 479: 0.484146    0.986234    3.405792    0.851162    0.052454    0.024294    0.512360    
#> 480: 0.484080    0.986288    3.405725    0.851641    0.052462    0.024313    0.512425    
#> 481: 0.483868    0.986329    3.405619    0.852120    0.052470    0.024323    0.512468    
#> 482: 0.483618    0.986355    3.405515    0.852450    0.052459    0.024341    0.512526    
#> 483: 0.483279    0.986378    3.405422    0.852561    0.052438    0.024362    0.512572    
#> 484: 0.483008    0.986357    3.405347    0.852400    0.052428    0.024381    0.512610    
#> 485: 0.482780    0.986455    3.405244    0.852370    0.052460    0.024408    0.512682    
#> 486: 0.482524    0.986554    3.405156    0.852362    0.052475    0.024419    0.512726    
#> 487: 0.482533    0.986603    3.405111    0.853048    0.052490    0.024436    0.512746    
#> 488: 0.482453    0.986616    3.405058    0.853565    0.052474    0.024445    0.512758    
#> 489: 0.482384    0.986642    3.404994    0.853736    0.052467    0.024454    0.512772    
#> 490: 0.482275    0.986657    3.404964    0.853751    0.052454    0.024454    0.512778    
#> 491: 0.482236    0.986677    3.404950    0.853717    0.052450    0.024443    0.512726    
#> 492: 0.482253    0.986733    3.404931    0.853936    0.052457    0.024433    0.512747    
#> 493: 0.482167    0.986829    3.404893    0.854105    0.052440    0.024433    0.512735    
#> 494: 0.482214    0.986927    3.404859    0.854527    0.052460    0.024445    0.512689    
#> 495: 0.482088    0.986960    3.404795    0.854765    0.052445    0.024445    0.512650    
#> 496: 0.482206    0.986990    3.404765    0.855248    0.052428    0.024440    0.512655    
#> 497: 0.482247    0.986983    3.404782    0.855621    0.052403    0.024430    0.512702    
#> 498: 0.482332    0.986936    3.404778    0.856032    0.052412    0.024422    0.512696    
#> 499: 0.482325    0.986933    3.404779    0.856065    0.052390    0.024415    0.512721    
#> 500: 0.482379    0.986898    3.404771    0.855967    0.052371    0.024405    0.512787    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.303029    0.977503    3.444528    0.392401    0.081314    0.016800    1.724858    
#> 002: 0.346610    1.034973    3.434777    0.372781    0.077248    0.015960    1.112012    
#> 003: 0.506657    1.003396    3.453636    0.354142    0.073386    0.015162    0.844591    
#> 004: 0.522326    1.005728    3.472277    0.336435    0.069716    0.014404    0.786260    
#> 005: 0.598470    1.013188    3.470002    0.319613    0.074469    0.013684    0.718775    
#> 006: 0.577002    1.019155    3.466380    0.303633    0.078773    0.013000    0.686536    
#> 007: 0.551307    1.031077    3.458171    0.311457    0.092684    0.012350    0.709914    
#> 008: 0.528795    1.017382    3.460011    0.304379    0.090098    0.011732    0.709106    
#> 009: 0.534864    0.998918    3.464528    0.317578    0.098011    0.011146    0.694077    
#> 010: 0.552512    0.988289    3.461806    0.301699    0.093110    0.010588    0.706027    
#> 011: 0.608357    0.995100    3.468847    0.286614    0.088455    0.010059    0.716971    
#> 012: 0.594667    1.005338    3.461743    0.298965    0.084032    0.009556    0.708031    
#> 013: 0.516123    1.025027    3.454741    0.284017    0.081261    0.009078    0.723958    
#> 014: 0.558302    1.026930    3.466976    0.319545    0.079765    0.008624    0.726750    
#> 015: 0.587508    1.018547    3.480112    0.303568    0.075777    0.008272    0.704341    
#> 016: 0.609676    1.033522    3.481536    0.312334    0.079261    0.008562    0.709052    
#> 017: 0.595170    1.032655    3.484412    0.340257    0.086274    0.009378    0.690256    
#> 018: 0.593511    1.010519    3.472140    0.330416    0.081961    0.009185    0.702938    
#> 019: 0.569307    1.012825    3.476179    0.313896    0.077863    0.008726    0.682621    
#> 020: 0.590256    1.019764    3.478650    0.298201    0.083627    0.008290    0.690535    
#> 021: 0.618972    1.002133    3.486595    0.310763    0.079476    0.009496    0.681753    
#> 022: 0.648705    0.998797    3.499277    0.396703    0.091556    0.009021    0.673471    
#> 023: 0.699593    0.987760    3.513278    0.376868    0.089355    0.010277    0.705676    
#> 024: 0.687324    1.009298    3.509409    0.393758    0.088656    0.011434    0.696250    
#> 025: 0.641000    0.994928    3.500641    0.374070    0.084223    0.011004    0.687370    
#> 026: 0.647027    1.022226    3.490451    0.355367    0.080012    0.010454    0.688953    
#> 027: 0.607884    1.023956    3.490596    0.337598    0.078554    0.009931    0.714162    
#> 028: 0.669074    1.007891    3.504519    0.320718    0.074627    0.011018    0.700231    
#> 029: 0.689421    1.006932    3.499100    0.315488    0.081394    0.012542    0.702247    
#> 030: 0.670827    1.000905    3.498678    0.326112    0.077324    0.013563    0.692246    
#> 031: 0.626609    0.985281    3.503057    0.383606    0.075234    0.012885    0.688314    
#> 032: 0.632474    0.995796    3.503728    0.379745    0.076186    0.012241    0.682139    
#> 033: 0.626337    1.015027    3.497636    0.360758    0.080316    0.011629    0.684469    
#> 034: 0.649897    1.011005    3.501722    0.342720    0.076300    0.011048    0.711324    
#> 035: 0.646990    0.988563    3.501058    0.325584    0.074978    0.012851    0.682734    
#> 036: 0.605686    1.003354    3.496321    0.309305    0.083547    0.012208    0.684831    
#> 037: 0.607016    1.010669    3.497334    0.293840    0.079369    0.012784    0.700950    
#> 038: 0.657422    1.013527    3.497755    0.305622    0.084581    0.012145    0.701640    
#> 039: 0.673483    1.006722    3.508174    0.312648    0.080351    0.011538    0.692664    
#> 040: 0.607760    1.019055    3.509929    0.306867    0.076334    0.011004    0.699547    
#> 041: 0.595692    1.015213    3.498952    0.306106    0.073286    0.011126    0.700793    
#> 042: 0.600741    1.013710    3.491240    0.290801    0.069622    0.010570    0.698646    
#> 043: 0.605363    1.019057    3.484400    0.276261    0.071419    0.010042    0.694062    
#> 044: 0.579371    1.020380    3.483700    0.297563    0.073618    0.009539    0.686300    
#> 045: 0.613616    1.032539    3.481821    0.298491    0.075847    0.009062    0.690307    
#> 046: 0.607034    1.002901    3.493505    0.283566    0.084485    0.010880    0.685402    
#> 047: 0.617740    1.020689    3.487182    0.269388    0.088654    0.011416    0.685031    
#> 048: 0.600826    0.992791    3.494515    0.302017    0.099496    0.010845    0.687745    
#> 049: 0.610763    1.019228    3.497262    0.292138    0.094521    0.010303    0.701135    
#> 050: 0.666900    0.983188    3.493564    0.318723    0.089795    0.009788    0.695092    
#> 051: 0.625449    1.008041    3.491228    0.302787    0.092306    0.009299    0.703939    
#> 052: 0.635399    1.005578    3.494714    0.287647    0.091147    0.008834    0.682025    
#> 053: 0.638318    1.002119    3.492375    0.304485    0.096345    0.008751    0.680164    
#> 054: 0.591281    0.997145    3.496649    0.289261    0.091527    0.010358    0.688222    
#> 055: 0.609959    1.002879    3.496121    0.274798    0.086951    0.009840    0.714269    
#> 056: 0.632123    0.992706    3.495957    0.277179    0.082604    0.009348    0.716004    
#> 057: 0.609129    0.994773    3.502726    0.322325    0.087831    0.009209    0.706222    
#> 058: 0.615453    0.978691    3.495897    0.306208    0.083439    0.009858    0.708095    
#> 059: 0.613921    0.954238    3.503200    0.290898    0.079267    0.012447    0.729029    
#> 060: 0.622819    0.946016    3.516884    0.276353    0.094804    0.011824    0.741674    
#> 061: 0.637785    0.979135    3.506412    0.279513    0.090064    0.011233    0.730094    
#> 062: 0.632980    0.993712    3.512317    0.305487    0.096079    0.011665    0.741303    
#> 063: 0.671282    0.977828    3.514066    0.290213    0.094748    0.011082    0.719869    
#> 064: 0.634346    0.996317    3.513097    0.275702    0.093150    0.010528    0.695884    
#> 065: 0.648160    0.974998    3.493821    0.263870    0.088493    0.010666    0.695177    
#> 066: 0.615707    0.996628    3.487886    0.285495    0.084068    0.010132    0.697200    
#> 067: 0.593492    1.006290    3.476836    0.325832    0.083798    0.009626    0.691995    
#> 068: 0.578704    1.008063    3.487298    0.309541    0.092946    0.009145    0.694085    
#> 069: 0.577671    1.021149    3.485278    0.294064    0.099437    0.009028    0.706904    
#> 070: 0.594286    1.017935    3.489842    0.318236    0.094465    0.010528    0.699872    
#> 071: 0.615303    1.014958    3.471935    0.340899    0.089742    0.010002    0.710040    
#> 072: 0.565300    0.992559    3.475070    0.337807    0.085255    0.009502    0.697644    
#> 073: 0.585287    0.995249    3.490865    0.320916    0.081805    0.009026    0.696983    
#> 074: 0.600097    0.979903    3.496363    0.304870    0.089314    0.010031    0.702170    
#> 075: 0.637345    0.961227    3.517268    0.289627    0.094036    0.009529    0.705046    
#> 076: 0.652607    0.990750    3.522281    0.275146    0.089656    0.009473    0.701790    
#> 077: 0.674625    0.990543    3.507338    0.283908    0.085991    0.010330    0.701755    
#> 078: 0.638256    1.001405    3.498590    0.302804    0.081692    0.009814    0.686349    
#> 079: 0.618371    1.008818    3.502381    0.287664    0.080451    0.009812    0.706044    
#> 080: 0.624298    1.000014    3.495035    0.292504    0.076429    0.009660    0.723798    
#> 081: 0.610443    1.008159    3.488564    0.277879    0.081479    0.013104    0.703575    
#> 082: 0.591572    1.013309    3.486952    0.328132    0.091437    0.012449    0.720501    
#> 083: 0.665262    1.024192    3.493787    0.380112    0.086865    0.011827    0.703334    
#> 084: 0.623819    1.008459    3.492145    0.361107    0.105676    0.012941    0.699994    
#> 085: 0.634728    1.020811    3.505059    0.355065    0.100671    0.012294    0.701626    
#> 086: 0.659985    0.999026    3.494438    0.337312    0.096937    0.011679    0.688976    
#> 087: 0.627738    1.030992    3.486905    0.321189    0.092090    0.011095    0.689326    
#> 088: 0.552642    1.015214    3.477274    0.305130    0.087486    0.012447    0.712931    
#> 089: 0.568731    1.026053    3.473696    0.289873    0.092864    0.015473    0.716945    
#> 090: 0.538277    1.036944    3.469850    0.275379    0.088221    0.014700    0.716553    
#> 091: 0.556140    1.037160    3.451244    0.303656    0.091476    0.013965    0.699253    
#> 092: 0.523872    1.061778    3.454658    0.288473    0.086903    0.013266    0.722329    
#> 093: 0.514388    1.053982    3.459227    0.289029    0.082558    0.012603    0.714699    
#> 094: 0.558169    1.034976    3.461546    0.298824    0.078430    0.012136    0.700447    
#> 095: 0.554879    1.049245    3.480981    0.310373    0.074508    0.014089    0.687808    
#> 096: 0.571199    1.019069    3.477619    0.307349    0.084381    0.013384    0.677442    
#> 097: 0.622031    1.036890    3.478632    0.308547    0.089858    0.012715    0.682886    
#> 098: 0.636198    1.050971    3.481705    0.319348    0.085365    0.012079    0.703936    
#> 099: 0.572362    1.025946    3.467845    0.303380    0.092824    0.011476    0.696441    
#> 100: 0.586869    1.042203    3.471187    0.288211    0.097332    0.010902    0.699047    
#> 101: 0.518472    1.015657    3.447503    0.293282    0.097306    0.010357    0.703838    
#> 102: 0.531105    1.031028    3.451949    0.306093    0.092441    0.009839    0.720335    
#> 103: 0.569969    1.035546    3.456910    0.328287    0.087819    0.009347    0.688527    
#> 104: 0.550722    1.039497    3.463824    0.315519    0.087291    0.008880    0.706077    
#> 105: 0.558959    1.025906    3.466272    0.324426    0.083617    0.008436    0.699456    
#> 106: 0.571387    1.027275    3.468263    0.308205    0.079437    0.008014    0.698223    
#> 107: 0.621063    1.030420    3.469547    0.294701    0.087242    0.007613    0.707619    
#> 108: 0.557391    1.034144    3.464699    0.335749    0.088112    0.008269    0.706776    
#> 109: 0.536037    1.033332    3.470069    0.318961    0.085202    0.007855    0.706985    
#> 110: 0.550773    1.024860    3.455010    0.303013    0.080942    0.007697    0.717674    
#> 111: 0.568000    1.041311    3.461806    0.307608    0.076895    0.007392    0.705070    
#> 112: 0.545197    1.005294    3.453304    0.292227    0.073050    0.007022    0.718367    
#> 113: 0.568192    1.034458    3.465301    0.336202    0.086558    0.006671    0.685237    
#> 114: 0.601688    1.015494    3.465182    0.320186    0.085340    0.006337    0.703655    
#> 115: 0.612859    0.988332    3.485163    0.304177    0.081073    0.006849    0.740539    
#> 116: 0.604620    1.019293    3.482101    0.288968    0.077019    0.008466    0.714110    
#> 117: 0.602585    1.025917    3.483684    0.326178    0.086999    0.008043    0.720153    
#> 118: 0.610315    1.023743    3.484134    0.348537    0.103733    0.007641    0.699322    
#> 119: 0.574586    1.029565    3.481480    0.351884    0.108499    0.007259    0.705713    
#> 120: 0.587732    1.006507    3.484738    0.334290    0.103074    0.007134    0.702207    
#> 121: 0.585567    1.032477    3.484244    0.317575    0.119452    0.006777    0.713975    
#> 122: 0.598802    1.006277    3.485233    0.316302    0.113480    0.006438    0.708744    
#> 123: 0.625795    1.036262    3.474710    0.308351    0.107806    0.006116    0.713189    
#> 124: 0.603996    1.048280    3.474961    0.292934    0.102415    0.005810    0.715326    
#> 125: 0.589390    1.042211    3.462783    0.323924    0.099365    0.005520    0.693653    
#> 126: 0.575532    1.040630    3.458094    0.307727    0.106159    0.005244    0.690922    
#> 127: 0.573429    1.006634    3.457143    0.299283    0.100851    0.004982    0.710949    
#> 128: 0.551742    1.019533    3.469561    0.315444    0.108839    0.004733    0.698934    
#> 129: 0.589675    1.039543    3.473711    0.299672    0.112080    0.004496    0.707385    
#> 130: 0.610534    1.024946    3.476624    0.297135    0.112871    0.004271    0.700406    
#> 131: 0.581983    1.026401    3.468027    0.305768    0.122810    0.004058    0.702953    
#> 132: 0.524397    1.027429    3.457034    0.301418    0.116669    0.003935    0.720623    
#> 133: 0.535699    1.017352    3.460928    0.300375    0.110836    0.004327    0.744573    
#> 134: 0.548489    1.021155    3.458673    0.329109    0.105294    0.005657    0.711572    
#> 135: 0.539580    1.023726    3.460281    0.331924    0.100029    0.005847    0.722565    
#> 136: 0.545873    1.012737    3.459880    0.315328    0.103088    0.005555    0.708754    
#> 137: 0.592659    1.025647    3.471607    0.299561    0.104911    0.005277    0.720978    
#> 138: 0.575808    1.035533    3.468374    0.284583    0.105534    0.005013    0.710519    
#> 139: 0.602062    1.021869    3.481112    0.307153    0.116932    0.004762    0.710878    
#> 140: 0.593178    1.042829    3.482924    0.339975    0.111085    0.005353    0.717554    
#> 141: 0.616942    0.992587    3.491441    0.322976    0.105531    0.005086    0.721794    
#> 142: 0.617229    0.994713    3.493353    0.311282    0.100254    0.004914    0.719800    
#> 143: 0.584474    1.006290    3.493753    0.295718    0.103530    0.005372    0.712118    
#> 144: 0.641738    1.020620    3.495045    0.282194    0.098354    0.005791    0.679203    
#> 145: 0.608819    1.019640    3.487518    0.287851    0.093436    0.006263    0.677819    
#> 146: 0.595874    1.035984    3.494484    0.303987    0.100949    0.006159    0.692547    
#> 147: 0.593646    1.007371    3.494494    0.315670    0.097785    0.008124    0.675430    
#> 148: 0.603130    1.010794    3.498073    0.320264    0.092895    0.008405    0.677176    
#> 149: 0.635872    0.992533    3.499211    0.325365    0.088251    0.009701    0.714419    
#> 150: 0.655307    0.993391    3.498602    0.309097    0.083838    0.010877    0.732477    
#> 151: 0.602132    1.026078    3.479903    0.293642    0.079646    0.010334    0.724535    
#> 152: 0.613307    1.030755    3.489743    0.307478    0.067772    0.007090    0.711698    
#> 153: 0.610207    1.026983    3.495225    0.315864    0.075991    0.009487    0.723262    
#> 154: 0.652192    1.014858    3.501315    0.336968    0.086517    0.009475    0.723486    
#> 155: 0.609191    1.003351    3.494462    0.311237    0.072160    0.010018    0.708333    
#> 156: 0.609770    1.026466    3.500587    0.289805    0.064249    0.011644    0.727889    
#> 157: 0.639850    1.013336    3.495248    0.299583    0.064846    0.011808    0.726367    
#> 158: 0.645474    1.024554    3.494830    0.272302    0.061642    0.010729    0.694939    
#> 159: 0.629657    1.019423    3.501121    0.303832    0.082183    0.013985    0.689636    
#> 160: 0.649657    0.980796    3.512858    0.303281    0.066353    0.015404    0.692274    
#> 161: 0.671217    0.992492    3.510567    0.335388    0.067508    0.013696    0.694311    
#> 162: 0.631157    0.996321    3.494128    0.297906    0.063636    0.012102    0.704653    
#> 163: 0.638541    0.981347    3.486858    0.280765    0.085712    0.011659    0.685393    
#> 164: 0.624486    1.005117    3.489811    0.317590    0.084222    0.010010    0.691623    
#> 165: 0.608907    1.004246    3.486518    0.306645    0.090413    0.009218    0.687294    
#> 166: 0.645479    1.037545    3.488009    0.366953    0.082698    0.009807    0.679203    
#> 167: 0.608249    1.039868    3.483234    0.330743    0.092630    0.010234    0.687091    
#> 168: 0.632820    1.043869    3.486064    0.335786    0.093545    0.008557    0.683639    
#> 169: 0.612228    1.037382    3.482228    0.290377    0.090331    0.008784    0.698905    
#> 170: 0.616328    1.013002    3.485032    0.305946    0.091309    0.007889    0.669948    
#> 171: 0.569861    1.024650    3.480822    0.303089    0.086218    0.007061    0.686149    
#> 172: 0.582081    1.031754    3.480241    0.313777    0.096050    0.006650    0.685522    
#> 173: 0.595067    1.020964    3.473851    0.320975    0.084580    0.008084    0.686069    
#> 174: 0.623392    1.021218    3.477458    0.323686    0.086399    0.008704    0.686344    
#> 175: 0.609935    1.030549    3.471802    0.284859    0.076042    0.009861    0.700590    
#> 176: 0.618849    1.043225    3.479767    0.337251    0.083062    0.010011    0.700248    
#> 177: 0.624376    1.019312    3.490802    0.341576    0.068213    0.008055    0.692450    
#> 178: 0.621784    1.019702    3.483962    0.274565    0.084702    0.006565    0.684914    
#> 179: 0.621556    1.035872    3.482433    0.300958    0.088376    0.007729    0.701378    
#> 180: 0.610681    1.027445    3.480932    0.310687    0.094801    0.006672    0.705281    
#> 181: 0.602942    1.004504    3.471436    0.309870    0.087154    0.007832    0.682948    
#> 182: 0.541298    1.025643    3.459357    0.315612    0.077703    0.007806    0.692822    
#> 183: 0.560361    1.045790    3.457284    0.278320    0.092577    0.009353    0.690664    
#> 184: 0.573799    1.037870    3.466850    0.289273    0.099249    0.010031    0.702511    
#> 185: 0.564742    1.046231    3.463821    0.282348    0.096427    0.008064    0.692554    
#> 186: 0.561904    1.042707    3.469833    0.276429    0.104475    0.007556    0.710739    
#> 187: 0.605248    1.013085    3.480310    0.306445    0.086275    0.007117    0.701267    
#> 188: 0.571083    1.036918    3.471673    0.322189    0.082614    0.008081    0.687493    
#> 189: 0.592225    1.036348    3.480570    0.305534    0.090154    0.007999    0.699193    
#> 190: 0.588791    1.011772    3.483587    0.300072    0.082026    0.008649    0.696350    
#> 191: 0.581682    1.043496    3.474698    0.360177    0.077037    0.007833    0.684284    
#> 192: 0.581084    1.026476    3.475562    0.395210    0.078640    0.007437    0.687536    
#> 193: 0.636018    1.030283    3.481619    0.331481    0.080044    0.007323    0.673562    
#> 194: 0.578461    1.020739    3.475094    0.336049    0.078502    0.009030    0.691760    
#> 195: 0.547423    1.029787    3.464682    0.323679    0.080798    0.010642    0.695270    
#> 196: 0.576113    1.027981    3.470225    0.350196    0.080036    0.010769    0.693123    
#> 197: 0.588233    1.015647    3.495851    0.348740    0.075816    0.011001    0.703164    
#> 198: 0.632383    0.992280    3.489125    0.379454    0.083668    0.011406    0.675015    
#> 199: 0.623866    0.999377    3.485836    0.364819    0.077678    0.010897    0.680341    
#> 200: 0.580096    1.005985    3.485180    0.311869    0.070875    0.009762    0.695935    
#> 201: 0.581008    1.009930    3.483060    0.319965    0.070787    0.009410    0.691382    
#> 202: 0.586532    1.010853    3.481734    0.338687    0.073862    0.009355    0.694714    
#> 203: 0.600161    1.010965    3.481551    0.336932    0.077443    0.009577    0.690871    
#> 204: 0.605558    1.010078    3.484312    0.339175    0.084535    0.009827    0.693820    
#> 205: 0.602551    1.015917    3.484219    0.339317    0.085175    0.010047    0.695565    
#> 206: 0.604890    1.020905    3.485467    0.346508    0.083320    0.010257    0.697478    
#> 207: 0.602150    1.020597    3.483822    0.333464    0.083300    0.010221    0.695439    
#> 208: 0.600966    1.021564    3.482477    0.325596    0.084257    0.010115    0.693509    
#> 209: 0.605238    1.020237    3.482292    0.323393    0.084688    0.010087    0.693738    
#> 210: 0.607603    1.018352    3.482787    0.321609    0.084964    0.009958    0.693522    
#> 211: 0.609531    1.017273    3.483466    0.318251    0.085748    0.009891    0.692850    
#> 212: 0.612294    1.015944    3.484142    0.318295    0.085056    0.009797    0.692844    
#> 213: 0.614348    1.013846    3.484517    0.321069    0.085665    0.009856    0.692731    
#> 214: 0.616342    1.013779    3.484926    0.323095    0.085175    0.009771    0.693667    
#> 215: 0.618142    1.013633    3.485725    0.323254    0.084347    0.009863    0.693600    
#> 216: 0.620692    1.011909    3.486436    0.323870    0.083773    0.010068    0.694257    
#> 217: 0.620125    1.012460    3.486626    0.322482    0.083390    0.010229    0.693831    
#> 218: 0.619021    1.013635    3.486310    0.322789    0.084205    0.010268    0.693645    
#> 219: 0.616420    1.014304    3.485075    0.323311    0.084147    0.010194    0.694229    
#> 220: 0.614379    1.015866    3.484507    0.324998    0.083870    0.010192    0.694223    
#> 221: 0.611475    1.016367    3.484106    0.324812    0.083463    0.010234    0.694251    
#> 222: 0.611099    1.016070    3.483830    0.325480    0.082681    0.010385    0.694494    
#> 223: 0.610542    1.016009    3.483503    0.325567    0.082501    0.010467    0.694415    
#> 224: 0.611843    1.017259    3.483784    0.327180    0.082688    0.010448    0.695041    
#> 225: 0.612107    1.016339    3.484282    0.328651    0.082644    0.010460    0.694841    
#> 226: 0.613707    1.014757    3.484585    0.329633    0.082666    0.010458    0.695260    
#> 227: 0.613616    1.014184    3.484850    0.331588    0.082665    0.010401    0.694841    
#> 228: 0.612835    1.014354    3.484634    0.330030    0.082092    0.010427    0.695050    
#> 229: 0.612357    1.014247    3.484508    0.330192    0.081857    0.010457    0.694636    
#> 230: 0.613255    1.013313    3.484599    0.330456    0.081343    0.010528    0.694667    
#> 231: 0.614510    1.013224    3.485313    0.330400    0.081357    0.010614    0.694661    
#> 232: 0.614832    1.013123    3.485798    0.332356    0.081201    0.010669    0.694418    
#> 233: 0.615189    1.011939    3.486190    0.332254    0.081095    0.010781    0.694459    
#> 234: 0.615111    1.011761    3.486545    0.331199    0.080856    0.010859    0.694348    
#> 235: 0.615169    1.012104    3.486639    0.329967    0.080794    0.010946    0.694221    
#> 236: 0.614473    1.012551    3.486548    0.329819    0.080571    0.010926    0.694311    
#> 237: 0.615170    1.012678    3.486744    0.329190    0.080289    0.010904    0.694703    
#> 238: 0.615659    1.012644    3.486749    0.328946    0.080282    0.010950    0.694834    
#> 239: 0.614903    1.012868    3.486624    0.329669    0.080073    0.010953    0.694510    
#> 240: 0.614472    1.012943    3.486654    0.329694    0.080156    0.010874    0.694284    
#> 241: 0.614578    1.012159    3.486945    0.328546    0.080325    0.010885    0.694349    
#> 242: 0.614407    1.011462    3.486966    0.326149    0.080369    0.010889    0.694634    
#> 243: 0.614233    1.011628    3.486975    0.324578    0.080559    0.010916    0.694937    
#> 244: 0.613920    1.011501    3.487243    0.325404    0.080168    0.011004    0.694965    
#> 245: 0.614505    1.011185    3.487569    0.324472    0.080207    0.011030    0.695373    
#> 246: 0.614890    1.010585    3.487816    0.324616    0.080007    0.011078    0.695271    
#> 247: 0.614557    1.010037    3.488296    0.323927    0.080209    0.011108    0.695180    
#> 248: 0.615128    1.009968    3.488463    0.324513    0.080174    0.011097    0.694812    
#> 249: 0.614681    1.009962    3.488374    0.324140    0.080073    0.011058    0.695223    
#> 250: 0.615040    1.010222    3.488303    0.323544    0.080188    0.011045    0.695564    
#> 251: 0.615636    1.010342    3.488583    0.324041    0.079927    0.011049    0.695693    
#> 252: 0.616488    1.010126    3.488995    0.323397    0.079826    0.011040    0.696142    
#> 253: 0.616614    1.010056    3.489038    0.322252    0.079802    0.011049    0.696460    
#> 254: 0.616572    1.010296    3.489231    0.321092    0.079759    0.011052    0.696756    
#> 255: 0.616997    1.010417    3.489570    0.321332    0.079753    0.011046    0.697071    
#> 256: 0.617298    1.010188    3.489612    0.320362    0.079982    0.011053    0.697271    
#> 257: 0.617302    1.009618    3.489708    0.320892    0.080436    0.011043    0.697005    
#> 258: 0.617411    1.009070    3.489693    0.320998    0.080709    0.011034    0.696843    
#> 259: 0.617651    1.008773    3.489685    0.320922    0.080696    0.011017    0.696784    
#> 260: 0.617428    1.008921    3.489744    0.321011    0.080634    0.010994    0.696617    
#> 261: 0.617679    1.008904    3.489821    0.321744    0.080696    0.010999    0.696321    
#> 262: 0.617789    1.009120    3.489805    0.321997    0.080573    0.011000    0.696389    
#> 263: 0.617368    1.009400    3.489762    0.322492    0.080667    0.010979    0.696483    
#> 264: 0.616466    1.009518    3.489651    0.323283    0.080853    0.010947    0.696538    
#> 265: 0.616280    1.009523    3.489505    0.323960    0.080937    0.010924    0.696558    
#> 266: 0.615912    1.009722    3.489284    0.324373    0.080853    0.010913    0.696643    
#> 267: 0.615487    1.009882    3.489180    0.324995    0.080858    0.010875    0.696549    
#> 268: 0.615273    1.009793    3.488972    0.325802    0.081068    0.010823    0.696395    
#> 269: 0.615994    1.009851    3.488887    0.327310    0.081103    0.010806    0.696535    
#> 270: 0.616192    1.009968    3.488732    0.328552    0.080960    0.010760    0.696532    
#> 271: 0.616771    1.010001    3.488649    0.329619    0.080735    0.010723    0.696606    
#> 272: 0.616840    1.010067    3.488555    0.329104    0.080794    0.010706    0.696937    
#> 273: 0.616723    1.010225    3.488591    0.329582    0.080732    0.010684    0.697040    
#> 274: 0.616777    1.010528    3.488606    0.329314    0.080780    0.010641    0.697176    
#> 275: 0.616689    1.010633    3.488447    0.328799    0.080933    0.010613    0.697069    
#> 276: 0.616342    1.010880    3.488529    0.329007    0.080721    0.010599    0.697226    
#> 277: 0.616416    1.011103    3.488692    0.328521    0.080558    0.010604    0.697095    
#> 278: 0.616421    1.010986    3.488871    0.327692    0.080598    0.010599    0.696978    
#> 279: 0.616554    1.010744    3.489046    0.327305    0.080522    0.010582    0.697035    
#> 280: 0.616413    1.010860    3.489116    0.327602    0.080508    0.010577    0.696944    
#> 281: 0.616397    1.010996    3.489207    0.327375    0.080645    0.010540    0.696947    
#> 282: 0.616266    1.011162    3.489248    0.326793    0.080637    0.010528    0.696898    
#> 283: 0.616536    1.011133    3.489305    0.326738    0.080762    0.010526    0.697252    
#> 284: 0.616505    1.010923    3.489382    0.326524    0.080703    0.010527    0.697225    
#> 285: 0.616596    1.010871    3.489333    0.326113    0.080708    0.010535    0.697137    
#> 286: 0.616446    1.010856    3.489300    0.325768    0.080663    0.010569    0.696996    
#> 287: 0.616128    1.011012    3.489253    0.325428    0.080520    0.010598    0.696898    
#> 288: 0.616427    1.010933    3.489300    0.324709    0.080567    0.010618    0.696867    
#> 289: 0.616759    1.010737    3.489360    0.324188    0.080642    0.010622    0.696908    
#> 290: 0.617110    1.010633    3.489428    0.324117    0.080700    0.010646    0.697006    
#> 291: 0.617586    1.010685    3.489594    0.324278    0.080572    0.010643    0.696750    
#> 292: 0.617786    1.010493    3.489658    0.324290    0.080617    0.010615    0.696612    
#> 293: 0.617926    1.010385    3.489670    0.324171    0.080750    0.010599    0.696514    
#> 294: 0.618335    1.010505    3.489615    0.324406    0.080892    0.010579    0.696253    
#> 295: 0.618380    1.010324    3.489630    0.324602    0.080947    0.010567    0.695973    
#> 296: 0.618364    1.010212    3.489670    0.324273    0.080980    0.010587    0.695847    
#> 297: 0.618426    1.010259    3.489741    0.323747    0.080968    0.010591    0.695823    
#> 298: 0.618625    1.010153    3.489846    0.323549    0.081018    0.010603    0.695792    
#> 299: 0.618792    1.010202    3.489848    0.323039    0.081017    0.010595    0.695766    
#> 300: 0.619207    1.009905    3.490029    0.322747    0.081062    0.010610    0.695572    
#> 301: 0.619553    1.009601    3.490025    0.322788    0.080977    0.010613    0.695694    
#> 302: 0.619665    1.009572    3.490020    0.322515    0.080975    0.010618    0.695714    
#> 303: 0.619898    1.009798    3.490061    0.322075    0.080900    0.010622    0.695792    
#> 304: 0.620328    1.010084    3.489971    0.321925    0.080872    0.010611    0.696009    
#> 305: 0.620041    1.009989    3.489911    0.321392    0.080890    0.010616    0.696026    
#> 306: 0.619596    1.009957    3.489745    0.320876    0.080931    0.010604    0.696205    
#> 307: 0.619528    1.009842    3.489635    0.320710    0.080887    0.010598    0.696391    
#> 308: 0.619166    1.009843    3.489489    0.321046    0.080799    0.010586    0.696466    
#> 309: 0.619201    1.009637    3.489408    0.320953    0.080715    0.010579    0.696435    
#> 310: 0.619270    1.009648    3.489291    0.320593    0.080750    0.010565    0.696295    
#> 311: 0.619191    1.009714    3.489175    0.320567    0.080684    0.010561    0.696345    
#> 312: 0.618687    1.009758    3.488958    0.320814    0.080636    0.010560    0.696555    
#> 313: 0.618449    1.009585    3.488829    0.320826    0.080776    0.010560    0.696612    
#> 314: 0.617774    1.009694    3.488637    0.320844    0.080815    0.010562    0.696540    
#> 315: 0.617293    1.009873    3.488477    0.320944    0.080774    0.010578    0.696578    
#> 316: 0.617049    1.010027    3.488378    0.320611    0.080621    0.010582    0.696700    
#> 317: 0.616726    1.010061    3.488324    0.320962    0.080606    0.010558    0.696666    
#> 318: 0.616538    1.010100    3.488249    0.320574    0.080538    0.010537    0.696616    
#> 319: 0.616495    1.010079    3.488254    0.320909    0.080481    0.010525    0.696656    
#> 320: 0.616258    1.009973    3.488211    0.320729    0.080411    0.010500    0.696690    
#> 321: 0.616125    1.010097    3.488086    0.320645    0.080452    0.010488    0.696791    
#> 322: 0.616258    1.010154    3.487962    0.320722    0.080499    0.010466    0.696759    
#> 323: 0.615618    1.010346    3.487813    0.320814    0.080500    0.010468    0.696777    
#> 324: 0.615462    1.010590    3.487835    0.320624    0.080436    0.010457    0.696727    
#> 325: 0.615291    1.010796    3.487725    0.320730    0.080372    0.010455    0.696651    
#> 326: 0.615094    1.010797    3.487576    0.320500    0.080317    0.010447    0.696654    
#> 327: 0.615392    1.010697    3.487568    0.320697    0.080140    0.010452    0.696832    
#> 328: 0.615540    1.010661    3.487551    0.320716    0.080020    0.010453    0.696920    
#> 329: 0.615610    1.010659    3.487601    0.320926    0.079961    0.010444    0.696834    
#> 330: 0.615522    1.010546    3.487604    0.321301    0.080038    0.010436    0.696888    
#> 331: 0.615579    1.010588    3.487610    0.321483    0.080040    0.010410    0.696853    
#> 332: 0.615699    1.010595    3.487679    0.321263    0.080025    0.010417    0.696755    
#> 333: 0.615621    1.010556    3.487663    0.320932    0.080071    0.010408    0.696775    
#> 334: 0.615410    1.010530    3.487546    0.321101    0.080083    0.010383    0.696869    
#> 335: 0.615181    1.010593    3.487493    0.321145    0.080086    0.010366    0.696891    
#> 336: 0.614826    1.010647    3.487408    0.321057    0.080067    0.010365    0.697033    
#> 337: 0.614614    1.011019    3.487289    0.320849    0.080078    0.010360    0.697179    
#> 338: 0.614526    1.011122    3.487314    0.320925    0.080083    0.010343    0.697211    
#> 339: 0.614455    1.011320    3.487290    0.321027    0.080040    0.010329    0.697087    
#> 340: 0.614425    1.011164    3.487339    0.320386    0.080016    0.010316    0.697095    
#> 341: 0.614660    1.011073    3.487424    0.320057    0.079986    0.010300    0.697052    
#> 342: 0.614609    1.010850    3.487508    0.319688    0.079921    0.010311    0.696992    
#> 343: 0.614564    1.010816    3.487606    0.319371    0.079879    0.010326    0.696877    
#> 344: 0.614550    1.010762    3.487684    0.318929    0.079840    0.010346    0.696822    
#> 345: 0.614575    1.010770    3.487764    0.318994    0.079819    0.010378    0.696746    
#> 346: 0.614515    1.010793    3.487713    0.319262    0.079738    0.010386    0.696635    
#> 347: 0.614546    1.010715    3.487659    0.319323    0.079747    0.010382    0.696661    
#> 348: 0.614586    1.010706    3.487634    0.319550    0.079803    0.010376    0.696633    
#> 349: 0.614544    1.010648    3.487595    0.319418    0.079855    0.010369    0.696568    
#> 350: 0.614433    1.010455    3.487576    0.319241    0.079863    0.010357    0.696659    
#> 351: 0.614330    1.010577    3.487526    0.318985    0.079858    0.010342    0.696719    
#> 352: 0.613922    1.010690    3.487484    0.318697    0.079888    0.010330    0.696961    
#> 353: 0.613784    1.010866    3.487443    0.318648    0.080042    0.010310    0.696947    
#> 354: 0.613800    1.010858    3.487337    0.318717    0.080157    0.010281    0.696944    
#> 355: 0.614078    1.010823    3.487272    0.318960    0.080245    0.010268    0.696940    
#> 356: 0.614160    1.010791    3.487281    0.318663    0.080211    0.010264    0.696925    
#> 357: 0.614399    1.010818    3.487285    0.318674    0.080193    0.010264    0.696876    
#> 358: 0.614363    1.010930    3.487314    0.318863    0.080192    0.010251    0.696817    
#> 359: 0.614210    1.011060    3.487321    0.318697    0.080161    0.010250    0.696759    
#> 360: 0.613882    1.011119    3.487186    0.318741    0.080131    0.010239    0.696627    
#> 361: 0.613633    1.011179    3.487077    0.318567    0.080245    0.010223    0.696582    
#> 362: 0.613498    1.011316    3.486931    0.318815    0.080317    0.010207    0.696434    
#> 363: 0.613381    1.011395    3.486855    0.318677    0.080332    0.010196    0.696341    
#> 364: 0.613304    1.011529    3.486777    0.318744    0.080343    0.010199    0.696263    
#> 365: 0.613098    1.011493    3.486737    0.318842    0.080421    0.010193    0.696269    
#> 366: 0.612922    1.011575    3.486658    0.319020    0.080429    0.010187    0.696311    
#> 367: 0.613054    1.011699    3.486590    0.319859    0.080405    0.010181    0.696367    
#> 368: 0.613146    1.011772    3.486532    0.319980    0.080460    0.010175    0.696215    
#> 369: 0.612907    1.011831    3.486470    0.320229    0.080442    0.010172    0.696225    
#> 370: 0.612681    1.011930    3.486400    0.320518    0.080489    0.010155    0.696168    
#> 371: 0.612391    1.012015    3.486227    0.320693    0.080433    0.010135    0.696202    
#> 372: 0.612219    1.012056    3.486153    0.320924    0.080413    0.010113    0.696376    
#> 373: 0.611904    1.012271    3.486066    0.320963    0.080547    0.010098    0.696461    
#> 374: 0.611900    1.012215    3.486010    0.321430    0.080607    0.010085    0.696393    
#> 375: 0.611773    1.012336    3.485947    0.321669    0.080692    0.010068    0.696428    
#> 376: 0.611692    1.012490    3.485890    0.321865    0.080714    0.010063    0.696401    
#> 377: 0.611505    1.012626    3.485870    0.321901    0.080760    0.010069    0.696458    
#> 378: 0.611530    1.012629    3.485860    0.322187    0.080810    0.010068    0.696638    
#> 379: 0.611378    1.012458    3.485932    0.322151    0.080897    0.010076    0.696668    
#> 380: 0.611400    1.012369    3.485958    0.321863    0.080978    0.010074    0.696716    
#> 381: 0.611299    1.012321    3.485961    0.321538    0.081003    0.010083    0.696728    
#> 382: 0.611337    1.012349    3.485937    0.321575    0.080997    0.010095    0.696672    
#> 383: 0.611448    1.012229    3.485987    0.321491    0.081087    0.010092    0.696612    
#> 384: 0.611455    1.012225    3.486039    0.321655    0.081053    0.010082    0.696591    
#> 385: 0.611618    1.012150    3.486098    0.321698    0.081098    0.010072    0.696540    
#> 386: 0.611780    1.012304    3.486170    0.321480    0.081244    0.010074    0.696570    
#> 387: 0.611874    1.012349    3.486261    0.321276    0.081306    0.010076    0.696548    
#> 388: 0.611877    1.012477    3.486299    0.321177    0.081311    0.010081    0.696567    
#> 389: 0.611784    1.012252    3.486315    0.320998    0.081240    0.010086    0.696694    
#> 390: 0.611704    1.012188    3.486347    0.320607    0.081254    0.010099    0.696779    
#> 391: 0.611849    1.012026    3.486375    0.320191    0.081305    0.010091    0.696867    
#> 392: 0.612090    1.011985    3.486476    0.320320    0.081370    0.010093    0.696929    
#> 393: 0.612185    1.011927    3.486448    0.320491    0.081341    0.010091    0.696964    
#> 394: 0.612233    1.011972    3.486392    0.320697    0.081354    0.010088    0.696999    
#> 395: 0.612560    1.012099    3.486421    0.321005    0.081358    0.010092    0.696906    
#> 396: 0.612831    1.012148    3.486447    0.320957    0.081292    0.010101    0.696881    
#> 397: 0.612978    1.012138    3.486520    0.320794    0.081257    0.010105    0.696801    
#> 398: 0.613153    1.012048    3.486581    0.320708    0.081217    0.010120    0.696767    
#> 399: 0.613271    1.012049    3.486632    0.320494    0.081236    0.010131    0.696708    
#> 400: 0.613395    1.012152    3.486688    0.320198    0.081197    0.010139    0.696662    
#> 401: 0.613482    1.012223    3.486707    0.320206    0.081230    0.010138    0.696711    
#> 402: 0.613384    1.012362    3.486700    0.320197    0.081239    0.010133    0.696692    
#> 403: 0.613440    1.012359    3.486689    0.320080    0.081180    0.010134    0.696617    
#> 404: 0.613471    1.012336    3.486594    0.320214    0.081257    0.010129    0.696594    
#> 405: 0.613318    1.012432    3.486568    0.320287    0.081303    0.010120    0.696658    
#> 406: 0.613233    1.012542    3.486528    0.320221    0.081344    0.010102    0.696722    
#> 407: 0.613102    1.012652    3.486474    0.320228    0.081391    0.010093    0.696688    
#> 408: 0.613111    1.012762    3.486403    0.320214    0.081322    0.010094    0.696669    
#> 409: 0.612904    1.012732    3.486285    0.320098    0.081331    0.010077    0.696603    
#> 410: 0.612844    1.012818    3.486199    0.320015    0.081412    0.010071    0.696533    
#> 411: 0.612840    1.012698    3.486156    0.320292    0.081484    0.010069    0.696533    
#> 412: 0.612935    1.012705    3.486147    0.320407    0.081462    0.010071    0.696478    
#> 413: 0.612837    1.012713    3.486110    0.320360    0.081467    0.010064    0.696481    
#> 414: 0.612656    1.012767    3.486087    0.320375    0.081491    0.010065    0.696440    
#> 415: 0.612690    1.012699    3.486058    0.320425    0.081493    0.010054    0.696454    
#> 416: 0.612730    1.012746    3.486038    0.320471    0.081535    0.010045    0.696418    
#> 417: 0.612748    1.012759    3.486018    0.320042    0.081517    0.010043    0.696440    
#> 418: 0.612641    1.012834    3.486019    0.319955    0.081485    0.010050    0.696449    
#> 419: 0.612638    1.012905    3.486003    0.320005    0.081471    0.010062    0.696463    
#> 420: 0.612765    1.012886    3.486005    0.320232    0.081466    0.010060    0.696425    
#> 421: 0.612640    1.012910    3.486017    0.320285    0.081459    0.010065    0.696305    
#> 422: 0.612715    1.012863    3.486011    0.320156    0.081435    0.010060    0.696288    
#> 423: 0.612897    1.012817    3.486026    0.320197    0.081405    0.010056    0.696257    
#> 424: 0.612841    1.012790    3.485973    0.320302    0.081446    0.010054    0.696167    
#> 425: 0.612862    1.012846    3.485955    0.320276    0.081513    0.010052    0.696216    
#> 426: 0.613100    1.012924    3.485990    0.320303    0.081534    0.010053    0.696248    
#> 427: 0.613064    1.012918    3.486047    0.320210    0.081505    0.010056    0.696177    
#> 428: 0.612921    1.012977    3.486053    0.320253    0.081481    0.010057    0.696150    
#> 429: 0.613013    1.012942    3.486107    0.320222    0.081469    0.010062    0.696120    
#> 430: 0.612978    1.012960    3.486120    0.320015    0.081437    0.010067    0.696121    
#> 431: 0.612928    1.012976    3.486134    0.320056    0.081392    0.010076    0.696088    
#> 432: 0.612786    1.013055    3.486145    0.320011    0.081388    0.010087    0.696058    
#> 433: 0.612817    1.013160    3.486171    0.320048    0.081474    0.010087    0.696052    
#> 434: 0.612590    1.013154    3.486152    0.319774    0.081501    0.010089    0.696043    
#> 435: 0.612584    1.013148    3.486113    0.319762    0.081513    0.010094    0.696022    
#> 436: 0.612539    1.013053    3.486136    0.319619    0.081553    0.010100    0.696013    
#> 437: 0.612470    1.013018    3.486122    0.319583    0.081561    0.010101    0.695994    
#> 438: 0.612411    1.013099    3.486115    0.319465    0.081597    0.010097    0.695942    
#> 439: 0.612422    1.013223    3.486072    0.319626    0.081602    0.010098    0.695813    
#> 440: 0.612316    1.013308    3.486060    0.319523    0.081635    0.010092    0.695783    
#> 441: 0.612307    1.013270    3.486071    0.319553    0.081673    0.010091    0.695727    
#> 442: 0.612196    1.013293    3.486069    0.319583    0.081658    0.010085    0.695641    
#> 443: 0.612060    1.013355    3.486044    0.319582    0.081641    0.010082    0.695598    
#> 444: 0.611961    1.013385    3.485987    0.319778    0.081663    0.010081    0.695475    
#> 445: 0.611778    1.013501    3.485913    0.319880    0.081687    0.010081    0.695509    
#> 446: 0.611572    1.013592    3.485873    0.319821    0.081710    0.010085    0.695522    
#> 447: 0.611674    1.013685    3.485869    0.319928    0.081693    0.010078    0.695549    
#> 448: 0.611594    1.013678    3.485858    0.319961    0.081705    0.010077    0.695565    
#> 449: 0.611714    1.013710    3.485947    0.319979    0.081767    0.010081    0.695671    
#> 450: 0.611686    1.013681    3.485958    0.319960    0.081808    0.010078    0.695750    
#> 451: 0.611770    1.013664    3.485936    0.319878    0.081837    0.010087    0.695766    
#> 452: 0.611772    1.013673    3.485897    0.319830    0.081848    0.010089    0.695757    
#> 453: 0.611765    1.013711    3.485881    0.320099    0.081892    0.010089    0.695698    
#> 454: 0.611752    1.013828    3.485827    0.320529    0.081980    0.010076    0.695644    
#> 455: 0.611791    1.013855    3.485799    0.320859    0.081968    0.010071    0.695694    
#> 456: 0.611727    1.013800    3.485818    0.320877    0.082029    0.010071    0.695708    
#> 457: 0.611647    1.013748    3.485854    0.320710    0.082057    0.010066    0.695651    
#> 458: 0.611637    1.013798    3.485923    0.320621    0.082033    0.010067    0.695574    
#> 459: 0.611606    1.013839    3.485964    0.320443    0.081995    0.010074    0.695495    
#> 460: 0.611552    1.013775    3.485980    0.320307    0.082021    0.010073    0.695405    
#> 461: 0.611537    1.013715    3.486004    0.320320    0.081991    0.010065    0.695405    
#> 462: 0.611485    1.013802    3.486022    0.320433    0.081972    0.010061    0.695386    
#> 463: 0.611595    1.013853    3.486051    0.320469    0.081970    0.010067    0.695356    
#> 464: 0.611899    1.013908    3.486104    0.320686    0.081929    0.010063    0.695341    
#> 465: 0.612164    1.013815    3.486161    0.320994    0.081886    0.010061    0.695280    
#> 466: 0.612323    1.013814    3.486199    0.320912    0.081832    0.010063    0.695333    
#> 467: 0.612370    1.013747    3.486226    0.320767    0.081818    0.010070    0.695326    
#> 468: 0.612562    1.013707    3.486276    0.320788    0.081829    0.010067    0.695379    
#> 469: 0.612495    1.013787    3.486288    0.320676    0.081901    0.010053    0.695437    
#> 470: 0.612337    1.013860    3.486254    0.320478    0.081935    0.010055    0.695500    
#> 471: 0.612042    1.013830    3.486236    0.320216    0.081939    0.010051    0.695541    
#> 472: 0.611957    1.013837    3.486249    0.319923    0.082027    0.010048    0.695572    
#> 473: 0.611855    1.013830    3.486242    0.319853    0.082016    0.010046    0.695497    
#> 474: 0.611858    1.013814    3.486248    0.319804    0.082015    0.010037    0.695558    
#> 475: 0.611963    1.013826    3.486264    0.319823    0.082001    0.010027    0.695531    
#> 476: 0.611987    1.013810    3.486252    0.319761    0.082025    0.010011    0.695590    
#> 477: 0.612064    1.013788    3.486291    0.319769    0.082018    0.009992    0.695590    
#> 478: 0.611991    1.013763    3.486301    0.319897    0.082040    0.009978    0.695651    
#> 479: 0.612012    1.013783    3.486308    0.319985    0.082061    0.009969    0.695655    
#> 480: 0.612015    1.013793    3.486313    0.319937    0.082060    0.009961    0.695705    
#> 481: 0.611985    1.013795    3.486305    0.319991    0.082119    0.009950    0.695689    
#> 482: 0.612062    1.013767    3.486295    0.320225    0.082160    0.009947    0.695618    
#> 483: 0.612107    1.013694    3.486309    0.320121    0.082164    0.009939    0.695602    
#> 484: 0.612109    1.013554    3.486341    0.320094    0.082167    0.009934    0.695632    
#> 485: 0.612096    1.013545    3.486341    0.320101    0.082229    0.009929    0.695659    
#> 486: 0.612180    1.013598    3.486348    0.320257    0.082284    0.009927    0.695683    
#> 487: 0.612342    1.013624    3.486405    0.320521    0.082308    0.009920    0.695639    
#> 488: 0.612280    1.013637    3.486432    0.320457    0.082329    0.009918    0.695631    
#> 489: 0.612262    1.013640    3.486432    0.320345    0.082347    0.009915    0.695618    
#> 490: 0.612361    1.013661    3.486495    0.320186    0.082355    0.009910    0.695641    
#> 491: 0.612308    1.013694    3.486539    0.320339    0.082400    0.009906    0.695649    
#> 492: 0.612230    1.013759    3.486524    0.320515    0.082456    0.009906    0.695709    
#> 493: 0.612349    1.013775    3.486548    0.320618    0.082515    0.009907    0.695737    
#> 494: 0.612490    1.013825    3.486561    0.320399    0.082583    0.009907    0.695706    
#> 495: 0.612504    1.013829    3.486566    0.320333    0.082607    0.009895    0.695645    
#> 496: 0.612619    1.013888    3.486518    0.320197    0.082671    0.009899    0.695680    
#> 497: 0.612673    1.013925    3.486496    0.320407    0.082713    0.009894    0.695668    
#> 498: 0.612729    1.013928    3.486481    0.320528    0.082758    0.009882    0.695634    
#> 499: 0.612651    1.013957    3.486452    0.320354    0.082749    0.009880    0.695603    
#> 500: 0.612680    1.013887    3.486464    0.320283    0.082744    0.009882    0.695606    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.305464    0.960420    3.433279    0.392401    0.078082    0.016800    1.732350    
#> 002: 0.347492    0.994851    3.474862    0.372781    0.074178    0.015960    1.188193    
#> 003: 0.447648    0.998511    3.505398    0.354142    0.078737    0.015162    1.006413    
#> 004: 0.445431    1.026710    3.504519    0.350630    0.075645    0.014404    0.863150    
#> 005: 0.517039    1.050143    3.497784    0.341311    0.076552    0.013684    0.816122    
#> 006: 0.501796    1.067159    3.489678    0.336550    0.072725    0.013855    0.767096    
#> 007: 0.464650    1.079109    3.484967    0.378265    0.075690    0.015979    0.769088    
#> 008: 0.433216    1.078621    3.477077    0.409820    0.071906    0.018370    0.778318    
#> 009: 0.423172    1.066668    3.473679    0.456761    0.068311    0.017451    0.767906    
#> 010: 0.431031    1.075864    3.466202    0.433923    0.064895    0.019703    0.769898    
#> 011: 0.514439    1.073151    3.486236    0.412226    0.061650    0.022043    0.801548    
#> 012: 0.531336    1.060639    3.495134    0.391615    0.069203    0.023886    0.771476    
#> 013: 0.489789    1.062599    3.483942    0.526501    0.065743    0.030407    0.771542    
#> 014: 0.584303    1.066904    3.496599    0.614042    0.062456    0.030195    0.783406    
#> 015: 0.529720    1.075801    3.499222    0.583340    0.067344    0.030444    0.783971    
#> 016: 0.504580    1.081135    3.502202    0.554173    0.064592    0.028921    0.793879    
#> 017: 0.526499    1.082800    3.505165    0.526464    0.061362    0.027475    0.752693    
#> 018: 0.499356    1.082958    3.487386    0.500141    0.058294    0.028272    0.752915    
#> 019: 0.471687    1.087218    3.485675    0.475134    0.059565    0.026859    0.749468    
#> 020: 0.495921    1.080073    3.495418    0.498800    0.063875    0.026630    0.732434    
#> 021: 0.501334    1.080799    3.505957    0.485521    0.060681    0.026629    0.741850    
#> 022: 0.517919    1.067385    3.511037    0.461245    0.057647    0.027045    0.739774    
#> 023: 0.631685    1.071480    3.531822    0.462492    0.054765    0.026146    0.775571    
#> 024: 0.589069    1.095247    3.513218    0.461054    0.052027    0.024838    0.757090    
#> 025: 0.535135    1.062200    3.501407    0.449180    0.053547    0.023596    0.758760    
#> 026: 0.491738    1.106332    3.478048    0.451284    0.068300    0.022417    0.747408    
#> 027: 0.472990    1.122060    3.461702    0.558768    0.064885    0.021296    0.784443    
#> 028: 0.529554    1.109501    3.479297    0.530830    0.061641    0.020231    0.752791    
#> 029: 0.511046    1.090292    3.477651    0.504288    0.063888    0.019219    0.774551    
#> 030: 0.534957    1.107194    3.495715    0.479074    0.072781    0.020390    0.774495    
#> 031: 0.489754    1.096859    3.491263    0.494915    0.069142    0.019370    0.770695    
#> 032: 0.503214    1.076311    3.496368    0.470170    0.069034    0.018981    0.765918    
#> 033: 0.444355    1.105968    3.472679    0.533741    0.065582    0.018521    0.762832    
#> 034: 0.486103    1.115741    3.474109    0.507054    0.068989    0.017595    0.750766    
#> 035: 0.432730    1.100846    3.459082    0.481702    0.065540    0.016715    0.760573    
#> 036: 0.458034    1.103553    3.465199    0.487972    0.062263    0.015880    0.784436    
#> 037: 0.454773    1.106953    3.477719    0.463573    0.059150    0.015086    0.794957    
#> 038: 0.466678    1.107680    3.470467    0.440395    0.058990    0.016897    0.789657    
#> 039: 0.483876    1.101377    3.473388    0.418375    0.056041    0.017405    0.771636    
#> 040: 0.502964    1.101928    3.490392    0.458388    0.069726    0.020559    0.764992    
#> 041: 0.457065    1.091880    3.486934    0.435468    0.066239    0.019531    0.768902    
#> 042: 0.472087    1.096603    3.473230    0.433753    0.072183    0.018555    0.750210    
#> 043: 0.467843    1.116216    3.457319    0.522528    0.071585    0.018348    0.749911    
#> 044: 0.440615    1.106842    3.462575    0.496402    0.068006    0.019547    0.753296    
#> 045: 0.407418    1.125331    3.455396    0.471581    0.066506    0.019398    0.754303    
#> 046: 0.443935    1.103284    3.464079    0.448002    0.069648    0.018428    0.759833    
#> 047: 0.463208    1.117508    3.464075    0.508841    0.066166    0.017507    0.750506    
#> 048: 0.429876    1.096326    3.459592    0.483399    0.062858    0.016631    0.758971    
#> 049: 0.497217    1.085736    3.473239    0.464371    0.059715    0.015800    0.761088    
#> 050: 0.551274    1.049678    3.499296    0.441152    0.064934    0.018619    0.774316    
#> 051: 0.552091    1.082270    3.496585    0.436468    0.061687    0.017688    0.764396    
#> 052: 0.527294    1.094829    3.499334    0.466239    0.064877    0.016803    0.758547    
#> 053: 0.518841    1.069604    3.498600    0.454187    0.061633    0.020347    0.754308    
#> 054: 0.472252    1.076387    3.499777    0.431478    0.072343    0.020621    0.765186    
#> 055: 0.481716    1.072175    3.487662    0.447178    0.076964    0.019590    0.762490    
#> 056: 0.510590    1.059916    3.484282    0.570311    0.084790    0.018643    0.772077    
#> 057: 0.525351    1.073297    3.490934    0.558308    0.080550    0.018231    0.771603    
#> 058: 0.501867    1.098297    3.470438    0.535132    0.076523    0.017319    0.791429    
#> 059: 0.480110    1.055796    3.468252    0.508375    0.072696    0.018846    0.776361    
#> 060: 0.496564    1.042629    3.488944    0.482956    0.069062    0.023526    0.780601    
#> 061: 0.522806    1.063668    3.515357    0.458809    0.065609    0.031203    0.789997    
#> 062: 0.541287    1.103375    3.500446    0.448210    0.062328    0.029643    0.797457    
#> 063: 0.589614    1.080467    3.498258    0.559431    0.063601    0.028160    0.770796    
#> 064: 0.552211    1.090291    3.497682    0.531459    0.063972    0.026752    0.768264    
#> 065: 0.551519    1.073817    3.487928    0.504886    0.064105    0.025415    0.772323    
#> 066: 0.542788    1.083177    3.503245    0.488777    0.060900    0.024144    0.773928    
#> 067: 0.544915    1.084494    3.494033    0.464339    0.057855    0.026564    0.766802    
#> 068: 0.457058    1.079409    3.489519    0.441122    0.054962    0.026426    0.768288    
#> 069: 0.464427    1.091644    3.466657    0.450867    0.053495    0.027720    0.781521    
#> 070: 0.479370    1.104914    3.473079    0.468051    0.065462    0.026334    0.772234    
#> 071: 0.502150    1.137990    3.469501    0.518529    0.068028    0.030645    0.764448    
#> 072: 0.478597    1.094527    3.480504    0.492603    0.066721    0.029113    0.758864    
#> 073: 0.499183    1.083812    3.507600    0.467973    0.063385    0.027658    0.775726    
#> 074: 0.489093    1.056651    3.496079    0.444574    0.060215    0.026275    0.755084    
#> 075: 0.508466    1.056788    3.520033    0.429050    0.057205    0.025340    0.757389    
#> 076: 0.524832    1.061649    3.520662    0.407597    0.059926    0.024073    0.784827    
#> 077: 0.579090    1.043518    3.523692    0.422204    0.063930    0.022869    0.795822    
#> 078: 0.598791    1.051577    3.534976    0.460431    0.065691    0.023478    0.768463    
#> 079: 0.590590    1.071791    3.525441    0.437409    0.062407    0.027556    0.790628    
#> 080: 0.538225    1.052637    3.512712    0.448489    0.064492    0.026178    0.806559    
#> 081: 0.517266    1.067824    3.500522    0.426064    0.061267    0.024869    0.790195    
#> 082: 0.461205    1.073269    3.489841    0.404761    0.058204    0.024119    0.808810    
#> 083: 0.484432    1.101240    3.486480    0.393922    0.071484    0.023053    0.764815    
#> 084: 0.468583    1.103675    3.475045    0.436619    0.074715    0.021900    0.765565    
#> 085: 0.489325    1.098082    3.497574    0.488098    0.070979    0.020805    0.772777    
#> 086: 0.489468    1.097205    3.498895    0.463693    0.067430    0.020509    0.743787    
#> 087: 0.515511    1.088652    3.489383    0.440508    0.068982    0.019483    0.745131    
#> 088: 0.463577    1.061271    3.499514    0.418483    0.065533    0.025350    0.752952    
#> 089: 0.494801    1.080605    3.500678    0.397559    0.062256    0.024627    0.758699    
#> 090: 0.468074    1.073880    3.487877    0.377826    0.059143    0.023396    0.776701    
#> 091: 0.444719    1.060856    3.474886    0.358935    0.060089    0.024649    0.777588    
#> 092: 0.443737    1.090270    3.467667    0.401171    0.063285    0.023417    0.767130    
#> 093: 0.442141    1.079046    3.464941    0.402219    0.060121    0.022246    0.783524    
#> 094: 0.451363    1.101466    3.467620    0.397796    0.057115    0.023364    0.769052    
#> 095: 0.456207    1.113564    3.484371    0.377906    0.054259    0.022359    0.756807    
#> 096: 0.437388    1.096904    3.476644    0.380345    0.051546    0.027867    0.751162    
#> 097: 0.472789    1.103653    3.474531    0.437590    0.048969    0.027389    0.727488    
#> 098: 0.465052    1.117849    3.480472    0.416621    0.046520    0.026020    0.753894    
#> 099: 0.433913    1.087037    3.460826    0.479912    0.044194    0.024719    0.747907    
#> 100: 0.410782    1.088914    3.464859    0.455917    0.041985    0.023661    0.737239    
#> 101: 0.438762    1.076493    3.460128    0.449666    0.039885    0.023868    0.750952    
#> 102: 0.430038    1.069782    3.467195    0.427182    0.044632    0.022675    0.760239    
#> 103: 0.451072    1.088232    3.468055    0.481886    0.045178    0.021541    0.749524    
#> 104: 0.453854    1.089226    3.484754    0.457792    0.046510    0.021434    0.780549    
#> 105: 0.493136    1.090785    3.477806    0.434902    0.047703    0.020765    0.766093    
#> 106: 0.521191    1.095252    3.484598    0.478827    0.046343    0.020128    0.758060    
#> 107: 0.542420    1.091012    3.493531    0.482180    0.044026    0.019122    0.767754    
#> 108: 0.524502    1.084567    3.493192    0.483074    0.056455    0.018166    0.756635    
#> 109: 0.498496    1.094372    3.484894    0.468260    0.053632    0.017396    0.759104    
#> 110: 0.496567    1.088619    3.471021    0.529486    0.062361    0.016526    0.765776    
#> 111: 0.479891    1.107339    3.483850    0.503012    0.059243    0.017138    0.755578    
#> 112: 0.456990    1.089291    3.468864    0.477861    0.076002    0.016281    0.764051    
#> 113: 0.484927    1.102105    3.478492    0.453968    0.072202    0.015467    0.750976    
#> 114: 0.515957    1.099820    3.484374    0.600021    0.077397    0.019011    0.749905    
#> 115: 0.537539    1.067021    3.480623    0.633179    0.073527    0.018061    0.772674    
#> 116: 0.546231    1.082733    3.480887    0.601520    0.069851    0.018299    0.778396    
#> 117: 0.509469    1.096993    3.489705    0.571444    0.066358    0.019004    0.765345    
#> 118: 0.509927    1.075200    3.481644    0.558898    0.063041    0.018327    0.759731    
#> 119: 0.508606    1.078692    3.472999    0.547515    0.059889    0.027746    0.776425    
#> 120: 0.456826    1.076639    3.482037    0.520139    0.058000    0.027322    0.767172    
#> 121: 0.500879    1.094275    3.489929    0.494132    0.057575    0.025956    0.767927    
#> 122: 0.538699    1.062196    3.508015    0.469425    0.054696    0.030341    0.785687    
#> 123: 0.554879    1.094613    3.496346    0.501250    0.051961    0.028824    0.757148    
#> 124: 0.552238    1.125822    3.491125    0.479181    0.058203    0.027383    0.763392    
#> 125: 0.538756    1.116209    3.489887    0.534190    0.058580    0.026014    0.757317    
#> 126: 0.495163    1.119221    3.475008    0.510828    0.063943    0.024713    0.758509    
#> 127: 0.496034    1.121053    3.466027    0.529341    0.068003    0.023477    0.773123    
#> 128: 0.480970    1.099115    3.482637    0.502874    0.064603    0.022304    0.767393    
#> 129: 0.504272    1.109605    3.488373    0.477731    0.073117    0.021188    0.776180    
#> 130: 0.526924    1.110925    3.495576    0.453844    0.071843    0.020129    0.756477    
#> 131: 0.504177    1.081078    3.497557    0.431152    0.068250    0.024409    0.765694    
#> 132: 0.460481    1.081040    3.472053    0.409594    0.064838    0.023189    0.775802    
#> 133: 0.531856    1.079501    3.494677    0.546332    0.061596    0.022029    0.785948    
#> 134: 0.519726    1.060134    3.494350    0.566354    0.058516    0.021993    0.788420    
#> 135: 0.518324    1.056228    3.496297    0.538036    0.060367    0.020893    0.774484    
#> 136: 0.518371    1.045989    3.495236    0.511134    0.057348    0.019849    0.782623    
#> 137: 0.554652    1.059062    3.509014    0.485578    0.054481    0.021685    0.781902    
#> 138: 0.536436    1.066204    3.507656    0.461299    0.055942    0.020601    0.773850    
#> 139: 0.524841    1.078847    3.509677    0.438234    0.059033    0.024484    0.769595    
#> 140: 0.539313    1.101281    3.510398    0.450548    0.065638    0.026988    0.782418    
#> 141: 0.509675    1.067936    3.496710    0.442555    0.082451    0.025638    0.760111    
#> 142: 0.546697    1.063715    3.518038    0.480997    0.078329    0.024357    0.768303    
#> 143: 0.532225    1.100719    3.504282    0.504016    0.074412    0.023999    0.745202    
#> 144: 0.555546    1.088516    3.512093    0.497697    0.070692    0.022799    0.725734    
#> 145: 0.530409    1.098803    3.490139    0.489243    0.067157    0.024580    0.745058    
#> 146: 0.461454    1.104323    3.481711    0.482270    0.063799    0.023351    0.770222    
#> 147: 0.429856    1.091166    3.456064    0.483962    0.060609    0.022183    0.743708    
#> 148: 0.450532    1.125198    3.470926    0.550940    0.070446    0.021074    0.750072    
#> 149: 0.444824    1.078736    3.473572    0.523393    0.078266    0.020020    0.770234    
#> 150: 0.469220    1.091800    3.459372    0.497224    0.079841    0.019080    0.792739    
#> 151: 0.467012    1.107053    3.470661    0.480936    0.075849    0.018126    0.767834    
#> 152: 0.422461    1.102696    3.474180    0.413081    0.079529    0.024296    0.771496    
#> 153: 0.458248    1.117497    3.483948    0.415642    0.068468    0.025009    0.787852    
#> 154: 0.553084    1.119420    3.504253    0.458382    0.068265    0.021746    0.767981    
#> 155: 0.485826    1.090366    3.492678    0.393958    0.067523    0.020144    0.757757    
#> 156: 0.500497    1.067446    3.507661    0.361320    0.063101    0.019370    0.797558    
#> 157: 0.487285    1.064538    3.511311    0.400884    0.061853    0.023450    0.779848    
#> 158: 0.529846    1.088848    3.501644    0.423793    0.061519    0.020815    0.757313    
#> 159: 0.463201    1.095604    3.501501    0.389875    0.052003    0.020186    0.757345    
#> 160: 0.524459    1.078308    3.499738    0.456851    0.054269    0.019799    0.768594    
#> 161: 0.507242    1.082586    3.487661    0.461642    0.057640    0.025286    0.755969    
#> 162: 0.473831    1.101371    3.480715    0.422242    0.052650    0.025269    0.765503    
#> 163: 0.495368    1.089785    3.480289    0.364410    0.045804    0.025783    0.773507    
#> 164: 0.505657    1.106859    3.483882    0.451508    0.052229    0.024383    0.763438    
#> 165: 0.482605    1.108359    3.477637    0.391439    0.052484    0.017030    0.747857    
#> 166: 0.511287    1.127624    3.484678    0.409399    0.058919    0.015410    0.766138    
#> 167: 0.540996    1.101354    3.495580    0.533432    0.054752    0.016649    0.804866    
#> 168: 0.526748    1.108782    3.500780    0.510557    0.051088    0.021226    0.754902    
#> 169: 0.499520    1.114234    3.481228    0.452210    0.061199    0.019866    0.767267    
#> 170: 0.510362    1.084039    3.485268    0.439470    0.050509    0.019897    0.753927    
#> 171: 0.453962    1.085326    3.480974    0.459310    0.052021    0.018711    0.747381    
#> 172: 0.438754    1.112266    3.469326    0.467201    0.046718    0.017644    0.766031    
#> 173: 0.452654    1.111920    3.458999    0.517718    0.043868    0.026877    0.753218    
#> 174: 0.457154    1.104713    3.476710    0.468850    0.047506    0.023700    0.758752    
#> 175: 0.459297    1.101606    3.463998    0.531610    0.043600    0.030176    0.771886    
#> 176: 0.459690    1.101050    3.494648    0.349587    0.049549    0.023143    0.772843    
#> 177: 0.485066    1.089643    3.502474    0.406173    0.058565    0.027987    0.755218    
#> 178: 0.513845    1.068635    3.494950    0.406996    0.049647    0.027825    0.746669    
#> 179: 0.517199    1.087394    3.494340    0.378145    0.050406    0.021154    0.759992    
#> 180: 0.491555    1.079797    3.495083    0.398746    0.049561    0.018339    0.739116    
#> 181: 0.516684    1.059482    3.478915    0.413023    0.058324    0.020685    0.752198    
#> 182: 0.500976    1.065926    3.470589    0.444534    0.059313    0.016245    0.778862    
#> 183: 0.499613    1.107056    3.470562    0.435657    0.054032    0.016688    0.778411    
#> 184: 0.452000    1.109227    3.469189    0.450179    0.057747    0.017675    0.782345    
#> 185: 0.442693    1.127092    3.461923    0.488121    0.053429    0.020186    0.760992    
#> 186: 0.445259    1.131645    3.468590    0.477425    0.047641    0.019622    0.779705    
#> 187: 0.441687    1.107895    3.475883    0.468128    0.056325    0.020941    0.758554    
#> 188: 0.442319    1.107923    3.472588    0.378407    0.055359    0.021402    0.763179    
#> 189: 0.427547    1.128100    3.462894    0.419796    0.058204    0.019360    0.765137    
#> 190: 0.455025    1.117788    3.469084    0.483022    0.059987    0.018662    0.751041    
#> 191: 0.429090    1.120517    3.461053    0.421069    0.059912    0.015624    0.732016    
#> 192: 0.432873    1.122193    3.461562    0.499357    0.070011    0.014079    0.732908    
#> 193: 0.503332    1.123585    3.474284    0.514903    0.067743    0.018853    0.740656    
#> 194: 0.478143    1.108140    3.470991    0.496314    0.063093    0.017707    0.756020    
#> 195: 0.469793    1.106726    3.469071    0.560862    0.057895    0.016915    0.758271    
#> 196: 0.461586    1.107536    3.470843    0.496259    0.059673    0.017294    0.770401    
#> 197: 0.424171    1.106266    3.482002    0.440320    0.061717    0.018319    0.783359    
#> 198: 0.486962    1.091141    3.475643    0.443677    0.048382    0.021159    0.754656    
#> 199: 0.441312    1.080694    3.480680    0.377618    0.049207    0.020985    0.748154    
#> 200: 0.495557    1.085825    3.482039    0.501067    0.053069    0.020753    0.755191    
#> 201: 0.492096    1.069887    3.491488    0.477492    0.055584    0.023200    0.759143    
#> 202: 0.496773    1.071649    3.493256    0.475168    0.053174    0.024342    0.761792    
#> 203: 0.507115    1.073659    3.492440    0.479157    0.054985    0.025112    0.759969    
#> 204: 0.515570    1.070638    3.493662    0.488713    0.056654    0.024547    0.764184    
#> 205: 0.509935    1.080372    3.492265    0.493952    0.058977    0.024942    0.766490    
#> 206: 0.507037    1.083584    3.493371    0.490107    0.058128    0.024992    0.768117    
#> 207: 0.500501    1.086659    3.491349    0.494662    0.056914    0.024878    0.768814    
#> 208: 0.493064    1.086801    3.490506    0.490324    0.055663    0.024641    0.768558    
#> 209: 0.493524    1.086765    3.489691    0.485019    0.055074    0.024864    0.768514    
#> 210: 0.497203    1.085615    3.490487    0.478719    0.054853    0.025043    0.767540    
#> 211: 0.499805    1.086855    3.491262    0.476469    0.054936    0.024606    0.766002    
#> 212: 0.501701    1.086361    3.491672    0.468830    0.054949    0.024683    0.765789    
#> 213: 0.503165    1.082234    3.492863    0.460254    0.054892    0.024726    0.767506    
#> 214: 0.506130    1.079966    3.494146    0.459050    0.054718    0.024622    0.767501    
#> 215: 0.505643    1.079441    3.495270    0.451801    0.054439    0.024575    0.767385    
#> 216: 0.509313    1.078170    3.495844    0.446518    0.054165    0.024380    0.769228    
#> 217: 0.510563    1.078197    3.496596    0.441574    0.054096    0.024406    0.769265    
#> 218: 0.512925    1.078389    3.496198    0.443145    0.053236    0.024461    0.769744    
#> 219: 0.510634    1.078115    3.494953    0.442561    0.053418    0.024410    0.769363    
#> 220: 0.506420    1.079013    3.493320    0.447331    0.053378    0.024265    0.768837    
#> 221: 0.503649    1.079779    3.492543    0.448493    0.053419    0.024203    0.768160    
#> 222: 0.502376    1.080528    3.492236    0.447877    0.053289    0.024218    0.767620    
#> 223: 0.502250    1.081144    3.491643    0.446103    0.053029    0.024396    0.766994    
#> 224: 0.503320    1.082821    3.491268    0.446367    0.052612    0.024551    0.766270    
#> 225: 0.501185    1.083090    3.491615    0.444154    0.052682    0.024574    0.765800    
#> 226: 0.499999    1.082604    3.490914    0.443456    0.052262    0.024661    0.765994    
#> 227: 0.498560    1.082759    3.490477    0.444996    0.052111    0.024777    0.766235    
#> 228: 0.497285    1.083642    3.489833    0.444698    0.052021    0.024809    0.766277    
#> 229: 0.495947    1.083749    3.489443    0.444186    0.051832    0.024844    0.765806    
#> 230: 0.495423    1.083821    3.489042    0.442939    0.051880    0.024838    0.765707    
#> 231: 0.494929    1.083908    3.489227    0.443062    0.051873    0.024873    0.764881    
#> 232: 0.494190    1.083717    3.489426    0.441477    0.052008    0.024764    0.764852    
#> 233: 0.493739    1.082931    3.489660    0.442377    0.052214    0.024632    0.764647    
#> 234: 0.493469    1.082910    3.489700    0.441341    0.052207    0.024626    0.764663    
#> 235: 0.493790    1.082503    3.489467    0.441683    0.052269    0.024475    0.764575    
#> 236: 0.494690    1.082753    3.489154    0.443443    0.052517    0.024345    0.764650    
#> 237: 0.494579    1.082946    3.488862    0.441196    0.052738    0.024176    0.765204    
#> 238: 0.494350    1.083119    3.488927    0.437412    0.053109    0.024128    0.766157    
#> 239: 0.494461    1.083841    3.488990    0.436046    0.052999    0.024167    0.766121    
#> 240: 0.494463    1.083767    3.489256    0.436556    0.052989    0.024177    0.765701    
#> 241: 0.494660    1.083186    3.489343    0.436769    0.052915    0.024212    0.765817    
#> 242: 0.494114    1.082865    3.489064    0.436612    0.052900    0.024216    0.766227    
#> 243: 0.493566    1.083527    3.488944    0.436574    0.052691    0.024274    0.767099    
#> 244: 0.492607    1.083771    3.488927    0.438290    0.052795    0.024265    0.767732    
#> 245: 0.492953    1.083655    3.488830    0.439878    0.052886    0.024162    0.768166    
#> 246: 0.492945    1.083992    3.488791    0.440793    0.053038    0.024172    0.768108    
#> 247: 0.493322    1.084184    3.488931    0.442634    0.053103    0.024191    0.767982    
#> 248: 0.492336    1.085066    3.488734    0.441862    0.053386    0.024197    0.767381    
#> 249: 0.491109    1.085680    3.488432    0.441871    0.053516    0.024223    0.767340    
#> 250: 0.491256    1.086376    3.488316    0.442268    0.053437    0.024228    0.767514    
#> 251: 0.491354    1.086834    3.488382    0.441998    0.053461    0.024171    0.767532    
#> 252: 0.491539    1.086980    3.488861    0.439980    0.053265    0.024240    0.767480    
#> 253: 0.491573    1.087007    3.488976    0.439489    0.053153    0.024263    0.767353    
#> 254: 0.491935    1.087164    3.489251    0.439548    0.052975    0.024290    0.767706    
#> 255: 0.492399    1.087488    3.489478    0.439939    0.053090    0.024376    0.767682    
#> 256: 0.492671    1.087523    3.489412    0.439591    0.053391    0.024437    0.767657    
#> 257: 0.493291    1.086985    3.489587    0.440235    0.053330    0.024411    0.767633    
#> 258: 0.493129    1.086453    3.489565    0.440060    0.053261    0.024468    0.767597    
#> 259: 0.492773    1.086253    3.489599    0.440616    0.053207    0.024475    0.767731    
#> 260: 0.492172    1.086467    3.489827    0.440140    0.053248    0.024402    0.767717    
#> 261: 0.491819    1.086253    3.490022    0.439059    0.053290    0.024426    0.767762    
#> 262: 0.492227    1.086222    3.490172    0.439544    0.053637    0.024423    0.767501    
#> 263: 0.491714    1.086406    3.490296    0.438598    0.053790    0.024420    0.767555    
#> 264: 0.491623    1.086325    3.490305    0.438761    0.054191    0.024375    0.767367    
#> 265: 0.491816    1.086136    3.490339    0.438899    0.054476    0.024326    0.767234    
#> 266: 0.492147    1.086205    3.490357    0.438867    0.054630    0.024325    0.767174    
#> 267: 0.492292    1.086096    3.490482    0.438608    0.054688    0.024265    0.767184    
#> 268: 0.492763    1.085787    3.490505    0.438998    0.054781    0.024259    0.767028    
#> 269: 0.493536    1.085394    3.490535    0.440672    0.054765    0.024304    0.767012    
#> 270: 0.493989    1.085530    3.490442    0.440992    0.054811    0.024289    0.766833    
#> 271: 0.494318    1.085873    3.490384    0.441663    0.054906    0.024272    0.766992    
#> 272: 0.494269    1.085786    3.490314    0.442708    0.055104    0.024222    0.767208    
#> 273: 0.494186    1.086062    3.490429    0.443053    0.055185    0.024169    0.767425    
#> 274: 0.493942    1.086266    3.490432    0.442707    0.055402    0.024129    0.767341    
#> 275: 0.493223    1.086357    3.490175    0.441814    0.055514    0.024046    0.767181    
#> 276: 0.493003    1.086665    3.490171    0.441786    0.055537    0.023970    0.767218    
#> 277: 0.492816    1.086996    3.490131    0.441847    0.055456    0.023927    0.766943    
#> 278: 0.492610    1.087121    3.490194    0.441831    0.055536    0.023897    0.766730    
#> 279: 0.492439    1.086982    3.490254    0.441283    0.055775    0.023884    0.766719    
#> 280: 0.492617    1.087042    3.490389    0.440788    0.055982    0.023879    0.766856    
#> 281: 0.492733    1.086947    3.490591    0.440064    0.056197    0.023872    0.766856    
#> 282: 0.492821    1.087002    3.490764    0.439456    0.056244    0.023843    0.767003    
#> 283: 0.492872    1.086920    3.490957    0.438251    0.056114    0.023786    0.767567    
#> 284: 0.492907    1.086711    3.490995    0.438036    0.056083    0.023762    0.767425    
#> 285: 0.492735    1.086631    3.490889    0.437885    0.056013    0.023760    0.767453    
#> 286: 0.492629    1.086851    3.490724    0.437611    0.055996    0.023774    0.767559    
#> 287: 0.492556    1.087102    3.490528    0.439242    0.056043    0.023775    0.767524    
#> 288: 0.492791    1.087131    3.490406    0.440174    0.055850    0.023883    0.767609    
#> 289: 0.493457    1.086932    3.490371    0.440571    0.055813    0.023882    0.767838    
#> 290: 0.494041    1.086829    3.490485    0.441396    0.055766    0.023901    0.767774    
#> 291: 0.494268    1.086881    3.490685    0.440860    0.055732    0.023945    0.767500    
#> 292: 0.494270    1.087078    3.490609    0.441125    0.055644    0.023981    0.767317    
#> 293: 0.494560    1.087039    3.490565    0.441889    0.055656    0.024022    0.767106    
#> 294: 0.494559    1.087105    3.490504    0.441992    0.055604    0.024074    0.767197    
#> 295: 0.494376    1.086797    3.490452    0.442308    0.055612    0.024069    0.767080    
#> 296: 0.494582    1.086648    3.490504    0.442193    0.055644    0.024050    0.767027    
#> 297: 0.494946    1.086408    3.490580    0.441942    0.055594    0.024041    0.767069    
#> 298: 0.495195    1.086245    3.490563    0.442705    0.055605    0.023985    0.766931    
#> 299: 0.495632    1.086342    3.490585    0.443531    0.055610    0.023912    0.766917    
#> 300: 0.495960    1.086342    3.490733    0.443344    0.055582    0.023913    0.766734    
#> 301: 0.496062    1.086090    3.490773    0.443892    0.055605    0.023926    0.766700    
#> 302: 0.496330    1.086150    3.490786    0.444270    0.055622    0.023919    0.766634    
#> 303: 0.496149    1.086224    3.490768    0.443990    0.055706    0.023901    0.766428    
#> 304: 0.496147    1.086411    3.490639    0.443646    0.055746    0.023893    0.766348    
#> 305: 0.495925    1.086224    3.490533    0.444037    0.055728    0.023866    0.766261    
#> 306: 0.495471    1.086281    3.490358    0.444398    0.055757    0.023872    0.766205    
#> 307: 0.495127    1.086261    3.490215    0.444916    0.055767    0.023886    0.766222    
#> 308: 0.494611    1.086340    3.490076    0.445156    0.055804    0.023872    0.766049    
#> 309: 0.494447    1.086324    3.489953    0.445120    0.055911    0.023875    0.766068    
#> 310: 0.494603    1.086405    3.489726    0.445518    0.055950    0.023802    0.765975    
#> 311: 0.494604    1.086431    3.489630    0.446104    0.055951    0.023742    0.765878    
#> 312: 0.494350    1.086465    3.489571    0.445730    0.055982    0.023731    0.765927    
#> 313: 0.494055    1.086193    3.489498    0.445449    0.055942    0.023730    0.766078    
#> 314: 0.493727    1.086292    3.489359    0.445641    0.055932    0.023720    0.766121    
#> 315: 0.493761    1.086453    3.489251    0.445658    0.055816    0.023708    0.766128    
#> 316: 0.493801    1.086605    3.489214    0.445559    0.055741    0.023707    0.766235    
#> 317: 0.493874    1.086524    3.489237    0.445916    0.055683    0.023722    0.766316    
#> 318: 0.493907    1.086613    3.489152    0.445696    0.055711    0.023705    0.766265    
#> 319: 0.494045    1.086592    3.489204    0.445660    0.055744    0.023718    0.766326    
#> 320: 0.493792    1.086690    3.489063    0.445778    0.055758    0.023691    0.766448    
#> 321: 0.493575    1.086777    3.488846    0.445005    0.055792    0.023660    0.766638    
#> 322: 0.493680    1.086700    3.488831    0.443795    0.055730    0.023636    0.766631    
#> 323: 0.493473    1.086669    3.488795    0.443250    0.055691    0.023588    0.766709    
#> 324: 0.493346    1.086806    3.488842    0.442613    0.055818    0.023583    0.766558    
#> 325: 0.493609    1.086893    3.488896    0.442249    0.055873    0.023591    0.766484    
#> 326: 0.493692    1.086851    3.488879    0.442406    0.055815    0.023580    0.766471    
#> 327: 0.493746    1.086796    3.488997    0.442387    0.055859    0.023594    0.766409    
#> 328: 0.493904    1.086903    3.488959    0.442293    0.055964    0.023571    0.766285    
#> 329: 0.494024    1.086805    3.489003    0.442481    0.055907    0.023607    0.766294    
#> 330: 0.493690    1.086797    3.488930    0.442274    0.055948    0.023598    0.766328    
#> 331: 0.493859    1.086997    3.488887    0.442229    0.056069    0.023572    0.766157    
#> 332: 0.494167    1.087078    3.488904    0.442436    0.056145    0.023516    0.766261    
#> 333: 0.494014    1.087143    3.488824    0.442277    0.056176    0.023467    0.766287    
#> 334: 0.493695    1.087158    3.488600    0.442488    0.056190    0.023476    0.766197    
#> 335: 0.493299    1.087287    3.488405    0.442347    0.056261    0.023457    0.766134    
#> 336: 0.492606    1.087474    3.488206    0.441853    0.056253    0.023439    0.766190    
#> 337: 0.492038    1.087865    3.487968    0.441800    0.056350    0.023430    0.766215    
#> 338: 0.491670    1.087973    3.487842    0.441567    0.056388    0.023401    0.766319    
#> 339: 0.491129    1.088161    3.487717    0.441254    0.056419    0.023373    0.766398    
#> 340: 0.490737    1.088100    3.487676    0.440733    0.056519    0.023349    0.766426    
#> 341: 0.490670    1.088184    3.487684    0.440275    0.056582    0.023326    0.766400    
#> 342: 0.490593    1.088029    3.487746    0.439968    0.056589    0.023305    0.766388    
#> 343: 0.490739    1.087966    3.487860    0.440260    0.056514    0.023313    0.766388    
#> 344: 0.491313    1.087872    3.488028    0.440846    0.056443    0.023331    0.766474    
#> 345: 0.491594    1.087723    3.488118    0.441007    0.056374    0.023352    0.766398    
#> 346: 0.491735    1.087830    3.488071    0.440944    0.056292    0.023364    0.766314    
#> 347: 0.491675    1.087647    3.487992    0.440298    0.056214    0.023370    0.766548    
#> 348: 0.491282    1.087700    3.487941    0.440338    0.056147    0.023389    0.766538    
#> 349: 0.490947    1.087577    3.487847    0.440337    0.056118    0.023390    0.766514    
#> 350: 0.490623    1.087440    3.487790    0.440256    0.056045    0.023414    0.766478    
#> 351: 0.490516    1.087528    3.487661    0.440634    0.055963    0.023430    0.766517    
#> 352: 0.490235    1.087572    3.487632    0.440568    0.055892    0.023459    0.766582    
#> 353: 0.490377    1.087701    3.487582    0.440187    0.055892    0.023455    0.766623    
#> 354: 0.490099    1.087673    3.487446    0.439796    0.055892    0.023422    0.766593    
#> 355: 0.490261    1.087571    3.487397    0.439365    0.055927    0.023383    0.766568    
#> 356: 0.490385    1.087462    3.487456    0.439396    0.055965    0.023352    0.766700    
#> 357: 0.490758    1.087630    3.487430    0.440145    0.056029    0.023287    0.766693    
#> 358: 0.490749    1.087854    3.487439    0.440312    0.056097    0.023260    0.766672    
#> 359: 0.490585    1.088028    3.487386    0.439932    0.056099    0.023271    0.766619    
#> 360: 0.490274    1.088112    3.487187    0.439541    0.056034    0.023275    0.766657    
#> 361: 0.489997    1.088238    3.487018    0.439749    0.055977    0.023269    0.766723    
#> 362: 0.489973    1.088359    3.486873    0.440055    0.055917    0.023260    0.766556    
#> 363: 0.489962    1.088358    3.486841    0.440126    0.055918    0.023275    0.766331    
#> 364: 0.489983    1.088404    3.486814    0.439767    0.055900    0.023295    0.766243    
#> 365: 0.489969    1.088311    3.486868    0.439766    0.055813    0.023313    0.766261    
#> 366: 0.489860    1.088325    3.486774    0.439853    0.055728    0.023294    0.766258    
#> 367: 0.489756    1.088352    3.486706    0.439420    0.055695    0.023267    0.766208    
#> 368: 0.489813    1.088408    3.486680    0.438959    0.055685    0.023254    0.766093    
#> 369: 0.489659    1.088498    3.486638    0.438779    0.055681    0.023211    0.766057    
#> 370: 0.489558    1.088567    3.486623    0.438475    0.055688    0.023200    0.766049    
#> 371: 0.489290    1.088717    3.486533    0.438025    0.055738    0.023166    0.766039    
#> 372: 0.489114    1.088848    3.486444    0.437796    0.055811    0.023139    0.766057    
#> 373: 0.488865    1.088984    3.486367    0.437433    0.055837    0.023137    0.766026    
#> 374: 0.488802    1.088868    3.486393    0.437232    0.055824    0.023146    0.765893    
#> 375: 0.488654    1.088896    3.486366    0.436890    0.055795    0.023148    0.765907    
#> 376: 0.488636    1.088866    3.486355    0.436568    0.055774    0.023152    0.765840    
#> 377: 0.488555    1.088976    3.486380    0.436441    0.055779    0.023157    0.765799    
#> 378: 0.488392    1.089002    3.486328    0.436377    0.055785    0.023123    0.765815    
#> 379: 0.488247    1.088833    3.486365    0.436136    0.055761    0.023123    0.765833    
#> 380: 0.488153    1.088741    3.486406    0.435636    0.055778    0.023161    0.765846    
#> 381: 0.487895    1.088724    3.486319    0.435545    0.055872    0.023148    0.765817    
#> 382: 0.487613    1.088755    3.486317    0.434933    0.055869    0.023123    0.765843    
#> 383: 0.487679    1.088771    3.486315    0.434632    0.055877    0.023124    0.765767    
#> 384: 0.487388    1.088689    3.486292    0.434398    0.055822    0.023156    0.765818    
#> 385: 0.487468    1.088657    3.486324    0.434159    0.055789    0.023162    0.765810    
#> 386: 0.487622    1.088700    3.486422    0.433925    0.055754    0.023172    0.765880    
#> 387: 0.487887    1.088637    3.486545    0.433780    0.055735    0.023208    0.765913    
#> 388: 0.488071    1.088548    3.486664    0.433367    0.055711    0.023222    0.765955    
#> 389: 0.488107    1.088385    3.486704    0.433078    0.055755    0.023246    0.765976    
#> 390: 0.488127    1.088349    3.486791    0.433000    0.055763    0.023257    0.766021    
#> 391: 0.488403    1.088259    3.486835    0.433073    0.055761    0.023272    0.766026    
#> 392: 0.488535    1.088226    3.486868    0.432885    0.055819    0.023263    0.766070    
#> 393: 0.488442    1.088114    3.486870    0.432459    0.055884    0.023226    0.766065    
#> 394: 0.488475    1.088062    3.486839    0.432485    0.055854    0.023207    0.766062    
#> 395: 0.488686    1.088129    3.486838    0.432665    0.055884    0.023201    0.765998    
#> 396: 0.488803    1.088179    3.486929    0.432516    0.055925    0.023200    0.765898    
#> 397: 0.488936    1.088123    3.487012    0.432515    0.055880    0.023200    0.765901    
#> 398: 0.489044    1.088017    3.487048    0.432558    0.055914    0.023179    0.765880    
#> 399: 0.489306    1.088028    3.487124    0.432801    0.055900    0.023162    0.765871    
#> 400: 0.489350    1.088176    3.487152    0.432715    0.055949    0.023171    0.765757    
#> 401: 0.489271    1.088306    3.487128    0.432747    0.055902    0.023183    0.765888    
#> 402: 0.489267    1.088390    3.487121    0.432586    0.055854    0.023199    0.766007    
#> 403: 0.489498    1.088410    3.487059    0.432986    0.055865    0.023206    0.765988    
#> 404: 0.489573    1.088447    3.486952    0.433472    0.055894    0.023214    0.765949    
#> 405: 0.489428    1.088517    3.486917    0.433705    0.055910    0.023245    0.766018    
#> 406: 0.489546    1.088493    3.486929    0.434223    0.055875    0.023295    0.766134    
#> 407: 0.489545    1.088424    3.486961    0.434409    0.055834    0.023327    0.766195    
#> 408: 0.489655    1.088507    3.486944    0.434970    0.055875    0.023311    0.766286    
#> 409: 0.489586    1.088484    3.486886    0.435193    0.055931    0.023301    0.766244    
#> 410: 0.489559    1.088496    3.486775    0.435354    0.055937    0.023284    0.766341    
#> 411: 0.489721    1.088306    3.486793    0.435666    0.055971    0.023280    0.766460    
#> 412: 0.489685    1.088260    3.486795    0.435765    0.055982    0.023272    0.766474    
#> 413: 0.489769    1.088265    3.486782    0.435900    0.055978    0.023276    0.766475    
#> 414: 0.489715    1.088262    3.486791    0.436163    0.055964    0.023311    0.766420    
#> 415: 0.489783    1.088251    3.486813    0.436076    0.055896    0.023335    0.766321    
#> 416: 0.489776    1.088277    3.486800    0.436090    0.055830    0.023337    0.766284    
#> 417: 0.489795    1.088201    3.486808    0.435559    0.055817    0.023342    0.766347    
#> 418: 0.489545    1.088228    3.486810    0.435362    0.055832    0.023360    0.766317    
#> 419: 0.489411    1.088329    3.486779    0.435317    0.055814    0.023375    0.766269    
#> 420: 0.489431    1.088438    3.486751    0.435479    0.055822    0.023386    0.766207    
#> 421: 0.489254    1.088532    3.486777    0.435316    0.055801    0.023396    0.766120    
#> 422: 0.489429    1.088463    3.486772    0.435224    0.055726    0.023402    0.766137    
#> 423: 0.489518    1.088319    3.486798    0.435127    0.055654    0.023413    0.766082    
#> 424: 0.489412    1.088208    3.486790    0.434961    0.055563    0.023445    0.766150    
#> 425: 0.489600    1.088210    3.486819    0.434736    0.055495    0.023512    0.766190    
#> 426: 0.489722    1.088295    3.486835    0.434642    0.055448    0.023530    0.766180    
#> 427: 0.489712    1.088294    3.486872    0.434661    0.055454    0.023532    0.766143    
#> 428: 0.489797    1.088334    3.486885    0.434735    0.055425    0.023526    0.766153    
#> 429: 0.489913    1.088388    3.486920    0.434570    0.055407    0.023505    0.766168    
#> 430: 0.490005    1.088434    3.486941    0.434651    0.055381    0.023495    0.766243    
#> 431: 0.489922    1.088425    3.486875    0.434589    0.055317    0.023471    0.766234    
#> 432: 0.489807    1.088521    3.486857    0.434590    0.055320    0.023475    0.766222    
#> 433: 0.489721    1.088668    3.486830    0.434499    0.055338    0.023484    0.766191    
#> 434: 0.489575    1.088599    3.486830    0.434355    0.055346    0.023477    0.766136    
#> 435: 0.489530    1.088583    3.486818    0.434012    0.055352    0.023478    0.766077    
#> 436: 0.489543    1.088535    3.486885    0.433811    0.055371    0.023466    0.766118    
#> 437: 0.489659    1.088523    3.486900    0.433898    0.055355    0.023468    0.766124    
#> 438: 0.489606    1.088607    3.486891    0.434001    0.055389    0.023457    0.766073    
#> 439: 0.489878    1.088631    3.486980    0.434063    0.055353    0.023451    0.765990    
#> 440: 0.489903    1.088683    3.487020    0.434048    0.055300    0.023444    0.765981    
#> 441: 0.490052    1.088615    3.487061    0.434095    0.055231    0.023429    0.765971    
#> 442: 0.490013    1.088620    3.487082    0.434172    0.055183    0.023412    0.765959    
#> 443: 0.489855    1.088720    3.486996    0.433985    0.055173    0.023409    0.765964    
#> 444: 0.489692    1.088774    3.486902    0.433725    0.055166    0.023404    0.765997    
#> 445: 0.489460    1.088778    3.486810    0.433374    0.055186    0.023403    0.766047    
#> 446: 0.489284    1.088845    3.486699    0.433457    0.055204    0.023398    0.766039    
#> 447: 0.489340    1.088893    3.486674    0.433508    0.055255    0.023372    0.766125    
#> 448: 0.489204    1.088909    3.486680    0.433724    0.055272    0.023351    0.766115    
#> 449: 0.489179    1.089007    3.486690    0.434203    0.055273    0.023333    0.766157    
#> 450: 0.489115    1.089100    3.486604    0.434513    0.055274    0.023307    0.766200    
#> 451: 0.489053    1.089300    3.486534    0.434702    0.055270    0.023303    0.766156    
#> 452: 0.489026    1.089349    3.486465    0.434949    0.055255    0.023308    0.766050    
#> 453: 0.488926    1.089411    3.486433    0.434979    0.055272    0.023320    0.765980    
#> 454: 0.488817    1.089479    3.486379    0.434919    0.055215    0.023326    0.765938    
#> 455: 0.488755    1.089486    3.486358    0.434909    0.055186    0.023319    0.765867    
#> 456: 0.488740    1.089455    3.486309    0.434930    0.055130    0.023313    0.765882    
#> 457: 0.488722    1.089448    3.486326    0.435019    0.055074    0.023319    0.765848    
#> 458: 0.488836    1.089563    3.486378    0.434958    0.055034    0.023352    0.765796    
#> 459: 0.488707    1.089631    3.486412    0.434996    0.055047    0.023359    0.765724    
#> 460: 0.488679    1.089666    3.486386    0.434914    0.055025    0.023365    0.765681    
#> 461: 0.488612    1.089677    3.486406    0.434743    0.054991    0.023365    0.765635    
#> 462: 0.488487    1.089746    3.486427    0.434764    0.054969    0.023366    0.765625    
#> 463: 0.488397    1.089838    3.486426    0.434929    0.054967    0.023358    0.765595    
#> 464: 0.488441    1.089853    3.486387    0.435070    0.054977    0.023356    0.765506    
#> 465: 0.488481    1.089739    3.486365    0.435180    0.054975    0.023355    0.765422    
#> 466: 0.488451    1.089755    3.486320    0.435424    0.054957    0.023344    0.765400    
#> 467: 0.488257    1.089732    3.486325    0.435622    0.054947    0.023344    0.765364    
#> 468: 0.488438    1.089782    3.486319    0.435755    0.054929    0.023332    0.765442    
#> 469: 0.488550    1.089858    3.486349    0.435689    0.054959    0.023332    0.765590    
#> 470: 0.488569    1.089920    3.486356    0.435622    0.054917    0.023339    0.765616    
#> 471: 0.488495    1.089937    3.486331    0.435633    0.054890    0.023342    0.765555    
#> 472: 0.488385    1.089948    3.486301    0.435598    0.054850    0.023354    0.765502    
#> 473: 0.488193    1.089986    3.486257    0.435477    0.054800    0.023354    0.765484    
#> 474: 0.488031    1.089971    3.486185    0.435458    0.054758    0.023372    0.765495    
#> 475: 0.487988    1.090070    3.486108    0.435387    0.054722    0.023362    0.765582    
#> 476: 0.487752    1.090123    3.486025    0.435128    0.054721    0.023344    0.765660    
#> 477: 0.487584    1.090140    3.485973    0.435194    0.054768    0.023341    0.765577    
#> 478: 0.487457    1.090145    3.485959    0.435041    0.054769    0.023341    0.765563    
#> 479: 0.487579    1.090157    3.485976    0.434875    0.054774    0.023343    0.765579    
#> 480: 0.487568    1.090162    3.485984    0.434782    0.054825    0.023340    0.765633    
#> 481: 0.487440    1.090162    3.485952    0.434728    0.054824    0.023331    0.765603    
#> 482: 0.487489    1.090142    3.485903    0.434749    0.054846    0.023328    0.765581    
#> 483: 0.487376    1.090119    3.485906    0.434569    0.054853    0.023329    0.765592    
#> 484: 0.487405    1.089999    3.485902    0.434754    0.054867    0.023326    0.765576    
#> 485: 0.487436    1.090025    3.485906    0.434810    0.054903    0.023335    0.765547    
#> 486: 0.487494    1.090057    3.485974    0.434602    0.054921    0.023331    0.765489    
#> 487: 0.487865    1.090086    3.486060    0.434589    0.054977    0.023319    0.765475    
#> 488: 0.488159    1.090063    3.486115    0.434707    0.054938    0.023319    0.765472    
#> 489: 0.488273    1.090017    3.486129    0.434454    0.054913    0.023323    0.765495    
#> 490: 0.488383    1.090093    3.486175    0.434344    0.054900    0.023322    0.765525    
#> 491: 0.488480    1.090157    3.486183    0.434464    0.054893    0.023313    0.765539    
#> 492: 0.488459    1.090276    3.486147    0.434687    0.054923    0.023327    0.765631    
#> 493: 0.488362    1.090316    3.486163    0.434727    0.054946    0.023340    0.765770    
#> 494: 0.488580    1.090411    3.486101    0.435014    0.054954    0.023351    0.765838    
#> 495: 0.488660    1.090464    3.486092    0.435212    0.054943    0.023374    0.765810    
#> 496: 0.488777    1.090553    3.486052    0.435436    0.054943    0.023388    0.765814    
#> 497: 0.488672    1.090580    3.486019    0.435598    0.054941    0.023392    0.765875    
#> 498: 0.488695    1.090554    3.485970    0.436038    0.054925    0.023392    0.765838    
#> 499: 0.488618    1.090601    3.485933    0.435938    0.054932    0.023385    0.765790    
#> 500: 0.488616    1.090620    3.485905    0.435800    0.054972    0.023362    0.765794    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.335640    0.970258    3.445926    0.392401    0.087669    0.016800    1.937268    
#> 002: 0.510692    1.011413    3.451730    0.372781    0.083285    0.017627    1.348317    
#> 003: 0.690004    0.985575    3.452453    0.354142    0.079121    0.016746    1.041739    
#> 004: 0.685232    0.983220    3.460416    0.336435    0.075165    0.015909    0.963023    
#> 005: 0.732507    0.985869    3.455512    0.319613    0.072575    0.015113    0.923194    
#> 006: 0.708596    1.002264    3.457979    0.303633    0.083394    0.014358    0.869932    
#> 007: 0.620204    0.999819    3.447419    0.288451    0.079225    0.013640    0.902029    
#> 008: 0.613044    0.991211    3.439441    0.298540    0.075889    0.014381    0.891385    
#> 009: 0.610425    0.982740    3.433385    0.311875    0.072621    0.013662    0.905236    
#> 010: 0.636218    0.964364    3.439449    0.323291    0.068990    0.016726    0.895754    
#> 011: 0.695137    0.975784    3.449143    0.359310    0.071598    0.015890    0.910993    
#> 012: 0.675696    1.004962    3.433842    0.351384    0.086878    0.015122    0.870553    
#> 013: 0.584647    1.001351    3.434364    0.333815    0.082534    0.015788    0.896214    
#> 014: 0.707833    1.007414    3.442449    0.336827    0.093636    0.017809    0.909637    
#> 015: 0.712202    0.974998    3.469251    0.341307    0.088954    0.016918    0.889883    
#> 016: 0.690129    1.004782    3.460986    0.339050    0.084507    0.024509    0.886731    
#> 017: 0.710234    1.003202    3.470713    0.322097    0.080281    0.023284    0.868883    
#> 018: 0.737085    1.001846    3.458746    0.331562    0.086325    0.025030    0.851411    
#> 019: 0.676346    0.991535    3.452345    0.335112    0.082009    0.023778    0.843010    
#> 020: 0.712889    0.988106    3.459398    0.318357    0.077909    0.022589    0.873083    
#> 021: 0.729487    0.969491    3.477582    0.318296    0.074013    0.021460    0.876047    
#> 022: 0.716449    0.975067    3.482518    0.344364    0.070313    0.020387    0.865870    
#> 023: 0.792782    0.985491    3.486232    0.373214    0.066797    0.020501    0.890000    
#> 024: 0.801822    1.001447    3.485360    0.354553    0.063457    0.021123    0.866243    
#> 025: 0.783405    0.967144    3.491622    0.348281    0.063653    0.020067    0.876062    
#> 026: 0.708982    1.005516    3.470088    0.330867    0.070031    0.019063    0.882510    
#> 027: 0.659469    1.004300    3.459127    0.314324    0.066529    0.021146    0.896428    
#> 028: 0.719118    0.994865    3.473503    0.306796    0.065457    0.020088    0.881529    
#> 029: 0.732650    0.991714    3.454405    0.365927    0.077849    0.019084    0.904441    
#> 030: 0.728391    1.011612    3.440627    0.409014    0.083724    0.018130    0.893012    
#> 031: 0.668944    0.985739    3.453504    0.388563    0.079538    0.018368    0.876686    
#> 032: 0.682002    0.990363    3.464171    0.369135    0.075561    0.018692    0.865240    
#> 033: 0.673903    1.008452    3.453037    0.439344    0.071783    0.020847    0.856143    
#> 034: 0.741642    1.014642    3.456963    0.508431    0.068194    0.019805    0.859244    
#> 035: 0.701337    0.995452    3.453530    0.483010    0.064784    0.018814    0.818916    
#> 036: 0.685485    1.006007    3.449801    0.458859    0.061545    0.017874    0.855446    
#> 037: 0.706145    1.016485    3.455696    0.435916    0.058468    0.017712    0.878067    
#> 038: 0.723866    0.996239    3.453003    0.414121    0.055544    0.021121    0.883027    
#> 039: 0.738358    0.983299    3.458540    0.469189    0.062336    0.020065    0.852291    
#> 040: 0.740024    0.985679    3.478956    0.445729    0.062753    0.019062    0.871691    
#> 041: 0.686160    0.988755    3.461220    0.423443    0.065193    0.018109    0.872635    
#> 042: 0.707070    0.992235    3.455803    0.448965    0.061933    0.017203    0.850095    
#> 043: 0.675638    1.025117    3.443950    0.449126    0.065042    0.016346    0.832107    
#> 044: 0.674770    1.028577    3.446417    0.426670    0.070042    0.018175    0.845650    
#> 045: 0.688401    1.037546    3.433044    0.405336    0.072434    0.020056    0.849088    
#> 046: 0.700557    1.009613    3.442915    0.447031    0.068812    0.019053    0.862174    
#> 047: 0.692313    1.000766    3.443993    0.424679    0.065372    0.018100    0.846472    
#> 048: 0.722676    0.996047    3.447722    0.403445    0.062103    0.017195    0.863515    
#> 049: 0.709130    0.988765    3.463246    0.383273    0.062411    0.019724    0.871812    
#> 050: 0.756267    0.960000    3.467909    0.398906    0.070206    0.019385    0.885650    
#> 051: 0.740435    0.991741    3.459253    0.427525    0.067004    0.018416    0.895904    
#> 052: 0.758655    0.998677    3.468120    0.406149    0.063995    0.017495    0.873869    
#> 053: 0.752470    0.994767    3.456564    0.392955    0.067132    0.016620    0.886867    
#> 054: 0.644982    0.999662    3.463383    0.373307    0.072172    0.015934    0.897125    
#> 055: 0.677585    0.979508    3.462830    0.354642    0.080142    0.017853    0.877189    
#> 056: 0.720117    0.975578    3.466270    0.336910    0.091322    0.022974    0.877522    
#> 057: 0.687001    0.978950    3.468356    0.320064    0.086756    0.021825    0.904696    
#> 058: 0.719431    0.993658    3.466752    0.357417    0.082958    0.020734    0.888090    
#> 059: 0.725113    0.956184    3.479033    0.412114    0.078810    0.019697    0.912295    
#> 060: 0.750564    0.930275    3.485509    0.417161    0.074870    0.021158    0.901550    
#> 061: 0.776491    0.977919    3.482399    0.519193    0.072175    0.022601    0.898311    
#> 062: 0.744801    0.982474    3.487663    0.493233    0.080561    0.024479    0.905996    
#> 063: 0.766962    0.950188    3.484387    0.480232    0.076533    0.027243    0.881663    
#> 064: 0.755621    0.988360    3.474338    0.456221    0.088252    0.025881    0.865721    
#> 065: 0.763010    0.986563    3.455397    0.433410    0.083839    0.024587    0.871604    
#> 066: 0.731575    1.004270    3.457591    0.411739    0.079647    0.026694    0.849348    
#> 067: 0.677761    1.010889    3.447192    0.391152    0.075665    0.028749    0.839236    
#> 068: 0.662998    1.022002    3.454476    0.371595    0.071881    0.027311    0.871094    
#> 069: 0.678867    1.026620    3.445564    0.440835    0.068287    0.026662    0.872652    
#> 070: 0.707168    1.011892    3.460985    0.418794    0.066714    0.030440    0.867786    
#> 071: 0.713920    1.022885    3.443760    0.397854    0.063378    0.028918    0.900170    
#> 072: 0.643846    1.004526    3.432351    0.377961    0.068258    0.027472    0.885102    
#> 073: 0.710983    0.995908    3.463779    0.411687    0.077343    0.026099    0.878018    
#> 074: 0.684377    1.005702    3.454345    0.391103    0.074685    0.024794    0.886036    
#> 075: 0.697321    0.997953    3.469434    0.371548    0.071512    0.023554    0.849666    
#> 076: 0.693818    1.003451    3.480544    0.384590    0.067936    0.022376    0.873381    
#> 077: 0.781276    0.980456    3.484165    0.365361    0.064539    0.021258    0.900833    
#> 078: 0.792826    0.981291    3.494606    0.347093    0.063703    0.020727    0.890237    
#> 079: 0.776734    0.993758    3.488904    0.372812    0.070361    0.023036    0.892198    
#> 080: 0.777058    0.964048    3.493543    0.354171    0.075849    0.024073    0.890358    
#> 081: 0.739728    0.979263    3.473428    0.336463    0.072056    0.025236    0.862008    
#> 082: 0.715221    0.983316    3.483780    0.342913    0.068453    0.023974    0.890526    
#> 083: 0.716027    1.001178    3.478927    0.325768    0.065031    0.023248    0.888195    
#> 084: 0.728189    1.007170    3.454736    0.357246    0.065336    0.022085    0.869669    
#> 085: 0.666226    1.020914    3.456685    0.339384    0.065295    0.020981    0.862650    
#> 086: 0.695185    1.007222    3.462316    0.354922    0.062030    0.019932    0.867302    
#> 087: 0.697569    0.988117    3.453149    0.337176    0.058929    0.019983    0.883332    
#> 088: 0.660358    0.988125    3.456828    0.456073    0.055982    0.018984    0.888507    
#> 089: 0.671510    1.018096    3.439332    0.439567    0.053183    0.018471    0.852237    
#> 090: 0.641667    1.013488    3.437320    0.417589    0.050524    0.019203    0.878127    
#> 091: 0.623747    0.994306    3.420029    0.396709    0.051414    0.020476    0.872254    
#> 092: 0.622359    1.026281    3.422779    0.422381    0.051645    0.022399    0.871664    
#> 093: 0.591962    1.015853    3.425799    0.401262    0.055723    0.021279    0.885201    
#> 094: 0.645634    1.019307    3.434768    0.381199    0.053021    0.020215    0.892776    
#> 095: 0.679521    1.018225    3.455696    0.407902    0.051766    0.019966    0.896335    
#> 096: 0.662579    1.029084    3.454207    0.387507    0.049177    0.018968    0.865355    
#> 097: 0.707274    1.032169    3.458882    0.368131    0.059782    0.018019    0.864801    
#> 098: 0.699675    1.047415    3.465560    0.354009    0.056793    0.017118    0.916195    
#> 099: 0.651229    1.007343    3.433574    0.336308    0.053954    0.016262    0.882465    
#> 100: 0.650436    1.024448    3.441369    0.319493    0.051256    0.017096    0.862575    
#> 101: 0.655555    1.017025    3.428287    0.325673    0.054710    0.016242    0.864061    
#> 102: 0.658412    1.011853    3.423835    0.325979    0.056869    0.018964    0.874807    
#> 103: 0.708140    1.012416    3.453635    0.315322    0.054290    0.018015    0.860803    
#> 104: 0.729270    0.992723    3.475030    0.402033    0.051575    0.018168    0.895473    
#> 105: 0.790371    0.977381    3.469872    0.505996    0.058152    0.017260    0.897546    
#> 106: 0.795936    0.989080    3.470405    0.517599    0.063875    0.016397    0.872613    
#> 107: 0.772673    0.971758    3.470552    0.518004    0.062183    0.016874    0.868477    
#> 108: 0.717011    0.984921    3.472293    0.492104    0.072784    0.017098    0.868765    
#> 109: 0.691948    1.002938    3.472794    0.467499    0.069144    0.016797    0.869531    
#> 110: 0.697186    0.994252    3.450211    0.444124    0.081503    0.015957    0.870417    
#> 111: 0.690758    1.005430    3.454154    0.421917    0.079199    0.015159    0.848848    
#> 112: 0.724229    0.965681    3.459457    0.400822    0.097641    0.014401    0.860290    
#> 113: 0.713083    1.007972    3.454249    0.380781    0.092759    0.013681    0.861674    
#> 114: 0.704042    1.025218    3.453102    0.361741    0.089421    0.015604    0.872448    
#> 115: 0.723719    0.976324    3.451401    0.434025    0.102182    0.015403    0.869470    
#> 116: 0.726373    0.994365    3.457351    0.488185    0.097073    0.016014    0.875640    
#> 117: 0.670122    1.026092    3.455876    0.463776    0.092219    0.017272    0.893570    
#> 118: 0.681763    1.021268    3.453495    0.440587    0.087608    0.019884    0.876278    
#> 119: 0.705591    1.015659    3.464690    0.418558    0.083228    0.029581    0.872319    
#> 120: 0.666911    1.010856    3.446258    0.397630    0.079066    0.028102    0.858365    
#> 121: 0.718527    1.039074    3.458199    0.377749    0.075113    0.026697    0.869615    
#> 122: 0.737764    1.010279    3.474955    0.378081    0.071357    0.025362    0.857096    
#> 123: 0.769745    1.007275    3.475137    0.403671    0.067790    0.024094    0.868995    
#> 124: 0.770558    1.032400    3.471499    0.420014    0.064400    0.026764    0.866458    
#> 125: 0.760572    1.025044    3.465512    0.399014    0.061180    0.025426    0.869582    
#> 126: 0.718347    1.006438    3.452286    0.394406    0.058121    0.024155    0.873588    
#> 127: 0.785091    0.976083    3.464346    0.501666    0.055215    0.022947    0.899608    
#> 128: 0.753561    0.961207    3.492611    0.504938    0.052454    0.022212    0.895096    
#> 129: 0.768718    0.989944    3.478945    0.505634    0.072664    0.021102    0.876564    
#> 130: 0.789619    1.029043    3.462416    0.604825    0.069031    0.023397    0.865634    
#> 131: 0.711263    1.009254    3.448473    0.574584    0.065580    0.023787    0.870347    
#> 132: 0.672818    1.014449    3.434746    0.545855    0.066922    0.022598    0.890307    
#> 133: 0.693277    0.995815    3.463949    0.518562    0.079759    0.021468    0.886069    
#> 134: 0.717530    0.975545    3.474384    0.492634    0.075771    0.023581    0.884086    
#> 135: 0.691658    0.971991    3.472353    0.468002    0.083182    0.022402    0.864754    
#> 136: 0.712000    0.974806    3.468403    0.444602    0.079022    0.021282    0.849085    
#> 137: 0.721410    0.989293    3.457563    0.465699    0.075071    0.020217    0.841117    
#> 138: 0.721554    0.991491    3.454667    0.526470    0.071318    0.019207    0.854542    
#> 139: 0.731000    0.995260    3.468210    0.532203    0.067752    0.022580    0.860514    
#> 140: 0.810632    0.998159    3.474809    0.585997    0.064931    0.024373    0.853652    
#> 141: 0.744410    0.967056    3.478435    0.556697    0.066917    0.023155    0.844509    
#> 142: 0.737926    0.942075    3.498363    0.528862    0.067448    0.021997    0.859390    
#> 143: 0.728832    0.979226    3.472389    0.502419    0.079305    0.020897    0.852757    
#> 144: 0.823531    0.982250    3.486908    0.477298    0.075340    0.019852    0.845260    
#> 145: 0.737845    0.994557    3.464185    0.453433    0.078582    0.018860    0.844706    
#> 146: 0.688406    0.986824    3.487118    0.430762    0.074653    0.023337    0.867390    
#> 147: 0.701919    0.966582    3.477155    0.409224    0.070920    0.027344    0.847856    
#> 148: 0.719929    0.994213    3.479561    0.388762    0.067374    0.030328    0.865002    
#> 149: 0.717269    0.981430    3.484463    0.369324    0.065411    0.028812    0.861070    
#> 150: 0.755768    0.978289    3.463740    0.402975    0.075489    0.027371    0.858989    
#> 151: 0.693733    1.009624    3.464958    0.382826    0.078543    0.026003    0.864470    
#> 152: 0.765172    0.993096    3.466169    0.443240    0.081491    0.021804    0.857756    
#> 153: 0.742245    1.011821    3.475379    0.432893    0.086525    0.020670    0.873007    
#> 154: 0.776485    0.997257    3.478751    0.487731    0.073147    0.022759    0.866943    
#> 155: 0.731553    0.986897    3.472341    0.412395    0.084010    0.021007    0.851971    
#> 156: 0.720763    0.984499    3.476718    0.361758    0.085806    0.021194    0.867660    
#> 157: 0.757483    0.962703    3.484660    0.369436    0.091269    0.023819    0.882079    
#> 158: 0.738727    0.994858    3.470203    0.358367    0.088838    0.019295    0.832747    
#> 159: 0.696688    1.018008    3.464582    0.363772    0.070993    0.017415    0.873448    
#> 160: 0.750272    0.979986    3.471633    0.469173    0.091229    0.015653    0.863960    
#> 161: 0.690661    1.006892    3.452085    0.409418    0.083820    0.015822    0.865460    
#> 162: 0.673758    1.025793    3.427212    0.459518    0.081492    0.013469    0.854549    
#> 163: 0.704099    1.021773    3.426757    0.511514    0.092435    0.013024    0.864614    
#> 164: 0.679351    1.053670    3.421004    0.455691    0.086089    0.012509    0.876223    
#> 165: 0.705113    1.009663    3.447467    0.486705    0.100105    0.012280    0.895026    
#> 166: 0.696917    1.049335    3.441330    0.435024    0.105318    0.007236    0.882495    
#> 167: 0.705564    1.045944    3.446119    0.432019    0.098231    0.007888    0.899704    
#> 168: 0.702323    1.052024    3.438331    0.424595    0.085855    0.009660    0.892824    
#> 169: 0.667849    1.080346    3.427956    0.362778    0.088111    0.009010    0.904257    
#> 170: 0.671105    1.047431    3.435181    0.365963    0.091807    0.007816    0.878672    
#> 171: 0.673090    1.036678    3.439208    0.360082    0.113609    0.006534    0.857435    
#> 172: 0.663965    1.047141    3.435758    0.327252    0.077364    0.007837    0.855175    
#> 173: 0.641087    1.054323    3.423757    0.300794    0.074751    0.009567    0.863765    
#> 174: 0.668768    1.034253    3.430871    0.409457    0.077338    0.010668    0.859700    
#> 175: 0.680094    1.049241    3.415971    0.392036    0.089524    0.014380    0.868376    
#> 176: 0.664281    1.061879    3.429053    0.472742    0.090977    0.014429    0.853655    
#> 177: 0.687722    1.026146    3.445547    0.389621    0.086755    0.011146    0.860046    
#> 178: 0.705219    1.038999    3.437172    0.399604    0.085970    0.011264    0.861195    
#> 179: 0.677369    1.033058    3.441003    0.375827    0.074015    0.012175    0.879010    
#> 180: 0.689507    1.012297    3.452090    0.376672    0.065470    0.015872    0.850619    
#> 181: 0.676765    0.998232    3.426448    0.361998    0.055852    0.013561    0.880509    
#> 182: 0.608986    1.011672    3.424704    0.302304    0.076875    0.011761    0.913261    
#> 183: 0.654932    1.039121    3.430094    0.404755    0.063630    0.008923    0.899630    
#> 184: 0.641341    1.023880    3.428836    0.369384    0.057650    0.010421    0.891619    
#> 185: 0.632415    1.038483    3.429891    0.339736    0.073740    0.011818    0.888884    
#> 186: 0.626653    1.035723    3.441906    0.360128    0.073328    0.013838    0.884062    
#> 187: 0.674781    0.988400    3.456946    0.383154    0.058354    0.018273    0.869804    
#> 188: 0.687065    1.018842    3.456334    0.384175    0.063091    0.021747    0.874684    
#> 189: 0.689805    1.033735    3.457030    0.391012    0.056380    0.021644    0.882739    
#> 190: 0.694565    1.017054    3.462100    0.434015    0.051712    0.016078    0.877727    
#> 191: 0.661132    1.030722    3.451068    0.328613    0.048532    0.016319    0.869210    
#> 192: 0.629493    1.033285    3.440387    0.298410    0.060664    0.018318    0.877904    
#> 193: 0.705600    1.035395    3.457205    0.357235    0.063577    0.014573    0.857100    
#> 194: 0.721281    1.015715    3.441639    0.447734    0.067259    0.014126    0.877894    
#> 195: 0.658211    1.033963    3.437888    0.440024    0.045167    0.016478    0.875985    
#> 196: 0.664537    1.018795    3.449394    0.348674    0.055260    0.016178    0.904094    
#> 197: 0.668151    1.040158    3.469281    0.339512    0.058836    0.016662    0.884413    
#> 198: 0.696054    1.005189    3.458057    0.331259    0.069761    0.023147    0.863225    
#> 199: 0.710768    1.013370    3.452924    0.410594    0.079491    0.019157    0.843605    
#> 200: 0.700042    1.008869    3.455193    0.414883    0.076126    0.023509    0.856587    
#> 201: 0.703037    1.001507    3.459055    0.440295    0.078068    0.022701    0.859531    
#> 202: 0.693657    1.006065    3.460558    0.413255    0.072625    0.023023    0.866032    
#> 203: 0.706335    1.007457    3.457880    0.395438    0.069028    0.024158    0.870202    
#> 204: 0.711416    0.997144    3.459654    0.408372    0.065797    0.024166    0.873926    
#> 205: 0.708222    1.000280    3.459250    0.406794    0.064129    0.024619    0.876221    
#> 206: 0.707060    1.004988    3.460058    0.408917    0.063377    0.024274    0.878374    
#> 207: 0.705577    1.005644    3.457866    0.414698    0.063324    0.023754    0.876871    
#> 208: 0.706074    1.007625    3.457817    0.423716    0.063265    0.023669    0.873705    
#> 209: 0.710219    1.005901    3.457379    0.427367    0.062232    0.023511    0.873121    
#> 210: 0.709974    1.004541    3.457247    0.426295    0.061691    0.023290    0.873739    
#> 211: 0.709834    1.004997    3.458105    0.421005    0.060759    0.022940    0.874197    
#> 212: 0.711545    1.005068    3.458478    0.419705    0.060204    0.022897    0.874769    
#> 213: 0.713936    1.000844    3.459403    0.423054    0.061073    0.023113    0.875634    
#> 214: 0.718576    0.998951    3.460605    0.423008    0.061674    0.023567    0.876293    
#> 215: 0.722106    0.999572    3.462213    0.424207    0.062011    0.023872    0.876481    
#> 216: 0.725740    0.997718    3.463027    0.421943    0.061467    0.023708    0.878262    
#> 217: 0.726375    0.998629    3.462903    0.419499    0.060950    0.023448    0.879182    
#> 218: 0.728086    0.999330    3.462402    0.417787    0.060676    0.023270    0.879204    
#> 219: 0.726933    0.998589    3.461535    0.417905    0.060696    0.023428    0.879583    
#> 220: 0.726705    0.998329    3.461639    0.421100    0.060677    0.023507    0.878860    
#> 221: 0.727333    0.997834    3.461627    0.419997    0.060381    0.023309    0.877724    
#> 222: 0.729997    0.997064    3.462343    0.419544    0.060000    0.023238    0.877761    
#> 223: 0.731902    0.997009    3.462897    0.417944    0.059687    0.023168    0.877498    
#> 224: 0.734851    0.997641    3.463803    0.416988    0.059679    0.023089    0.876672    
#> 225: 0.734139    0.996453    3.464470    0.413146    0.059817    0.023139    0.876250    
#> 226: 0.733419    0.994891    3.464279    0.411027    0.059801    0.023021    0.875968    
#> 227: 0.731743    0.994770    3.464356    0.407206    0.059581    0.023131    0.875916    
#> 228: 0.730438    0.995895    3.463841    0.405334    0.059712    0.023158    0.875693    
#> 229: 0.727972    0.995595    3.463434    0.405015    0.059726    0.022995    0.875674    
#> 230: 0.728502    0.994589    3.463291    0.405391    0.059715    0.022789    0.876002    
#> 231: 0.729318    0.994670    3.463653    0.405571    0.060251    0.022675    0.876076    
#> 232: 0.728381    0.994280    3.464295    0.402487    0.060779    0.022541    0.876362    
#> 233: 0.728226    0.993568    3.464446    0.402055    0.061178    0.022443    0.875778    
#> 234: 0.727405    0.993476    3.464493    0.402216    0.061765    0.022293    0.875360    
#> 235: 0.727042    0.993268    3.464138    0.401336    0.062017    0.022015    0.875582    
#> 236: 0.725396    0.994281    3.463378    0.399742    0.062419    0.021857    0.876148    
#> 237: 0.724946    0.995433    3.462950    0.400270    0.062648    0.021807    0.875953    
#> 238: 0.725780    0.996149    3.463017    0.400487    0.063105    0.021682    0.875892    
#> 239: 0.725696    0.996924    3.462783    0.399460    0.063104    0.021569    0.876131    
#> 240: 0.725381    0.997003    3.462972    0.396465    0.063224    0.021476    0.875678    
#> 241: 0.725330    0.996145    3.463355    0.394775    0.062920    0.021514    0.876109    
#> 242: 0.724791    0.995237    3.463225    0.395037    0.062831    0.021537    0.876997    
#> 243: 0.723089    0.995769    3.462980    0.394439    0.062478    0.021640    0.877436    
#> 244: 0.722065    0.995984    3.463027    0.393524    0.062239    0.021746    0.877588    
#> 245: 0.722154    0.995726    3.462986    0.393091    0.061851    0.021860    0.877768    
#> 246: 0.721992    0.995760    3.463034    0.392374    0.061368    0.022034    0.877934    
#> 247: 0.721929    0.995629    3.463265    0.390652    0.061126    0.022156    0.878485    
#> 248: 0.721757    0.996037    3.463339    0.390730    0.061147    0.022216    0.878101    
#> 249: 0.721127    0.996675    3.463309    0.390698    0.061330    0.022267    0.877892    
#> 250: 0.721388    0.996939    3.463277    0.391202    0.061030    0.022320    0.878066    
#> 251: 0.721388    0.997690    3.463434    0.391942    0.061113    0.022206    0.878625    
#> 252: 0.721276    0.997832    3.463643    0.391981    0.061297    0.022127    0.878439    
#> 253: 0.721468    0.997975    3.463494    0.393630    0.061553    0.022117    0.878562    
#> 254: 0.721332    0.998519    3.463521    0.394240    0.061606    0.022090    0.878445    
#> 255: 0.720832    0.998859    3.463512    0.394534    0.061667    0.022086    0.878210    
#> 256: 0.720957    0.998669    3.463426    0.394546    0.061618    0.022082    0.878104    
#> 257: 0.720370    0.998212    3.463354    0.392777    0.061417    0.022002    0.878323    
#> 258: 0.720172    0.997577    3.463272    0.392869    0.061292    0.021914    0.878012    
#> 259: 0.719845    0.997543    3.463271    0.392152    0.061482    0.021854    0.877693    
#> 260: 0.719435    0.997745    3.463304    0.392209    0.061420    0.021846    0.877311    
#> 261: 0.719508    0.997524    3.463434    0.392500    0.061227    0.021873    0.877243    
#> 262: 0.719329    0.997798    3.463447    0.391077    0.061150    0.021919    0.877127    
#> 263: 0.718633    0.998142    3.463368    0.390467    0.061104    0.022037    0.877090    
#> 264: 0.717441    0.998617    3.462997    0.389732    0.060956    0.021961    0.877669    
#> 265: 0.716968    0.999210    3.462745    0.388739    0.061097    0.021981    0.878087    
#> 266: 0.716722    0.999567    3.462613    0.388768    0.061067    0.021953    0.878035    
#> 267: 0.716845    0.999482    3.462715    0.389078    0.060997    0.021912    0.877858    
#> 268: 0.717311    0.999407    3.462600    0.389467    0.060990    0.021874    0.877560    
#> 269: 0.717593    0.999374    3.462579    0.388140    0.061141    0.021799    0.877638    
#> 270: 0.718056    0.999640    3.462481    0.387252    0.061258    0.021681    0.877508    
#> 271: 0.718601    0.999665    3.462382    0.386976    0.061356    0.021618    0.877418    
#> 272: 0.718444    0.999496    3.462189    0.387507    0.061365    0.021545    0.877571    
#> 273: 0.718198    0.999825    3.462212    0.387093    0.061526    0.021495    0.877894    
#> 274: 0.717016    1.000240    3.462105    0.386288    0.061718    0.021408    0.877728    
#> 275: 0.716695    1.000449    3.461923    0.385479    0.061671    0.021341    0.877533    
#> 276: 0.716712    1.000445    3.462017    0.384857    0.061583    0.021357    0.877531    
#> 277: 0.716083    1.000513    3.462027    0.383650    0.061665    0.021298    0.877491    
#> 278: 0.715920    1.000508    3.462067    0.383122    0.061674    0.021208    0.877641    
#> 279: 0.715857    1.000226    3.462125    0.383620    0.061873    0.021242    0.877750    
#> 280: 0.715971    1.000306    3.462187    0.383846    0.062013    0.021207    0.877667    
#> 281: 0.715118    1.000456    3.462188    0.383704    0.061967    0.021167    0.877931    
#> 282: 0.714769    1.000452    3.462135    0.384483    0.062066    0.021077    0.878167    
#> 283: 0.714359    1.000507    3.461969    0.385420    0.062147    0.021027    0.878470    
#> 284: 0.713818    1.000280    3.461844    0.386052    0.062127    0.020952    0.878490    
#> 285: 0.713248    1.000475    3.461575    0.385635    0.062355    0.020878    0.878668    
#> 286: 0.713205    1.000744    3.461339    0.386357    0.062278    0.020826    0.878814    
#> 287: 0.712828    1.000727    3.461215    0.386312    0.062448    0.020811    0.878795    
#> 288: 0.712833    1.000754    3.461174    0.386450    0.062424    0.020760    0.878841    
#> 289: 0.713023    1.000508    3.461197    0.386416    0.062411    0.020735    0.878713    
#> 290: 0.713161    1.000521    3.461268    0.385676    0.062506    0.020698    0.878678    
#> 291: 0.713245    1.000948    3.461306    0.385197    0.062609    0.020680    0.878279    
#> 292: 0.713016    1.001221    3.461248    0.385397    0.062612    0.020680    0.878184    
#> 293: 0.712669    1.001262    3.461096    0.385075    0.062577    0.020673    0.877968    
#> 294: 0.712552    1.001402    3.460931    0.385273    0.062497    0.020638    0.877841    
#> 295: 0.712356    1.001144    3.460852    0.384667    0.062642    0.020563    0.877753    
#> 296: 0.712308    1.001015    3.460742    0.384204    0.062693    0.020509    0.877908    
#> 297: 0.712206    1.001097    3.460687    0.384522    0.062760    0.020483    0.877806    
#> 298: 0.712198    1.000897    3.460719    0.384712    0.062793    0.020427    0.877696    
#> 299: 0.712060    1.001066    3.460653    0.384685    0.062820    0.020402    0.877453    
#> 300: 0.712541    1.001091    3.460830    0.384877    0.062829    0.020418    0.877107    
#> 301: 0.713237    1.000976    3.460813    0.384621    0.062902    0.020398    0.876958    
#> 302: 0.713365    1.001053    3.460769    0.384140    0.062852    0.020367    0.876747    
#> 303: 0.713052    1.001217    3.460759    0.384197    0.062924    0.020361    0.876503    
#> 304: 0.712854    1.001570    3.460628    0.384247    0.063063    0.020323    0.876547    
#> 305: 0.712883    1.001502    3.460611    0.384419    0.063081    0.020311    0.876485    
#> 306: 0.712655    1.001258    3.460446    0.384548    0.063070    0.020341    0.876438    
#> 307: 0.712779    1.001220    3.460418    0.384657    0.063147    0.020358    0.876627    
#> 308: 0.712549    1.001155    3.460362    0.385271    0.063262    0.020361    0.876907    
#> 309: 0.712751    1.000978    3.460339    0.385864    0.063159    0.020374    0.877283    
#> 310: 0.713064    1.000891    3.460199    0.386228    0.063017    0.020357    0.877604    
#> 311: 0.712766    1.001134    3.460026    0.386390    0.062986    0.020312    0.877499    
#> 312: 0.712639    1.001098    3.459975    0.386787    0.062899    0.020302    0.877483    
#> 313: 0.712324    1.000890    3.459880    0.386843    0.062770    0.020329    0.877609    
#> 314: 0.711753    1.000907    3.459779    0.386652    0.062706    0.020354    0.877683    
#> 315: 0.711046    1.001104    3.459701    0.386457    0.062677    0.020324    0.877450    
#> 316: 0.711135    1.001229    3.459595    0.387182    0.062732    0.020293    0.877209    
#> 317: 0.711249    1.001101    3.459730    0.387110    0.062748    0.020321    0.877232    
#> 318: 0.711269    1.001028    3.459702    0.387028    0.062731    0.020295    0.877202    
#> 319: 0.711245    1.000873    3.459728    0.386561    0.062715    0.020265    0.877231    
#> 320: 0.710698    1.000837    3.459632    0.385799    0.062738    0.020233    0.877232    
#> 321: 0.710186    1.001000    3.459539    0.385171    0.062759    0.020198    0.877526    
#> 322: 0.710101    1.001138    3.459291    0.385353    0.062831    0.020155    0.877457    
#> 323: 0.709617    1.001196    3.459157    0.385574    0.062731    0.020103    0.877525    
#> 324: 0.709633    1.001538    3.459031    0.386542    0.062800    0.020088    0.877307    
#> 325: 0.709578    1.001854    3.458854    0.386792    0.062832    0.020061    0.877173    
#> 326: 0.709532    1.001588    3.458808    0.386916    0.062891    0.020051    0.877388    
#> 327: 0.709609    1.001694    3.458855    0.386868    0.063038    0.020025    0.877433    
#> 328: 0.710032    1.001937    3.458877    0.387261    0.063077    0.019993    0.877393    
#> 329: 0.710313    1.002118    3.458890    0.386881    0.063174    0.019959    0.877374    
#> 330: 0.710198    1.002081    3.458891    0.386715    0.063116    0.019925    0.877320    
#> 331: 0.710487    1.002128    3.458924    0.386938    0.063079    0.019889    0.877192    
#> 332: 0.710669    1.002201    3.458953    0.386867    0.063134    0.019818    0.877299    
#> 333: 0.710340    1.002293    3.458811    0.387177    0.063171    0.019747    0.877339    
#> 334: 0.710045    1.002361    3.458645    0.387304    0.063166    0.019703    0.877390    
#> 335: 0.709694    1.002535    3.458475    0.387441    0.063239    0.019680    0.877386    
#> 336: 0.709356    1.002775    3.458336    0.387844    0.063305    0.019663    0.877347    
#> 337: 0.708948    1.003264    3.458218    0.388558    0.063404    0.019633    0.877411    
#> 338: 0.708710    1.003490    3.458160    0.388809    0.063547    0.019598    0.877398    
#> 339: 0.708543    1.003644    3.458030    0.388641    0.063581    0.019577    0.877290    
#> 340: 0.708536    1.003742    3.457996    0.389176    0.063646    0.019557    0.877328    
#> 341: 0.708580    1.003858    3.457998    0.389125    0.063781    0.019553    0.877365    
#> 342: 0.708207    1.003871    3.457882    0.389086    0.063834    0.019511    0.877360    
#> 343: 0.707713    1.004091    3.457794    0.388928    0.063821    0.019461    0.877325    
#> 344: 0.707760    1.004150    3.457741    0.389210    0.063852    0.019442    0.877385    
#> 345: 0.707840    1.004180    3.457706    0.388903    0.063891    0.019425    0.877329    
#> 346: 0.707742    1.004399    3.457597    0.388966    0.063878    0.019393    0.877279    
#> 347: 0.707733    1.004318    3.457496    0.389106    0.063833    0.019410    0.877284    
#> 348: 0.707571    1.004366    3.457380    0.389468    0.063841    0.019415    0.877383    
#> 349: 0.707386    1.004480    3.457263    0.389887    0.063793    0.019426    0.877461    
#> 350: 0.706747    1.004614    3.457042    0.389949    0.063886    0.019384    0.877439    
#> 351: 0.706396    1.004984    3.456797    0.390103    0.063938    0.019368    0.877485    
#> 352: 0.705929    1.005188    3.456676    0.390699    0.064028    0.019376    0.877532    
#> 353: 0.705629    1.005435    3.456507    0.390600    0.064085    0.019389    0.877639    
#> 354: 0.705363    1.005611    3.456288    0.390138    0.064064    0.019409    0.877593    
#> 355: 0.705656    1.005546    3.456277    0.390388    0.064110    0.019398    0.877457    
#> 356: 0.705546    1.005552    3.456317    0.390441    0.064232    0.019366    0.877508    
#> 357: 0.705502    1.005621    3.456307    0.390150    0.064228    0.019322    0.877558    
#> 358: 0.705459    1.005749    3.456306    0.389835    0.064271    0.019296    0.877489    
#> 359: 0.705191    1.005979    3.456229    0.390155    0.064301    0.019290    0.877285    
#> 360: 0.704814    1.006063    3.456077    0.389805    0.064279    0.019293    0.877114    
#> 361: 0.704567    1.006206    3.455947    0.389680    0.064232    0.019299    0.876985    
#> 362: 0.704581    1.006258    3.455907    0.389164    0.064161    0.019315    0.876832    
#> 363: 0.704810    1.006177    3.455925    0.388962    0.064132    0.019313    0.876618    
#> 364: 0.704983    1.006156    3.456005    0.388980    0.064117    0.019322    0.876532    
#> 365: 0.705137    1.006043    3.456115    0.389275    0.064135    0.019341    0.876573    
#> 366: 0.705108    1.005937    3.456091    0.389160    0.064180    0.019328    0.876563    
#> 367: 0.705061    1.005848    3.456063    0.388935    0.064172    0.019309    0.876558    
#> 368: 0.705433    1.005825    3.456064    0.389488    0.064087    0.019287    0.876417    
#> 369: 0.705419    1.005630    3.456121    0.389940    0.064010    0.019270    0.876472    
#> 370: 0.705414    1.005573    3.456191    0.389491    0.063981    0.019289    0.876527    
#> 371: 0.705170    1.005594    3.456124    0.389170    0.063989    0.019270    0.876566    
#> 372: 0.704979    1.005753    3.456037    0.389067    0.064069    0.019249    0.876584    
#> 373: 0.704798    1.005957    3.455904    0.389222    0.064113    0.019225    0.876640    
#> 374: 0.704796    1.005896    3.455891    0.388946    0.064123    0.019196    0.876628    
#> 375: 0.704413    1.005878    3.455847    0.388947    0.064063    0.019183    0.876692    
#> 376: 0.704066    1.005918    3.455774    0.388593    0.064030    0.019168    0.876681    
#> 377: 0.703692    1.006021    3.455687    0.388435    0.064054    0.019159    0.876579    
#> 378: 0.703074    1.005965    3.455551    0.388046    0.063995    0.019162    0.876662    
#> 379: 0.702784    1.005847    3.455511    0.388074    0.063921    0.019146    0.876649    
#> 380: 0.702600    1.005800    3.455443    0.388175    0.063935    0.019149    0.876575    
#> 381: 0.702537    1.005711    3.455441    0.388029    0.063848    0.019161    0.876440    
#> 382: 0.702668    1.005720    3.455525    0.388395    0.063825    0.019158    0.876332    
#> 383: 0.703172    1.005613    3.455601    0.388808    0.063758    0.019196    0.876177    
#> 384: 0.703156    1.005581    3.455649    0.388520    0.063778    0.019225    0.876068    
#> 385: 0.703536    1.005480    3.455676    0.388649    0.063804    0.019218    0.876033    
#> 386: 0.703944    1.005517    3.455801    0.389033    0.063831    0.019216    0.876037    
#> 387: 0.704465    1.005432    3.455970    0.388919    0.063778    0.019219    0.876116    
#> 388: 0.704595    1.005336    3.456081    0.388762    0.063685    0.019206    0.876095    
#> 389: 0.704658    1.005164    3.456137    0.388318    0.063646    0.019197    0.876171    
#> 390: 0.704376    1.005162    3.456094    0.388094    0.063602    0.019181    0.876216    
#> 391: 0.704447    1.005080    3.456069    0.387826    0.063563    0.019166    0.876146    
#> 392: 0.704681    1.005058    3.456147    0.388062    0.063559    0.019148    0.876207    
#> 393: 0.704784    1.005057    3.456116    0.388387    0.063602    0.019122    0.876177    
#> 394: 0.705029    1.005069    3.456065    0.389190    0.063644    0.019104    0.876116    
#> 395: 0.705700    1.005213    3.456060    0.390488    0.063630    0.019095    0.876109    
#> 396: 0.706201    1.005245    3.456047    0.391760    0.063650    0.019083    0.875992    
#> 397: 0.706277    1.005164    3.456067    0.391902    0.063637    0.019083    0.875869    
#> 398: 0.706405    1.005020    3.456122    0.391785    0.063642    0.019069    0.875974    
#> 399: 0.706296    1.004946    3.456194    0.391738    0.063630    0.019070    0.876040    
#> 400: 0.706222    1.004973    3.456235    0.391865    0.063646    0.019064    0.876128    
#> 401: 0.706195    1.004982    3.456275    0.391737    0.063656    0.019067    0.876155    
#> 402: 0.706107    1.005089    3.456306    0.391404    0.063643    0.019070    0.876204    
#> 403: 0.706247    1.005118    3.456331    0.390952    0.063700    0.019063    0.876183    
#> 404: 0.706383    1.005147    3.456301    0.390539    0.063703    0.019088    0.876204    
#> 405: 0.706297    1.005131    3.456321    0.390108    0.063690    0.019095    0.876249    
#> 406: 0.706434    1.005160    3.456341    0.389798    0.063689    0.019123    0.876299    
#> 407: 0.706480    1.005206    3.456358    0.389808    0.063745    0.019147    0.876256    
#> 408: 0.706542    1.005314    3.456407    0.389518    0.063857    0.019148    0.876275    
#> 409: 0.706618    1.005304    3.456378    0.389673    0.063835    0.019152    0.876232    
#> 410: 0.706575    1.005391    3.456275    0.389725    0.063833    0.019170    0.876217    
#> 411: 0.706742    1.005289    3.456236    0.389741    0.063749    0.019165    0.876328    
#> 412: 0.706798    1.005358    3.456180    0.389610    0.063746    0.019189    0.876347    
#> 413: 0.706820    1.005335    3.456115    0.389643    0.063706    0.019202    0.876423    
#> 414: 0.706783    1.005305    3.456122    0.389640    0.063705    0.019193    0.876372    
#> 415: 0.706948    1.005239    3.456135    0.389856    0.063691    0.019182    0.876268    
#> 416: 0.707192    1.005283    3.456149    0.390431    0.063711    0.019168    0.876183    
#> 417: 0.707396    1.005294    3.456165    0.390803    0.063688    0.019155    0.876127    
#> 418: 0.707254    1.005262    3.456171    0.390625    0.063650    0.019143    0.876072    
#> 419: 0.707244    1.005315    3.456179    0.390830    0.063597    0.019121    0.876159    
#> 420: 0.707238    1.005271    3.456198    0.390799    0.063551    0.019105    0.876090    
#> 421: 0.707140    1.005233    3.456233    0.390510    0.063513    0.019088    0.876038    
#> 422: 0.707340    1.005168    3.456228    0.390685    0.063483    0.019086    0.876004    
#> 423: 0.707344    1.005180    3.456238    0.390360    0.063496    0.019108    0.875951    
#> 424: 0.707268    1.005173    3.456167    0.390372    0.063464    0.019108    0.875882    
#> 425: 0.707423    1.005254    3.456148    0.390362    0.063403    0.019104    0.875971    
#> 426: 0.707382    1.005417    3.456097    0.390518    0.063383    0.019095    0.875872    
#> 427: 0.707174    1.005477    3.456096    0.390555    0.063406    0.019107    0.875818    
#> 428: 0.707096    1.005478    3.456083    0.390156    0.063462    0.019120    0.875754    
#> 429: 0.707060    1.005470    3.456106    0.389707    0.063431    0.019138    0.875687    
#> 430: 0.707010    1.005499    3.456061    0.389710    0.063416    0.019146    0.875626    
#> 431: 0.706966    1.005523    3.456005    0.389947    0.063380    0.019129    0.875592    
#> 432: 0.706741    1.005650    3.455936    0.390160    0.063332    0.019119    0.875483    
#> 433: 0.706597    1.005839    3.455906    0.390251    0.063300    0.019114    0.875510    
#> 434: 0.706273    1.005797    3.455890    0.390306    0.063283    0.019100    0.875495    
#> 435: 0.706311    1.005776    3.455889    0.390279    0.063236    0.019110    0.875391    
#> 436: 0.706258    1.005659    3.455939    0.390380    0.063112    0.019112    0.875495    
#> 437: 0.706101    1.005626    3.455915    0.390401    0.063070    0.019111    0.875515    
#> 438: 0.706012    1.005748    3.455925    0.390161    0.063055    0.019085    0.875486    
#> 439: 0.705928    1.005816    3.455924    0.389747    0.063023    0.019081    0.875463    
#> 440: 0.705677    1.005912    3.455844    0.389510    0.062979    0.019083    0.875487    
#> 441: 0.705642    1.005929    3.455820    0.389616    0.063013    0.019087    0.875381    
#> 442: 0.705572    1.005941    3.455829    0.389624    0.063015    0.019093    0.875264    
#> 443: 0.705650    1.005972    3.455787    0.389729    0.063048    0.019083    0.875177    
#> 444: 0.705722    1.006017    3.455711    0.389764    0.063038    0.019087    0.875193    
#> 445: 0.705654    1.006079    3.455648    0.389773    0.063074    0.019072    0.875192    
#> 446: 0.705487    1.006032    3.455618    0.389707    0.063013    0.019068    0.875144    
#> 447: 0.705634    1.006020    3.455633    0.389521    0.062960    0.019072    0.875146    
#> 448: 0.705493    1.006030    3.455662    0.389194    0.062915    0.019080    0.875111    
#> 449: 0.705534    1.006037    3.455768    0.388898    0.062895    0.019096    0.875004    
#> 450: 0.705536    1.006017    3.455777    0.388745    0.062866    0.019081    0.874989    
#> 451: 0.705603    1.006013    3.455776    0.388863    0.062858    0.019069    0.874984    
#> 452: 0.705595    1.006004    3.455746    0.388757    0.062817    0.019059    0.874963    
#> 453: 0.705436    1.005983    3.455704    0.388496    0.062777    0.019044    0.874909    
#> 454: 0.705386    1.006077    3.455665    0.388463    0.062725    0.019032    0.874825    
#> 455: 0.705528    1.006097    3.455633    0.388675    0.062748    0.019031    0.874787    
#> 456: 0.705491    1.006035    3.455638    0.388802    0.062728    0.019044    0.874785    
#> 457: 0.705515    1.005982    3.455671    0.389024    0.062710    0.019042    0.874787    
#> 458: 0.705515    1.006068    3.455718    0.389295    0.062696    0.019043    0.874832    
#> 459: 0.705481    1.006164    3.455697    0.389176    0.062766    0.019033    0.874823    
#> 460: 0.705424    1.006230    3.455615    0.388982    0.062767    0.019030    0.874819    
#> 461: 0.705275    1.006340    3.455565    0.388750    0.062799    0.019017    0.874888    
#> 462: 0.705015    1.006471    3.455490    0.388523    0.062826    0.018993    0.874881    
#> 463: 0.704977    1.006556    3.455459    0.388416    0.062830    0.018974    0.874919    
#> 464: 0.705106    1.006587    3.455459    0.388180    0.062868    0.018969    0.874873    
#> 465: 0.705082    1.006479    3.455482    0.387815    0.062916    0.018968    0.874843    
#> 466: 0.705213    1.006530    3.455450    0.388003    0.062931    0.018949    0.874835    
#> 467: 0.705188    1.006526    3.455482    0.388151    0.062914    0.018929    0.874774    
#> 468: 0.705348    1.006490    3.455549    0.388617    0.062916    0.018930    0.874757    
#> 469: 0.705568    1.006549    3.455615    0.388837    0.062875    0.018946    0.874770    
#> 470: 0.705539    1.006606    3.455577    0.388867    0.062846    0.018941    0.874748    
#> 471: 0.705424    1.006573    3.455544    0.388814    0.062823    0.018926    0.874675    
#> 472: 0.705518    1.006616    3.455530    0.389031    0.062763    0.018923    0.874658    
#> 473: 0.705484    1.006680    3.455519    0.389022    0.062765    0.018918    0.874579    
#> 474: 0.705364    1.006734    3.455494    0.388663    0.062836    0.018914    0.874560    
#> 475: 0.705371    1.006836    3.455511    0.388445    0.062824    0.018911    0.874614    
#> 476: 0.705354    1.006822    3.455521    0.388372    0.062830    0.018912    0.874586    
#> 477: 0.705330    1.006828    3.455585    0.388303    0.062863    0.018919    0.874480    
#> 478: 0.705247    1.006789    3.455580    0.388196    0.062913    0.018920    0.874513    
#> 479: 0.705387    1.006840    3.455597    0.388246    0.062950    0.018905    0.874559    
#> 480: 0.705577    1.006885    3.455599    0.388391    0.062967    0.018910    0.874585    
#> 481: 0.705669    1.006911    3.455582    0.388355    0.062906    0.018916    0.874558    
#> 482: 0.705902    1.006846    3.455575    0.388457    0.062875    0.018933    0.874582    
#> 483: 0.705821    1.006784    3.455578    0.388570    0.062832    0.018926    0.874621    
#> 484: 0.705803    1.006683    3.455557    0.388897    0.062819    0.018924    0.874617    
#> 485: 0.705773    1.006789    3.455527    0.389071    0.062863    0.018910    0.874574    
#> 486: 0.705628    1.006901    3.455476    0.389175    0.062863    0.018898    0.874520    
#> 487: 0.705742    1.007019    3.455469    0.389063    0.062833    0.018890    0.874529    
#> 488: 0.705795    1.007067    3.455468    0.389135    0.062809    0.018892    0.874490    
#> 489: 0.706014    1.007021    3.455465    0.389408    0.062833    0.018895    0.874501    
#> 490: 0.706060    1.007095    3.455499    0.389624    0.062817    0.018908    0.874465    
#> 491: 0.706213    1.007145    3.455567    0.389441    0.062802    0.018915    0.874473    
#> 492: 0.706141    1.007181    3.455601    0.388942    0.062747    0.018931    0.874540    
#> 493: 0.706044    1.007128    3.455623    0.388609    0.062718    0.018957    0.874613    
#> 494: 0.706167    1.007076    3.455640    0.388402    0.062659    0.018977    0.874650    
#> 495: 0.706243    1.007095    3.455640    0.388727    0.062639    0.018981    0.874646    
#> 496: 0.706219    1.007214    3.455540    0.388754    0.062648    0.018984    0.874672    
#> 497: 0.706167    1.007154    3.455540    0.388770    0.062642    0.018991    0.874718    
#> 498: 0.706124    1.007146    3.455523    0.388844    0.062621    0.019013    0.874738    
#> 499: 0.706131    1.007218    3.455488    0.388896    0.062602    0.019024    0.874652    
#> 500: 0.706215    1.007170    3.455463    0.388911    0.062559    0.019033    0.874646    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.270481    0.961774    3.455763    0.392401    0.079265    0.016800    1.465414    
#> 002: 0.277072    1.063213    3.484834    0.372781    0.075301    0.015960    0.894576    
#> 003: 0.265480    1.090084    3.497796    0.354142    0.071536    0.016014    0.716371    
#> 004: 0.286112    1.149991    3.501875    0.336435    0.067959    0.015214    0.670908    
#> 005: 0.359112    1.145922    3.505845    0.319613    0.064561    0.014453    0.635905    
#> 006: 0.316759    1.150312    3.491425    0.303633    0.061333    0.013972    0.608693    
#> 007: 0.267978    1.154396    3.485752    0.288451    0.058267    0.015253    0.612697    
#> 008: 0.283950    1.151569    3.481478    0.274029    0.055353    0.014491    0.618214    
#> 009: 0.277800    1.143418    3.479288    0.266493    0.052586    0.016229    0.613510    
#> 010: 0.283849    1.139692    3.478364    0.280253    0.049956    0.015806    0.618597    
#> 011: 0.298900    1.164131    3.488122    0.266240    0.047459    0.016057    0.607388    
#> 012: 0.298772    1.158282    3.478247    0.317233    0.045086    0.017415    0.598323    
#> 013: 0.247205    1.157861    3.462186    0.314228    0.042831    0.020715    0.604493    
#> 014: 0.294882    1.159383    3.473510    0.298517    0.040690    0.019679    0.618040    
#> 015: 0.322650    1.160949    3.506226    0.283591    0.038655    0.021637    0.593815    
#> 016: 0.310522    1.170027    3.506467    0.270465    0.036723    0.020555    0.602356    
#> 017: 0.340739    1.159826    3.498987    0.256941    0.034886    0.019527    0.588394    
#> 018: 0.341243    1.148059    3.501786    0.244094    0.033142    0.020975    0.617403    
#> 019: 0.294805    1.144810    3.492480    0.260241    0.031485    0.019926    0.601936    
#> 020: 0.304982    1.151420    3.489887    0.287490    0.029911    0.022079    0.598482    
#> 021: 0.344457    1.145860    3.499833    0.273115    0.028415    0.020975    0.607304    
#> 022: 0.342980    1.135541    3.518651    0.259459    0.026994    0.020983    0.585445    
#> 023: 0.400082    1.138684    3.517055    0.284574    0.025645    0.021837    0.602935    
#> 024: 0.383117    1.161676    3.516376    0.281994    0.024363    0.020745    0.587912    
#> 025: 0.387385    1.146074    3.514595    0.300976    0.023417    0.027968    0.588216    
#> 026: 0.345980    1.162165    3.513353    0.313067    0.024258    0.031511    0.595525    
#> 027: 0.342952    1.157899    3.507858    0.297413    0.023045    0.029936    0.610433    
#> 028: 0.392207    1.150086    3.514716    0.297630    0.021893    0.033544    0.587316    
#> 029: 0.345645    1.144786    3.499104    0.298585    0.020798    0.031867    0.621422    
#> 030: 0.347687    1.153782    3.497992    0.283655    0.019758    0.030466    0.599058    
#> 031: 0.311912    1.144315    3.506356    0.287930    0.023558    0.028943    0.591933    
#> 032: 0.307753    1.141166    3.509627    0.273534    0.022380    0.027495    0.594370    
#> 033: 0.333423    1.156352    3.509903    0.276743    0.021261    0.029944    0.595001    
#> 034: 0.378989    1.151478    3.522313    0.267636    0.020198    0.028881    0.587900    
#> 035: 0.325488    1.133554    3.503190    0.254254    0.019188    0.029988    0.585651    
#> 036: 0.328978    1.149861    3.498291    0.274040    0.021117    0.032951    0.584341    
#> 037: 0.319876    1.158366    3.496559    0.263248    0.020569    0.031304    0.582968    
#> 038: 0.319777    1.157681    3.495473    0.250086    0.019540    0.032034    0.596999    
#> 039: 0.354782    1.151675    3.512917    0.250928    0.018563    0.034410    0.587045    
#> 040: 0.330653    1.137792    3.519237    0.251279    0.017635    0.033480    0.608807    
#> 041: 0.332945    1.127642    3.507501    0.284226    0.016754    0.034295    0.589481    
#> 042: 0.346072    1.125059    3.504616    0.301933    0.015916    0.032580    0.586657    
#> 043: 0.331465    1.149302    3.490580    0.303775    0.015120    0.033678    0.592710    
#> 044: 0.290624    1.151467    3.485705    0.337051    0.014895    0.031994    0.599722    
#> 045: 0.295485    1.146650    3.486162    0.320199    0.014151    0.034098    0.609183    
#> 046: 0.320239    1.147314    3.487391    0.304189    0.017181    0.032971    0.616304    
#> 047: 0.310418    1.167189    3.485201    0.334877    0.016322    0.036739    0.605046    
#> 048: 0.304893    1.156621    3.480413    0.318133    0.017286    0.035039    0.603859    
#> 049: 0.280018    1.150444    3.487186    0.302227    0.019397    0.033287    0.608741    
#> 050: 0.337782    1.132459    3.500187    0.327821    0.018427    0.031623    0.622669    
#> 051: 0.326913    1.138006    3.501310    0.331291    0.018363    0.035184    0.613341    
#> 052: 0.329067    1.144675    3.507263    0.314726    0.017445    0.033425    0.605173    
#> 053: 0.310501    1.138327    3.501105    0.298990    0.020910    0.031753    0.607297    
#> 054: 0.329478    1.154578    3.504183    0.284040    0.022660    0.031500    0.611862    
#> 055: 0.327608    1.162911    3.502444    0.269838    0.021527    0.033642    0.608881    
#> 056: 0.376349    1.150053    3.517281    0.305496    0.020450    0.031960    0.592453    
#> 057: 0.330555    1.143233    3.505680    0.290221    0.019428    0.031818    0.608247    
#> 058: 0.329161    1.144586    3.499832    0.275710    0.018457    0.032006    0.591355    
#> 059: 0.334440    1.128144    3.507664    0.307086    0.019675    0.035666    0.594332    
#> 060: 0.326132    1.121147    3.502458    0.291732    0.020165    0.035287    0.587949    
#> 061: 0.316979    1.131615    3.504430    0.277145    0.019157    0.036408    0.593758    
#> 062: 0.328629    1.147712    3.508705    0.290258    0.022003    0.035575    0.583734    
#> 063: 0.353737    1.142107    3.495747    0.293331    0.022017    0.033796    0.589185    
#> 064: 0.362283    1.131667    3.512899    0.278665    0.020916    0.032106    0.597173    
#> 065: 0.359036    1.134677    3.503213    0.264731    0.022167    0.030501    0.588243    
#> 066: 0.355234    1.144646    3.503054    0.287731    0.021059    0.028976    0.581658    
#> 067: 0.337822    1.156761    3.492144    0.287704    0.020006    0.029282    0.586733    
#> 068: 0.313666    1.160191    3.507225    0.308418    0.021707    0.034541    0.596946    
#> 069: 0.326685    1.164681    3.495928    0.293564    0.020622    0.032814    0.590259    
#> 070: 0.332180    1.151605    3.511174    0.278886    0.019762    0.034494    0.601269    
#> 071: 0.312445    1.166136    3.493305    0.264942    0.019650    0.033405    0.616972    
#> 072: 0.295046    1.150246    3.487477    0.251694    0.018668    0.031735    0.606416    
#> 073: 0.329253    1.150944    3.508732    0.259041    0.017734    0.040076    0.593519    
#> 074: 0.334447    1.137959    3.505798    0.246089    0.017714    0.038072    0.599731    
#> 075: 0.369333    1.132727    3.534856    0.272384    0.019215    0.036169    0.602888    
#> 076: 0.377585    1.138954    3.529247    0.285981    0.018254    0.036143    0.595244    
#> 077: 0.403915    1.130380    3.541785    0.311122    0.017342    0.039110    0.609159    
#> 078: 0.378324    1.134575    3.525637    0.314467    0.016475    0.038224    0.585964    
#> 079: 0.368727    1.141233    3.516517    0.298744    0.015651    0.036313    0.593040    
#> 080: 0.391647    1.135939    3.532270    0.283807    0.018720    0.039663    0.592429    
#> 081: 0.386390    1.128273    3.526807    0.269616    0.017784    0.038170    0.598562    
#> 082: 0.354966    1.125577    3.519082    0.267455    0.019113    0.036261    0.602985    
#> 083: 0.334605    1.131319    3.506042    0.311613    0.018158    0.034448    0.598215    
#> 084: 0.327538    1.140122    3.503843    0.296033    0.019257    0.032726    0.614993    
#> 085: 0.330579    1.151487    3.510104    0.281231    0.018294    0.031089    0.625894    
#> 086: 0.322485    1.135616    3.506251    0.267169    0.017380    0.029535    0.600877    
#> 087: 0.314437    1.131010    3.499735    0.261347    0.020767    0.028058    0.591705    
#> 088: 0.267717    1.130724    3.506207    0.260599    0.021054    0.026655    0.606358    
#> 089: 0.285581    1.136013    3.488787    0.247569    0.024381    0.025322    0.596877    
#> 090: 0.298919    1.152046    3.489340    0.235483    0.024757    0.025092    0.592191    
#> 091: 0.306991    1.149149    3.479701    0.262782    0.023519    0.025202    0.591506    
#> 092: 0.297342    1.159713    3.486780    0.249643    0.022343    0.025225    0.582670    
#> 093: 0.284588    1.153805    3.495983    0.237161    0.021226    0.030233    0.612153    
#> 094: 0.290019    1.152962    3.481760    0.251705    0.024206    0.029410    0.590690    
#> 095: 0.304381    1.162911    3.494051    0.245582    0.023508    0.027940    0.595713    
#> 096: 0.283208    1.174030    3.492003    0.273655    0.030718    0.026543    0.581009    
#> 097: 0.349839    1.179709    3.497008    0.273371    0.030189    0.025216    0.590512    
#> 098: 0.339687    1.186590    3.502120    0.266757    0.028679    0.026746    0.582493    
#> 099: 0.283384    1.163889    3.492437    0.253419    0.033303    0.025409    0.588259    
#> 100: 0.306052    1.167604    3.493070    0.253486    0.031638    0.024139    0.588146    
#> 101: 0.290702    1.148408    3.482716    0.240811    0.030056    0.022932    0.586353    
#> 102: 0.304167    1.152173    3.483536    0.245506    0.028553    0.021785    0.597929    
#> 103: 0.339702    1.142746    3.503162    0.236475    0.027126    0.023018    0.595531    
#> 104: 0.324810    1.141753    3.509033    0.269218    0.027728    0.026524    0.603998    
#> 105: 0.359909    1.135775    3.516029    0.286880    0.036371    0.026365    0.592385    
#> 106: 0.364057    1.141378    3.519859    0.274357    0.034552    0.027911    0.587358    
#> 107: 0.365767    1.153905    3.512460    0.291603    0.032824    0.026951    0.587416    
#> 108: 0.376496    1.143292    3.527576    0.286571    0.031183    0.025603    0.605668    
#> 109: 0.387713    1.148646    3.529553    0.272243    0.029624    0.024323    0.612700    
#> 110: 0.382513    1.136750    3.521337    0.258630    0.028143    0.023107    0.599032    
#> 111: 0.397426    1.126640    3.523378    0.255314    0.026736    0.022370    0.592246    
#> 112: 0.347803    1.124836    3.500708    0.257705    0.025399    0.024919    0.601766    
#> 113: 0.353483    1.143958    3.512861    0.263057    0.024129    0.027838    0.590427    
#> 114: 0.343796    1.150650    3.506290    0.271617    0.022923    0.029501    0.592837    
#> 115: 0.341578    1.134945    3.494057    0.298799    0.021776    0.028026    0.611912    
#> 116: 0.328957    1.156797    3.498411    0.283859    0.021829    0.031524    0.597469    
#> 117: 0.278107    1.164331    3.497766    0.287386    0.020878    0.030764    0.605035    
#> 118: 0.344636    1.158280    3.500977    0.305523    0.019834    0.031658    0.588935    
#> 119: 0.366615    1.152723    3.506626    0.290247    0.018842    0.030076    0.602798    
#> 120: 0.320449    1.133548    3.512065    0.275735    0.021174    0.030027    0.593158    
#> 121: 0.328726    1.148998    3.513863    0.261948    0.027319    0.029453    0.601832    
#> 122: 0.328246    1.145066    3.510747    0.248851    0.029105    0.027980    0.591866    
#> 123: 0.370626    1.160385    3.500831    0.275354    0.027650    0.026581    0.601816    
#> 124: 0.367499    1.166320    3.506466    0.292678    0.026268    0.025252    0.593792    
#> 125: 0.387750    1.161360    3.511531    0.297175    0.024954    0.023989    0.602953    
#> 126: 0.315963    1.173861    3.503382    0.282317    0.023707    0.024290    0.606207    
#> 127: 0.334608    1.162509    3.491447    0.291466    0.022521    0.024210    0.603600    
#> 128: 0.304172    1.142073    3.510773    0.276893    0.022589    0.025196    0.599772    
#> 129: 0.349733    1.151295    3.513105    0.263048    0.023515    0.031746    0.600984    
#> 130: 0.368095    1.171426    3.501082    0.249896    0.024102    0.030159    0.597728    
#> 131: 0.357410    1.150143    3.501092    0.237401    0.027566    0.028651    0.592843    
#> 132: 0.335593    1.150548    3.492900    0.318768    0.026187    0.028854    0.598476    
#> 133: 0.326525    1.136803    3.498683    0.302830    0.024878    0.032307    0.603874    
#> 134: 0.335771    1.112231    3.515570    0.287688    0.023634    0.033392    0.603490    
#> 135: 0.327193    1.119268    3.517956    0.273304    0.031559    0.031723    0.609785    
#> 136: 0.348001    1.128329    3.522546    0.259638    0.030888    0.030137    0.599665    
#> 137: 0.381558    1.126472    3.526019    0.246657    0.029343    0.028630    0.610650    
#> 138: 0.342285    1.132638    3.514624    0.234324    0.027876    0.027198    0.608769    
#> 139: 0.345615    1.143580    3.527121    0.227689    0.026482    0.026339    0.611589    
#> 140: 0.347832    1.158315    3.517805    0.226194    0.025158    0.028108    0.617745    
#> 141: 0.338577    1.143695    3.514140    0.221487    0.026897    0.026702    0.588546    
#> 142: 0.373467    1.112750    3.535891    0.250444    0.025552    0.028923    0.592267    
#> 143: 0.314163    1.135258    3.509973    0.237922    0.024275    0.027477    0.597599    
#> 144: 0.349201    1.144370    3.513800    0.247290    0.023061    0.028509    0.584863    
#> 145: 0.305681    1.153314    3.491863    0.253579    0.021908    0.027083    0.594324    
#> 146: 0.303867    1.160960    3.497471    0.283636    0.024854    0.025729    0.580952    
#> 147: 0.267318    1.159268    3.487935    0.269454    0.026524    0.024443    0.582802    
#> 148: 0.307452    1.143156    3.507042    0.255981    0.025198    0.024066    0.593957    
#> 149: 0.331794    1.127659    3.518946    0.243182    0.023938    0.025404    0.608553    
#> 150: 0.372123    1.114416    3.516624    0.231023    0.022741    0.025482    0.624500    
#> 151: 0.303123    1.138990    3.507901    0.238673    0.021604    0.024573    0.618808    
#> 152: 0.316639    1.145751    3.501684    0.240837    0.017320    0.023009    0.617552    
#> 153: 0.321929    1.159069    3.517577    0.221400    0.020296    0.029634    0.632744    
#> 154: 0.376384    1.140317    3.520236    0.282232    0.016631    0.029818    0.608488    
#> 155: 0.355908    1.112778    3.517812    0.268492    0.019596    0.028127    0.601084    
#> 156: 0.380249    1.127968    3.521009    0.254960    0.021687    0.034257    0.632171    
#> 157: 0.353470    1.125330    3.522910    0.235257    0.027354    0.027514    0.624042    
#> 158: 0.352687    1.145167    3.516049    0.222246    0.021362    0.024476    0.602135    
#> 159: 0.314136    1.148810    3.520547    0.227165    0.022273    0.026165    0.610396    
#> 160: 0.369414    1.131685    3.535841    0.225247    0.027814    0.028971    0.602936    
#> 161: 0.378820    1.142059    3.519971    0.223560    0.028737    0.029578    0.610211    
#> 162: 0.340315    1.151267    3.512517    0.197458    0.026116    0.024456    0.616973    
#> 163: 0.352237    1.140183    3.504148    0.184926    0.030679    0.024036    0.614287    
#> 164: 0.357182    1.143001    3.512689    0.221185    0.023184    0.024368    0.606923    
#> 165: 0.354355    1.146575    3.507586    0.250310    0.023378    0.028083    0.597379    
#> 166: 0.371416    1.162254    3.506173    0.204859    0.027752    0.026999    0.592596    
#> 167: 0.355424    1.165135    3.511585    0.217535    0.025780    0.026541    0.596485    
#> 168: 0.356472    1.164389    3.514471    0.243085    0.026901    0.025871    0.600746    
#> 169: 0.357090    1.178277    3.503024    0.223821    0.031203    0.023006    0.610140    
#> 170: 0.348521    1.149541    3.510525    0.225479    0.031549    0.023189    0.595905    
#> 171: 0.316423    1.150505    3.504590    0.211267    0.021849    0.023691    0.590572    
#> 172: 0.322393    1.167555    3.507827    0.224120    0.027106    0.023488    0.582839    
#> 173: 0.299820    1.177201    3.483472    0.258579    0.024000    0.022578    0.578004    
#> 174: 0.340490    1.167848    3.503912    0.266652    0.017851    0.022443    0.578578    
#> 175: 0.293964    1.169749    3.484563    0.272666    0.017777    0.022202    0.596255    
#> 176: 0.307214    1.183264    3.488375    0.282338    0.017745    0.022362    0.593949    
#> 177: 0.332148    1.179420    3.497833    0.261191    0.017104    0.019538    0.605783    
#> 178: 0.317808    1.161048    3.501602    0.256278    0.017824    0.026766    0.598084    
#> 179: 0.349119    1.168096    3.511517    0.248578    0.023253    0.037356    0.604621    
#> 180: 0.313220    1.161924    3.496368    0.223056    0.020129    0.031322    0.594501    
#> 181: 0.330505    1.140693    3.486416    0.262921    0.015503    0.033282    0.604227    
#> 182: 0.277600    1.134202    3.481077    0.262780    0.013516    0.033167    0.614839    
#> 183: 0.314156    1.150193    3.493228    0.258833    0.016116    0.030626    0.610894    
#> 184: 0.315708    1.127614    3.509175    0.222513    0.018890    0.030836    0.595531    
#> 185: 0.315994    1.145164    3.503503    0.228027    0.018891    0.028524    0.587043    
#> 186: 0.318113    1.154805    3.509622    0.204373    0.017180    0.034524    0.606484    
#> 187: 0.334910    1.149134    3.512044    0.234816    0.020452    0.035763    0.610815    
#> 188: 0.304530    1.173964    3.499981    0.200533    0.025487    0.028389    0.604664    
#> 189: 0.350717    1.169324    3.509701    0.239848    0.026069    0.028734    0.605981    
#> 190: 0.344726    1.150566    3.515666    0.244534    0.016102    0.030612    0.594453    
#> 191: 0.328147    1.156566    3.493974    0.280624    0.016372    0.027906    0.598497    
#> 192: 0.301401    1.163337    3.497505    0.315985    0.015122    0.032257    0.594957    
#> 193: 0.350130    1.159573    3.508977    0.253315    0.016597    0.030121    0.604469    
#> 194: 0.332738    1.152804    3.510228    0.229266    0.019915    0.032613    0.601942    
#> 195: 0.286107    1.151648    3.494591    0.253980    0.015784    0.029585    0.611496    
#> 196: 0.290197    1.142203    3.498361    0.223236    0.015730    0.027064    0.619347    
#> 197: 0.269496    1.161108    3.495775    0.231722    0.021710    0.020285    0.602786    
#> 198: 0.332059    1.162696    3.496990    0.273553    0.018249    0.022786    0.595071    
#> 199: 0.325204    1.152082    3.498503    0.288042    0.021146    0.020105    0.592734    
#> 200: 0.300338    1.157816    3.484178    0.288998    0.029994    0.025696    0.595448    
#> 201: 0.301909    1.153883    3.488180    0.293913    0.030699    0.025990    0.588375    
#> 202: 0.304092    1.152449    3.488606    0.292305    0.028086    0.024376    0.589064    
#> 203: 0.315298    1.151095    3.488370    0.289312    0.027818    0.023098    0.589983    
#> 204: 0.321099    1.149150    3.491389    0.286634    0.028021    0.023167    0.592648    
#> 205: 0.326381    1.151932    3.493780    0.285999    0.027037    0.023434    0.597198    
#> 206: 0.329734    1.155308    3.496696    0.292418    0.026252    0.024453    0.596048    
#> 207: 0.326689    1.157352    3.495441    0.293008    0.025916    0.024600    0.594336    
#> 208: 0.327890    1.157792    3.496136    0.288212    0.025082    0.024506    0.593057    
#> 209: 0.329227    1.157367    3.495419    0.285307    0.024718    0.024559    0.592133    
#> 210: 0.330436    1.156420    3.496245    0.283138    0.024378    0.024405    0.591095    
#> 211: 0.332557    1.157548    3.496122    0.282321    0.024494    0.024821    0.590243    
#> 212: 0.333061    1.156992    3.496718    0.279917    0.024721    0.024904    0.589843    
#> 213: 0.334026    1.154625    3.497730    0.277170    0.024645    0.025154    0.589952    
#> 214: 0.337320    1.153406    3.498812    0.276368    0.024496    0.025331    0.590234    
#> 215: 0.340837    1.152379    3.500478    0.273426    0.024569    0.025372    0.591136    
#> 216: 0.343185    1.150235    3.501783    0.271427    0.025095    0.025486    0.592632    
#> 217: 0.343762    1.149972    3.502534    0.270744    0.025379    0.025303    0.592669    
#> 218: 0.343922    1.150291    3.502300    0.269722    0.025715    0.025207    0.592828    
#> 219: 0.342589    1.149880    3.501715    0.268387    0.025567    0.025214    0.593401    
#> 220: 0.341367    1.149780    3.501904    0.267371    0.025250    0.025641    0.593441    
#> 221: 0.340215    1.149699    3.502026    0.265608    0.025185    0.025804    0.593250    
#> 222: 0.340376    1.149749    3.501865    0.262539    0.025290    0.026008    0.593647    
#> 223: 0.341541    1.149769    3.502326    0.260833    0.025047    0.026084    0.593359    
#> 224: 0.343172    1.150108    3.502624    0.258787    0.024758    0.026117    0.593876    
#> 225: 0.342076    1.149220    3.502758    0.257215    0.024419    0.026341    0.594279    
#> 226: 0.340768    1.148519    3.502381    0.255751    0.024154    0.026420    0.594276    
#> 227: 0.341097    1.148490    3.502432    0.255032    0.024099    0.026606    0.593943    
#> 228: 0.339742    1.149263    3.501979    0.254019    0.024179    0.026736    0.594204    
#> 229: 0.338500    1.149052    3.501925    0.253938    0.024175    0.026821    0.594060    
#> 230: 0.338522    1.148872    3.502105    0.252794    0.024190    0.026746    0.594131    
#> 231: 0.338207    1.148945    3.502195    0.251583    0.024090    0.026759    0.593929    
#> 232: 0.337319    1.148642    3.502358    0.250742    0.023978    0.026778    0.593974    
#> 233: 0.336589    1.148130    3.502394    0.250735    0.023890    0.026801    0.594085    
#> 234: 0.336053    1.147704    3.502210    0.251239    0.023959    0.026841    0.593944    
#> 235: 0.337141    1.147368    3.502692    0.250260    0.023877    0.026951    0.594161    
#> 236: 0.337648    1.147629    3.502843    0.250141    0.023809    0.027007    0.594284    
#> 237: 0.338610    1.147056    3.503231    0.249804    0.023759    0.027005    0.595588    
#> 238: 0.339469    1.146699    3.503351    0.249938    0.023790    0.027033    0.596836    
#> 239: 0.339393    1.147058    3.503189    0.250007    0.023834    0.027049    0.597033    
#> 240: 0.339166    1.147028    3.503428    0.250304    0.023872    0.027219    0.596671    
#> 241: 0.339556    1.146824    3.503616    0.250771    0.023843    0.027246    0.596532    
#> 242: 0.339241    1.146675    3.503390    0.251501    0.023848    0.027332    0.596404    
#> 243: 0.338714    1.146931    3.503175    0.252200    0.023909    0.027411    0.596545    
#> 244: 0.338520    1.146575    3.503507    0.253401    0.023790    0.027537    0.596547    
#> 245: 0.339064    1.146090    3.503916    0.253819    0.023703    0.027667    0.596914    
#> 246: 0.339725    1.145696    3.504150    0.253492    0.023548    0.027842    0.597038    
#> 247: 0.339628    1.145540    3.504318    0.253432    0.023421    0.027939    0.597161    
#> 248: 0.339478    1.145762    3.504474    0.252754    0.023409    0.027993    0.597439    
#> 249: 0.339191    1.145529    3.504586    0.252178    0.023340    0.028047    0.597648    
#> 250: 0.339531    1.145440    3.504795    0.251590    0.023518    0.028152    0.598025    
#> 251: 0.339978    1.145550    3.505170    0.251977    0.023568    0.028208    0.598217    
#> 252: 0.340024    1.145636    3.505516    0.251714    0.023581    0.028188    0.598519    
#> 253: 0.340035    1.145595    3.505620    0.251633    0.023593    0.028224    0.598521    
#> 254: 0.340247    1.145991    3.505508    0.252390    0.023664    0.028234    0.598666    
#> 255: 0.339682    1.146291    3.505118    0.253179    0.023670    0.028234    0.598701    
#> 256: 0.339653    1.146501    3.504759    0.253618    0.023672    0.028138    0.598821    
#> 257: 0.339417    1.146540    3.504436    0.253441    0.023746    0.028120    0.598857    
#> 258: 0.338640    1.146283    3.504332    0.253372    0.023669    0.028107    0.598909    
#> 259: 0.338620    1.145986    3.504448    0.253198    0.023600    0.028103    0.599011    
#> 260: 0.338897    1.145890    3.504595    0.252661    0.023601    0.028003    0.599091    
#> 261: 0.339486    1.145781    3.504877    0.252257    0.023585    0.027897    0.599424    
#> 262: 0.339408    1.145766    3.504797    0.251965    0.023572    0.027804    0.599562    
#> 263: 0.339030    1.145993    3.504747    0.251301    0.023548    0.027763    0.599372    
#> 264: 0.338491    1.146303    3.504740    0.250966    0.023535    0.027748    0.599409    
#> 265: 0.338523    1.146471    3.504773    0.251296    0.023535    0.027718    0.599607    
#> 266: 0.339085    1.146437    3.504988    0.251579    0.023562    0.027704    0.599577    
#> 267: 0.339190    1.146223    3.505313    0.251631    0.023608    0.027761    0.599372    
#> 268: 0.339410    1.145980    3.505474    0.251569    0.023554    0.027788    0.599207    
#> 269: 0.339706    1.145809    3.505569    0.252034    0.023548    0.027846    0.599063    
#> 270: 0.339412    1.145890    3.505410    0.252095    0.023449    0.027865    0.599017    
#> 271: 0.338988    1.145771    3.505210    0.252149    0.023397    0.027922    0.599060    
#> 272: 0.339102    1.145603    3.505211    0.252155    0.023407    0.027959    0.599489    
#> 273: 0.339115    1.145749    3.505229    0.252594    0.023410    0.027962    0.599379    
#> 274: 0.339317    1.145796    3.505315    0.252946    0.023353    0.027952    0.599261    
#> 275: 0.339352    1.145898    3.505252    0.253015    0.023257    0.027957    0.599130    
#> 276: 0.339563    1.145815    3.505403    0.254261    0.023224    0.028006    0.598846    
#> 277: 0.339746    1.145715    3.505646    0.254264    0.023140    0.028048    0.598744    
#> 278: 0.339658    1.145879    3.505749    0.254580    0.023123    0.028071    0.598833    
#> 279: 0.339560    1.145847    3.505808    0.254285    0.023064    0.028121    0.598971    
#> 280: 0.339348    1.145849    3.505905    0.254267    0.022979    0.028124    0.598884    
#> 281: 0.339005    1.145922    3.505934    0.253699    0.023018    0.028065    0.598943    
#> 282: 0.339113    1.145940    3.506108    0.253681    0.023053    0.028061    0.598877    
#> 283: 0.338875    1.145997    3.506192    0.253742    0.023144    0.028091    0.598861    
#> 284: 0.338807    1.145960    3.506265    0.253720    0.023163    0.028038    0.598772    
#> 285: 0.338610    1.146065    3.506094    0.253634    0.023144    0.028005    0.598773    
#> 286: 0.338555    1.146091    3.506046    0.253538    0.023190    0.028034    0.598688    
#> 287: 0.338302    1.146104    3.505974    0.253666    0.023181    0.028075    0.598778    
#> 288: 0.338454    1.145858    3.506150    0.253781    0.023149    0.028146    0.598713    
#> 289: 0.338764    1.145733    3.506169    0.254314    0.023092    0.028193    0.598573    
#> 290: 0.339023    1.145726    3.506195    0.254691    0.023066    0.028172    0.598628    
#> 291: 0.339145    1.145805    3.506340    0.254606    0.023030    0.028144    0.598581    
#> 292: 0.339188    1.145808    3.506271    0.254362    0.023005    0.028123    0.598533    
#> 293: 0.339027    1.145845    3.506178    0.254580    0.022961    0.028099    0.598609    
#> 294: 0.338775    1.145908    3.506072    0.254991    0.022940    0.028077    0.598543    
#> 295: 0.338683    1.145714    3.506069    0.254647    0.022912    0.028069    0.598577    
#> 296: 0.338670    1.145659    3.506040    0.254321    0.022926    0.028041    0.598775    
#> 297: 0.338743    1.145727    3.506139    0.253945    0.022904    0.027985    0.599061    
#> 298: 0.338954    1.145665    3.506125    0.253882    0.022874    0.027924    0.599025    
#> 299: 0.339096    1.145564    3.506209    0.253577    0.022815    0.027922    0.598824    
#> 300: 0.339230    1.145471    3.506246    0.253452    0.022788    0.027863    0.598747    
#> 301: 0.339278    1.145433    3.506258    0.253641    0.022776    0.027838    0.598880    
#> 302: 0.339147    1.145393    3.506149    0.253493    0.022729    0.027823    0.598709    
#> 303: 0.338747    1.145488    3.505992    0.253521    0.022633    0.027850    0.598641    
#> 304: 0.338746    1.145693    3.505905    0.253340    0.022582    0.027844    0.598668    
#> 305: 0.338624    1.145613    3.505931    0.253257    0.022552    0.027847    0.598595    
#> 306: 0.338268    1.145569    3.505798    0.253314    0.022533    0.027810    0.598572    
#> 307: 0.337870    1.145596    3.505682    0.253404    0.022502    0.027794    0.598629    
#> 308: 0.337271    1.145721    3.505514    0.253313    0.022448    0.027788    0.598759    
#> 309: 0.336965    1.145717    3.505406    0.253638    0.022430    0.027767    0.598933    
#> 310: 0.337142    1.145663    3.505283    0.253505    0.022407    0.027785    0.599141    
#> 311: 0.336981    1.145646    3.505298    0.253476    0.022397    0.027789    0.599172    
#> 312: 0.336888    1.145637    3.505203    0.253810    0.022372    0.027793    0.599154    
#> 313: 0.336797    1.145663    3.505092    0.254074    0.022343    0.027809    0.599027    
#> 314: 0.336674    1.145657    3.505046    0.254385    0.022347    0.027808    0.598996    
#> 315: 0.336464    1.145641    3.504993    0.254243    0.022380    0.027813    0.598937    
#> 316: 0.336576    1.145645    3.505028    0.254002    0.022412    0.027793    0.598868    
#> 317: 0.336816    1.145552    3.505111    0.254137    0.022439    0.027735    0.598958    
#> 318: 0.337099    1.145543    3.505153    0.254206    0.022429    0.027711    0.598845    
#> 319: 0.337188    1.145526    3.505251    0.254378    0.022430    0.027701    0.598914    
#> 320: 0.336973    1.145493    3.505250    0.254563    0.022448    0.027707    0.598959    
#> 321: 0.336877    1.145591    3.505260    0.254442    0.022447    0.027707    0.598960    
#> 322: 0.336760    1.145547    3.505236    0.254162    0.022403    0.027754    0.599008    
#> 323: 0.336294    1.145615    3.505153    0.254095    0.022396    0.027805    0.598978    
#> 324: 0.336214    1.145860    3.505047    0.254118    0.022385    0.027815    0.599096    
#> 325: 0.335964    1.146083    3.504926    0.254073    0.022372    0.027805    0.599106    
#> 326: 0.335986    1.146117    3.504824    0.254158    0.022406    0.027814    0.599006    
#> 327: 0.336000    1.146140    3.504833    0.254103    0.022392    0.027819    0.598967    
#> 328: 0.336194    1.146089    3.504880    0.254138    0.022422    0.027825    0.598957    
#> 329: 0.336495    1.146000    3.505008    0.254255    0.022449    0.027823    0.599030    
#> 330: 0.336471    1.145951    3.505079    0.254490    0.022459    0.027849    0.599045    
#> 331: 0.336802    1.146102    3.505208    0.254630    0.022431    0.027898    0.598998    
#> 332: 0.336867    1.146091    3.505295    0.255064    0.022380    0.027977    0.599019    
#> 333: 0.336707    1.146104    3.505242    0.254943    0.022319    0.028036    0.599041    
#> 334: 0.336435    1.146062    3.505160    0.254715    0.022269    0.028090    0.599074    
#> 335: 0.336160    1.146035    3.504996    0.254731    0.022193    0.028123    0.599105    
#> 336: 0.336020    1.146050    3.505017    0.254712    0.022144    0.028168    0.599180    
#> 337: 0.335946    1.146134    3.504945    0.254635    0.022102    0.028189    0.599198    
#> 338: 0.335757    1.146290    3.504939    0.254393    0.022083    0.028192    0.599223    
#> 339: 0.335408    1.146456    3.504825    0.254217    0.022097    0.028187    0.599315    
#> 340: 0.335380    1.146529    3.504853    0.253756    0.022117    0.028192    0.599255    
#> 341: 0.335503    1.146609    3.504901    0.253452    0.022124    0.028168    0.599216    
#> 342: 0.335191    1.146598    3.504891    0.253385    0.022092    0.028176    0.599101    
#> 343: 0.334802    1.146718    3.504856    0.253404    0.022090    0.028191    0.599035    
#> 344: 0.334708    1.146757    3.504828    0.253507    0.022076    0.028204    0.598943    
#> 345: 0.334593    1.146805    3.504821    0.253600    0.022093    0.028175    0.598979    
#> 346: 0.334545    1.146846    3.504798    0.253445    0.022071    0.028150    0.598994    
#> 347: 0.334491    1.146854    3.504788    0.253162    0.022058    0.028152    0.599085    
#> 348: 0.334333    1.146946    3.504712    0.253064    0.022084    0.028132    0.599115    
#> 349: 0.334381    1.146952    3.504751    0.253103    0.022113    0.028092    0.599031    
#> 350: 0.334300    1.146835    3.504763    0.253128    0.022115    0.028086    0.598987    
#> 351: 0.334336    1.146900    3.504715    0.253282    0.022122    0.028075    0.598887    
#> 352: 0.333977    1.146991    3.504675    0.253364    0.022152    0.028062    0.598958    
#> 353: 0.333971    1.147135    3.504645    0.253235    0.022160    0.028059    0.598916    
#> 354: 0.333806    1.147212    3.504577    0.253202    0.022127    0.028066    0.598904    
#> 355: 0.334021    1.147060    3.504602    0.253342    0.022104    0.028051    0.598880    
#> 356: 0.334154    1.147021    3.504656    0.253822    0.022113    0.028029    0.598873    
#> 357: 0.334228    1.147109    3.504648    0.254065    0.022129    0.028050    0.598788    
#> 358: 0.334334    1.147255    3.504668    0.254106    0.022124    0.028056    0.598704    
#> 359: 0.334285    1.147447    3.504603    0.254105    0.022127    0.028032    0.598703    
#> 360: 0.333971    1.147572    3.504396    0.254392    0.022144    0.028021    0.598668    
#> 361: 0.333638    1.147800    3.504231    0.254328    0.022163    0.027991    0.598502    
#> 362: 0.333537    1.147873    3.504125    0.254266    0.022158    0.027950    0.598345    
#> 363: 0.333459    1.147860    3.504116    0.254230    0.022150    0.027956    0.598238    
#> 364: 0.333416    1.147927    3.504095    0.254136    0.022128    0.027952    0.598254    
#> 365: 0.333428    1.147891    3.504145    0.254074    0.022126    0.027973    0.598293    
#> 366: 0.333538    1.147864    3.504127    0.254171    0.022100    0.028015    0.598304    
#> 367: 0.333645    1.147878    3.504165    0.253901    0.022091    0.028026    0.598262    
#> 368: 0.333826    1.147894    3.504236    0.253592    0.022089    0.028044    0.598151    
#> 369: 0.333777    1.147900    3.504242    0.253379    0.022068    0.028050    0.598166    
#> 370: 0.333777    1.148030    3.504244    0.253154    0.022064    0.028054    0.598150    
#> 371: 0.333592    1.148059    3.504206    0.253006    0.022057    0.028038    0.598115    
#> 372: 0.333586    1.148078    3.504186    0.253164    0.022051    0.028044    0.598119    
#> 373: 0.333347    1.148143    3.504111    0.253266    0.022020    0.028076    0.598138    
#> 374: 0.333258    1.148096    3.504058    0.253367    0.021974    0.028129    0.598115    
#> 375: 0.333090    1.148071    3.504018    0.253235    0.021938    0.028173    0.598157    
#> 376: 0.332982    1.148112    3.504008    0.253227    0.021945    0.028191    0.598092    
#> 377: 0.332831    1.148185    3.503976    0.253508    0.021958    0.028195    0.598006    
#> 378: 0.332703    1.148211    3.503894    0.253691    0.021955    0.028210    0.597986    
#> 379: 0.332683    1.148140    3.503926    0.253725    0.021946    0.028223    0.597913    
#> 380: 0.332575    1.148145    3.503914    0.253798    0.021937    0.028233    0.597773    
#> 381: 0.332406    1.148146    3.503874    0.253846    0.021939    0.028225    0.597749    
#> 382: 0.332352    1.148137    3.503884    0.253767    0.021911    0.028233    0.597667    
#> 383: 0.332365    1.148129    3.503815    0.253759    0.021900    0.028207    0.597607    
#> 384: 0.332177    1.148203    3.503751    0.253867    0.021882    0.028194    0.597635    
#> 385: 0.332246    1.148236    3.503772    0.253722    0.021865    0.028218    0.597660    
#> 386: 0.332324    1.148310    3.503806    0.253679    0.021852    0.028214    0.597688    
#> 387: 0.332622    1.148307    3.503920    0.253569    0.021856    0.028211    0.597685    
#> 388: 0.332829    1.148305    3.503984    0.253581    0.021850    0.028209    0.597667    
#> 389: 0.332869    1.148195    3.504023    0.253392    0.021856    0.028176    0.597712    
#> 390: 0.332752    1.148160    3.504032    0.253340    0.021847    0.028147    0.597745    
#> 391: 0.332921    1.148100    3.504052    0.253196    0.021845    0.028164    0.597774    
#> 392: 0.332974    1.148079    3.504091    0.253196    0.021848    0.028161    0.597779    
#> 393: 0.333001    1.148054    3.504089    0.253082    0.021842    0.028182    0.597723    
#> 394: 0.332955    1.148051    3.504038    0.253047    0.021809    0.028185    0.597680    
#> 395: 0.333126    1.148091    3.504081    0.253017    0.021805    0.028162    0.597657    
#> 396: 0.333236    1.148133    3.504089    0.252915    0.021811    0.028149    0.597577    
#> 397: 0.333315    1.148121    3.504117    0.252876    0.021811    0.028148    0.597554    
#> 398: 0.333516    1.148047    3.504178    0.252872    0.021793    0.028158    0.597482    
#> 399: 0.333758    1.148004    3.504269    0.252871    0.021804    0.028165    0.597431    
#> 400: 0.333910    1.148040    3.504317    0.252706    0.021802    0.028157    0.597372    
#> 401: 0.333979    1.148128    3.504328    0.252659    0.021799    0.028161    0.597417    
#> 402: 0.333980    1.148134    3.504349    0.252671    0.021797    0.028152    0.597378    
#> 403: 0.334194    1.148115    3.504353    0.252863    0.021802    0.028150    0.597350    
#> 404: 0.334135    1.148198    3.504295    0.252960    0.021806    0.028115    0.597361    
#> 405: 0.334247    1.148254    3.504318    0.253097    0.021813    0.028092    0.597401    
#> 406: 0.334224    1.148284    3.504265    0.253300    0.021835    0.028084    0.597420    
#> 407: 0.334263    1.148320    3.504251    0.253403    0.021862    0.028036    0.597379    
#> 408: 0.334343    1.148437    3.504236    0.253406    0.021883    0.028013    0.597443    
#> 409: 0.334281    1.148481    3.504226    0.253413    0.021876    0.027992    0.597438    
#> 410: 0.334129    1.148514    3.504186    0.253326    0.021901    0.027962    0.597452    
#> 411: 0.334200    1.148414    3.504231    0.253195    0.021919    0.027936    0.597418    
#> 412: 0.334230    1.148421    3.504238    0.253209    0.021939    0.027917    0.597402    
#> 413: 0.334290    1.148397    3.504242    0.253219    0.021944    0.027896    0.597466    
#> 414: 0.334029    1.148372    3.504233    0.253030    0.021946    0.027879    0.597560    
#> 415: 0.334116    1.148327    3.504260    0.252844    0.021935    0.027863    0.597524    
#> 416: 0.334122    1.148379    3.504283    0.252947    0.021934    0.027875    0.597450    
#> 417: 0.334070    1.148412    3.504255    0.253092    0.021958    0.027845    0.597437    
#> 418: 0.333850    1.148470    3.504213    0.253179    0.021985    0.027816    0.597380    
#> 419: 0.333736    1.148587    3.504127    0.253240    0.022000    0.027788    0.597336    
#> 420: 0.333642    1.148760    3.504064    0.253132    0.022030    0.027763    0.597279    
#> 421: 0.333530    1.148848    3.504043    0.253056    0.022057    0.027753    0.597252    
#> 422: 0.333572    1.148846    3.504040    0.253093    0.022076    0.027733    0.597277    
#> 423: 0.333649    1.148806    3.504078    0.253061    0.022101    0.027722    0.597262    
#> 424: 0.333549    1.148777    3.504004    0.252970    0.022112    0.027701    0.597236    
#> 425: 0.333604    1.148820    3.503960    0.252964    0.022120    0.027686    0.597319    
#> 426: 0.333617    1.148886    3.503931    0.252894    0.022106    0.027674    0.597329    
#> 427: 0.333549    1.148827    3.503941    0.252912    0.022086    0.027660    0.597336    
#> 428: 0.333464    1.148809    3.503958    0.253017    0.022075    0.027650    0.597393    
#> 429: 0.333457    1.148766    3.504001    0.253015    0.022065    0.027658    0.597404    
#> 430: 0.333457    1.148784    3.504004    0.253003    0.022054    0.027662    0.597451    
#> 431: 0.333394    1.148777    3.503963    0.253094    0.022054    0.027657    0.597353    
#> 432: 0.333356    1.148796    3.503952    0.253153    0.022077    0.027653    0.597325    
#> 433: 0.333418    1.148865    3.503955    0.253216    0.022084    0.027668    0.597315    
#> 434: 0.333356    1.148832    3.503946    0.253164    0.022080    0.027671    0.597347    
#> 435: 0.333366    1.148835    3.503935    0.253074    0.022061    0.027664    0.597351    
#> 436: 0.333330    1.148757    3.503960    0.253126    0.022069    0.027643    0.597320    
#> 437: 0.333438    1.148677    3.504009    0.253021    0.022085    0.027637    0.597332    
#> 438: 0.333536    1.148762    3.504027    0.252932    0.022073    0.027667    0.597302    
#> 439: 0.333653    1.148805    3.504049    0.252839    0.022084    0.027662    0.597223    
#> 440: 0.333704    1.148844    3.504060    0.252807    0.022083    0.027653    0.597194    
#> 441: 0.333664    1.148866    3.504017    0.253013    0.022102    0.027644    0.597130    
#> 442: 0.333384    1.148921    3.503945    0.253159    0.022133    0.027616    0.597084    
#> 443: 0.333211    1.148945    3.503862    0.253071    0.022130    0.027623    0.597067    
#> 444: 0.333106    1.149017    3.503763    0.253132    0.022136    0.027629    0.597015    
#> 445: 0.332971    1.149027    3.503694    0.253033    0.022119    0.027631    0.597045    
#> 446: 0.332838    1.149026    3.503667    0.253068    0.022100    0.027638    0.597068    
#> 447: 0.332810    1.149047    3.503661    0.253039    0.022071    0.027668    0.597103    
#> 448: 0.332854    1.149093    3.503693    0.253102    0.022056    0.027711    0.597041    
#> 449: 0.332926    1.149133    3.503770    0.253202    0.022042    0.027733    0.596989    
#> 450: 0.332985    1.149133    3.503798    0.253167    0.022025    0.027775    0.597015    
#> 451: 0.333098    1.149175    3.503805    0.253224    0.022015    0.027796    0.597084    
#> 452: 0.333204    1.149221    3.503786    0.253505    0.022001    0.027810    0.597084    
#> 453: 0.333261    1.149270    3.503802    0.253647    0.022000    0.027816    0.597060    
#> 454: 0.333391    1.149305    3.503841    0.253724    0.021982    0.027843    0.597017    
#> 455: 0.333475    1.149317    3.503869    0.253833    0.021967    0.027853    0.597027    
#> 456: 0.333435    1.149312    3.503887    0.253825    0.021973    0.027872    0.597002    
#> 457: 0.333399    1.149338    3.503895    0.253824    0.021994    0.027878    0.596960    
#> 458: 0.333410    1.149418    3.503911    0.253911    0.022008    0.027877    0.596917    
#> 459: 0.333278    1.149498    3.503853    0.253853    0.022017    0.027853    0.596925    
#> 460: 0.333059    1.149545    3.503775    0.253740    0.022050    0.027844    0.596954    
#> 461: 0.332953    1.149585    3.503757    0.253581    0.022069    0.027865    0.596902    
#> 462: 0.332853    1.149655    3.503765    0.253567    0.022069    0.027879    0.596871    
#> 463: 0.332895    1.149719    3.503790    0.253576    0.022065    0.027885    0.596864    
#> 464: 0.332934    1.149747    3.503778    0.253516    0.022044    0.027890    0.596816    
#> 465: 0.332862    1.149677    3.503803    0.253495    0.022037    0.027882    0.596804    
#> 466: 0.332973    1.149666    3.503809    0.253380    0.022047    0.027881    0.596848    
#> 467: 0.332959    1.149674    3.503872    0.253271    0.022042    0.027866    0.596790    
#> 468: 0.333156    1.149716    3.503957    0.253318    0.022035    0.027863    0.596822    
#> 469: 0.333224    1.149763    3.504009    0.253242    0.022026    0.027883    0.596925    
#> 470: 0.333257    1.149733    3.504022    0.253241    0.022010    0.027920    0.596888    
#> 471: 0.333220    1.149725    3.504027    0.253196    0.021998    0.027929    0.596875    
#> 472: 0.333184    1.149699    3.504022    0.253278    0.021995    0.027938    0.596849    
#> 473: 0.333199    1.149673    3.504051    0.253244    0.021987    0.027950    0.596790    
#> 474: 0.333250    1.149659    3.504048    0.253275    0.021989    0.027962    0.596789    
#> 475: 0.333309    1.149701    3.504069    0.253296    0.021989    0.027959    0.596772    
#> 476: 0.333321    1.149704    3.504048    0.253350    0.021987    0.027955    0.596788    
#> 477: 0.333285    1.149699    3.504091    0.253385    0.021972    0.027963    0.596742    
#> 478: 0.333226    1.149687    3.504098    0.253454    0.021933    0.027966    0.596748    
#> 479: 0.333283    1.149689    3.504096    0.253490    0.021921    0.027961    0.596790    
#> 480: 0.333315    1.149728    3.504119    0.253567    0.021924    0.027968    0.596806    
#> 481: 0.333311    1.149695    3.504126    0.253718    0.021927    0.027981    0.596784    
#> 482: 0.333345    1.149705    3.504066    0.253882    0.021945    0.027962    0.596794    
#> 483: 0.333199    1.149745    3.504014    0.253841    0.021972    0.027939    0.596746    
#> 484: 0.333150    1.149718    3.504032    0.253676    0.021982    0.027927    0.596729    
#> 485: 0.333125    1.149769    3.504020    0.253602    0.021992    0.027921    0.596742    
#> 486: 0.333222    1.149816    3.504063    0.253577    0.021987    0.027906    0.596727    
#> 487: 0.333479    1.149858    3.504125    0.253532    0.021975    0.027895    0.596801    
#> 488: 0.333495    1.149830    3.504146    0.253607    0.021967    0.027875    0.596780    
#> 489: 0.333686    1.149788    3.504183    0.253657    0.021970    0.027857    0.596816    
#> 490: 0.333817    1.149845    3.504208    0.253624    0.021973    0.027840    0.596841    
#> 491: 0.333853    1.149891    3.504221    0.253719    0.021969    0.027839    0.596834    
#> 492: 0.333732    1.149962    3.504181    0.253766    0.021963    0.027828    0.596901    
#> 493: 0.333602    1.149988    3.504195    0.253767    0.021972    0.027820    0.596949    
#> 494: 0.333565    1.150091    3.504163    0.253714    0.021997    0.027821    0.596913    
#> 495: 0.333562    1.150152    3.504163    0.253640    0.021996    0.027813    0.596897    
#> 496: 0.333705    1.150218    3.504154    0.253518    0.021979    0.027798    0.596924    
#> 497: 0.333733    1.150213    3.504183    0.253409    0.021983    0.027783    0.597020    
#> 498: 0.333752    1.150190    3.504213    0.253438    0.022000    0.027770    0.596978    
#> 499: 0.333721    1.150233    3.504189    0.253380    0.022025    0.027751    0.596924    
#> 500: 0.333703    1.150195    3.504161    0.253321    0.022032    0.027737    0.596916    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.235843    0.972594    3.444847    0.392401    0.078661    0.016800    1.606536    
#> 002: 0.118500    0.985042    3.482615    0.372781    0.074728    0.016132    1.119928    
#> 003: 0.154311    0.966974    3.488770    0.354142    0.070992    0.021629    0.833438    
#> 004: 0.087538    0.992724    3.485690    0.336435    0.080445    0.020547    0.757348    
#> 005: 0.131168    1.008412    3.466835    0.319613    0.088709    0.020810    0.698059    
#> 006: 0.066322    1.030299    3.452602    0.303633    0.092625    0.022837    0.665463    
#> 007: 0.039188    1.045863    3.441275    0.288451    0.099311    0.029542    0.650493    
#> 008: 0.027739    1.052174    3.431974    0.274029    0.096253    0.030132    0.655988    
#> 009: 0.005290    1.036541    3.422018    0.260327    0.098163    0.031556    0.643123    
#> 010: -0.014776   1.052145    3.417750    0.247311    0.097146    0.037764    0.647745    
#> 011: -0.012615   1.069145    3.408346    0.234945    0.092289    0.035876    0.646351    
#> 012: 0.015776    1.069044    3.420567    0.223198    0.087675    0.034323    0.633570    
#> 013: -0.043029   1.052003    3.408971    0.212038    0.083291    0.040370    0.651942    
#> 014: 0.037025    1.057751    3.422760    0.201436    0.087804    0.038351    0.651036    
#> 015: 0.039041    1.069696    3.429166    0.191364    0.088971    0.036434    0.642793    
#> 016: 0.068389    1.063821    3.457254    0.181796    0.084522    0.036361    0.659506    
#> 017: 0.094202    1.056544    3.464320    0.172706    0.086342    0.034543    0.627850    
#> 018: 0.061203    1.065722    3.447333    0.164071    0.082025    0.032816    0.643393    
#> 019: -0.000641   1.051352    3.431673    0.155867    0.082319    0.031175    0.645068    
#> 020: 0.034369    1.048280    3.448213    0.148074    0.078203    0.040316    0.638291    
#> 021: 0.059037    1.039925    3.450525    0.154406    0.074292    0.038300    0.638941    
#> 022: 0.054989    1.071906    3.452599    0.173429    0.073400    0.041247    0.632383    
#> 023: 0.119020    1.043592    3.458523    0.164757    0.070491    0.039185    0.650406    
#> 024: 0.119313    1.061004    3.463281    0.158572    0.073808    0.037225    0.644018    
#> 025: 0.069745    1.042019    3.449264    0.158010    0.079005    0.036182    0.649919    
#> 026: 0.043952    1.073864    3.433999    0.152243    0.081951    0.046750    0.623828    
#> 027: 0.020724    1.091642    3.426091    0.144631    0.077854    0.045702    0.652125    
#> 028: 0.056162    1.070057    3.440722    0.142028    0.073961    0.043417    0.632089    
#> 029: 0.062292    1.067625    3.433071    0.134926    0.070263    0.041246    0.660431    
#> 030: 0.084145    1.065943    3.433712    0.128180    0.081146    0.039239    0.652913    
#> 031: 0.025440    1.054916    3.442090    0.126499    0.077751    0.041278    0.637461    
#> 032: 0.029095    1.051481    3.449566    0.122798    0.080784    0.043269    0.650588    
#> 033: 0.036695    1.050799    3.454162    0.141353    0.076744    0.041470    0.641477    
#> 034: 0.042336    1.061740    3.446270    0.176175    0.076839    0.044139    0.621288    
#> 035: 0.023618    1.032454    3.444708    0.167367    0.077000    0.041932    0.618489    
#> 036: 0.025569    1.054297    3.438448    0.158998    0.073150    0.039835    0.633717    
#> 037: 0.022780    1.054792    3.438329    0.160007    0.069493    0.037844    0.642599    
#> 038: 0.050406    1.073227    3.431594    0.152007    0.066018    0.042505    0.641928    
#> 039: 0.043946    1.054718    3.428901    0.199054    0.062717    0.046767    0.623824    
#> 040: 0.045137    1.051466    3.440940    0.191424    0.075923    0.045464    0.631247    
#> 041: 0.010942    1.045594    3.433138    0.195854    0.072127    0.043191    0.631468    
#> 042: 0.042579    1.062247    3.432640    0.186061    0.075355    0.041031    0.613700    
#> 043: 0.017604    1.071851    3.420328    0.176758    0.078919    0.038980    0.623236    
#> 044: 0.001131    1.074377    3.419757    0.169804    0.074973    0.038456    0.627073    
#> 045: -0.015384   1.095303    3.403827    0.174725    0.071224    0.040688    0.634756    
#> 046: -0.003116   1.080335    3.410680    0.165989    0.067663    0.038654    0.635888    
#> 047: 0.036860    1.078518    3.418543    0.167246    0.065801    0.038783    0.634179    
#> 048: 0.044502    1.068899    3.432757    0.191184    0.067634    0.044579    0.635521    
#> 049: 0.002294    1.070864    3.427630    0.181624    0.071270    0.042350    0.639251    
#> 050: 0.068267    1.030484    3.454956    0.172543    0.067706    0.044081    0.652886    
#> 051: 0.052537    1.050445    3.438860    0.163916    0.064321    0.041877    0.638386    
#> 052: 0.059953    1.053472    3.448825    0.155720    0.073069    0.039784    0.621467    
#> 053: 0.070348    1.048859    3.443156    0.171054    0.081941    0.037794    0.625034    
#> 054: 0.035461    1.035760    3.439283    0.162502    0.095397    0.035905    0.652994    
#> 055: 0.018213    1.049516    3.444200    0.154376    0.093269    0.034109    0.668040    
#> 056: 0.060277    1.041845    3.450590    0.146658    0.097668    0.032404    0.659323    
#> 057: 0.088214    1.035603    3.460938    0.140334    0.092784    0.032482    0.659082    
#> 058: 0.066666    1.029304    3.458291    0.133317    0.088145    0.032235    0.662838    
#> 059: 0.086448    1.004304    3.464845    0.153155    0.083738    0.039998    0.653763    
#> 060: 0.080391    0.996524    3.464023    0.174429    0.079551    0.037998    0.662678    
#> 061: 0.097738    1.040266    3.467416    0.181678    0.086488    0.040304    0.666988    
#> 062: 0.101061    1.072917    3.464893    0.172594    0.082163    0.039672    0.671526    
#> 063: 0.133164    1.031313    3.461674    0.163965    0.078055    0.037689    0.654439    
#> 064: 0.049452    1.052745    3.444098    0.155767    0.084515    0.035804    0.629967    
#> 065: 0.050307    1.050832    3.422870    0.147978    0.085242    0.034014    0.646909    
#> 066: 0.035219    1.079574    3.428628    0.140579    0.080979    0.032313    0.630953    
#> 067: 0.023969    1.060333    3.427026    0.138151    0.077483    0.031660    0.625763    
#> 068: -0.012206   1.066221    3.434953    0.141822    0.080963    0.033682    0.670323    
#> 069: 0.011689    1.085555    3.420515    0.134731    0.089132    0.036915    0.669648    
#> 070: 0.018252    1.074229    3.432588    0.127995    0.088804    0.040672    0.662334    
#> 071: 0.008168    1.086004    3.412933    0.121595    0.089464    0.038638    0.669388    
#> 072: -0.031333   1.066873    3.411374    0.119008    0.084991    0.036706    0.656959    
#> 073: 0.025663    1.085618    3.437017    0.113057    0.080742    0.035385    0.653763    
#> 074: 0.000032    1.046996    3.439097    0.107404    0.076704    0.033616    0.644228    
#> 075: 0.025596    1.044399    3.452388    0.120607    0.072869    0.034159    0.662488    
#> 076: 0.051545    1.061291    3.449917    0.122158    0.072975    0.034327    0.645155    
#> 077: 0.082463    1.030280    3.457049    0.116050    0.077622    0.037413    0.653873    
#> 078: 0.093608    1.037535    3.466484    0.120840    0.073741    0.037473    0.633589    
#> 079: 0.093660    1.055946    3.457011    0.158467    0.070054    0.037368    0.640514    
#> 080: 0.094134    1.049846    3.463291    0.150543    0.066551    0.040365    0.654401    
#> 081: 0.053496    1.053029    3.448454    0.143016    0.063224    0.038347    0.635664    
#> 082: 0.053074    1.038314    3.446425    0.135865    0.061276    0.037250    0.631545    
#> 083: 0.049634    1.060298    3.445421    0.150267    0.068711    0.041816    0.621538    
#> 084: 0.044946    1.059350    3.435152    0.152272    0.067621    0.039725    0.625384    
#> 085: 0.050006    1.065748    3.450204    0.158556    0.078685    0.037739    0.637499    
#> 086: 0.021111    1.058887    3.425699    0.159779    0.074751    0.038522    0.619373    
#> 087: 0.018888    1.060251    3.420911    0.151790    0.071857    0.036596    0.636951    
#> 088: -0.042606   1.072466    3.419598    0.154679    0.080899    0.034766    0.654141    
#> 089: -0.039142   1.068810    3.403787    0.146945    0.077447    0.033028    0.639805    
#> 090: -0.053955   1.069566    3.399986    0.139598    0.073575    0.032329    0.652480    
#> 091: -0.019791   1.053209    3.396624    0.147692    0.074388    0.035060    0.644128    
#> 092: -0.032736   1.085330    3.394997    0.143587    0.078645    0.037700    0.650653    
#> 093: -0.049667   1.064727    3.414261    0.152866    0.074712    0.041209    0.664950    
#> 094: -0.015444   1.076909    3.406832    0.145223    0.070977    0.041354    0.666240    
#> 095: -0.000834   1.062384    3.424655    0.172756    0.074134    0.039287    0.658019    
#> 096: -0.017279   1.070336    3.415307    0.181261    0.081928    0.042954    0.642683    
#> 097: 0.021518    1.078295    3.416827    0.172198    0.077832    0.041466    0.630193    
#> 098: 0.007371    1.084189    3.427905    0.163588    0.073940    0.041278    0.633268    
#> 099: -0.008568   1.070177    3.409717    0.155409    0.070243    0.039214    0.631784    
#> 100: -0.022569   1.077204    3.419635    0.147638    0.068986    0.039362    0.641380    
#> 101: -0.027078   1.062120    3.405857    0.151295    0.065536    0.040563    0.641927    
#> 102: -0.009710   1.061604    3.408643    0.143730    0.067759    0.038535    0.652315    
#> 103: 0.010907    1.059181    3.425812    0.137379    0.064371    0.036608    0.650280    
#> 104: 0.008208    1.071727    3.435252    0.167443    0.061152    0.043222    0.648651    
#> 105: 0.060883    1.068059    3.441142    0.184168    0.069475    0.042976    0.637868    
#> 106: 0.054226    1.046074    3.439673    0.174959    0.066001    0.042988    0.642993    
#> 107: 0.055733    1.064894    3.442689    0.166212    0.069936    0.040839    0.640715    
#> 108: 0.045640    1.056988    3.461633    0.157901    0.081626    0.038797    0.676906    
#> 109: 0.037255    1.061912    3.450531    0.150006    0.079291    0.036857    0.667932    
#> 110: 0.032865    1.042422    3.434877    0.142506    0.075838    0.035014    0.642665    
#> 111: 0.047169    1.052723    3.442217    0.155115    0.082206    0.033263    0.630448    
#> 112: 0.022262    1.033929    3.426077    0.147359    0.078095    0.037712    0.647680    
#> 113: 0.035823    1.069009    3.436947    0.150514    0.074191    0.044175    0.637961    
#> 114: 0.041878    1.061303    3.443247    0.142988    0.070481    0.041966    0.653492    
#> 115: 0.051034    1.030512    3.443006    0.148920    0.074364    0.039868    0.659546    
#> 116: 0.035377    1.034282    3.437827    0.164542    0.074768    0.038621    0.639723    
#> 117: 0.027688    1.062707    3.442572    0.156315    0.073164    0.044627    0.635480    
#> 118: 0.048193    1.047711    3.449890    0.170603    0.074405    0.045434    0.633668    
#> 119: 0.068313    1.029690    3.457724    0.162073    0.070685    0.047328    0.643024    
#> 120: 0.051856    1.031101    3.453870    0.153969    0.067151    0.044961    0.636158    
#> 121: 0.053132    1.064823    3.447740    0.174382    0.068862    0.044260    0.645519    
#> 122: 0.069444    1.029999    3.458056    0.165663    0.071967    0.042047    0.653309    
#> 123: 0.093608    1.039925    3.446384    0.157380    0.075569    0.039945    0.654593    
#> 124: 0.094325    1.053056    3.455844    0.149511    0.075653    0.039518    0.645347    
#> 125: 0.105069    1.035709    3.452734    0.165355    0.071871    0.042340    0.653628    
#> 126: 0.056817    1.074421    3.442629    0.178287    0.068277    0.043178    0.642860    
#> 127: 0.055796    1.072529    3.424446    0.195605    0.081014    0.041019    0.633366    
#> 128: 0.008356    1.074560    3.430763    0.185825    0.076963    0.038968    0.649061    
#> 129: 0.010199    1.071988    3.438470    0.176533    0.076069    0.038716    0.644579    
#> 130: 0.072312    1.074052    3.431327    0.167707    0.072266    0.039646    0.632894    
#> 131: 0.042702    1.049372    3.433747    0.159321    0.068652    0.037730    0.652750    
#> 132: 0.007206    1.037783    3.415471    0.154121    0.067323    0.035844    0.653167    
#> 133: 0.013492    1.058035    3.427232    0.146415    0.084826    0.035051    0.646095    
#> 134: 0.069733    1.047659    3.452075    0.139094    0.080584    0.033298    0.658177    
#> 135: 0.055710    1.028836    3.459928    0.132139    0.076555    0.034744    0.641443    
#> 136: 0.065095    1.039830    3.452490    0.133492    0.079781    0.033007    0.629834    
#> 137: 0.107484    1.023339    3.466172    0.145732    0.076221    0.033967    0.645436    
#> 138: 0.088211    1.040866    3.460634    0.138445    0.074586    0.032269    0.639887    
#> 139: 0.057602    1.062104    3.461233    0.150642    0.070856    0.035253    0.641080    
#> 140: 0.061758    1.066642    3.449496    0.143110    0.073355    0.041490    0.648703    
#> 141: 0.044403    1.040593    3.444034    0.135955    0.075862    0.039415    0.655231    
#> 142: 0.079115    1.042868    3.469677    0.129157    0.075110    0.037444    0.667130    
#> 143: 0.056930    1.058622    3.455222    0.125522    0.071355    0.041734    0.664830    
#> 144: 0.098950    1.046045    3.462750    0.144852    0.068095    0.039648    0.655510    
#> 145: 0.046483    1.053373    3.442916    0.139824    0.066580    0.038597    0.627896    
#> 146: 0.047163    1.067638    3.449751    0.144207    0.077103    0.036667    0.633851    
#> 147: 0.003133    1.058593    3.423955    0.137479    0.080236    0.036334    0.630552    
#> 148: 0.003627    1.066079    3.432682    0.144072    0.080499    0.034517    0.643901    
#> 149: 0.022228    1.067623    3.430008    0.136869    0.091658    0.032791    0.643268    
#> 150: 0.036935    1.071899    3.415217    0.149964    0.087075    0.031217    0.641755    
#> 151: 0.000897    1.081402    3.425374    0.142466    0.082721    0.033168    0.634868    
#> 152: -0.005763   1.067912    3.427591    0.130009    0.074951    0.032314    0.630012    
#> 153: 0.008739    1.073511    3.431731    0.124372    0.076140    0.028935    0.644129    
#> 154: 0.016139    1.081875    3.422063    0.121463    0.077185    0.031868    0.649871    
#> 155: 0.012517    1.065029    3.420462    0.114009    0.078253    0.026361    0.657184    
#> 156: 0.000017    1.079837    3.415411    0.113699    0.078954    0.021337    0.669895    
#> 157: -0.010055   1.074822    3.417145    0.109054    0.088493    0.020090    0.664867    
#> 158: 0.013090    1.084962    3.419420    0.098380    0.095921    0.022094    0.642903    
#> 159: -0.014192   1.072965    3.422543    0.122610    0.081673    0.021359    0.654056    
#> 160: 0.025120    1.036775    3.436901    0.105298    0.090506    0.020568    0.656824    
#> 161: 0.025677    1.060430    3.426074    0.111774    0.100284    0.024195    0.657277    
#> 162: 0.012250    1.063761    3.424967    0.103965    0.087021    0.024086    0.665500    
#> 163: 0.018351    1.054342    3.427408    0.101760    0.090944    0.025326    0.667647    
#> 164: 0.018403    1.060778    3.421552    0.094726    0.080899    0.023340    0.663247    
#> 165: 0.037504    1.067620    3.440761    0.112193    0.093621    0.028146    0.649974    
#> 166: 0.039568    1.098420    3.434597    0.117787    0.102473    0.029752    0.656782    
#> 167: 0.045725    1.074403    3.435136    0.149522    0.091842    0.023554    0.649868    
#> 168: 0.041816    1.086962    3.441446    0.138555    0.093709    0.022431    0.675771    
#> 169: -0.014601   1.116976    3.411758    0.128643    0.088749    0.020800    0.680269    
#> 170: -0.004056   1.078800    3.414582    0.128235    0.080541    0.023222    0.650658    
#> 171: -0.023255   1.087510    3.411626    0.132664    0.091402    0.024806    0.638618    
#> 172: -0.011208   1.089088    3.418444    0.106302    0.079281    0.025791    0.639347    
#> 173: -0.004486   1.102248    3.411693    0.120168    0.080297    0.024424    0.634183    
#> 174: -0.001708   1.069880    3.418951    0.134655    0.083850    0.023874    0.629274    
#> 175: 0.003556    1.081735    3.410799    0.112536    0.082520    0.023888    0.652819    
#> 176: 0.016912    1.100977    3.432396    0.132807    0.089248    0.024740    0.656287    
#> 177: 0.036881    1.078516    3.440025    0.116775    0.099314    0.025873    0.634662    
#> 178: 0.049206    1.041205    3.441188    0.143123    0.077299    0.029420    0.633530    
#> 179: 0.074215    1.063483    3.451434    0.148260    0.067170    0.035937    0.644635    
#> 180: 0.027180    1.048647    3.441828    0.160482    0.068123    0.032332    0.649917    
#> 181: 0.037848    1.043823    3.418965    0.177315    0.062061    0.029091    0.649921    
#> 182: 0.020885    1.052952    3.419467    0.173366    0.067577    0.033566    0.649631    
#> 183: 0.017034    1.079430    3.418834    0.158486    0.061179    0.032488    0.644327    
#> 184: 0.010783    1.049158    3.428890    0.137374    0.064902    0.033005    0.653354    
#> 185: -0.014283   1.069368    3.421282    0.137521    0.062907    0.031835    0.644757    
#> 186: 0.013981    1.080091    3.430597    0.139597    0.054196    0.039671    0.640069    
#> 187: 0.007537    1.071261    3.426576    0.132631    0.069587    0.038209    0.638593    
#> 188: -0.011473   1.095107    3.417484    0.122711    0.068684    0.034558    0.656676    
#> 189: 0.011221    1.086261    3.424305    0.146450    0.070036    0.036774    0.654836    
#> 190: 0.015221    1.076485    3.436098    0.148780    0.069340    0.033581    0.635078    
#> 191: 0.011197    1.080889    3.418717    0.163471    0.072178    0.030102    0.634299    
#> 192: 0.034807    1.082939    3.433170    0.135444    0.082476    0.032105    0.627755    
#> 193: 0.067694    1.085579    3.438458    0.143782    0.077161    0.030249    0.640305    
#> 194: 0.010937    1.064908    3.428209    0.148671    0.092125    0.031664    0.639894    
#> 195: -0.016670   1.086937    3.409352    0.163741    0.079039    0.021899    0.636953    
#> 196: 0.002335    1.078167    3.412516    0.144480    0.077825    0.025777    0.636836    
#> 197: -0.018433   1.097262    3.426972    0.149840    0.085262    0.027107    0.661207    
#> 198: 0.043886    1.070623    3.434459    0.148654    0.086365    0.024626    0.639016    
#> 199: 0.025519    1.070334    3.435304    0.159381    0.087016    0.028589    0.626443    
#> 200: 0.034203    1.055660    3.441658    0.127506    0.085778    0.028122    0.655414    
#> 201: 0.039286    1.043427    3.447168    0.124479    0.084598    0.030795    0.656617    
#> 202: 0.048875    1.046467    3.447818    0.127434    0.080361    0.032574    0.651687    
#> 203: 0.058407    1.042818    3.447941    0.127179    0.078488    0.031804    0.652820    
#> 204: 0.063859    1.040119    3.450711    0.129046    0.079030    0.031662    0.648813    
#> 205: 0.060192    1.044127    3.449662    0.127666    0.080079    0.031502    0.648780    
#> 206: 0.057419    1.048554    3.448719    0.128358    0.081125    0.031860    0.651407    
#> 207: 0.052000    1.050789    3.445326    0.129428    0.081825    0.031630    0.652407    
#> 208: 0.048210    1.052006    3.444253    0.127553    0.079490    0.031519    0.652191    
#> 209: 0.047311    1.050565    3.442591    0.124578    0.077608    0.032073    0.651568    
#> 210: 0.047787    1.049474    3.442312    0.124686    0.076834    0.032657    0.649992    
#> 211: 0.049301    1.049377    3.443357    0.123639    0.075510    0.033348    0.648461    
#> 212: 0.051258    1.048823    3.444196    0.124893    0.074837    0.033633    0.647745    
#> 213: 0.052645    1.047581    3.445198    0.125712    0.074722    0.034101    0.648038    
#> 214: 0.055428    1.047191    3.446666    0.125654    0.074915    0.034530    0.647552    
#> 215: 0.056401    1.046892    3.447323    0.125941    0.074868    0.034822    0.647170    
#> 216: 0.058217    1.045671    3.447903    0.126518    0.074944    0.035134    0.647715    
#> 217: 0.059520    1.045858    3.448705    0.127825    0.074959    0.035368    0.646511    
#> 218: 0.060606    1.045825    3.449178    0.126856    0.074968    0.035378    0.646058    
#> 219: 0.061158    1.044960    3.449290    0.126024    0.074867    0.035644    0.646087    
#> 220: 0.060854    1.045083    3.449213    0.124619    0.074554    0.035735    0.646478    
#> 221: 0.060438    1.045642    3.449133    0.124466    0.074060    0.035801    0.646103    
#> 222: 0.059833    1.046296    3.448579    0.123801    0.073681    0.035898    0.646756    
#> 223: 0.060362    1.046339    3.448315    0.123510    0.073433    0.035902    0.646591    
#> 224: 0.060496    1.047124    3.448008    0.122889    0.073101    0.036075    0.646661    
#> 225: 0.060212    1.046161    3.448181    0.123192    0.073068    0.036470    0.646633    
#> 226: 0.059783    1.045634    3.447872    0.124478    0.072588    0.036482    0.646482    
#> 227: 0.058424    1.045669    3.447469    0.125383    0.072251    0.036892    0.645786    
#> 228: 0.056717    1.046582    3.446468    0.126397    0.072272    0.037072    0.645092    
#> 229: 0.055697    1.047112    3.445874    0.127495    0.072208    0.037217    0.644720    
#> 230: 0.055497    1.047476    3.445488    0.127851    0.071969    0.037294    0.644662    
#> 231: 0.054794    1.048089    3.445326    0.127481    0.071717    0.037235    0.644625    
#> 232: 0.053282    1.047748    3.445047    0.127561    0.071436    0.037169    0.644617    
#> 233: 0.052379    1.047160    3.445010    0.128568    0.071357    0.037184    0.644341    
#> 234: 0.051924    1.046776    3.444900    0.129187    0.071396    0.037335    0.644301    
#> 235: 0.051755    1.046352    3.445065    0.128989    0.071444    0.037373    0.645367    
#> 236: 0.052040    1.046635    3.445031    0.128788    0.071536    0.037359    0.646068    
#> 237: 0.052777    1.046571    3.445266    0.129029    0.071791    0.037570    0.646588    
#> 238: 0.053949    1.046654    3.445702    0.129383    0.071999    0.037823    0.647191    
#> 239: 0.054641    1.047458    3.445699    0.129517    0.072143    0.037846    0.646941    
#> 240: 0.055364    1.047490    3.446048    0.129571    0.072250    0.037922    0.646621    
#> 241: 0.056075    1.046966    3.446414    0.129456    0.071845    0.038119    0.646874    
#> 242: 0.055470    1.046787    3.446185    0.129279    0.072040    0.038150    0.647058    
#> 243: 0.053885    1.047903    3.445528    0.129417    0.072320    0.038157    0.647301    
#> 244: 0.052614    1.048432    3.445407    0.129102    0.072373    0.038116    0.647656    
#> 245: 0.052334    1.048173    3.445274    0.128748    0.072276    0.038196    0.648116    
#> 246: 0.051912    1.048416    3.445035    0.128419    0.071983    0.038395    0.648332    
#> 247: 0.051859    1.048404    3.445189    0.128373    0.072048    0.038397    0.648276    
#> 248: 0.051955    1.048744    3.445181    0.128493    0.072190    0.038461    0.648054    
#> 249: 0.052025    1.048707    3.445395    0.128576    0.072095    0.038599    0.648059    
#> 250: 0.052247    1.048949    3.445483    0.128601    0.072064    0.038682    0.648037    
#> 251: 0.052787    1.049427    3.445550    0.129064    0.071928    0.038734    0.647877    
#> 252: 0.053434    1.049771    3.445824    0.129403    0.072027    0.038878    0.647692    
#> 253: 0.053591    1.049797    3.445858    0.129719    0.072042    0.038871    0.647849    
#> 254: 0.053659    1.050209    3.445699    0.129726    0.072118    0.038853    0.647721    
#> 255: 0.053149    1.050670    3.445522    0.129644    0.072383    0.038857    0.647500    
#> 256: 0.052533    1.050977    3.445175    0.129972    0.072600    0.038856    0.647223    
#> 257: 0.051541    1.051241    3.444836    0.130153    0.072637    0.038922    0.646993    
#> 258: 0.051117    1.051077    3.444770    0.130426    0.072647    0.038928    0.647073    
#> 259: 0.050861    1.050959    3.444728    0.130685    0.072637    0.038908    0.647174    
#> 260: 0.050512    1.051246    3.444753    0.130369    0.072684    0.038890    0.647093    
#> 261: 0.050473    1.051072    3.444844    0.130299    0.072548    0.038788    0.647353    
#> 262: 0.050947    1.051145    3.444993    0.130583    0.072532    0.038867    0.647391    
#> 263: 0.050821    1.051417    3.445051    0.131296    0.072509    0.038959    0.647406    
#> 264: 0.050499    1.051198    3.445149    0.131700    0.072871    0.038906    0.647656    
#> 265: 0.050709    1.051146    3.445093    0.132133    0.073244    0.038934    0.647902    
#> 266: 0.051064    1.051276    3.445081    0.132732    0.073390    0.038978    0.648036    
#> 267: 0.050980    1.051338    3.445189    0.133143    0.073482    0.039097    0.647784    
#> 268: 0.050814    1.051194    3.445119    0.133393    0.073634    0.039111    0.647454    
#> 269: 0.051325    1.051138    3.445265    0.133421    0.073622    0.039121    0.647476    
#> 270: 0.052014    1.050991    3.445293    0.133256    0.073643    0.039027    0.647458    
#> 271: 0.052024    1.051045    3.445131    0.133454    0.073821    0.038876    0.647652    
#> 272: 0.051868    1.050951    3.444937    0.133713    0.073845    0.038791    0.647909    
#> 273: 0.051670    1.051110    3.445025    0.133952    0.073992    0.038722    0.648079    
#> 274: 0.051466    1.051329    3.445019    0.133896    0.074157    0.038623    0.648084    
#> 275: 0.051525    1.051321    3.444953    0.133774    0.074242    0.038612    0.648130    
#> 276: 0.051483    1.051472    3.445037    0.133926    0.074156    0.038625    0.648053    
#> 277: 0.051551    1.051758    3.445185    0.133788    0.074132    0.038622    0.647950    
#> 278: 0.051691    1.051613    3.445342    0.133550    0.074083    0.038648    0.647901    
#> 279: 0.051783    1.051438    3.445471    0.133400    0.074362    0.038692    0.648088    
#> 280: 0.051994    1.051197    3.445570    0.133438    0.074439    0.038749    0.647992    
#> 281: 0.051909    1.051244    3.445513    0.133675    0.074422    0.038770    0.647903    
#> 282: 0.051773    1.051405    3.445570    0.133745    0.074347    0.038771    0.648030    
#> 283: 0.051832    1.051526    3.445553    0.134122    0.074222    0.038825    0.648060    
#> 284: 0.051765    1.051349    3.445561    0.134326    0.074019    0.038878    0.648033    
#> 285: 0.051858    1.051449    3.445489    0.134282    0.073842    0.038982    0.648109    
#> 286: 0.051638    1.051509    3.445285    0.134155    0.073719    0.039012    0.648082    
#> 287: 0.051441    1.051594    3.445156    0.134158    0.073837    0.039076    0.648097    
#> 288: 0.051456    1.051293    3.445307    0.134072    0.073651    0.039226    0.648309    
#> 289: 0.051453    1.051261    3.445321    0.134201    0.073611    0.039262    0.648420    
#> 290: 0.051596    1.051188    3.445404    0.134324    0.073791    0.039226    0.648508    
#> 291: 0.051732    1.051336    3.445528    0.134541    0.073846    0.039174    0.648232    
#> 292: 0.051824    1.051310    3.445572    0.134898    0.073809    0.039164    0.648105    
#> 293: 0.051707    1.051343    3.445498    0.134955    0.073814    0.039101    0.647907    
#> 294: 0.051308    1.051401    3.445375    0.134979    0.073712    0.039041    0.647783    
#> 295: 0.050930    1.051343    3.445219    0.134799    0.073654    0.038965    0.647565    
#> 296: 0.050694    1.051209    3.445085    0.134681    0.073663    0.038885    0.647620    
#> 297: 0.050429    1.051341    3.444998    0.134633    0.073719    0.038745    0.647676    
#> 298: 0.050559    1.051383    3.444899    0.134547    0.073787    0.038638    0.647654    
#> 299: 0.050416    1.051501    3.444873    0.134440    0.073717    0.038612    0.647495    
#> 300: 0.050513    1.051417    3.445024    0.134469    0.073681    0.038582    0.647413    
#> 301: 0.050766    1.051368    3.445049    0.134433    0.073676    0.038518    0.647571    
#> 302: 0.051008    1.051446    3.444996    0.134317    0.073640    0.038460    0.647462    
#> 303: 0.050912    1.051671    3.444875    0.134169    0.073708    0.038405    0.647428    
#> 304: 0.050972    1.051992    3.444762    0.134366    0.073804    0.038345    0.647455    
#> 305: 0.050874    1.051796    3.444680    0.134437    0.073681    0.038299    0.647500    
#> 306: 0.050595    1.051641    3.444631    0.134451    0.073639    0.038305    0.647522    
#> 307: 0.050409    1.051604    3.444531    0.134738    0.073621    0.038355    0.647440    
#> 308: 0.049877    1.051542    3.444404    0.134818    0.073611    0.038322    0.647441    
#> 309: 0.049699    1.051328    3.444359    0.134839    0.073657    0.038312    0.647431    
#> 310: 0.049659    1.051263    3.444219    0.134610    0.073630    0.038218    0.647490    
#> 311: 0.049483    1.051274    3.444209    0.134701    0.073552    0.038198    0.647338    
#> 312: 0.049262    1.051236    3.444118    0.134806    0.073418    0.038259    0.647177    
#> 313: 0.048966    1.051169    3.443973    0.134896    0.073333    0.038307    0.647377    
#> 314: 0.048570    1.051337    3.443787    0.134869    0.073322    0.038328    0.647456    
#> 315: 0.048194    1.051565    3.443590    0.134747    0.073316    0.038315    0.647608    
#> 316: 0.047801    1.051854    3.443293    0.134677    0.073473    0.038218    0.647668    
#> 317: 0.047454    1.052196    3.443156    0.134609    0.073648    0.038188    0.647828    
#> 318: 0.047107    1.052507    3.443011    0.134436    0.073871    0.038160    0.647880    
#> 319: 0.046993    1.052617    3.442990    0.134209    0.074011    0.038143    0.647952    
#> 320: 0.046651    1.052673    3.442976    0.134002    0.074176    0.038103    0.647941    
#> 321: 0.046314    1.052766    3.442837    0.133993    0.074193    0.038061    0.647973    
#> 322: 0.046103    1.052809    3.442752    0.133828    0.074262    0.037985    0.648079    
#> 323: 0.045616    1.052858    3.442700    0.133705    0.074247    0.037934    0.648206    
#> 324: 0.045554    1.053016    3.442721    0.133654    0.074326    0.037905    0.648084    
#> 325: 0.045392    1.053139    3.442577    0.133464    0.074379    0.037875    0.647919    
#> 326: 0.045165    1.053094    3.442499    0.133336    0.074251    0.037906    0.647853    
#> 327: 0.045244    1.053036    3.442592    0.133018    0.074193    0.037942    0.647881    
#> 328: 0.045269    1.053179    3.442591    0.132762    0.074266    0.037947    0.647866    
#> 329: 0.045337    1.053296    3.442614    0.132603    0.074261    0.037906    0.647869    
#> 330: 0.045273    1.053271    3.442670    0.132597    0.074253    0.037869    0.647756    
#> 331: 0.045435    1.053357    3.442707    0.132632    0.074255    0.037870    0.647665    
#> 332: 0.045505    1.053327    3.442734    0.132530    0.074252    0.037811    0.647641    
#> 333: 0.045324    1.053362    3.442697    0.132571    0.074184    0.037800    0.647589    
#> 334: 0.045116    1.053375    3.442583    0.132467    0.074169    0.037857    0.647515    
#> 335: 0.044846    1.053346    3.442438    0.132457    0.074077    0.037877    0.647326    
#> 336: 0.044312    1.053533    3.442213    0.132446    0.073970    0.037882    0.647350    
#> 337: 0.044130    1.053910    3.442016    0.132435    0.073948    0.037908    0.647384    
#> 338: 0.043946    1.054055    3.441989    0.132407    0.073874    0.037948    0.647346    
#> 339: 0.043660    1.054229    3.441787    0.132456    0.073902    0.037991    0.647293    
#> 340: 0.043407    1.054114    3.441728    0.132647    0.073968    0.038002    0.647293    
#> 341: 0.043593    1.054111    3.441795    0.132782    0.073958    0.038036    0.647246    
#> 342: 0.043467    1.053940    3.441763    0.132958    0.073950    0.038002    0.647254    
#> 343: 0.043249    1.053936    3.441765    0.132910    0.073897    0.037983    0.647288    
#> 344: 0.043335    1.054009    3.441782    0.132966    0.073943    0.037945    0.647286    
#> 345: 0.043340    1.054085    3.441733    0.132932    0.074030    0.037914    0.647238    
#> 346: 0.043255    1.054148    3.441613    0.133005    0.073955    0.037899    0.647221    
#> 347: 0.043255    1.054266    3.441505    0.133088    0.073873    0.037889    0.647290    
#> 348: 0.042928    1.054374    3.441393    0.133160    0.073890    0.037861    0.647366    
#> 349: 0.042840    1.054282    3.441410    0.133145    0.073901    0.037828    0.647381    
#> 350: 0.042772    1.054229    3.441443    0.133085    0.073888    0.037814    0.647466    
#> 351: 0.042799    1.054263    3.441483    0.132790    0.073976    0.037820    0.647503    
#> 352: 0.042723    1.054261    3.441518    0.132632    0.073964    0.037843    0.647603    
#> 353: 0.042800    1.054368    3.441481    0.132571    0.073979    0.037888    0.647714    
#> 354: 0.042872    1.054366    3.441454    0.132639    0.073932    0.037931    0.647680    
#> 355: 0.043058    1.054228    3.441456    0.132607    0.073921    0.037898    0.647617    
#> 356: 0.043123    1.054101    3.441483    0.132745    0.074034    0.037845    0.647721    
#> 357: 0.043206    1.054071    3.441425    0.132880    0.074085    0.037792    0.647733    
#> 358: 0.043118    1.054191    3.441346    0.132921    0.074048    0.037807    0.647611    
#> 359: 0.042944    1.054426    3.441241    0.132907    0.074034    0.037811    0.647536    
#> 360: 0.042617    1.054524    3.441019    0.132914    0.073952    0.037814    0.647435    
#> 361: 0.042405    1.054540    3.440897    0.132880    0.073921    0.037781    0.647493    
#> 362: 0.042325    1.054586    3.440770    0.132798    0.073892    0.037739    0.647469    
#> 363: 0.042180    1.054539    3.440706    0.132711    0.073963    0.037711    0.647344    
#> 364: 0.042070    1.054744    3.440599    0.132651    0.074029    0.037662    0.647370    
#> 365: 0.041833    1.054816    3.440522    0.132650    0.074049    0.037659    0.647432    
#> 366: 0.041660    1.054928    3.440375    0.132717    0.074064    0.037614    0.647417    
#> 367: 0.041479    1.055095    3.440275    0.132707    0.074061    0.037577    0.647344    
#> 368: 0.041477    1.055247    3.440229    0.132734    0.074044    0.037571    0.647251    
#> 369: 0.041406    1.055242    3.440150    0.132773    0.073976    0.037579    0.647205    
#> 370: 0.041224    1.055271    3.440063    0.132765    0.073907    0.037594    0.647293    
#> 371: 0.041151    1.055329    3.440000    0.132693    0.073838    0.037593    0.647288    
#> 372: 0.041165    1.055475    3.439918    0.132718    0.073818    0.037599    0.647259    
#> 373: 0.040993    1.055710    3.439798    0.132826    0.073814    0.037590    0.647308    
#> 374: 0.040906    1.055738    3.439732    0.132827    0.073812    0.037569    0.647353    
#> 375: 0.040796    1.055781    3.439730    0.132786    0.073742    0.037568    0.647463    
#> 376: 0.040766    1.055788    3.439743    0.132719    0.073732    0.037557    0.647341    
#> 377: 0.040657    1.055873    3.439688    0.132708    0.073784    0.037541    0.647298    
#> 378: 0.040439    1.055938    3.439599    0.132765    0.073804    0.037520    0.647303    
#> 379: 0.040189    1.055837    3.439524    0.132969    0.073709    0.037526    0.647294    
#> 380: 0.039913    1.055884    3.439491    0.132878    0.073726    0.037561    0.647172    
#> 381: 0.039593    1.055900    3.439376    0.132879    0.073728    0.037583    0.647158    
#> 382: 0.039302    1.056001    3.439237    0.132946    0.073719    0.037563    0.647063    
#> 383: 0.039237    1.056097    3.439133    0.133064    0.073731    0.037550    0.647001    
#> 384: 0.038965    1.056187    3.439047    0.133158    0.073803    0.037566    0.646957    
#> 385: 0.038978    1.056263    3.439006    0.133198    0.073842    0.037569    0.646872    
#> 386: 0.038927    1.056349    3.438978    0.133273    0.073851    0.037546    0.646844    
#> 387: 0.039018    1.056418    3.439001    0.133360    0.073869    0.037507    0.646782    
#> 388: 0.038994    1.056348    3.438993    0.133467    0.073898    0.037481    0.646697    
#> 389: 0.038783    1.056231    3.438916    0.133414    0.073925    0.037416    0.646865    
#> 390: 0.038680    1.056335    3.438809    0.133532    0.073975    0.037377    0.646931    
#> 391: 0.038656    1.056363    3.438788    0.133588    0.074029    0.037364    0.646993    
#> 392: 0.038847    1.056344    3.438907    0.133578    0.074078    0.037357    0.647053    
#> 393: 0.038917    1.056268    3.438927    0.133588    0.074169    0.037327    0.647073    
#> 394: 0.038946    1.056250    3.438911    0.133483    0.074185    0.037263    0.647110    
#> 395: 0.039052    1.056358    3.438907    0.133457    0.074246    0.037209    0.647203    
#> 396: 0.039289    1.056376    3.438965    0.133483    0.074316    0.037184    0.647252    
#> 397: 0.039439    1.056311    3.439018    0.133659    0.074367    0.037156    0.647280    
#> 398: 0.039695    1.056156    3.439133    0.133709    0.074404    0.037133    0.647315    
#> 399: 0.040007    1.056068    3.439274    0.133856    0.074386    0.037130    0.647281    
#> 400: 0.040186    1.056063    3.439370    0.133942    0.074427    0.037139    0.647181    
#> 401: 0.040421    1.056038    3.439490    0.134116    0.074394    0.037181    0.647118    
#> 402: 0.040709    1.056051    3.439552    0.134322    0.074399    0.037213    0.647068    
#> 403: 0.041112    1.055988    3.439635    0.134399    0.074415    0.037215    0.647048    
#> 404: 0.041197    1.055988    3.439640    0.134462    0.074421    0.037218    0.646925    
#> 405: 0.041305    1.055972    3.439669    0.134502    0.074358    0.037242    0.646857    
#> 406: 0.041359    1.055944    3.439651    0.134473    0.074373    0.037266    0.646838    
#> 407: 0.041362    1.056023    3.439646    0.134499    0.074371    0.037275    0.646812    
#> 408: 0.041397    1.056170    3.439620    0.134564    0.074459    0.037266    0.646866    
#> 409: 0.041250    1.056171    3.439600    0.134590    0.074480    0.037234    0.646866    
#> 410: 0.041217    1.056263    3.439544    0.134633    0.074490    0.037219    0.646878    
#> 411: 0.041337    1.056127    3.439557    0.134665    0.074518    0.037204    0.646878    
#> 412: 0.041381    1.056107    3.439569    0.134713    0.074566    0.037213    0.646874    
#> 413: 0.041457    1.056130    3.439556    0.134714    0.074584    0.037186    0.646899    
#> 414: 0.041394    1.056187    3.439547    0.134724    0.074647    0.037172    0.646850    
#> 415: 0.041430    1.056189    3.439517    0.134728    0.074703    0.037178    0.646863    
#> 416: 0.041553    1.056187    3.439540    0.134785    0.074755    0.037176    0.646900    
#> 417: 0.041669    1.056097    3.439600    0.134768    0.074785    0.037136    0.646911    
#> 418: 0.041590    1.056040    3.439652    0.134720    0.074816    0.037108    0.646879    
#> 419: 0.041604    1.056032    3.439633    0.134742    0.074819    0.037077    0.646833    
#> 420: 0.041586    1.056041    3.439623    0.134754    0.074838    0.037064    0.646800    
#> 421: 0.041480    1.056071    3.439691    0.134686    0.074877    0.037068    0.646834    
#> 422: 0.041513    1.055982    3.439704    0.134645    0.074827    0.037080    0.646843    
#> 423: 0.041604    1.055880    3.439734    0.134655    0.074863    0.037068    0.646834    
#> 424: 0.041479    1.055795    3.439737    0.134636    0.074799    0.037081    0.646814    
#> 425: 0.041594    1.055770    3.439767    0.134690    0.074711    0.037118    0.646829    
#> 426: 0.041676    1.055824    3.439760    0.134658    0.074653    0.037127    0.646772    
#> 427: 0.041613    1.055852    3.439750    0.134582    0.074618    0.037140    0.646709    
#> 428: 0.041515    1.055914    3.439718    0.134552    0.074661    0.037121    0.646734    
#> 429: 0.041368    1.056002    3.439675    0.134512    0.074685    0.037081    0.646760    
#> 430: 0.041233    1.056062    3.439630    0.134400    0.074711    0.037053    0.646814    
#> 431: 0.041142    1.056096    3.439596    0.134374    0.074731    0.037041    0.646765    
#> 432: 0.041078    1.056198    3.439564    0.134409    0.074747    0.037017    0.646752    
#> 433: 0.041055    1.056312    3.439547    0.134354    0.074756    0.037009    0.646694    
#> 434: 0.041022    1.056257    3.439523    0.134299    0.074761    0.037001    0.646644    
#> 435: 0.041103    1.056194    3.439569    0.134346    0.074756    0.036990    0.646595    
#> 436: 0.041071    1.056161    3.439617    0.134409    0.074739    0.036966    0.646613    
#> 437: 0.041183    1.055972    3.439718    0.134308    0.074784    0.036945    0.646670    
#> 438: 0.041154    1.056065    3.439709    0.134276    0.074773    0.036940    0.646658    
#> 439: 0.041293    1.056158    3.439743    0.134172    0.074736    0.036932    0.646726    
#> 440: 0.041183    1.056212    3.439766    0.134184    0.074721    0.036909    0.646701    
#> 441: 0.041186    1.056176    3.439817    0.134079    0.074695    0.036909    0.646651    
#> 442: 0.041114    1.056251    3.439767    0.134072    0.074691    0.036906    0.646570    
#> 443: 0.041019    1.056380    3.439658    0.134033    0.074636    0.036927    0.646550    
#> 444: 0.040854    1.056525    3.439518    0.134144    0.074581    0.036956    0.646515    
#> 445: 0.040670    1.056660    3.439419    0.134310    0.074524    0.037008    0.646457    
#> 446: 0.040437    1.056739    3.439328    0.134357    0.074409    0.037033    0.646430    
#> 447: 0.040281    1.056803    3.439237    0.134457    0.074330    0.037043    0.646414    
#> 448: 0.040116    1.056837    3.439196    0.134498    0.074294    0.037074    0.646363    
#> 449: 0.040131    1.056916    3.439209    0.134580    0.074261    0.037079    0.646363    
#> 450: 0.040135    1.056983    3.439161    0.134547    0.074260    0.037074    0.646367    
#> 451: 0.040075    1.057017    3.439108    0.134541    0.074289    0.037041    0.646410    
#> 452: 0.040020    1.057044    3.439091    0.134524    0.074336    0.037019    0.646405    
#> 453: 0.039974    1.057084    3.439045    0.134489    0.074371    0.037021    0.646350    
#> 454: 0.039856    1.057225    3.438972    0.134546    0.074335    0.037043    0.646272    
#> 455: 0.039824    1.057299    3.438910    0.134582    0.074321    0.037058    0.646192    
#> 456: 0.039702    1.057317    3.438865    0.134576    0.074314    0.037062    0.646161    
#> 457: 0.039619    1.057325    3.438885    0.134544    0.074342    0.037048    0.646088    
#> 458: 0.039565    1.057460    3.438893    0.134536    0.074364    0.037035    0.646037    
#> 459: 0.039413    1.057617    3.438823    0.134524    0.074447    0.036998    0.646037    
#> 460: 0.039178    1.057697    3.438709    0.134526    0.074477    0.036964    0.646017    
#> 461: 0.038997    1.057776    3.438628    0.134452    0.074527    0.036957    0.646024    
#> 462: 0.038880    1.057832    3.438598    0.134374    0.074504    0.036951    0.646051    
#> 463: 0.038774    1.057946    3.438578    0.134315    0.074516    0.036920    0.646107    
#> 464: 0.038771    1.057979    3.438547    0.134294    0.074509    0.036914    0.646095    
#> 465: 0.038701    1.057819    3.438558    0.134176    0.074520    0.036901    0.646153    
#> 466: 0.038703    1.057823    3.438508    0.134059    0.074566    0.036862    0.646187    
#> 467: 0.038626    1.057830    3.438520    0.133945    0.074545    0.036843    0.646146    
#> 468: 0.038706    1.057849    3.438558    0.133973    0.074521    0.036834    0.646152    
#> 469: 0.038709    1.057912    3.438586    0.133990    0.074503    0.036840    0.646147    
#> 470: 0.038706    1.057974    3.438591    0.133892    0.074444    0.036845    0.646094    
#> 471: 0.038614    1.057974    3.438567    0.133833    0.074396    0.036821    0.646095    
#> 472: 0.038569    1.057900    3.438546    0.133832    0.074355    0.036806    0.646109    
#> 473: 0.038505    1.057884    3.438522    0.133738    0.074348    0.036802    0.646070    
#> 474: 0.038539    1.057869    3.438557    0.133665    0.074334    0.036824    0.646076    
#> 475: 0.038565    1.057870    3.438582    0.133628    0.074312    0.036839    0.645993    
#> 476: 0.038653    1.057830    3.438599    0.133717    0.074238    0.036854    0.645967    
#> 477: 0.038713    1.057771    3.438675    0.133757    0.074162    0.036894    0.645840    
#> 478: 0.038646    1.057764    3.438694    0.133804    0.074079    0.036937    0.645788    
#> 479: 0.038660    1.057801    3.438666    0.133911    0.074032    0.036947    0.645766    
#> 480: 0.038680    1.057875    3.438639    0.133904    0.074003    0.036976    0.645799    
#> 481: 0.038694    1.057902    3.438651    0.133890    0.073942    0.036990    0.645786    
#> 482: 0.038720    1.057987    3.438607    0.133928    0.073933    0.036996    0.645850    
#> 483: 0.038674    1.057996    3.438607    0.134015    0.073924    0.036995    0.645812    
#> 484: 0.038719    1.057916    3.438643    0.133985    0.073940    0.037002    0.645863    
#> 485: 0.038788    1.057867    3.438678    0.134011    0.073940    0.037021    0.645902    
#> 486: 0.038837    1.057788    3.438727    0.134008    0.073898    0.037025    0.645896    
#> 487: 0.039077    1.057761    3.438835    0.133932    0.073869    0.037033    0.645888    
#> 488: 0.039195    1.057700    3.438924    0.133915    0.073861    0.037042    0.645876    
#> 489: 0.039382    1.057667    3.438958    0.133890    0.073873    0.037025    0.645860    
#> 490: 0.039477    1.057657    3.439026    0.133908    0.073854    0.037017    0.645868    
#> 491: 0.039522    1.057665    3.439103    0.133865    0.073805    0.037038    0.645845    
#> 492: 0.039597    1.057725    3.439112    0.133806    0.073777    0.037050    0.645864    
#> 493: 0.039642    1.057692    3.439200    0.133842    0.073740    0.037062    0.645840    
#> 494: 0.039832    1.057692    3.439239    0.133782    0.073713    0.037083    0.645838    
#> 495: 0.039969    1.057677    3.439290    0.133698    0.073711    0.037106    0.645814    
#> 496: 0.040141    1.057676    3.439294    0.133616    0.073704    0.037096    0.645904    
#> 497: 0.040257    1.057602    3.439375    0.133491    0.073733    0.037111    0.645952    
#> 498: 0.040359    1.057604    3.439371    0.133454    0.073702    0.037120    0.645935    
#> 499: 0.040344    1.057605    3.439371    0.133422    0.073714    0.037127    0.645883    
#> 500: 0.040389    1.057584    3.439354    0.133379    0.073720    0.037112    0.645865    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.329040    0.969690    3.435590    0.392401    0.076161    0.016800    1.793684    
#> 002: 0.460094    1.036324    3.463863    0.372781    0.072353    0.015960    1.160156    
#> 003: 0.663864    1.045281    3.461520    0.354142    0.068735    0.015162    0.838797    
#> 004: 0.642567    1.098679    3.474185    0.422279    0.065298    0.014404    0.713331    
#> 005: 0.724256    1.123942    3.473488    0.553322    0.062033    0.013684    0.664264    
#> 006: 0.734725    1.131361    3.474644    0.621594    0.058932    0.015361    0.611838    
#> 007: 0.705503    1.135283    3.478685    0.590514    0.058504    0.019628    0.618256    
#> 008: 0.718461    1.113281    3.476968    0.563747    0.055579    0.023848    0.623163    
#> 009: 0.698041    1.114701    3.474564    0.536058    0.052800    0.022655    0.608486    
#> 010: 0.740181    1.096422    3.485333    0.540099    0.050160    0.022020    0.612941    
#> 011: 0.813957    1.104579    3.498561    0.613467    0.048869    0.025404    0.622536    
#> 012: 0.755561    1.096891    3.492304    0.582793    0.046425    0.031228    0.610891    
#> 013: 0.763157    1.095792    3.485926    0.583473    0.044104    0.033573    0.621088    
#> 014: 0.771003    1.111156    3.490361    0.629098    0.041899    0.033392    0.619100    
#> 015: 0.805776    1.130931    3.493902    0.682912    0.039804    0.032926    0.596846    
#> 016: 0.830999    1.127034    3.503655    0.648766    0.037814    0.034685    0.610283    
#> 017: 0.857181    1.111387    3.513056    0.664131    0.035923    0.034424    0.594573    
#> 018: 0.834636    1.108970    3.496561    0.687933    0.034854    0.035808    0.597700    
#> 019: 0.812068    1.098685    3.494325    0.653536    0.034229    0.034017    0.603296    
#> 020: 0.864609    1.080600    3.508069    0.657860    0.032517    0.038219    0.613372    
#> 021: 0.808415    1.095595    3.511045    0.653728    0.032035    0.039527    0.599490    
#> 022: 0.824573    1.103923    3.512708    0.626267    0.030434    0.042740    0.608402    
#> 023: 0.883394    1.105399    3.524443    0.619425    0.032473    0.046489    0.614880    
#> 024: 0.837873    1.119641    3.515068    0.588454    0.032592    0.044165    0.611320    
#> 025: 0.827685    1.097110    3.506629    0.559031    0.030962    0.041957    0.613870    
#> 026: 0.819535    1.125627    3.494780    0.601690    0.029414    0.039859    0.604720    
#> 027: 0.800666    1.137823    3.495214    0.571606    0.028747    0.037866    0.616440    
#> 028: 0.848687    1.121871    3.499052    0.666654    0.030781    0.036612    0.617815    
#> 029: 0.832032    1.121432    3.503067    0.648806    0.034971    0.038227    0.610757    
#> 030: 0.800337    1.131107    3.491228    0.616366    0.033223    0.040962    0.613073    
#> 031: 0.792230    1.116465    3.510443    0.587869    0.033284    0.038914    0.599731    
#> 032: 0.795152    1.115532    3.504673    0.587672    0.034495    0.036969    0.597840    
#> 033: 0.825356    1.131026    3.504720    0.693152    0.038384    0.035120    0.606843    
#> 034: 0.865352    1.132049    3.503333    0.712500    0.036465    0.034853    0.597638    
#> 035: 0.805061    1.112032    3.496513    0.676875    0.034642    0.033110    0.583461    
#> 036: 0.783308    1.114539    3.492608    0.643032    0.032909    0.031454    0.615437    
#> 037: 0.783354    1.122098    3.500937    0.629366    0.031264    0.029882    0.615696    
#> 038: 0.858499    1.114161    3.495251    0.762676    0.035404    0.035017    0.618279    
#> 039: 0.841037    1.101980    3.500654    0.724542    0.035393    0.034883    0.614069    
#> 040: 0.789382    1.111253    3.504556    0.688315    0.033623    0.036215    0.609572    
#> 041: 0.792155    1.102706    3.501378    0.653899    0.031942    0.034478    0.604298    
#> 042: 0.849965    1.098652    3.505982    0.641620    0.030345    0.033968    0.595240    
#> 043: 0.804171    1.117883    3.500080    0.609539    0.028828    0.035495    0.593030    
#> 044: 0.816129    1.121743    3.495867    0.657867    0.029418    0.037572    0.588086    
#> 045: 0.817203    1.132335    3.491164    0.664170    0.027947    0.035693    0.589193    
#> 046: 0.808349    1.122567    3.502923    0.667159    0.026550    0.037618    0.595981    
#> 047: 0.892551    1.116809    3.510445    0.831447    0.025222    0.035737    0.591034    
#> 048: 0.890626    1.102184    3.503302    0.832845    0.026139    0.038767    0.602716    
#> 049: 0.908298    1.096756    3.518907    0.834096    0.024832    0.036828    0.612300    
#> 050: 0.921751    1.078967    3.523309    0.841657    0.026591    0.037361    0.613973    
#> 051: 0.931322    1.090846    3.517765    0.924570    0.025262    0.043380    0.608837    
#> 052: 0.942022    1.096242    3.527764    0.944862    0.025533    0.041211    0.612250    
#> 053: 0.932386    1.084025    3.516007    0.897619    0.029540    0.039150    0.612635    
#> 054: 0.884702    1.090681    3.511569    0.871191    0.039772    0.037193    0.609358    
#> 055: 0.846498    1.107590    3.506742    0.835685    0.039982    0.035333    0.608218    
#> 056: 0.858482    1.113326    3.507507    0.793900    0.044410    0.033566    0.607237    
#> 057: 0.839828    1.125724    3.510245    0.754205    0.042227    0.031888    0.612043    
#> 058: 0.816337    1.126914    3.490691    0.716495    0.041182    0.030294    0.605649    
#> 059: 0.826458    1.092596    3.508115    0.700975    0.039123    0.029892    0.601404    
#> 060: 0.841665    1.096333    3.498828    0.665926    0.039381    0.033154    0.605069    
#> 061: 0.865939    1.095825    3.515801    0.725909    0.039393    0.038500    0.613694    
#> 062: 0.823964    1.114477    3.512116    0.689614    0.044080    0.041363    0.607070    
#> 063: 0.852144    1.084417    3.513855    0.655133    0.041876    0.041819    0.613292    
#> 064: 0.846426    1.096112    3.503670    0.703453    0.039782    0.040695    0.606852    
#> 065: 0.856513    1.095237    3.498344    0.699460    0.037793    0.038660    0.592010    
#> 066: 0.810149    1.116062    3.503139    0.664487    0.035904    0.040468    0.581112    
#> 067: 0.799636    1.129533    3.493715    0.679266    0.034108    0.038445    0.587670    
#> 068: 0.763902    1.121269    3.489752    0.645303    0.032403    0.036522    0.598543    
#> 069: 0.777669    1.122602    3.475512    0.675719    0.030783    0.034696    0.608124    
#> 070: 0.801434    1.129769    3.495648    0.656067    0.038444    0.032961    0.601380    
#> 071: 0.746793    1.147321    3.468769    0.623264    0.037035    0.031313    0.612034    
#> 072: 0.751614    1.127227    3.490722    0.592101    0.035183    0.029748    0.610609    
#> 073: 0.774231    1.124590    3.503603    0.595425    0.033424    0.028260    0.625712    
#> 074: 0.774908    1.127042    3.493757    0.640598    0.034909    0.030985    0.613836    
#> 075: 0.805508    1.120301    3.505651    0.708944    0.036306    0.033466    0.629305    
#> 076: 0.853852    1.128260    3.510925    0.718748    0.034491    0.032110    0.629550    
#> 077: 0.852385    1.109287    3.503378    0.682811    0.032766    0.036952    0.611529    
#> 078: 0.818581    1.116611    3.502867    0.659000    0.031128    0.035104    0.596637    
#> 079: 0.857519    1.111983    3.502259    0.671716    0.029571    0.035800    0.613131    
#> 080: 0.857504    1.110295    3.503040    0.698420    0.028093    0.034010    0.615515    
#> 081: 0.816276    1.107256    3.505762    0.748024    0.026688    0.035839    0.608061    
#> 082: 0.802084    1.110735    3.500025    0.744291    0.028340    0.034047    0.615550    
#> 083: 0.814865    1.116858    3.499103    0.707077    0.028769    0.032345    0.621598    
#> 084: 0.783731    1.130944    3.485591    0.671723    0.033047    0.030727    0.613136    
#> 085: 0.814585    1.116084    3.503922    0.734014    0.038822    0.031030    0.594646    
#> 086: 0.808903    1.113894    3.498876    0.697313    0.036880    0.034944    0.597448    
#> 087: 0.816653    1.122378    3.486931    0.732146    0.035036    0.033197    0.594346    
#> 088: 0.810111    1.116486    3.505379    0.769632    0.033285    0.035387    0.597158    
#> 089: 0.795763    1.126929    3.491917    0.731150    0.031951    0.039322    0.591991    
#> 090: 0.821661    1.118802    3.492360    0.724721    0.034782    0.041189    0.576055    
#> 091: 0.798034    1.112076    3.494597    0.689621    0.033043    0.039130    0.593961    
#> 092: 0.781502    1.119748    3.481205    0.655140    0.031391    0.038985    0.606207    
#> 093: 0.722369    1.113264    3.483770    0.664519    0.033517    0.037035    0.610845    
#> 094: 0.757171    1.128110    3.472951    0.636139    0.031841    0.041983    0.609331    
#> 095: 0.767326    1.135498    3.483792    0.636635    0.033212    0.042152    0.606942    
#> 096: 0.743972    1.131684    3.482244    0.632053    0.031551    0.046039    0.603647    
#> 097: 0.788758    1.138027    3.473247    0.736558    0.029974    0.044280    0.608677    
#> 098: 0.824301    1.139238    3.491556    0.736031    0.028475    0.042867    0.601364    
#> 099: 0.797349    1.123506    3.475100    0.699230    0.027051    0.040724    0.608845    
#> 100: 0.780425    1.114742    3.493587    0.712853    0.025699    0.040271    0.600655    
#> 101: 0.761782    1.109934    3.484806    0.677210    0.024414    0.040852    0.597435    
#> 102: 0.801358    1.093254    3.496565    0.646755    0.025526    0.039078    0.591947    
#> 103: 0.807347    1.105669    3.502988    0.676704    0.024250    0.037124    0.605938    
#> 104: 0.842332    1.113641    3.503166    0.729329    0.026846    0.036952    0.608217    
#> 105: 0.846165    1.114376    3.498493    0.737142    0.035004    0.038507    0.613219    
#> 106: 0.833322    1.108862    3.494153    0.753470    0.035199    0.036582    0.591586    
#> 107: 0.849830    1.121825    3.499001    0.742676    0.033439    0.034753    0.597751    
#> 108: 0.823910    1.117282    3.507274    0.709880    0.031767    0.035672    0.609383    
#> 109: 0.808901    1.118813    3.516780    0.674386    0.030179    0.033889    0.624558    
#> 110: 0.867090    1.104975    3.507908    0.688093    0.029056    0.032194    0.612357    
#> 111: 0.857592    1.111219    3.507384    0.695798    0.030855    0.030783    0.597561    
#> 112: 0.824874    1.094559    3.492364    0.661008    0.036838    0.029244    0.604786    
#> 113: 0.808703    1.120907    3.497447    0.673578    0.035594    0.030938    0.587103    
#> 114: 0.800510    1.120259    3.498622    0.639899    0.033814    0.030515    0.598823    
#> 115: 0.831387    1.101965    3.488773    0.710701    0.035425    0.029972    0.616519    
#> 116: 0.857167    1.112588    3.489305    0.747071    0.033654    0.028473    0.614289    
#> 117: 0.823003    1.128638    3.503658    0.761456    0.037862    0.033051    0.588845    
#> 118: 0.865965    1.114971    3.496503    0.839735    0.035969    0.035345    0.598071    
#> 119: 0.868608    1.127368    3.496919    0.806935    0.034170    0.036383    0.623588    
#> 120: 0.800939    1.122273    3.499992    0.766588    0.032462    0.035718    0.605144    
#> 121: 0.857929    1.140479    3.505473    0.728259    0.032887    0.033932    0.593830    
#> 122: 0.842479    1.120901    3.510601    0.691846    0.031243    0.036332    0.604502    
#> 123: 0.898422    1.143459    3.508509    0.674397    0.031731    0.037179    0.618165    
#> 124: 0.827113    1.154792    3.501407    0.640677    0.030145    0.036524    0.623548    
#> 125: 0.819091    1.152307    3.497053    0.615037    0.028637    0.043888    0.608961    
#> 126: 0.795889    1.160292    3.472592    0.714360    0.034081    0.041694    0.632205    
#> 127: 0.835708    1.145355    3.472998    0.705651    0.032377    0.039609    0.622736    
#> 128: 0.833084    1.146016    3.493690    0.784442    0.030758    0.037628    0.618022    
#> 129: 0.843469    1.142917    3.505343    0.745220    0.029220    0.035747    0.622843    
#> 130: 0.897033    1.138632    3.499006    0.789249    0.027759    0.038686    0.612260    
#> 131: 0.854946    1.120959    3.492036    0.749787    0.026697    0.037880    0.602941    
#> 132: 0.763493    1.122094    3.469192    0.712298    0.029364    0.035986    0.604541    
#> 133: 0.749090    1.120932    3.480468    0.676683    0.033771    0.036404    0.611566    
#> 134: 0.782898    1.107554    3.504230    0.642849    0.034012    0.035901    0.601478    
#> 135: 0.798647    1.101361    3.503804    0.610706    0.034001    0.034106    0.610060    
#> 136: 0.800561    1.096259    3.510824    0.580171    0.034456    0.032400    0.594517    
#> 137: 0.870524    1.083849    3.523609    0.577578    0.032733    0.036348    0.599723    
#> 138: 0.838969    1.098260    3.512832    0.596696    0.031097    0.036320    0.610946    
#> 139: 0.824172    1.101918    3.525424    0.622033    0.029542    0.038533    0.607219    
#> 140: 0.853591    1.108375    3.519526    0.655929    0.032001    0.036607    0.639824    
#> 141: 0.817456    1.097953    3.499458    0.645986    0.034617    0.034776    0.615072    
#> 142: 0.855863    1.095472    3.525293    0.622297    0.032886    0.034726    0.627834    
#> 143: 0.805639    1.092341    3.523368    0.591182    0.031242    0.039515    0.629395    
#> 144: 0.873132    1.089762    3.525950    0.642529    0.029680    0.037539    0.597937    
#> 145: 0.807133    1.112740    3.503514    0.610403    0.029536    0.039338    0.606426    
#> 146: 0.847026    1.102035    3.514358    0.609537    0.032222    0.039616    0.603573    
#> 147: 0.793026    1.104402    3.498667    0.579060    0.030611    0.042321    0.594843    
#> 148: 0.801864    1.118298    3.500563    0.581394    0.029081    0.040205    0.600841    
#> 149: 0.797394    1.108036    3.502362    0.552324    0.027627    0.038195    0.618692    
#> 150: 0.839701    1.098208    3.493295    0.600463    0.032563    0.036285    0.612991    
#> 151: 0.817912    1.128691    3.499667    0.688666    0.030935    0.034471    0.606067    
#> 152: 0.785125    1.112559    3.494796    0.637802    0.025714    0.038797    0.615929    
#> 153: 0.793952    1.116935    3.500316    0.700636    0.033795    0.034277    0.626430    
#> 154: 0.804361    1.135942    3.488477    0.749901    0.031815    0.032172    0.619699    
#> 155: 0.793663    1.126624    3.493665    0.756744    0.037933    0.032167    0.610225    
#> 156: 0.827275    1.124587    3.496511    0.735860    0.037044    0.032528    0.614269    
#> 157: 0.825339    1.118640    3.501464    0.694768    0.042146    0.036856    0.606445    
#> 158: 0.846431    1.130945    3.502538    0.664018    0.035951    0.043091    0.619186    
#> 159: 0.795959    1.137494    3.507297    0.609142    0.037236    0.041056    0.611307    
#> 160: 0.843684    1.110462    3.517177    0.636647    0.030351    0.043581    0.614727    
#> 161: 0.837253    1.109947    3.515263    0.593787    0.030943    0.039267    0.611920    
#> 162: 0.834152    1.123363    3.508779    0.599830    0.029644    0.038423    0.615529    
#> 163: 0.835742    1.104778    3.506691    0.679006    0.026532    0.037962    0.590533    
#> 164: 0.860378    1.104356    3.513562    0.599305    0.024252    0.038260    0.593086    
#> 165: 0.860288    1.097363    3.514340    0.661022    0.028676    0.041117    0.597838    
#> 166: 0.878661    1.123986    3.503332    0.672310    0.031905    0.033434    0.618400    
#> 167: 0.864836    1.128246    3.526002    0.580347    0.032532    0.034463    0.618231    
#> 168: 0.883217    1.116945    3.530342    0.641284    0.038615    0.034418    0.623095    
#> 169: 0.842210    1.142112    3.514807    0.613841    0.046514    0.034092    0.623818    
#> 170: 0.828073    1.121132    3.519723    0.568288    0.050882    0.038957    0.632081    
#> 171: 0.808206    1.111638    3.508165    0.562519    0.047209    0.025427    0.618155    
#> 172: 0.778149    1.131721    3.491651    0.613234    0.041422    0.024753    0.597749    
#> 173: 0.754550    1.143395    3.482728    0.536182    0.048476    0.024318    0.586804    
#> 174: 0.807795    1.134203    3.496319    0.578886    0.042285    0.030895    0.609375    
#> 175: 0.778118    1.139703    3.485189    0.595550    0.040147    0.028250    0.614555    
#> 176: 0.788070    1.143949    3.493093    0.568582    0.041185    0.031512    0.605162    
#> 177: 0.788582    1.135145    3.489629    0.661570    0.043460    0.031044    0.598530    
#> 178: 0.811233    1.131667    3.490474    0.561861    0.034111    0.033484    0.606503    
#> 179: 0.837055    1.133678    3.494236    0.575767    0.033729    0.027516    0.635284    
#> 180: 0.775758    1.121236    3.499632    0.495367    0.030472    0.032859    0.635516    
#> 181: 0.787191    1.103037    3.492706    0.510992    0.029135    0.031339    0.631929    
#> 182: 0.758666    1.104399    3.483517    0.505108    0.031265    0.027058    0.637241    
#> 183: 0.810334    1.109998    3.496619    0.497713    0.035057    0.029124    0.629094    
#> 184: 0.799296    1.105906    3.500845    0.583842    0.034983    0.026790    0.612133    
#> 185: 0.781252    1.134314    3.495621    0.574958    0.040015    0.026929    0.613056    
#> 186: 0.764635    1.138939    3.488743    0.552252    0.045963    0.026956    0.617327    
#> 187: 0.785099    1.137430    3.492352    0.564702    0.037809    0.030678    0.602247    
#> 188: 0.788352    1.144173    3.484607    0.695179    0.035629    0.028937    0.604328    
#> 189: 0.793411    1.149800    3.503336    0.674780    0.039621    0.030170    0.607422    
#> 190: 0.792855    1.131153    3.502879    0.581254    0.034457    0.035250    0.593126    
#> 191: 0.804150    1.130230    3.496064    0.659902    0.025929    0.035089    0.588343    
#> 192: 0.813100    1.140128    3.499831    0.628273    0.026367    0.033599    0.592688    
#> 193: 0.834314    1.125814    3.507724    0.630662    0.021188    0.037219    0.606805    
#> 194: 0.810039    1.113695    3.509026    0.616468    0.027255    0.039573    0.605512    
#> 195: 0.767962    1.117327    3.491496    0.631731    0.027713    0.034742    0.601247    
#> 196: 0.807734    1.112447    3.507659    0.633707    0.031461    0.038571    0.626504    
#> 197: 0.771536    1.113813    3.509243    0.590404    0.029163    0.037070    0.634392    
#> 198: 0.856345    1.096060    3.504642    0.618719    0.028198    0.033823    0.613943    
#> 199: 0.841462    1.102090    3.511883    0.525443    0.029515    0.035181    0.630242    
#> 200: 0.811552    1.115183    3.506876    0.552988    0.043213    0.030331    0.623120    
#> 201: 0.807290    1.106537    3.507447    0.549199    0.038964    0.031371    0.614345    
#> 202: 0.800407    1.104116    3.506856    0.541510    0.036058    0.034279    0.613228    
#> 203: 0.809116    1.102881    3.506050    0.557164    0.033976    0.035667    0.613346    
#> 204: 0.811630    1.100483    3.509254    0.564290    0.032822    0.036459    0.612068    
#> 205: 0.827146    1.104315    3.509338    0.600485    0.032576    0.036399    0.613798    
#> 206: 0.835867    1.109327    3.509641    0.635248    0.032594    0.035532    0.613016    
#> 207: 0.835078    1.112027    3.508729    0.642499    0.033270    0.034690    0.610718    
#> 208: 0.833246    1.113043    3.506803    0.639519    0.032816    0.033993    0.609970    
#> 209: 0.834258    1.113243    3.504656    0.647844    0.032368    0.033942    0.610171    
#> 210: 0.832865    1.113569    3.504355    0.653496    0.032180    0.033692    0.608967    
#> 211: 0.833796    1.114514    3.503976    0.658386    0.031952    0.033675    0.608790    
#> 212: 0.833974    1.114976    3.504405    0.662271    0.031475    0.034378    0.608511    
#> 213: 0.837727    1.112328    3.505534    0.662471    0.030951    0.034452    0.609670    
#> 214: 0.839480    1.110236    3.506763    0.660484    0.030318    0.034504    0.610058    
#> 215: 0.842450    1.109027    3.508319    0.658646    0.029953    0.034700    0.609904    
#> 216: 0.848681    1.107687    3.509410    0.664584    0.030089    0.034652    0.610266    
#> 217: 0.850191    1.106848    3.510314    0.667044    0.030050    0.034710    0.609893    
#> 218: 0.850337    1.106741    3.510297    0.666875    0.030309    0.034756    0.610066    
#> 219: 0.849755    1.106298    3.509636    0.667586    0.030607    0.034407    0.610204    
#> 220: 0.846139    1.106378    3.509136    0.662914    0.030704    0.033978    0.610360    
#> 221: 0.843244    1.107258    3.508676    0.657236    0.030746    0.033530    0.610470    
#> 222: 0.842037    1.108079    3.508097    0.655979    0.030925    0.033227    0.609701    
#> 223: 0.842576    1.108608    3.508245    0.654419    0.031221    0.033020    0.608971    
#> 224: 0.842865    1.109134    3.508429    0.652280    0.031258    0.032814    0.608337    
#> 225: 0.843738    1.108123    3.508806    0.652880    0.031275    0.032577    0.608166    
#> 226: 0.845779    1.106882    3.509085    0.654491    0.031054    0.032452    0.608546    
#> 227: 0.845844    1.106526    3.509253    0.656088    0.031182    0.032523    0.607687    
#> 228: 0.845102    1.106816    3.508937    0.653750    0.031349    0.032535    0.607159    
#> 229: 0.844620    1.106840    3.508843    0.653346    0.031300    0.032585    0.606662    
#> 230: 0.844464    1.106540    3.508788    0.651958    0.031236    0.032496    0.606448    
#> 231: 0.844575    1.106627    3.509006    0.651521    0.031378    0.032413    0.606749    
#> 232: 0.843875    1.106358    3.508934    0.652416    0.031313    0.032317    0.607313    
#> 233: 0.843814    1.106151    3.508788    0.652948    0.031443    0.032195    0.607107    
#> 234: 0.842454    1.106403    3.508242    0.652788    0.031718    0.032064    0.607187    
#> 235: 0.841847    1.106245    3.507962    0.653081    0.031793    0.031952    0.607441    
#> 236: 0.840122    1.106482    3.507528    0.651455    0.031962    0.031815    0.607652    
#> 237: 0.840014    1.106689    3.507310    0.651915    0.032199    0.031789    0.608068    
#> 238: 0.840442    1.106938    3.507540    0.649842    0.032453    0.031749    0.608756    
#> 239: 0.840683    1.107244    3.507636    0.649184    0.032643    0.031805    0.608966    
#> 240: 0.840913    1.107072    3.508029    0.649190    0.032885    0.031831    0.608768    
#> 241: 0.841834    1.106477    3.508272    0.649512    0.033142    0.031804    0.608574    
#> 242: 0.841896    1.105927    3.508249    0.649920    0.033492    0.031778    0.608638    
#> 243: 0.841073    1.106200    3.508038    0.649733    0.033738    0.031651    0.608636    
#> 244: 0.840022    1.106245    3.508207    0.649617    0.033743    0.031616    0.608769    
#> 245: 0.839235    1.106009    3.508162    0.647993    0.033785    0.031526    0.609117    
#> 246: 0.839671    1.105689    3.508415    0.647825    0.033624    0.031614    0.609124    
#> 247: 0.840203    1.105459    3.508495    0.649358    0.033572    0.031725    0.608945    
#> 248: 0.839658    1.105929    3.508306    0.650632    0.033566    0.031666    0.608548    
#> 249: 0.839033    1.106355    3.507973    0.652636    0.033686    0.031617    0.608454    
#> 250: 0.839895    1.106702    3.507933    0.655651    0.033788    0.031612    0.608355    
#> 251: 0.840245    1.107281    3.507794    0.658313    0.033883    0.031574    0.608256    
#> 252: 0.841281    1.107771    3.507954    0.661809    0.034093    0.031574    0.608243    
#> 253: 0.840947    1.108271    3.507787    0.662613    0.034217    0.031657    0.608189    
#> 254: 0.840925    1.108981    3.507704    0.662092    0.034403    0.031614    0.608037    
#> 255: 0.840702    1.109554    3.507597    0.661853    0.034553    0.031559    0.607920    
#> 256: 0.840749    1.109810    3.507441    0.662499    0.034591    0.031471    0.607938    
#> 257: 0.839511    1.109693    3.507301    0.660612    0.034539    0.031346    0.607797    
#> 258: 0.838996    1.109388    3.507170    0.660472    0.034531    0.031301    0.607840    
#> 259: 0.838728    1.109124    3.507149    0.661469    0.034500    0.031274    0.608114    
#> 260: 0.838365    1.109214    3.507143    0.659851    0.034492    0.031202    0.608158    
#> 261: 0.837925    1.109212    3.507330    0.658557    0.034559    0.031196    0.607929    
#> 262: 0.837656    1.109194    3.507305    0.657356    0.034570    0.031177    0.607796    
#> 263: 0.837555    1.109286    3.507297    0.657343    0.034560    0.031241    0.607728    
#> 264: 0.837431    1.109479    3.507196    0.657771    0.034536    0.031350    0.607645    
#> 265: 0.837492    1.109575    3.507107    0.657204    0.034654    0.031498    0.607715    
#> 266: 0.837898    1.109782    3.506944    0.658452    0.034698    0.031587    0.607765    
#> 267: 0.837747    1.110048    3.506971    0.659483    0.034696    0.031673    0.607866    
#> 268: 0.837455    1.110063    3.506821    0.659631    0.034711    0.031687    0.607870    
#> 269: 0.837515    1.109889    3.506691    0.660092    0.034714    0.031749    0.607830    
#> 270: 0.837671    1.110116    3.506556    0.661095    0.034667    0.031797    0.607688    
#> 271: 0.837462    1.110209    3.506546    0.661588    0.034633    0.031888    0.607597    
#> 272: 0.837640    1.110023    3.506603    0.661448    0.034516    0.031965    0.607966    
#> 273: 0.837505    1.110123    3.506583    0.660922    0.034465    0.032032    0.607989    
#> 274: 0.837375    1.110276    3.506679    0.660231    0.034403    0.032129    0.608013    
#> 275: 0.837767    1.110291    3.506588    0.661650    0.034299    0.032160    0.607987    
#> 276: 0.837718    1.110409    3.506452    0.663591    0.034224    0.032181    0.608132    
#> 277: 0.837931    1.110726    3.506493    0.665488    0.034149    0.032290    0.608277    
#> 278: 0.837930    1.110966    3.506423    0.667767    0.034164    0.032319    0.608218    
#> 279: 0.838066    1.110989    3.506334    0.669072    0.034191    0.032356    0.608253    
#> 280: 0.837933    1.111122    3.506239    0.669161    0.034088    0.032449    0.608352    
#> 281: 0.837925    1.111257    3.506281    0.670978    0.033966    0.032535    0.608392    
#> 282: 0.838206    1.111467    3.506253    0.673754    0.033906    0.032548    0.608401    
#> 283: 0.838252    1.111652    3.506093    0.675821    0.033795    0.032670    0.608478    
#> 284: 0.838297    1.111675    3.506093    0.676756    0.033684    0.032792    0.608489    
#> 285: 0.838555    1.111808    3.505791    0.679461    0.033610    0.032856    0.608704    
#> 286: 0.838809    1.111942    3.505633    0.681118    0.033529    0.032915    0.608907    
#> 287: 0.838518    1.112045    3.505368    0.683133    0.033455    0.032963    0.609003    
#> 288: 0.838771    1.112066    3.505249    0.684574    0.033469    0.033050    0.609214    
#> 289: 0.839192    1.112171    3.505168    0.685119    0.033390    0.033006    0.609288    
#> 290: 0.839288    1.112265    3.505216    0.685947    0.033310    0.033004    0.609355    
#> 291: 0.839425    1.112566    3.505265    0.686317    0.033254    0.033067    0.609230    
#> 292: 0.839179    1.112698    3.505131    0.687036    0.033201    0.033109    0.609153    
#> 293: 0.838985    1.112727    3.504993    0.687944    0.033192    0.033190    0.609094    
#> 294: 0.839199    1.112865    3.504799    0.689304    0.033121    0.033251    0.609079    
#> 295: 0.839316    1.112695    3.504723    0.689817    0.033114    0.033293    0.609015    
#> 296: 0.839377    1.112461    3.504736    0.689194    0.033040    0.033359    0.609015    
#> 297: 0.839296    1.112512    3.504719    0.689104    0.032917    0.033397    0.609218    
#> 298: 0.838829    1.112506    3.504595    0.688124    0.032801    0.033437    0.609251    
#> 299: 0.838470    1.112544    3.504473    0.687948    0.032745    0.033453    0.609132    
#> 300: 0.838550    1.112465    3.504464    0.689065    0.032689    0.033535    0.609229    
#> 301: 0.838455    1.112497    3.504291    0.688708    0.032674    0.033548    0.609446    
#> 302: 0.838756    1.112666    3.504178    0.689121    0.032729    0.033500    0.609536    
#> 303: 0.838892    1.112781    3.504050    0.690046    0.032730    0.033465    0.609396    
#> 304: 0.839182    1.113001    3.503943    0.691477    0.032683    0.033489    0.609425    
#> 305: 0.839279    1.112801    3.503872    0.691967    0.032634    0.033511    0.609333    
#> 306: 0.838674    1.112677    3.503792    0.691462    0.032650    0.033495    0.609297    
#> 307: 0.837966    1.112549    3.503566    0.691260    0.032704    0.033486    0.609399    
#> 308: 0.837419    1.112545    3.503384    0.691586    0.032781    0.033506    0.609391    
#> 309: 0.837268    1.112386    3.503346    0.692019    0.032803    0.033519    0.609626    
#> 310: 0.837162    1.112339    3.503271    0.692939    0.032853    0.033538    0.609639    
#> 311: 0.837160    1.112284    3.503203    0.693556    0.032889    0.033538    0.609736    
#> 312: 0.837378    1.112182    3.503225    0.694923    0.032905    0.033488    0.609794    
#> 313: 0.837530    1.112001    3.503176    0.696548    0.032962    0.033472    0.609890    
#> 314: 0.837291    1.112034    3.503093    0.696952    0.033028    0.033424    0.609902    
#> 315: 0.836901    1.112001    3.503004    0.696444    0.033061    0.033415    0.609919    
#> 316: 0.836878    1.112034    3.502986    0.696466    0.033153    0.033419    0.609851    
#> 317: 0.836683    1.111908    3.503097    0.695252    0.033165    0.033446    0.610170    
#> 318: 0.836344    1.111932    3.503013    0.693993    0.033152    0.033474    0.610215    
#> 319: 0.835819    1.111900    3.502931    0.693311    0.033127    0.033506    0.610292    
#> 320: 0.835244    1.111887    3.502798    0.692616    0.033166    0.033505    0.610414    
#> 321: 0.835341    1.112069    3.502629    0.694033    0.033124    0.033500    0.610350    
#> 322: 0.834863    1.112165    3.502510    0.693916    0.033155    0.033464    0.610493    
#> 323: 0.834369    1.112300    3.502378    0.693638    0.033108    0.033430    0.610578    
#> 324: 0.834038    1.112521    3.502301    0.692999    0.033105    0.033448    0.610449    
#> 325: 0.833690    1.112689    3.502225    0.691474    0.033069    0.033444    0.610431    
#> 326: 0.833173    1.112708    3.502146    0.690440    0.033058    0.033423    0.610387    
#> 327: 0.833135    1.112702    3.502206    0.690147    0.033088    0.033411    0.610437    
#> 328: 0.833208    1.112784    3.502251    0.689418    0.033062    0.033431    0.610448    
#> 329: 0.833152    1.112797    3.502349    0.688666    0.033067    0.033430    0.610308    
#> 330: 0.833197    1.112677    3.502447    0.688032    0.033050    0.033413    0.610221    
#> 331: 0.833440    1.112751    3.502573    0.687929    0.033044    0.033395    0.610281    
#> 332: 0.833629    1.112697    3.502677    0.687710    0.032992    0.033396    0.610321    
#> 333: 0.834082    1.112729    3.502636    0.688703    0.033023    0.033400    0.610278    
#> 334: 0.834154    1.112635    3.502554    0.688738    0.032993    0.033416    0.610289    
#> 335: 0.834167    1.112674    3.502518    0.688657    0.033032    0.033454    0.610231    
#> 336: 0.833672    1.112675    3.502431    0.687801    0.033102    0.033483    0.610229    
#> 337: 0.833202    1.112883    3.502280    0.687405    0.033133    0.033505    0.610215    
#> 338: 0.832849    1.113079    3.502252    0.686234    0.033157    0.033543    0.610235    
#> 339: 0.832215    1.113277    3.502094    0.684838    0.033145    0.033602    0.610211    
#> 340: 0.831761    1.113332    3.501982    0.684123    0.033200    0.033667    0.610227    
#> 341: 0.831633    1.113383    3.502001    0.683655    0.033206    0.033722    0.610179    
#> 342: 0.831104    1.113430    3.501882    0.683023    0.033234    0.033721    0.610082    
#> 343: 0.830835    1.113497    3.501807    0.682873    0.033251    0.033720    0.610013    
#> 344: 0.830909    1.113477    3.501813    0.683382    0.033288    0.033702    0.609911    
#> 345: 0.830881    1.113479    3.501763    0.683600    0.033279    0.033689    0.609856    
#> 346: 0.830890    1.113515    3.501704    0.683327    0.033219    0.033689    0.609808    
#> 347: 0.830963    1.113336    3.501698    0.683097    0.033166    0.033722    0.609843    
#> 348: 0.830671    1.113296    3.501637    0.683046    0.033190    0.033727    0.609888    
#> 349: 0.830526    1.113182    3.501591    0.683532    0.033198    0.033753    0.609851    
#> 350: 0.830437    1.112977    3.501529    0.683589    0.033191    0.033742    0.609809    
#> 351: 0.830465    1.113120    3.501493    0.683471    0.033218    0.033713    0.609813    
#> 352: 0.830248    1.113344    3.501495    0.682687    0.033283    0.033708    0.609983    
#> 353: 0.830154    1.113472    3.501429    0.682349    0.033283    0.033713    0.609958    
#> 354: 0.830011    1.113600    3.501312    0.682617    0.033259    0.033750    0.609948    
#> 355: 0.830225    1.113561    3.501232    0.682871    0.033245    0.033777    0.609975    
#> 356: 0.830094    1.113579    3.501215    0.682815    0.033311    0.033796    0.609987    
#> 357: 0.829935    1.113677    3.501154    0.683010    0.033310    0.033830    0.609843    
#> 358: 0.829633    1.113762    3.501109    0.682780    0.033313    0.033861    0.609667    
#> 359: 0.829501    1.113898    3.501068    0.682783    0.033306    0.033905    0.609564    
#> 360: 0.829406    1.113963    3.501003    0.683186    0.033298    0.033950    0.609415    
#> 361: 0.829243    1.114088    3.500892    0.683112    0.033263    0.033967    0.609321    
#> 362: 0.829075    1.114173    3.500800    0.683340    0.033223    0.033982    0.609164    
#> 363: 0.829101    1.114182    3.500780    0.684088    0.033172    0.034011    0.609080    
#> 364: 0.829285    1.114254    3.500687    0.685216    0.033161    0.034071    0.609088    
#> 365: 0.829451    1.114210    3.500671    0.686463    0.033162    0.034091    0.609159    
#> 366: 0.829347    1.114218    3.500526    0.687224    0.033158    0.034082    0.609221    
#> 367: 0.829105    1.114319    3.500384    0.687075    0.033216    0.034065    0.609229    
#> 368: 0.829027    1.114397    3.500320    0.687384    0.033182    0.034059    0.609165    
#> 369: 0.828752    1.114472    3.500257    0.687505    0.033184    0.034051    0.609118    
#> 370: 0.828370    1.114602    3.500179    0.686990    0.033177    0.034060    0.609114    
#> 371: 0.827943    1.114696    3.500075    0.686955    0.033169    0.034063    0.609003    
#> 372: 0.827494    1.114811    3.499951    0.686840    0.033150    0.034062    0.608979    
#> 373: 0.826984    1.115024    3.499842    0.686784    0.033172    0.034077    0.608953    
#> 374: 0.826849    1.115157    3.499765    0.687289    0.033175    0.034091    0.608872    
#> 375: 0.826564    1.115215    3.499679    0.687212    0.033216    0.034069    0.608940    
#> 376: 0.826272    1.115351    3.499628    0.686733    0.033278    0.034047    0.608928    
#> 377: 0.826097    1.115469    3.499575    0.686243    0.033300    0.034057    0.608856    
#> 378: 0.825764    1.115563    3.499441    0.685932    0.033301    0.034060    0.608853    
#> 379: 0.825394    1.115495    3.499402    0.685536    0.033322    0.034061    0.608934    
#> 380: 0.825063    1.115521    3.499339    0.685186    0.033362    0.034062    0.608932    
#> 381: 0.824825    1.115526    3.499234    0.685339    0.033408    0.034043    0.608971    
#> 382: 0.824628    1.115441    3.499190    0.685325    0.033413    0.034041    0.608893    
#> 383: 0.824400    1.115420    3.499175    0.684952    0.033391    0.034042    0.608844    
#> 384: 0.824007    1.115364    3.499171    0.684215    0.033355    0.034075    0.608787    
#> 385: 0.823950    1.115350    3.499182    0.683858    0.033334    0.034099    0.608767    
#> 386: 0.823908    1.115418    3.499187    0.683306    0.033308    0.034122    0.608824    
#> 387: 0.823790    1.115462    3.499183    0.683290    0.033271    0.034152    0.608787    
#> 388: 0.823599    1.115565    3.499095    0.683559    0.033223    0.034185    0.608768    
#> 389: 0.823544    1.115438    3.499046    0.683820    0.033169    0.034249    0.608873    
#> 390: 0.823460    1.115438    3.499030    0.683823    0.033146    0.034268    0.608950    
#> 391: 0.823400    1.115392    3.498991    0.683376    0.033102    0.034275    0.608969    
#> 392: 0.823343    1.115296    3.499032    0.683016    0.033106    0.034298    0.608985    
#> 393: 0.823400    1.115168    3.499046    0.683080    0.033098    0.034304    0.608944    
#> 394: 0.823593    1.115051    3.499077    0.683255    0.033091    0.034314    0.608929    
#> 395: 0.823776    1.115114    3.499070    0.683379    0.033061    0.034328    0.608937    
#> 396: 0.823863    1.115121    3.499087    0.683379    0.033026    0.034342    0.609014    
#> 397: 0.824040    1.115073    3.499131    0.683433    0.032989    0.034345    0.609070    
#> 398: 0.824409    1.115000    3.499192    0.684146    0.032975    0.034306    0.609102    
#> 399: 0.824557    1.114947    3.499292    0.684252    0.032942    0.034275    0.609057    
#> 400: 0.824517    1.114948    3.499356    0.684042    0.032963    0.034270    0.608947    
#> 401: 0.824490    1.114986    3.499417    0.683358    0.032988    0.034262    0.608984    
#> 402: 0.824543    1.114953    3.499486    0.683001    0.032993    0.034259    0.608922    
#> 403: 0.824787    1.114909    3.499537    0.683128    0.033019    0.034238    0.608909    
#> 404: 0.824846    1.114872    3.499499    0.683194    0.033006    0.034228    0.608826    
#> 405: 0.824871    1.114828    3.499492    0.684058    0.033013    0.034223    0.608771    
#> 406: 0.824820    1.114810    3.499459    0.684033    0.032981    0.034242    0.608753    
#> 407: 0.824694    1.114881    3.499444    0.683771    0.032969    0.034266    0.608724    
#> 408: 0.824696    1.115013    3.499407    0.683683    0.032961    0.034268    0.608711    
#> 409: 0.824483    1.115059    3.499413    0.683195    0.032943    0.034286    0.608667    
#> 410: 0.824357    1.115113    3.499398    0.682849    0.032921    0.034303    0.608670    
#> 411: 0.824176    1.115008    3.499350    0.682783    0.032899    0.034308    0.608669    
#> 412: 0.823902    1.114988    3.499305    0.682200    0.032907    0.034301    0.608661    
#> 413: 0.823632    1.115040    3.499282    0.681459    0.032930    0.034287    0.608760    
#> 414: 0.823471    1.115052    3.499325    0.681408    0.032923    0.034280    0.608775    
#> 415: 0.823481    1.115059    3.499328    0.681157    0.032901    0.034303    0.608669    
#> 416: 0.823464    1.115114    3.499381    0.680646    0.032907    0.034325    0.608562    
#> 417: 0.823628    1.115103    3.499393    0.680657    0.032921    0.034336    0.608507    
#> 418: 0.823661    1.115140    3.499444    0.680687    0.032945    0.034325    0.608394    
#> 419: 0.823652    1.115234    3.499444    0.680627    0.032927    0.034327    0.608367    
#> 420: 0.823613    1.115287    3.499447    0.680502    0.032936    0.034329    0.608315    
#> 421: 0.823409    1.115348    3.499427    0.680402    0.032968    0.034325    0.608286    
#> 422: 0.823429    1.115312    3.499438    0.680480    0.032963    0.034335    0.608228    
#> 423: 0.823681    1.115254    3.499443    0.680754    0.032932    0.034341    0.608306    
#> 424: 0.823542    1.115118    3.499405    0.681097    0.032905    0.034372    0.608359    
#> 425: 0.823339    1.115107    3.499340    0.681260    0.032869    0.034416    0.608517    
#> 426: 0.823042    1.115203    3.499240    0.681461    0.032823    0.034449    0.608536    
#> 427: 0.822761    1.115246    3.499203    0.681531    0.032776    0.034497    0.608567    
#> 428: 0.822308    1.115365    3.499151    0.681413    0.032751    0.034524    0.608599    
#> 429: 0.821985    1.115480    3.499050    0.681384    0.032761    0.034532    0.608618    
#> 430: 0.821672    1.115646    3.498993    0.680812    0.032761    0.034554    0.608630    
#> 431: 0.821573    1.115744    3.498983    0.680416    0.032725    0.034563    0.608593    
#> 432: 0.821578    1.115831    3.498977    0.680400    0.032709    0.034585    0.608628    
#> 433: 0.821560    1.115910    3.498965    0.680321    0.032653    0.034610    0.608696    
#> 434: 0.821396    1.115868    3.498956    0.679952    0.032586    0.034656    0.608748    
#> 435: 0.821481    1.115857    3.499006    0.679728    0.032533    0.034705    0.608761    
#> 436: 0.821642    1.115806    3.499065    0.679606    0.032473    0.034722    0.608878    
#> 437: 0.821743    1.115737    3.499098    0.679542    0.032430    0.034733    0.608918    
#> 438: 0.821712    1.115873    3.499051    0.679668    0.032454    0.034730    0.608909    
#> 439: 0.821638    1.115945    3.499069    0.679378    0.032470    0.034726    0.608858    
#> 440: 0.821465    1.116008    3.499051    0.678951    0.032481    0.034727    0.608837    
#> 441: 0.821441    1.116046    3.499043    0.678665    0.032494    0.034737    0.608802    
#> 442: 0.821221    1.116088    3.499025    0.678205    0.032499    0.034740    0.608814    
#> 443: 0.821130    1.116199    3.498966    0.677970    0.032507    0.034722    0.608809    
#> 444: 0.820962    1.116256    3.498922    0.677843    0.032538    0.034721    0.608771    
#> 445: 0.820818    1.116343    3.498865    0.677710    0.032598    0.034732    0.608756    
#> 446: 0.820566    1.116450    3.498834    0.677488    0.032665    0.034717    0.608766    
#> 447: 0.820427    1.116532    3.498794    0.677107    0.032704    0.034708    0.608789    
#> 448: 0.820190    1.116566    3.498780    0.676724    0.032734    0.034688    0.608788    
#> 449: 0.819977    1.116664    3.498826    0.676231    0.032777    0.034651    0.608814    
#> 450: 0.819816    1.116684    3.498800    0.675835    0.032813    0.034615    0.608822    
#> 451: 0.819763    1.116742    3.498752    0.675509    0.032859    0.034583    0.608826    
#> 452: 0.819617    1.116775    3.498759    0.675204    0.032884    0.034565    0.608780    
#> 453: 0.819534    1.116833    3.498754    0.674804    0.032912    0.034560    0.608756    
#> 454: 0.819489    1.116884    3.498728    0.674599    0.032925    0.034529    0.608735    
#> 455: 0.819537    1.116844    3.498753    0.674596    0.032938    0.034531    0.608721    
#> 456: 0.819474    1.116776    3.498734    0.674746    0.032923    0.034539    0.608771    
#> 457: 0.819299    1.116772    3.498725    0.674846    0.032906    0.034532    0.608806    
#> 458: 0.819349    1.116876    3.498722    0.675114    0.032917    0.034545    0.608781    
#> 459: 0.819229    1.116996    3.498693    0.675213    0.032939    0.034554    0.608802    
#> 460: 0.819045    1.117023    3.498656    0.674817    0.032916    0.034556    0.608824    
#> 461: 0.819019    1.117029    3.498693    0.674554    0.032931    0.034555    0.608819    
#> 462: 0.818922    1.117043    3.498724    0.674408    0.032931    0.034552    0.608814    
#> 463: 0.818988    1.117093    3.498752    0.674416    0.032922    0.034545    0.608830    
#> 464: 0.819198    1.117107    3.498749    0.674523    0.032918    0.034534    0.608810    
#> 465: 0.819365    1.117037    3.498757    0.674661    0.032903    0.034528    0.608777    
#> 466: 0.819385    1.117029    3.498725    0.674826    0.032871    0.034514    0.608776    
#> 467: 0.819320    1.117020    3.498763    0.674795    0.032854    0.034514    0.608695    
#> 468: 0.819643    1.117035    3.498826    0.675359    0.032841    0.034539    0.608663    
#> 469: 0.820000    1.117119    3.498849    0.675904    0.032831    0.034550    0.608677    
#> 470: 0.820068    1.117174    3.498782    0.676642    0.032821    0.034558    0.608654    
#> 471: 0.820013    1.117228    3.498733    0.677050    0.032811    0.034546    0.608612    
#> 472: 0.820063    1.117297    3.498718    0.677361    0.032799    0.034546    0.608591    
#> 473: 0.819972    1.117326    3.498686    0.677050    0.032782    0.034540    0.608605    
#> 474: 0.819794    1.117276    3.498661    0.676902    0.032751    0.034534    0.608639    
#> 475: 0.819834    1.117302    3.498675    0.677003    0.032727    0.034535    0.608606    
#> 476: 0.819912    1.117331    3.498672    0.677070    0.032720    0.034531    0.608602    
#> 477: 0.819981    1.117333    3.498738    0.677074    0.032744    0.034529    0.608563    
#> 478: 0.819899    1.117255    3.498790    0.676767    0.032745    0.034525    0.608527    
#> 479: 0.819958    1.117248    3.498830    0.676470    0.032755    0.034531    0.608539    
#> 480: 0.819978    1.117275    3.498821    0.676273    0.032742    0.034536    0.608563    
#> 481: 0.819822    1.117307    3.498788    0.675805    0.032753    0.034525    0.608583    
#> 482: 0.819606    1.117331    3.498693    0.675490    0.032768    0.034522    0.608609    
#> 483: 0.819386    1.117362    3.498631    0.675411    0.032778    0.034522    0.608623    
#> 484: 0.819240    1.117275    3.498588    0.675260    0.032780    0.034507    0.608655    
#> 485: 0.819153    1.117319    3.498556    0.675233    0.032783    0.034506    0.608682    
#> 486: 0.819177    1.117351    3.498631    0.674923    0.032777    0.034499    0.608743    
#> 487: 0.819365    1.117369    3.498742    0.674820    0.032786    0.034510    0.608797    
#> 488: 0.819363    1.117314    3.498787    0.674553    0.032775    0.034515    0.608815    
#> 489: 0.819563    1.117223    3.498813    0.674310    0.032788    0.034524    0.608832    
#> 490: 0.819749    1.117123    3.498899    0.674356    0.032798    0.034540    0.608821    
#> 491: 0.819770    1.117108    3.498964    0.674046    0.032816    0.034551    0.608771    
#> 492: 0.819703    1.117100    3.498981    0.673653    0.032797    0.034544    0.608796    
#> 493: 0.819678    1.117110    3.498997    0.673383    0.032790    0.034572    0.608798    
#> 494: 0.819693    1.117165    3.498972    0.673111    0.032794    0.034574    0.608779    
#> 495: 0.819696    1.117215    3.498942    0.673186    0.032785    0.034585    0.608752    
#> 496: 0.819777    1.117263    3.498889    0.673419    0.032797    0.034572    0.608756    
#> 497: 0.819795    1.117265    3.498871    0.673578    0.032825    0.034559    0.608788    
#> 498: 0.819799    1.117232    3.498865    0.673694    0.032840    0.034546    0.608754    
#> 499: 0.819828    1.117258    3.498869    0.673699    0.032871    0.034545    0.608717    
#> 500: 0.819784    1.117216    3.498832    0.673521    0.032892    0.034531    0.608714    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.276616    0.981738    3.460211    0.392401    0.084175    0.016800    1.667158    
#> 002: 0.174530    1.077405    3.499496    0.372781    0.079966    0.015960    1.080634    
#> 003: 0.360727    1.045997    3.534732    0.410692    0.075968    0.015162    0.782165    
#> 004: 0.381044    1.106411    3.539018    0.415489    0.072170    0.014404    0.655667    
#> 005: 0.436184    1.129478    3.531083    0.468581    0.068561    0.013684    0.598861    
#> 006: 0.452535    1.139138    3.524833    0.536321    0.065133    0.013000    0.540497    
#> 007: 0.447041    1.169399    3.522652    0.534486    0.061876    0.012350    0.542957    
#> 008: 0.461733    1.156689    3.514155    0.591178    0.058783    0.011732    0.520672    
#> 009: 0.404614    1.150496    3.509886    0.561619    0.055843    0.011429    0.531187    
#> 010: 0.414652    1.149565    3.508950    0.583137    0.053051    0.015722    0.534076    
#> 011: 0.459275    1.159823    3.512677    0.679300    0.050399    0.015858    0.530300    
#> 012: 0.479578    1.140491    3.522019    0.645335    0.047879    0.015447    0.517120    
#> 013: 0.421595    1.147754    3.508275    0.674256    0.045485    0.018704    0.524096    
#> 014: 0.435537    1.145440    3.515159    0.640543    0.043211    0.017769    0.527833    
#> 015: 0.439772    1.155021    3.516788    0.642251    0.041050    0.017233    0.516426    
#> 016: 0.483794    1.165624    3.528259    0.650497    0.038998    0.016371    0.519359    
#> 017: 0.459681    1.146620    3.532650    0.617972    0.037634    0.015553    0.511225    
#> 018: 0.448626    1.169300    3.514826    0.587074    0.041081    0.014775    0.513471    
#> 019: 0.401529    1.159174    3.512508    0.557720    0.039027    0.014036    0.511050    
#> 020: 0.455819    1.161482    3.513196    0.551768    0.037248    0.013743    0.508456    
#> 021: 0.445459    1.148551    3.523280    0.575674    0.035386    0.013773    0.505083    
#> 022: 0.461244    1.142691    3.532315    0.624892    0.033617    0.013084    0.505547    
#> 023: 0.538228    1.149158    3.542185    0.740917    0.034690    0.012430    0.523412    
#> 024: 0.490213    1.171123    3.533241    0.703871    0.032956    0.011809    0.511362    
#> 025: 0.493429    1.152908    3.528720    0.668678    0.031308    0.012404    0.506721    
#> 026: 0.481823    1.169886    3.534316    0.635244    0.029742    0.014675    0.525956    
#> 027: 0.450573    1.168173    3.529307    0.603482    0.034096    0.013941    0.533656    
#> 028: 0.467487    1.155296    3.520715    0.645792    0.032391    0.014382    0.522011    
#> 029: 0.463335    1.162364    3.517724    0.633280    0.030771    0.014620    0.533437    
#> 030: 0.493595    1.168955    3.515540    0.779750    0.030458    0.018468    0.521991    
#> 031: 0.450231    1.153532    3.518055    0.740762    0.028935    0.017555    0.516748    
#> 032: 0.433951    1.157702    3.522850    0.703724    0.032419    0.016677    0.514415    
#> 033: 0.451430    1.166160    3.518455    0.668538    0.035531    0.016284    0.510203    
#> 034: 0.478472    1.171580    3.522156    0.652373    0.035683    0.015470    0.508664    
#> 035: 0.444501    1.143903    3.516635    0.629388    0.033899    0.014697    0.511937    
#> 036: 0.458479    1.146866    3.523307    0.597918    0.036947    0.013962    0.513151    
#> 037: 0.486937    1.150776    3.535590    0.612246    0.043242    0.014101    0.518528    
#> 038: 0.494309    1.136940    3.536259    0.581633    0.041080    0.015306    0.530705    
#> 039: 0.515678    1.134564    3.543631    0.562784    0.039026    0.016961    0.532539    
#> 040: 0.498034    1.138811    3.544099    0.604120    0.037074    0.016113    0.526538    
#> 041: 0.503928    1.134569    3.545790    0.573914    0.035221    0.015308    0.510774    
#> 042: 0.530276    1.137393    3.547268    0.660881    0.033460    0.014542    0.511422    
#> 043: 0.496823    1.149120    3.537188    0.631459    0.033314    0.014495    0.507387    
#> 044: 0.490126    1.148284    3.535895    0.599886    0.034489    0.013770    0.509687    
#> 045: 0.474979    1.156204    3.532187    0.569892    0.033373    0.013082    0.510648    
#> 046: 0.466153    1.142484    3.531803    0.565542    0.038185    0.012882    0.515444    
#> 047: 0.453980    1.144516    3.520009    0.551239    0.036276    0.012437    0.513449    
#> 048: 0.435526    1.144074    3.517342    0.543426    0.035650    0.013140    0.506774    
#> 049: 0.440241    1.140936    3.526983    0.534964    0.033867    0.012483    0.512325    
#> 050: 0.502867    1.132448    3.536643    0.678443    0.032174    0.012767    0.529039    
#> 051: 0.490641    1.143736    3.533780    0.653318    0.035838    0.013320    0.520490    
#> 052: 0.497097    1.152206    3.542104    0.620652    0.038595    0.013718    0.507245    
#> 053: 0.490981    1.135316    3.545295    0.589620    0.036665    0.013032    0.501033    
#> 054: 0.475742    1.135218    3.541964    0.560139    0.034832    0.012380    0.525667    
#> 055: 0.483262    1.130005    3.539349    0.564415    0.037036    0.011761    0.532018    
#> 056: 0.493567    1.129137    3.538166    0.609115    0.041119    0.012493    0.548905    
#> 057: 0.491195    1.127691    3.543409    0.578660    0.039063    0.013612    0.547941    
#> 058: 0.452153    1.143010    3.510844    0.659224    0.037110    0.017128    0.527700    
#> 059: 0.454867    1.122444    3.512267    0.711583    0.036236    0.017455    0.532941    
#> 060: 0.466280    1.129180    3.522178    0.676004    0.040088    0.017357    0.542308    
#> 061: 0.536500    1.133181    3.542219    0.707931    0.038226    0.016489    0.543164    
#> 062: 0.505047    1.144481    3.542339    0.672534    0.040887    0.018499    0.539999    
#> 063: 0.528573    1.130830    3.543468    0.638908    0.042369    0.017574    0.546013    
#> 064: 0.492590    1.132507    3.540367    0.627960    0.040251    0.016695    0.548388    
#> 065: 0.499752    1.125788    3.525202    0.596562    0.041060    0.016508    0.545474    
#> 066: 0.477391    1.149621    3.521212    0.707120    0.039007    0.016281    0.530446    
#> 067: 0.485012    1.143604    3.520382    0.671764    0.037056    0.015467    0.521068    
#> 068: 0.443115    1.152983    3.530925    0.638175    0.035204    0.016624    0.521186    
#> 069: 0.476527    1.156613    3.519310    0.725234    0.033443    0.015793    0.514282    
#> 070: 0.486578    1.153057    3.535470    0.688972    0.039772    0.015361    0.515671    
#> 071: 0.463931    1.173701    3.520007    0.654524    0.039447    0.014593    0.518900    
#> 072: 0.457840    1.157017    3.518327    0.621798    0.037475    0.013864    0.511822    
#> 073: 0.468361    1.156247    3.537410    0.623919    0.038705    0.016116    0.510400    
#> 074: 0.458038    1.124381    3.534663    0.592723    0.036770    0.015488    0.515446    
#> 075: 0.457686    1.144859    3.544851    0.626291    0.034931    0.015494    0.518961    
#> 076: 0.507606    1.142881    3.548783    0.594977    0.034260    0.017271    0.530119    
#> 077: 0.546529    1.124096    3.549074    0.650275    0.032692    0.016408    0.525496    
#> 078: 0.506090    1.128017    3.543724    0.661912    0.031058    0.017948    0.511689    
#> 079: 0.513928    1.151713    3.536746    0.712799    0.033317    0.017050    0.516098    
#> 080: 0.506921    1.143784    3.534152    0.718652    0.036846    0.016636    0.521904    
#> 081: 0.503201    1.145053    3.522458    0.740395    0.035374    0.015804    0.521906    
#> 082: 0.482129    1.137840    3.535593    0.704947    0.033606    0.016301    0.525045    
#> 083: 0.463427    1.164187    3.530178    0.669700    0.031925    0.018087    0.521874    
#> 084: 0.512297    1.156368    3.527821    0.738609    0.038001    0.017183    0.528887    
#> 085: 0.478831    1.152215    3.533682    0.701679    0.039162    0.016324    0.519678    
#> 086: 0.496273    1.152112    3.527388    0.666595    0.042213    0.015507    0.514250    
#> 087: 0.452003    1.152252    3.520032    0.633265    0.040103    0.014732    0.504103    
#> 088: 0.447465    1.152826    3.532481    0.601602    0.038677    0.013995    0.513067    
#> 089: 0.434589    1.170059    3.514986    0.602679    0.040010    0.013296    0.522617    
#> 090: 0.417545    1.171977    3.511961    0.572545    0.045197    0.012631    0.530161    
#> 091: 0.432609    1.157150    3.511540    0.556699    0.048495    0.011999    0.515562    
#> 092: 0.421337    1.167349    3.504805    0.560684    0.046999    0.011399    0.523487    
#> 093: 0.395990    1.158869    3.501787    0.626109    0.044649    0.011492    0.541729    
#> 094: 0.395240    1.159564    3.495520    0.595112    0.042417    0.013117    0.534228    
#> 095: 0.449699    1.152057    3.525048    0.586817    0.043268    0.013513    0.520479    
#> 096: 0.454483    1.155027    3.527842    0.615500    0.049056    0.012837    0.509367    
#> 097: 0.482180    1.165686    3.524360    0.663711    0.046603    0.012195    0.511260    
#> 098: 0.492182    1.156068    3.544854    0.630526    0.044273    0.011586    0.519859    
#> 099: 0.488016    1.133039    3.535833    0.599000    0.045786    0.011332    0.523877    
#> 100: 0.462847    1.145622    3.537285    0.569050    0.043496    0.013925    0.519646    
#> 101: 0.416746    1.148118    3.519371    0.540597    0.041321    0.014149    0.510853    
#> 102: 0.435462    1.148460    3.511939    0.601167    0.039255    0.013441    0.520933    
#> 103: 0.455395    1.160919    3.522935    0.571109    0.037293    0.013642    0.518939    
#> 104: 0.453213    1.157700    3.534361    0.592891    0.043515    0.012959    0.524136    
#> 105: 0.462147    1.160477    3.524861    0.647951    0.041339    0.013796    0.527881    
#> 106: 0.483391    1.144826    3.524740    0.674029    0.039272    0.016567    0.519465    
#> 107: 0.473411    1.159413    3.525514    0.644558    0.037308    0.015738    0.515664    
#> 108: 0.424754    1.163938    3.520270    0.612330    0.035668    0.014952    0.525030    
#> 109: 0.430731    1.161188    3.517895    0.602433    0.033884    0.014204    0.536945    
#> 110: 0.446869    1.151410    3.507307    0.572312    0.033867    0.013494    0.529719    
#> 111: 0.448348    1.163053    3.518675    0.543696    0.032174    0.012819    0.521179    
#> 112: 0.445902    1.136617    3.512048    0.552080    0.030565    0.013601    0.529685    
#> 113: 0.441422    1.165704    3.525460    0.537399    0.031808    0.013717    0.525131    
#> 114: 0.485298    1.169756    3.527031    0.510529    0.030218    0.015605    0.531994    
#> 115: 0.476014    1.150958    3.524521    0.614499    0.028707    0.014825    0.543140    
#> 116: 0.493768    1.162715    3.526574    0.589437    0.035879    0.017731    0.519182    
#> 117: 0.427980    1.171346    3.524964    0.559965    0.034085    0.017488    0.536766    
#> 118: 0.492996    1.152184    3.538006    0.531967    0.032381    0.016614    0.524129    
#> 119: 0.462090    1.168491    3.530351    0.575593    0.030762    0.016070    0.527013    
#> 120: 0.470523    1.150214    3.529387    0.652152    0.029494    0.015266    0.511096    
#> 121: 0.487959    1.149366    3.534529    0.619544    0.030178    0.015653    0.515794    
#> 122: 0.483551    1.131589    3.535663    0.588567    0.036037    0.014870    0.514055    
#> 123: 0.504086    1.163529    3.532360    0.614293    0.034235    0.014127    0.506016    
#> 124: 0.471910    1.176918    3.525524    0.583578    0.033663    0.013826    0.515831    
#> 125: 0.473672    1.170634    3.522014    0.575503    0.031980    0.013134    0.522933    
#> 126: 0.477334    1.164577    3.520202    0.546727    0.030381    0.014376    0.527698    
#> 127: 0.487842    1.157183    3.521559    0.593769    0.028993    0.014588    0.530892    
#> 128: 0.513931    1.145835    3.540179    0.612405    0.034006    0.013859    0.524654    
#> 129: 0.506724    1.145087    3.541857    0.599562    0.035317    0.013166    0.523398    
#> 130: 0.517456    1.155189    3.534835    0.611250    0.039914    0.012508    0.513893    
#> 131: 0.462412    1.145807    3.524045    0.580687    0.041969    0.011882    0.521092    
#> 132: 0.431554    1.163062    3.509722    0.600845    0.039871    0.011288    0.525353    
#> 133: 0.438963    1.143774    3.521239    0.570802    0.040233    0.011966    0.528406    
#> 134: 0.448587    1.135197    3.537634    0.551002    0.045192    0.011368    0.527933    
#> 135: 0.489560    1.125767    3.546969    0.554818    0.042949    0.010799    0.527066    
#> 136: 0.481117    1.135236    3.544725    0.527077    0.046163    0.010259    0.519539    
#> 137: 0.539346    1.127216    3.548230    0.632202    0.044541    0.009746    0.531266    
#> 138: 0.518596    1.137822    3.544342    0.600592    0.042676    0.009417    0.519854    
#> 139: 0.460003    1.131091    3.546302    0.570563    0.041978    0.010653    0.520292    
#> 140: 0.505776    1.142169    3.546797    0.542035    0.044756    0.013385    0.520207    
#> 141: 0.486784    1.119849    3.552229    0.522843    0.045163    0.012716    0.519097    
#> 142: 0.492351    1.109822    3.560636    0.496701    0.042905    0.012080    0.544348    
#> 143: 0.468219    1.122872    3.547419    0.477466    0.040760    0.013012    0.537996    
#> 144: 0.551630    1.125892    3.559001    0.600285    0.038722    0.013863    0.514775    
#> 145: 0.482377    1.134232    3.547548    0.570271    0.036786    0.013170    0.503369    
#> 146: 0.495334    1.135833    3.545977    0.541757    0.037353    0.012512    0.520051    
#> 147: 0.456364    1.128775    3.532532    0.523705    0.037206    0.013263    0.511784    
#> 148: 0.438269    1.152180    3.538027    0.549961    0.036987    0.012722    0.518419    
#> 149: 0.483140    1.144865    3.541713    0.522463    0.035137    0.012086    0.522469    
#> 150: 0.500111    1.135050    3.533927    0.596694    0.038660    0.011686    0.541928    
#> 151: 0.481607    1.146284    3.540992    0.578353    0.036727    0.011102    0.522536    
#> 152: 0.465608    1.146147    3.538063    0.544327    0.031739    0.011059    0.525164    
#> 153: 0.474143    1.147709    3.547110    0.539339    0.031267    0.010884    0.529007    
#> 154: 0.482191    1.148674    3.541494    0.575832    0.031627    0.012166    0.533433    
#> 155: 0.446606    1.127865    3.530518    0.577592    0.041186    0.010793    0.526806    
#> 156: 0.472300    1.143971    3.542238    0.524045    0.047988    0.011175    0.527120    
#> 157: 0.503054    1.130741    3.547419    0.589216    0.048294    0.009869    0.537884    
#> 158: 0.542520    1.137263    3.549742    0.535668    0.048783    0.008315    0.527955    
#> 159: 0.514423    1.137438    3.548874    0.545930    0.048932    0.008391    0.536957    
#> 160: 0.531148    1.127179    3.556606    0.551092    0.050259    0.007221    0.534965    
#> 161: 0.518686    1.146777    3.549465    0.570248    0.052185    0.006274    0.537443    
#> 162: 0.500533    1.146053    3.538551    0.565347    0.057225    0.005632    0.540303    
#> 163: 0.525494    1.145712    3.539314    0.631158    0.064069    0.005417    0.528588    
#> 164: 0.494003    1.148892    3.538225    0.551932    0.050901    0.006769    0.525736    
#> 165: 0.495509    1.126954    3.542438    0.626651    0.042476    0.009690    0.514236    
#> 166: 0.484378    1.161435    3.537444    0.517522    0.041844    0.011090    0.508360    
#> 167: 0.500070    1.165449    3.538716    0.534911    0.043685    0.012495    0.512469    
#> 168: 0.494702    1.166358    3.535020    0.546292    0.042541    0.010013    0.510506    
#> 169: 0.523371    1.174592    3.530948    0.593322    0.040444    0.007956    0.526791    
#> 170: 0.519101    1.155894    3.534351    0.602956    0.044539    0.008636    0.521120    
#> 171: 0.487847    1.154821    3.527126    0.594263    0.037987    0.009423    0.512328    
#> 172: 0.444081    1.174981    3.526054    0.531232    0.042609    0.009883    0.517426    
#> 173: 0.432026    1.174381    3.510097    0.571742    0.040822    0.008637    0.511230    
#> 174: 0.447060    1.155763    3.518141    0.623506    0.039200    0.009978    0.518624    
#> 175: 0.448893    1.149578    3.513356    0.647238    0.033178    0.010757    0.530480    
#> 176: 0.481796    1.151186    3.532312    0.676221    0.033424    0.012640    0.517582    
#> 177: 0.469339    1.146909    3.538689    0.540949    0.033949    0.015023    0.531165    
#> 178: 0.477243    1.146402    3.540328    0.523411    0.035742    0.011805    0.535702    
#> 179: 0.481496    1.156061    3.530492    0.577635    0.031951    0.013299    0.541675    
#> 180: 0.475425    1.153844    3.527437    0.650645    0.033448    0.012422    0.521168    
#> 181: 0.477258    1.150180    3.515967    0.607147    0.027901    0.012961    0.529108    
#> 182: 0.458457    1.150016    3.518912    0.573863    0.023515    0.014796    0.533156    
#> 183: 0.496948    1.161860    3.527917    0.587711    0.026263    0.016755    0.526103    
#> 184: 0.477176    1.134235    3.532243    0.599869    0.025010    0.016994    0.526502    
#> 185: 0.465598    1.159204    3.529686    0.595821    0.029691    0.014173    0.523015    
#> 186: 0.481368    1.153527    3.539414    0.551642    0.028295    0.016506    0.519691    
#> 187: 0.494574    1.152188    3.538082    0.631368    0.035792    0.013483    0.503053    
#> 188: 0.484638    1.143949    3.539695    0.580928    0.033110    0.013008    0.509323    
#> 189: 0.480202    1.146076    3.541307    0.673612    0.028477    0.015157    0.523055    
#> 190: 0.512874    1.136565    3.545656    0.751472    0.028804    0.015008    0.510127    
#> 191: 0.498347    1.141751    3.537810    0.621735    0.031895    0.012404    0.509554    
#> 192: 0.510464    1.145759    3.541597    0.666482    0.031614    0.014870    0.516043    
#> 193: 0.508666    1.152971    3.542425    0.642800    0.032630    0.013323    0.517181    
#> 194: 0.483465    1.151684    3.520740    0.559114    0.032371    0.013723    0.526535    
#> 195: 0.453794    1.160434    3.521561    0.619839    0.035506    0.014787    0.508844    
#> 196: 0.476440    1.155831    3.530180    0.577227    0.035922    0.014590    0.519013    
#> 197: 0.443229    1.151786    3.535302    0.542355    0.038722    0.011914    0.521702    
#> 198: 0.503600    1.127177    3.536466    0.501444    0.037499    0.012908    0.519255    
#> 199: 0.499053    1.123991    3.542645    0.592426    0.036740    0.014127    0.514291    
#> 200: 0.530744    1.126257    3.548675    0.715716    0.036225    0.015410    0.527391    
#> 201: 0.528849    1.122320    3.553582    0.653084    0.036340    0.016741    0.522969    
#> 202: 0.525245    1.122091    3.553775    0.624239    0.035128    0.017219    0.529717    
#> 203: 0.527708    1.122238    3.551651    0.616085    0.033667    0.017049    0.531633    
#> 204: 0.520602    1.121979    3.551785    0.614468    0.033907    0.016711    0.532538    
#> 205: 0.517643    1.126583    3.550942    0.614265    0.033361    0.016409    0.532255    
#> 206: 0.512353    1.131038    3.550922    0.609678    0.033699    0.016276    0.532545    
#> 207: 0.509961    1.132010    3.548915    0.611253    0.034179    0.015994    0.532558    
#> 208: 0.511287    1.132881    3.548836    0.609528    0.034576    0.015617    0.530200    
#> 209: 0.510379    1.132214    3.547755    0.606310    0.035355    0.015400    0.528720    
#> 210: 0.509757    1.131484    3.547523    0.605647    0.035383    0.015299    0.527516    
#> 211: 0.509177    1.132458    3.547445    0.598962    0.035326    0.015181    0.527376    
#> 212: 0.508524    1.132070    3.547225    0.598391    0.035527    0.014937    0.527746    
#> 213: 0.510033    1.131316    3.547201    0.604197    0.036175    0.014886    0.528600    
#> 214: 0.512881    1.130511    3.547649    0.607042    0.036166    0.014709    0.527967    
#> 215: 0.515179    1.130557    3.547914    0.610156    0.036377    0.014438    0.527370    
#> 216: 0.515277    1.129552    3.548639    0.607935    0.036798    0.014444    0.527517    
#> 217: 0.514175    1.129348    3.548893    0.603976    0.037285    0.014340    0.526785    
#> 218: 0.514120    1.130436    3.548286    0.603500    0.037668    0.014219    0.526979    
#> 219: 0.513671    1.130832    3.547265    0.603635    0.037766    0.014063    0.527267    
#> 220: 0.512145    1.131529    3.546867    0.604487    0.037929    0.013983    0.527515    
#> 221: 0.511253    1.132565    3.546522    0.604252    0.038335    0.013937    0.526918    
#> 222: 0.510296    1.133073    3.546167    0.602588    0.038801    0.013895    0.527214    
#> 223: 0.509682    1.133221    3.545835    0.601484    0.038899    0.013770    0.527663    
#> 224: 0.510277    1.133500    3.546077    0.600155    0.038651    0.013659    0.527821    
#> 225: 0.510258    1.132127    3.546587    0.599329    0.038570    0.013576    0.528243    
#> 226: 0.509220    1.131505    3.546283    0.597868    0.038806    0.013439    0.528267    
#> 227: 0.509205    1.131477    3.546096    0.599000    0.038820    0.013404    0.527799    
#> 228: 0.507989    1.132190    3.545536    0.598954    0.038894    0.013296    0.527512    
#> 229: 0.505257    1.132464    3.545012    0.599044    0.038867    0.013229    0.527022    
#> 230: 0.503233    1.132796    3.544415    0.597300    0.038943    0.013227    0.526941    
#> 231: 0.501517    1.133719    3.544038    0.596227    0.039015    0.013204    0.526540    
#> 232: 0.499937    1.134061    3.543818    0.594411    0.038941    0.013200    0.526118    
#> 233: 0.498838    1.133759    3.543841    0.595247    0.038880    0.013172    0.526166    
#> 234: 0.498274    1.133811    3.543627    0.597135    0.038955    0.013160    0.526014    
#> 235: 0.497998    1.133864    3.543352    0.597581    0.038855    0.013178    0.526141    
#> 236: 0.497403    1.134433    3.542778    0.597615    0.038831    0.013182    0.526005    
#> 237: 0.497199    1.134485    3.542292    0.599244    0.038629    0.013211    0.526434    
#> 238: 0.497374    1.134556    3.542177    0.599491    0.038527    0.013224    0.526899    
#> 239: 0.496780    1.134888    3.542032    0.597197    0.038558    0.013180    0.526926    
#> 240: 0.495873    1.134941    3.541956    0.593697    0.038484    0.013131    0.527278    
#> 241: 0.495491    1.134589    3.541871    0.591902    0.038451    0.013103    0.527453    
#> 242: 0.495161    1.134482    3.541556    0.593836    0.038343    0.013089    0.527446    
#> 243: 0.494562    1.135135    3.541296    0.593923    0.038364    0.013111    0.527415    
#> 244: 0.494819    1.135203    3.541255    0.593717    0.038184    0.013070    0.527586    
#> 245: 0.495062    1.135006    3.541245    0.593321    0.038121    0.013051    0.527545    
#> 246: 0.494639    1.134786    3.541059    0.592856    0.038088    0.013062    0.527577    
#> 247: 0.494568    1.134534    3.541028    0.592261    0.037970    0.013039    0.527572    
#> 248: 0.494305    1.134826    3.540886    0.591648    0.037900    0.013025    0.527434    
#> 249: 0.494385    1.135128    3.540868    0.592544    0.037943    0.013015    0.527356    
#> 250: 0.494079    1.135698    3.540688    0.591923    0.038057    0.013041    0.527361    
#> 251: 0.494120    1.136408    3.540634    0.590602    0.038178    0.013040    0.527651    
#> 252: 0.494695    1.136729    3.540667    0.591506    0.038201    0.013040    0.527649    
#> 253: 0.494346    1.137055    3.540455    0.591975    0.038180    0.013049    0.527713    
#> 254: 0.493711    1.137841    3.540124    0.591629    0.038181    0.013047    0.527674    
#> 255: 0.493715    1.138329    3.540001    0.592217    0.038084    0.013042    0.527678    
#> 256: 0.493805    1.138367    3.539952    0.592321    0.038021    0.013031    0.527674    
#> 257: 0.493285    1.138032    3.539997    0.590629    0.038105    0.013021    0.527699    
#> 258: 0.493102    1.137676    3.540135    0.589671    0.038144    0.013006    0.527561    
#> 259: 0.492637    1.137503    3.540094    0.590197    0.038035    0.013008    0.527368    
#> 260: 0.492245    1.137494    3.540123    0.589347    0.037993    0.013009    0.527252    
#> 261: 0.492146    1.137399    3.540135    0.588794    0.038003    0.013002    0.527085    
#> 262: 0.491561    1.137590    3.540105    0.587376    0.037924    0.012998    0.526941    
#> 263: 0.491110    1.137916    3.539986    0.587432    0.037834    0.012992    0.526949    
#> 264: 0.490500    1.138232    3.539837    0.587067    0.037797    0.012980    0.527061    
#> 265: 0.490032    1.138182    3.539748    0.585829    0.037703    0.013006    0.527264    
#> 266: 0.490345    1.138145    3.539846    0.585025    0.037718    0.013016    0.527134    
#> 267: 0.490530    1.138132    3.539944    0.585846    0.037681    0.013043    0.527105    
#> 268: 0.490857    1.138092    3.539942    0.586399    0.037748    0.013082    0.527254    
#> 269: 0.490998    1.137955    3.539954    0.586410    0.037727    0.013141    0.527288    
#> 270: 0.490980    1.137992    3.539837    0.586673    0.037717    0.013174    0.527121    
#> 271: 0.491100    1.138094    3.539701    0.587239    0.037720    0.013214    0.527095    
#> 272: 0.491453    1.137853    3.539735    0.587343    0.037665    0.013226    0.526990    
#> 273: 0.491272    1.137974    3.539763    0.586495    0.037550    0.013234    0.526957    
#> 274: 0.491356    1.137944    3.539846    0.586192    0.037495    0.013230    0.526770    
#> 275: 0.491679    1.137953    3.539887    0.585464    0.037349    0.013231    0.526709    
#> 276: 0.491699    1.138023    3.539989    0.584872    0.037272    0.013241    0.526683    
#> 277: 0.491298    1.138319    3.540083    0.584242    0.037271    0.013262    0.526764    
#> 278: 0.490942    1.138434    3.540156    0.583681    0.037229    0.013281    0.526905    
#> 279: 0.490387    1.138464    3.540066    0.583209    0.037236    0.013278    0.526947    
#> 280: 0.490085    1.138672    3.539967    0.582716    0.037210    0.013257    0.526908    
#> 281: 0.489840    1.138827    3.540010    0.582353    0.037234    0.013235    0.526796    
#> 282: 0.489831    1.138889    3.540024    0.582585    0.037212    0.013241    0.526701    
#> 283: 0.489954    1.138920    3.540012    0.583834    0.037365    0.013244    0.526682    
#> 284: 0.489949    1.138834    3.539925    0.584890    0.037412    0.013228    0.526500    
#> 285: 0.490133    1.139078    3.539788    0.585684    0.037491    0.013233    0.526533    
#> 286: 0.490134    1.139251    3.539704    0.586736    0.037572    0.013243    0.526579    
#> 287: 0.489490    1.139629    3.539413    0.586599    0.037655    0.013228    0.526653    
#> 288: 0.489373    1.139800    3.539306    0.587295    0.037657    0.013239    0.526656    
#> 289: 0.489634    1.139946    3.539326    0.587806    0.037636    0.013253    0.526519    
#> 290: 0.489689    1.140077    3.539270    0.587378    0.037574    0.013262    0.526522    
#> 291: 0.489614    1.140199    3.539274    0.586886    0.037526    0.013287    0.526386    
#> 292: 0.489446    1.140425    3.539134    0.586193    0.037511    0.013302    0.526231    
#> 293: 0.488904    1.140592    3.538924    0.585576    0.037413    0.013340    0.526216    
#> 294: 0.488511    1.140738    3.538720    0.585659    0.037374    0.013371    0.526348    
#> 295: 0.488387    1.140472    3.538735    0.584740    0.037339    0.013362    0.526411    
#> 296: 0.488316    1.140523    3.538694    0.584482    0.037373    0.013341    0.526369    
#> 297: 0.488585    1.140720    3.538737    0.585243    0.037418    0.013296    0.526309    
#> 298: 0.488754    1.140583    3.538805    0.584791    0.037403    0.013283    0.526273    
#> 299: 0.488669    1.140565    3.538808    0.584320    0.037383    0.013275    0.526176    
#> 300: 0.489007    1.140357    3.538968    0.585168    0.037404    0.013293    0.526063    
#> 301: 0.489243    1.140206    3.539004    0.584475    0.037329    0.013292    0.526127    
#> 302: 0.489156    1.140275    3.538843    0.584023    0.037281    0.013289    0.526024    
#> 303: 0.488917    1.140516    3.538720    0.583844    0.037324    0.013274    0.525941    
#> 304: 0.488581    1.140929    3.538518    0.583743    0.037379    0.013255    0.526006    
#> 305: 0.488447    1.140854    3.538508    0.583820    0.037377    0.013239    0.526009    
#> 306: 0.488288    1.140817    3.538411    0.583688    0.037342    0.013236    0.525964    
#> 307: 0.487946    1.140731    3.538231    0.583690    0.037309    0.013242    0.525897    
#> 308: 0.487734    1.140769    3.538132    0.583501    0.037256    0.013214    0.525860    
#> 309: 0.487761    1.140623    3.538068    0.584221    0.037278    0.013203    0.525854    
#> 310: 0.487958    1.140516    3.538024    0.584752    0.037284    0.013186    0.525858    
#> 311: 0.487862    1.140503    3.537999    0.585276    0.037242    0.013185    0.525786    
#> 312: 0.487373    1.140541    3.537871    0.585158    0.037207    0.013200    0.525841    
#> 313: 0.487067    1.140394    3.537779    0.585099    0.037194    0.013186    0.525947    
#> 314: 0.486651    1.140467    3.537677    0.584837    0.037151    0.013188    0.525943    
#> 315: 0.486197    1.140605    3.537553    0.584268    0.037136    0.013176    0.525926    
#> 316: 0.485956    1.140734    3.537426    0.584276    0.037184    0.013165    0.525901    
#> 317: 0.485865    1.140759    3.537383    0.583752    0.037192    0.013159    0.525979    
#> 318: 0.485906    1.140860    3.537275    0.583676    0.037186    0.013155    0.525966    
#> 319: 0.485723    1.140822    3.537278    0.583776    0.037179    0.013169    0.525909    
#> 320: 0.485406    1.140796    3.537235    0.583488    0.037252    0.013181    0.525955    
#> 321: 0.485253    1.140807    3.537176    0.583709    0.037302    0.013194    0.525952    
#> 322: 0.485185    1.140867    3.537058    0.583558    0.037332    0.013202    0.525872    
#> 323: 0.485140    1.140901    3.536987    0.583629    0.037322    0.013202    0.525741    
#> 324: 0.485111    1.141039    3.536946    0.583907    0.037277    0.013202    0.525513    
#> 325: 0.484962    1.141300    3.536887    0.584060    0.037249    0.013200    0.525409    
#> 326: 0.484849    1.141261    3.536814    0.584481    0.037194    0.013182    0.525369    
#> 327: 0.484961    1.141365    3.536836    0.584264    0.037182    0.013158    0.525322    
#> 328: 0.485093    1.141438    3.536817    0.584316    0.037179    0.013136    0.525237    
#> 329: 0.485284    1.141413    3.536868    0.584026    0.037183    0.013137    0.525142    
#> 330: 0.485118    1.141381    3.536913    0.583754    0.037136    0.013143    0.525048    
#> 331: 0.485263    1.141513    3.536940    0.584070    0.037117    0.013147    0.524847    
#> 332: 0.485389    1.141517    3.536991    0.584080    0.037110    0.013165    0.524739    
#> 333: 0.485506    1.141468    3.536986    0.583782    0.037073    0.013173    0.524721    
#> 334: 0.485266    1.141398    3.536864    0.583309    0.037077    0.013158    0.524759    
#> 335: 0.485072    1.141370    3.536821    0.582736    0.037013    0.013144    0.524751    
#> 336: 0.484865    1.141385    3.536774    0.582469    0.036935    0.013144    0.524720    
#> 337: 0.484720    1.141627    3.536657    0.582845    0.036908    0.013148    0.524724    
#> 338: 0.484468    1.141752    3.536630    0.582996    0.036912    0.013149    0.524731    
#> 339: 0.484036    1.141922    3.536469    0.582987    0.036999    0.013145    0.524611    
#> 340: 0.483550    1.142027    3.536286    0.583230    0.037083    0.013129    0.524514    
#> 341: 0.483334    1.142174    3.536125    0.583754    0.037167    0.013112    0.524438    
#> 342: 0.482967    1.142243    3.536002    0.583859    0.037201    0.013110    0.524380    
#> 343: 0.482652    1.142298    3.535909    0.583921    0.037224    0.013091    0.524370    
#> 344: 0.482617    1.142325    3.535889    0.583937    0.037242    0.013085    0.524357    
#> 345: 0.482681    1.142386    3.535917    0.583998    0.037265    0.013077    0.524319    
#> 346: 0.482758    1.142446    3.535836    0.584390    0.037306    0.013066    0.524196    
#> 347: 0.482843    1.142351    3.535790    0.584543    0.037320    0.013039    0.524165    
#> 348: 0.482475    1.142446    3.535760    0.583936    0.037376    0.013031    0.524176    
#> 349: 0.482294    1.142504    3.535725    0.583761    0.037388    0.013029    0.524100    
#> 350: 0.482125    1.142500    3.535661    0.583784    0.037406    0.013028    0.523954    
#> 351: 0.482013    1.142625    3.535561    0.584161    0.037403    0.013021    0.523874    
#> 352: 0.481784    1.142725    3.535499    0.584055    0.037402    0.013009    0.523896    
#> 353: 0.481804    1.142854    3.535486    0.584298    0.037389    0.013014    0.523901    
#> 354: 0.481799    1.142828    3.535422    0.584367    0.037364    0.013013    0.523879    
#> 355: 0.482084    1.142764    3.535377    0.585432    0.037358    0.013008    0.523922    
#> 356: 0.482379    1.142809    3.535343    0.587121    0.037384    0.012999    0.523910    
#> 357: 0.482647    1.142948    3.535275    0.588318    0.037375    0.013003    0.523856    
#> 358: 0.482824    1.143114    3.535277    0.589276    0.037457    0.012995    0.523795    
#> 359: 0.482859    1.143275    3.535214    0.590185    0.037453    0.012983    0.523710    
#> 360: 0.482750    1.143357    3.535112    0.590214    0.037452    0.012974    0.523635    
#> 361: 0.482626    1.143489    3.535008    0.590492    0.037463    0.012960    0.523626    
#> 362: 0.482542    1.143569    3.534943    0.590329    0.037489    0.012934    0.523519    
#> 363: 0.482369    1.143543    3.534875    0.590635    0.037509    0.012911    0.523398    
#> 364: 0.482301    1.143672    3.534831    0.590290    0.037576    0.012894    0.523402    
#> 365: 0.482265    1.143734    3.534823    0.590224    0.037617    0.012894    0.523424    
#> 366: 0.482119    1.143783    3.534749    0.589866    0.037617    0.012897    0.523432    
#> 367: 0.482111    1.143734    3.534739    0.589782    0.037573    0.012898    0.523404    
#> 368: 0.482460    1.143845    3.534711    0.590589    0.037578    0.012902    0.523346    
#> 369: 0.482454    1.143871    3.534715    0.590611    0.037612    0.012917    0.523317    
#> 370: 0.482468    1.143938    3.534724    0.590243    0.037641    0.012920    0.523314    
#> 371: 0.482474    1.143975    3.534676    0.590115    0.037605    0.012919    0.523304    
#> 372: 0.482219    1.144009    3.534588    0.590349    0.037580    0.012926    0.523259    
#> 373: 0.481818    1.144203    3.534478    0.590703    0.037565    0.012936    0.523253    
#> 374: 0.481732    1.144218    3.534426    0.591021    0.037502    0.012965    0.523205    
#> 375: 0.481517    1.144257    3.534357    0.591324    0.037467    0.012976    0.523253    
#> 376: 0.481405    1.144286    3.534334    0.591372    0.037401    0.013009    0.523249    
#> 377: 0.481395    1.144318    3.534364    0.591322    0.037343    0.013034    0.523194    
#> 378: 0.481327    1.144263    3.534369    0.591113    0.037318    0.013060    0.523224    
#> 379: 0.481075    1.144110    3.534398    0.591007    0.037276    0.013082    0.523230    
#> 380: 0.481055    1.143980    3.534392    0.590754    0.037281    0.013101    0.523254    
#> 381: 0.480955    1.143947    3.534370    0.590804    0.037274    0.013109    0.523303    
#> 382: 0.481055    1.143974    3.534344    0.591607    0.037245    0.013121    0.523266    
#> 383: 0.481058    1.144007    3.534297    0.591609    0.037257    0.013119    0.523214    
#> 384: 0.480863    1.144014    3.534295    0.591414    0.037240    0.013115    0.523161    
#> 385: 0.480686    1.144032    3.534279    0.591097    0.037259    0.013108    0.523149    
#> 386: 0.480766    1.144137    3.534331    0.590714    0.037287    0.013115    0.523165    
#> 387: 0.480767    1.144222    3.534350    0.590635    0.037310    0.013116    0.523140    
#> 388: 0.480772    1.144283    3.534367    0.590744    0.037320    0.013117    0.523080    
#> 389: 0.480943    1.144291    3.534352    0.590762    0.037339    0.013109    0.523081    
#> 390: 0.480759    1.144376    3.534267    0.590903    0.037354    0.013096    0.523069    
#> 391: 0.480674    1.144423    3.534191    0.591017    0.037344    0.013092    0.523015    
#> 392: 0.480633    1.144451    3.534184    0.591203    0.037335    0.013107    0.523016    
#> 393: 0.480535    1.144424    3.534118    0.591267    0.037325    0.013116    0.522933    
#> 394: 0.480673    1.144453    3.534079    0.591695    0.037302    0.013120    0.522945    
#> 395: 0.480840    1.144543    3.534035    0.592597    0.037326    0.013119    0.522914    
#> 396: 0.480917    1.144632    3.533974    0.593463    0.037342    0.013109    0.522931    
#> 397: 0.480933    1.144604    3.533957    0.593513    0.037344    0.013103    0.522910    
#> 398: 0.481120    1.144539    3.533997    0.593415    0.037351    0.013096    0.522925    
#> 399: 0.481197    1.144502    3.534058    0.593350    0.037390    0.013089    0.522902    
#> 400: 0.481312    1.144387    3.534121    0.593083    0.037388    0.013083    0.522964    
#> 401: 0.481354    1.144382    3.534142    0.592661    0.037436    0.013086    0.523021    
#> 402: 0.481285    1.144460    3.534144    0.592400    0.037513    0.013074    0.523079    
#> 403: 0.481453    1.144505    3.534158    0.592137    0.037505    0.013064    0.523070    
#> 404: 0.481408    1.144492    3.534098    0.591993    0.037495    0.013051    0.523104    
#> 405: 0.481325    1.144482    3.534095    0.592051    0.037482    0.013045    0.523105    
#> 406: 0.481145    1.144546    3.534034    0.591964    0.037473    0.013052    0.523134    
#> 407: 0.480998    1.144684    3.533990    0.591912    0.037478    0.013048    0.523169    
#> 408: 0.481006    1.144873    3.533930    0.591721    0.037482    0.013043    0.523202    
#> 409: 0.480905    1.144846    3.533862    0.591513    0.037474    0.013032    0.523204    
#> 410: 0.480721    1.144933    3.533786    0.591442    0.037483    0.013022    0.523273    
#> 411: 0.480575    1.144820    3.533766    0.591005    0.037469    0.013014    0.523336    
#> 412: 0.480584    1.144823    3.533722    0.590781    0.037460    0.013005    0.523320    
#> 413: 0.480599    1.144865    3.533670    0.590687    0.037447    0.012992    0.523313    
#> 414: 0.480353    1.144861    3.533648    0.590258    0.037437    0.012983    0.523365    
#> 415: 0.480374    1.144913    3.533646    0.590483    0.037437    0.012959    0.523400    
#> 416: 0.480544    1.145027    3.533628    0.590991    0.037457    0.012945    0.523374    
#> 417: 0.480650    1.145023    3.533604    0.591286    0.037480    0.012925    0.523328    
#> 418: 0.480699    1.145047    3.533616    0.591358    0.037497    0.012919    0.523274    
#> 419: 0.480887    1.145099    3.533646    0.591773    0.037505    0.012914    0.523239    
#> 420: 0.480977    1.145136    3.533645    0.591940    0.037517    0.012906    0.523169    
#> 421: 0.480973    1.145190    3.533651    0.592045    0.037505    0.012899    0.523127    
#> 422: 0.481051    1.145147    3.533679    0.592207    0.037500    0.012891    0.523115    
#> 423: 0.481245    1.145084    3.533714    0.592403    0.037516    0.012878    0.523110    
#> 424: 0.481172    1.145002    3.533698    0.592478    0.037507    0.012866    0.523116    
#> 425: 0.481314    1.145015    3.533705    0.592958    0.037495    0.012857    0.523128    
#> 426: 0.481456    1.145075    3.533744    0.593359    0.037470    0.012851    0.523128    
#> 427: 0.481386    1.145068    3.533756    0.593366    0.037439    0.012836    0.523115    
#> 428: 0.481483    1.145114    3.533780    0.593409    0.037456    0.012822    0.523082    
#> 429: 0.481612    1.145117    3.533840    0.593501    0.037471    0.012810    0.523043    
#> 430: 0.481665    1.145108    3.533834    0.593127    0.037475    0.012797    0.523076    
#> 431: 0.481783    1.145095    3.533830    0.593090    0.037486    0.012783    0.523000    
#> 432: 0.481816    1.145139    3.533827    0.593252    0.037507    0.012771    0.522962    
#> 433: 0.482003    1.145243    3.533870    0.593312    0.037507    0.012770    0.522979    
#> 434: 0.481971    1.145242    3.533848    0.593142    0.037521    0.012746    0.522942    
#> 435: 0.481877    1.145274    3.533791    0.592994    0.037531    0.012736    0.522911    
#> 436: 0.481919    1.145245    3.533833    0.592914    0.037568    0.012729    0.522899    
#> 437: 0.481903    1.145218    3.533787    0.592665    0.037589    0.012721    0.522893    
#> 438: 0.482039    1.145298    3.533774    0.592643    0.037589    0.012720    0.522847    
#> 439: 0.482065    1.145319    3.533779    0.592450    0.037586    0.012716    0.522774    
#> 440: 0.482143    1.145376    3.533805    0.592673    0.037594    0.012711    0.522669    
#> 441: 0.482190    1.145348    3.533799    0.592685    0.037571    0.012713    0.522572    
#> 442: 0.482021    1.145354    3.533813    0.592377    0.037556    0.012714    0.522526    
#> 443: 0.481944    1.145376    3.533771    0.592184    0.037529    0.012715    0.522498    
#> 444: 0.481770    1.145407    3.533710    0.591998    0.037498    0.012726    0.522447    
#> 445: 0.481778    1.145418    3.533690    0.592133    0.037453    0.012742    0.522459    
#> 446: 0.481609    1.145426    3.533634    0.591903    0.037419    0.012746    0.522483    
#> 447: 0.481534    1.145491    3.533584    0.591790    0.037389    0.012765    0.522479    
#> 448: 0.481441    1.145525    3.533570    0.591627    0.037382    0.012784    0.522454    
#> 449: 0.481294    1.145581    3.533611    0.591372    0.037392    0.012795    0.522481    
#> 450: 0.481267    1.145627    3.533610    0.591243    0.037410    0.012807    0.522457    
#> 451: 0.481380    1.145630    3.533605    0.591371    0.037420    0.012808    0.522483    
#> 452: 0.481315    1.145679    3.533586    0.591025    0.037407    0.012808    0.522465    
#> 453: 0.481254    1.145689    3.533578    0.590629    0.037387    0.012807    0.522463    
#> 454: 0.481356    1.145777    3.533584    0.590880    0.037366    0.012801    0.522425    
#> 455: 0.481475    1.145816    3.533572    0.591208    0.037349    0.012800    0.522396    
#> 456: 0.481486    1.145796    3.533580    0.591155    0.037353    0.012797    0.522435    
#> 457: 0.481381    1.145820    3.533581    0.590882    0.037379    0.012794    0.522428    
#> 458: 0.481384    1.145919    3.533591    0.590761    0.037407    0.012790    0.522395    
#> 459: 0.481219    1.145983    3.533572    0.590700    0.037418    0.012785    0.522412    
#> 460: 0.481066    1.146009    3.533544    0.590505    0.037429    0.012778    0.522384    
#> 461: 0.481015    1.146019    3.533553    0.590219    0.037428    0.012779    0.522337    
#> 462: 0.480840    1.146067    3.533540    0.590145    0.037418    0.012779    0.522289    
#> 463: 0.480864    1.146117    3.533562    0.590051    0.037406    0.012780    0.522244    
#> 464: 0.480989    1.146146    3.533554    0.590090    0.037391    0.012784    0.522184    
#> 465: 0.481035    1.146072    3.533557    0.589882    0.037387    0.012785    0.522142    
#> 466: 0.481065    1.146077    3.533548    0.589887    0.037389    0.012789    0.522138    
#> 467: 0.481091    1.146075    3.533571    0.590032    0.037400    0.012787    0.522084    
#> 468: 0.481226    1.146105    3.533592    0.590384    0.037405    0.012787    0.522086    
#> 469: 0.481272    1.146159    3.533623    0.590286    0.037409    0.012784    0.522070    
#> 470: 0.481233    1.146223    3.533601    0.590469    0.037415    0.012781    0.522112    
#> 471: 0.481149    1.146268    3.533553    0.590470    0.037412    0.012788    0.522104    
#> 472: 0.481016    1.146281    3.533540    0.590344    0.037423    0.012781    0.522064    
#> 473: 0.480891    1.146311    3.533528    0.590161    0.037424    0.012777    0.521999    
#> 474: 0.480787    1.146316    3.533509    0.589844    0.037423    0.012776    0.522030    
#> 475: 0.480734    1.146402    3.533501    0.589603    0.037426    0.012772    0.522065    
#> 476: 0.480526    1.146421    3.533463    0.589545    0.037431    0.012779    0.522092    
#> 477: 0.480416    1.146441    3.533464    0.589489    0.037411    0.012785    0.522066    
#> 478: 0.480321    1.146406    3.533466    0.589313    0.037412    0.012792    0.522081    
#> 479: 0.480377    1.146425    3.533507    0.589123    0.037408    0.012796    0.522083    
#> 480: 0.480557    1.146403    3.533525    0.589352    0.037420    0.012800    0.522137    
#> 481: 0.480601    1.146420    3.533524    0.589197    0.037424    0.012798    0.522138    
#> 482: 0.480601    1.146406    3.533510    0.589279    0.037446    0.012795    0.522131    
#> 483: 0.480479    1.146403    3.533481    0.589308    0.037476    0.012791    0.522124    
#> 484: 0.480467    1.146364    3.533483    0.589418    0.037472    0.012793    0.522065    
#> 485: 0.480526    1.146352    3.533471    0.589567    0.037449    0.012789    0.522059    
#> 486: 0.480595    1.146364    3.533483    0.589666    0.037430    0.012788    0.522030    
#> 487: 0.480747    1.146350    3.533521    0.589847    0.037415    0.012793    0.521980    
#> 488: 0.480850    1.146356    3.533537    0.589990    0.037405    0.012792    0.521971    
#> 489: 0.480934    1.146328    3.533530    0.590098    0.037416    0.012788    0.522006    
#> 490: 0.480958    1.146341    3.533545    0.590076    0.037422    0.012778    0.522002    
#> 491: 0.480986    1.146396    3.533565    0.590163    0.037413    0.012777    0.521999    
#> 492: 0.480906    1.146405    3.533577    0.589961    0.037427    0.012784    0.522057    
#> 493: 0.480815    1.146374    3.533572    0.589930    0.037450    0.012778    0.522080    
#> 494: 0.480941    1.146389    3.533554    0.589771    0.037464    0.012772    0.522071    
#> 495: 0.481052    1.146419    3.533557    0.589565    0.037462    0.012770    0.522057    
#> 496: 0.481297    1.146459    3.533547    0.589799    0.037460    0.012774    0.522059    
#> 497: 0.481279    1.146410    3.533579    0.589479    0.037463    0.012776    0.522079    
#> 498: 0.481304    1.146356    3.533606    0.589327    0.037469    0.012772    0.522076    
#> 499: 0.481276    1.146365    3.533594    0.589307    0.037482    0.012764    0.522052    
#> 500: 0.481290    1.146320    3.533574    0.589523    0.037480    0.012758    0.522071    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.293996    0.956759    3.442237    0.392401    0.088909    0.016800    1.800463    
#> 002: 0.337049    0.911959    3.458485    0.372781    0.084463    0.015960    1.302529    
#> 003: 0.472494    0.875340    3.469152    0.354142    0.080240    0.015162    1.048054    
#> 004: 0.442707    0.874773    3.465548    0.336435    0.076228    0.015261    0.968960    
#> 005: 0.473874    0.907978    3.455038    0.319613    0.072417    0.014497    0.964884    
#> 006: 0.425943    0.898792    3.430694    0.303633    0.068796    0.013773    0.927697    
#> 007: 0.348063    0.902942    3.421388    0.288451    0.066314    0.013084    0.941864    
#> 008: 0.352296    0.890738    3.417248    0.274029    0.070669    0.012430    0.920878    
#> 009: 0.349620    0.885558    3.415612    0.260327    0.067135    0.011808    0.914695    
#> 010: 0.366410    0.883945    3.434642    0.247311    0.065228    0.011218    0.928385    
#> 011: 0.427387    0.899355    3.431162    0.267315    0.078913    0.011097    0.910703    
#> 012: 0.381751    0.905162    3.423050    0.296565    0.079419    0.011561    0.898348    
#> 013: 0.299350    0.908048    3.403768    0.281737    0.075448    0.011235    0.913132    
#> 014: 0.333106    0.929121    3.405193    0.267650    0.071676    0.013107    0.947292    
#> 015: 0.345802    0.935644    3.426306    0.254267    0.068092    0.012451    0.914649    
#> 016: 0.371029    0.951944    3.432856    0.241554    0.064687    0.014017    0.924529    
#> 017: 0.351650    0.948957    3.422158    0.229476    0.061453    0.013316    0.896331    
#> 018: 0.334462    0.969300    3.397430    0.229415    0.059903    0.014236    0.901918    
#> 019: 0.283722    0.971972    3.400543    0.217945    0.061476    0.013524    0.888276    
#> 020: 0.311686    0.962383    3.408621    0.207047    0.058403    0.012848    0.919005    
#> 021: 0.308825    0.950384    3.405964    0.209264    0.055483    0.012562    0.892891    
#> 022: 0.319208    0.936630    3.413620    0.203147    0.052708    0.011933    0.888349    
#> 023: 0.389311    0.937841    3.428419    0.253534    0.050073    0.012203    0.909449    
#> 024: 0.429104    0.942149    3.425185    0.289965    0.047569    0.011593    0.908906    
#> 025: 0.357592    0.921076    3.419440    0.275467    0.053961    0.011013    0.899618    
#> 026: 0.329861    0.964990    3.414375    0.261694    0.062751    0.010462    0.903753    
#> 027: 0.316677    0.970902    3.402995    0.248609    0.063630    0.012765    0.907398    
#> 028: 0.379959    0.944624    3.414251    0.236178    0.060449    0.012127    0.890259    
#> 029: 0.360713    0.932426    3.410624    0.314111    0.062374    0.011521    0.887131    
#> 030: 0.351568    0.939928    3.402021    0.298405    0.059255    0.010945    0.894645    
#> 031: 0.330681    0.936493    3.409058    0.322556    0.075273    0.010397    0.889792    
#> 032: 0.325495    0.953953    3.414848    0.306428    0.071509    0.009878    0.890206    
#> 033: 0.294198    0.943117    3.402565    0.291107    0.067934    0.009384    0.908543    
#> 034: 0.327629    0.961823    3.395864    0.276552    0.067665    0.008915    0.904728    
#> 035: 0.288748    0.951775    3.386198    0.298906    0.064282    0.008469    0.895445    
#> 036: 0.305208    0.963702    3.382798    0.371847    0.068884    0.008045    0.897551    
#> 037: 0.310177    0.967413    3.388677    0.353254    0.065440    0.007643    0.911788    
#> 038: 0.361448    0.973623    3.383211    0.379210    0.062168    0.007261    0.908761    
#> 039: 0.318372    0.970424    3.392502    0.398216    0.059060    0.007261    0.906255    
#> 040: 0.280281    0.978515    3.387891    0.427479    0.056107    0.007363    0.895901    
#> 041: 0.305115    0.938474    3.389081    0.462141    0.057918    0.006995    0.894929    
#> 042: 0.345679    0.911974    3.398325    0.439034    0.057245    0.006645    0.895119    
#> 043: 0.327525    0.954918    3.394442    0.417082    0.058281    0.006313    0.882765    
#> 044: 0.310780    0.961073    3.396990    0.396228    0.055989    0.005997    0.889033    
#> 045: 0.327516    0.987215    3.394614    0.376417    0.060355    0.005697    0.872633    
#> 046: 0.317719    0.968104    3.401552    0.357596    0.057337    0.005412    0.880959    
#> 047: 0.322567    0.981962    3.392105    0.339716    0.055068    0.005309    0.875031    
#> 048: 0.328311    0.955691    3.393632    0.322730    0.060968    0.005807    0.900288    
#> 049: 0.321528    0.961907    3.401097    0.316037    0.071931    0.005654    0.896283    
#> 050: 0.371979    0.919924    3.393961    0.300235    0.068334    0.005372    0.931722    
#> 051: 0.322223    0.960251    3.399499    0.301885    0.064917    0.005103    0.943332    
#> 052: 0.348323    0.965940    3.399989    0.363657    0.066284    0.004848    0.918195    
#> 053: 0.369970    0.945220    3.409518    0.345474    0.066132    0.004606    0.920324    
#> 054: 0.291808    0.945314    3.417981    0.328200    0.082799    0.004375    0.908245    
#> 055: 0.333816    0.958038    3.417281    0.311790    0.079357    0.004396    0.903037    
#> 056: 0.381153    0.940504    3.421069    0.296201    0.077931    0.004903    0.939202    
#> 057: 0.361033    0.950922    3.423005    0.281391    0.074034    0.004658    0.947046    
#> 058: 0.382541    0.941633    3.416816    0.267321    0.071348    0.004425    0.929103    
#> 059: 0.346066    0.909475    3.412655    0.347517    0.081038    0.004204    0.920925    
#> 060: 0.347103    0.908215    3.417043    0.330141    0.076986    0.004267    0.931753    
#> 061: 0.378383    0.921632    3.417616    0.313634    0.085841    0.004202    0.920300    
#> 062: 0.386388    0.952310    3.419168    0.297952    0.096525    0.004118    0.935451    
#> 063: 0.403348    0.927665    3.414956    0.308916    0.092434    0.004023    0.914870    
#> 064: 0.327999    0.934337    3.412337    0.338700    0.087812    0.003822    0.892519    
#> 065: 0.368967    0.923902    3.405988    0.321765    0.085279    0.003631    0.905237    
#> 066: 0.370528    0.945117    3.416225    0.308775    0.087201    0.004863    0.868028    
#> 067: 0.337558    0.942329    3.406974    0.293336    0.082841    0.006104    0.876766    
#> 068: 0.302408    0.959992    3.401275    0.278670    0.078699    0.005799    0.917213    
#> 069: 0.279345    0.971012    3.388411    0.264736    0.078122    0.006469    0.944237    
#> 070: 0.314494    0.944710    3.403293    0.272605    0.074215    0.007021    0.921655    
#> 071: 0.313640    0.982468    3.391413    0.258974    0.070505    0.008008    0.943812    
#> 072: 0.250202    0.972254    3.370966    0.315060    0.074736    0.007608    0.904246    
#> 073: 0.303635    0.959985    3.391341    0.299307    0.071000    0.007546    0.893475    
#> 074: 0.310426    0.956311    3.398740    0.284341    0.070077    0.007169    0.914075    
#> 075: 0.349983    0.937572    3.418237    0.283249    0.077228    0.006810    0.903735    
#> 076: 0.362078    0.966441    3.429544    0.309551    0.073366    0.006470    0.933255    
#> 077: 0.400422    0.915797    3.420375    0.295910    0.069698    0.006146    0.906717    
#> 078: 0.361003    0.915667    3.425025    0.281114    0.075883    0.005952    0.901134    
#> 079: 0.364260    0.946971    3.418832    0.273061    0.072088    0.005960    0.928978    
#> 080: 0.352620    0.936311    3.416116    0.312943    0.092362    0.005662    0.947878    
#> 081: 0.342588    0.943581    3.411490    0.297296    0.087744    0.005756    0.901639    
#> 082: 0.363997    0.924420    3.427294    0.282431    0.083357    0.007749    0.927405    
#> 083: 0.370453    0.973521    3.422419    0.268309    0.079189    0.007362    0.906720    
#> 084: 0.332647    0.964582    3.412242    0.254894    0.075230    0.006993    0.897202    
#> 085: 0.333605    0.939033    3.412779    0.271366    0.071468    0.006644    0.908087    
#> 086: 0.345743    0.937651    3.414141    0.271327    0.067895    0.007630    0.912249    
#> 087: 0.342494    0.937014    3.406766    0.257761    0.064500    0.007249    0.916501    
#> 088: 0.266466    0.955275    3.404650    0.248655    0.061275    0.007746    0.913067    
#> 089: 0.302334    0.961556    3.391756    0.249576    0.067132    0.008560    0.919761    
#> 090: 0.287318    0.967729    3.393839    0.242129    0.063775    0.008132    0.892798    
#> 091: 0.303739    0.939857    3.385293    0.275603    0.060674    0.008521    0.893950    
#> 092: 0.328459    0.968647    3.388163    0.261822    0.060781    0.009670    0.891438    
#> 093: 0.276711    0.935262    3.387262    0.251215    0.075597    0.010669    0.909261    
#> 094: 0.301084    0.956178    3.391312    0.275287    0.071817    0.011157    0.918817    
#> 095: 0.342063    0.962312    3.409712    0.268834    0.068226    0.010599    0.914106    
#> 096: 0.323498    0.945556    3.400198    0.260111    0.064815    0.010069    0.900346    
#> 097: 0.333048    0.977755    3.396715    0.305955    0.061574    0.012463    0.888163    
#> 098: 0.307001    0.991972    3.390523    0.290658    0.058495    0.011840    0.920761    
#> 099: 0.285105    0.972522    3.372505    0.308172    0.055570    0.011248    0.904321    
#> 100: 0.276100    0.972749    3.370208    0.311943    0.052792    0.010686    0.886972    
#> 101: 0.227199    0.959770    3.358890    0.307460    0.053299    0.010151    0.900768    
#> 102: 0.264801    0.960577    3.358137    0.299617    0.071899    0.009644    0.910796    
#> 103: 0.335471    0.963988    3.382517    0.314732    0.068304    0.009162    0.875424    
#> 104: 0.319691    0.972761    3.393639    0.404219    0.064913    0.008704    0.900043    
#> 105: 0.276772    0.978599    3.379175    0.384008    0.073711    0.008268    0.901178    
#> 106: 0.278994    0.987392    3.375989    0.364808    0.070026    0.007855    0.887435    
#> 107: 0.331638    0.982250    3.379668    0.392756    0.066524    0.007462    0.899203    
#> 108: 0.283883    0.983680    3.369507    0.373119    0.069507    0.007089    0.907647    
#> 109: 0.281644    0.986101    3.382841    0.381111    0.066032    0.006735    0.921988    
#> 110: 0.290274    0.975900    3.360885    0.401439    0.063292    0.006398    0.901088    
#> 111: 0.291171    1.004430    3.363917    0.381368    0.062990    0.006078    0.882546    
#> 112: 0.258226    0.972675    3.352809    0.362299    0.086289    0.005774    0.894000    
#> 113: 0.277198    0.991899    3.358416    0.345268    0.081975    0.005485    0.900359    
#> 114: 0.246267    0.995488    3.360793    0.328005    0.077876    0.005211    0.904215    
#> 115: 0.273898    0.975432    3.362547    0.320961    0.073982    0.005873    0.899444    
#> 116: 0.261923    0.982588    3.368528    0.304912    0.070283    0.006090    0.912656    
#> 117: 0.272759    0.992939    3.378509    0.340681    0.066769    0.006184    0.883826    
#> 118: 0.312177    0.986005    3.380335    0.323647    0.063431    0.006273    0.888220    
#> 119: 0.311063    0.979756    3.383781    0.307465    0.060259    0.007415    0.904586    
#> 120: 0.290790    0.959967    3.382613    0.298078    0.057246    0.007830    0.870876    
#> 121: 0.302924    0.966943    3.374412    0.300956    0.059449    0.008792    0.891533    
#> 122: 0.284714    0.956088    3.390665    0.285909    0.058206    0.008644    0.899369    
#> 123: 0.349592    0.971414    3.395266    0.271613    0.055296    0.008286    0.898866    
#> 124: 0.329537    0.995178    3.388003    0.258032    0.052531    0.009378    0.911319    
#> 125: 0.312519    1.000818    3.387465    0.249798    0.055879    0.010430    0.903326    
#> 126: 0.285859    1.006012    3.379331    0.295241    0.053085    0.012662    0.903460    
#> 127: 0.272453    0.994064    3.366297    0.322554    0.050431    0.012029    0.881587    
#> 128: 0.270020    0.975914    3.384184    0.306427    0.051769    0.012496    0.879578    
#> 129: 0.352546    0.971397    3.397275    0.291105    0.075196    0.011872    0.885591    
#> 130: 0.380321    0.977728    3.395842    0.291492    0.071436    0.011619    0.889122    
#> 131: 0.334439    0.982635    3.374295    0.276918    0.069332    0.011823    0.881348    
#> 132: 0.269642    0.984361    3.360556    0.280670    0.078260    0.011232    0.899312    
#> 133: 0.304516    0.976084    3.375718    0.347976    0.086845    0.010671    0.905657    
#> 134: 0.336508    0.964909    3.389434    0.330577    0.082503    0.011777    0.899027    
#> 135: 0.320549    0.935123    3.398264    0.328317    0.078378    0.011188    0.912059    
#> 136: 0.332697    0.936685    3.390405    0.369530    0.074459    0.011150    0.894580    
#> 137: 0.380205    0.933001    3.405364    0.376757    0.070736    0.010592    0.898863    
#> 138: 0.371229    0.927272    3.408657    0.376115    0.067199    0.010063    0.896991    
#> 139: 0.370210    0.953400    3.413086    0.357309    0.063839    0.011766    0.866031    
#> 140: 0.331237    0.955783    3.412195    0.339444    0.061366    0.011892    0.895012    
#> 141: 0.332156    0.943948    3.413403    0.322471    0.070041    0.011297    0.896158    
#> 142: 0.377666    0.922073    3.427553    0.306348    0.068654    0.010732    0.906422    
#> 143: 0.298986    0.939774    3.412732    0.291030    0.075110    0.010196    0.928985    
#> 144: 0.366069    0.940819    3.425628    0.276479    0.071355    0.009686    0.897977    
#> 145: 0.314917    0.967829    3.401621    0.262655    0.067787    0.009202    0.891213    
#> 146: 0.321650    0.970196    3.410703    0.249622    0.066691    0.012029    0.917042    
#> 147: 0.298190    0.932378    3.401947    0.237141    0.063357    0.011427    0.917461    
#> 148: 0.328164    0.954791    3.414614    0.225284    0.060189    0.010856    0.898478    
#> 149: 0.333724    0.943199    3.417826    0.272267    0.057180    0.010322    0.907208    
#> 150: 0.355881    0.931300    3.404206    0.300745    0.062055    0.009806    0.906250    
#> 151: 0.318319    0.967612    3.396474    0.300727    0.062439    0.009315    0.905539    
#> 152: 0.351141    0.953247    3.408625    0.277730    0.066221    0.007724    0.907717    
#> 153: 0.364028    0.969545    3.410788    0.277486    0.072002    0.007941    0.910273    
#> 154: 0.357237    0.977104    3.412295    0.260949    0.067273    0.010357    0.912120    
#> 155: 0.342208    0.929380    3.411275    0.275145    0.054038    0.010933    0.889438    
#> 156: 0.345465    0.949658    3.417924    0.280536    0.069440    0.012269    0.895297    
#> 157: 0.363485    0.922126    3.418838    0.326367    0.075599    0.010570    0.917438    
#> 158: 0.394630    0.982176    3.411669    0.282825    0.079615    0.010627    0.887398    
#> 159: 0.319872    0.966039    3.410929    0.292557    0.059677    0.009642    0.889798    
#> 160: 0.361583    0.929681    3.426462    0.284822    0.075490    0.008598    0.917852    
#> 161: 0.337811    0.942503    3.419126    0.285035    0.060418    0.009973    0.912078    
#> 162: 0.358314    0.962016    3.407188    0.359480    0.051087    0.009404    0.886165    
#> 163: 0.379153    0.937636    3.407165    0.335920    0.052993    0.007546    0.893585    
#> 164: 0.371417    0.943165    3.408969    0.381386    0.049084    0.009627    0.883566    
#> 165: 0.378007    0.948229    3.416140    0.336989    0.057859    0.008390    0.879421    
#> 166: 0.428130    0.980671    3.420428    0.442712    0.056428    0.007329    0.886432    
#> 167: 0.450868    0.981578    3.423921    0.428197    0.057415    0.007540    0.909155    
#> 168: 0.462717    0.960501    3.433135    0.401721    0.053286    0.009150    0.907683    
#> 169: 0.414770    0.974949    3.413368    0.370967    0.058408    0.008124    0.915912    
#> 170: 0.414294    0.950359    3.412045    0.425994    0.053873    0.009464    0.901702    
#> 171: 0.334938    0.963091    3.411244    0.309864    0.064117    0.008189    0.889881    
#> 172: 0.324310    0.987977    3.394058    0.210972    0.047111    0.008663    0.897007    
#> 173: 0.321242    1.000703    3.382539    0.270842    0.048224    0.008799    0.891368    
#> 174: 0.320615    0.991508    3.389241    0.377173    0.042980    0.010224    0.880319    
#> 175: 0.353684    0.980758    3.387938    0.301050    0.050992    0.011783    0.879379    
#> 176: 0.339893    0.988434    3.397831    0.329336    0.048125    0.010435    0.887857    
#> 177: 0.336416    0.981468    3.401691    0.336097    0.046855    0.012081    0.874020    
#> 178: 0.338751    0.953602    3.405138    0.307063    0.043006    0.011388    0.864629    
#> 179: 0.379642    0.963108    3.409276    0.366984    0.046277    0.012701    0.875910    
#> 180: 0.337240    0.952164    3.412256    0.339562    0.045343    0.014007    0.866868    
#> 181: 0.344313    0.935685    3.398854    0.265016    0.050020    0.013508    0.871650    
#> 182: 0.297270    0.963181    3.379479    0.275278    0.054170    0.012126    0.881105    
#> 183: 0.300133    0.996752    3.377866    0.310259    0.046672    0.011283    0.880486    
#> 184: 0.321801    0.965602    3.376007    0.316271    0.043041    0.009760    0.889675    
#> 185: 0.295456    0.985713    3.378505    0.285449    0.037169    0.008606    0.916688    
#> 186: 0.306527    0.987484    3.390106    0.316929    0.054702    0.009910    0.893010    
#> 187: 0.311850    0.970621    3.391147    0.373740    0.047687    0.011477    0.865607    
#> 188: 0.276292    0.999701    3.384114    0.307578    0.053436    0.010517    0.907737    
#> 189: 0.314523    1.007972    3.391407    0.287521    0.055111    0.011704    0.910917    
#> 190: 0.360188    0.991949    3.400416    0.334471    0.052249    0.012458    0.892065    
#> 191: 0.332414    0.977884    3.394153    0.287862    0.048057    0.010858    0.879310    
#> 192: 0.276338    0.986124    3.384292    0.300803    0.046233    0.008406    0.888554    
#> 193: 0.328808    0.992850    3.393772    0.288212    0.046614    0.006302    0.880097    
#> 194: 0.292832    0.982847    3.375559    0.369013    0.064943    0.005243    0.892565    
#> 195: 0.251262    0.961416    3.373607    0.387219    0.049745    0.003703    0.914491    
#> 196: 0.261484    0.977453    3.376487    0.332733    0.067046    0.004491    0.905762    
#> 197: 0.267330    0.999955    3.390540    0.283265    0.061617    0.004875    0.894122    
#> 198: 0.315356    0.988082    3.375566    0.269852    0.061477    0.005960    0.884260    
#> 199: 0.293704    0.976405    3.384942    0.274335    0.076110    0.004093    0.880721    
#> 200: 0.301853    0.977742    3.381025    0.336757    0.077473    0.005448    0.895898    
#> 201: 0.300487    0.963374    3.384854    0.332145    0.071893    0.006135    0.893364    
#> 202: 0.315150    0.958064    3.385613    0.330207    0.071611    0.005876    0.899356    
#> 203: 0.322088    0.952659    3.386862    0.321043    0.069952    0.006030    0.902155    
#> 204: 0.324082    0.946584    3.389558    0.310938    0.067605    0.006011    0.906837    
#> 205: 0.321128    0.950414    3.391564    0.303626    0.066311    0.006434    0.907540    
#> 206: 0.319914    0.957752    3.390959    0.299556    0.067147    0.006576    0.910165    
#> 207: 0.316257    0.956646    3.390410    0.297056    0.066018    0.006677    0.911610    
#> 208: 0.314419    0.954546    3.391599    0.295567    0.064744    0.006862    0.911261    
#> 209: 0.316102    0.953541    3.390906    0.294107    0.063407    0.006951    0.911172    
#> 210: 0.320561    0.952870    3.391278    0.291505    0.062845    0.006948    0.907978    
#> 211: 0.323088    0.953887    3.392691    0.287232    0.062750    0.006922    0.906008    
#> 212: 0.326659    0.952603    3.393673    0.285356    0.061919    0.006889    0.904572    
#> 213: 0.327037    0.949890    3.394003    0.283510    0.060879    0.007075    0.905719    
#> 214: 0.328977    0.949695    3.394597    0.282066    0.061101    0.007392    0.905658    
#> 215: 0.330511    0.950678    3.395763    0.283574    0.060619    0.007673    0.906042    
#> 216: 0.332704    0.949713    3.396038    0.286333    0.060719    0.007721    0.908783    
#> 217: 0.333788    0.950419    3.395882    0.283576    0.060238    0.007674    0.910182    
#> 218: 0.334391    0.950628    3.395467    0.283356    0.060204    0.007637    0.909679    
#> 219: 0.333693    0.949733    3.394644    0.287436    0.060387    0.007691    0.908511    
#> 220: 0.331773    0.950187    3.394421    0.288072    0.059723    0.007674    0.908309    
#> 221: 0.330625    0.950251    3.394258    0.290157    0.059142    0.007618    0.907068    
#> 222: 0.331437    0.949823    3.394563    0.291229    0.059180    0.007731    0.905717    
#> 223: 0.332736    0.949905    3.394955    0.291707    0.059553    0.007742    0.903921    
#> 224: 0.333427    0.949962    3.395622    0.293509    0.059597    0.007831    0.902750    
#> 225: 0.333884    0.948543    3.396138    0.297158    0.059610    0.007844    0.902769    
#> 226: 0.332883    0.947282    3.395962    0.300149    0.059437    0.007789    0.903328    
#> 227: 0.333172    0.947327    3.396450    0.302142    0.059494    0.007707    0.903715    
#> 228: 0.333099    0.948683    3.396429    0.304734    0.059600    0.007682    0.903731    
#> 229: 0.332886    0.948733    3.396465    0.306383    0.059703    0.007684    0.902882    
#> 230: 0.332859    0.948872    3.396127    0.306939    0.059636    0.007666    0.902497    
#> 231: 0.332507    0.949864    3.395991    0.307693    0.059565    0.007639    0.902447    
#> 232: 0.331210    0.950283    3.395929    0.306199    0.059407    0.007634    0.902819    
#> 233: 0.330662    0.949752    3.395772    0.306410    0.059062    0.007692    0.902901    
#> 234: 0.329629    0.950293    3.395903    0.305947    0.059068    0.007705    0.902818    
#> 235: 0.329492    0.950895    3.395915    0.306203    0.058987    0.007664    0.903030    
#> 236: 0.330178    0.951528    3.395877    0.305959    0.058922    0.007671    0.903610    
#> 237: 0.331509    0.952540    3.395655    0.306615    0.059260    0.007732    0.903720    
#> 238: 0.332383    0.953004    3.395651    0.306925    0.059772    0.007722    0.903990    
#> 239: 0.332282    0.954028    3.395636    0.306411    0.060035    0.007802    0.903907    
#> 240: 0.332177    0.954160    3.395741    0.306039    0.060446    0.007838    0.903551    
#> 241: 0.331170    0.953942    3.395729    0.306383    0.060541    0.007805    0.903965    
#> 242: 0.330622    0.954047    3.395527    0.306120    0.060408    0.007821    0.904631    
#> 243: 0.329826    0.955248    3.395346    0.305436    0.060447    0.007839    0.904767    
#> 244: 0.329840    0.955367    3.395456    0.306040    0.060606    0.007877    0.905090    
#> 245: 0.329506    0.955148    3.395500    0.306770    0.060840    0.007873    0.905196    
#> 246: 0.329286    0.954816    3.395785    0.306499    0.060504    0.007932    0.905300    
#> 247: 0.329324    0.954467    3.396254    0.305831    0.060269    0.007952    0.904918    
#> 248: 0.329981    0.954577    3.396567    0.305198    0.060130    0.007936    0.904492    
#> 249: 0.330285    0.954462    3.396895    0.305323    0.060128    0.007945    0.904210    
#> 250: 0.330698    0.954747    3.397071    0.304521    0.060080    0.007954    0.904044    
#> 251: 0.330974    0.955309    3.397228    0.305524    0.060271    0.007933    0.903636    
#> 252: 0.331531    0.955567    3.397378    0.305606    0.060615    0.007911    0.903239    
#> 253: 0.331749    0.955374    3.397598    0.305467    0.061016    0.007912    0.903006    
#> 254: 0.332368    0.955827    3.397934    0.305831    0.061128    0.007922    0.902564    
#> 255: 0.332306    0.956019    3.398252    0.305268    0.061202    0.007982    0.902593    
#> 256: 0.332888    0.955475    3.398500    0.305081    0.061124    0.008022    0.902352    
#> 257: 0.332957    0.955031    3.398499    0.305942    0.061008    0.008022    0.902293    
#> 258: 0.332603    0.954914    3.398560    0.304498    0.060868    0.007995    0.902686    
#> 259: 0.332282    0.954899    3.398573    0.303423    0.061140    0.007965    0.902694    
#> 260: 0.332232    0.955339    3.398676    0.304220    0.061183    0.007960    0.902211    
#> 261: 0.332655    0.955281    3.398840    0.305695    0.061151    0.007967    0.901835    
#> 262: 0.333105    0.955651    3.398821    0.305689    0.061363    0.007958    0.901707    
#> 263: 0.333075    0.956210    3.398797    0.306000    0.061448    0.007974    0.901471    
#> 264: 0.332518    0.956473    3.398545    0.306375    0.061209    0.007964    0.901671    
#> 265: 0.332351    0.956728    3.398374    0.306071    0.061227    0.007974    0.901641    
#> 266: 0.332319    0.957167    3.398169    0.305902    0.061186    0.008002    0.901439    
#> 267: 0.332305    0.957429    3.398077    0.305203    0.061330    0.007998    0.901549    
#> 268: 0.332351    0.957666    3.397947    0.304798    0.061385    0.007983    0.901583    
#> 269: 0.332987    0.957622    3.397862    0.304222    0.061469    0.007977    0.901683    
#> 270: 0.332807    0.957822    3.397529    0.303803    0.061522    0.007964    0.901545    
#> 271: 0.332781    0.957871    3.397304    0.304050    0.061498    0.007952    0.901275    
#> 272: 0.332277    0.957866    3.397040    0.305213    0.061538    0.007920    0.901191    
#> 273: 0.332005    0.958205    3.396971    0.305095    0.061758    0.007895    0.901199    
#> 274: 0.331756    0.958494    3.396982    0.305626    0.061887    0.007856    0.901211    
#> 275: 0.331441    0.958768    3.396845    0.305589    0.061875    0.007842    0.901020    
#> 276: 0.331252    0.958833    3.396982    0.306221    0.061894    0.007843    0.901152    
#> 277: 0.331554    0.959161    3.397077    0.306311    0.061902    0.007847    0.901187    
#> 278: 0.331573    0.959077    3.397235    0.306234    0.061882    0.007835    0.901202    
#> 279: 0.331250    0.958810    3.397278    0.305897    0.061993    0.007840    0.901407    
#> 280: 0.331281    0.958990    3.397549    0.306099    0.062097    0.007837    0.901300    
#> 281: 0.330966    0.958959    3.397706    0.305673    0.062055    0.007834    0.901489    
#> 282: 0.331132    0.959258    3.397888    0.305331    0.062196    0.007795    0.901405    
#> 283: 0.330932    0.959473    3.397974    0.305111    0.062175    0.007786    0.901625    
#> 284: 0.331210    0.959027    3.398064    0.305088    0.062078    0.007764    0.901726    
#> 285: 0.331141    0.959013    3.398017    0.305241    0.062160    0.007764    0.901678    
#> 286: 0.330003    0.959274    3.397731    0.304984    0.062261    0.007764    0.901766    
#> 287: 0.329018    0.959900    3.397361    0.304745    0.062452    0.007761    0.901986    
#> 288: 0.328902    0.959991    3.397042    0.305117    0.062491    0.007746    0.902027    
#> 289: 0.329067    0.959928    3.396910    0.305117    0.062391    0.007745    0.902194    
#> 290: 0.328975    0.959901    3.396701    0.305598    0.062374    0.007734    0.902336    
#> 291: 0.328921    0.960274    3.396611    0.305325    0.062429    0.007710    0.902268    
#> 292: 0.328630    0.960519    3.396504    0.305133    0.062498    0.007699    0.902218    
#> 293: 0.328418    0.960699    3.396332    0.304278    0.062563    0.007685    0.902163    
#> 294: 0.327954    0.960956    3.396161    0.303770    0.062705    0.007670    0.902179    
#> 295: 0.327745    0.960762    3.396093    0.303737    0.062802    0.007644    0.901970    
#> 296: 0.327359    0.960893    3.395935    0.304165    0.062780    0.007610    0.902011    
#> 297: 0.327226    0.960997    3.395862    0.303928    0.062663    0.007602    0.902020    
#> 298: 0.327309    0.960812    3.395842    0.304445    0.062513    0.007584    0.902082    
#> 299: 0.327479    0.961037    3.395810    0.304600    0.062461    0.007562    0.901899    
#> 300: 0.327387    0.961070    3.395903    0.304486    0.062393    0.007532    0.901748    
#> 301: 0.327577    0.961096    3.395880    0.304226    0.062395    0.007513    0.901818    
#> 302: 0.327649    0.961357    3.395818    0.304323    0.062437    0.007495    0.901753    
#> 303: 0.327239    0.961471    3.395701    0.304642    0.062534    0.007495    0.901499    
#> 304: 0.326960    0.961488    3.395649    0.304867    0.062439    0.007490    0.901459    
#> 305: 0.326939    0.961339    3.395616    0.304635    0.062458    0.007489    0.901340    
#> 306: 0.326529    0.961161    3.395549    0.304458    0.062520    0.007469    0.901331    
#> 307: 0.326268    0.960819    3.395451    0.304364    0.062704    0.007455    0.901330    
#> 308: 0.325656    0.960564    3.395342    0.304052    0.062926    0.007444    0.901467    
#> 309: 0.325568    0.960371    3.395304    0.303877    0.062885    0.007439    0.901555    
#> 310: 0.325803    0.960269    3.395142    0.304370    0.062860    0.007423    0.901692    
#> 311: 0.325840    0.960139    3.395089    0.304453    0.062941    0.007404    0.901613    
#> 312: 0.325703    0.960024    3.394909    0.304609    0.062981    0.007396    0.901570    
#> 313: 0.325314    0.959789    3.394836    0.304690    0.062929    0.007387    0.901640    
#> 314: 0.324975    0.959773    3.394734    0.304378    0.062849    0.007368    0.901737    
#> 315: 0.324468    0.959909    3.394676    0.304446    0.062815    0.007353    0.901884    
#> 316: 0.324373    0.960140    3.394612    0.303963    0.062890    0.007334    0.901960    
#> 317: 0.324304    0.960252    3.394586    0.303959    0.062885    0.007331    0.901984    
#> 318: 0.324609    0.960347    3.394513    0.304641    0.062792    0.007322    0.901729    
#> 319: 0.324884    0.960360    3.394491    0.304986    0.062854    0.007309    0.901556    
#> 320: 0.324626    0.960373    3.394376    0.305340    0.062870    0.007297    0.901508    
#> 321: 0.324203    0.960345    3.394158    0.305639    0.062812    0.007291    0.901499    
#> 322: 0.324096    0.960554    3.393923    0.305841    0.062727    0.007297    0.901506    
#> 323: 0.323487    0.960650    3.393828    0.305970    0.062613    0.007309    0.901735    
#> 324: 0.323604    0.960714    3.393873    0.305860    0.062667    0.007306    0.901637    
#> 325: 0.323551    0.960968    3.393886    0.305762    0.062746    0.007300    0.901535    
#> 326: 0.323307    0.960781    3.393827    0.305652    0.062745    0.007285    0.901471    
#> 327: 0.323372    0.960990    3.393867    0.305580    0.062876    0.007290    0.901247    
#> 328: 0.323335    0.961185    3.393820    0.305227    0.062860    0.007287    0.901240    
#> 329: 0.323631    0.961307    3.393842    0.305198    0.062832    0.007284    0.901140    
#> 330: 0.323540    0.961426    3.393871    0.304759    0.062801    0.007285    0.901316    
#> 331: 0.323391    0.961649    3.393843    0.304377    0.062779    0.007270    0.901398    
#> 332: 0.323313    0.961538    3.393779    0.304069    0.062674    0.007240    0.901716    
#> 333: 0.323023    0.961540    3.393642    0.303843    0.062615    0.007220    0.901855    
#> 334: 0.322648    0.961628    3.393483    0.303925    0.062533    0.007218    0.901832    
#> 335: 0.322215    0.961691    3.393314    0.303677    0.062552    0.007203    0.901775    
#> 336: 0.321791    0.961754    3.393196    0.303578    0.062653    0.007193    0.901768    
#> 337: 0.321569    0.962051    3.393124    0.303645    0.062737    0.007183    0.901685    
#> 338: 0.321688    0.962221    3.393126    0.303282    0.062787    0.007177    0.901738    
#> 339: 0.321436    0.962407    3.393088    0.303359    0.062778    0.007182    0.901687    
#> 340: 0.321360    0.962347    3.393101    0.303625    0.062976    0.007182    0.901659    
#> 341: 0.321570    0.962231    3.393197    0.303836    0.063010    0.007184    0.901608    
#> 342: 0.321200    0.962089    3.393202    0.303833    0.062983    0.007184    0.901585    
#> 343: 0.320815    0.962206    3.393199    0.303437    0.062940    0.007189    0.901698    
#> 344: 0.320798    0.962095    3.393266    0.303450    0.062764    0.007197    0.901854    
#> 345: 0.320714    0.962038    3.393273    0.303248    0.062739    0.007202    0.901728    
#> 346: 0.320515    0.962109    3.393247    0.302814    0.062649    0.007200    0.901722    
#> 347: 0.320516    0.962081    3.393114    0.302704    0.062642    0.007211    0.901871    
#> 348: 0.320102    0.962230    3.392982    0.303023    0.062636    0.007212    0.902007    
#> 349: 0.319946    0.962377    3.392849    0.303148    0.062572    0.007223    0.901967    
#> 350: 0.319899    0.962352    3.392746    0.303456    0.062531    0.007233    0.901908    
#> 351: 0.319896    0.962528    3.392644    0.303168    0.062514    0.007238    0.901968    
#> 352: 0.319597    0.962645    3.392637    0.303068    0.062465    0.007252    0.902148    
#> 353: 0.319578    0.962908    3.392567    0.302869    0.062472    0.007258    0.902171    
#> 354: 0.319550    0.963095    3.392451    0.302755    0.062457    0.007263    0.901997    
#> 355: 0.319820    0.963040    3.392434    0.302926    0.062454    0.007250    0.901813    
#> 356: 0.319538    0.963032    3.392394    0.302821    0.062548    0.007234    0.901786    
#> 357: 0.319655    0.963119    3.392376    0.302754    0.062524    0.007220    0.901841    
#> 358: 0.319793    0.963299    3.392409    0.303188    0.062416    0.007224    0.901819    
#> 359: 0.319604    0.963571    3.392315    0.303485    0.062378    0.007230    0.901772    
#> 360: 0.319275    0.963659    3.392129    0.303331    0.062341    0.007233    0.901669    
#> 361: 0.318806    0.963791    3.392019    0.303199    0.062300    0.007242    0.901759    
#> 362: 0.318921    0.963709    3.391991    0.303037    0.062243    0.007240    0.901653    
#> 363: 0.318783    0.963602    3.391950    0.302502    0.062172    0.007242    0.901644    
#> 364: 0.318907    0.963764    3.391983    0.301981    0.062108    0.007256    0.901613    
#> 365: 0.318881    0.963728    3.392051    0.301661    0.062000    0.007266    0.901605    
#> 366: 0.318935    0.963733    3.391999    0.301783    0.062042    0.007278    0.901488    
#> 367: 0.318932    0.963748    3.392012    0.302092    0.062113    0.007266    0.901378    
#> 368: 0.319211    0.963834    3.392004    0.302438    0.062018    0.007257    0.901368    
#> 369: 0.319261    0.963845    3.392031    0.302447    0.061981    0.007255    0.901392    
#> 370: 0.319249    0.963943    3.391998    0.302433    0.061893    0.007266    0.901475    
#> 371: 0.319027    0.963947    3.391909    0.302452    0.061879    0.007265    0.901494    
#> 372: 0.318790    0.964077    3.391810    0.302753    0.061873    0.007268    0.901587    
#> 373: 0.318528    0.964245    3.391754    0.303181    0.061869    0.007262    0.901601    
#> 374: 0.318489    0.964311    3.391705    0.303280    0.061867    0.007246    0.901515    
#> 375: 0.318332    0.964280    3.391619    0.303501    0.061889    0.007236    0.901525    
#> 376: 0.318240    0.964281    3.391581    0.303704    0.061913    0.007232    0.901437    
#> 377: 0.318243    0.964356    3.391552    0.303520    0.061976    0.007227    0.901403    
#> 378: 0.317840    0.964405    3.391497    0.303339    0.061997    0.007216    0.901532    
#> 379: 0.317653    0.964316    3.391511    0.303177    0.062058    0.007205    0.901423    
#> 380: 0.317481    0.964376    3.391450    0.303048    0.062108    0.007202    0.901349    
#> 381: 0.317399    0.964402    3.391401    0.302767    0.062076    0.007201    0.901220    
#> 382: 0.317507    0.964426    3.391394    0.302777    0.062083    0.007195    0.901035    
#> 383: 0.317637    0.964399    3.391402    0.302336    0.061990    0.007209    0.901016    
#> 384: 0.317686    0.964386    3.391426    0.302122    0.061949    0.007222    0.901001    
#> 385: 0.317720    0.964416    3.391473    0.301801    0.061932    0.007237    0.901092    
#> 386: 0.317806    0.964574    3.391548    0.301518    0.061917    0.007239    0.901082    
#> 387: 0.318039    0.964585    3.391693    0.301286    0.061901    0.007249    0.900953    
#> 388: 0.318042    0.964586    3.391778    0.301098    0.061836    0.007250    0.900930    
#> 389: 0.318050    0.964444    3.391784    0.301230    0.061717    0.007244    0.901037    
#> 390: 0.317781    0.964459    3.391712    0.301392    0.061606    0.007251    0.901065    
#> 391: 0.317894    0.964467    3.391649    0.301465    0.061569    0.007258    0.900905    
#> 392: 0.318040    0.964525    3.391662    0.301559    0.061551    0.007258    0.901009    
#> 393: 0.317973    0.964418    3.391619    0.301516    0.061510    0.007255    0.901074    
#> 394: 0.317765    0.964352    3.391576    0.301461    0.061494    0.007266    0.901048    
#> 395: 0.318014    0.964406    3.391605    0.301291    0.061474    0.007259    0.901075    
#> 396: 0.318119    0.964384    3.391602    0.301135    0.061415    0.007248    0.901076    
#> 397: 0.318192    0.964276    3.391639    0.300938    0.061360    0.007243    0.901110    
#> 398: 0.318273    0.964208    3.391662    0.300766    0.061362    0.007231    0.901139    
#> 399: 0.318271    0.964176    3.391709    0.300989    0.061375    0.007226    0.901204    
#> 400: 0.318327    0.964220    3.391778    0.300853    0.061449    0.007228    0.901270    
#> 401: 0.318409    0.964267    3.391775    0.300795    0.061465    0.007227    0.901282    
#> 402: 0.318278    0.964323    3.391778    0.300445    0.061394    0.007229    0.901317    
#> 403: 0.318493    0.964291    3.391803    0.300201    0.061394    0.007231    0.901296    
#> 404: 0.318708    0.964330    3.391816    0.300002    0.061395    0.007229    0.901279    
#> 405: 0.318796    0.964307    3.391899    0.300057    0.061390    0.007243    0.901245    
#> 406: 0.318938    0.964311    3.391922    0.299941    0.061413    0.007251    0.901278    
#> 407: 0.319226    0.964303    3.392016    0.299727    0.061500    0.007262    0.901172    
#> 408: 0.319342    0.964340    3.392058    0.299552    0.061566    0.007259    0.901246    
#> 409: 0.319277    0.964194    3.392004    0.299394    0.061629    0.007256    0.901236    
#> 410: 0.319341    0.964192    3.391942    0.299203    0.061691    0.007257    0.901283    
#> 411: 0.319611    0.964054    3.391932    0.299197    0.061767    0.007256    0.901415    
#> 412: 0.319759    0.964091    3.391938    0.299424    0.061802    0.007261    0.901411    
#> 413: 0.319811    0.964030    3.391916    0.299689    0.061829    0.007258    0.901435    
#> 414: 0.319747    0.963957    3.391988    0.299705    0.061868    0.007262    0.901367    
#> 415: 0.320152    0.963863    3.392107    0.299827    0.061863    0.007281    0.901365    
#> 416: 0.320529    0.963852    3.392215    0.300090    0.061901    0.007289    0.901262    
#> 417: 0.320662    0.963841    3.392253    0.300418    0.061938    0.007301    0.901172    
#> 418: 0.320443    0.963796    3.392275    0.300262    0.062015    0.007307    0.901159    
#> 419: 0.320313    0.963899    3.392275    0.300707    0.062056    0.007310    0.901073    
#> 420: 0.320521    0.963865    3.392332    0.301003    0.062076    0.007302    0.900982    
#> 421: 0.320462    0.963829    3.392381    0.301179    0.062079    0.007299    0.900943    
#> 422: 0.320668    0.963688    3.392407    0.300894    0.062110    0.007300    0.900984    
#> 423: 0.320852    0.963596    3.392450    0.300653    0.062158    0.007300    0.901047    
#> 424: 0.320882    0.963487    3.392456    0.300617    0.062155    0.007296    0.901087    
#> 425: 0.321117    0.963532    3.392511    0.300581    0.062133    0.007300    0.901117    
#> 426: 0.321321    0.963566    3.392574    0.300599    0.062098    0.007295    0.901083    
#> 427: 0.321192    0.963512    3.392556    0.300307    0.062109    0.007303    0.901034    
#> 428: 0.321034    0.963557    3.392504    0.300035    0.062143    0.007306    0.901028    
#> 429: 0.321035    0.963544    3.392499    0.299849    0.062162    0.007311    0.901025    
#> 430: 0.320958    0.963663    3.392475    0.299832    0.062124    0.007321    0.900912    
#> 431: 0.320879    0.963646    3.392443    0.299639    0.062085    0.007315    0.900819    
#> 432: 0.320680    0.963842    3.392404    0.299450    0.062088    0.007314    0.900820    
#> 433: 0.320658    0.964028    3.392402    0.299449    0.062044    0.007313    0.900811    
#> 434: 0.320549    0.963996    3.392429    0.299545    0.062063    0.007326    0.900739    
#> 435: 0.320640    0.964003    3.392439    0.299682    0.062061    0.007333    0.900639    
#> 436: 0.320669    0.964000    3.392440    0.299688    0.062035    0.007338    0.900585    
#> 437: 0.320624    0.964021    3.392425    0.299809    0.062006    0.007337    0.900543    
#> 438: 0.320461    0.964298    3.392390    0.300039    0.062079    0.007329    0.900480    
#> 439: 0.320381    0.964417    3.392347    0.300048    0.062087    0.007323    0.900407    
#> 440: 0.320223    0.964447    3.392305    0.300179    0.062080    0.007315    0.900331    
#> 441: 0.320143    0.964385    3.392326    0.300131    0.062141    0.007314    0.900282    
#> 442: 0.319982    0.964454    3.392314    0.300116    0.062208    0.007314    0.900261    
#> 443: 0.319989    0.964516    3.392270    0.300174    0.062290    0.007309    0.900336    
#> 444: 0.320093    0.964561    3.392254    0.300216    0.062338    0.007301    0.900277    
#> 445: 0.319998    0.964586    3.392253    0.300144    0.062484    0.007293    0.900359    
#> 446: 0.319805    0.964631    3.392214    0.299994    0.062479    0.007283    0.900460    
#> 447: 0.319768    0.964682    3.392184    0.299822    0.062501    0.007281    0.900487    
#> 448: 0.319547    0.964795    3.392123    0.299734    0.062488    0.007282    0.900473    
#> 449: 0.319511    0.964920    3.392214    0.299781    0.062430    0.007282    0.900445    
#> 450: 0.319597    0.964936    3.392250    0.299796    0.062352    0.007285    0.900472    
#> 451: 0.319737    0.964996    3.392245    0.299803    0.062273    0.007289    0.900509    
#> 452: 0.319656    0.965062    3.392204    0.299834    0.062262    0.007295    0.900449    
#> 453: 0.319601    0.965107    3.392147    0.299969    0.062273    0.007291    0.900422    
#> 454: 0.319530    0.965207    3.392109    0.299859    0.062276    0.007291    0.900337    
#> 455: 0.319525    0.965218    3.392066    0.299508    0.062251    0.007287    0.900434    
#> 456: 0.319323    0.965202    3.392025    0.299239    0.062202    0.007294    0.900560    
#> 457: 0.319257    0.965150    3.392042    0.299033    0.062175    0.007295    0.900550    
#> 458: 0.319277    0.965216    3.392099    0.299006    0.062140    0.007298    0.900544    
#> 459: 0.319167    0.965284    3.392135    0.299169    0.062102    0.007304    0.900514    
#> 460: 0.319054    0.965354    3.392109    0.299252    0.062083    0.007310    0.900484    
#> 461: 0.319036    0.965492    3.392085    0.299261    0.062065    0.007306    0.900505    
#> 462: 0.318965    0.965619    3.392103    0.299488    0.062095    0.007298    0.900490    
#> 463: 0.318989    0.965686    3.392109    0.299711    0.062098    0.007288    0.900489    
#> 464: 0.319160    0.965708    3.392110    0.299901    0.062102    0.007280    0.900411    
#> 465: 0.319221    0.965563    3.392131    0.300057    0.062104    0.007271    0.900413    
#> 466: 0.319220    0.965582    3.392110    0.300175    0.062080    0.007258    0.900472    
#> 467: 0.319172    0.965521    3.392137    0.300062    0.062060    0.007253    0.900408    
#> 468: 0.319326    0.965524    3.392188    0.300113    0.062007    0.007260    0.900403    
#> 469: 0.319279    0.965588    3.392218    0.299903    0.061977    0.007271    0.900424    
#> 470: 0.319123    0.965595    3.392195    0.299657    0.061956    0.007283    0.900435    
#> 471: 0.318909    0.965619    3.392175    0.299357    0.061946    0.007282    0.900512    
#> 472: 0.318834    0.965625    3.392183    0.299189    0.061909    0.007283    0.900516    
#> 473: 0.318746    0.965655    3.392163    0.299074    0.061861    0.007293    0.900425    
#> 474: 0.318768    0.965681    3.392149    0.298918    0.061866    0.007304    0.900417    
#> 475: 0.318858    0.965812    3.392147    0.298733    0.061837    0.007310    0.900418    
#> 476: 0.318853    0.965864    3.392124    0.298633    0.061829    0.007314    0.900433    
#> 477: 0.318763    0.965860    3.392137    0.298516    0.061810    0.007319    0.900350    
#> 478: 0.318685    0.965894    3.392140    0.298403    0.061818    0.007315    0.900376    
#> 479: 0.318740    0.965978    3.392149    0.298282    0.061860    0.007308    0.900434    
#> 480: 0.318823    0.965924    3.392183    0.298232    0.061943    0.007304    0.900476    
#> 481: 0.318810    0.965897    3.392189    0.298262    0.062015    0.007302    0.900497    
#> 482: 0.318854    0.965953    3.392154    0.298242    0.061993    0.007304    0.900539    
#> 483: 0.318674    0.965919    3.392110    0.298162    0.061957    0.007302    0.900598    
#> 484: 0.318543    0.965737    3.392083    0.298238    0.061952    0.007300    0.900626    
#> 485: 0.318511    0.965787    3.392078    0.298096    0.061989    0.007306    0.900569    
#> 486: 0.318464    0.965786    3.392060    0.298147    0.061997    0.007297    0.900448    
#> 487: 0.318545    0.965791    3.392076    0.298004    0.062006    0.007295    0.900385    
#> 488: 0.318497    0.965715    3.392116    0.297868    0.061970    0.007300    0.900343    
#> 489: 0.318622    0.965628    3.392166    0.297876    0.061952    0.007307    0.900370    
#> 490: 0.318771    0.965579    3.392223    0.297918    0.061946    0.007307    0.900366    
#> 491: 0.318898    0.965594    3.392291    0.297848    0.061959    0.007315    0.900314    
#> 492: 0.318966    0.965606    3.392344    0.297825    0.061927    0.007316    0.900403    
#> 493: 0.319000    0.965579    3.392374    0.297814    0.061880    0.007322    0.900405    
#> 494: 0.319140    0.965674    3.392387    0.297571    0.061850    0.007321    0.900452    
#> 495: 0.319280    0.965702    3.392434    0.297337    0.061808    0.007327    0.900427    
#> 496: 0.319350    0.965822    3.392412    0.297269    0.061850    0.007325    0.900435    
#> 497: 0.319336    0.965846    3.392423    0.297270    0.061868    0.007315    0.900401    
#> 498: 0.319377    0.965853    3.392410    0.297323    0.061852    0.007308    0.900357    
#> 499: 0.319430    0.965876    3.392387    0.297242    0.061907    0.007300    0.900304    
#> 500: 0.319513    0.965775    3.392380    0.297074    0.061886    0.007293    0.900338    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.291519    0.970315    3.447367    0.392401    0.082843    0.016800    1.818705    
#> 002: 0.309388    0.979948    3.479054    0.372781    0.078701    0.015960    1.172742    
#> 003: 0.425122    0.976207    3.475705    0.354142    0.074766    0.015162    0.905549    
#> 004: 0.354588    0.974262    3.480330    0.336435    0.083675    0.015756    0.777506    
#> 005: 0.395588    1.014645    3.460880    0.399633    0.079491    0.014968    0.669941    
#> 006: 0.393631    1.000003    3.458853    0.379651    0.075517    0.014299    0.626866    
#> 007: 0.344187    1.011803    3.442077    0.416663    0.071741    0.013584    0.633659    
#> 008: 0.310330    1.013335    3.434772    0.395830    0.069703    0.012945    0.606055    
#> 009: 0.275999    1.000157    3.426434    0.419921    0.066218    0.012991    0.598567    
#> 010: 0.278642    1.006915    3.417972    0.480199    0.062907    0.014730    0.608153    
#> 011: 0.322502    1.018312    3.414425    0.478749    0.079575    0.013993    0.603131    
#> 012: 0.307910    1.026007    3.417016    0.519585    0.075597    0.015668    0.594189    
#> 013: 0.313320    1.030369    3.413284    0.559672    0.071817    0.021130    0.580116    
#> 014: 0.342789    1.027739    3.420429    0.650746    0.068226    0.022119    0.580862    
#> 015: 0.381774    1.020835    3.433729    0.618208    0.064815    0.021013    0.556281    
#> 016: 0.398596    1.034371    3.445864    0.587298    0.065251    0.023986    0.565661    
#> 017: 0.380588    1.043884    3.438038    0.621567    0.061989    0.022833    0.554638    
#> 018: 0.375368    1.040173    3.434490    0.590489    0.060873    0.021692    0.558880    
#> 019: 0.329557    1.030100    3.433769    0.560964    0.057830    0.020607    0.560303    
#> 020: 0.382395    1.028262    3.436236    0.532916    0.059069    0.021219    0.561925    
#> 021: 0.340280    1.020776    3.436649    0.506270    0.056116    0.020158    0.553563    
#> 022: 0.321281    1.027443    3.447258    0.493599    0.053310    0.022732    0.556062    
#> 023: 0.373278    1.031926    3.446233    0.528842    0.051057    0.024252    0.562222    
#> 024: 0.371273    1.039607    3.439985    0.548373    0.052896    0.023494    0.553576    
#> 025: 0.371506    1.019568    3.439327    0.520955    0.050251    0.025841    0.561094    
#> 026: 0.341188    1.032280    3.428204    0.524093    0.047739    0.024549    0.560490    
#> 027: 0.357467    1.040950    3.425538    0.584142    0.045352    0.025483    0.561021    
#> 028: 0.364064    1.031538    3.429146    0.585377    0.048018    0.024649    0.562191    
#> 029: 0.304378    1.036317    3.418336    0.556108    0.051356    0.023416    0.584193    
#> 030: 0.345495    1.047997    3.420864    0.528302    0.048788    0.022570    0.586767    
#> 031: 0.322022    1.035346    3.441197    0.501887    0.046348    0.022822    0.577790    
#> 032: 0.340514    1.029407    3.444554    0.476793    0.044031    0.025593    0.574898    
#> 033: 0.305021    1.031142    3.441584    0.452953    0.044205    0.025018    0.566560    
#> 034: 0.356174    1.022007    3.443595    0.445013    0.044391    0.023767    0.566242    
#> 035: 0.312951    1.021732    3.432323    0.422762    0.042172    0.022578    0.557599    
#> 036: 0.313051    1.023005    3.437286    0.401624    0.040141    0.025090    0.574075    
#> 037: 0.322604    1.028091    3.434309    0.401661    0.047127    0.023835    0.581982    
#> 038: 0.312618    1.032199    3.419061    0.511233    0.051191    0.022644    0.573412    
#> 039: 0.328778    1.031513    3.428244    0.526818    0.054742    0.021511    0.564281    
#> 040: 0.330082    1.029198    3.438162    0.500477    0.052005    0.020896    0.583281    
#> 041: 0.300383    1.030503    3.436394    0.475453    0.049536    0.019851    0.570947    
#> 042: 0.325675    1.034034    3.434256    0.503079    0.047060    0.022436    0.571076    
#> 043: 0.313842    1.040304    3.419128    0.481102    0.048351    0.021314    0.565929    
#> 044: 0.293885    1.030614    3.422534    0.488238    0.051781    0.020248    0.578609    
#> 045: 0.311683    1.044819    3.411767    0.530531    0.052687    0.019236    0.573869    
#> 046: 0.297114    1.033484    3.416505    0.504005    0.055421    0.018274    0.584563    
#> 047: 0.293769    1.043510    3.412591    0.478805    0.053873    0.017360    0.577049    
#> 048: 0.309613    1.045460    3.415813    0.545230    0.061452    0.019672    0.579911    
#> 049: 0.316400    1.023057    3.424338    0.517968    0.066855    0.019940    0.584481    
#> 050: 0.345643    1.008076    3.427527    0.578506    0.065484    0.023950    0.587257    
#> 051: 0.330839    1.010984    3.421981    0.573312    0.062210    0.022753    0.576096    
#> 052: 0.362501    1.008815    3.445063    0.544646    0.060146    0.021615    0.562879    
#> 053: 0.370581    0.993869    3.441625    0.539170    0.057138    0.020534    0.563559    
#> 054: 0.343108    1.013462    3.445154    0.512211    0.054281    0.023981    0.579719    
#> 055: 0.350161    1.019381    3.453956    0.486601    0.053104    0.022782    0.586485    
#> 056: 0.369946    1.007245    3.448488    0.462271    0.053989    0.023755    0.606694    
#> 057: 0.368564    1.028144    3.442369    0.571887    0.064148    0.022567    0.589167    
#> 058: 0.355355    1.031326    3.427125    0.565993    0.060940    0.023189    0.579677    
#> 059: 0.339096    1.000304    3.436347    0.537693    0.057893    0.022030    0.589896    
#> 060: 0.315879    1.006581    3.437214    0.510808    0.057391    0.023666    0.600334    
#> 061: 0.375700    1.006292    3.450048    0.549467    0.055444    0.025062    0.601933    
#> 062: 0.333657    1.032898    3.436597    0.557508    0.075621    0.029042    0.605001    
#> 063: 0.351264    1.008340    3.433139    0.563274    0.071840    0.032955    0.607941    
#> 064: 0.339751    1.017214    3.444021    0.535110    0.068248    0.031307    0.606121    
#> 065: 0.331105    1.016539    3.423048    0.519177    0.064836    0.029742    0.590221    
#> 066: 0.346797    1.024957    3.434158    0.506522    0.061594    0.029056    0.589739    
#> 067: 0.337684    1.023972    3.436225    0.481196    0.058514    0.029589    0.573210    
#> 068: 0.324916    1.019334    3.436213    0.479421    0.060993    0.028885    0.576245    
#> 069: 0.306713    1.014975    3.429223    0.455450    0.057943    0.027441    0.588158    
#> 070: 0.313628    1.030474    3.438327    0.432678    0.062712    0.026069    0.598047    
#> 071: 0.327885    1.036917    3.427591    0.483126    0.059576    0.027911    0.582437    
#> 072: 0.342800    1.003562    3.437901    0.481052    0.059568    0.029507    0.571364    
#> 073: 0.390615    1.022873    3.447383    0.610692    0.056770    0.028363    0.566326    
#> 074: 0.379545    1.002674    3.438680    0.580158    0.053931    0.026945    0.565606    
#> 075: 0.350100    1.009644    3.447956    0.551150    0.051235    0.028599    0.569252    
#> 076: 0.410090    1.019785    3.459222    0.523592    0.048673    0.030462    0.586686    
#> 077: 0.418922    0.992998    3.463541    0.555358    0.046239    0.028939    0.584280    
#> 078: 0.408941    0.992289    3.459108    0.549576    0.047633    0.027492    0.560890    
#> 079: 0.365030    1.005588    3.445256    0.522097    0.049157    0.026117    0.569789    
#> 080: 0.406344    1.001730    3.454796    0.535603    0.053626    0.028978    0.573400    
#> 081: 0.388872    1.014950    3.457711    0.525284    0.050945    0.027529    0.571248    
#> 082: 0.360822    1.017389    3.445175    0.499020    0.048398    0.026153    0.589174    
#> 083: 0.372459    1.017905    3.445059    0.506288    0.045978    0.024845    0.582841    
#> 084: 0.339148    1.033935    3.446035    0.480974    0.045739    0.023603    0.578235    
#> 085: 0.336483    1.030533    3.452856    0.456925    0.045725    0.022784    0.584194    
#> 086: 0.345526    1.037950    3.440108    0.488433    0.052443    0.023414    0.566620    
#> 087: 0.376951    1.027369    3.437503    0.577606    0.049821    0.024283    0.583701    
#> 088: 0.338394    1.021884    3.432982    0.562427    0.047330    0.023069    0.595578    
#> 089: 0.338659    1.026152    3.429925    0.534305    0.050657    0.024292    0.582452    
#> 090: 0.376844    1.035076    3.431830    0.532840    0.060681    0.026006    0.578427    
#> 091: 0.318277    1.012916    3.424914    0.506198    0.057647    0.024706    0.570457    
#> 092: 0.324715    1.023634    3.433876    0.480888    0.054765    0.027405    0.561507    
#> 093: 0.311103    1.011703    3.437923    0.456844    0.057762    0.026035    0.589466    
#> 094: 0.311494    1.012065    3.428130    0.434001    0.054874    0.028273    0.577960    
#> 095: 0.319998    1.015675    3.440099    0.412301    0.052131    0.027173    0.578459    
#> 096: 0.306259    1.032705    3.421880    0.495668    0.049524    0.025814    0.565688    
#> 097: 0.361455    1.028487    3.420524    0.511319    0.049515    0.024524    0.578599    
#> 098: 0.336853    1.039276    3.432197    0.485753    0.051850    0.023298    0.586952    
#> 099: 0.333993    1.026029    3.418397    0.553236    0.051060    0.023183    0.577693    
#> 100: 0.334178    1.030445    3.417487    0.541814    0.049985    0.022024    0.578634    
#> 101: 0.294074    1.034390    3.398763    0.514723    0.061326    0.020923    0.568372    
#> 102: 0.284731    1.044858    3.397007    0.488987    0.062001    0.019877    0.576691    
#> 103: 0.288625    1.049297    3.410461    0.466343    0.058901    0.019146    0.569534    
#> 104: 0.292893    1.052343    3.427474    0.518326    0.055956    0.020021    0.589173    
#> 105: 0.330454    1.042207    3.430177    0.502469    0.060164    0.019020    0.600851    
#> 106: 0.361961    1.016297    3.437598    0.553648    0.062972    0.020951    0.572735    
#> 107: 0.362544    1.011256    3.440437    0.525966    0.059823    0.026691    0.569501    
#> 108: 0.374466    1.010258    3.457262    0.499667    0.056832    0.026168    0.587738    
#> 109: 0.320727    1.021096    3.450027    0.512473    0.053990    0.028359    0.586831    
#> 110: 0.330910    1.021679    3.428941    0.486849    0.051291    0.027560    0.586265    
#> 111: 0.324916    1.017929    3.436516    0.462507    0.048726    0.026182    0.568401    
#> 112: 0.357548    1.004293    3.425048    0.494973    0.046290    0.026691    0.578616    
#> 113: 0.334246    1.036008    3.429959    0.537204    0.043975    0.029652    0.567525    
#> 114: 0.325444    1.029448    3.421378    0.520872    0.045979    0.030728    0.565326    
#> 115: 0.324209    1.020879    3.413700    0.526859    0.048132    0.029191    0.578586    
#> 116: 0.330467    1.039450    3.421669    0.500516    0.049130    0.027732    0.577168    
#> 117: 0.303804    1.059132    3.424094    0.526845    0.048336    0.026345    0.587051    
#> 118: 0.345474    1.036133    3.423728    0.515025    0.045919    0.025028    0.574916    
#> 119: 0.332110    1.040519    3.423336    0.519511    0.057569    0.025355    0.574274    
#> 120: 0.271620    1.021284    3.422921    0.493535    0.054690    0.024570    0.568658    
#> 121: 0.324969    1.043790    3.426642    0.512649    0.051956    0.028579    0.561783    
#> 122: 0.351750    1.031799    3.431015    0.542133    0.053808    0.027150    0.566336    
#> 123: 0.370653    1.041544    3.419391    0.550295    0.056989    0.025792    0.584092    
#> 124: 0.354321    1.077644    3.424291    0.610934    0.054139    0.024503    0.580609    
#> 125: 0.317332    1.058621    3.414030    0.580388    0.051432    0.023278    0.567866    
#> 126: 0.285305    1.051196    3.407343    0.551368    0.048861    0.022114    0.579088    
#> 127: 0.341615    1.033493    3.421538    0.523800    0.046418    0.021008    0.566636    
#> 128: 0.322578    1.036123    3.431715    0.497610    0.056738    0.019958    0.569575    
#> 129: 0.330641    1.029508    3.434281    0.480989    0.057488    0.021390    0.568987    
#> 130: 0.361103    1.039072    3.435710    0.482944    0.054614    0.023305    0.570157    
#> 131: 0.337788    1.015565    3.430974    0.458797    0.060201    0.023357    0.575261    
#> 132: 0.328656    1.048691    3.413561    0.507832    0.071375    0.022645    0.555742    
#> 133: 0.295608    1.035780    3.422054    0.482441    0.067807    0.025939    0.560401    
#> 134: 0.332943    1.026213    3.429739    0.538521    0.064416    0.028322    0.561817    
#> 135: 0.345552    1.023148    3.435492    0.511595    0.061195    0.028025    0.552015    
#> 136: 0.359379    1.012494    3.441305    0.486015    0.058136    0.028771    0.568424    
#> 137: 0.384557    1.003392    3.455293    0.461715    0.055229    0.027333    0.594139    
#> 138: 0.356523    1.017240    3.437319    0.502568    0.052798    0.026532    0.572935    
#> 139: 0.361636    1.015630    3.449588    0.522185    0.053560    0.029417    0.578446    
#> 140: 0.346993    1.021484    3.443918    0.496075    0.053839    0.031304    0.574451    
#> 141: 0.335412    1.014523    3.440385    0.518151    0.051147    0.030537    0.582346    
#> 142: 0.382891    1.007022    3.450442    0.542467    0.051814    0.029129    0.582196    
#> 143: 0.362776    1.018286    3.449143    0.555394    0.058496    0.029825    0.574067    
#> 144: 0.380654    1.026937    3.449813    0.552549    0.055571    0.029659    0.576997    
#> 145: 0.339879    1.021947    3.428416    0.584961    0.055002    0.032452    0.565197    
#> 146: 0.356488    1.019305    3.435520    0.622526    0.052252    0.032657    0.572904    
#> 147: 0.329173    1.010081    3.423209    0.591400    0.049639    0.031025    0.565636    
#> 148: 0.314168    1.035871    3.426023    0.561830    0.051826    0.030599    0.558169    
#> 149: 0.347061    1.028169    3.422808    0.628658    0.049235    0.029247    0.566963    
#> 150: 0.407013    1.025669    3.426410    0.772009    0.050285    0.028454    0.562300    
#> 151: 0.376728    1.039673    3.429320    0.814903    0.047770    0.027031    0.562784    
#> 152: 0.358909    1.041009    3.426510    0.827132    0.045367    0.028940    0.557388    
#> 153: 0.351489    1.046656    3.423519    0.838265    0.051882    0.029753    0.576078    
#> 154: 0.359679    1.043870    3.425381    0.746692    0.043261    0.027413    0.565892    
#> 155: 0.312010    1.024542    3.418567    0.583810    0.057933    0.023431    0.559737    
#> 156: 0.317255    1.034988    3.416403    0.541298    0.057107    0.020701    0.562815    
#> 157: 0.327292    1.027886    3.432872    0.453183    0.053803    0.021857    0.577869    
#> 158: 0.345640    1.034163    3.433602    0.469321    0.048619    0.022375    0.566217    
#> 159: 0.314369    1.056232    3.439546    0.415125    0.050621    0.026284    0.578365    
#> 160: 0.323794    1.018489    3.443420    0.472741    0.051630    0.025580    0.583227    
#> 161: 0.322612    1.029168    3.435904    0.345027    0.042067    0.028430    0.595261    
#> 162: 0.298520    1.038826    3.428912    0.436921    0.051230    0.026183    0.575692    
#> 163: 0.334281    1.038133    3.423378    0.492574    0.047636    0.026721    0.567053    
#> 164: 0.361930    1.023432    3.438054    0.536221    0.039412    0.029295    0.563439    
#> 165: 0.368060    1.006530    3.450583    0.451880    0.044510    0.028525    0.565412    
#> 166: 0.369477    1.039462    3.434948    0.458625    0.049977    0.027485    0.578546    
#> 167: 0.336282    1.047860    3.439572    0.481808    0.041665    0.027441    0.579789    
#> 168: 0.363241    1.033233    3.432581    0.547353    0.045680    0.026368    0.567267    
#> 169: 0.351299    1.057207    3.431087    0.494941    0.044068    0.027745    0.580717    
#> 170: 0.335161    1.036702    3.430472    0.445008    0.042455    0.025602    0.587793    
#> 171: 0.337478    1.031535    3.428360    0.511280    0.046434    0.026899    0.557152    
#> 172: 0.300075    1.054948    3.425029    0.521264    0.050195    0.025222    0.565117    
#> 173: 0.319208    1.049590    3.409333    0.566150    0.053535    0.022313    0.547919    
#> 174: 0.312643    1.047451    3.414232    0.556902    0.057544    0.022176    0.559206    
#> 175: 0.322240    1.053022    3.403458    0.606974    0.056918    0.025581    0.560071    
#> 176: 0.266682    1.071248    3.416285    0.507088    0.053323    0.023699    0.579588    
#> 177: 0.297277    1.057496    3.423323    0.484363    0.043674    0.030247    0.572002    
#> 178: 0.309874    1.029727    3.425049    0.504137    0.045445    0.031855    0.563566    
#> 179: 0.335633    1.046672    3.423477    0.472089    0.051463    0.028230    0.581146    
#> 180: 0.331036    1.040273    3.435708    0.504752    0.052219    0.029726    0.572169    
#> 181: 0.334479    1.022490    3.425585    0.474278    0.048886    0.025412    0.581165    
#> 182: 0.302916    1.037607    3.420897    0.451728    0.054640    0.029220    0.593120    
#> 183: 0.332353    1.039314    3.426097    0.435320    0.065205    0.024222    0.587697    
#> 184: 0.314222    1.029975    3.428017    0.423719    0.054379    0.024363    0.577072    
#> 185: 0.287546    1.039626    3.417956    0.469168    0.054749    0.024589    0.582644    
#> 186: 0.301611    1.042288    3.418399    0.472883    0.055814    0.023811    0.586184    
#> 187: 0.333238    1.034704    3.428319    0.461323    0.055613    0.020625    0.588487    
#> 188: 0.309018    1.041918    3.429897    0.479966    0.061440    0.019877    0.562526    
#> 189: 0.307444    1.047450    3.433911    0.413393    0.061024    0.017833    0.579653    
#> 190: 0.299787    1.047036    3.426425    0.399772    0.050617    0.017108    0.572298    
#> 191: 0.266329    1.046043    3.416280    0.391574    0.047239    0.017093    0.574587    
#> 192: 0.297108    1.061561    3.424349    0.406658    0.053737    0.020577    0.561817    
#> 193: 0.325695    1.052348    3.430421    0.412422    0.047861    0.020391    0.570625    
#> 194: 0.316065    1.035469    3.430724    0.447640    0.052955    0.020047    0.558554    
#> 195: 0.290971    1.032329    3.422736    0.428940    0.055572    0.022348    0.560815    
#> 196: 0.271335    1.029442    3.429264    0.416138    0.054223    0.020965    0.576285    
#> 197: 0.290639    1.026542    3.441026    0.502759    0.050637    0.021056    0.581566    
#> 198: 0.366767    1.013533    3.426817    0.530415    0.043997    0.023671    0.580495    
#> 199: 0.337088    1.021348    3.430500    0.518952    0.058536    0.022528    0.562542    
#> 200: 0.332172    1.003990    3.442114    0.512199    0.054243    0.023797    0.575740    
#> 201: 0.340678    1.002503    3.442252    0.534881    0.049633    0.026721    0.569570    
#> 202: 0.330992    1.007291    3.439512    0.535862    0.049076    0.026861    0.568535    
#> 203: 0.338709    1.011759    3.436800    0.532329    0.048355    0.026202    0.568641    
#> 204: 0.339194    1.012228    3.438142    0.525416    0.047362    0.026134    0.569306    
#> 205: 0.337075    1.017291    3.436221    0.520861    0.048412    0.025645    0.571990    
#> 206: 0.336665    1.021853    3.436139    0.527102    0.049832    0.025151    0.572299    
#> 207: 0.336857    1.024025    3.434853    0.517952    0.050370    0.025016    0.571035    
#> 208: 0.338867    1.025275    3.434374    0.512479    0.050372    0.024778    0.571034    
#> 209: 0.339843    1.024375    3.433204    0.518295    0.052073    0.024273    0.571734    
#> 210: 0.340305    1.023170    3.432884    0.526701    0.052542    0.024089    0.571358    
#> 211: 0.341501    1.023963    3.432649    0.528286    0.052952    0.023818    0.570174    
#> 212: 0.342630    1.024368    3.433112    0.528405    0.053523    0.023668    0.568883    
#> 213: 0.344225    1.024194    3.433808    0.523740    0.053780    0.023621    0.569954    
#> 214: 0.346401    1.023022    3.434691    0.522981    0.053936    0.023671    0.569668    
#> 215: 0.345338    1.023572    3.435379    0.517705    0.053842    0.023593    0.569691    
#> 216: 0.347331    1.023394    3.435375    0.514292    0.054034    0.023415    0.570314    
#> 217: 0.347237    1.024153    3.435270    0.514404    0.054267    0.023287    0.569846    
#> 218: 0.347466    1.024659    3.434544    0.517302    0.054180    0.023344    0.569066    
#> 219: 0.345759    1.025209    3.433778    0.517414    0.054070    0.023454    0.569630    
#> 220: 0.344519    1.025370    3.433455    0.519437    0.053792    0.023634    0.569522    
#> 221: 0.343240    1.025271    3.433227    0.517937    0.053229    0.023757    0.569302    
#> 222: 0.340934    1.025792    3.432515    0.516827    0.053057    0.023793    0.569054    
#> 223: 0.340936    1.026151    3.432224    0.517989    0.052831    0.023787    0.569042    
#> 224: 0.341419    1.027343    3.431938    0.520088    0.052878    0.023789    0.568300    
#> 225: 0.341741    1.026651    3.432126    0.521038    0.052604    0.023857    0.568312    
#> 226: 0.341595    1.025539    3.431974    0.520384    0.052599    0.024045    0.568367    
#> 227: 0.340539    1.025440    3.432052    0.518691    0.052268    0.024256    0.568371    
#> 228: 0.339308    1.025846    3.431626    0.518623    0.052394    0.024412    0.568677    
#> 229: 0.337969    1.025666    3.431364    0.517770    0.052334    0.024503    0.568756    
#> 230: 0.337326    1.025383    3.430763    0.519662    0.052483    0.024439    0.569004    
#> 231: 0.336420    1.026390    3.430413    0.520830    0.052837    0.024460    0.569365    
#> 232: 0.335184    1.026743    3.430344    0.520885    0.053061    0.024423    0.569205    
#> 233: 0.333963    1.026432    3.430304    0.521003    0.053106    0.024424    0.569345    
#> 234: 0.333258    1.026139    3.430091    0.519490    0.053169    0.024415    0.569665    
#> 235: 0.333057    1.026128    3.429755    0.519357    0.053279    0.024285    0.569851    
#> 236: 0.333267    1.026409    3.429574    0.519704    0.053659    0.024141    0.569998    
#> 237: 0.332762    1.026733    3.429548    0.519430    0.053869    0.024174    0.570607    
#> 238: 0.332137    1.026871    3.429307    0.518062    0.053863    0.024143    0.571061    
#> 239: 0.331190    1.027436    3.428829    0.518338    0.054073    0.024065    0.571137    
#> 240: 0.331217    1.027806    3.428743    0.519196    0.054046    0.023932    0.571013    
#> 241: 0.331670    1.027411    3.428812    0.519105    0.054025    0.023774    0.571307    
#> 242: 0.331438    1.027129    3.428549    0.520331    0.053784    0.023634    0.571863    
#> 243: 0.330376    1.027463    3.428413    0.519034    0.053592    0.023689    0.572315    
#> 244: 0.330070    1.027497    3.428626    0.517161    0.053485    0.023705    0.572514    
#> 245: 0.330427    1.027075    3.428697    0.516795    0.053611    0.023787    0.572893    
#> 246: 0.330337    1.026946    3.428603    0.515987    0.053687    0.023771    0.573100    
#> 247: 0.329785    1.026911    3.428489    0.516317    0.053758    0.023698    0.573048    
#> 248: 0.329720    1.027301    3.428286    0.516194    0.053741    0.023682    0.573020    
#> 249: 0.328804    1.027820    3.428105    0.514571    0.053852    0.023646    0.573142    
#> 250: 0.328816    1.028144    3.428122    0.514806    0.053908    0.023648    0.573243    
#> 251: 0.328694    1.028528    3.428322    0.513052    0.053911    0.023730    0.573306    
#> 252: 0.329019    1.028600    3.428643    0.511565    0.053918    0.023748    0.573437    
#> 253: 0.329143    1.028580    3.428650    0.510287    0.053894    0.023730    0.573451    
#> 254: 0.329314    1.028793    3.428723    0.510289    0.053882    0.023736    0.573347    
#> 255: 0.329909    1.029027    3.428887    0.510549    0.053667    0.023809    0.573327    
#> 256: 0.330483    1.028859    3.429034    0.510540    0.053447    0.023867    0.573373    
#> 257: 0.330135    1.028626    3.428982    0.509308    0.053295    0.023901    0.573489    
#> 258: 0.329748    1.028363    3.428923    0.509811    0.053233    0.023942    0.573508    
#> 259: 0.329837    1.028363    3.428859    0.509060    0.053299    0.024018    0.573599    
#> 260: 0.329969    1.028472    3.428938    0.508660    0.053407    0.024028    0.573541    
#> 261: 0.330162    1.028356    3.429139    0.509578    0.053525    0.024046    0.573532    
#> 262: 0.330329    1.028538    3.429331    0.510215    0.053614    0.024146    0.573570    
#> 263: 0.330543    1.028788    3.429429    0.510258    0.053583    0.024219    0.573620    
#> 264: 0.330393    1.029128    3.429355    0.510250    0.053604    0.024203    0.573927    
#> 265: 0.330646    1.029007    3.429484    0.509942    0.053608    0.024200    0.574046    
#> 266: 0.330815    1.029192    3.429386    0.510829    0.053717    0.024165    0.574054    
#> 267: 0.330940    1.029192    3.429586    0.511260    0.053815    0.024145    0.574171    
#> 268: 0.331059    1.028941    3.429579    0.512319    0.053847    0.024095    0.574244    
#> 269: 0.331802    1.028909    3.429521    0.513713    0.053901    0.024158    0.574125    
#> 270: 0.331767    1.029103    3.429424    0.514397    0.053938    0.024152    0.574063    
#> 271: 0.332155    1.028961    3.429381    0.515245    0.053796    0.024146    0.573951    
#> 272: 0.332361    1.028850    3.429357    0.514633    0.053689    0.024185    0.574103    
#> 273: 0.332348    1.029121    3.429346    0.514807    0.053730    0.024195    0.574136    
#> 274: 0.332700    1.029422    3.429340    0.515455    0.053535    0.024198    0.574226    
#> 275: 0.332779    1.029422    3.429366    0.515175    0.053359    0.024215    0.574203    
#> 276: 0.332817    1.029457    3.429558    0.514915    0.053213    0.024288    0.574270    
#> 277: 0.332944    1.029623    3.429723    0.513851    0.053142    0.024336    0.574385    
#> 278: 0.332885    1.029476    3.429875    0.512971    0.053122    0.024356    0.574392    
#> 279: 0.332974    1.029154    3.430000    0.513233    0.053220    0.024378    0.574452    
#> 280: 0.332857    1.029208    3.429999    0.512632    0.053254    0.024340    0.574544    
#> 281: 0.332228    1.029325    3.429908    0.512739    0.053150    0.024306    0.574448    
#> 282: 0.331874    1.029591    3.429879    0.511540    0.053093    0.024251    0.574536    
#> 283: 0.331541    1.029835    3.429798    0.510664    0.053004    0.024210    0.574989    
#> 284: 0.331331    1.029771    3.429826    0.509797    0.052895    0.024155    0.575071    
#> 285: 0.331057    1.029914    3.429769    0.509319    0.052886    0.024070    0.575037    
#> 286: 0.331199    1.029873    3.429764    0.509072    0.053012    0.024002    0.574988    
#> 287: 0.330653    1.029930    3.429736    0.508399    0.053120    0.023977    0.574865    
#> 288: 0.330579    1.029969    3.429658    0.507968    0.053195    0.023928    0.574860    
#> 289: 0.330771    1.030033    3.429667    0.507779    0.053173    0.023883    0.574718    
#> 290: 0.330834    1.029861    3.429725    0.507551    0.053149    0.023834    0.574775    
#> 291: 0.330856    1.029890    3.429789    0.507296    0.053146    0.023777    0.574696    
#> 292: 0.331000    1.029851    3.429838    0.506742    0.053153    0.023763    0.574681    
#> 293: 0.331389    1.029844    3.429862    0.506874    0.053108    0.023763    0.574613    
#> 294: 0.331211    1.029881    3.429748    0.506518    0.053114    0.023767    0.574507    
#> 295: 0.331219    1.029692    3.429772    0.506792    0.053088    0.023749    0.574379    
#> 296: 0.331565    1.029634    3.429755    0.507245    0.053023    0.023735    0.574489    
#> 297: 0.331894    1.029796    3.429822    0.507471    0.053008    0.023731    0.574526    
#> 298: 0.331965    1.029738    3.429883    0.506911    0.052925    0.023791    0.574573    
#> 299: 0.331688    1.029813    3.429837    0.506322    0.052849    0.023857    0.574350    
#> 300: 0.331749    1.029706    3.429892    0.506242    0.052889    0.023868    0.574217    
#> 301: 0.332213    1.029688    3.429915    0.506531    0.052881    0.023884    0.574247    
#> 302: 0.332562    1.029786    3.429935    0.506789    0.052892    0.023905    0.574225    
#> 303: 0.332329    1.029904    3.429896    0.506710    0.052915    0.023922    0.574093    
#> 304: 0.332575    1.030095    3.429875    0.506353    0.052936    0.023943    0.574052    
#> 305: 0.332766    1.029883    3.429935    0.505620    0.052993    0.023971    0.573930    
#> 306: 0.332666    1.029844    3.429875    0.505308    0.053008    0.023980    0.573762    
#> 307: 0.332222    1.029884    3.429792    0.505050    0.053138    0.023994    0.573796    
#> 308: 0.331809    1.029999    3.429586    0.504936    0.053345    0.023988    0.573855    
#> 309: 0.331709    1.029902    3.429597    0.505132    0.053389    0.023943    0.573979    
#> 310: 0.331666    1.029846    3.429515    0.505216    0.053451    0.023904    0.574122    
#> 311: 0.331480    1.029970    3.429488    0.505347    0.053527    0.023874    0.574152    
#> 312: 0.331111    1.029979    3.429398    0.505561    0.053549    0.023850    0.574164    
#> 313: 0.330762    1.029787    3.429242    0.505632    0.053544    0.023853    0.574149    
#> 314: 0.330392    1.029811    3.429033    0.505834    0.053561    0.023886    0.574102    
#> 315: 0.329986    1.030019    3.428835    0.505909    0.053651    0.023891    0.574053    
#> 316: 0.329982    1.030018    3.428825    0.505757    0.053669    0.023914    0.573992    
#> 317: 0.330326    1.029992    3.428858    0.505991    0.053694    0.023922    0.574174    
#> 318: 0.330652    1.030139    3.428838    0.506353    0.053649    0.023892    0.574271    
#> 319: 0.330988    1.030101    3.428895    0.506347    0.053674    0.023878    0.574427    
#> 320: 0.330662    1.029969    3.428841    0.506240    0.053673    0.023841    0.574697    
#> 321: 0.330345    1.030099    3.428693    0.506007    0.053734    0.023816    0.574879    
#> 322: 0.329890    1.030134    3.428589    0.505887    0.053684    0.023849    0.575027    
#> 323: 0.329570    1.030227    3.428496    0.505719    0.053713    0.023873    0.575029    
#> 324: 0.329601    1.030189    3.428516    0.505841    0.053735    0.023855    0.574907    
#> 325: 0.329589    1.030304    3.428478    0.505955    0.053803    0.023829    0.574782    
#> 326: 0.329290    1.030253    3.428384    0.505818    0.053864    0.023839    0.574630    
#> 327: 0.329135    1.030308    3.428306    0.505777    0.053930    0.023842    0.574586    
#> 328: 0.329125    1.030458    3.428297    0.505821    0.053882    0.023878    0.574522    
#> 329: 0.329205    1.030601    3.428301    0.505871    0.053844    0.023896    0.574438    
#> 330: 0.329115    1.030555    3.428316    0.505343    0.053744    0.023929    0.574477    
#> 331: 0.329300    1.030556    3.428467    0.504815    0.053632    0.023978    0.574511    
#> 332: 0.329496    1.030579    3.428564    0.504161    0.053526    0.024008    0.574594    
#> 333: 0.329344    1.030660    3.428566    0.503437    0.053526    0.024005    0.574553    
#> 334: 0.329030    1.030672    3.428454    0.503072    0.053532    0.023989    0.574516    
#> 335: 0.328781    1.030641    3.428386    0.502467    0.053512    0.023978    0.574534    
#> 336: 0.328458    1.030746    3.428329    0.502033    0.053538    0.023947    0.574501    
#> 337: 0.328187    1.031059    3.428215    0.501338    0.053539    0.023947    0.574587    
#> 338: 0.328244    1.031321    3.428214    0.501411    0.053589    0.023924    0.574587    
#> 339: 0.328274    1.031472    3.428170    0.501150    0.053571    0.023886    0.574552    
#> 340: 0.328275    1.031341    3.428193    0.500960    0.053568    0.023886    0.574459    
#> 341: 0.328448    1.031319    3.428273    0.500991    0.053629    0.023877    0.574381    
#> 342: 0.328417    1.031139    3.428309    0.500895    0.053648    0.023866    0.574412    
#> 343: 0.328270    1.031248    3.428296    0.500958    0.053713    0.023859    0.574403    
#> 344: 0.328301    1.031250    3.428322    0.500903    0.053646    0.023858    0.574507    
#> 345: 0.328239    1.031265    3.428303    0.500546    0.053562    0.023856    0.574460    
#> 346: 0.328068    1.031337    3.428137    0.500170    0.053550    0.023813    0.574359    
#> 347: 0.327805    1.031249    3.428045    0.500309    0.053584    0.023814    0.574264    
#> 348: 0.327447    1.031321    3.427912    0.500349    0.053613    0.023834    0.574263    
#> 349: 0.327133    1.031273    3.427829    0.500187    0.053573    0.023833    0.574244    
#> 350: 0.326946    1.031224    3.427754    0.500400    0.053579    0.023837    0.574269    
#> 351: 0.326958    1.031341    3.427654    0.500769    0.053631    0.023844    0.574383    
#> 352: 0.326939    1.031460    3.427621    0.500617    0.053667    0.023889    0.574374    
#> 353: 0.327185    1.031528    3.427704    0.500658    0.053630    0.023938    0.574276    
#> 354: 0.327214    1.031525    3.427684    0.500704    0.053614    0.023951    0.574251    
#> 355: 0.327637    1.031411    3.427757    0.501027    0.053628    0.023983    0.574331    
#> 356: 0.327832    1.031297    3.427872    0.500968    0.053623    0.023976    0.574494    
#> 357: 0.328208    1.031294    3.427968    0.500751    0.053588    0.023997    0.574499    
#> 358: 0.328170    1.031331    3.428025    0.500477    0.053602    0.023979    0.574492    
#> 359: 0.327958    1.031418    3.427949    0.500007    0.053623    0.023951    0.574523    
#> 360: 0.327957    1.031446    3.427845    0.500193    0.053599    0.023921    0.574508    
#> 361: 0.328002    1.031553    3.427833    0.499909    0.053609    0.023910    0.574501    
#> 362: 0.328129    1.031656    3.427810    0.499954    0.053615    0.023919    0.574362    
#> 363: 0.328218    1.031629    3.427804    0.499923    0.053564    0.023893    0.574321    
#> 364: 0.328409    1.031624    3.427839    0.500400    0.053582    0.023871    0.574370    
#> 365: 0.328424    1.031505    3.427890    0.500284    0.053606    0.023830    0.574439    
#> 366: 0.328360    1.031479    3.427840    0.499717    0.053659    0.023781    0.574520    
#> 367: 0.328399    1.031507    3.427837    0.499500    0.053672    0.023755    0.574494    
#> 368: 0.328673    1.031606    3.427837    0.499647    0.053594    0.023734    0.574489    
#> 369: 0.328644    1.031628    3.427807    0.499509    0.053645    0.023719    0.574467    
#> 370: 0.328623    1.031701    3.427759    0.499584    0.053683    0.023698    0.574541    
#> 371: 0.328454    1.031838    3.427623    0.499129    0.053799    0.023659    0.574589    
#> 372: 0.328216    1.031925    3.427525    0.498807    0.053863    0.023627    0.574574    
#> 373: 0.328015    1.032038    3.427446    0.498699    0.053897    0.023606    0.574651    
#> 374: 0.328074    1.032049    3.427406    0.498869    0.053882    0.023611    0.574588    
#> 375: 0.327819    1.032111    3.427353    0.498620    0.053947    0.023631    0.574547    
#> 376: 0.327713    1.032247    3.427308    0.498650    0.053983    0.023655    0.574491    
#> 377: 0.327628    1.032336    3.427225    0.498815    0.053997    0.023688    0.574459    
#> 378: 0.327227    1.032438    3.427118    0.498393    0.053955    0.023749    0.574528    
#> 379: 0.327003    1.032381    3.427019    0.498523    0.053915    0.023778    0.574582    
#> 380: 0.326875    1.032391    3.426962    0.498760    0.053867    0.023809    0.574564    
#> 381: 0.326719    1.032400    3.426838    0.499295    0.053832    0.023848    0.574544    
#> 382: 0.326533    1.032374    3.426754    0.499604    0.053794    0.023858    0.574533    
#> 383: 0.326556    1.032300    3.426735    0.499762    0.053748    0.023840    0.574556    
#> 384: 0.326576    1.032232    3.426735    0.499908    0.053749    0.023829    0.574517    
#> 385: 0.326597    1.032282    3.426693    0.499953    0.053754    0.023836    0.574409    
#> 386: 0.326631    1.032400    3.426728    0.499899    0.053748    0.023843    0.574370    
#> 387: 0.326614    1.032461    3.426739    0.499873    0.053708    0.023827    0.574338    
#> 388: 0.326502    1.032594    3.426736    0.499860    0.053673    0.023812    0.574348    
#> 389: 0.326392    1.032550    3.426684    0.500170    0.053659    0.023791    0.574462    
#> 390: 0.326209    1.032661    3.426618    0.500326    0.053603    0.023771    0.574547    
#> 391: 0.326165    1.032728    3.426558    0.500275    0.053586    0.023737    0.574495    
#> 392: 0.326022    1.032779    3.426495    0.500369    0.053583    0.023719    0.574470    
#> 393: 0.325994    1.032778    3.426457    0.500153    0.053571    0.023722    0.574421    
#> 394: 0.326026    1.032868    3.426435    0.500241    0.053574    0.023726    0.574370    
#> 395: 0.326141    1.033005    3.426392    0.500474    0.053517    0.023744    0.574427    
#> 396: 0.326044    1.033046    3.426355    0.500464    0.053442    0.023753    0.574460    
#> 397: 0.326080    1.033044    3.426410    0.500561    0.053387    0.023770    0.574554    
#> 398: 0.326138    1.032971    3.426465    0.500650    0.053300    0.023795    0.574638    
#> 399: 0.326294    1.032870    3.426562    0.500701    0.053233    0.023826    0.574685    
#> 400: 0.326367    1.032839    3.426599    0.500919    0.053187    0.023829    0.574680    
#> 401: 0.326352    1.032844    3.426575    0.500805    0.053210    0.023813    0.574778    
#> 402: 0.326304    1.032958    3.426525    0.500667    0.053206    0.023801    0.574837    
#> 403: 0.326354    1.033010    3.426544    0.500662    0.053210    0.023790    0.574823    
#> 404: 0.326369    1.033031    3.426542    0.500612    0.053111    0.023792    0.574876    
#> 405: 0.326239    1.033074    3.426573    0.500253    0.053009    0.023792    0.574958    
#> 406: 0.326296    1.033101    3.426572    0.500238    0.052942    0.023804    0.575029    
#> 407: 0.326208    1.033175    3.426623    0.499954    0.052880    0.023803    0.575073    
#> 408: 0.326387    1.033266    3.426683    0.499896    0.052888    0.023792    0.575047    
#> 409: 0.326448    1.033250    3.426737    0.499931    0.052878    0.023793    0.575001    
#> 410: 0.326470    1.033244    3.426708    0.500070    0.052862    0.023777    0.575022    
#> 411: 0.326470    1.033080    3.426731    0.500347    0.052802    0.023782    0.575044    
#> 412: 0.326641    1.033116    3.426773    0.500536    0.052793    0.023791    0.574999    
#> 413: 0.326929    1.033160    3.426836    0.500920    0.052753    0.023810    0.574996    
#> 414: 0.326927    1.033110    3.426908    0.500747    0.052686    0.023799    0.575013    
#> 415: 0.327031    1.033094    3.426910    0.500709    0.052645    0.023786    0.575069    
#> 416: 0.327260    1.033119    3.426987    0.500780    0.052638    0.023783    0.575054    
#> 417: 0.327252    1.033095    3.427029    0.500639    0.052621    0.023779    0.575008    
#> 418: 0.327119    1.033102    3.427073    0.500366    0.052632    0.023772    0.574964    
#> 419: 0.327004    1.033202    3.427079    0.499986    0.052663    0.023771    0.574913    
#> 420: 0.326980    1.033246    3.427113    0.499692    0.052681    0.023762    0.574798    
#> 421: 0.326868    1.033259    3.427105    0.499670    0.052642    0.023753    0.574714    
#> 422: 0.326841    1.033202    3.427107    0.499725    0.052662    0.023739    0.574673    
#> 423: 0.327042    1.033131    3.427165    0.499635    0.052688    0.023730    0.574634    
#> 424: 0.327040    1.033070    3.427160    0.499396    0.052709    0.023709    0.574625    
#> 425: 0.327182    1.033089    3.427124    0.499763    0.052720    0.023703    0.574624    
#> 426: 0.327133    1.033191    3.427125    0.499854    0.052765    0.023693    0.574553    
#> 427: 0.327121    1.033218    3.427134    0.500031    0.052793    0.023678    0.574543    
#> 428: 0.327148    1.033231    3.427158    0.500314    0.052821    0.023677    0.574534    
#> 429: 0.327310    1.033281    3.427204    0.500459    0.052836    0.023681    0.574543    
#> 430: 0.327335    1.033293    3.427233    0.500350    0.052808    0.023681    0.574540    
#> 431: 0.327418    1.033269    3.427247    0.500262    0.052793    0.023660    0.574533    
#> 432: 0.327364    1.033336    3.427250    0.500336    0.052787    0.023655    0.574558    
#> 433: 0.327293    1.033340    3.427236    0.500274    0.052753    0.023628    0.574586    
#> 434: 0.327157    1.033262    3.427238    0.499988    0.052739    0.023610    0.574554    
#> 435: 0.327087    1.033248    3.427201    0.499842    0.052744    0.023610    0.574451    
#> 436: 0.327082    1.033192    3.427235    0.499554    0.052734    0.023610    0.574463    
#> 437: 0.327151    1.033145    3.427271    0.499186    0.052702    0.023603    0.574460    
#> 438: 0.327172    1.033236    3.427306    0.498839    0.052669    0.023598    0.574475    
#> 439: 0.327255    1.033306    3.427335    0.498651    0.052680    0.023598    0.574420    
#> 440: 0.327335    1.033297    3.427391    0.498317    0.052653    0.023618    0.574349    
#> 441: 0.327451    1.033226    3.427480    0.498180    0.052630    0.023629    0.574266    
#> 442: 0.327487    1.033224    3.427524    0.498005    0.052593    0.023647    0.574170    
#> 443: 0.327484    1.033259    3.427526    0.497639    0.052580    0.023651    0.574100    
#> 444: 0.327432    1.033262    3.427501    0.497392    0.052553    0.023661    0.574069    
#> 445: 0.327252    1.033270    3.427486    0.497101    0.052561    0.023662    0.574086    
#> 446: 0.327120    1.033306    3.427450    0.496911    0.052575    0.023666    0.574045    
#> 447: 0.327280    1.033317    3.427448    0.496965    0.052599    0.023672    0.573992    
#> 448: 0.327380    1.033353    3.427472    0.497140    0.052579    0.023687    0.573897    
#> 449: 0.327451    1.033397    3.427584    0.497002    0.052559    0.023706    0.573913    
#> 450: 0.327553    1.033383    3.427612    0.497106    0.052530    0.023716    0.573912    
#> 451: 0.327610    1.033373    3.427608    0.497038    0.052533    0.023713    0.573944    
#> 452: 0.327689    1.033399    3.427625    0.496970    0.052520    0.023712    0.573928    
#> 453: 0.327677    1.033422    3.427604    0.497091    0.052492    0.023707    0.573848    
#> 454: 0.327597    1.033491    3.427593    0.497089    0.052467    0.023713    0.573810    
#> 455: 0.327543    1.033491    3.427594    0.497166    0.052440    0.023724    0.573763    
#> 456: 0.327532    1.033442    3.427608    0.497009    0.052442    0.023715    0.573761    
#> 457: 0.327578    1.033320    3.427653    0.496778    0.052447    0.023720    0.573764    
#> 458: 0.327576    1.033343    3.427689    0.496586    0.052474    0.023715    0.573715    
#> 459: 0.327516    1.033396    3.427691    0.496579    0.052444    0.023710    0.573701    
#> 460: 0.327408    1.033394    3.427662    0.496513    0.052413    0.023718    0.573598    
#> 461: 0.327434    1.033369    3.427704    0.496452    0.052396    0.023722    0.573539    
#> 462: 0.327423    1.033348    3.427755    0.496188    0.052409    0.023730    0.573506    
#> 463: 0.327493    1.033389    3.427822    0.496003    0.052425    0.023756    0.573519    
#> 464: 0.327562    1.033425    3.427853    0.495761    0.052432    0.023785    0.573482    
#> 465: 0.327699    1.033349    3.427909    0.495713    0.052412    0.023788    0.573448    
#> 466: 0.327743    1.033334    3.427905    0.495752    0.052368    0.023811    0.573445    
#> 467: 0.327629    1.033281    3.427934    0.495360    0.052357    0.023827    0.573441    
#> 468: 0.327634    1.033240    3.427983    0.495070    0.052303    0.023853    0.573434    
#> 469: 0.327609    1.033297    3.427993    0.494828    0.052273    0.023875    0.573491    
#> 470: 0.327504    1.033337    3.427959    0.494702    0.052253    0.023883    0.573553    
#> 471: 0.327453    1.033333    3.427955    0.494836    0.052219    0.023891    0.573539    
#> 472: 0.327352    1.033329    3.427961    0.494797    0.052217    0.023891    0.573457    
#> 473: 0.327398    1.033353    3.427966    0.494837    0.052200    0.023897    0.573344    
#> 474: 0.327397    1.033361    3.427933    0.495005    0.052213    0.023898    0.573316    
#> 475: 0.327500    1.033446    3.427940    0.495335    0.052213    0.023897    0.573312    
#> 476: 0.327525    1.033436    3.427931    0.495337    0.052240    0.023887    0.573286    
#> 477: 0.327571    1.033393    3.427994    0.495209    0.052258    0.023886    0.573239    
#> 478: 0.327536    1.033308    3.428036    0.495384    0.052293    0.023895    0.573280    
#> 479: 0.327644    1.033307    3.428054    0.495731    0.052299    0.023888    0.573307    
#> 480: 0.327719    1.033276    3.428059    0.496094    0.052330    0.023901    0.573304    
#> 481: 0.327775    1.033279    3.428029    0.496195    0.052334    0.023901    0.573262    
#> 482: 0.327779    1.033285    3.428004    0.496156    0.052326    0.023896    0.573256    
#> 483: 0.327654    1.033296    3.427995    0.495961    0.052330    0.023889    0.573259    
#> 484: 0.327636    1.033179    3.428008    0.495791    0.052321    0.023892    0.573280    
#> 485: 0.327702    1.033169    3.428029    0.495708    0.052265    0.023897    0.573296    
#> 486: 0.327699    1.033197    3.428026    0.495580    0.052246    0.023887    0.573328    
#> 487: 0.327889    1.033222    3.428051    0.495851    0.052237    0.023891    0.573338    
#> 488: 0.327874    1.033219    3.428054    0.495922    0.052215    0.023884    0.573310    
#> 489: 0.327874    1.033202    3.428039    0.495828    0.052189    0.023878    0.573302    
#> 490: 0.327903    1.033272    3.428043    0.495804    0.052181    0.023865    0.573281    
#> 491: 0.327957    1.033347    3.428050    0.495698    0.052170    0.023860    0.573240    
#> 492: 0.327897    1.033408    3.428012    0.495723    0.052150    0.023861    0.573290    
#> 493: 0.327787    1.033446    3.427997    0.495675    0.052144    0.023857    0.573294    
#> 494: 0.327913    1.033469    3.427995    0.495797    0.052134    0.023859    0.573286    
#> 495: 0.327876    1.033480    3.427997    0.495780    0.052134    0.023855    0.573308    
#> 496: 0.327963    1.033512    3.427983    0.495815    0.052119    0.023843    0.573327    
#> 497: 0.327908    1.033479    3.427992    0.495797    0.052099    0.023837    0.573362    
#> 498: 0.327955    1.033426    3.427990    0.495973    0.052084    0.023845    0.573303    
#> 499: 0.327971    1.033429    3.427991    0.495878    0.052057    0.023851    0.573246    
#> 500: 0.327957    1.033375    3.427994    0.495792    0.052069    0.023847    0.573241    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  001: 0.278242    0.974873    3.449415    0.392401    0.078804    0.016800    1.831966    
#> 002: 0.150655    1.058387    3.458504    0.372781    0.074863    0.015960    1.223280    
#> 003: 0.238226    1.046889    3.481492    0.354142    0.071120    0.016037    0.925289    
#> 004: 0.220211    1.092228    3.484057    0.336435    0.067564    0.015235    0.838737    
#> 005: 0.283432    1.119448    3.476950    0.319613    0.070186    0.014474    0.788895    
#> 006: 0.241687    1.131298    3.465320    0.303633    0.085569    0.014744    0.740552    
#> 007: 0.185109    1.126116    3.479003    0.288451    0.107636    0.019250    0.723677    
#> 008: 0.200953    1.134137    3.470794    0.308907    0.102255    0.019529    0.732479    
#> 009: 0.197572    1.126024    3.461251    0.334673    0.097142    0.019824    0.727281    
#> 010: 0.225737    1.132158    3.470773    0.317939    0.092285    0.021141    0.741639    
#> 011: 0.281327    1.153881    3.480187    0.302042    0.115314    0.023763    0.733925    
#> 012: 0.263047    1.129655    3.473678    0.286940    0.109549    0.024644    0.721808    
#> 013: 0.228159    1.134662    3.472093    0.272593    0.104071    0.023412    0.715721    
#> 014: 0.258942    1.126568    3.482187    0.265083    0.098868    0.024823    0.735406    
#> 015: 0.273435    1.136331    3.488442    0.295134    0.093924    0.024599    0.716651    
#> 016: 0.231634    1.150987    3.485843    0.282057    0.089228    0.024250    0.727068    
#> 017: 0.223339    1.151452    3.483727    0.288290    0.084767    0.028115    0.703877    
#> 018: 0.260684    1.144126    3.477061    0.279255    0.080528    0.027752    0.700732    
#> 019: 0.235848    1.143434    3.489102    0.287474    0.076502    0.028810    0.692307    
#> 020: 0.299078    1.140083    3.489741    0.273100    0.072677    0.029156    0.710836    
#> 021: 0.285847    1.125637    3.500771    0.275708    0.069043    0.031458    0.713038    
#> 022: 0.280297    1.107153    3.514070    0.261923    0.065591    0.031634    0.705029    
#> 023: 0.355128    1.105694    3.519877    0.277690    0.062311    0.030053    0.741729    
#> 024: 0.349830    1.113865    3.504771    0.294276    0.070873    0.028550    0.728252    
#> 025: 0.325897    1.089312    3.508713    0.282638    0.067329    0.029051    0.728651    
#> 026: 0.280555    1.143377    3.491634    0.297707    0.078570    0.027598    0.707382    
#> 027: 0.234497    1.158317    3.476861    0.307991    0.078091    0.026218    0.712799    
#> 028: 0.285037    1.128709    3.488145    0.292591    0.076592    0.027955    0.690102    
#> 029: 0.284819    1.136918    3.480665    0.277961    0.082234    0.026558    0.718128    
#> 030: 0.268494    1.149016    3.477187    0.288377    0.080765    0.025975    0.710609    
#> 031: 0.254958    1.123184    3.487390    0.273958    0.093197    0.024676    0.704181    
#> 032: 0.280744    1.101483    3.508167    0.272010    0.088537    0.023442    0.711524    
#> 033: 0.242134    1.125576    3.491344    0.292548    0.084110    0.022270    0.727930    
#> 034: 0.284061    1.147507    3.483692    0.286419    0.079905    0.026380    0.713777    
#> 035: 0.254911    1.127185    3.478346    0.272098    0.080725    0.025061    0.710673    
#> 036: 0.257967    1.138137    3.476930    0.292837    0.084008    0.024042    0.711147    
#> 037: 0.248579    1.138146    3.483558    0.294569    0.085219    0.022840    0.718865    
#> 038: 0.225379    1.125690    3.475252    0.279840    0.080958    0.021749    0.724409    
#> 039: 0.265166    1.112943    3.494619    0.277306    0.076910    0.027497    0.714404    
#> 040: 0.274526    1.138527    3.509196    0.263441    0.073065    0.030291    0.730183    
#> 041: 0.261212    1.111185    3.493034    0.255520    0.069412    0.032789    0.723312    
#> 042: 0.305212    1.122734    3.490749    0.346210    0.065941    0.032300    0.693762    
#> 043: 0.274619    1.131865    3.482878    0.328899    0.062644    0.032802    0.700278    
#> 044: 0.266049    1.130049    3.488437    0.312454    0.060951    0.033355    0.708838    
#> 045: 0.246439    1.148484    3.471954    0.337944    0.060878    0.032826    0.689475    
#> 046: 0.270638    1.133464    3.491260    0.326913    0.059751    0.032620    0.688318    
#> 047: 0.257919    1.135245    3.469489    0.337116    0.056763    0.033268    0.701822    
#> 048: 0.240607    1.132352    3.475070    0.336554    0.060504    0.033778    0.703456    
#> 049: 0.230291    1.138874    3.475973    0.319726    0.068156    0.032090    0.709731    
#> 050: 0.269856    1.101329    3.493614    0.325652    0.064749    0.030485    0.728658    
#> 051: 0.278064    1.123675    3.476886    0.341661    0.061511    0.034009    0.733541    
#> 052: 0.282614    1.126347    3.508686    0.324578    0.065903    0.035450    0.696015    
#> 053: 0.292613    1.115643    3.498162    0.308349    0.062608    0.036650    0.693773    
#> 054: 0.250415    1.138265    3.489746    0.351976    0.070558    0.034818    0.691750    
#> 055: 0.275094    1.135431    3.494548    0.334377    0.067038    0.033077    0.705804    
#> 056: 0.283330    1.111857    3.501710    0.317658    0.063686    0.031423    0.717484    
#> 057: 0.280732    1.123542    3.498964    0.301775    0.068561    0.031516    0.725694    
#> 058: 0.305690    1.133293    3.475289    0.303042    0.065133    0.029940    0.717623    
#> 059: 0.275197    1.107581    3.490405    0.287890    0.067372    0.034233    0.718367    
#> 060: 0.284985    1.110270    3.510559    0.288516    0.064003    0.039122    0.727564    
#> 061: 0.312696    1.110714    3.515298    0.336850    0.061046    0.037166    0.754608    
#> 062: 0.358133    1.118543    3.524031    0.320008    0.073761    0.044378    0.767734    
#> 063: 0.379426    1.086956    3.521012    0.350282    0.070653    0.043141    0.748656    
#> 064: 0.330332    1.102170    3.530206    0.332768    0.067121    0.041566    0.736586    
#> 065: 0.349453    1.094555    3.513352    0.316130    0.063765    0.039487    0.718807    
#> 066: 0.348087    1.137777    3.517315    0.300323    0.072062    0.037513    0.707762    
#> 067: 0.306790    1.117912    3.515165    0.285307    0.068601    0.036419    0.695545    
#> 068: 0.252816    1.120296    3.506040    0.271042    0.073080    0.034598    0.723922    
#> 069: 0.283956    1.134222    3.496057    0.257490    0.069426    0.032869    0.745540    
#> 070: 0.264645    1.124804    3.504783    0.244615    0.068383    0.032030    0.737757    
#> 071: 0.250138    1.152634    3.476356    0.232384    0.077526    0.031166    0.752281    
#> 072: 0.186822    1.125678    3.478073    0.220765    0.073650    0.036773    0.743388    
#> 073: 0.249557    1.118169    3.498135    0.264970    0.069968    0.035597    0.746541    
#> 074: 0.230815    1.117490    3.472122    0.262697    0.066469    0.033817    0.727844    
#> 075: 0.252949    1.095417    3.512931    0.258899    0.082579    0.033907    0.726898    
#> 076: 0.322931    1.105376    3.515360    0.273975    0.078450    0.032707    0.728990    
#> 077: 0.320672    1.097091    3.512270    0.260276    0.074528    0.035672    0.732347    
#> 078: 0.291162    1.107059    3.516349    0.247262    0.070801    0.033889    0.716124    
#> 079: 0.280303    1.131870    3.497191    0.340972    0.067261    0.032194    0.721957    
#> 080: 0.299853    1.121499    3.505936    0.323923    0.070192    0.030585    0.744675    
#> 081: 0.280548    1.149230    3.501307    0.307727    0.066683    0.029055    0.732797    
#> 082: 0.277481    1.125023    3.505446    0.292341    0.063349    0.030176    0.723908    
#> 083: 0.270240    1.146893    3.496241    0.330949    0.062494    0.028667    0.708389    
#> 084: 0.259434    1.148833    3.493050    0.314402    0.070686    0.030320    0.707960    
#> 085: 0.271668    1.135247    3.510999    0.298682    0.067152    0.028804    0.721273    
#> 086: 0.292454    1.133728    3.512485    0.283748    0.069574    0.033658    0.701150    
#> 087: 0.267929    1.129626    3.488418    0.269560    0.069889    0.031975    0.720309    
#> 088: 0.208882    1.126246    3.477873    0.298701    0.066394    0.031282    0.737309    
#> 089: 0.221173    1.125708    3.471980    0.283766    0.065872    0.043377    0.717063    
#> 090: 0.212608    1.129818    3.468906    0.283340    0.065110    0.041208    0.712150    
#> 091: 0.202914    1.125764    3.454680    0.302510    0.063540    0.039147    0.712667    
#> 092: 0.229281    1.141405    3.469174    0.287385    0.060363    0.037190    0.727838    
#> 093: 0.233089    1.133313    3.476866    0.297303    0.068403    0.035331    0.721270    
#> 094: 0.257924    1.159623    3.473436    0.284638    0.064983    0.033564    0.724262    
#> 095: 0.257172    1.151281    3.477122    0.339586    0.061733    0.034514    0.714946    
#> 096: 0.214118    1.153960    3.466645    0.325677    0.058647    0.035701    0.697624    
#> 097: 0.241738    1.157744    3.470480    0.309393    0.055714    0.039889    0.694677    
#> 098: 0.245640    1.159239    3.476497    0.293923    0.052929    0.037894    0.707748    
#> 099: 0.204871    1.139375    3.458740    0.322485    0.057495    0.039312    0.704384    
#> 100: 0.228344    1.141690    3.470333    0.314405    0.067214    0.039481    0.700730    
#> 101: 0.202336    1.135692    3.454778    0.298685    0.063853    0.037507    0.691388    
#> 102: 0.218098    1.143840    3.466634    0.308751    0.063790    0.035632    0.704895    
#> 103: 0.231345    1.148799    3.474982    0.293314    0.060601    0.037633    0.705858    
#> 104: 0.237218    1.153264    3.480095    0.354599    0.062589    0.035752    0.724837    
#> 105: 0.277742    1.144953    3.487487    0.385701    0.071417    0.033964    0.709513    
#> 106: 0.278515    1.149512    3.483854    0.377032    0.067846    0.032266    0.705839    
#> 107: 0.282119    1.136916    3.481200    0.433934    0.064453    0.031743    0.716618    
#> 108: 0.243042    1.132752    3.487446    0.412238    0.079730    0.030911    0.709777    
#> 109: 0.235374    1.141815    3.493585    0.391626    0.075743    0.029365    0.714820    
#> 110: 0.270875    1.111648    3.480340    0.372044    0.071956    0.030228    0.709135    
#> 111: 0.255988    1.127966    3.487536    0.353442    0.070042    0.031839    0.699604    
#> 112: 0.223764    1.130439    3.468851    0.335770    0.092614    0.030247    0.726122    
#> 113: 0.266195    1.158797    3.485376    0.318982    0.087983    0.030717    0.715583    
#> 114: 0.263553    1.154730    3.484903    0.314075    0.083584    0.031846    0.722250    
#> 115: 0.269919    1.135950    3.481910    0.360537    0.079405    0.032982    0.719906    
#> 116: 0.278427    1.111921    3.477542    0.342510    0.075434    0.034164    0.709229    
#> 117: 0.231695    1.133287    3.484630    0.325384    0.071663    0.034735    0.707326    
#> 118: 0.269343    1.118422    3.485156    0.309115    0.068080    0.032999    0.704569    
#> 119: 0.248566    1.123159    3.486143    0.293659    0.064676    0.034289    0.711709    
#> 120: 0.237942    1.106582    3.486804    0.307936    0.061442    0.037880    0.710442    
#> 121: 0.262628    1.149835    3.486420    0.292539    0.078052    0.035986    0.724770    
#> 122: 0.246145    1.135980    3.497552    0.287856    0.074149    0.037907    0.713412    
#> 123: 0.270787    1.140893    3.486712    0.273464    0.076923    0.036012    0.716415    
#> 124: 0.268999    1.151559    3.476189    0.302955    0.073077    0.034211    0.722875    
#> 125: 0.276732    1.149583    3.478367    0.327068    0.072404    0.032501    0.700201    
#> 126: 0.258346    1.164311    3.464040    0.324455    0.072032    0.037758    0.694355    
#> 127: 0.286798    1.161322    3.467801    0.370453    0.070175    0.035870    0.712276    
#> 128: 0.260601    1.126805    3.487707    0.351930    0.066666    0.036756    0.720402    
#> 129: 0.293823    1.137970    3.503711    0.334334    0.066932    0.044331    0.730485    
#> 130: 0.325901    1.124524    3.499853    0.317617    0.063586    0.043007    0.702392    
#> 131: 0.286371    1.134132    3.490620    0.301736    0.071432    0.040856    0.710311    
#> 132: 0.235758    1.144039    3.464052    0.310733    0.076602    0.038814    0.703531    
#> 133: 0.254055    1.128535    3.472320    0.313333    0.072772    0.036873    0.712069    
#> 134: 0.266724    1.122913    3.497156    0.297666    0.069133    0.035679    0.724209    
#> 135: 0.279548    1.112790    3.500887    0.282783    0.065676    0.034627    0.723361    
#> 136: 0.307373    1.093438    3.507791    0.268644    0.062393    0.038159    0.721106    
#> 137: 0.329216    1.086527    3.525873    0.273257    0.059273    0.041862    0.744015    
#> 138: 0.330430    1.093715    3.525986    0.279265    0.056309    0.043617    0.723264    
#> 139: 0.334715    1.098810    3.542998    0.268084    0.054913    0.045669    0.718648    
#> 140: 0.329811    1.106468    3.528777    0.254680    0.058142    0.043386    0.735524    
#> 141: 0.270443    1.087439    3.510186    0.242817    0.055235    0.041216    0.735962    
#> 142: 0.254886    1.075977    3.515900    0.272990    0.052473    0.040491    0.754379    
#> 143: 0.261770    1.097732    3.507387    0.270627    0.049850    0.041704    0.744274    
#> 144: 0.308462    1.120449    3.510448    0.282817    0.047357    0.046222    0.723420    
#> 145: 0.241067    1.121110    3.476583    0.286005    0.045280    0.046610    0.712211    
#> 146: 0.225991    1.134047    3.488009    0.340582    0.045707    0.044279    0.712225    
#> 147: 0.213791    1.129750    3.468535    0.323725    0.047545    0.042066    0.701324    
#> 148: 0.235298    1.132510    3.478063    0.307539    0.057544    0.039962    0.702067    
#> 149: 0.250716    1.133724    3.480648    0.315721    0.058252    0.038695    0.731378    
#> 150: 0.285392    1.108806    3.476511    0.334533    0.058300    0.036761    0.728503    
#> 151: 0.225284    1.144957    3.488877    0.317807    0.060314    0.039010    0.714619    
#> 152: 0.235525    1.147949    3.470013    0.297348    0.057070    0.053940    0.698316    
#> 153: 0.267786    1.136990    3.499731    0.266741    0.070115    0.044654    0.722024    
#> 154: 0.309484    1.124064    3.507628    0.234199    0.060527    0.041345    0.695296    
#> 155: 0.307408    1.090073    3.515068    0.211989    0.045854    0.042700    0.714263    
#> 156: 0.314311    1.096566    3.508560    0.212965    0.046501    0.050283    0.740135    
#> 157: 0.307778    1.085488    3.519571    0.234213    0.043643    0.050615    0.716352    
#> 158: 0.333823    1.088005    3.525560    0.250847    0.047115    0.047634    0.722760    
#> 159: 0.300078    1.105610    3.522545    0.256075    0.054235    0.044234    0.715228    
#> 160: 0.334095    1.096357    3.526057    0.278972    0.058309    0.042169    0.702893    
#> 161: 0.343034    1.099337    3.536163    0.277977    0.057372    0.047806    0.715711    
#> 162: 0.309897    1.116453    3.515517    0.271442    0.054811    0.046202    0.727915    
#> 163: 0.314539    1.105555    3.505799    0.215710    0.057627    0.036952    0.716428    
#> 164: 0.306509    1.107427    3.512071    0.243343    0.055198    0.042044    0.723248    
#> 165: 0.310098    1.101628    3.503236    0.275278    0.056926    0.037791    0.704454    
#> 166: 0.313212    1.144462    3.503692    0.252477    0.061885    0.037901    0.714724    
#> 167: 0.331192    1.153700    3.521058    0.298128    0.061270    0.043200    0.708895    
#> 168: 0.292658    1.151311    3.508034    0.271513    0.065414    0.037378    0.704475    
#> 169: 0.279017    1.176283    3.488035    0.208888    0.065301    0.037407    0.727529    
#> 170: 0.252736    1.155629    3.480516    0.220848    0.067001    0.038117    0.711765    
#> 171: 0.233691    1.140120    3.484692    0.239326    0.065081    0.027472    0.716620    
#> 172: 0.198658    1.160112    3.465387    0.235705    0.061578    0.025892    0.706150    
#> 173: 0.179929    1.176201    3.439897    0.287419    0.057969    0.032728    0.696713    
#> 174: 0.199083    1.173653    3.457381    0.326770    0.073471    0.036722    0.715420    
#> 175: 0.196634    1.175050    3.448482    0.271096    0.070114    0.037175    0.707313    
#> 176: 0.206819    1.162767    3.467485    0.302877    0.069506    0.029992    0.703968    
#> 177: 0.219882    1.143635    3.472749    0.316353    0.085844    0.028549    0.686704    
#> 178: 0.258332    1.152724    3.484338    0.298360    0.080321    0.030774    0.680708    
#> 179: 0.295768    1.150946    3.477611    0.320274    0.083972    0.029927    0.697751    
#> 180: 0.264373    1.144532    3.483766    0.282287    0.069273    0.032274    0.688231    
#> 181: 0.250791    1.142445    3.465503    0.313944    0.073193    0.032013    0.708590    
#> 182: 0.206416    1.143842    3.454728    0.299433    0.065584    0.032759    0.723021    
#> 183: 0.245361    1.166508    3.463472    0.345502    0.073345    0.036155    0.701329    
#> 184: 0.230105    1.152752    3.467622    0.309581    0.060938    0.039601    0.697274    
#> 185: 0.202287    1.161621    3.457680    0.309544    0.049754    0.039160    0.702934    
#> 186: 0.221581    1.183236    3.467318    0.313967    0.075406    0.044844    0.702539    
#> 187: 0.229345    1.147361    3.470014    0.288496    0.063315    0.047789    0.703772    
#> 188: 0.200002    1.167775    3.469739    0.271709    0.066461    0.038710    0.717265    
#> 189: 0.235877    1.164309    3.473269    0.278818    0.061057    0.037120    0.711856    
#> 190: 0.225985    1.147036    3.476144    0.273380    0.056050    0.044724    0.708973    
#> 191: 0.240666    1.147992    3.473739    0.287697    0.045599    0.036374    0.703771    
#> 192: 0.207692    1.154889    3.477236    0.273733    0.056417    0.034710    0.700895    
#> 193: 0.263079    1.153400    3.482864    0.289763    0.055461    0.034835    0.697285    
#> 194: 0.251018    1.144746    3.483382    0.302756    0.066496    0.031083    0.699338    
#> 195: 0.240000    1.144126    3.461215    0.352153    0.060989    0.032409    0.700180    
#> 196: 0.230671    1.149973    3.480044    0.266806    0.071283    0.034876    0.702095    
#> 197: 0.232808    1.161038    3.488877    0.271849    0.063163    0.037309    0.717886    
#> 198: 0.277981    1.140689    3.486101    0.338317    0.042949    0.046085    0.696754    
#> 199: 0.252816    1.125080    3.474472    0.348102    0.052052    0.037780    0.707504    
#> 200: 0.242513    1.142528    3.477386    0.347389    0.064566    0.034642    0.701210    
#> 201: 0.222515    1.130756    3.487517    0.321003    0.058015    0.037689    0.714668    
#> 202: 0.227218    1.133459    3.484244    0.328008    0.059132    0.037436    0.710047    
#> 203: 0.238411    1.133695    3.480671    0.340769    0.059849    0.037590    0.710198    
#> 204: 0.248743    1.125046    3.485357    0.344799    0.059987    0.037970    0.712033    
#> 205: 0.249230    1.128401    3.485435    0.340669    0.061362    0.038159    0.713134    
#> 206: 0.243388    1.136837    3.482483    0.336007    0.063170    0.037174    0.712440    
#> 207: 0.245607    1.137803    3.481097    0.333362    0.063119    0.037193    0.711532    
#> 208: 0.246548    1.137674    3.482993    0.325434    0.062313    0.037807    0.711180    
#> 209: 0.249259    1.133596    3.483324    0.318766    0.061681    0.037875    0.710683    
#> 210: 0.252422    1.132081    3.484388    0.319186    0.061672    0.037679    0.710207    
#> 211: 0.255291    1.132396    3.485825    0.317355    0.062422    0.037491    0.708951    
#> 212: 0.260036    1.130980    3.487373    0.317995    0.061573    0.037591    0.708524    
#> 213: 0.262140    1.128363    3.488670    0.317023    0.060733    0.038004    0.709297    
#> 214: 0.265693    1.126835    3.490592    0.312962    0.060250    0.038341    0.709857    
#> 215: 0.265254    1.126403    3.492161    0.310768    0.059585    0.038722    0.710075    
#> 216: 0.270078    1.124425    3.494251    0.310897    0.059470    0.039024    0.710914    
#> 217: 0.273144    1.124159    3.495540    0.311236    0.058996    0.039128    0.711435    
#> 218: 0.274409    1.125099    3.495529    0.309219    0.058997    0.039331    0.710713    
#> 219: 0.273246    1.125027    3.494490    0.308130    0.058535    0.039339    0.711378    
#> 220: 0.271716    1.125314    3.494189    0.304444    0.057906    0.039372    0.711788    
#> 221: 0.270296    1.125497    3.493887    0.302029    0.057921    0.039685    0.711912    
#> 222: 0.269981    1.125593    3.493485    0.299018    0.058370    0.039742    0.712450    
#> 223: 0.271175    1.125404    3.493693    0.299375    0.058834    0.039781    0.712738    
#> 224: 0.272980    1.125970    3.493605    0.298944    0.059309    0.039469    0.713157    
#> 225: 0.272348    1.124895    3.493711    0.299483    0.059865    0.039413    0.713485    
#> 226: 0.272820    1.123573    3.494024    0.299437    0.060487    0.039136    0.713512    
#> 227: 0.271972    1.122860    3.493987    0.299138    0.061253    0.038928    0.713746    
#> 228: 0.271640    1.122773    3.493924    0.298479    0.061438    0.038777    0.713622    
#> 229: 0.272323    1.122056    3.494014    0.297813    0.061389    0.038757    0.713051    
#> 230: 0.273041    1.121649    3.494092    0.298569    0.061373    0.038601    0.712966    
#> 231: 0.273143    1.121893    3.494409    0.296330    0.061478    0.038498    0.713188    
#> 232: 0.273359    1.121428    3.494882    0.294961    0.061307    0.038276    0.713316    
#> 233: 0.273194    1.120463    3.495033    0.295233    0.060928    0.038459    0.712759    
#> 234: 0.273498    1.119931    3.495357    0.293928    0.060752    0.038463    0.712761    
#> 235: 0.273633    1.119161    3.495358    0.293025    0.060645    0.038605    0.712401    
#> 236: 0.273616    1.119611    3.495346    0.292317    0.060620    0.038662    0.712667    
#> 237: 0.274596    1.119829    3.495528    0.292145    0.060678    0.038641    0.713346    
#> 238: 0.275784    1.119926    3.495805    0.290988    0.061050    0.038711    0.713870    
#> 239: 0.275370    1.120632    3.495598    0.290156    0.061211    0.038960    0.713520    
#> 240: 0.275432    1.120767    3.495866    0.289278    0.061306    0.039133    0.713329    
#> 241: 0.275377    1.120278    3.495730    0.288666    0.061571    0.039090    0.713225    
#> 242: 0.274870    1.120057    3.495458    0.287900    0.062067    0.038919    0.713562    
#> 243: 0.273494    1.120872    3.495136    0.286629    0.062459    0.038760    0.714135    
#> 244: 0.273395    1.120840    3.495499    0.284619    0.062482    0.038725    0.714758    
#> 245: 0.273633    1.120407    3.495815    0.284174    0.062781    0.038687    0.715053    
#> 246: 0.273855    1.120467    3.495959    0.283406    0.062685    0.038682    0.715408    
#> 247: 0.273775    1.120402    3.496027    0.282204    0.062717    0.038675    0.715346    
#> 248: 0.273886    1.120493    3.495989    0.281969    0.062672    0.038521    0.715009    
#> 249: 0.273667    1.120455    3.495965    0.280922    0.062637    0.038486    0.714604    
#> 250: 0.273604    1.121018    3.495943    0.280463    0.062993    0.038428    0.714258    
#> 251: 0.273899    1.121650    3.496079    0.280123    0.063148    0.038346    0.714161    
#> 252: 0.274128    1.121916    3.496337    0.279581    0.063497    0.038269    0.714158    
#> 253: 0.274302    1.122130    3.496424    0.279429    0.063850    0.038202    0.714265    
#> 254: 0.274411    1.122489    3.496648    0.278622    0.064117    0.038042    0.714115    
#> 255: 0.274341    1.122748    3.496607    0.278487    0.064117    0.037916    0.714351    
#> 256: 0.274605    1.122343    3.496630    0.278735    0.064199    0.037737    0.714691    
#> 257: 0.274869    1.121988    3.496594    0.278340    0.064282    0.037559    0.715132    
#> 258: 0.274833    1.121157    3.496735    0.279182    0.064193    0.037464    0.715528    
#> 259: 0.274632    1.120978    3.496791    0.279105    0.064206    0.037406    0.715797    
#> 260: 0.274456    1.121197    3.496643    0.279926    0.064133    0.037454    0.715755    
#> 261: 0.274433    1.120997    3.496806    0.280218    0.064130    0.037561    0.715713    
#> 262: 0.274982    1.121112    3.496886    0.280851    0.064122    0.037546    0.715720    
#> 263: 0.275164    1.121346    3.496924    0.280910    0.064075    0.037554    0.715680    
#> 264: 0.275044    1.121225    3.496908    0.280962    0.064136    0.037596    0.715844    
#> 265: 0.275800    1.120939    3.497030    0.281653    0.064225    0.037662    0.715786    
#> 266: 0.276450    1.120908    3.497215    0.282357    0.064240    0.037678    0.715639    
#> 267: 0.276817    1.120732    3.497433    0.282692    0.064175    0.037731    0.715607    
#> 268: 0.277039    1.120617    3.497412    0.282589    0.064269    0.037764    0.715441    
#> 269: 0.277530    1.120834    3.497285    0.282843    0.064254    0.037772    0.715479    
#> 270: 0.277709    1.121154    3.497187    0.283089    0.064208    0.037764    0.715240    
#> 271: 0.277845    1.121218    3.497051    0.283304    0.064193    0.037729    0.715329    
#> 272: 0.277527    1.120954    3.496898    0.283388    0.064222    0.037760    0.715646    
#> 273: 0.277203    1.121139    3.496838    0.284021    0.064252    0.037819    0.715958    
#> 274: 0.276568    1.121504    3.496702    0.283980    0.064144    0.037778    0.715977    
#> 275: 0.276172    1.121694    3.496505    0.283943    0.064248    0.037705    0.715810    
#> 276: 0.275582    1.121865    3.496432    0.284875    0.064105    0.037629    0.715901    
#> 277: 0.275498    1.122048    3.496575    0.284572    0.063988    0.037581    0.715980    
#> 278: 0.275632    1.122019    3.496725    0.284142    0.064090    0.037514    0.716053    
#> 279: 0.275473    1.121982    3.496921    0.283670    0.064294    0.037452    0.716169    
#> 280: 0.275619    1.122263    3.496929    0.283771    0.064494    0.037367    0.716146    
#> 281: 0.275214    1.122640    3.496874    0.284214    0.064539    0.037406    0.716096    
#> 282: 0.275056    1.123216    3.496838    0.284720    0.064549    0.037480    0.716184    
#> 283: 0.274697    1.123673    3.496676    0.285356    0.064515    0.037533    0.716405    
#> 284: 0.274136    1.123802    3.496492    0.286001    0.064415    0.037528    0.716205    
#> 285: 0.273800    1.123951    3.496274    0.286073    0.064401    0.037528    0.716119    
#> 286: 0.273416    1.124143    3.496102    0.286114    0.064416    0.037486    0.716065    
#> 287: 0.273111    1.124529    3.495929    0.286200    0.064475    0.037455    0.716048    
#> 288: 0.273381    1.124512    3.495969    0.285903    0.064413    0.037424    0.716312    
#> 289: 0.273712    1.124312    3.495978    0.286152    0.064482    0.037397    0.716405    
#> 290: 0.274007    1.124211    3.495948    0.286844    0.064316    0.037401    0.716666    
#> 291: 0.274115    1.124328    3.495970    0.287476    0.064224    0.037411    0.716474    
#> 292: 0.273767    1.124362    3.495831    0.287627    0.064146    0.037386    0.716366    
#> 293: 0.273246    1.124609    3.495691    0.287412    0.064161    0.037348    0.716290    
#> 294: 0.272863    1.124870    3.495570    0.287574    0.064212    0.037328    0.716118    
#> 295: 0.272360    1.124796    3.495425    0.287153    0.064070    0.037334    0.715951    
#> 296: 0.271835    1.124819    3.495246    0.286880    0.063900    0.037330    0.715911    
#> 297: 0.271591    1.124952    3.495120    0.286813    0.063745    0.037366    0.715832    
#> 298: 0.271754    1.124833    3.495099    0.286652    0.063734    0.037328    0.715761    
#> 299: 0.271519    1.124930    3.494951    0.286258    0.063761    0.037248    0.715759    
#> 300: 0.271337    1.124956    3.494861    0.286319    0.063864    0.037152    0.715598    
#> 301: 0.271414    1.124916    3.494706    0.286461    0.063919    0.037072    0.715694    
#> 302: 0.271504    1.125279    3.494551    0.286200    0.064088    0.037011    0.715432    
#> 303: 0.271221    1.125668    3.494302    0.286068    0.064242    0.036932    0.715132    
#> 304: 0.271229    1.126104    3.494011    0.286099    0.064246    0.036854    0.715136    
#> 305: 0.270890    1.126054    3.493820    0.285899    0.064263    0.036825    0.715093    
#> 306: 0.270419    1.125997    3.493620    0.285656    0.064306    0.036745    0.714976    
#> 307: 0.270228    1.125970    3.493404    0.285984    0.064452    0.036664    0.714934    
#> 308: 0.269659    1.125959    3.493210    0.286011    0.064649    0.036623    0.714893    
#> 309: 0.269444    1.125883    3.493182    0.286189    0.064705    0.036553    0.715023    
#> 310: 0.269734    1.125726    3.493129    0.286164    0.064810    0.036496    0.715121    
#> 311: 0.269768    1.125683    3.493201    0.286408    0.064824    0.036475    0.714939    
#> 312: 0.269839    1.125659    3.493179    0.286979    0.064895    0.036491    0.714805    
#> 313: 0.269634    1.125383    3.493092    0.287426    0.064960    0.036511    0.714931    
#> 314: 0.269268    1.125341    3.492969    0.287553    0.065028    0.036510    0.715067    
#> 315: 0.269104    1.125269    3.492925    0.287324    0.064971    0.036489    0.715085    
#> 316: 0.269251    1.125390    3.492953    0.287524    0.064972    0.036465    0.715165    
#> 317: 0.269338    1.125502    3.493022    0.287756    0.064946    0.036417    0.715289    
#> 318: 0.269271    1.125673    3.492824    0.287968    0.064916    0.036417    0.715267    
#> 319: 0.269045    1.125801    3.492677    0.288151    0.064927    0.036446    0.715391    
#> 320: 0.268751    1.125842    3.492470    0.288554    0.064838    0.036402    0.715448    
#> 321: 0.268555    1.125886    3.492233    0.288888    0.064762    0.036335    0.715570    
#> 322: 0.268176    1.125981    3.492142    0.288601    0.064738    0.036300    0.715570    
#> 323: 0.267598    1.126039    3.492027    0.288678    0.064731    0.036264    0.715668    
#> 324: 0.267525    1.126272    3.491954    0.288735    0.064761    0.036219    0.715581    
#> 325: 0.267408    1.126506    3.491881    0.288280    0.064692    0.036211    0.715568    
#> 326: 0.267643    1.126196    3.492003    0.287787    0.064612    0.036201    0.715662    
#> 327: 0.267817    1.126066    3.492177    0.287260    0.064573    0.036204    0.715786    
#> 328: 0.267832    1.125971    3.492249    0.286738    0.064494    0.036172    0.715807    
#> 329: 0.268096    1.125895    3.492368    0.286509    0.064490    0.036134    0.715765    
#> 330: 0.268166    1.125868    3.492454    0.286337    0.064531    0.036082    0.715765    
#> 331: 0.268262    1.126014    3.492426    0.286260    0.064597    0.036048    0.715896    
#> 332: 0.268222    1.125990    3.492542    0.286241    0.064554    0.036022    0.716051    
#> 333: 0.267970    1.126022    3.492483    0.285892    0.064525    0.036040    0.716003    
#> 334: 0.267812    1.125899    3.492459    0.285598    0.064468    0.036054    0.715897    
#> 335: 0.267810    1.125935    3.492300    0.285708    0.064462    0.036048    0.715798    
#> 336: 0.267469    1.126149    3.492209    0.285917    0.064470    0.036032    0.715855    
#> 337: 0.267170    1.126470    3.491961    0.285847    0.064492    0.036010    0.715906    
#> 338: 0.266797    1.126761    3.491863    0.285759    0.064472    0.036041    0.715960    
#> 339: 0.266434    1.127007    3.491700    0.285737    0.064364    0.036089    0.715904    
#> 340: 0.266176    1.126984    3.491610    0.285590    0.064283    0.036119    0.715854    
#> 341: 0.266132    1.126992    3.491635    0.285432    0.064277    0.036145    0.715842    
#> 342: 0.265859    1.126837    3.491614    0.285274    0.064265    0.036171    0.715774    
#> 343: 0.265634    1.126796    3.491668    0.284822    0.064257    0.036212    0.715704    
#> 344: 0.265674    1.126676    3.491747    0.284782    0.064139    0.036237    0.715693    
#> 345: 0.265895    1.126539    3.491821    0.284910    0.064098    0.036276    0.715749    
#> 346: 0.265930    1.126506    3.491794    0.284937    0.064027    0.036314    0.715702    
#> 347: 0.265874    1.126315    3.491755    0.285004    0.064031    0.036366    0.715787    
#> 348: 0.265678    1.126430    3.491716    0.284769    0.064149    0.036388    0.715905    
#> 349: 0.265439    1.126343    3.491645    0.284915    0.064128    0.036404    0.715881    
#> 350: 0.265107    1.126139    3.491537    0.284953    0.064169    0.036400    0.715970    
#> 351: 0.265096    1.126294    3.491474    0.284860    0.064174    0.036374    0.715982    
#> 352: 0.264878    1.126442    3.491455    0.284725    0.064196    0.036367    0.716259    
#> 353: 0.264824    1.126616    3.491343    0.284841    0.064206    0.036405    0.716273    
#> 354: 0.264814    1.126755    3.491251    0.285012    0.064180    0.036437    0.716209    
#> 355: 0.265145    1.126719    3.491262    0.285406    0.064077    0.036476    0.716235    
#> 356: 0.265213    1.126620    3.491293    0.285685    0.064063    0.036510    0.716233    
#> 357: 0.265446    1.126756    3.491292    0.285816    0.064043    0.036546    0.716166    
#> 358: 0.265532    1.126768    3.491362    0.285542    0.063969    0.036623    0.716095    
#> 359: 0.265413    1.126826    3.491305    0.285380    0.063907    0.036666    0.716089    
#> 360: 0.265198    1.126887    3.491138    0.285504    0.063920    0.036661    0.715994    
#> 361: 0.264980    1.127052    3.491070    0.285242    0.063907    0.036655    0.715970    
#> 362: 0.264964    1.127137    3.491000    0.284793    0.063874    0.036631    0.715843    
#> 363: 0.264999    1.127152    3.490976    0.284704    0.063794    0.036632    0.715665    
#> 364: 0.265012    1.127328    3.490929    0.284493    0.063793    0.036657    0.715530    
#> 365: 0.264882    1.127331    3.490905    0.284353    0.063745    0.036665    0.715571    
#> 366: 0.264851    1.127397    3.490802    0.284260    0.063792    0.036647    0.715622    
#> 367: 0.264732    1.127521    3.490717    0.284175    0.063844    0.036592    0.715584    
#> 368: 0.264823    1.127593    3.490672    0.283982    0.063813    0.036565    0.715564    
#> 369: 0.264730    1.127634    3.490641    0.283921    0.063873    0.036544    0.715589    
#> 370: 0.264564    1.127791    3.490569    0.283809    0.063848    0.036526    0.715569    
#> 371: 0.264173    1.127938    3.490375    0.284015    0.063798    0.036514    0.715508    
#> 372: 0.264001    1.127971    3.490274    0.284370    0.063766    0.036527    0.715494    
#> 373: 0.263743    1.128067    3.490133    0.285125    0.063795    0.036520    0.715460    
#> 374: 0.263721    1.128148    3.490048    0.285483    0.063808    0.036533    0.715416    
#> 375: 0.263284    1.128104    3.489930    0.285593    0.063786    0.036504    0.715488    
#> 376: 0.263099    1.128136    3.489832    0.285914    0.063765    0.036523    0.715361    
#> 377: 0.262950    1.128175    3.489748    0.286195    0.063711    0.036491    0.715345    
#> 378: 0.262880    1.128156    3.489704    0.286380    0.063698    0.036470    0.715375    
#> 379: 0.262872    1.128025    3.489708    0.286809    0.063715    0.036487    0.715312    
#> 380: 0.262782    1.127964    3.489642    0.287127    0.063732    0.036469    0.715225    
#> 381: 0.262597    1.127882    3.489578    0.287306    0.063734    0.036434    0.715273    
#> 382: 0.262607    1.127923    3.489600    0.287695    0.063763    0.036427    0.715144    
#> 383: 0.262725    1.127839    3.489647    0.288168    0.063792    0.036427    0.714979    
#> 384: 0.262741    1.127782    3.489650    0.288538    0.063765    0.036425    0.714951    
#> 385: 0.262820    1.127684    3.489670    0.288533    0.063774    0.036433    0.714968    
#> 386: 0.262953    1.127748    3.489699    0.288789    0.063815    0.036438    0.714931    
#> 387: 0.263239    1.127666    3.489863    0.288801    0.063826    0.036429    0.714952    
#> 388: 0.263272    1.127685    3.489920    0.288762    0.063802    0.036423    0.714955    
#> 389: 0.263174    1.127588    3.489838    0.288745    0.063703    0.036421    0.715062    
#> 390: 0.262954    1.127572    3.489729    0.288996    0.063677    0.036393    0.715071    
#> 391: 0.262909    1.127614    3.489643    0.288972    0.063672    0.036374    0.715058    
#> 392: 0.262905    1.127591    3.489663    0.288899    0.063625    0.036337    0.715182    
#> 393: 0.262927    1.127455    3.489647    0.289017    0.063554    0.036328    0.715145    
#> 394: 0.262977    1.127466    3.489702    0.288780    0.063531    0.036328    0.715224    
#> 395: 0.263130    1.127600    3.489690    0.288721    0.063523    0.036337    0.715214    
#> 396: 0.263310    1.127658    3.489728    0.288768    0.063486    0.036359    0.715185    
#> 397: 0.263419    1.127610    3.489804    0.288723    0.063372    0.036361    0.715190    
#> 398: 0.263746    1.127452    3.489894    0.288673    0.063299    0.036379    0.715143    
#> 399: 0.264060    1.127525    3.489965    0.288876    0.063353    0.036358    0.715116    
#> 400: 0.264148    1.127651    3.489985    0.289054    0.063419    0.036327    0.715106    
#> 401: 0.264249    1.127704    3.490000    0.289179    0.063437    0.036336    0.715255    
#> 402: 0.264341    1.127782    3.490040    0.289275    0.063430    0.036363    0.715315    
#> 403: 0.264665    1.127881    3.490027    0.289313    0.063407    0.036396    0.715351    
#> 404: 0.264609    1.127961    3.489941    0.289246    0.063391    0.036407    0.715356    
#> 405: 0.264643    1.128062    3.489954    0.289150    0.063359    0.036418    0.715320    
#> 406: 0.264658    1.128198    3.489858    0.289215    0.063311    0.036414    0.715317    
#> 407: 0.264600    1.128325    3.489797    0.289240    0.063340    0.036422    0.715304    
#> 408: 0.264572    1.128394    3.489767    0.289385    0.063319    0.036422    0.715371    
#> 409: 0.264404    1.128407    3.489674    0.289489    0.063341    0.036419    0.715345    
#> 410: 0.264220    1.128515    3.489529    0.289618    0.063401    0.036426    0.715323    
#> 411: 0.264127    1.128395    3.489485    0.289814    0.063457    0.036426    0.715408    
#> 412: 0.263982    1.128433    3.489440    0.289744    0.063483    0.036419    0.715379    
#> 413: 0.263835    1.128505    3.489353    0.289503    0.063456    0.036404    0.715427    
#> 414: 0.263490    1.128606    3.489272    0.289276    0.063438    0.036397    0.715388    
#> 415: 0.263424    1.128681    3.489255    0.289085    0.063387    0.036395    0.715329    
#> 416: 0.263495    1.128809    3.489255    0.289021    0.063443    0.036371    0.715260    
#> 417: 0.263392    1.128866    3.489238    0.289228    0.063503    0.036350    0.715245    
#> 418: 0.263223    1.128934    3.489241    0.289130    0.063593    0.036335    0.715227    
#> 419: 0.263144    1.129130    3.489167    0.289256    0.063659    0.036377    0.715159    
#> 420: 0.263294    1.129174    3.489139    0.289493    0.063642    0.036391    0.715102    
#> 421: 0.263224    1.129211    3.489168    0.289585    0.063621    0.036420    0.715074    
#> 422: 0.263365    1.129172    3.489169    0.289714    0.063586    0.036436    0.715071    
#> 423: 0.263462    1.129125    3.489150    0.289759    0.063549    0.036425    0.715157    
#> 424: 0.263452    1.129104    3.489133    0.289998    0.063547    0.036431    0.715226    
#> 425: 0.263421    1.129147    3.489100    0.290274    0.063534    0.036463    0.715230    
#> 426: 0.263424    1.129221    3.489028    0.290343    0.063504    0.036464    0.715190    
#> 427: 0.263300    1.129246    3.489054    0.290262    0.063461    0.036491    0.715115    
#> 428: 0.263091    1.129380    3.489049    0.290112    0.063440    0.036494    0.715184    
#> 429: 0.263276    1.129340    3.489160    0.289705    0.063475    0.036500    0.715302    
#> 430: 0.263280    1.129325    3.489218    0.289517    0.063429    0.036490    0.715377    
#> 431: 0.263316    1.129302    3.489263    0.289313    0.063404    0.036456    0.715324    
#> 432: 0.263343    1.129349    3.489278    0.289251    0.063419    0.036458    0.715277    
#> 433: 0.263396    1.129367    3.489332    0.289157    0.063430    0.036448    0.715292    
#> 434: 0.263385    1.129226    3.489357    0.289061    0.063416    0.036462    0.715349    
#> 435: 0.263526    1.129225    3.489374    0.289147    0.063403    0.036449    0.715300    
#> 436: 0.263595    1.129193    3.489457    0.289265    0.063432    0.036438    0.715352    
#> 437: 0.263677    1.129133    3.489493    0.289249    0.063470    0.036419    0.715368    
#> 438: 0.263675    1.129332    3.489461    0.289139    0.063566    0.036407    0.715400    
#> 439: 0.263691    1.129418    3.489451    0.289172    0.063578    0.036397    0.715360    
#> 440: 0.263613    1.129432    3.489454    0.289262    0.063591    0.036385    0.715300    
#> 441: 0.263451    1.129408    3.489421    0.289481    0.063580    0.036368    0.715210    
#> 442: 0.263344    1.129439    3.489400    0.289598    0.063608    0.036351    0.715131    
#> 443: 0.263346    1.129479    3.489359    0.289412    0.063617    0.036339    0.715147    
#> 444: 0.263284    1.129565    3.489230    0.289466    0.063681    0.036331    0.715119    
#> 445: 0.263054    1.129700    3.489169    0.289484    0.063779    0.036313    0.715175    
#> 446: 0.262936    1.129754    3.489127    0.289482    0.063816    0.036283    0.715146    
#> 447: 0.262962    1.129762    3.489135    0.289379    0.063816    0.036268    0.715136    
#> 448: 0.262882    1.129769    3.489119    0.289301    0.063855    0.036245    0.715037    
#> 449: 0.262949    1.129842    3.489193    0.289215    0.063872    0.036225    0.715034    
#> 450: 0.262914    1.129849    3.489207    0.289056    0.063925    0.036220    0.715007    
#> 451: 0.263017    1.129861    3.489238    0.289013    0.063982    0.036242    0.715012    
#> 452: 0.263028    1.129905    3.489241    0.288977    0.064045    0.036254    0.714963    
#> 453: 0.263040    1.129963    3.489169    0.289100    0.064092    0.036242    0.714896    
#> 454: 0.262917    1.130103    3.489103    0.289022    0.064120    0.036231    0.714875    
#> 455: 0.262800    1.130093    3.489064    0.288924    0.064104    0.036221    0.714897    
#> 456: 0.262674    1.130060    3.489024    0.288955    0.064092    0.036205    0.714900    
#> 457: 0.262532    1.130055    3.489044    0.288766    0.064098    0.036216    0.714911    
#> 458: 0.262468    1.130110    3.489077    0.288757    0.064091    0.036249    0.714885    
#> 459: 0.262317    1.130259    3.489037    0.288800    0.064079    0.036263    0.714876    
#> 460: 0.262162    1.130372    3.488895    0.288835    0.064065    0.036280    0.714874    
#> 461: 0.261931    1.130471    3.488834    0.288736    0.064021    0.036275    0.714806    
#> 462: 0.261726    1.130538    3.488771    0.288679    0.064004    0.036264    0.714800    
#> 463: 0.261620    1.130612    3.488778    0.288649    0.064045    0.036259    0.714838    
#> 464: 0.261704    1.130598    3.488779    0.288687    0.064054    0.036245    0.714785    
#> 465: 0.261727    1.130420    3.488814    0.288693    0.064032    0.036235    0.714835    
#> 466: 0.261762    1.130434    3.488778    0.288606    0.064019    0.036216    0.714839    
#> 467: 0.261777    1.130419    3.488879    0.288392    0.064037    0.036204    0.714758    
#> 468: 0.262046    1.130397    3.488998    0.288494    0.064007    0.036210    0.714706    
#> 469: 0.262138    1.130469    3.489062    0.288740    0.064041    0.036186    0.714719    
#> 470: 0.262022    1.130442    3.489093    0.288657    0.064070    0.036172    0.714761    
#> 471: 0.262097    1.130370    3.489156    0.288634    0.064032    0.036142    0.714837    
#> 472: 0.262179    1.130324    3.489174    0.288607    0.064075    0.036109    0.714862    
#> 473: 0.262050    1.130315    3.489189    0.288355    0.064079    0.036112    0.714878    
#> 474: 0.262060    1.130302    3.489189    0.288228    0.064079    0.036117    0.715002    
#> 475: 0.262137    1.130338    3.489202    0.288212    0.064056    0.036095    0.715074    
#> 476: 0.262214    1.130246    3.489204    0.288311    0.064033    0.036092    0.715123    
#> 477: 0.262094    1.130274    3.489236    0.288270    0.064000    0.036109    0.715084    
#> 478: 0.262045    1.130232    3.489256    0.288172    0.063980    0.036100    0.715102    
#> 479: 0.262178    1.130157    3.489318    0.288093    0.063943    0.036110    0.715084    
#> 480: 0.262270    1.130119    3.489395    0.287881    0.063935    0.036115    0.715147    
#> 481: 0.262270    1.130133    3.489374    0.287856    0.063981    0.036109    0.715078    
#> 482: 0.262313    1.130160    3.489349    0.287935    0.063999    0.036091    0.715053    
#> 483: 0.262366    1.130123    3.489323    0.288140    0.063995    0.036081    0.715025    
#> 484: 0.262367    1.129980    3.489344    0.288251    0.063927    0.036076    0.715055    
#> 485: 0.262436    1.129983    3.489426    0.288201    0.063890    0.036078    0.715116    
#> 486: 0.262466    1.130026    3.489477    0.288181    0.063881    0.036065    0.715098    
#> 487: 0.262711    1.130042    3.489565    0.288074    0.063912    0.036046    0.715079    
#> 488: 0.262707    1.130035    3.489608    0.288060    0.063898    0.036047    0.715055    
#> 489: 0.262812    1.130011    3.489611    0.288120    0.063913    0.036048    0.715035    
#> 490: 0.262847    1.130079    3.489654    0.288208    0.063935    0.036043    0.715004    
#> 491: 0.262950    1.130125    3.489705    0.288196    0.063961    0.036042    0.714905    
#> 492: 0.262972    1.130169    3.489702    0.288293    0.063975    0.036036    0.714889    
#> 493: 0.263006    1.130168    3.489754    0.288319    0.063974    0.036043    0.714851    
#> 494: 0.263150    1.130184    3.489779    0.288260    0.064010    0.036032    0.714803    
#> 495: 0.263233    1.130132    3.489821    0.288136    0.064006    0.036008    0.714753    
#> 496: 0.263405    1.130157    3.489840    0.288101    0.064041    0.035992    0.714739    
#> 497: 0.263338    1.130153    3.489831    0.288105    0.064082    0.035979    0.714725    
#> 498: 0.263304    1.130177    3.489742    0.288244    0.064090    0.035972    0.714685    
#> 499: 0.263303    1.130231    3.489690    0.288257    0.064115    0.035971    0.714622    
#> 500: 0.263308    1.130194    3.489642    0.288451    0.064102    0.035961    0.714585    
#> [====|====|=>-------------------------------------]  25%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [==>----------------------------------------------]  07%; 0:00:00 [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  [====|====|====|====|====|====|====|====|====|====] 100%; 0:00:00                                                                                  
fit2
#> ── nlmixr² SAEM OBJF by FOCEi approximation ──
#> 
#>  Gaussian/Laplacian Likelihoods: AIC(fit) or fit$objf etc. 
#>  FOCEi CWRES & Likelihoods: addCwres(fit) 
#> 
#> ── Time (sec fit$time): ──
#> 
#>            setup covariance  saem table compress    other
#> elapsed 0.001167   2.185006 2.265 0.035    0.022 1.359827
#> 
#> ── Population Parameters (fit$parFixed or fit$parFixedDf): ──
#> 
#>        Parameter  Est.     SE %RSE Back-transformed(95%CI) BSV(CV%) Shrink(SD)%
#> tka       Log Ka 0.454  0.211 46.5       1.57 (1.04, 2.38)     71.5   -0.0203% 
#> tcl       Log Cl  1.02 0.0739 7.28       2.76 (2.39, 3.19)     27.6      3.46% 
#> tv         Log V  3.45 0.0433 1.25       31.5 (28.9, 34.3)     13.4      9.89% 
#> add.sd           0.693                               0.693                     
#>  
#>   Covariance Type (fit$covMethod): boot200
#>     other calculated covs (setCov()): linFim
#>   No correlations in between subject variability (BSV) matrix
#>   Full BSV covariance (fit$omega) or correlation (fit$omegaR; diagonals=SDs) 
#>   Distribution stats (mean/skewness/kurtosis/p-value) available in fit$shrink 
#>   Censoring (fit$censInformation): No censoring
#> 
#> ── Fit Data (object fit is a modified tibble): ──
#> # A tibble: 132 × 19
#>   ID     TIME    DV  PRED    RES IPRED   IRES  IWRES eta.ka eta.cl   eta.v    cp
#>   <fct> <dbl> <dbl> <dbl>  <dbl> <dbl>  <dbl>  <dbl>  <dbl>  <dbl>   <dbl> <dbl>
#> 1 1      0     0.74  0     0.74   0     0.74   1.07   0.103 -0.491 -0.0820  0   
#> 2 1      0.25  2.84  3.27 -0.426  3.87 -1.03  -1.48   0.103 -0.491 -0.0820  3.87
#> 3 1      0.57  6.57  5.85  0.723  6.82 -0.246 -0.356  0.103 -0.491 -0.0820  6.82
#> # … with 129 more rows, and 7 more variables: depot <dbl>, center <dbl>,
#> #   ka <dbl>, cl <dbl>, v <dbl>, tad <dbl>, dosenum <dbl>
```
